//
// Copyright 2014 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Created by postproc-cld2 4.0 on 2014-01-31 09:58:05
// From command line:
//  --nearby_probs=2.5 --extra_entries=be-Cyrl bh-Deva bs-Latn hr-Latn
//  sr-Latn gl-Latn es-Latn id-Latn ms-Latn sv-Latn  --cld2 --cc
//  --just_read_raw --quad --standard --minchars=2 --mincount=2
//  --max_items_per_langscript=6000 --flatmap --rr_alloc --freq_alloc
//  --boostcloseweakerpercent=00 --indirectbits=16 --thresh=224 --v25
//  --kentries=192 --tablename=QuadChrome0122_19 --remap=xxx-Latn=>ut-Latn
//  tw-Latn=>ak-Latn nd-Latn=>nr-Latn blu-Latn=>hmn-Latn nn-Latn=>no-Latn
//  --include=af-Latn ar-Arab be-Cyrl bg-Cyrl bs-Latn ca-Latn cs-Latn
//  cy-Latn    da-Latn de-Latn el-Grek en-Latn es-Latn et-Latn fa-Arab
//  fi-Latn fr-Latn    ga-Latn gd-Latn hi-Deva hr-Latn hu-Latn id-Latn
//  is-Latn it-Latn iw-Hebr    ja-Hani ko-Hani lg-Latn lt-Latn lv-Latn
//  mk-Cyrl ms-Latn nl-Latn no-Latn    pl-Latn pt-Latn ro-Latn ro-Cyrl
//  ru-Cyrl rw-Latn sh-Cyrl sh-Latn sk-Latn sl-Latn sr-Cyrl    sv-Latn
//  sw-Latn th-Thai tl-Latn tr-Latn uk-Cyrl vi-Latn yi-Hebr    zh-Hani zh-TW
//  zhT-Hani    sq-Latn az-Latn eu-Latn bn-Beng gl-Latn ht-Latn mt-Latn
//  sr-Latn ur-Arab    bh-Deva mr-Deva ne-Deva lg-Latn rw-Latn gd-Latn
//  ut-Latn ut-Deva    ceb-Latn blu-Latn hmn-Latn jw-Latn    so-Latn ig-Latn
//  ha-Latn yo-Latn zu-Latn --ko_english --force_to_lang_soft --nosoft_cram2
//  --nomsidlevel --shapeflatprob --langpriorpercent=10 --skipnuc
//  --noshapeforcetop --noshapeeventop --noshapesteep2 --langcounts
//  --writebin --list_items=120 --max_langs_per_item=3
//  /hdb1/cld2/probs/p90_raw_quadgrams_2014.utf8
//
// CLD2_pslangs
//
// See compact_lang_det.cc for usage
//
#include "cld2tablesummary.h"
namespace CLD2 {

// For this build date, looking up 'qpdbmrmxyzptlkuuddlrlrbas' gives AZERBAIJANI
static const uint32 kQuadChrome0122_19BuildDate = 20140131;    // yyyymmdd


// Of 390154 offered items into 196608 table entries:
// 196417 filled (50%), 651 merged (0%), 193086 dropped (49%)

// Nil-grams: 19 languages
//     GREEK MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA PUNJABI
//     GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI CHEROKEE
//     SYRIAC LIMBU ORIYA INUKTITUT

// Uni-grams: 4 languages
//     Japanese Korean Chinese ChineseT

// Words/Quads: 67 languages in range ENGLISH..HMONG:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN
//     BULGARIAN CROATIAN SERBIAN IRISH GALICIAN TAGALOG TURKISH
//     UKRAINIAN HINDI MACEDONIAN BENGALI INDONESIAN MALAY WELSH
//     NEPALI ALBANIAN BELARUSIAN JAVANESE URDU BIHARI ARABIC CATALAN
//     BASQUE SCOTS_GAELIC SWAHILI SLOVENIAN MARATHI MALTESE
//     VIETNAMESE SLOVAK AZERBAIJANI PERSIAN BOSNIAN ZULU YIDDISH
//     SOMALI MONGOLIAN AFRIKAANS YORUBA HAUSA HAITIAN_CREOLE
//     KINYARWANDA GANDA IGBO CEBUANO HMONG

// TopLanguage  TokenCount
//  ENGLISH 2744
//  DANISH 2723
//  DUTCH 2735
//  FINNISH 2709
//  FRENCH 2721
//  GERMAN 2637
//  HEBREW 2661
//  ITALIAN 2525
//  NORWEGIAN 2735
//  POLISH 2720
//  PORTUGUESE 2701
//  RUSSIAN 2633
//  SPANISH 3604
//  SWEDISH 3997
//  CZECH 5471
//  ICELANDIC 2679
//  LATVIAN 2692
//  LITHUANIAN 2709
//  ROMANIAN 5308
//  HUNGARIAN 2730
//  ESTONIAN 2702
//  BULGARIAN 2619
//  CROATIAN 4044
//  SERBIAN 6103
//  IRISH 2723
//  GALICIAN 3611
//  TAGALOG 2437
//  TURKISH 2699
//  UKRAINIAN 2591
//  HINDI 5268
//  MACEDONIAN 2635
//  BENGALI 2688
//  INDONESIAN 4187
//  MALAY 2911
//  WELSH 2715
//  NEPALI 2691
//  ALBANIAN 2711
//  BELARUSIAN 3855
//  JAVANESE 2725
//  URDU 2705
//  BIHARI 4276
//  ARABIC 2648
//  CATALAN 2680
//  BASQUE 2716
//  SCOTS_GAELIC 2752
//  SWAHILI 2741
//  SLOVENIAN 2717
//  MARATHI 2587
//  MALTESE 2710
//  VIETNAMESE 2698
//  SLOVAK 2721
//  AZERBAIJANI 2739
//  PERSIAN 2696
//  BOSNIAN 2935
//  ZULU 2682
//  YIDDISH 2625
//  SOMALI 2719
//  MONGOLIAN 15
//  AFRIKAANS 2723
//  YORUBA 2715
//  HAUSA 2646
//  HAITIAN_CREOLE 2709
//  KINYARWANDA 2719
//  GANDA 2750
//  IGBO 2655
//  CEBUANO 2254
//  HMONG 2186



// Recognized language-script combinations [69]:
static const char* const kQuadChrome0122_19RecognizedLangScripts =
  "af-Latn ar-Arab az-Latn be-Cyrl bg-Cyrl bh-Deva bn-Beng bs-Latn "
  "ca-Latn ceb-Latn cs-Latn cy-Latn da-Latn de-Latn en-Latn es-Latn "
  "et-Latn eu-Latn fa-Arab fi-Latn fr-Latn ga-Latn gd-Latn gl-Latn "
  "ha-Latn hi-Deva hmn-Latn hr-Latn ht-Latn hu-Latn id-Latn ig-Latn "
  "is-Latn it-Latn iw-Hebr jw-Latn lg-Latn lt-Latn lv-Latn mk-Cyrl "
  "mn-Latn mr-Deva ms-Latn mt-Latn ne-Deva nl-Latn no-Latn pl-Latn "
  "pt-Latn ro-Cyrl ro-Latn ru-Cyrl rw-Latn sk-Latn sl-Latn so-Latn "
  "sq-Latn sr-Cyrl sr-Latn sv-Latn sw-Latn tl-Latn tr-Latn uk-Cyrl "
  "ur-Arab vi-Latn yi-Hebr yo-Latn zu-Latn ";

static const uint32 kQuadChrome0122_19Size = 32768;    // Bucket count
static const uint32 kQuadChrome0122_19KeyMask = 0xffff8000;    // Mask hash key

static const IndirectProbBucket4 kQuadChrome0122_19[kQuadChrome0122_19Size] = {
  // hash_indirect[4], tokens[4] in UTF-8
   {{0xe9da0002,0xe2970003,0x7c2e0004,0x20078005}},	// [000] вка_, аат_, ssbr, _huni_,
   {{0x20078006,0x64438007,0xbddb0008,0x23bf0009}},	//   _kuni_, kuni, stèr, täjä_,
   {{0xddc4000a,0x6563800b,0x52e2800c,0x02e2800d}},	//   _križ, denh, _पर्स, _पर्न,
   {{0x6443800e,0x4916000f,0x63bb8010,0x20078011}},	//   duni, _प्रो_, jiun, _muni_,
   {{0x20078012,0x3ea08013,0x27ed8014,0x63a98015}},	//   _luni_, áit_, _dhen_, dhen,
   {{0x65638016,0x64438017,0x6fdd0018,0xef1f0019}},	//   genh, funi, léct, tjük_,
   {{0x6443801a,0x3ea0801b,0x2451801c,0x2007801d}},	//   guni, šit_, _cơm_, _nuni_,
   {{0x63bb801e,0xef1f0019,0x63a9801f,0x6fdd0020}},	//   giun, rjük_, ghen, néct,
   {{0x36678021,0x65638022,0xa3ab0023,0x2fc68024}},	//   _като_, benh, कोट_, mnog_,
   {{0x2fc68025,0x64438026,0x645e0009,0x20078027}},	//   lnog_, buni, _oppi, _buni_,
   {{0x2b9c0028,0x75288029,0x63bb802a,0x6aad002b}},	//   _tích_, _iedz, biun, zzaf,
   {{0x63a9802c,0x4ea7002d,0x63bb802e,0x2252002f}},	//   chen, арга, ciun, ktyk_,
   {{0x69dc0030,0x645e0031,0xadc38032,0x6b828033}},	//   _okre, _appi, _atẹn, _inog,
   {{0x6e240034,0x75288035,0x2b988036,0x20078037}},	//   _dwib, _jedz, _vécu_, _funi_,
   {{0x75288038,0x89378039,0xddc40024,0x212c8014}},	//   _medz, _כרגע_, _friž, madh_,
   {{0x2fc6803a,0x248d003b,0x212c803c,0xf699003d}},	//   jnog_, ćem_, ladh_, _منبع_,
   {{0x6b82803b,0x2fc68025,0x7afd803e,0xafb8003f}},	// [010] _mnog, dnog_, žstv, _خطوط_,
   {{0x212c803c,0x63bb802e,0x64438040,0x20078041}},	//   nadh_, ziun, yuni, _yuni_,
   {{0x6b828042,0x69d70043,0x65638044,0x27ed8045}},	//   _onog, roxe, venh, _phen_,
   {{0x212c8046,0x69dc0047,0xa8040048,0xc7c48049}},	//   hadh_, _ekre, ізіл, осчи,
   {{0x44310019,0x75288035,0x63a9804a,0x672b804b}},	//   lsz_, _bedz, vhen, ragj,
   {{0x27ed804c,0x6443804d,0x9474004e,0x26df804f}},	//   _when_, tuni, _ادیا, _vyuo_,
   {{0x63bb8012,0x65638050,0x2fc68024,0x27ed8051}},	//   tiun, renh, bnog_, _then_,
   {{0x2fc68052,0x65638053,0xa3ab0054,0x20078055}},	//   cnog_, senh, कोच_, _runi_,
   {{0xe9d98056,0x63a98057,0x64438058,0x29188059}},	//   лки_, rhen, suni, ıran_,
   {{0x212c803c,0x63bb805a,0x63a9805b,0x2007805c}},	//   gadh_, siun, shen, _puni_,
   {{0x63a9805d,0xa3d7005e,0x6616005f,0x8d748060}},	//   phen, ाका_, _styk, _باقا,
   {{0x44310061,0x66018062,0x6fdd002a,0xd5438032}},	//   dsz_, _hilk, xéct, _fẹ̀f,
   {{0x66018063,0xeab38064,0x7e6d0065,0x67298066}},	//   _kilk, _بعض_, _csap, _meej,
   {{0x2fc68067,0x212c8068,0x67298069,0xb21b006a}},	//   znog_, cadh_, _leej, _kræf,
   {{0x1015806b,0x64a3006c,0xfce6006d,0x7e6d006e}},	//   _ابتد, пара, сово, _esap,
   {{0x69dc006f,0xee3f003e,0x260a8006,0x67298070}},	//   _skre, brý_, ादमी_, _neej,
   {{0x2fc6803a,0x0aea0071,0x3a3f802a,0x28a58072}},	// [020] vnog_, удай_, nrup_, खनवि,
   {{0xa5bb0073,0x46db8074,0x31710037,0xda0a8075}},	//   ssór, _बड़ह, _cazz_, _हंसत_,
   {{0x2fc6803a,0xaad80076,0x75288029,0x7e7b8077}},	//   tnog_, _भुरक, _redz, _arup,
   {{0xbb860013,0x43860013,0xfdb0800f,0xa3e7800f}},	//   _الحي, _الحق, जफ्फ, _मील_,
   {{0x2fc68025,0x66018078,0x65948009,0x291e8079}},	//   rnog_, _bilk, жалу, ybta_,
   {{0x69dc007a,0x3a3f806a,0xdb16007b,0x8e57007c}},	//   _ukre, drup_, ábær, מינג_,
   {{0x2fc6805c,0x3860807d,0x66018079,0xe644807e}},	//   pnog_, _ćiro_, _dilk, ğlığ,
   {{0x5214807f,0xe6448059,0x79838080,0x53988081}},	//   одит, şlığ, _annw, рвия_,
   {{0x22400082,0x212c8083,0xa92a8084,0x6fc80085}},	//   nrik_, tadh_, ліне_, rıcl,
   {{0x388e8086,0xf96a8087,0x20098088,0x44310035}},	//   ləri_, урий_, _čair_, ysz_,
   {{0x212c803c,0x22400089,0x6729808a,0xdb0d008b}},	//   radh_, hrik_, _yeej, knað,
   {{0x212c808c,0x6601808d,0x212a008e,0x96f9008f}},	//   sadh_, _zilk, _lebh_, иент_,
   {{0x4ad80076,0x212c8090,0x9f588091,0x44310092}},	//   _भुलव, padh_, _burú_, wsz_,
   {{0x44310019,0x22400093,0x66018079,0x6d4a8094}},	//   tsz_, drik_, _xilk, ngfa,
   {{0x69da8095,0x79950063,0xe8d98028,0x69c88096}},	//   mote, _rozw, _đủ_, mnde,
   {{0x7ae28097,0x67d40098,0x22400099,0xdb0d007b}},	//   _kyot, _нощу, frik_, gnað,
   {{0x7995009a,0x44310019,0xddc2809b,0x7e6d009c}},	// [030] _pozw, ssz_, dvož, _usap,
   {{0x69da809d,0x672f0063,0x69c8809e,0x6441009f}},	//   note, lacj, nnde, àlis,
   {{0xe71980a0,0x439500a1,0x388e8085,0x644100a2}},	//   ليات_, _данс, fəri_, álid,
   {{0x644700a3,0x200a00a4,0xe00b80a5,0x672f0035}},	//   muji, _dubi_, _संसद_, nacj,
   {{0x69da80a6,0x660180a7,0x63ad00a8,0x7e7b8085}},	//   kote, _pilk, mhan, _qrup,
   {{0x63ad00a9,0x69da80aa,0xcfcf00ab,0xd6580039}},	//   lhan, jote, রতিন, ציות_,
   {{0x660180ac,0x645500ad,0x672f0063,0x200a0052}},	//   _vilk, ntzi, kacj, _gubi_,
   {{0x36d580ae,0xeb9980af,0x69c880b0,0x7e7b80b1}},	//   _добр, рии_, ende, _trup,
   {{0x660180b2,0xbfa880b3,0x7e7b80b4,0x69da80b5}},	//   _tilk, _утре_, _urup, fote,
   {{0x499980b6,0xfeb880b7,0x644700b8,0x3b1f80b9}},	//   ртия_, _طاقت_, kuji, sbuq_,
   {{0xa3e900ba,0xe2a88077,0x63ad00bb,0xfbd900bc}},	//   यता_, لاین_, khan, भकाम,
   {{0x69c880bd,0x9986809a,0x14d680be,0xaa5980bf}},	//   ande, _ktoś_, _וועל_, _виду_,
   {{0x63ad00c0,0x69da80c1,0xc8e600c2,0xddc400c3}},	//   dhan, bote, _कर्म_, _asiš,
   {{0x98a580c4,0xa0a580c5,0x7bc980c6,0x63ad00c7}},	//   _миле, _малд, lneu, ehan,
   {{0x09c400c8,0x63ad00c9,0x8b9600ca,0x3b9600a9}},	//   ্তমা, fhan, орач, ојат,
   {{0x63ad00cb,0x7bc980cc,0x2fcd80cd,0x7c3a00ce}},	//   ghan, nneu, _njeg_, štro,
   {{0xa3bb00cf,0x27e000d0,0x200a00d1,0x7c2900d2}},	// [040] _अगर_, _ikin_, _subi_, ćera,
   {{0x224000d3,0x0f2280d4,0x2b4f808e,0x2b58003d}},	//   rrik_, मर्स_, _lcgc_, _گیرد_,
   {{0xc8ca00d5,0x106a00d6,0x13a800d7,0x7bc980d8}},	//   جوان_, рией_, _هندی_, kneu,
   {{0x68e380d9,0x63ad00da,0xa3ae001b,0x69da80db}},	//   _mynd, chan, _कति_, zote,
   {{0xa3d700dc,0x27e000dd,0x69da80de,0x69c68061}},	//   ाकर_, _mkin_, yote, ékek,
   {{0x672f0063,0x200a00df,0x63a400e0,0x644100e1}},	//   zacj, _tubi_, lkin, šlie,
   {{0x07a680e2,0x6d4a80e3,0x7ae280e4,0x201800e5}},	//   _давн, rgfa, _syot, _utri_,
   {{0x63a400e6,0x7bc980e7,0x81e780ab,0xd32680e8}},	//   nkin, gneu, _মূল_, цьки,
   {{0x298a80e9,0x63a400ea,0xdcfe00eb,0xb21b00ec}},	//   асно_, ikin, _kopē, _græd,
   {{0x69c880ed,0x7ae2804f,0x2a6200ee,0x27e680ef}},	//   unde, _vyot, _mpkb_, llon_,
   {{0x200480f0,0x201880f1,0xdb060019,0x672f009a}},	//   _kimi_, ëri_, _elké, tacj,
   {{0x290780f2,0x63a400f3,0x69da80f4,0x27e680f5}},	//   _egna_, jkin, sote, nlon_,
   {{0x200480f6,0x672f0063,0xd25080f7,0x69da80f8}},	//   _mimi_, racj, _أنت_, pote,
   {{0x7bc080f9,0x200480fa,0x27e680fb,0x63ad00fc}},	//   limu, _limi_, hlon_, whan,
   {{0x63ad00fd,0x27e6803b,0x63a400fe,0x261080ff}},	//   than, klon_, fkin, _lào_,
   {{0x20048100,0x2a620101,0x64550102,0x52150103}},	//   _nimi_, _bpkb_, rtzi, здат,
   {{0x26108104,0xe8108105,0xdb0b8106,0x1dbc8107}},	// [050] _nào_, _ठंडा_, _umgå, ्चात,
   {{0x63ad0108,0x7bc08109,0xddc2809a,0x6447010a}},	//   shan, himu, rtoś, puji,
   {{0x672d010b,0x660d010c,0x63a4010d,0x7bc0810e}},	//   _keaj, _huak, bkin, kimu,
   {{0x63a40039,0xf093810f,0x261080ff,0x7bc08110}},	//   ckin, ונע_, _bào_, jimu,
   {{0xa3e40105,0x7bc08111,0xa77c00be,0x660500b9}},	//   _पीट_, dimu, יראפ, _kihk,
   {{0x98a5802e,0x5a340112,0x99640113,0x7bc98114}},	//   nală_, _інст, _отсл, wneu,
   {{0xdd8e80f7,0x22490102,0x20048115,0x27e68116}},	//   اوى_, luak_, _fimi_, blon_,
   {{0xd90e0117,0xdb028118,0x7bc08119,0xb21b006a}},	//   _لیے_, _eloí, gimu, _træd,
   {{0x76428036,0xdce3811a,0x2249011b,0x68e6811c}},	//   croy, menč, nuak_, əkdi,
   {{0x661b811d,0x63a4011e,0x2004811f,0xae44803d}},	//   _ituk, zkin, _zimi_, _آپلو,
   {{0x63a40120,0x7bc08121,0x660d0122,0x7bc98123}},	//   ykin, bimu, _auak, pneu,
   {{0xf7720124,0x6d410125,0x2249011b,0x6e298126}},	//   راج_, ólan, kuak_, _kweb,
   {{0xa3ca8127,0xa3c10128,0x290780ee,0x26108129}},	//   ोवर_, ्चन_, _tgna_, _xào_,
   {{0xdd920077,0x427a812a,0x67228024,0x7c29012b}},	//   روز_, _לאנג, zboj, ćern,
   {{0x63a4012c,0x27e6812d,0x69c1812e,0x9479012f}},	//   tkin, ylon_, mile, осту_,
   {{0x69c18130,0x6f098131,0xdce38132,0xfd4c8133}},	//   lile, _ngec, jenč, _belụ,
   {{0xc64a0013,0xeb970134,0x69c18083,0x6e298135}},	// [060] _اجعل_, чит_, oile, _nweb,
   {{0x20048136,0x63a40137,0xb6bb0051,0x867b012a}},	//   _simi_, skin, _לצפי, _פריו,
   {{0x63a40138,0x036a0139,0xfce6013a,0x661b813b}},	//   pkin, _линк_, _хоно, _atuk,
   {{0xb21b013c,0x69c1813d,0x2249013e,0x2d9a0039}},	//   _dræb, hile, buak_, _hope_,
   {{0x69c1813f,0x672280eb,0x7bc08110,0xddc98140}},	//   kile, rboj, vimu, _drež,
   {{0x6d4e0141,0x26108142,0x6d5c0143,0x76428144}},	//   ngba, _vào_, nfra, rroy,
   {{0x69c18145,0x6e298146,0x27e68147,0x20048148}},	//   dile, _eweb, plon_, _timi_,
   {{0x69de0149,0x7e6400d2,0x65ab0085,0x7642814a}},	//   lope, _opip, _müha, proy,
   {{0xadc38028,0x7bc0814b,0xe944803d,0x9d46814c}},	//   _quản, rimu, وردی, _неад,
   {{0x7bc0814d,0x69c1814e,0x6d4e00f3,0x69de014f}},	//   simu, gile, jgba, nope,
   {{0x7bc08150,0x672d0151,0x290a0135,0xe8df00ff}},	//   pimu, _peaj, _mgba_, _trục_,
   {{0x37ab0152,0xeb978153,0xd36f8154,0x660d00ee}},	//   стон_, _них_, _مهم_, _puak,
   {{0x69c18155,0x6d5c0156,0x69de0157,0xe3b38158}},	//   bile, ffra, kope, _אױף_,
   {{0x72eb8159,0x69c1815a,0xe9448077,0xf9c4815b}},	//   _פֿאַ, cile, _آرشی, _تحصی,
   {{0xd5c88104,0x98a58087,0x7c29012b,0xe7e8015c}},	//   yền_, rală_, ćero, _टीका_,
   {{0x2249011e,0x660d015d,0x290a015e,0x6d4e015f}},	//   tuak_, _tuak, _agba_, agba,
   {{0xb9990160,0xdce38161,0x98a58162,0x644a0163}},	// [070] овах_, venč, pală_, _åfin,
   {{0x5c070098,0x644a8164,0x22490102,0xc1788110}},	//   _няма, kufi, ruak_, ndė_,
   {{0x3ea60029,0xddc98165,0x661b8166,0x2249011b}},	//   _ļoti_, _prež, _stuk, suak_,
   {{0x69c18167,0x6443807a,0x65770168,0x290a0032}},	//   zile, vrni, _haxh, _egba_,
   {{0x69c18169,0x7bdf016a,0xee3880e8,0xddc98088}},	//   yile, moqu, зні_, _vrež,
   {{0x7bdf00a2,0x050100ab,0xddd6016b,0xfce5816c}},	//   loqu, ্রীর_, _kryš, моло,
   {{0x6458816d,0x200e8041,0x65770168,0x6443816e}},	//   gtvi, _nufi_, _maxh, urni,
   {{0x09b7816f,0x7bcd0170,0x22158171,0x64c50115}},	//   ेच्य, nnau, мфор, _ičić,
   {{0x69c18172,0x6d5c0114,0x661b8173,0xd24e8174}},	//   tile, yfra, _utuk, لني_,
   {{0x7bcd0175,0x23c38176,0x6d410177,0x10a58178}},	//   hnau, _bèjè_, ólal, дион,
   {{0x69c18179,0x5455817a,0xe3c2017b,0xf746017c}},	//   rile, _цвет, lmış_, мено,
   {{0x69c1817d,0xd24e817e,0x7c3a017f,0xe2918180}},	//   sile, دنی_, štrk, _لذت_,
   {{0x65b00181,0xe3c20182,0x6d5c0183,0x69c18184}},	//   _lähe, nmış_, tfra, pile,
   {{0x90c58185,0x7ae60186,0x65ab0074,0x69de0187}},	//   _обле, _rykt, _püha, xope,
   {{0xfce30188,0x6d5c0189,0x7bdf018a,0xa507018b}},	//   воро, rfra, foqu, дера_,
   {{0x8ffa003d,0x320f808e,0x764b818c,0x6441018d}},	//   _برتر_, _kugy_, kugy, ália,
   {{0xd5b20019,0x2fc0018e,0x7c248115,0x3207818f}},	// [080] _لفظ_, _imig_, ćiri, _kiny_,
   {{0xb1430190,0xa0a60191,0x320f810c,0x65ab0192}},	//   кнул, мазд, _mugy_, _hühn,
   {{0xeb9a0193,0x69de0194,0xb21b006a,0x8b260195}},	//   _дин_, rope, _præc, _одне,
   {{0xfaa60196,0x46ea80b3,0x201c00eb,0xddc98197}},	//   _жамо, оден_, īvi_, _ereż,
   {{0x65b00198,0xfe6f8199,0x05d20035,0x69de019a}},	//   _tähd, لدو_, _सदाब, pope,
   {{0x6458819b,0x443a019c,0x290a019d,0x644a819e}},	//   ttvi, _kvp_, _ugba_, tufi,
   {{0xd90d019f,0x910301a0,0x443a00c3,0x443801a1}},	//   _ایم_, _апре, _jvp_, nsr_,
   {{0xda088104,0x28bd01a2,0x645881a3,0x02a681a4}},	//   _hỏi_, ्परि, rtvi, дром,
   {{0x200e81a5,0x961880ab,0x6f09016b,0x6aa401a6}},	//   _sufi_, _ডটকম_, žeck, nyif,
   {{0x6e2281a7,0xb5aa81a8,0x443800b9,0x67d201a9}},	//   mpob, _بارك_, ksr_, vāja,
   {{0x26ee81aa,0xda0880ff,0xa3ae01ab,0x65ab0192}},	//   _जरुर_, _mỏi_, कसा_, _bühn,
   {{0xdce501ac,0x67d200eb,0x733681ad,0x338381ae}},	//   _pohľ, tāja, _آرائ, _аушв,
   {{0xa3e781af,0x799c01b0,0x7bdf01b1,0x200e80b9}},	//   _मीट_, _oorw, voqu, _wufi_,
   {{0x58d481b2,0x29070110,0xdb0b81b3,0x660881b4}},	//   _полт, žnai_, _algè, _jidk,
   {{0x7bdf00a9,0x66088079,0x9f588144,0xd13981b5}},	//   toqu, _midk, _juró_, _ххі_,
   {{0x26ee81b6,0x628281b7,0x67d200eb,0x53de816f}},	//   _जरूर_, _kroo, pāja, मविश,
   {{0x7bcd01b8,0x050100ab,0xddc981b9,0x799c01ba}},	// [090] rnau, ্রের_, _preż, _borw,
   {{0x51f801bb,0xaca301bc,0x2a6680ee,0xd13101bd}},	//   дную_, _arụg, _mpob_, اما_,
   {{0x753501be,0x200901bf,0x9f9c808b,0x443a01c0}},	//   mazz, _kiai_, tíð_, _gvp_,
   {{0x753501c1,0x65b001c2,0x6e2d01c3,0xa635804a}},	//   lazz, _vähe, _kwab, енді,
   {{0x59de81c4,0x628281c5,0x6e2d008e,0x799c01c6}},	//   नकार, _nroo, _jwab, _forw,
   {{0x753501b9,0x65b00006,0x9f588144,0xba430084}},	//   nazz, _tähe, _buró_, žįst,
   {{0x76598114,0x628281c7,0x3ea981c8,0x64c50088}},	//   stwy, _aroo, šat_, _učić,
   {{0x6f0d01c9,0x9f5881ca,0x6aca81cb,0xe3c201cc}},	//   _ngac, _duró_, ापूर, pmış_,
   {{0x753501cd,0xb4bc01ce,0x020581cf,0x67f601d0}},	//   kazz, _अध्_, нзин, náje,
   {{0xf9918013,0x628280c9,0x6b9d01d1,0x7c3a017f}},	//   ابة_, _droo, _losg, štri,
   {{0xa3c101d2,0xfc3080f7,0x2011004f,0x39588014}},	//   ्चा_, _نحن_, _juzi_, òrsa_,
   {{0x6e2d01d3,0x201101d4,0x69c501d5,0x248601d6}},	//   _bwab, _muzi_, hihe, _čom_,
   {{0xee3701d7,0x628281d8,0xa68301d9,0x6b8b81da}},	//   ння_, _groo, гляд, _ingg,
   {{0xceb281db,0x753501dc,0x7c2201dd,0x236d81de}},	//   נים_, gazz, _čorb, leej_,
   {{0x77a601df,0xdb0b80e7,0x69c501e0,0x6b9d01e1}},	//   _lóxi, _algé, dihe, _bosg,
   {{0xddcd01e2,0x63a981e3,0x2009001c,0x6b9d01e4}},	//   _graž, nken, _giai_, _cosg,
   {{0x6b6301e5,0xe8df801c,0x799c01e6,0x6b8b80dd}},	// [0a0] ыкта, _khỏi_, _porw, _mngg,
   {{0x61e181e7,0x753501e8,0x236d81e9,0x63a981ea}},	//   noll, cazz, heej_, hken,
   {{0x63a981eb,0x799c01ec,0x6b9d01e4,0x03a60087}},	//   kken, _vorw, _fosg, _зино,
   {{0x201100d2,0x63a981ed,0x644e01ee,0x61e181ef}},	//   _duzi_, jken, mubi, holl,
   {{0x61e181f0,0x63a9813c,0x99800110,0xdfcf81a8}},	//   koll, dken, usių_, حين_,
   {{0x6b8b81f1,0xdd9080f7,0x63a981f2,0xda088129}},	//   _angg, شوب_, eken, _tỏi_,
   {{0x186701f3,0x316c81ac,0x201101f4,0x61e181f5}},	//   _пари_, vedz_, _guzi_, doll,
   {{0x2a66808e,0x67d201a9,0x7c38800b,0x656e01f6}},	//   _ppob_, dājo, rsvr, hebh,
   {{0x645c01f7,0x644e01f8,0xdd8f81f9,0x6d4101fa}},	//   htri, hubi, _گول_, ólak,
   {{0x6b8b81fb,0x644e01fc,0xbddb01fd,0x6e2d00b4}},	//   _engg, kubi, trèm, _rwab,
   {{0xa3d001fe,0x753501ff,0x2d8c8200,0xd8f880e8}},	//   वचा_, vazz, _inde_, ьної_,
   {{0x645a8201,0x63a98202,0xe7cf00ab,0x657a8203}},	//   _iqti, cken, রত্য, _hath,
   {{0x657a8204,0x2d9e8205,0x61e18206,0xb5fb0207}},	//   _kath, _kote_, boll, ntág,
   {{0x61e18208,0xd12f8077,0xb21b013c,0x2d9e8168}},	//   coll, _همه_, _bræn, _jote_,
   {{0xddcd0209,0x753501cd,0x6b9d020a,0xa4d400e8}},	//   _traž, razz, _posg, горі,
   {{0x657a820b,0x6e2d020c,0x3ea6820d,0x25dc820e}},	//   _lath, _twab, kyot_, मकुण,
   {{0x245a820f,0x2d8c8210,0x75350211,0x21310176}},	// [0b0] hëm_, _onde_, pazz, _pezh_,
   {{0x657a8212,0xdb0d00f7,0x2d9e8213,0x3eb30214}},	//   _nath, mhaí, _note_, ıntı_,
   {{0xb21b0215,0x644e0216,0x69c50217,0x645c0218}},	//   _græn, cubi, rihe, ctri,
   {{0x44210219,0x201c021a,0x61fe021b,0x69c5021c}},	//   _ith_, ívia_, ampl, sihe,
   {{0x2d9e821d,0xe618821e,0x3ea6821f,0x8b9a0039}},	//   _bote_, еді_, gyot_, _חברת,
   {{0x7bc28220,0xbea28221,0x2d9e8222,0x644800eb}},	//   _amou, рашк, _cote_, šdie,
   {{0x61e18223,0x657a8224,0xeb998225,0xabd58226}},	//   voll, _dath, дий_, кциј,
   {{0x2d8c8227,0x77a60228,0xc1788110,0x657a8229}},	//   _ende_, _tóxi, klės_, _eath,
   {{0x61e1822a,0x853c8084,0xddcd022b,0x98ac81a9}},	//   toll, _plėt, _braż, vadā_,
   {{0x926480f7,0x236d822c,0xb5fb0118,0x777b811b}},	//   اديم, seej_, ntád, _haux,
   {{0xb604000d,0x645c022d,0xe80b8105,0x6b8b80dd}},	//   ntář, xtri, _सूखा_, _tngg,
   {{0x2d9e822e,0x6b8b822f,0x22490230,0x61e18231}},	//   _zote_, _ungg, krak_, soll,
   {{0x2d9e822e,0x61e18232,0x44210233,0x657a8234}},	//   _yote_, poll, _ath_, _yath,
   {{0x645c0235,0xa5bb0236,0x61458237,0x644e0238}},	//   ttri, spón, _река, tubi,
   {{0xb0248104,0x44210239,0xfce6006d,0x22490102}},	//   _trườ, _cth_, тово, erak_,
   {{0x1e86023a,0xf41380ab,0x764f023b,0x2c7c81d0}},	//   _алим, _সবার_, bucy, ládá_,
   {{0xc332804c,0x6d41803a,0x2619023c,0x644e023d}},	// [0c0] יון_, _odla, _यूपी_, subi,
   {{0xb21b0022,0x3f8d823e,0xa92480e1,0xe9d7023f}},	//   _træn, _aneu_, peľň, вку_,
   {{0x657a8240,0x2d9e8241,0x7e698242,0x7aeb8243}},	//   _rath, _rote_, _apep, _lygt,
   {{0x6d418244,0xdce88038,0x2d9e8245,0x22490246}},	//   _adla, _podľ, _sote_, brak_,
   {{0x2d9e8247,0xa3c10054,0x69c38248,0xeb970249}},	//   _pote_, ्चर_, _omne, _рия_,
   {{0x245a820f,0x2fc68110,0x44210101,0x7c3a024a}},	//   tëm_, siog_, _yth_, štru,
   {{0x6da3824b,0x6aca824c,0x629d8106,0x2d9e824d}},	//   рија, ाप्र, äson, _vote_,
   {{0x2d9e822e,0x6286024e,0x657a805d,0x8fa3824f}},	//   _wote_, _krko, _wath, _касе,
   {{0xe73781a1,0xa6658250,0xcb678251,0x2d9e8252}},	//   _шет_, _مطلو, тање_, _tote_,
   {{0x2d8c8012,0x657a80f7,0x601e80eb,0x62860253}},	//   _unde_, _uath, _līme, _mrko,
   {{0x31370039,0x7f590254,0x22490255,0x1cba8061}},	//   כנים_, нанс_, zrak_, _غائب_,
   {{0x97a70256,0x69c38257,0xdb0d00f7,0x1fa70258}},	//   трол, _emne, thaí, трог,
   {{0xecdb000f,0xdddb8259,0xa2c2025a,0x629601c0}},	//   _मुजफ, _hruš, _रेल्, jxyo,
   {{0xdddb825b,0x765d025c,0xdbd1808b,0x764f018e}},	//   _kruš, rtsy, lýðs, rucy,
   {{0xd5b8025d,0xb4ad025e,0xa3d680c2,0x81d800ab}},	//   тся_, कने_, _सदा_, াতা_,
   {{0x6286012b,0x644a81a8,0x7d080061,0x9cd7825f}},	//   _brko, irfi, _sérü, דולה_,
   {{0x27e90260,0x62848084,0x443c8088,0x777b8261}},	// [0d0] _ikan_, _šioj, hsv_, _raux,
   {{0x224900ad,0x69c88262,0x645a009f,0x23b180e1}},	//   rrak_, nide, àtic, _mája_,
   {{0x290700f2,0x62860263,0x981401a8,0x4cc10264}},	//   äna_, _erko, لبنا, _শুরু,
   {{0x63b60265,0x69c88266,0x75220267,0x22490268}},	//   chyn, hide, _đozi, prak_,
   {{0x69c88269,0x2509026a,0x3f8181d0,0xadc4026b}},	//   kide, _ترکی_, ěhu_, _arẹw,
   {{0x24858101,0x2b59026c,0x6d55026d,0xf483803d}},	//   _prlm_, _hcsc_, ngza, لاعی,
   {{0x27e9026e,0x61e5026f,0x69c88270,0x25a101d0}},	//   _okan_, mohl, dide, _mohl_,
   {{0x63ad0271,0xb5fb0272,0xdb098073,0xaca3019d}},	//   nkan, ntáb, nheç, _abịd,
   {{0x443e8273,0x1a65826a,0x7e69804f,0xb5fb0118}},	//   _evt_, ایتی_, _upep, itáb,
   {{0x27e90274,0x69c88275,0x63ad0057,0x6d418276}},	//   _akan_, gide, hkan, _udla,
   {{0xcea90158,0xcb558277,0x8fa60278,0x64410279}},	//   _צי_, _مناظ, гане, šlij,
   {{0x63ad027a,0x61e5027b,0x69c8827c,0x2619827d}},	//   jkan, hohl, aide, _kèo_,
   {{0x69c880ad,0xe1ee827e,0x200d8098,0xdddb827f}},	//   bide, _гг_, _miei_, _zruš,
   {{0x27e90280,0x63ad0281,0x237d8282,0x7bc98283}},	//   _ekan_, ekan, _hawj_, lieu,
   {{0x98ac8162,0xbb460284,0x225f8285,0x63b60286}},	//   radă_, левк, ltuk_, thyn,
   {{0x7bc98287,0xc0528051,0x63ad0288,0x62860289}},	//   nieu, _הזה_, gkan, _prko,
   {{0x225f828a,0xe1fa028b,0x63b6028c,0x6abb81ec}},	// [0e0] ntuk_, ега_, rhyn, nzuf,
   {{0x63ad028d,0x237d822c,0x6e240214,0x7c3e0115}},	//   akan, _lawj_, _itib, _tvpr,
   {{0x11d70013,0xdca6028e,0x9c7c828f,0x70560290}},	//   دولة_, _сани, _tyči, انصا,
   {{0x69c88291,0x63ad0292,0xee3a8293,0x237d8282}},	//   zide, ckan, енд_, _nawj_,
   {{0xdddb8067,0x443e816d,0x56948162,0x6da68294}},	//   _sruš, _svt_, ралт, лида,
   {{0x443e8295,0xdddb8296,0x2816003d,0x644a8088}},	//   _pvt_, _pruš, _موسس, trfi,
   {{0x657e0297,0xb5fb0298,0x66160299,0xdd32029a}},	//   _maph, ltác, _luyk, zəşt,
   {{0x657e029b,0x7bc9829c,0x7f440168,0x69c8829d}},	//   _laph, gieu, _ndiq, wide,
   {{0x69c8829e,0xb5fb029f,0x237d81c0,0x6e2402a0}},	//   tide, ntác, _dawj_, _ntib,
   {{0xd6cf8277,0x657e0234,0x27e682a1,0xb33b02a2}},	//   _عقل_, _naph, loon_, _moça,
   {{0x63ad02a3,0x0c2682a4,0xdddb82a5,0x6b9b82a6}},	//   ykan, _смен, _uruš, bjug,
   {{0x27e682a7,0x7bc980e7,0x7a868019,0x644101a9}},	//   noon_, cieu, _مشتم, šlik,
   {{0xb8eb82a8,0x199482a9,0x78ba8019,0x657e0234}},	//   _रे_, _валя, sztv, _baph,
   {{0x27e682aa,0x2d9c80f1,0x63a28074,0x2a79018e}},	//   hoon_, njve_, _hoon, _rssb_,
   {{0x63a282ab,0xf36702ac,0x63ad02ad,0x27e682ae}},	//   _koon, лтан, tkan, koon_,
   {{0x764b8286,0x25a102af,0x63a282b0,0x67f600e1}},	//   yrgy, _wohl_, _joon, pája,
   {{0x6d5a82b1,0x65ab0074,0x27e681b4,0x38c90019}},	// [0f0] _octa, _lühi, doon_, ھائی_,
   {{0x63ad02b2,0x63a282b3,0x26188105,0x2bc602b4}},	//   skan, _loon, _पढ़ी_, रोबा,
   {{0x44ce8086,0x27e682b5,0x63ad02b6,0xb5fb02b7}},	//   _nə_, foon_, pkan, ptáb,
   {{0x63a282b8,0xbddb00e7,0x27e682b9,0x61fc01ec}},	//   _noon, ssèd, goon_, _ehrl,
   {{0xd9f68076,0xb5fb02ba,0x6b9b826c,0x657e0234}},	//   ुगात_, ctác, vjug, _yaph,
   {{0xdcfa82bb,0xdca582bc,0x9f42016b,0x3a2900ee}},	//   _altı, иали, roké_, mpap_,
   {{0x63a282bd,0x290502be,0x9f42026f,0x27e681b4}},	//   _boon, _àla_, soké_, boon_,
   {{0x44ce82bf,0xc24582c0,0x225f8061,0x2619827d}},	//   _də_, аник, ttuk_, _tèo_,
   {{0x63a282c1,0x7bc982c2,0x6d4502c3,0x7e6d02c4}},	//   _doon, rieu, _odha, _npap,
   {{0xb5fd803b,0x7bc982be,0x7e7b82c5,0xaca3026b}},	//   _opši, sieu, _isup, _abọd,
   {{0x7e6d02c6,0xe8f682c7,0x63a282c8,0x225f82c9}},	//   _apap, иль_, _foon, stuk_,
   {{0x6d4502ca,0x8e8602cb,0x657e02cc,0x63a281b4}},	//   _adha, агме, _saph, _goon,
   {{0x7c2502cd,0x69c702ce,0x44258088,0x2bb880f7}},	//   _athr, _omje, _htl_, _حالة_,
   {{0x63a282cf,0x44ce811c,0x291f02d0,0x27e682d1}},	//   _zoon, _yə_, _şuan_, zoon_,
   {{0x63a282d2,0x4174803d,0xab5d81b9,0x88838019}},	//   _yoon, _دانس, viżj, _ایجن,
   {{0x032602d3,0x65b001ec,0x657e0234,0x7e7b82d4}},	//   рдан, _zähl, _waph, _osup,
   {{0x3f9202d5,0x6a830087,0x98b102d6,0x442582d7}},	// [100] _inyu_, олта, _dezč_, _ltl_,
   {{0x27e682d8,0x2a6002d9,0xd94602da,0x628402db}},	//   woon_, rtib_, режи, rvio,
   {{0x7e7b802e,0xe73a82dc,0x27e682dd,0x67f601ac}},	//   _asup, вее_, toon_, nájo,
   {{0xd62a82de,0x753c0035,0xc6a682df,0xb6cb8019}},	//   воде_, larz, ирли, ھانے_,
   {{0x27e682e0,0x63a282e1,0x644182e2,0xfe7282e3}},	//   roon_, _roon, _avli, تدا_,
   {{0xbebb020f,0x27e682e4,0x224002e5,0x798181c0}},	//   mbët, soon_, msik_, jdlw,
   {{0x442582e6,0x63a282e7,0x224002e8,0x7e7b82e9}},	//   _ctl_, _poon, lsik_, _esup,
   {{0x44ce82ea,0xafe382eb,0x7bd602ec,0x67f880e1}},	//   _və_, _досл, nnyu, bíja,
   {{0x753c009a,0x6441807e,0x201802ed,0xe57a82ee}},	//   karz, _evli, _huri_, _иза_,
   {{0x1daa82ef,0x201802f0,0x63a282d8,0x65ab02f1}},	//   _कवित, _kuri_, _woon, _tühi,
   {{0x201802f2,0x63a282f3,0x753c009a,0xdcfa8176}},	//   _juri_, _toon, darz, _katč,
   {{0x201802f4,0xc4778051,0x224002f5,0x65b002af}},	//   _muri_, _כתבו_, ksik_, _wähl,
   {{0x95cb00b3,0x539b82f6,0x6d4502f7,0x442580e5}},	//   вува_, _שידו, _pdha, _ztl_,
   {{0x6d5882f8,0xdb0d0187,0x6703016f,0x753c02f9}},	//   ngva, lhaç, रेषक_, garz,
   {{0x201802fa,0xb21b013c,0x8bc702fb,0x442502fc}},	//   _nuri_, _træk, асад, ël_,
   {{0x69c702fd,0xf77f0187,0x7e6282fe,0x473502ff}},	//   _smje, moço_, ktop, _унис,
   {{0x7e628042,0x20180300,0x2fc90229,0x7c2d8301}},	// [110] jtop, _auri_, _imag_, ćari,
   {{0xdce181e2,0x201802a0,0x673d0302,0x6d450303}},	//   _galė, _buri_, lasj, _udha,
   {{0x20180304,0x4dda01c6,0x67030305,0x7e7b8306}},	//   _curi_, _תחתו, रेरक_, _ssup,
   {{0x9f058307,0x44258308,0x64550309,0x61e8803e}},	//   موضو, _rtl_, muzi, hodl,
   {{0x6455030a,0x7bcd0110,0xd244002e,0x2d810074}},	//   luzi, miau, _мэри, _kahe_,
   {{0x69c7030b,0x2d83030c,0x7bcd01e2,0x5187030d}},	//   _umje, ndje_, liau, _тума,
   {{0x2018030e,0xf773830f,0x673d0310,0x64550311}},	//   _guri_, _وار_, kasj, nuzi,
   {{0x224d8312,0x7e7b809c,0x7bcd0110,0x3219016b}},	//   trek_, _tsup, niau, _kusy_,
   {{0x20180313,0xa3af0006,0x6aad0314,0x27ed8315}},	//   _zuri_, _कवन_, nyaf, _iken_,
   {{0x224d811e,0x64550316,0x3f800317,0x2d8300f3}},	//   rrek_, kuzi, _saiu_, jdje_,
   {{0xe73a0318,0x600a0319,0x480a031a,0x7bcd031b}},	//   лен_, лном_, леон_, kiau,
   {{0x6455031c,0x25a5831d,0x753c009a,0x224d831e}},	//   duzi, _holl_, warz, prek_,
   {{0xa969831f,0x21698320,0x25a5816d,0x4ac70321}},	//   _била_, _били_, _koll_, _रेलव,
   {{0x2d8302fd,0x63bb8322,0x2fc90162,0x41268323}},	//   gdje_, lhun, _emag_, _лошо_,
   {{0x27ff8324,0x27ed8325,0xa34a0098,0x2d810326}},	//   _ohun_, _oken_, лзва_, _dahe_,
   {{0xb4e80327,0x7bcd0110,0x3f920101,0x20180314}},	//   _बडी_, giau, _unyu_, _ruri_,
   {{0xe2970328,0x17570039,0xb1460329,0x2018032a}},	// [120] бат_, _הספר_, йнал, _suri_,
   {{0x645c832b,0x2018032c,0x6455032d,0x2240032e}},	//   _årig, _puri_, buzi, rsik_,
   {{0x6c860013,0x27ff832f,0x64550330,0x63bb805d}},	//   _الجم, _bhun_, cuzi, khun,
   {{0x44440331,0x27ff8332,0xb5fb0333,0x7bcd0334}},	//   _iv_, _chun_, ntán, ciau,
   {{0x63bb8335,0x44440336,0x20180337,0xb5fb0118}},	//   dhun, _hv_, _wuri_, itán,
   {{0x6b840338,0x20180339,0x27ed833a,0x3f80833b}},	//   ldig, _turi_, _eken_, žiu_,
   {{0x7e62833c,0x31cd80c8,0x628b833d,0x44440077}},	//   stop, রকাশ, _argo, _jv_,
   {{0x63bb833e,0xd544826b,0x3a26833f,0x2d830340}},	//   ghun, _bẹ̀w, _ptop_, zdje_,
   {{0x44440341,0x67d20341,0xa5bb00f7,0xd13080f7}},	//   _lv_, nāju, spói, ومة_,
   {{0x44440342,0x361b8039,0x2fc90343,0x67240344}},	//   _ov_, _עובד, _smag_, _afij,
   {{0xd90d803d,0x673d00e8,0x2d83026c,0x63bb8345}},	//   نیه_, tasj, vdje_, bhun,
   {{0x63bb8346,0x753a80f3,0xf8b30039,0x61e88347}},	//   chun, _hetz, פשר_, sodl,
   {{0x44440348,0x673d00e8,0x6b840349,0x2d81008e}},	//   _av_, rasj, ddig, _pahe_,
   {{0x753a834a,0x6455034b,0xb21b013c,0x4444034c}},	//   _jetz, tuzi, _kræv, _bv_,
   {{0x7bcd034d,0x63a6034e,0x2d83034f,0x32190350}},	//   tiau, _bokn, rdje_, _susy_,
   {{0x44440351,0x753a8352,0x64550098,0xddc40353}},	//   _dv_, _letz, ruzi, _vpiš,
   {{0x6d488354,0x7bcd01e2,0x6e360355,0x67d201a9}},	// [130] _odda, riau, _gwyb, gāju,
   {{0x753a82af,0x213e8229,0x6b828356,0x44440357}},	//   _netz, nath_, _laog, _fv_,
   {{0xddc4003a,0x63bb8358,0x6aad0359,0x27ff80ff}},	//   _upiš, yhun, syaf, _phun_,
   {{0x25a58352,0x64c3835a,0x6d48835b,0x6b82835c}},	//   _soll_, _वेगळ, _adda, _naog,
   {{0xb5fd835d,0x25a5835e,0x9599835f,0x2c618035}},	//   _opšt, _poll_, итку_, wód_,
   {{0x4444011e,0x7afd0360,0x2bb18361,0x6b828362}},	//   _yv_, _izst, जस्थ, _aaog,
   {{0x44440363,0x65b00364,0x63bb805d,0x25a581ec}},	//   _xv_, _sähk, thun, _voll_,
   {{0x2c61809a,0x6d488365,0x27ed804a,0x628b81f4}},	//   ród_, _edda, _uken_, _prgo,
   {{0x60250110,0xb21b0366,0x25a58367,0x7d000032}},	//   _dėme, _usæd, _toll_, _kárí,
   {{0x63bb8368,0x628b8369,0x776d036a,0x3eb2804a}},	//   shun, _vrgo, _abax, øyte_,
   {{0xc952036b,0x6b84036c,0xa3e9036d,0x673b836e}},	//   ומי_, ydig, मका_, _keuj,
   {{0x628b836f,0xe3b381bd,0x661b8364,0x64438370}},	//   _trgo, _عرض_, _kuuk, msni,
   {{0x61458371,0x63a60372,0x69cf8373,0xd9458374}},	//   _дела, _rokn, éces, _дели,
   {{0x67d200eb,0xb5fb0375,0x6d410376,0x63a60377}},	//   vāju, stán, ólap, _sokn,
   {{0x8fa60003,0xd5e4019d,0xdb1d016d,0x64438378}},	//   _маке, _arị, _omsä, nsni,
   {{0x44440379,0x67d20029,0x6b84037a,0x333f80e7}},	//   _vv_, tāju, udig, naux_,
   {{0x9f5f8028,0x65b0037b,0x7983837c,0xdce381d0}},	// [140] _thuê_, _lähi, _kanw, teně,
   {{0xb5fb037d,0x4444037e,0x6b84037f,0xa7fd0380}},	//   ntál, _tv_, sdig, ntın,
   {{0xef1a8381,0xdce18029,0x79838382,0xdb060168}},	//   аме_, _dalī, _manw, _kokë,
   {{0xf1bf0065,0x6d5c0383,0x753a8384,0xbddb0385}},	//   _után_, lgra, _setz, nsèn,
   {{0x25e68076,0x3e640386,0x2b400387,0x644100e1}},	//   टवली_, nöt_, maic_, šlit,
   {{0x27388028,0x67228388,0x6b828014,0xc7b98061}},	//   ẩn_, scoj, _saog, _elő_,
   {{0xe73a8389,0x2636809a,0x68300032,0x6e29838a}},	//   _веб_, sło_, _dòdò, _eteb,
   {{0x66e6838b,0xdee6838c,0x0b8a838d,0x7983838e}},	//   _доба, _доби, рски_, _aanw,
   {{0x7983838f,0x386d0390,0xed5a8391,0xdfcf8174}},	//   _banw, _ćeri_, _воз_, _شيك_,
   {{0x6d48813c,0x6d5c0392,0x3f84804f,0x23b88036}},	//   _udda, jgra, _hamu_, _déja_,
   {{0x3f848393,0x213e8394,0x6d5c0395,0xd7fb0396}},	//   _kamu_, rath_, dgra, иум_,
   {{0xa2cb835a,0x3f848397,0x333f80e7,0x442e8398}},	//   _तेव्, _jamu_, caux_, mpf_,
   {{0xdefb0196,0x64588399,0x22948081,0x79838286}},	//   рын_, luvi, _хиля, _fanw,
   {{0x69ca839a,0x6d5c039b,0x2918039c,0xe2a98180}},	//   _umfe, ggra, _ngra_, _دامن_,
   {{0x5ba7039d,0xe0d480be,0x602181a9,0x3b280133}},	//   ораз, _מײַ_, _tēma, _ọyị_,
   {{0x6d5c0013,0x3f84839e,0xdce180eb,0xdb0f0333}},	//   agra, _namu_, _salī, _alcá,
   {{0x1ddb81fe,0xdce18029,0x2bbc0076,0x201c82f1}},	// [150] _बदलत, _palī, _ईतरा, _huvi_,
   {{0x69da839f,0x64438370,0x645883a0,0x7afd808b}},	//   nnte, ysni, kuvi, ýsti,
   {{0x65ab02af,0x6e2983a1,0xb5fb03a2,0x3f8483a3}},	//   _führ, _steb, ntám, _bamu_,
   {{0xd47a0158,0xa3af03a4,0xb5fb0019,0x2cac0106}},	//   _פארל, _कवि_, ztál, ädde_,
   {{0x333f82be,0x7afd00eb,0x3f8483a5,0x539a0039}},	//   vaux_, _uzst, _damu_, _הירו,
   {{0x644383a6,0x201c83a7,0xdb0403a8,0xa7fd0085}},	//   tsni, _ouvi_, chiñ, xtın,
   {{0x201c8358,0x333f80e7,0x21ef01ec,0x9f3583a9}},	//   _nuvi_, taux_, bühr_, _неві,
   {{0x69da83aa,0x644383ab,0x79838091,0x3a3903ac}},	//   ente, rsni, _sanw, _kwsp_,
   {{0x644380f2,0x6d5c03ad,0x798382f7,0x333f80e7}},	//   ssni, ygra, _panw, raux_,
   {{0x644381e2,0x3f8483ae,0x65b00074,0x69da83af}},	//   psni, _zamu_, _tähi, gnte,
   {{0xb5fb03b0,0x7c2d83b1,0x6d5c0289,0x798383b2}},	//   rtál, ćars, vgra, _vanw,
   {{0xb5fb03b3,0x2d8583b4,0xbebb0168,0x201c802a}},	//   stál, _hale_, rcën, _duvi_,
   {{0x2d8583b5,0xa2cb03b6,0xcaea03b7,0x19958081}},	//   _kale_, _सेल्, _झुंड_, _надя,
   {{0x2d8583b8,0xda1f0105,0x6d5c03b9,0x2d8783ba}},	//   _jale_, _बढ़त_, ugra, ndne_,
   {{0x9f9203bb,0x64a603bc,0xdb060168,0x224682d4}},	//   lší_, чава, _tokë, _zvok_,
   {{0x422603bd,0x225203be,0xa7fd03bf,0x65618122}},	//   здав, tryk_, ntıl, _lclh,
   {{0x27e003c0,0x6e4600f7,0x9f9203c1,0x6d5c03c2}},	// [160] _ijin_, _عندم, nší_, pgra,
   {{0x3f8483c3,0x2b4003c4,0xb46603c5,0x2d8581f6}},	//   _samu_, saic_, _екол, _nale_,
   {{0xe1ff00a9,0x764603c6,0x9d1b00be,0x628f01e8}},	//   _após_, lsky, _לויט, _erco,
   {{0x205503c7,0xdc9b03c8,0x3f8683c9,0x6ecd83ca}},	//   ьтур, _היטל, udou_, _देहु,
   {{0x9f9203cb,0x764603cc,0x3f8683cd,0xa3e900d4}},	//   jší_, nsky, rdou_, मकर_,
   {{0x645883ce,0x63b603cf,0xa6db007b,0x2d8583d0}},	//   tuvi, lkyn, naða, _cale_,
   {{0x80d080c8,0x69ce03d1,0x3f8483d2,0xddc98162}},	//   _সুন্, _imbe, _tamu_, _speţ,
   {{0x69dd83d3,0x63a403d4,0x645883d5,0xb21b0366}},	//   ésen, njin, ruvi, _græs,
   {{0x2d8583d6,0x201c83d7,0x7d028032,0x6b8603d8}},	//   _fale_, _suvi_, _bírí, _makg,
   {{0x764603d9,0x69da83da,0x27e00300,0x7d070036}},	//   dsky, unte, _ajin_, néré,
   {{0x69ce00dd,0x261583db,0x69da83dc,0xf99301c6}},	//   _mmbe, _फूटी_, rnte, גרת_,
   {{0x09b903dd,0x6028801b,0x78fb03de,0x2d8583df}},	//   _इत्य, _něme, מפיו, _zale_,
   {{0x69ce03e0,0x443a03e1,0x9f4b0216,0x764603e2}},	//   _ombe, _awp_, nocé_, gsky,
   {{0x7afd83e3,0x9f42016b,0x7d02826b,0x442c83e4}},	//   üste, roká_, _gírí, _ktd_,
   {{0x9f42026f,0x6b8603e5,0x7d0703e6,0x628f00c3}},	//   soká_, _bakg, déré, _srco,
   {{0x27e003e7,0x63a400f1,0xa3bc03e8,0x087783de}},	//   _gjin_, gjin, _अतः_, _זעהט_,
   {{0x3edf0135,0xdcf200eb,0x6b8603e9,0x442c81c6}},	// [170] _kpọọ_, īgāk, _dakg, _ltd_,
   {{0x6e2d03ea,0xceb200be,0xaca301bc,0xbba983eb}},	//   _itab, _סיי_, _asụg, _छक्क,
   {{0xb21b013c,0x2d8583ec,0x673f03ed,0xa3be8035}},	//   _præs, _rale_, _keqj, ीफा_,
   {{0x69ce03ee,0x64550289,0x2d8583ef,0x256f807e}},	//   _embe, mrzi, _sale_, zılı_,
   {{0xd2468065,0x644883f0,0x442c83f1,0x256f8214}},	//   _جن_, _avdi, _atd_, yılı_,
   {{0xcb120051,0x645501ed,0x9f9203f2,0x68f500e1}},	//   _שלך_, orzi, vší_, _tyzd,
   {{0x2d8583f3,0xac09827e,0x628283f4,0x2d8783f5}},	//   _vale_, онка_, _asoo, rdne_,
   {{0x2d8583f6,0x9f92001b,0x6e2d03f7,0x395e80eb}},	//   _wale_, tší_, _otab, egts_,
   {{0xfe7083f8,0x2d8583f9,0x2a6903fa,0x6e2d02a0}},	//   _مدل_, _tale_, ntab_, _ntab,
   {{0x9f9203fb,0x3ce8809a,0x27f203fc,0xab5b0192}},	//   rší_, _चुके_, _skyn_, _flüg,
   {{0x6d4383fd,0xd37180f7,0xdddb805c,0x6e2d03fe}},	//   mana, _لها_, _kruž, _atab,
   {{0x65b003ff,0x9f920400,0x2a690401,0x7bc08402}},	//   _läht, pší_, ktab_, chmu,
   {{0xb8f48403,0xa6db008b,0x443a0404,0xdcfa8162}},	//   _से_, taða, _swp_, _tată,
   {{0x79870063,0x76460405,0x65b00406,0x273c0028}},	//   _najw, rsky, _näht, ận_,
   {{0xdddb8025,0x6e2d0407,0x76460408,0x69c18409}},	//   _oruž, _etab, ssky, mhle,
   {{0x6d43840a,0x6b89840b,0x6f1b840c,0xeb97040d}},	//   hana, ndeg, _nguc, мис_,
   {{0x59e1824c,0xdb0b840e,0x63ab840f,0x63a680f2}},	// [180] _पदार, _algú, _mogn, ökni,
   {{0x6d438410,0x69c18234,0x63b60411,0x63a40412}},	//   jana, nhle, skyn, sjin,
   {{0x6d438413,0x657c0414,0x628b0106,0x7bc78084}},	//   dana, merh, ågor, _įjun,
   {{0x645c0415,0xdd8f8416,0x657c0417,0x3fbe80ab}},	//   muri, یون_, lerh, েক্ষ,
   {{0x6d438418,0xdddb8419,0x4cd300ab,0x7988831d}},	//   fana, _druž, _দুপু, yddw,
   {{0x69ce041a,0x657c02af,0x442c83ac,0x63ab8362}},	//   _umbe, nerh, _ptd_, _aogn,
   {{0x645c041b,0x442c841c,0x69c1841d,0x644d81a9}},	//   nuri, _qtd_, dhle, ņain,
   {{0x63ab841e,0xdddb841f,0x6d438420,0x6b898421}},	//   _cogn, _gruž, aana, gdeg,
   {{0x657c0422,0x645c0423,0xe7bd8424,0x52148425}},	//   kerh, huri, ्फरप, ндит,
   {{0x645c0426,0x442c808e,0x69c18427,0x657c0144}},	//   kuri, _ttd_, ghle, jerh,
   {{0x39570051,0x6e20820f,0x79888428,0x63ab8429}},	//   ושים_, _humb, rddw, _fogn,
   {{0x6e20842a,0x628281c5,0xe29a81e2,0x26c681c0}},	//   _kumb, _tsoo, _мае_, ozoo_,
   {{0xdce881e2,0xdde2042b,0x6e20842c,0x26c68144}},	//   _padė, _šušk, _jumb, nzoo_,
   {{0xceb38158,0xe0cf8416,0x645c042d,0x69c1842e}},	//   דיש_, ازی_, furi, chle,
   {{0x67d5042f,0x6e208430,0xb5fb00f7,0xdb060019}},	//   _поку, _lumb, ntái, _elkü,
   {{0x6d438431,0x2a690432,0x2cac0106,0x7c220088}},	//   zana, ttab_, ädda_, _čort,
   {{0x657c0433,0x6e208434,0x6e2d0435,0x65950436}},	// [190] berh, _numb, _utab, _запу,
   {{0x645c0437,0x6d438438,0x765d0439,0x4905801b}},	//   buri, xana, musy, हेको_,
   {{0xdddb812b,0x2a690006,0x6d43843a,0x765d043b}},	//   _pruž, stab_, vana, lusy,
   {{0x6d43843c,0x2a690242,0x93c90019,0xef1982a6}},	//   wana, ptab_, _راجہ_, _każi_,
   {{0xcb360051,0x65b0043d,0x6e20843e,0x6d43843f}},	//   _ראשי_, _täht, _cumb, tana,
   {{0x63ab8440,0xa2bf0441,0x9f4d8229,0x44210442}},	//   _sogn, लैण्, _cheò_, _kuh_,
   {{0x6d438443,0x442101d6,0x22490444,0x67298197}},	//   rana, _juh_, lsak_, _tfej,
   {{0x6d438445,0x65b002af,0x765d0446,0x26c6822c}},	//   sana, _jähr, kusy, bzoo_,
   {{0x6d438447,0x645c8448,0x6b898449,0x6e20844a}},	//   pana, _årin, rdeg, _gumb,
   {{0x645c044b,0x6d43844c,0x9f4d8362,0x6b89844d}},	//   yuri, qana, _gheò_, sdeg,
   {{0x657c044e,0xe8f9844f,0x6d4180eb,0x67248450}},	//   verh, яло_, _iela, žije,
   {{0xf0920451,0x6d418452,0x22490453,0x657c0454}},	//   אנט_, _hela, ksak_, werh,
   {{0x6d418455,0x657c0456,0x3e6980e1,0xe3c20457}},	//   _kela, terh, nút_, nlış_,
   {{0x6d418458,0x92c18459,0x9aa4845a,0xdd92045b}},	//   _jela, ığın, _جمهو, دوس_,
   {{0x6d41845c,0xfce3045d,0xddcd0087,0x6603045e}},	//   _mela, горо, _spaţ, упра,
   {{0x6d41845f,0xa2d48076,0x645c0460,0x765d0461}},	//   _lela, _बेड्, ruri, busy,
   {{0xf41280be,0x22490462,0x02060463,0xdb060242}},	// [1a0] רפן_, gsak_, езан, _alkò,
   {{0x6d418464,0x645c0465,0xe889801c,0x442100ee}},	//   _nela, puri, _kẻ_, _fuh_,
   {{0x6e208397,0x65b001ec,0xdddb8035,0x21f40192}},	//   _sumb, _fähr, _druż, fähr_,
   {{0xa2cb0466,0xfaa60467,0xfe468468,0xe6668469}},	//   _सेक्, _замо, ендо, етко,
   {{0xe889801c,0x394580eb,0x98ac0085,0x91b48035}},	//   _lẻ_, kals_, ğlıq_, ेसमै,
   {{0xe5a3846a,0x6d4182ad,0x7bd6046b,0x98ac0085}},	//   личи, _cela, liyu, şlıq_,
   {{0x6d41846c,0x8d1a8065,0xdbe3046d,0x26c681c0}},	//   _dela, _ہزار_, _béèn, szoo_,
   {{0xb5fb00f7,0x6d4182f1,0x51200054,0x8aa6846e}},	//   rtái, _eela, _बलुआ_, ерод,
   {{0xb5fb0013,0x6d41846f,0x66e38470,0x6aa40118}},	//   stái, _fela, _бота, nxif,
   {{0x64a68471,0xb5ca8065,0x39458472,0x7afd8085}},	//   _паза, _عوام_, gals_, üsta,
   {{0x815700be,0x3f890473,0xdb12007b,0x7c218474}},	//   עסטע_, _paau_, _ágæt, _gulr,
   {{0xfa888142,0x6d418102,0x765d0475,0xb5fb0476}},	//   _từ_, _zela, tusy, ntáv,
   {{0x42db00ab,0x7d278106,0x44210477,0x6d418478}},	//   _দর্শ, _årså, _suh_, _yela,
   {{0x39458479,0x661a847a,0x9f4b001b,0x4421047b}},	//   cals_, _jitk, mocí_, _puh_,
   {{0x317e80cd,0x6286047c,0xb3a4847d,0x7bd6008e}},	//   metz_, _asko, _खचाख, fiyu,
   {{0x7bc4047e,0x7bdf047f,0x22490480,0xdcf88088}},	//   ghiu, unqu, tsak_, jevč,
   {{0x66d38065,0x9f4b0388,0x443e82f7,0xd2510481}},	// [1b0] _műkö, nocí_, _lwt_, شنا_,
   {{0x661a8482,0x44210483,0xd8e70484,0x65b002af}},	//   _nitk, _tuh_, нцеп, _währ,
   {{0x62860485,0x6d470486,0x20090028,0x22490487}},	//   _esko, maja, _khai_, ssak_,
   {{0x6d41845c,0x6d470393,0x200901c0,0x7bc40488}},	//   _sela, laja, _jhai_, chiu,
   {{0x661a8489,0x6b9d048a,0xdb0b80f1,0x69dd8019}},	//   _bitk, _insg, _vogë, ések,
   {{0x6d47048b,0xb90700c8,0xdce88029,0x443e848c}},	//   naja, _পর_, _gadī, _bwt_,
   {{0x63af02a5,0xab5b02af,0x80d080ab,0x644a848d}},	//   _kocn, _glüc, _সুস্, gsfi,
   {{0xe8898028,0x69d701df,0x6d470353,0x6d41848e}},	//   _rẻ_, lixe, haja, _wela,
   {{0x6d41848f,0x39458490,0xe8898028,0x63af0491}},	//   _tela, tals_, _sẻ_, _mocn,
   {{0x6d470492,0x27fd8428,0x798a8428,0x93bc8493}},	//   jaja, llwn_, _cafw, _stăt,
   {{0x39458494,0x6d470495,0x2fc001e9,0xf9920496}},	//   rals_, daja, _plig_, ברי_,
   {{0x39458497,0xe8898028,0x20090498,0x6b8d01ed}},	//   sals_, _vẻ_, _chai_, jdag,
   {{0x63a9830b,0x6b8d03a6,0x93b68051,0xddcd0499}},	//   mjen, ddag, _שלנו_, _spaš,
   {{0xceb2804c,0x6d47049a,0x7bd600b4,0x65638129}},	//   סים_, gaja, wiyu, ngnh,
   {{0xdce880eb,0xddc280eb,0x6b8b849b,0x443e049c}},	//   _radī, ntoš, _kagg, èt_,
   {{0x63a9849d,0x63bb849e,0x6b8d049f,0x087680be}},	//   njen, nkun, gdag, _יעצט_,
   {{0x6b8b84a0,0x6d4704a1,0x3951026c,0x4b2300e8}},	// [1c0] _magg, baja, _bdzs_, рмув,
   {{0x6d470025,0x63a984a2,0xb65b007c,0x00da04a3}},	//   caja, hjen, _קדיש, وبات_,
   {{0x63bb84a4,0xdce88029,0x63a984a5,0x661a84a6}},	//   kkun, _vadī, kjen, _ritk,
   {{0x6b8b84a7,0x70530077,0x6e24004f,0x7bd600dd}},	//   _nagg, شنها, _kuib, qiyu,
   {{0x63a984a8,0x628604a9,0x661a8364,0x443e84aa}},	//   djen, _usko, _pitk, _swt_,
   {{0xb5fb04ab,0x69c504ac,0xd49a84ad,0x8d6384ae}},	//   stáv, chhe, дри_, авље,
   {{0x6b8b84af,0xb5fb001b,0xcbe684b0,0x2cb80362}},	//   _bagg, ptáv, кции, nyrd_,
   {{0x63a984b1,0x63bb84b2,0x09da8072,0x61fe04b3}},	//   gjen, gkun, यच्य, llpl,
   {{0xd00f8013,0xfbd30051,0x2009031d,0x6b8b84b4}},	//   _ذلك_, יתה_, _rhai_, _dagg,
   {{0xa3f5800d,0x661a837a,0xb4d2016f,0x200900fc}},	//   ější_, _uitk, _वधू_, _shai_,
   {{0x2d9e84b5,0x6d4704b6,0x63a984b7,0xd1388110}},	//   _inte_, vaja, bjen, rbą_,
   {{0x2d8c84b8,0x317e81ec,0x6b8b84b9,0x63bb82af}},	//   _hade_, setz_, _gagg, ckun,
   {{0x6d4704ba,0x2d8c84bb,0x6e2404bc,0xc9aa84bd}},	//   taja, _kade_, _cuib, _овде_,
   {{0x2d8c84be,0xea778039,0xa4d500e8,0x63af01f4}},	//   _jade_, _סגור_, гогі, _socn,
   {{0x6d4704bf,0x63af0052,0x80a384c0,0x6b8d03b2}},	//   raja, _pocn, _نمون, tdag,
   {{0x5f7704c1,0x2d8c84c2,0x6b8b8079,0x2009004f}},	//   _شاعر, _lade_, _xagg, _uhai_,
   {{0x2d9e84c3,0x6d4704c4,0x63af025b,0xf8e284c5}},	// [1d0] _onte_, paja, _vocn, _पशुप,
   {{0x6b8d03a6,0x63bb80ad,0x68fc04c6,0x80be0264}},	//   sdag, zkun, _byrd, ্পন্,
   {{0x44270193,0x3eb904c7,0xc953810f,0x69d704c8}},	//   _în_, lyst_, שמע_, rixe,
   {{0x2d9e84c9,0x44330183,0xb4c1009a,0x7659831d}},	//   _ante_, _itx_, ्छी_, trwy,
   {{0x6d4504ca,0x6b8b84cb,0x4ea78081,0x6b8084cc}},	//   _keha, _ragg, ържа, demg,
   {{0x6d4504cd,0xf2d20051,0x7bc284ce,0xa93404cf}},	//   _jeha, _פעם_, _alou, _верш,
   {{0x63a984d0,0x7afd04d1,0x6b8b84d2,0x7bc284d3}},	//   tjen, _hyst, _pagg, _blou,
   {{0x2d9e84d4,0xddc284d5,0x7afd04d6,0x7bc284d7}},	//   _ente_, rtoš, _kyst, _clou,
   {{0x3f9f82c1,0x63a984d8,0x7bc2800d,0xee8484d9}},	//   _inuu_, rjen, _dlou, _выхо,
   {{0x63bb84da,0xdcbb8021,0x2d8c8247,0x5fb9835a}},	//   skun, _още_, _gade_, _आवडल,
   {{0x2dd880f7,0xf74604db,0x7afd04dc,0x046784dd}},	//   _شبكة_, лено, _lyst, _штам,
   {{0xdb0f0073,0xc43a84de,0x7ae48289,0x44258087}},	//   _você, _נתני, _žite, _iul_,
   {{0x442584df,0x6d4504e0,0x7afd04e1,0x69d504e2}},	//   _hul_, _beha, _nyst, _omze,
   {{0x88c584e3,0x442584e4,0x2bcf84e5,0x7bc28067}},	//   _متعل, _kul_, तोरा, _zlou,
   {{0x224d84e6,0x7981805d,0x442584e7,0x987980be}},	//   lsek_, melw, _jul_, _טאַט,
   {{0x7afd04e8,0x2d8c04e9,0x44258006,0x7981805d}},	//   _byst, žde_, _mul_, lelw,
   {{0x7afd0114,0xdcfc026f,0x442584ea,0x6d450144}},	// [1e0] _cyst, merč, _lul_, _feha,
   {{0x6d4504eb,0x7afd04ec,0x3f8204ed,0x798184ee}},	//   _geha, _dyst, leku_, nelw,
   {{0xdb06003e,0x2d8c84ef,0xdce38110,0xb5fb04f0}},	//   _doká, _rade_, menė, rtát,
   {{0xb5fb04f1,0x2d8c84f2,0x6d45011e,0x224d8214}},	//   gráf, _sade_, _zeha, ksek_,
   {{0x2d8c84f3,0x7981805d,0x7f3b00be,0x7afd0114}},	//   _pade_, kelw, גענו, _gyst,
   {{0x7bc2801b,0x442584f4,0xd5b1801c,0x7e7b808e}},	//   _slou, _bul_, _có_, _dpup,
   {{0x442584f5,0x5b2684f6,0x2d8c8214,0x7bc284f7}},	//   _cul_, льпа, _vade_, _plou,
   {{0xb5fb04f8,0x442584f9,0x3f820499,0x539884fa}},	//   ntár, _dul_, jeku_, твия_,
   {{0x2d8c84fb,0xbebb0168,0x224d82c4,0xdb060061}},	//   _tade_, ncët, gsek_, _elkö,
   {{0xc05a8221,0x602180eb,0x442584fc,0x79818114}},	//   нім_, _lēmu, _ful_, gelw,
   {{0x291884fd,0x98be8087,0x442584fe,0x798e04ff}},	//   ära_, dată_, _gul_, _mabw,
   {{0x6d450500,0x6d4a8501,0x644e0502,0xa6db007b}},	//   _seha, lafa, dsbi, laði,
   {{0x6d450503,0x44258504,0x645c011b,0x79818505}},	//   _peha, _zul_, erri, belw,
   {{0x44258506,0xbb1b02be,0x6d4a8507,0xa6db008b}},	//   _yul_, _maît, nafa, naði,
   {{0x6d450508,0x44258509,0xb4c1050a,0x3ebf050b}},	//   _veha, _xul_, ्छे_, šut_,
   {{0xc4c4850c,0x7afd0009,0xa3cf050d,0x246e8085}},	//   _ہے_, _pyst, वों_, _cəmi_,
   {{0x6d4a850e,0x6d450074,0x645c02f9,0x5b7b80be}},	// [1f0] kafa, _teha, arri, ערמא,
   {{0x7afd050f,0x645a0510,0x98be802e,0xb5fb0061}},	//   _vyst, átic, cată_, rtás,
   {{0x7afd0063,0x2d8302a0,0xb5fb0511,0xd7c880d7}},	//   _wyst, meje_, tráf, گونه_,
   {{0x31e18512,0x645a011f,0x2d830513,0x7afd0514}},	//   _पद्ध, štic, leje_, _tyst,
   {{0x44258515,0x6d4a8516,0xa2d4800c,0x98aa01a9}},	//   _sul_, fafa, _बेल्, ējām_,
   {{0x44258085,0x2d830517,0xf483804e,0x6d4a8518}},	//   _pul_, neje_, ماعی, gafa,
   {{0x63ad0110,0xa7fd007e,0xa2d90519,0x7981851a}},	//   ojan, ntıs, _नेत्, velw,
   {{0x63ad051b,0x4425838e,0x98be8087,0xddc4051c}},	//   njan, _vul_, zată_, _spiż,
   {{0x69da851d,0x6b8f051e,0x6d4a851f,0x2b468176}},	//   fite, _macg, bafa, _deoc_,
   {{0x2d830520,0x44258521,0x27e90522,0x69c8808c}},	//   jeje_, _tul_, _ajan_, ghde,
   {{0xe73a0523,0x2d830524,0x63ad0525,0x66ca8019}},	//   кен_, deje_, kjan, _töké,
   {{0xc6000526,0x7981805d,0xb5fb0527,0x63ad0528}},	//   ोग्य_, selw, hrád, jjan,
   {{0x63ad0529,0x98be8087,0x2bc9052a,0xb5fb052b}},	//   djan, tată_, रसना, vtár,
   {{0x3f82052c,0x69c8852d,0x644e052e,0x7bc980e7}},	//   seku_, chde, tsbi, lheu,
   {{0x98be802e,0x645c052f,0xdd0e02d0,0x8c460530}},	//   rată_, urri, _dışa, ребе,
   {{0xc0528039,0x7bc980e7,0xdb0b8531,0x63ad0532}},	//   _וזה_, nheu, _logí, gjan,
   {{0x6d4a8533,0x661e0534,0x644e0535,0xeab70536}},	// [200] yafa, _tipk, ssbi, айт_,
   {{0x394782fe,0xb5fb0537,0xf0a98032,0xdebb0538}},	//   _jens_, stár, _gbàà_, _סמיל,
   {{0xa3af00d4,0x64a60539,0x63ad053a,0xdca6053b}},	//   _कवच_, _тана, bjan, _тани,
   {{0x69da853c,0x6d4a8010,0x764400b4,0x6e93053d}},	//   zite, wafa, _kwiy, _الیا,
   {{0xb8fd053e,0xe8e2853f,0x23a98540,0x6d4a8541}},	//   _ते_, _पश्च, कानद, tafa,
   {{0x44440542,0x3947809f,0xb8660019,0x6b840543}},	//   _kw_, _nens_, _پاسو, leig,
   {{0x92e280c8,0x292700e1,0xa6db008b,0x03c68544}},	//   _ধরে_, ávať_, raði, исим,
   {{0x44440545,0x69da8546,0x6d4a8547,0x0fc100ab}},	//   _mw_, wite, safa, _উদ্ধ,
   {{0x444402ec,0x27e68420,0x39478548,0x2d830549}},	//   _lw_, mnon_, _bens_, yeje_,
   {{0x444402ec,0x6b84054a,0x63ad054b,0x4973854c}},	//   _ow_, heig, zjan, ольс,
   {{0x628b854d,0x7644054e,0x3947854f,0x58d880e8}},	//   _esgo, _awiy, _dens_, удня_,
   {{0x69da8550,0x394782d8,0x27e68551,0x6d488102}},	//   site, _eens_, nnon_, _heda,
   {{0x44440552,0x63a28553,0x6d4884bf,0xd6d80554}},	//   _aw_, _inon, _keda, атр_,
   {{0x6d488025,0x44440555,0x7bc60556,0x39478557}},	//   _jeda, _bw_, _alku, _gens_,
   {{0x6d488558,0x2d830559,0xf77f055a,0x63ad055b}},	//   _meda, reje_, ança_, tjan,
   {{0x7c288025,0x6d48855c,0x4444055d,0x628b8355}},	//   _mudr, _leda, _dw_, _ysgo,
   {{0x7c28855e,0x2905055f,0xadf683eb,0x717900e5}},	// [210] _ludr, _šla_, इवान_, лбар_,
   {{0x6f098063,0x39470560,0x3947802a,0x394c8561}},	//   _rzec, úns_, _xens_, nads_,
   {{0x44440562,0x63ad0563,0x63a28564,0x6b8401a9}},	//   _gw_, pjan, _onon, beig,
   {{0x27e68565,0x2014009f,0xdc9a03de,0x63a283f7}},	//   gnon_, _èxit_, _עירל, _nnon,
   {{0x7c288566,0x69d881eb,0x44440567,0xed598568}},	//   _audr, _omve, _zw_, гол_,
   {{0x63a28569,0x44440355,0x27e6856a,0x5f0a056b}},	//   _anon, _yw_, anon_, _सरस्_,
   {{0x4444056c,0x6d48856d,0xa6db0125,0x0574803d}},	//   _xw_, _deda, maðu, تاند,
   {{0x3947856e,0x69c7056f,0x23690570,0x1dd98571}},	//   _sens_, _hlje, ngaj_, _भगवत,
   {{0xe1f98572,0x248c8573,0xdd2c0110,0xe7308019}},	//   лги_, _esdm_, vėži, _آصف_,
   {{0x6b840352,0x6d488574,0xa6db007b,0x63a28575}},	//   zeig, _geda, naðu, _enon,
   {{0xa3e80576,0x69c702ce,0x7c288577,0x7dc200e1}},	//   _बदल_, _mlje, _gudr, _dôsl,
   {{0x44440578,0x3947837a,0x7dc201ac,0x6d570579}},	//   _rw_, _wens_, _pôso, _adxa,
   {{0x34b2057a,0x7f49857b,0x69c7057c,0xa7fd02d0}},	//   ीन्द, _meeq, _olje, ttır,
   {{0x4444057d,0x6e298264,0x6e21857e,0x28b980f7}},	//   _pw_, _mueb, _jilb, _مطبخ_,
   {{0x44440282,0x6b84057f,0xdb0b8187,0xdb1d0580}},	//   _qw_, teig, _fogã, _alsà,
   {{0xf1bf001c,0x69c1800b,0x44440581,0xfd6901bc}},	//   _quán_, lkle, _vw_, _kepụ,
   {{0x69c70582,0xa7fd0214,0x6e2982d5,0xfaa30530}},	// [220] _blje, ptır, _nueb, пато,
   {{0x44440583,0x01d70013,0x69c18584,0x6b840585}},	//   _tw_, موقع_, nkle, seig,
   {{0x44440586,0x3f920587,0x6d4e0588,0x291c0589}},	//   _uw_, _kayu_, maba, äva_,
   {{0x6d4e058a,0x7bc6058b,0x78a30338,0x68fc8192}},	//   laba, _ulku, ånva, ürdi,
   {{0x6e21811e,0xa3ab858c,0x2b40058d,0x3f920041}},	//   _bilb, खान_, mbic_, _mayu_,
   {{0x6d4e058e,0x225f858f,0x3f920590,0xe1e78591}},	//   naba, druk_, _layu_, _رس_,
   {{0x2bbf0592,0x6d488593,0xb5fb026f,0x394c80eb}},	//   _एकमा, _veda, duál, vads_,
   {{0x69de0594,0x6d4e0595,0x9b6a8596,0x6d488597}},	//   lipe, haba, ушка_, _weda,
   {{0x6d4e0598,0x6d488599,0x7dcb0059,0x394c859a}},	//   kaba, _teda, _hüse, tads_,
   {{0x69de059b,0x6d4e059c,0x8c0000ab,0xfd6901bc}},	//   nipe, jaba, ্দিন_, _depụ,
   {{0x672d80ce,0x64a3859d,0x3f92059e,0x9f42016b}},	//   žaje, _нафа, _bayu_, soký_,
   {{0x4422059f,0xaad98105,0x69de0087,0x225f85a0}},	//   _nik_, _बेवक, hipe, bruk_,
   {{0x69de05a1,0x645a0091,0x394a05a2,0x3f9202f7}},	//   kipe, átin, _oebs_, _dayu_,
   {{0x6d4e05a3,0xf1bf05a4,0x4422016d,0x30a685a5}},	//   gaba, _cuál_, _aik_, _грив,
   {{0x645a05a6,0x61fa8580,0x69de05a7,0xc05a85a8}},	//   štin, motl, dipe, _сіл_,
   {{0x69c702fd,0x442205a9,0x61fa85aa,0xeda585ab}},	//   _slje, _cik_, lotl, _गच्छ,
   {{0x6d4e05ac,0x442205ad,0x69c70052,0x7c2285ae}},	// [230] baba, _dik_, _plje, _mior,
   {{0x6d4e005d,0x7c228118,0x6f0d05af,0x61fa85b0}},	//   caba, _lior, _izac, notl,
   {{0x44220022,0x2fc905b1,0x660384e8,0x6d4105b2}},	//   _fik_, _klag_, vlnk, ılad,
   {{0x1da705b3,0x6e2985b4,0xdb0b8013,0x4422013c}},	//   खावत, _pueb, _logá, _gik_,
   {{0x7bdf05b5,0x7bcd05b6,0x61fa85b7,0x6e218176}},	//   miqu, mhau, kotl, _pilb,
   {{0x7bdf05b8,0x628f0197,0xb5fb05b9,0x69de05ba}},	//   liqu, _isco, xuál, cipe,
   {{0xddcc01e2,0x224680ee,0x442200ee,0x7c2285bb}},	//   _žiūr, _awok_, _yik_, _bior,
   {{0x23c905b3,0x7bdf05bc,0x6d4e05bd,0xa91c8038}},	//   रसिद, niqu, zaba, teľn,
   {{0x6e2185be,0xb5fb05bf,0x7c2285c0,0x3e72802e}},	//   _tilb, tuál, _dior, cât_,
   {{0x80be00c8,0x8d778416,0x3f9205c1,0xe9d985c2}},	//   ্পর্, _دارا, _sayu_, рко_,
   {{0x7c228098,0x2fc905c3,0x15fa009a,0x6f0d05c4}},	//   _fior, _blag_, ृतसर_, _azac,
   {{0x7c228021,0xdd0e85c5,0x6d4e05c6,0x2d8785c7}},	//   _gior, lışm, waba, lene_,
   {{0x6d4e05c8,0x7bdf05c9,0xf8a6016f,0x7bcd05ca}},	//   taba, diqu, _गप्प, dhau,
   {{0x442205cb,0x2d8785cc,0xdb0f002a,0xdd0e83bf}},	//   _sik_, nene_, _cocí, nışm,
   {{0x6d4e05cd,0x7bdf05ce,0x628f0098,0x629d05cf}},	//   raba, fiqu, _asco, _arso,
   {{0x7bdf0557,0xb5fb05d0,0x2d8785d1,0x3f868118}},	//   giqu, trác, hene_, xeou_,
   {{0x2d8785d2,0xe9da05d3,0x6d4e05d4,0xb5fb00e1}},	// [240] kene_, ака_, paba, urác,
   {{0x27ff85d5,0x27ed80b9,0xe16600f7,0x6d4e05d6}},	//   _akun_, _ajen_, تدري, qaba,
   {{0x442205d7,0x2d87835f,0x628f05d8,0x69de05d9}},	//   _tik_, dene_, _esco, ripe,
   {{0xeb9a05da,0x7bdf05db,0xb5fb026f,0x394a05dc}},	//   _тим_, ciqu, prác, _webs_,
   {{0x7c2285dd,0xfe6f85de,0x2d8785df,0x61fa85e0}},	//   _rior, ندو_, fene_, yotl,
   {{0x69de020f,0x2d8785e1,0x443a05e2,0x7c228014}},	//   qipe, gene_, _ktp_, _sior,
   {{0x69dc00f7,0x7c2285e3,0x6fc60118,0x50b5002e}},	//   _imre, _pior, _nóco, _есту,
   {{0x78a105e4,0xa3ba80f7,0x27ed8168,0xe3bf0144}},	//   _álva, شاعر_, _gjen_, _tiñe_,
   {{0x2d8785e5,0xa91c8038,0xf41302f6,0x69dc02f7}},	//   bene_, teľo, ופה_, _kmre,
   {{0x2fc905e6,0x61e881ec,0x20068168,0x7bdf05e7}},	//   _slag_, undl, lloi_, ziqu,
   {{0x09b78307,0xeb0705e8,0x2fc9056c,0x28f885e9}},	//   تطيع_, _शर्त_, _plag_, сень_,
   {{0x93258077,0x32058039,0xea0100ff,0x7bdf05ea}},	//   _فرهن, ally_, _đập_, xiqu,
   {{0x645a005c,0x442c84fe,0x69dc05eb,0xf98f80d5}},	//   štil, _hud_, _omre, ربی_,
   {{0x63a605ec,0x72e980be,0x443a05ed,0x200005ee}},	//   _ankn, _פֿײַ, _btp_, _ekii_,
   {{0x7bdf05ef,0x69ca808e,0x442c8162,0x7bcd05f0}},	//   tiqu, _ilfe, _jud_, thau,
   {{0x5a3505f1,0x798885f2,0x3a3905f3,0x69dc05f4}},	//   знат, ledw, _ptsp_, _amre,
   {{0x7bdf03d3,0x442c85f5,0x7bcd05f6,0x2d9305f7}},	// [250] riqu, _lud_, rhau, _taxe_,
   {{0x7bdf0557,0x442c85f8,0x7bcd05f9,0xaca301bc}},	//   siqu, _oud_, shau, _apụg,
   {{0x2d8785fa,0x6e2d022c,0xf8ca85fb,0x20ca85fc}},	//   vene_, _huab, ानिय, ानिध,
   {{0x6d5a85fd,0x7e6281e0,0x2d8780d7,0x6e2d05fe}},	//   _adta, frop, wene_, _kuab,
   {{0xf77085ff,0x27ed80f1,0x2d87835f,0x7c3a8600}},	//   ضان_, _vjen_, tene_, _attr,
   {{0x442c8601,0xb2ba01c6,0x6e2d0602,0xa2ba01c6}},	//   _bud_, _המשר, _muab, _המשט,
   {{0x2d878603,0xd8380048,0x27ff81cd,0x7d1c808b}},	//   rene_, _мэт_, _tkun_, _úrsl,
   {{0x5ba98604,0x442c8197,0x2d878605,0x69ca8606}},	//   ским_, _dud_, sene_, _alfe,
   {{0xe9d98607,0x2d878608,0x64488609,0x79950234}},	//   йки_, pene_, _ewdi, _kazw,
   {{0x442c80f7,0x6ca7860a,0x69c5060b,0x2ba981cb}},	//   _fud_, _мреж, nkhe, काहा,
   {{0x6d43860c,0x442c8082,0x2a6901c5,0x6e2d0362}},	//   mbna, _gud_, huab_, _auab,
   {{0x69ca860d,0xe29f007b,0x7649860e,0x628d060f}},	//   _elfe, _orð_, _kwey, kwao,
   {{0xb9028610,0xfaa58611,0x7bcb8612,0x629800eb}},	//   _ने_, _хало, _ilgu, āvok,
   {{0xceb2804c,0x69c50613,0x79950063,0x645a005c}},	//   עים_, jkhe, _nazw, štim,
   {{0x61e18614,0xdca30615,0x64a30616,0x764983f7}},	//   mill, нари, нара, _lwey,
   {{0x61e18617,0x67298618,0x3cde8006,0x69dc0619}},	//   lill, _ngej, _कइसे_, _smre,
   {{0x61e1861a,0x443a008e,0x2737001c,0x37e180ab}},	// [260] oill, _wtp_, _ủng_, যকার,
   {{0x3ea0061b,0x443a0359,0x6d41061c,0xa96a01a8}},	//   _irit_, _ttp_, ılac, إمام_,
   {{0x7e628372,0x6e3b861d,0x55bb01c6,0x2ec4861e}},	//   wrop, _atub, _המיו, वन्त,
   {{0x442c861f,0x2d980620,0x2d8a0621,0x7e628622}},	//   _rud_, ldre_, lebe_, trop,
   {{0x61e18623,0xdfcf8624,0xc61580c8,0x2a690282}},	//   kill, دين_, াদনা_, cuab_,
   {{0x7bcb8531,0x2d980625,0xb5fb0626,0x61e18627}},	//   _algu, ndre_, hrán, jill,
   {{0xf7468628,0x200683d3,0x62828629,0xb4c6800d}},	//   _нево, ploi_, _spoo, उने_,
   {{0x7dcb062a,0x2d8a062b,0x9f5900e7,0x61e1862c}},	//   _müsa, hebe_, posé_, eill,
   {{0x63b9862d,0x61e1862e,0x60338087,0xdcfa80eb}},	//   _down, fill, _răma, _patē,
   {{0xe3bf062f,0x442c8630,0x61e18631,0x6d5a806a}},	//   _miña_, _tud_, gill, _udta,
   {{0xe3bf062f,0xb5fb0632,0x2d8a0633,0x442c8634}},	//   _liña_, frán, debe_, _uud_,
   {{0x61fe0047,0x61e18635,0x79888636,0x22400637}},	//   hopl, aill, sedw, kpik_,
   {{0x71a68638,0x61fe0639,0xe3bf0264,0x2ba9863a}},	//   _надз, kopl, _niña_, कारा,
   {{0x61e1863b,0x64550065,0x4426863c,0x2d8a063d}},	//   cill, tszi, _hio_, gebe_,
   {{0x4426863e,0x3ea00176,0x48dc016f,0xb5fb03c1}},	//   _kio_, _erit_, _गेलो_, brán,
   {{0xcf2700f7,0x3ea0006a,0x2d98063f,0x6e2d0640}},	//   _عربي, _frit_, adre_, _tuab,
   {{0x44268641,0x61eb8019,0x7c260642,0x2d8a0643}},	// [270] _mio_, _állí, _dikr, bebe_,
   {{0x2d8a0644,0x61fe00fe,0x44268645,0xeb9f0646}},	//   cebe_, gopl, _lio_, _skød_,
   {{0x7c260647,0x69c50648,0x25d800be,0x2a690069}},	//   _fikr, rkhe, _מוזן_, suab_,
   {{0x61e18649,0xb8d5064a,0x4426864b,0xe29f008b}},	//   zill, _जप_, _nio_, _eyða_,
   {{0x6ff5809a,0xcb9a0039,0x63b9864c,0xf8a9864d}},	//   jące, _וסרט, _rown, _छप्प,
   {{0xd1268013,0x06f4803d,0x6b89864e,0xbea2864f}},	//   _لم_, رسنج, weeg, ташк,
   {{0x44268025,0x6b898650,0x2ba98651,0xdb0603ec}},	//   _bio_, teeg, काला, _ankè,
   {{0x2fc68052,0x5f948652,0x44268653,0x3f8b0654}},	//   ckog_, _пист, _cio_, jecu_,
   {{0x6b898079,0x44268655,0x8d878656,0x60188009}},	//   reeg, _dio_, _нужд, _хотя_,
   {{0x61e180e7,0x26c20084,0x63b982f7,0x5555803d}},	//   uill, vyko_, _wown, _آپار,
   {{0x61e18657,0x7dd00009,0x442683a7,0xb5fb0658}},	//   rill, _jäse, _fio_, trán,
   {{0x61e18659,0x4426865a,0xdee6065b,0x66e6065c}},	//   sill, _gio_, доми, дома,
   {{0x7dd0016d,0xb5fb05e4,0xab0b803d,0x6fc6002a}},	//   _läse, rrán, _اتاق_, _hóck,
   {{0xb21b065d,0x26110105,0x7c26065e,0x61e1865f}},	//   _spæn, _दीदी_, _sikr, qill,
   {{0x2d9801b3,0x3e76006a,0x2d8a00b4,0x3b960073}},	//   rdre_, sæt_, rebe_, мјат,
   {{0x6ff60307,0x3ea00660,0xea01001c,0xe3bf0661}},	//   _تستط, _trit_, _đạp_, _piña_,
   {{0x61fe0662,0x2bbf0663,0x3b070098,0x7c260664}},	// [280] topl, _एकरा, дето_, _vikr,
   {{0x3cde8665,0xe3bf05e4,0xc98601a8,0x2fcd8162}},	//   _कइले_, _viña_, بشري, _aleg_,
   {{0x7c260666,0x61fe0667,0x8cb503eb,0x2fc68668}},	//   _tikr, ropl, _उपयो, tkog_,
   {{0xe3bf062f,0x672d8669,0x2fcd810c,0x4f0a866a}},	//   _tiña_, žajn, _cleg_, онен_,
   {{0x442680a9,0xa91c80e1,0xa248003d,0xdb0f016a}},	//   _rio_, teľk, _ریال_, _tocá,
   {{0x2fc68289,0x44268010,0x3f8b017f,0x7d1c808b}},	//   skog_, _sio_, zecu_, _úrsk,
   {{0xd49781bb,0x52b8866b,0x6da3866c,0x69ce066d}},	//   дры_, ेन्स, тија, _ilbe,
   {{0x27e000e4,0xcfaa866e,0xc1788196,0x2918066f}},	//   _nmin_, _باسم_, ynės_, ągać_,
   {{0x8cb50670,0x44268671,0x29078672,0xb5fb016a}},	//   _उपभो, _vio_, _ayna_, rtáz,
   {{0x27e00673,0x7c3e003a,0x76428674,0x290781b0}},	//   _amin_, _otpr, mpoy, _byna_,
   {{0x44268675,0xf1bf001c,0x3f8b026c,0xf99301c6}},	//   _tio_, _quái_, tecu_, דרת_,
   {{0x443e8065,0x72c68676,0x62860677,0x29078114}},	//   _itt_, _обез, _opko, _dyna_,
   {{0x441b8158,0x69ce0358,0xa3ab8105,0x3f8b017f}},	//   _וואס, _olbe, खार_, recu_,
   {{0x34950678,0x443e8679,0x27e0067a,0x7dcf8366}},	//   нагр, _ktt_, _emin_, _tøse,
   {{0xe4e400e8,0x628600eb,0xc1788084,0x7d088366}},	//   вітн, _apko, snės_, _jyds,
   {{0x69ce067b,0xcbcd00ab,0xddc9801b,0x7dd0039c}},	//   _albe, রচ্ছ, _dveř, _räse,
   {{0x6feb0063,0x5215067c,0xbbbf036d,0x6b82867d}},	// [290] jęci, едат, _एकीक, _mbog,
   {{0x443e867e,0x2fcd867f,0x64588680,0x26000072}},	//   _ott_, _sleg_, ksvi, ळवणी_,
   {{0x3cde835a,0x443e8681,0x6d470682,0x764d0683}},	//   _केले_, _ntt_, mbja, _hway,
   {{0x764d0684,0x69ce0685,0x64588686,0x7dd00106}},	//   _kway, _elbe, dsvi, _väse,
   {{0x443e8687,0xb906058c,0x6fc600f7,0x733a00be}},	//   _att_, _बे_, _dóch, _מערס,
   {{0x6b828688,0x6d550689,0x63bd068a,0x764d0247}},	//   _abog, naza, _hosn, _mway,
   {{0x26c9803a,0x6458868b,0x6aa2808e,0x63bd007b}},	//   šao_, gsvi, _arof, _kosn,
   {{0x6d55068c,0x672d068d,0xe3bf04c3,0x61e5068e}},	//   haza, _ngaj, _miño_, lihl,
   {{0x443e868f,0xb5fb0019,0x29078690,0x6aa28691}},	//   _ett_, trál, _syna_, _crof,
   {{0xf1b180f7,0x672d04b9,0x6e288197,0x63bd0692}},	//   اءة_, _agaj, _gidb, _losn,
   {{0xe3bf0693,0x764d0694,0x6aa2826b,0x6d550695}},	//   _niño_, _away, _erof, daza,
   {{0x649a8051,0x6b828324,0x63bd0696,0x64438502}},	//   _מסעד, _gbog, _nosn, mpni,
   {{0x0aeb8077,0xe1ee8098,0x6d55005d,0x34c80697}},	//   _براي_, _бг_, faza, रन्द,
   {{0x7bcf0698,0x200b0699,0x6d55069a,0x6b82812b}},	//   _alcu, alci_, gaza, _zbog,
   {{0xafe6069b,0xb042801c,0xdb86069c,0x63bd069d}},	//   _покл, _trưở, нгви, _bosn,
   {{0x6b9b869e,0x7ae4869f,0x63bd0090,0x27e0008e}},	//   ndug, _žiti, _cosn, _umin_,
   {{0x6d5506a0,0xada606a1,0x7bc98198,0x200206a2}},	// [2a0] baza, _запл, ikeu, moki_,
   {{0xdb0d0125,0x200206a3,0x7bcf0144,0x673b85ee}},	//   rkað, loki_, _elcu, _afuj,
   {{0x7dcb0457,0xb5fb016b,0x717300f7,0x7bc98198}},	//   _müsl, kráj, اهما, kkeu,
   {{0x2d9a06a4,0x48c300ab,0x601606a5,0x2ca5006a}},	//   _hape_, ্পূর, lámb, ælde_,
   {{0x2d9a06a6,0x490686a7,0x7bc986a8,0xfeb7803d}},	//   _kape_, _सुनो_, dkeu, فاوت_,
   {{0x63ab86a9,0x645886aa,0xab5b01ec,0x200206ab}},	//   _angn, tsvi, _flüs, hoki_,
   {{0x200206ac,0x2d9a06ad,0xa3ab86ae,0xb0de86af}},	//   koki_, _mape_, खां_, _फेंग,
   {{0x645883a6,0x6b9b84a7,0x8cb182f1,0x9f5901ca}},	//   rsvi, gdug, _अपरो, tosí_,
   {{0x6d5506b0,0x60e00110,0x645886b1,0x200206b2}},	//   yaza, žymė, ssvi, doki_,
   {{0x27e686b3,0x7d08867f,0x2d9a06b4,0x6b8d011b}},	//   lion_, _tyds, _nape_, zeag,
   {{0xc05786b5,0x764d06b6,0x5fc486b7,0xdddb80ce}},	//   нія_, _sway, _वकाल, _upuš,
   {{0x6d5506b8,0x6b8286b9,0x27e686ba,0x6b998326}},	//   waza, _ubog, nion_, _gawg,
   {{0xcf938158,0x26c686bb,0x6d5506bc,0x63bd06bd}},	//   נטש_, nyoo_, taza, _rosn,
   {{0x7d0306be,0xbbc902ef,0x2bc906bf,0x764d06c0}},	//   _ønsk, रस्क, रस्थ, _vway,
   {{0x6d5506c1,0x26ec8665,0x63bd06c2,0x5ff50098}},	//   raza, जपुर_, _posn, _изку,
   {{0xe3bf04c3,0x6d5a06c3,0x27e686c4,0x60160118}},	//   _viño_, ótar, jion_, táme,
   {{0x27e686c5,0x6b8d06c6,0x6d5506c7,0x497506c8}},	// [2b0] dion_, reag, paza, клас,
   {{0x601606c9,0x8cb1809a,0x63bd008e,0x6b8d06ca}},	//   ráme, _अपलो, _wosn, seag,
   {{0xc95380be,0x6fc60187,0x6f0986cb,0x61e506cc}},	//   רמע_, _sóci, _syec, rihl,
   {{0x27e686cd,0x61e5005d,0x60c50009,0x76598428}},	//   gion_, sihl, ryhm, tswy,
   {{0xa3b486ce,0xee3886cf,0x7e7d06d0,0xd35604de}},	//   ञान_, ені_, ntsp, _שישי_,
   {{0xfce581cf,0x442b06d1,0x7bc981ed,0xd5bb86d2}},	//   коло, _hic_, wkeu, ясе_,
   {{0x645a06d3,0x27e68114,0x02c986d4,0x6b9b86d5}},	//   štiv, bion_, िन्न, tdug,
   {{0x27e686d6,0x25ac802a,0x644386d7,0x443306d8}},	//   cion_, _endl_, rpni, _mux_,
   {{0x7dd000f2,0x7bc986d9,0x443306da,0x2a690066}},	//   _läsa, rkeu, _lux_, nrab_,
   {{0x644386db,0x3f8f807b,0xddc28110,0x7bc986dc}},	//   ppni, legu_, puoš, skeu,
   {{0x660386dd,0xa3c306de,0x442b06df,0x200206e0}},	//   monk, ्सा_, _oic_, toki_,
   {{0x442b06e1,0xb4bf8076,0xf77206e2,0x66038234}},	//   _nic_, ुनी_, جاد_, lonk,
   {{0x443306e3,0x200206e4,0x3f9b0609,0x7e7d06e5}},	//   _aux_, roki_, _daqu_, gtsp,
   {{0x008586e6,0x442b06e7,0x7d048214,0x27e686e8}},	//   _алко, _aic_, şise, zion_,
   {{0xdce18214,0xa50706e9,0x601886ea,0xd62706eb}},	//   _kalı, вера_, líme, торе_,
   {{0x27e682be,0x3f8f86ec,0x442b06ed,0x660386ee}},	//   xion_, jegu_, _cic_, honk,
   {{0x442b06ef,0x443302be,0x3ae80077,0x2ebd86f0}},	// [2c0] _dic_, _eux_, ربری_, ्नोत,
   {{0xb14306f1,0x261683db,0xdcfc00eb,0x7c2b86f2}},	//   инул, _पीढी_, ndrī, _ligr,
   {{0x27e686f3,0xe0d200f7,0xd6a9026a,0x27f7015b}},	//   tion_, جزء_, _قدیم_, _سفید_,
   {{0x7c2b86f4,0x2d858039,0xa3a9064a,0x442b06f5}},	//   _nigr, _able_, _गोप_, _gic_,
   {{0x27e686f6,0xa3ab823c,0x644186f7,0xc32000ab}},	//   rion_, खाई_, _atli, _ফ্রি_,
   {{0x27e686f8,0xd94306f9,0x442b0087,0x614306fa}},	//   sion_, _вери, _zic_, _вера,
   {{0xdce183bf,0x27e686fb,0x2d8e86fc,0x09e306fd}},	//   _balı, pion_, refe_, _торн,
   {{0x442006fe,0x7bd606ff,0xb5fb0700,0xd9ca8701}},	//   nmi_, nhyu, nuár, िस्ट,
   {{0x64418702,0x877b80be,0x60188661,0x3cde8074}},	//   _etli, _קאמי, gíme, _कइके_,
   {{0x79a68703,0x66038704,0xf1a68705,0x2fc00706}},	//   трие, conk, трин, _aoig_,
   {{0x799c0707,0x7bd60708,0x44200709,0x4ce080ab}},	//   _marw, khyu, kmi_, _পুরু,
   {{0x6d58870a,0x7e7d070b,0x4420070c,0x9f4b0020}},	//   lava, ttsp, jmi_, vocó_,
   {{0xb5fb0065,0x2902809a,0x4420070d,0xf40800ab}},	//   nság, łka_, dmi_, লগার_,
   {{0x6d58870e,0x442b00f1,0xdd11026f,0x4420070f}},	//   nava, _sic_, _výži, emi_,
   {{0x61e88710,0x2fd20711,0xf41480be,0x645c0106}},	//   midl, _flyg_, ָפּ_, gsri,
   {{0x6d588712,0xdce18713,0xa3dd009a,0xef670098}},	//   hava, _xalı, थों_, _ръко,
   {{0x799c0714,0x6d588715,0x2009010c,0x2b4900fe}},	// [2d0] _barw, kava, _ikai_, rbac_,
   {{0x6d588025,0x44200716,0x799c0717,0xb5fb0718}},	//   java, ami_, _carw, dság,
   {{0x2d9100b4,0x48c300ab,0x3c388019,0xd246853d}},	//   meze_, ্প্র, _név_, _گن_,
   {{0x2d910719,0x6603871a,0x4420071b,0x926b0087}},	//   leze_, wonk, cmi_, _орга_,
   {{0x645a003a,0x35a8023c,0xd2468065,0x799c0428}},	//   štit, _छोड़, _دن_, _farw,
   {{0xa3c3035a,0x6d58871c,0x3e7b82be,0x6575071d}},	//   ्सव_, gava, rêt_, ngzh,
   {{0x6603871e,0xfd500135,0xdb0b80e7,0x6b9d0122}},	//   ronk, _aghụ, _ingé, _kasg,
   {{0x7c3e803e,0x6603871f,0x7bcd0720,0x1fa48721}},	//   ípra, sonk, nkau, _круг,
   {{0x6603807a,0x2fc00722,0x6b9d0723,0x2d910724}},	//   ponk, _roig_, _masg, keze_,
   {{0x44200725,0x20090041,0x3c3880e7,0x61e88726}},	//   zmi_, _akai_, _fév_, gidl,
   {{0x7c2b8727,0x44200728,0x7bcd0364,0x80ad8540}},	//   _tigr, ymi_, kkau, टमें,
   {{0x366a0729,0xeb9f006a,0x5275872a,0x7bcd01c0}},	//   намо_, _skøn_, _буку, jkau,
   {{0x6f0d00b4,0x4420072b,0x765d072c,0x61e8872d}},	//   _cyac, vmi_, gssy, bidl,
   {{0x63bb872e,0x4095872f,0x2d9102a0,0x645c0730}},	//   ljun, _брит, geze_, tsri,
   {{0x07a60048,0x44200731,0x6b9d0732,0x6f0d0733}},	//   _байн, tmi_, _basg, _eyac,
   {{0x63bb8734,0x7bcd0735,0x44200736,0x6b9d0114}},	//   njun, gkau, umi_, _casg,
   {{0xc332836b,0xdcfa80eb,0x6d588737,0x60160511}},	// [2e0] מון_, _patī, yava, cáma,
   {{0xd05a0558,0x64410207,0xddd481ac,0x7bd602a0}},	//   ерді_, ílic, _ťažk, shyu,
   {{0x6d588738,0x63bb808b,0x2a7f82f1,0x6b9d0739}},	//   vava, kjun, htub_, _fasg,
   {{0x4444073a,0x61e8873b,0xb4c2073c,0x799c073d}},	//   _it_, zidl, ्नी_, _warw,
   {{0x6d58873e,0x4444073f,0xa3c30740,0x799c0741}},	//   tava, _ht_, ्सर_, _tarw,
   {{0x270300ff,0xb5fb0742,0x7dd001d6,0x98be8196}},	//   ổng_, trái, _mäso, lbtą_,
   {{0x6d588743,0x44440744,0x61e8827f,0x395a01e0}},	//   rava, _jt_, vidl, maps_,
   {{0x7dc68125,0x2d910745,0xb5fb01a8,0x6f090035}},	//   _aðst, zeze_, rrái, żeci,
   {{0x44440746,0x6d5e84c3,0xb4c2000d,0x0aea80f7}},	//   _lt_, ópas, ्नु_, عربي_,
   {{0x44440747,0xc27b03de,0x765d0163,0x776402f9}},	//   _ot_, עריי, vssy, _adix,
   {{0x20090748,0x28f88749,0x63bb874a,0x26e200ab}},	//   _pkai_, тень_, bjun, _গুলো_,
   {{0x09c1016f,0x2d91074b,0x2006874c,0x765d074d}},	//   _शक्य, weze_, nooi_, tssy,
   {{0x4444004c,0x61e8874e,0xa91c81ac,0x2d91074f}},	//   _at_, pidl, teľs, teze_,
   {{0x7dcb0006,0xb5fb003e,0x0cb680c8,0x23278750}},	//   _küsi, hráv, জনীত, _сочи_,
   {{0x2d910751,0x6b840752,0x6b9d0753,0xd13f809a}},	//   reze_, ffig, _pasg, łącz_,
   {{0x672d8754,0x44440755,0x2d910756,0x261a06a7}},	//   žaji, _dt_, seze_, _मीठी_,
   {{0x44440757,0x99550758,0x7bcd0759,0xf96b075a}},	// [2f0] _et_, икац, rkau, ерей_,
   {{0x2d9e875b,0x7bcd075c,0x444401c6,0x6b9d075d}},	//   _nate_, skau, _ft_, _wasg,
   {{0x6b9d0014,0x3ea904e8,0x92b50264,0x63bb875e}},	//   _tasg, _hrat_, জনে_, yjun,
   {{0xb4d100a5,0x3ea9075f,0x66070088,0x64450760}},	//   वनी_, _krat_, lojk, _ithi,
   {{0x2d9e8761,0x248c80ee,0x29180762,0xd2440087}},	//   _bate_, _apdm_, _ezra_, _гэси,
   {{0xd6580051,0x22490763,0x6da58764,0x2d9e802e}},	//   ניות_, mpak_, рика, _cate_,
   {{0xeb998765,0x2d9e8766,0x23d58767,0xa3b90768}},	//   вий_, _date_, ицир, चाप_,
   {{0xea010104,0xb5fb01df,0x3ff980be,0x2d9e838a}},	//   _đẹp_, nsáb, _ספּע, _eate_,
   {{0x22490769,0x59a686a7,0xe3b6876a,0xd7f88084}},	//   npak_, _कोहर, рбы_, _сур_,
   {{0x3a2e83a8,0x7c2f076b,0x6ff201a9,0x64450234}},	//   _cifp_, _licr, māci, _othi,
   {{0x7dd000f2,0x7c9586e2,0xf9920039,0x6607076c}},	//   _säso, _خلاص, חרי_, dojk,
   {{0x2249076d,0xf1d98651,0x7c2f0706,0x2d218072}},	//   kpak_, योजन, _nicr, मधील_,
   {{0x6445076e,0xa3b90321,0x2d9e876f,0x6ff200eb}},	//   _athi, चान_, _yate_, nāci,
   {{0x3ea9008e,0x7bc281c0,0x9fb881d0,0xe4da00d7}},	//   _drat_, _zoou, včí_, پورت_,
   {{0xb4c20770,0x3ea9010b,0xd5e4019d,0x69c38771}},	//   ्ने_, _erat_, _apị, _ione,
   {{0x6ff200eb,0xa3a90105,0x2d9e027f,0xb5fb04f0}},	//   kāci, _गोद_, žte_, dráu,
   {{0x442f8772,0x44440773,0x64450774,0x60188775}},	// [300] _mig_, _wt_, _ethi, jíma,
   {{0x44440776,0x442f8777,0xbbd28778,0xe9d70779}},	//   _tt_, _lig_, _तत्क, аку_,
   {{0x4444077a,0x673b077b,0x69c3877c,0xd91000d5}},	//   _ut_, žuje, _mone, سیر_,
   {{0xc60e83b7,0xddc28029,0x6d41877d,0x53ca0424}},	//   ित्य_, droš, _afla, _रविश,
   {{0x7c24077e,0x9f82077f,0x7ae90669,0xeb970081}},	//   mmir, _yóò_, _žetv, _тия_,
   {{0x2b4d8780,0x6d5c0781,0x69c380b4,0x442f8782}},	//   ebec_, nara, _none, _aig_,
   {{0x442f8783,0x601d02be,0xb5fb026f,0x2bdd016f}},	//   _big_, léme, práv, नोका,
   {{0xa3b905b3,0x442f8784,0x0b8a8139,0x938a8785}},	//   चाय_, _cig_, тски_, тска_,
   {{0x442f8786,0x2a6d8787,0x6d5c0788,0x3c3c0789}},	//   _dig_, greb_, kara, _lív_,
   {{0x6d5c078a,0x4e7b8051,0x64430036,0x442f878b}},	//   jara, _באמצ, _énig, _eig_,
   {{0x6607003b,0x69c3878c,0xb4c203bb,0x3137078d}},	//   vojk, _done, ्नो_, ינים_,
   {{0x6d57078e,0x41a68076,0x3ea9078f,0x0aea8790}},	//   _sexa, _कोरस, _prat_, _идей_,
   {{0xdefb0791,0x6d5c0792,0x69c38793,0x7c240669}},	//   тын_, fara, _fone, dmir,
   {{0x6d5c0794,0x442f8795,0x7c2f031d,0x3ea90796}},	//   gara, _zig_, _sicr, _vrat_,
   {{0x442f8069,0xe4a40256,0x6d570797,0x6ff20029}},	//   _yig_, орто, _vexa, zāci,
   {{0x7c240798,0x3ea90799,0x83350081,0x69c3879a}},	//   gmir, _trat_, снах, _zone,
   {{0x6d5c079b,0x8d8701a1,0x69d5001b,0xba5501a8}},	// [310] bara, _кунд, _plze, صناع,
   {{0xe29f8125,0xc1788110,0x6ff201a9,0x3958079c}},	//   æði_, ngė_, vāci, _cers_,
   {{0xd1380698,0x224902f7,0x6445079d,0x4395079e}},	//   рху_, spak_, _uthi, _ланс,
   {{0x3958079f,0x224687a0,0x6ff200eb,0x6018807b}},	//   _eers_, _otok_, tāci, tíma,
   {{0x6d4181ec,0x9f42016b,0x60160019,0xbea587a1}},	//   _pfla, niká_, zámo, салк,
   {{0x442f87a2,0xb5fb07a3,0x6ff20029,0x629d07a4}},	//   _sig_, crát, rāci, _isso,
   {{0x27e907a5,0xe3b180f7,0x22468748,0x69c387a6}},	//   _oman_, كرة_, _atok_, _rone,
   {{0x69c387a7,0x442f822c,0x27e907a8,0x2a6d87a9}},	//   _sone, _qig_, _nman_, treb_,
   {{0x69c387aa,0xdcfe01a9,0x36d4804a,0x2b4d87ab}},	//   _pone, _papī, _дотр, rbec_,
   {{0xdef887ac,0x27e90590,0x25a107ad,0x69da8039}},	//   _тыс_, _aman_, _nahl_, ghte,
   {{0x2ed00076,0x442f87ae,0x1bf905e8,0x69c387af}},	//   हन्त, _tig_, ्काल_, _vone,
   {{0x6d5c07b0,0xcdc90051,0x601607b1,0x69c380f3}},	//   wara, _אך_, rámo, _wone,
   {{0x6d5c07b2,0x69c387b3,0x539a8039,0x7bdb8079}},	//   tara, _tone, _תינו, mhuu,
   {{0x69da87b4,0x27e9011e,0x32b881a8,0x601603a8}},	//   chte, _eman_, _خدمة_, pámo,
   {{0x629d07b5,0x04460226,0xb5fb016b,0x25a104dc}},	//   _asso, себн, vrát, _dahl_,
   {{0xe29a07b6,0x9f82007b,0x2b5907b7,0x7dd007b8}},	//   лаб_, _góð_, _cesc_, _käsk,
   {{0x2b400390,0xaaa786ae,0x09360742,0xb5fb07b9}},	// [320] rcic_, कटिक, مراج, trát,
   {{0x6d5c07ba,0x2a6007bb,0x2d87826c,0x601d07bc}},	//   qara, rsib_, jfne_, réme,
   {{0xfbd207bd,0x395807be,0x629d07bf,0x6f1b85e4}},	//   _فتح_, _vers_, _esso, _azuc,
   {{0xc88507c0,0x25a107c1,0x201f87c2,0x939607c3}},	//   daşı_, _zahl_, _chui_, _اجدا,
   {{0xe5c687c4,0x248c01b9,0x69da87c5,0x201f8362}},	//   йско, ħdmu_, yhte, _dhui_,
   {{0x443a07c6,0x62840106,0x6b96057b,0xe196002e}},	//   _kup_, mtio, leyg, _урмэ,
   {{0x7bc6029b,0x224687c7,0x62840009,0x29c9802a}},	//   _koku, _stok_, ltio, _lúas_,
   {{0xd00a87c8,0x443a0067,0x6b9607c9,0xb33b0315}},	//   _себе_, _mup_, neyg, _kaça,
   {{0x7ae907ca,0x63a407cb,0x628407cc,0x7bc607cd}},	//   _þett, idin, ntio, _moku,
   {{0x7bc607ce,0x27e907cf,0x984a8098,0xb33b07d0}},	//   _loku, _sman_, ляма_, _maça,
   {{0x7dcb07d1,0xe45287d2,0xb5fb07d3,0x8b66803d}},	//   _xüsu, _رضا_, krár, _هاشم,
   {{0x628407d4,0x69da820f,0x7bc6029b,0x6d5a816d}},	//   ktio, shte, _noku, _heta,
   {{0x6d5a87d5,0x63a407d6,0x7f5d002a,0xb4d107d7}},	//   _keta, ddin, rasq, वन्_,
   {{0x27078104,0x29c9862f,0x7c3a87d8,0xd6d800e8}},	//   ống_, _dúas_, _kutr, стю_,
   {{0xdce887d9,0x6d5a87da,0x395e87db,0x69d884a2}},	//   _kadı, _meta, mats_, _ilve,
   {{0x395e87dc,0x6d5a87dd,0x27e907de,0x7c3a811b}},	//   lats_, _leta, _uman_, _mutr,
   {{0x63a2822e,0x7c3a82a5,0x200b07df,0xb33b07e0}},	// [330] _maon, _lutr, moci_, _caça,
   {{0x7c3a87e1,0x2ba905b3,0x395e87e2,0x63a407e3}},	//   _outr, _चोरा, nats_, adin,
   {{0xceeb8077,0x5335079e,0x443a07e4,0x628407e5}},	//   گران_, _мент, _gup_, atio,
   {{0x61c587e6,0xb33b07e7,0xdea1803d,0x395e87e8}},	//   _लक्ष, _faça, ویزی, hats_,
   {{0x628407e9,0x7c3a86e3,0x6d5a87ea,0x25ed835a}},	//   ctio, _autr, _beta, _अगदी_,
   {{0x313507eb,0x6d5a87ec,0x7bc6029b,0xdcf88110}},	//   _февр, _ceta, _zoku, nevė,
   {{0x7bc6029b,0x628282a3,0x395e87ed,0x7c3a8087}},	//   _yoku, _aqoo, dats_, _cutr,
   {{0x69d887ee,0x69c707ef,0x7c3a87f0,0x6d5a87f1}},	//   _alve, _hoje, _dutr, _eeta,
   {{0x69c7003a,0xe9d987f2,0x64488201,0x200b0052}},	//   _koje, ики_, _etdi, doci_,
   {{0x7dcb0352,0x29c984c3,0x395e87f3,0x7dd0016d}},	//   _müss, _rúas_, gats_, _väsk,
   {{0x29c987f4,0x69c707f5,0x63a407f6,0x645e80e1}},	//   _súas_, _moje, ydin, špir,
   {{0x6d4507f7,0x69d887f8,0x6d5a87f9,0x200b0722}},	//   _afha, _elve, _zeta, goci_,
   {{0x395e87fa,0x6d5a87fb,0xa2948112,0xd9fb016f}},	//   bats_, _yeta, _наці, ्वात_,
   {{0x7dd003ff,0x395e87fc,0x7bc6029b,0x63a40295}},	//   _käsi, cats_, _soku, wdin,
   {{0x7bc607fd,0x63a287fe,0x64a307ff,0x7dcb0800}},	//   _poku, _yaon, мара, _rüst,
   {{0xb06880d5,0x63a40801,0x29c984c3,0x7dcb0074}},	//   _اصول_, udin, _túas_, _süst,
   {{0x63a40802,0x98a583bf,0x7dcb02f1,0x224d8088}},	// [340] rdin, malı_, _püst, npek_,
   {{0x7bc6029b,0x63a40803,0x3ea006c0,0x69c70804}},	//   _woku, sdin, _isit_, _coje,
   {{0x69c70805,0x62840806,0x7bc60807,0xdbd18214}},	//   _doje, stio, _toku, _güçl,
   {{0x2d980808,0x62840809,0x510c8158,0x98a5880a}},	//   lere_, ptio, נהאַ, nalı_,
   {{0xd5ba8009,0x4e96880b,0x63a2880c,0x601d080d}},	//   иск_, تشار, _raon, néma,
   {{0x2d98080e,0x7c3a81f1,0x3ead809f,0x7e6280b9}},	//   nere_, _putr, _dret_, rsop,
   {{0x395e880f,0xaff58065,0x98a5861c,0xb4d4853f}},	//   vats_, _کہنا_, kalı_, हने_,
   {{0x2d980810,0xdce88201,0x32668811,0x9faf001b}},	//   here_, _qadı, отов, tří_,
   {{0x6d5a8812,0x395e8813,0x2d980814,0xdb1d0019}},	//   _teta, tats_, kere_, _kosá,
   {{0x2d980815,0x670e0816,0xddc2809a,0x63a2804f}},	//   jere_, _सड़क_, społ, _waon,
   {{0x2d980817,0x395e8818,0x63a282b8,0xeb9a8819}},	//   dere_, rats_, _taon, _вие_,
   {{0x395e881a,0xf8ad881b,0xb09b01c6,0x2d98038a}},	//   sats_, اکو_, ביטר, eere_,
   {{0x2d98081c,0x200b081d,0x395e881e,0xa3b9081f}},	//   fere_, roci_, pats_, चास_,
   {{0x2d980820,0xddcf0162,0x61ea8162,0x69d88821}},	//   gere_, ducţ, _umfl, _ulve,
   {{0xfbd30013,0xa1778051,0x69c70822,0xc05a821e}},	//   وتر_, _ועוד_, _roje, _тіл_,
   {{0x44220823,0x69c70824,0xb5fb0825,0x98a58826}},	//   _chk_, _soje, rráq, calı_,
   {{0x2d980827,0x69c70828,0xe1f30829,0x7c22882a}},	// [350] bere_, _poje, وسط_, _mhor,
   {{0x2d98082b,0x44220006,0xdddb882c,0x3f99082d}},	//   cere_, _ehk_, _spuž, lesu_,
   {{0xe7f78076,0x2d81082e,0x69c7026f,0x7649882f}},	//   ंचला_, _iche_, _voje, _stey,
   {{0x3ead8830,0x320c8831,0x69c7009a,0x4c9a04de}},	//   _pret_, hody_, _woje, _פברו,
   {{0xb3ba0039,0x320c866f,0x00000000,0x00000000}},	//   _המרכ, kody_, --, --,
   {{0x7c228832,0x270a0104,0x27ef8833,0x246580eb}},	//   _ahor, ờng_, sign_, tēm_,
   {{0x98a58059,0xc5f4007c,0x7c228834,0x6b898122}},	//   yalı_, ודס_, _bhor, tfeg,
   {{0x3cfc012a,0x44290835,0x2d9800b4,0x3f99005d}},	//   ילונ, nma_, zere_, jesu_,
   {{0x6aa48836,0x7c228837,0x27ed8838,0xe7af009a}},	//   _šifr, _dhor, _imen_, _जोधप,
   {{0xe9d98139,0xaca38135,0x2d810135,0xba228071}},	//   ско_, _ahụm, _nche_, ндык,
   {{0x2d980839,0x4429083a,0x7c228013,0x224d883b}},	//   vere_, kma_, _fhor, spek_,
   {{0x2d98082e,0x7c22883c,0x4429083d,0x2fc9002a}},	//   were_, _ghor, jma_, _coag_,
   {{0x2d98083e,0x4429083f,0x98a583bf,0x25a58840}},	//   tere_, dma_, ralı_, _kall_,
   {{0x44290841,0x7c22816b,0x7dd00338,0x7ddd810c}},	//   ema_, _zhor, _läsv, _hèsb,
   {{0x2d980842,0x7c298843,0x44220573,0x27ed8844}},	//   rere_, omer, _phk_, _omen_,
   {{0x2d980845,0x44290846,0x4a460847,0x7c298848}},	//   sere_, gma_, знав, nmer,
   {{0x2d980849,0x6d41084a,0xe9da084b,0x236000dd}},	// [360] pere_, ılar, бка_, raij_,
   {{0x4429084c,0xb33b02be,0x7c29884d,0xdb04084e}},	//   ama_, _faço, hmer, ndié,
   {{0x6d5e00eb,0x7c29884f,0x6d3b01c6,0x63768850}},	//   _iepa, kmer, _לתינ, nünü,
   {{0xb4b800c2,0x7c298851,0xf1ba8129,0x291d0326}},	//   चमी_, jmer, _nhơn_, ƙwan_,
   {{0x6d5e0852,0xa3b90853,0xb4e486a7,0xa7fd02d0}},	//   _kepa, चार_, _पेड़_, ksın,
   {{0x6d5e0854,0x63a60855,0x7c228039,0x25a58856}},	//   _jepa, _hakn, _shor, _call_,
   {{0x25a58698,0x7c228857,0x63a60858,0x320c83fb}},	//   _dall_, _phor, _kakn, vody_,
   {{0x6d5e0859,0x7bd6085a,0x7c29885b,0xdcf881a9}},	//   _lepa, nkyu, gmer, levī,
   {{0x63a6085c,0x320c885d,0x25a5885e,0xdb040036}},	//   _makn, tody_, _fall_, udiè,
   {{0x64a6885f,0x20030025,0x672082fd,0xdca68860}},	//   _наза, čkim_, _izmj, _нази,
   {{0x44290861,0xa3190740,0x7c298862,0x660e0079}},	//   yma_, _दर्ज_, bmer, dobk,
   {{0x7c228863,0x44290864,0x2d810865,0x443e8866}},	//   _uhor, xma_, _sche_, _iut_,
   {{0x6d5e05f8,0xe80d80ba,0xb80d86b7,0x7c3e00e7}},	//   _bepa, िकता_, िकतम_, _aupr,
   {{0x6d5e0867,0x443e8868,0x1a9b80be,0x224b80e1}},	//   _cepa, _kut_, _לידע, ícke_,
   {{0x44290869,0x7c3e002e,0xdcf881a9,0xa3b9086a}},	//   tma_, _cupr, devī, चाल_,
   {{0x4429086b,0x443e886c,0x7dcf80e8,0x63a600b9}},	//   uma_, _mut_, _høst, _cakn,
   {{0x5a3500b3,0x443e886d,0x601d086e,0x69dc0362}},	// [370] днат, _lut_, lémo, _blre,
   {{0x443e804c,0x6d5e04eb,0x7c29886f,0x2d810870}},	//   _out_, _gepa, zmer, _uche_,
   {{0x7c298428,0xf8dc86ae,0x442902d0,0x9f4f8036}},	//   ymer, मनिय, pma_, ligé_,
   {{0xc10400a0,0x6d488871,0xa7fd02d0,0x60160118}},	//   روني, _afda, zsın, támi,
   {{0xf7708872,0x443e8873,0x6da586f1,0x81bc80eb}},	//   طان_, _aut_, дила, rmēj,
   {{0x443e804c,0x60160874,0xf6508875,0x6b828876}},	//   _but_, rámi, ائن_, _acog,
   {{0x63a60877,0x25a58722,0xdca28098,0x70940878}},	//   _yakn, _vall_, ващи, _парф,
   {{0x7dd00879,0x443e811e,0x601d087a,0x25a5887b}},	//   _häst, _dut_, démo, _wall_,
   {{0x200f887c,0x6449887d,0x91e5887e,0x443e8036}},	//   mogi_, _žlič, допе, _eut_,
   {{0x7c29887f,0x443e8880,0x39e9835f,0x69ca8881}},	//   smer, _fut_, ідно_, _cofe,
   {{0x65638882,0x7bdd02bb,0xdd1c826f,0x764d0883}},	//   manh, _olsu, _záži, _atay,
   {{0x7dd00884,0x637683bf,0x5ec600ab,0x65638885}},	//   _läst, rünü, _লেগে, lanh,
   {{0x6d5e0886,0x7bcb8887,0x7c3e0888,0x799a8889}},	//   _pepa, _iogu, _supr, betw,
   {{0x7dd004b8,0x63a9888a,0x51878791,0x63a6088b}},	//   _näst, lden, _худа, _sakn,
   {{0xa3b90076,0x660e0831,0x7bcb888c,0x764d038a}},	//   चां_, robk, _kogu, _etay,
   {{0x7ae4011b,0x673b888d,0x6d5e088e,0x6563888f}},	//   tzit, _nguj, _wepa, hanh,
   {{0x7bcb803a,0x7dd004b8,0x6d5e0890,0x62898891}},	// [380] _mogu, _bäst, _tepa, nteo,
   {{0x673b81ca,0x7bcb8892,0x6b9b80f3,0x63a98198}},	//   _aguj, _logu, heug, hden,
   {{0xdb0f023e,0xd91000d7,0x765b8893,0x59c40894}},	//   _encà, ایز_, _awuy, लॉगर,
   {{0xef1a8895,0x63a98896,0x443e8897,0x200f8898}},	//   оме_, jden, _rut_, gogi_,
   {{0x443e831d,0x7dd0016d,0xd765803d,0x60188899}},	//   _sut_, _fäst, رنوی, ními,
   {{0x7dd0089a,0x63a9889b,0x443e869d,0x6b8281e8}},	//   _gäst, eden, _put_, _scog,
   {{0x7dd0089c,0x78450110,0xb4bc052a,0x601d002a}},	//   _häss, _tėva, _आपो_, xémo,
   {{0x69ca889d,0xd7648019,0x7dcf889e,0x7bcb889f}},	//   _sofe, _سنئی, _søst, _cogu,
   {{0x291808a0,0x7bcb88a1,0xa80283bf,0x1eaa803d}},	//   _hyra_, _dogu, ğıda, _بازي_,
   {{0x443e88a2,0x7abb0039,0x7dd008a3,0x601d08a4}},	//   _tut_, קציו, _mäss, témo,
   {{0x2d9c820f,0x7dd002af,0xc0578221,0x443e8074}},	//   meve_, _läss, мія_, _uut_,
   {{0x2d9c88a5,0x6aa28041,0x601d08a6,0x764088a7}},	//   leve_, _tsof, rémo, _kumy,
   {{0x442688a8,0x628988a9,0x7dd008aa,0xa2fd066f}},	//   _iho_, cteo, _näss, _एशेज_,
   {{0x2d9c80f1,0x7dd4809f,0x764088ab,0x7bcb83ed}},	//   neve_, _bàsi, _mumy, _zogu,
   {{0x442688ac,0x200f88ad,0x2bbb01a8,0x16340198}},	//   _kho_, yogi_, يارة_, теря,
   {{0x7bcb81df,0x6aad88ae,0x2ba908af,0x439408b0}},	//   _xogu, _šafi, _चोखा, касс,
   {{0xa3d68424,0x6563833e,0x4e0e8035,0x764d08b1}},	// [390] _हवन_, yanh, ाकाई_, _utay,
   {{0x2d9c88b2,0x442688b3,0x6b9b82af,0xdbd68074}},	//   jeve_, _lho_, zeug, _hääl,
   {{0x7dd000f2,0xdb0b80f2,0x2d9c88b4,0x63a988b5}},	//   _väst, _ingå, deve_, yden,
   {{0xdb0f03a8,0x442688b6,0xddcd016b,0x656380b9}},	//   _encá, _nho_, _staň, wanh,
   {{0x20030025,0x7c2d0687,0x656388b7,0x7dd00364}},	//   čkih_, mmar, tanh, _täst,
   {{0x442688b8,0x44390051,0x291800f2,0x0ea880e8}},	//   _aho_, _his_, _fyra_, ькій_,
   {{0x443908b9,0x7bcb88ba,0x44268046,0x656388bb}},	//   _kis_, _pogu, _bho_, ranh,
   {{0x442688bc,0x7c2d08bd,0x443908be,0x7e7d08bf}},	//   _cho_, nmar, _jis_, kusp,
   {{0x443908c0,0x66f38894,0x656388c1,0x2a6908c2}},	//   _mis_, _अधिक_, panh, nsab_,
   {{0x443908c3,0x3f9d88c4,0x600808c5,0x628988c6}},	//   _lis_, lewu_, zımd, rteo,
   {{0x628988c7,0x7c2d08c8,0x7bcb88c9,0xdb060168}},	//   steo, kmar, _togu, _pakë,
   {{0xf77208ca,0x44390046,0x64418012,0x656181a3}},	//   داد_, _nis_, _iuli, _helh,
   {{0x442d88cb,0x81d588cc,0x644188cd,0x213c80ee}},	//   mme_, _подх, _huli, _fgvh_,
   {{0x644188ce,0x7c2608cf,0x4439061f,0x3f8401b9}},	//   _kuli, _shkr, _ais_, żmu_,
   {{0x65618003,0x443908d0,0xb8f480c8,0xa3b48054}},	//   _melh, _bis_, _সে_, _छोड_,
   {{0x442d8179,0x644188d1,0x7c2d08d2,0xf0628081}},	//   nme_, _muli, gmar, _скъп,
   {{0x291e0025,0x443908d3,0x160f88d4,0x422608d5}},	// [3a0] _šta_, _dis_, िवार_, едав,
   {{0x442d88d6,0x443908d7,0x7c2d08d8,0xdb06001b}},	//   hme_, _eis_, amar, _jaké,
   {{0x443908d9,0x644188da,0x442d88db,0x61fe08dc}},	//   _fis_, _nuli, kme_, rnpl,
   {{0x442d88dd,0x7dd00364,0x3f8208de,0xe853003d}},	//   jme_, _täss, ngku_, انند,
   {{0x2d9c820f,0x442688df,0x442d88e0,0x245e001b}},	//   teve_, _rho_, dme_, lům_,
   {{0x443908e1,0x644188e2,0x442d88e3,0x27f2008e}},	//   _zis_, _buli, eme_, _lmyn_,
   {{0x644188e4,0x2d9c80f1,0xd49784d9,0x27e008e5}},	//   _culi, reve_, еры_, _olin_,
   {{0x644188e6,0x442681e9,0x44390069,0x69ce011e}},	//   _duli, _qho_, _xis_, _hobe,
   {{0x65618065,0x69ce08e7,0x7c39831d,0x2d9c8168}},	//   _felh, _kobe, _diwr, peve_,
   {{0x44268051,0x27e008e8,0xef1f08e9,0x442d88ea}},	//   _who_, _alin_, ngüe_, ame_,
   {{0x644188eb,0xdbd68364,0x33d6835f,0x27e008ec}},	//   _guli, _pääl, _підт, _blin_,
   {{0x7e7d04a2,0xa2e688ed,0x7c2d0079,0x442d88ee}},	//   tusp, _поед, xmar, cme_,
   {{0x443908ef,0x0cc906ce,0x644188f0,0xa3d58006}},	//   _ris_, रह्म, _zuli, _सकत_,
   {{0x443901e9,0x7afd88f1,0x644188f2,0x27e008f3}},	//   _sis_, úste, _yuli, _elin_,
   {{0x443908f4,0x7e7d08f5,0xdbd68009,0x644188f6}},	//   _pis_, susp, _tääl, _xuli,
   {{0x44390069,0xa4010264,0x75d8007e,0x69c88106}},	//   _qis_, ্ষ্য_, _ağzı, ljde,
   {{0x443908f7,0x98ac83bf,0x1b0e80ab,0x7f490216}},	// [3b0] _vis_, madı_, াইকে_, ñequ,
   {{0x443903f8,0x69da88f8,0x98ac861c,0x9f590174}},	//   _wis_, nkte, ladı_, insí_,
   {{0xd36688f9,0x69ce08fa,0xaca30133,0x27e00198}},	//   _په_, _dobe, _kpọg, _ylin_,
   {{0x443908fb,0x7e6d08fc,0x6e3a8362,0x2d83021e}},	//   _uis_, _kvap, _aitb, lgje_,
   {{0xe7e288fd,0x2fcd80c9,0x6e3a88fe,0x2fdf874c}},	//   _खतरा_, _voeg_, _bitb, _vlug_,
   {{0x69ce08ff,0x64418900,0x20048088,0x7d1a8901}},	//   _gobe, _puli, _ejmi_, _byts,
   {{0x442d8902,0x65618903,0x301b80f7,0x6441811c}},	//   tme_, _velh, _فترة_, _quli,
   {{0x7bcf0012,0x64418904,0x2242008e,0x69da8905}},	//   _jocu, _vuli, _yukk_, ekte,
   {{0x628d0906,0x1309835f,0x9f4200f1,0x65618907}},	//   ntao, ьний_, shkë_, _telh,
   {{0x7bcf0012,0x64418908,0xb63587c3,0x63ad0909}},	//   _locu, _tuli, _شفاع, hdan,
   {{0xf8e1090a,0x63ad090b,0x442d890c,0xdb1d00f7}},	//   पनिय, kdan, pme_, _cosú,
   {{0x13a7803d,0x79818114,0x6e3a890d,0x78bc8338}},	//   _سنتی_, sglw, _zitb, årva,
   {{0x63ad090e,0x69c4090f,0x21e401ec,0x3f8c009a}},	//   ddan, रामी, _höhe_, ędu_,
   {{0x7ae98065,0x7e6d012b,0x69da8910,0x827680be}},	//   mzet, _dvap, ckte, _יענע_,
   {{0xa8060098,0x69ce0911,0xc5630912,0x2bc58913}},	//   _изкл, _robe, ркск, वापा,
   {{0x63ad0914,0x7bc98915,0x63ab8916,0x6f16809a}},	//   gdan, njeu, _jagn, życi,
   {{0x69ce0917,0x7bcf0918,0xe7f780d4,0x7ae98919}},	// [3c0] _pobe, _docu, ूचना_, nzet,
   {{0xdb0d008b,0x63ab891a,0x867b01c6,0x63ad091b}},	//   rjað, _lagn, _קריו, adan,
   {{0xa50a091c,0x3d16835a,0x8fa6891d,0x1d0a091e}},	//   _цена_, _पुढे_, каже, _цени_,
   {{0x4444091f,0x69ce0920,0x63ab8921,0x78b5026c}},	//   _iu_, _wobe, _nagn, _drzv,
   {{0x44440922,0xe7f3809a,0x776403a8,0xe7378923}},	//   _hu_, _आगरा_, _meix, вец_,
   {{0x44440924,0x77640118,0x249a00b9,0x7ae98925}},	//   _ku_, _leix, _kppm_, dzet,
   {{0x44440926,0x63ab8098,0x6f098927,0x629986c0}},	//   _ju_, _bagn, _exec, _apwo,
   {{0x44440928,0x3d16835a,0xb5fb00f7,0x63ab8929}},	//   _mu_, _पुणे_, rsái, _cagn,
   {{0x4444092a,0x249a008e,0xdb028118,0x7ae98061}},	//   _lu_, _lppm_, _taoí, gzet,
   {{0x4444092b,0xbda587bd,0xdb1d0331,0x6e3a837a}},	//   _ou_, _محمو, _posú, _uitb,
   {{0x4444092c,0x601d092d,0x717b010f,0x69da892e}},	//   _nu_, lémi, וניס, rkte,
   {{0x63ab892f,0xb4c08076,0x7ec900f1,0xb5fb0073}},	//   _gagn, ुही_, _nëpë, nsáv,
   {{0x44440930,0x77640931,0x63ad05f5,0xd25080f7}},	//   _au_, _deix, vdan, _انت_,
   {{0x44440932,0x63ab8933,0x76440326,0xceb381c6}},	//   _bu_, _zagn, _duiy, ביש_,
   {{0x44440934,0xa3d68935,0x77640936,0x657a00f7}},	//   _cu_, _हवा_, _feix, ótha,
   {{0x249a00b9,0x600802d0,0x6b840937,0x63a0821e}},	//   _dppm_, rımc, ggig, nemn,
   {{0x44440938,0x63ad0939,0x27e6893a,0x628081e0}},	// [3d0] _eu_, rdan, dhon_, numo,
   {{0x4444093b,0xa2940160,0x601d093c,0x628d00e5}},	//   _fu_, рафі, démi, rtao,
   {{0x44440782,0xf1ba8104,0x6280893d,0x94d5093e}},	//   _gu_, _chơi_, humo, _сонц,
   {{0xf093893f,0x65650940,0x62808941,0x63a08942}},	//   ינע_, _hehh, kumo, jemn,
   {{0x44440943,0x63ab8944,0x628080eb,0x6008080a}},	//   _zu_, _ragn, jumo, nıma,
   {{0xee38835f,0x7ae98945,0x8d548098,0x63ab8946}},	//   вні_, vzet, атъч, _sagn,
   {{0x44440947,0x63ab8948,0x64450074,0x20020035}},	//   _xu_, _pagn, _juhi, ynki_,
   {{0x64450949,0x27e6894a,0x7ae9894b,0x3f89022c}},	//   _muhi, chon_, tzet, _ncau_,
   {{0x7ae9803b,0x63ab894c,0x23c580d4,0x7764094d}},	//   uzet, _vagn, वाबद, _reix,
   {{0x798502f7,0x7ae9894e,0x7764094f,0x7bdb8950}},	//   nghw, rzet, _seix, skuu,
   {{0x54558951,0x63ab8952,0x6d418953,0x7ae98019}},	//   _свет, _tagn, _igla, szet,
   {{0x44440954,0xdce38955,0x63a0808e,0x92b58250}},	//   _ru_, nanč, cemn, _محتا,
   {{0x644502f1,0xe7370956,0x3ea90957,0x62c78174}},	//   _auhi, лею_, _csat_, _جزاك,
   {{0x44440958,0x64450959,0x2002026c,0x7c3d0362}},	//   _pu_, _buhi, snki_, _aisr,
   {{0x444406e3,0xfce3095a,0x7764095b,0x6565008e}},	//   _qu_, боро, _teix, _dehh,
   {{0x4444095c,0xdce38110,0xfaa6095d,0x81bc81a9}},	//   _vu_, janč, лабо, smēt,
   {{0x6d41895e,0x4444095f,0xfe7200d5,0x032602fb}},	// [3e0] _ogla, _wu_, _ادب_, удан,
   {{0x44440960,0x6d41845a,0x63a08961,0xf1ba8129}},	//   _tu_, _ngla, zemn, _phơi_,
   {{0x44440962,0x81bc8029,0x27e68963,0x644502a0}},	//   _uu_, slēg, thon_, _guhi,
   {{0x2a6d8964,0x6d418965,0x4b550081,0xbe8a8966}},	//   kseb_, _agla, _върт, еске_,
   {{0x44200967,0x6d5c0968,0xcc3b00be,0x44320969}},	//   mli_, obra, _רעכט, mmy_,
   {{0x4432096a,0x6143096b,0xe9df00f7,0xc6930039}},	//   lmy_, _гера, _dtús_, צאו_,
   {{0xe0c7896c,0x4420096d,0xdb1d03ec,0x63a0896e}},	//   _از_, oli_, _ansè, temn,
   {{0x4420017b,0x02a6896f,0x44320970,0x6e3e0971}},	//   nli_, гром, nmy_, _lipb,
   {{0x060a8972,0xaf068973,0xe20b009a,0x248e81e0}},	//   _знак_, _спал, łóż_, stfm_,
   {{0x44200255,0x2a978013,0x63a08974,0x62808975}},	//   hli_, ائية_, semn, rumo,
   {{0x438680d5,0x683e8110,0x62808976,0x02170039}},	//   _ملاق, _būda, sumo, רחים_,
   {{0x273a8182,0x3f8686c0,0x64450977,0x9f590168}},	//   _günü_, ngou_, _ruhi, misë_,
   {{0xeab284e3,0x64450978,0x9f590168,0x98b8022b}},	//   _دعا_, _suhi, lisë_, _ferħ_,
   {{0x44200979,0x2fc0097a,0x44320035,0x6445097b}},	//   eli_, _enig_, emy_, _puhi,
   {{0x4420097c,0x9f5900f1,0xfaff00f1,0xa2ac897d}},	//   fli_, nisë_, _ndër_, जिक्,
   {{0x4420097e,0x61fa897f,0x81bc80eb,0xdb0f0118}},	//   gli_, litl, slēd, _incú,
   {{0x6d5c0098,0xdce381f4,0x3ea90980,0xe51b83b7}},	// [3f0] bbra, vanč, _usat_, _पुनि_,
   {{0x44200981,0x6d5c0362,0x61fa8982,0x9f590168}},	//   ali_, cbra, nitl, kisë_,
   {{0x44200983,0xa3d58006,0xdce38984,0xdb04016a}},	//   bli_, _सकल_, tanč, rdiá,
   {{0xb4c3035a,0x44200985,0x673b011f,0x9f5903ed}},	//   ्ही_, cli_, žuju, disë_,
   {{0xd90f0986,0x8d658987,0xdce38988,0xea0080ff}},	//   _کیا_, авле, ranč, _giầy_,
   {{0x3f758104,0x7dd48722,0x443d8989,0xaaa80081}},	//   ều_, _bàsq, _siw_, _съюз_,
   {{0x5ed380c8,0x463c098a,0x7aed047f,0x244a898b}},	//   _দেশে, געגע, lzat, _cùm_,
   {{0x7bcd098c,0x0b45898d,0x22468122,0x6d5c098e}},	//   njau, шнин, _buok_, zbra,
   {{0x7aed098f,0x63af0990,0x11e58991,0x4a458992}},	//   nzat, _macn, ижим, јнов,
   {{0x6d41803a,0x43758077,0xe9d98993,0x44200994}},	//   _ugla, _چهار, тко_, zli_,
   {{0xf1b20451,0x44200995,0x23c58996,0x53c580d4}},	//   קסט_, yli_, वादद, वादश,
   {{0x22958997,0x629d074c,0x6d5c0998,0xb4b18999}},	//   _видя, _opso, wbra, टटी_,
   {{0x228f0019,0x6d5c099a,0x61fa899b,0x4420099c}},	//   jük_, tbra, bitl, vli_,
   {{0x2d87899d,0x4420099e,0x200900b9,0xeaf8853d}},	//   ngne_, wli_, _ejai_, _حرمت_,
   {{0x4420099f,0x64a609a0,0x629d003a,0x6d5c09a1}},	//   tli_, шава, _apso, rbra,
   {{0x35c7800f,0xdb0400a9,0x864604ad,0x2fc0031d}},	//   लाड़, ndiç, _книж, _unig_,

   {{0x442009a2,0xade589a3,0x443209a4,0x896609a5}},	// [400] rli_, कसान_, rmy_, икаж,
   {{0x442009a6,0xd5a409a7,0x63af00f7,0x68e481d0}},	//   sli_, _الدی, _eacn, _řidi,
   {{0x18a609a8,0x161f09a9,0xb5fb09aa,0x68e489ab}},	//   раем, _मीटर_, rsát, _ƙidi,
   {{0x442009ac,0x7bdf09ad,0x244a8014,0x7e6409ae}},	//   qli_, ckqu, _rùm_, _kwip,
   {{0x63a409af,0xe5c689b0,0x614609b1,0x3f8689b2}},	//   mein, иско, _вега, rgou_,
   {{0xd49a8381,0x5d7a0158,0x672981a9,0x63af09b3}},	//   ври_, דאַק, _dzej, _zacn,
   {{0x53e689b4,0xcbe689b5,0x672989b6,0x00000000}},	//   ициа, иции, _ezej, --,
   {{0x9f5908cf,0xdb008065,0x63a409b7,0x7afb0289}},	//   risë_, lemé, nein, _žuti,
   {{0x9f5900f1,0x75e201ac,0xee3a89b8,0x6fb38290}},	//   sisë_, _rôzn, _ана_, _بمقا,
   {{0x63a40352,0xe61f00e7,0x9f5909b9,0x3e328019}},	//   hein, ntôt_, pisë_, _بہتر,
   {{0x7aed09ba,0x9f5909bb,0x3167819d,0x61fa89bc}},	//   zzat, lisé_, _denz_, ritl,
   {{0x228f084a,0x61fa89bd,0x656889be,0x6618816b}},	//   yük_, sitl, _hedh, lovk,
   {{0x61fa89bf,0x644889c0,0xf1c909c1,0x34df09c2}},	//   pitl, _hudi, रामन, नन्द,
   {{0x644889c3,0x656889c4,0x249e89c5,0x752d801b}},	//   _kudi, _jedh, _kptm_, řaze,
   {{0x63a409c6,0x403509c7,0x31578039,0xb4c309c8}},	//   fein, _лекс, _דיון_, ्हे_,
   {{0x81e880c8,0x644889c9,0x2cba09ca,0x7aed09cb}},	//   _যদি_, _mudi, _drpd_, tzat,
   {{0x6e950307,0x7bcd0364,0x4df88105,0x5e9500f7}},	// [410] _الخا, rjau, ्चाई_, _الخط,
   {{0x201909cc,0x7bcd09cd,0x228f09ce,0xa80281cc}},	//   losi_, sjau, rük_, şıla,
   {{0x63af09cf,0xea008028,0x6618826f,0x6d4509d0}},	//   _tacn, _giấy_, dovk, _igha,
   {{0x64570102,0x63a400e7,0xdce709d1,0x5f7480f7}},	//   _itxi, cein, najč, قاهر,
   {{0xef1f080a,0x2bc5816f,0xa3bc06a7,0x656880d7}},	//   zgün_, वासा, _आफत_, _bedh,
   {{0x75eb0059,0x201909d2,0xa1840150,0x7bc289d3}},	//   _düzg, hosi_, _мысл, _anou,
   {{0x201909d4,0x2d8789d5,0xddc98087,0x6d4509d6}},	//   kosi_, rgne_, _aveţ, _mgha,
   {{0xd77489d7,0x6e45803d,0x3ff980be,0x316781e8}},	//   _واقع, _هنرم, _עפּע, _senz_,
   {{0x6568822e,0x69d509d8,0x201909d9,0x316c89da}},	//   _fedh, _koze, dosi_, fadz_,
   {{0x6d4509db,0x3ead83a7,0x65688077,0x69d509dc}},	//   _ngha, _iset_, _gedh, _joze,
   {{0x27338104,0x645701e9,0x7e6409dd,0x2019047f}},	//   _ảnh_, _ntxi, _swip, fosi_,
   {{0x6d4509de,0xdb0609df,0x0cb3864a,0xfaff067f}},	//   _agha, _laká, ंटीम, _reën_,
   {{0xe9ce89e0,0x64570102,0x6d450609,0x05c30035}},	//   _ек_, _atxi, _bgha, शांब,
   {{0xc5f28158,0x9f590009,0x63a40114,0x644889e1}},	//   ִדן_, ensä_, wein, _yudi,
   {{0x764189e2,0xdcf70201,0x644889e3,0x201909e4}},	//   _mily, _baxı, _xudi, bosi_,
   {{0x6b8989e5,0x6618826f,0x776989e6,0x7ddd88f9}},	//   ngeg, zovk, _neex, _dèsi,
   {{0x63a409e7,0xb5fb03a7,0x69d509e8,0xdb008061}},	// [420] rein, rsár, _boze, temé,
   {{0xb5fb09e9,0x05aa04d9,0x458609ea,0x3ea002d5}},	//   ssár, _свой_, _угов, _ipit_,
   {{0x656889eb,0x3ead89ec,0x442f89ed,0x6008080a}},	//   _redh, _aset_, _ohg_, yıml,
   {{0x644889ee,0x656e09ef,0x76498144,0x6b89890d}},	//   _rudi, labh, _buey, jgeg,
   {{0x6448803b,0x6b8989f0,0x69c38009,0x764189f1}},	//   _sudi, dgeg, _onne, _bily,
   {{0x2d9187d9,0x644888a4,0x20190135,0x9f5902be}},	//   _özel_, _pudi, zosi_, risé_,
   {{0x270409f2,0xdcf70201,0x645c09f3,0x442f89f4}},	//   रपुर_, _yaxı, npri, _bhg_,
   {{0x69c389f5,0xdb06003e,0x656e09f6,0x65688077}},	//   _anne, _zaká, habh, _wedh,
   {{0x6ff58063,0x75eb0214,0x316c8890,0x600801cc}},	//   jący, _yüzd, tadz_, rıml,
   {{0xc05a89f7,0x64488573,0x76418114,0x69c38144}},	//   лім_, _tudi, _gily, _cnne,
   {{0x644889f8,0x645c0639,0x201909f9,0x656e0706}},	//   _uudi, jpri, tosi_, dabh,
   {{0x69c389fa,0xa3cc0740,0x61fe0214,0x442f82c4}},	//   _enne, लाफ_, hipl, _ghg_,
   {{0x201909fb,0x2d9809fc,0x442480b9,0xdce181a9}},	//   rosi_, ffre_, mlm_, _ielā,
   {{0x6d480024,0xddcd009a,0x10f98019,0x15eb00e8}},	//   ždan, _stał, ابیں_, уємо_,
   {{0xd12f896b,0x69d509fd,0x7c240609,0x645c09fe}},	//   _хх_, _roze, flir, gpri,
   {{0x68e10074,0xdb0f0216,0x61fe09ff,0x98a78196}},	//   _üldi, _hacé, eipl, _agnė_,
   {{0x69d50a00,0x27e90a01,0xdd9100f7,0x645c0a02}},	// [430] _poze, _ilan_, _قوة_, apri,
   {{0x44248106,0x672d0a03,0xdb098118,0x776981b4}},	//   hlm_, _izaj, ndeá, _seex,
   {{0x463c0158,0x7c240a04,0x69d50a05,0xdb1d0a06}},	//   _געזע, blir, _voze, _insí,
   {{0x75eb07d9,0x76418a07,0xdb0981a8,0x2b4680ff}},	//   _düze, _sily, hdeá, _ngoc_,
   {{0x442480dd,0x62350a08,0xdb2300d7,0xdb060a09}},	//   dlm_, _мему, _روسی, _taká,
   {{0x27180028,0x442f8573,0x27fd8114,0x321a0a0a}},	//   ọng_, _shg_, siwn_, copy_,
   {{0x27e90a0b,0x75eb0179,0x64428a0c,0x2bc58a0d}},	//   _olan_, _güze, _bioi, वाला,
   {{0xa9f385b3,0x8c428a0e,0xa3cc016f,0x5f948193}},	//   ेच्छ_, меще, लाय_, _нист,
   {{0xdd3a8012,0x22430a0f,0x6b898a10,0x6442802a}},	//   tăţi, _kijk_, rgeg, _dioi,
   {{0x6b898a11,0x645c0a12,0x75eb02d0,0xfaff067f}},	//   sgeg, ypri, _yüze, _reël_,
   {{0x27e906c0,0x600a0a13,0xe5c48a14,0x3ea00a15}},	//   _blan_, ином_, _эсто, _spit_,
   {{0xd9a60a16,0x64428081,0x7a30016d,0xdb1d016a}},	//   _ऑस्ट, _gioi, mäte, _ansí,
   {{0xdb0f0a17,0x8db6004a,0x11d58a18,0x51f58a19}},	//   _facé, осві, _мікр, _وستر,
   {{0x645c0a1a,0xcb368039,0x27e90a1b,0x672d069f}},	//   tpri, _ואני_, _elan_, _dzaj,
   {{0x656e0834,0x236001ed,0xdb0b816a,0x2ea681d0}},	//   rabh, tbij_, _magí, _गन्त,
   {{0x27e90a1c,0x656e0a1d,0x645c0a1e,0xf34e8870}},	//   _glan_, sabh, rpri, _hụrụ_,
   {{0xe1fa0a1f,0x23600613,0x3ea00a20,0x53368158}},	// [440] ага_, rbij_, _upit_, ַנען_,
   {{0x244e0a21,0xf6530039,0x645c0a22,0xf77f0214}},	//   _tým_, _קצת_, ppri, rkçe_,
   {{0x321a0873,0x7c240a23,0x224301ed,0xf34e8135}},	//   ropy_, plir, _dijk_, _mụrụ_,
   {{0xf34e8133,0xdb040174,0x7a300198,0xb09a83de}},	//   _lụrụ_, idiú, däte, ייער,
   {{0x7bc60a24,0xddc98a25,0x2d588a26,0xdce701a9}},	//   _inku, _sveš, биль_, majā,
   {{0xddc9801b,0x624901a1,0x8cb88a27,0x78af0198}},	//   _kteř, _džod, ्मलो, äivä,
   {{0xc0c900a9,0x9cca8a28,0x37e680e8,0x3ea981b9}},	//   _луѓе_, рыла_, _довг, ħata_,
   {{0xd00a8a29,0x68e30257,0x39478a2a,0x7dd00198}},	//   _тебе_, ønde, _agns_, _väsy,
   {{0x77628a2b,0xf34e8a2c,0x661c0a2d,0xc1a68a2e}},	//   mbox, _bụrụ_, kork, ојни,
   {{0x661c0a2f,0x64a68a30,0x68e901d0,0x776288dc}},	//   jork, _маза, _ředi, lbox,
   {{0x27e90220,0xf2df001c,0x7bc60a31,0xc9530039}},	//   _plan_, _ngân_, _onku, ומת_,
   {{0x645a8a32,0x68318a33,0x77628a34,0x6724018e}},	//   _itti, rådg, nbox, _byij,
   {{0xf7738039,0x661c0a35,0x99d381f9,0x63b60428}},	//   וקר_, fork, ستیا, ddyn,
   {{0xdcfa8214,0x2d9e8267,0x661c0a36,0xf34e8133}},	//   _hatı, _jbte_, gork, _gụrụ_,
   {{0xdcfa87d9,0x224b0a37,0x224300f3,0xdb6b02dc}},	//   _katı, _suck_, _rijk_, ирал_,
   {{0x69d88a38,0x27e90a39,0x3eb00009,0xf34e8133}},	//   _hove, _ulan_, ältä_, _zụrụ_,
   {{0x161a8a3a,0x672d0a3b,0x69d88a3c,0x2aab0a3d}},	// [450] धवार_, _uzaj, _kove, штво_,
   {{0x69d88a3e,0x645a8a3f,0x661c00dd,0x7bc60a40}},	//   _jove, _otti, cork, _enku,
   {{0x69d88039,0xef58819d,0xb4b50a41,0x90990a42}},	//   _move, _ịfụn, _эйнш, свет_,
   {{0x2bb68a43,0x6d488a44,0x224300f3,0x59c9001b}},	//   _अफगा, _agda, _wijk_, राहर,
   {{0x645a8a45,0xf1bc8076,0x68e3006a,0x9e6480e8}},	//   _atti, ्ञान, øndb, двід,
   {{0x76450101,0x7a3001ec,0xb5fb002a,0x764d02d0}},	//   _jihy, täte, lpáb, _muay,
   {{0x69c70a46,0x459c0158,0x5ed380ab,0xdcfa807e}},	//   _inje, יסגע, _দেখে, _batı,
   {{0xf7738a47,0x6e958009,0x7a300a48,0xf1c906ab}},	//   _زار_, _нибу, räte, रावन,
   {{0x81ae0a49,0x69d88613,0x645a8a4a,0xa3cc0935}},	//   কার_, _bove, _etti, लात_,
   {{0x69d88a4b,0x7e698135,0x99158a4c,0x2484819d}},	//   _cove, _iwep, зьмі, _ịmee_,
   {{0x69d88a4d,0x6d55009a,0x6c4980f7,0x661c0a4e}},	//   _dove, dcza, _الصف_, vork,
   {{0x764d0a4f,0x201d8035,0x3ebf8a50,0x69ce8a51}},	//   _buay, nowi_, _krut_, öber,
   {{0x63a98a52,0xdce881d0,0xa3b48074,0xf34e8135}},	//   meen, _oddě, _छोट_, _tụrụ_,
   {{0x63a98a53,0x7e698a54,0x225f859e,0x69d88a55}},	//   leen, _mwep, mpuk_, _gove,
   {{0xdcfa8457,0x8af00085,0xdce701a9,0xdb0f0144}},	//   _yatı, hbət, tajā, _oncó,
   {{0x24518a56,0x69c70a57,0x69d88a58,0x661c0088}},	//   _mám_, _anje, _zove, sork,
   {{0x661c0057,0x764d0a59,0x765b8a5a,0x7e698133}},	// [460] pork, _guay, _ntuy, _nwep,
   {{0x69d8862f,0x14bd885d,0x63a98a5b,0x42230073}},	//   _xove, ्माण, heen, едув,
   {{0x24518a5c,0x81ae00c8,0x63a98a5d,0x62960a5e}},	//   _nám_, কাল_, keen, styo,
   {{0x20020a5f,0x7bc6029b,0x26c00503,0x63a98a60}},	//   niki_, _unku, _krio_, jeen,
   {{0x1dc78a61,0x63a98a62,0xdb060106,0x64460a63}},	//   लांत, deen, _bakå, _iiki,
   {{0xdcfa82bb,0x68e18a64,0xf1d0801c,0xdb0f03a8}},	//   _satı, kyld, _mạch_, _encó,
   {{0x2451801c,0x645800e7,0x24778087,0x7e698870}},	//   _cám_, _évid, găm_, _ewep,
   {{0x63a98079,0x75eb0201,0x24518a65,0xa6d380ab}},	//   geen, _müza, _dám_, _দেওয়,
   {{0x644607ca,0x20020a66,0x36678a67,0x5a348a68}},	//   _miki, diki_, _нато_, мнит,
   {{0x68318370,0x64460a69,0x68e1813c,0x62840084}},	//   råde, _liki, fyld, irio,
   {{0x20020a6a,0x80df80c8,0x9b46803d,0x63a98a6b}},	//   fiki_, _ফেব্, _فناو, been,
   {{0x64460a6c,0x683f0110,0xf1d0801c,0x7bd985ee}},	//   _niki, _kūdi, _bạch_, _gowu,
   {{0x9f4d816d,0x7c228a6d,0x27e68a6e,0x69d88a6f}},	//   _umeå_, _ikor, ikon_, _tove,
   {{0x644603c3,0x4a7b812a,0x62840a70,0x5558002e}},	//   _aiki, _פרוב, drio, заря_,
   {{0x64460a71,0x2c5580eb,0x20020a72,0x6d550035}},	//   _biki, _kāda_, biki_, rcza,
   {{0x64460a73,0x683f0029,0x671e000f,0x69c702ce}},	//   _ciki, _līdz, _युवक_, _snje,
   {{0x4422013c,0xe802009a,0xf1d080ff,0x5edc8264}},	// [470] _dkk_, _लगता_, _gạch_, _মেসে,
   {{0xda0c8a74,0x2fc9022c,0x8af00085,0x20b08a75}},	//   िचित_, _hnag_, vbət, _जनाध,
   {{0x6284040e,0x64460a76,0xdb0b8065,0x7c228a77}},	//   ario, _fiki, _magá, _okor,
   {{0xdb0f05a4,0x64460a78,0x3ebf8a79,0x321e8a7a}},	//   _hací, _giki, _prut_, hoty_,
   {{0x44290a7b,0x2451826f,0x4ea781e2,0x9f4b0216}},	//   mla_, _sám_, яржа, licó_,
   {{0x44290a7c,0x20020a7d,0x7c228a7e,0x63a98079}},	//   lla_, ziki_, _akor, ween,
   {{0x58840a7f,0x44290a80,0x63a98a81,0xd5fb819d}},	//   _пыта, ola_, teen, _apụ,
   {{0x24518775,0x69dc8884,0x44290a82,0x7a300a83}},	//   _vám_, ören, nla_, mäta,
   {{0x44290695,0x3ebf845f,0x27ff8a84,0x63a98a85}},	//   ila_, _urut_, _imun_, reen,
   {{0x44290a86,0x13068364,0x81bc80eb,0x7c228a87}},	//   hla_, ьный_, blēm, _ekor,
   {{0x20020a88,0x66038a89,0xf1d0801c,0x2fc90a2a}},	//   tiki_, mink, _sạch_, _bnag_,
   {{0xad1a893f,0x3f8f859c,0x44290a8a,0x9f4b06a5}},	//   _ווער, nggu_, jla_, dicó_,
   {{0x44290a8b,0x7c298179,0x20020a8c,0x62898a8d}},	//   dla_, mler, riki_, queo,
   {{0x66038a8e,0x64460a8f,0x64a60a90,0x20020a91}},	//   nink, _siki, мага, siki_,
   {{0x27ed8a92,0x64460a93,0x80160a94,0xe6430a95}},	//   _olen_, _piki, _офиц, терп,
   {{0x7c2987d9,0xdb008a96,0x26c00a97,0x2d840214}},	//   nler, lemá, _trio_, şme_,
   {{0x41c901fe,0xec098104,0x66038a98,0xdb0f04c3}},	// [480] रांस, yến_, kink, _fací,
   {{0x64460a99,0xceb40086,0x66038a9a,0x27ed8669}},	//   _wiki, _isə_, jink, _alen_,
   {{0x44290a9b,0x64460a9c,0x7c298a9d,0x66038a9e}},	//   bla_, _tiki, kler, dink,
   {{0x62840a9f,0x44290aa0,0xe8d680be,0xbf9b0129}},	//   prio, cla_, ווער_, hiên,
   {{0x27e68aa1,0x7c298aa2,0x22478aa3,0x66038aa4}},	//   rkon_, dler, _oink_, fink,
   {{0x27e68aa5,0xa3cc009a,0x44200aa6,0x7bdd81ec}},	//   skon_, लाव_, loi_, ösun,
   {{0x7c298aa7,0xdcfe0214,0xbf9b03a7,0x27ed8aa8}},	//   fler, _kapı, diên, _flen_,
   {{0xfbdf0104,0x69dc0aa9,0x7c298aaa,0x44200aab}},	//   _liên_, _hore, gler, noi_,
   {{0xc9868aac,0x34ab0aad,0xdb0b8aae,0x6aa880d4}},	//   муни, _चन्द, _pagá, कबेर,
   {{0x44290aaf,0x645e0289,0x7c298ab0,0xfbdf001c}},	//   zla_, _otpi, aler, _niên_,
   {{0x69dc0ab1,0x442902bb,0x7c298620,0x2247879f}},	//   _more, yla_, bler, _dink_,
   {{0xe3638ab2,0xca488104,0x69dc0ab3,0x7c228ab4}},	//   _акци, _lời_, _lore, _ukor,
   {{0x8c438ab5,0x44290ab6,0xe81f800c,0x3f85017b}},	//   _реце, vla_, यकता_, ğlu_,
   {{0xbf9b03a7,0x69dc021e,0x9f4b0216,0x06e180ab}},	//   ciên, _nore, ticó_, _মেডি,
   {{0x62868ab7,0x44290ab8,0xdb0f05a4,0x76488ab9}},	//   škod, tla_, _vací, _midy,
   {{0x66038aba,0x44200abb,0x44290365,0xdb0d03a7}},	//   zink, goi_, ula_, ndaç,
   {{0x66038abc,0x63a28abd,0xdce7009a,0x5a350abe}},	// [490] yink, _mbon, dają, енат,
   {{0x69dc0abf,0x44290ac0,0x7c2987d9,0xddc40668}},	//   _core, sla_, zler, _zviž,
   {{0x66038ac1,0x69dc0ac2,0x44200ac3,0x27ed86c0}},	//   vink, _dore, boi_, _plen_,
   {{0x6d5a8ac4,0xdd0d009a,0x66038ac5,0x44290085}},	//   _afta, półp, wink, qla_,
   {{0x69dc0ac6,0x660381e2,0x63ad0ac7,0x36698ac8}},	//   _fore, tink, mean, чало_,
   {{0x63ad0ac9,0x69dc816d,0xed598aca,0x65750168}},	//   lean, örel, чок_, nazh,
   {{0xdcfe0179,0x7c298179,0xa3e38074,0x7bdd0acb}},	//   _yapı, tler, _नकद_, _kosu,
   {{0x66038acc,0x63ad0acd,0x7f85803f,0x7f4d0ace}},	//   sink, nean, _سلطن, _ngaq,
   {{0x69c403b7,0x7c298179,0x3d0605b3,0xdb008acf}},	//   राची, rler, _हेने_, temá,
   {{0x63ad0ad0,0x7c298ad1,0xdb1d016d,0xe1ff009a}},	//   hean, sler, _insä, _swój_,
   {{0x7c298214,0xbf9b0073,0x31710ad2,0xbc6880f7}},	//   pler, riên, _mezz_, _يمكن_,
   {{0x44200ad3,0x6e250ad4,0x60dc8106,0x34bd8ad5}},	//   xoi_, _akhb, ärma, ्मीद,
   {{0x7bcb8ad6,0x63ad0ad7,0x63bb8ad8,0x6d478019}},	//   _ingu, dean, mdun, _újab,
   {{0x63bb8ad9,0xf1d0801c,0x40958ada,0x65750168}},	//   ldun, _hạnh_, _зрит, gazh,
   {{0xdca30adb,0xfbdf0104,0x44200adc,0x32058add}},	//   лари, _viên_, toi_, mily_,
   {{0x63bb8ade,0xc4d28158,0x7bdd0087,0xca4880ff}},	//   ndun, נגן_, _cosu, _rời_,
   {{0x69dc003b,0x629b8a7f,0xfbdf0028,0x44200adf}},	// [4a0] _pore, ntuo, _tiên_, roi_,
   {{0xf1d08028,0x81e180ab,0x44200ae0,0x171b0039}},	//   _lạnh_, নোর_, soi_, _מופע,
   {{0x69dc0ae1,0x63ad0ae2,0x4420002e,0xdcfe08c5}},	//   _vore, bean, poi_, _tapı,
   {{0x63ad0ae3,0xca4880ff,0x76488122,0x629b8084}},	//   cean, _vời_, _sidy, ktuo,
   {{0x69dc0ae4,0x3f9a809a,0xdce70035,0xfbd3801b}},	//   _tore, ępu_, rają, थानम,
   {{0x7bcb8ae5,0xb90600c8,0x7e628ae6,0x629b8122}},	//   _angu, _বই_, rpop, dtuo,
   {{0x3f6a8ae7,0x987e801b,0x7bdd0ae8,0x7bcb808e}},	//   _ниво_, _péče_, _yosu, _bngu,
   {{0xa2c403b7,0xf1d0801c,0x76488ae9,0x63bb8420}},	//   रिप्, _cạnh_, _widy, gdun,
   {{0xa3e805e8,0x63b98aea,0x7c2084dc,0x3205816b}},	//   _भवन_, _dawn, romr, fily_,
   {{0x7bcb8aeb,0x7c208082,0xa2b18aec,0x2006811b}},	//   _engu, somr, _अनर्, lioi_,
   {{0x6815809a,0x2bb88aed,0xdb1d0106,0x63b98aee}},	//   ląda, _आसपा, _inså, _fawn,
   {{0xc02e8104,0x63a28aef,0x9cd78039,0x20d58196}},	//   _điều_, _ubon, _רואה_, džią_,
   {{0x91e68af0,0x44268af1,0x2d8507a3,0x09e68af2}},	//   _поде, _iko_, óleo_, _подн,
   {{0xa2c40af3,0x92f283bf,0x69ca8af4,0x7bdd0af5}},	//   रिन्, ığım, _unfe, _sosu,
   {{0x63ad0af6,0xe57180be,0xa25b0187,0xb4cb0af7}},	//   tean, יַן_, _crôn, लमे_,
   {{0x657500f1,0x6836002a,0xdb008366,0x44268af8}},	//   sazh, táde, remæ, _jko_,
   {{0x63ad0af9,0x62490a2f,0x75eb007e,0xa7fd02d0}},	// [4b0] rean, _džon, _yüzl, ksız,
   {{0x63ad0afa,0x99990084,0xafdb0366,0x22b202d6}},	//   sean, _rusų_, smød, _dņk_,
   {{0x63ad0afb,0x78ba01ac,0xa7758afc,0xddc982d0}},	//   pean, _štvr, влеч, _ateş,
   {{0x66070586,0x44268afd,0xe50001a2,0xdb1d0106}},	//   lijk, _nko_, ोपरि_, _anså,
   {{0x7c2d0afe,0x44390aff,0x23690087,0x212b80ff}},	//   mlar, _ihs_, mbaj_, ́ch_,
   {{0x44268b00,0x6da58b01,0xada58b02,0x7c2d0b03}},	//   _ako_, тика, такл, llar,
   {{0x1fa786b5,0x34bd8b04,0x270d009a,0x32058b05}},	//   _праг, ्मेद, सपुर_, vily_,
   {{0x7c2d0b06,0xdb008009,0x629b8b07,0xd6d880ab}},	//   nlar, kemä, ttuo, _দেওয,
   {{0x66070a0f,0x63bb8b08,0x44268b09,0x7c2d011b}},	//   kijk, rdun, _dko_, ilar,
   {{0x3d1a0063,0x7c2d080a,0x44268b0a,0x7d798077}},	//   _मुझे_, hlar, _eko_, _آمار_,
   {{0x7c2d0b0b,0x629b8b0c,0x23e780e8,0xc95204de}},	//   klar, stuo, _підв, ימי_,
   {{0x7bcb8b0d,0x6e238b0e,0x7c2d0457,0x2d81010c}},	//   _ungu, lonb, jlar, _adhe_,
   {{0x443f8b0f,0x7c2d0b10,0x442d8b11,0x26c4001b}},	//   mmu_, dlar, mle_, ímo_,
   {{0x644b8b12,0xb5fb016a,0x2fdf8118,0x3ea90b13}},	//   _higi, spán, _loug_, _dpat_,
   {{0x442d8b14,0x644b8b15,0x7c2d0b16,0x44390b17}},	//   ole_, _kigi, flar, _bhs_,
   {{0x2d810b18,0x442d8b19,0x7c2d0b1a,0x443f8b1b}},	//   _edhe_, nle_, glar, nmu_,
   {{0x442d8219,0x443f8b1c,0xdb0f00f7,0x6e238b1d}},	// [4c0] ile_, imu_, _pacá, konb,
   {{0x644b8b1e,0xf1aa0077,0x442d8b1f,0x443f8b20}},	//   _ligi, باره_, hle_, hmu_,
   {{0x7c2d0b21,0x443f8886,0x27e00b22,0x442d8b23}},	//   blar, kmu_, _koin_, kle_,
   {{0x443f8b24,0x27e00b25,0x4f0a8b26,0x442d8b27}},	//   jmu_, _join_, мнен_, jle_,
   {{0x442d8b28,0x443f8b29,0x6e238b2a,0x96968098}},	//   dle_, dmu_, fonb, треш,
   {{0x442d8b2b,0x442680b2,0x7c240b2c,0x443f8b2d}},	//   ele_, _sko_, loir, emu_,
   {{0x69ce0b2e,0x644b80b4,0x443902f7,0xeb9f00e8}},	//   _inbe, _bigi, _yhs_, _kjøp_,
   {{0x68e30b2f,0x27e00364,0xeb978b30,0x644b8b31}},	//   ände, _noin_, вић_, _cigi,
   {{0x644b8b32,0xea00801c,0x2d968b33,0x78ad8140}},	//   _digi, _nhảy_, _арес, _ćava,
   {{0x442d8b34,0x7c2d017b,0x644b8b35,0xdb0401df}},	//   ale_, zlar, _eigi, ndiñ,
   {{0x442d8b36,0x44268b37,0x7c2d0b38,0xf9930039}},	//   ble_, _tko_, ylar, ברת_,
   {{0x44268578,0x442d8b39,0x644b8b3a,0x660700f3}},	//   _uko_, cle_, _gigi, wijk,
   {{0xa3cc0b3b,0x7c24062f,0x69ce0b3c,0x4ab6800c}},	//   लाई_, doir, _onbe, _अनिव,
   {{0x44248b3d,0x82778158,0x644b8b3e,0x44390b3f}},	//   lom_, _יעדע_, _zigi, _shs_,
   {{0x7c2d084a,0x66070a0f,0x644b8314,0x2bc4097d}},	//   tlar, rijk, _yigi, _लोहा,
   {{0x69ce0b40,0xe7870b41,0xe41400e8,0xfbdf00ff}},	//   _anbe, _руко, адсь, _tiêm_,
   {{0x7c2d0b42,0x6b828010,0x3b540087,0x64408198}},	// [4d0] rlar, _mdog, ркур, immi,
   {{0x44248b43,0x2fcd8b44,0x7c2d0b45,0x442d8b46}},	//   hom_, _sneg_, slar, zle_,
   {{0x442d8b47,0x7c2d03bf,0x21a4035f,0x6836027f}},	//   yle_, plar, риєм, láda,
   {{0x7c2d0086,0x44248b48,0xb8db0b49,0x6b828b4a}},	//   qlar, jom_, _अन_, _ndog,
   {{0x442d83a6,0x6e238b4b,0x628b0b4c,0xdd0180d2}},	//   vle_, tonb, ágod, _čuđe,
   {{0x68388b4d,0x6b828b4e,0x68e88106,0x69d80019}},	//   víde, _adog, kydd, övet,
   {{0x442d8b4f,0x443f8b50,0x18b80009,0x644b8b51}},	//   tle_, tmu_, _игры_, _pigi,
   {{0x4424803a,0x442d8b52,0x5f458b53,0x62898b54}},	//   gom_, ule_, _منزل, treo,
   {{0x442d8b55,0x63bd0b56,0x644b8b57,0x11d980f7}},	//   rle_, _masn, _vigi, فوظة_,
   {{0x442d8b58,0x443f8b59,0x62898b5a,0xe0d98b5b}},	//   sle_, smu_, rreo, ево_,
   {{0x442d8b5c,0x77940077,0x27e00072,0x443f859e}},	//   ple_, لیغا, _poin_, pmu_,
   {{0x44248b5d,0xf649010f,0x69da8282,0x672d0b5e}},	//   com_, _זצ_, ajte, _byaj,
   {{0xa9a58b5f,0x7c2400e7,0x27e00198,0x7e7d0b60}},	//   _билд, voir, _voin_, gssp,
   {{0x68e88114,0x7bcf0b61,0x645c841c,0xdb040b62}},	//   bydd, _ancu, _éric, leiç,
   {{0x7c2402be,0x0c7901bb,0x7ae98b63,0xdb008b64}},	//   toir, ксты_, lyet, remå,
   {{0x63bd0b65,0x6d5c0b66,0x62490b67,0xf09281c6}},	//   _casn, scra, _džom, _הנה_,
   {{0x7ae98b68,0x43750b69,0xdb1989c4,0x7c240b6a}},	// [4e0] nyet, руст, _bawé, roir,
   {{0x7bcf0b6b,0x3c3a8168,0x764b0036,0x7c240b6c}},	//   _encu, mëve_, _égyp, soir,
   {{0x98a68b6d,0x2fd70077,0xdb040b6e,0x3c3a80f1}},	//   čiće_, _شوید_, rdiñ, lëve_,
   {{0x7880003e,0x27e08125,0x61e08b6f,0x63bd0b70}},	//   _návš, ðin_, _पक्ष, _gasn,
   {{0x4a750b71,0x44248b72,0x3c3a80f1,0x7e2a8b73}},	//   _выст, vom_, nëve_, ніка_,
   {{0x63a40b74,0x69ce02af,0xa3cc0b75,0x4424833e}},	//   lfin, _unbe, लाक_, wom_,
   {{0xa1160b76,0x98be83bf,0xdb040187,0xa3cf8a27}},	//   _صورت, yatı_, feiç, शां_,
   {{0xd90d0077,0x6440826c,0x20048b77,0x3c3a80f1}},	//   _تیم_, ummi, _ummi_, këve_,
   {{0x68e88355,0x81bc8029,0x3c3a8168,0x64408b78}},	//   wydd, klēt, jëve_, rmmi,
   {{0x49748b79,0x683881d0,0x3c3a8168,0x24588b7a}},	//   шлос, bídc, dëve_, _tém_,
   {{0x7e640b7b,0x44248b7c,0xea008028,0x48150b7d}},	//   _atip, pom_, _chạy_, имос,
   {{0x44248b7e,0x68e88b7f,0x59d2801b,0x63a400fe}},	//   qom_, rydd, ताहर, jfin,
   {{0x6b7b810f,0x63bd011f,0x5eb880ab,0x62490b80}},	//   _טראנ, _rasn, _আপডে, _džoj,
   {{0xdb070019,0x63bd00eb,0x7e7d0b81,0x6836016b}},	//   ámít, _sasn, rssp, ráda,
   {{0x63bd0b82,0x81da0264,0x683604e8,0x40350b83}},	//   _pasn, ়সা_, mádn, _кекс,
   {{0x59d28b84,0xa3cc0b85,0x75eb0214,0x683603b0}},	//   तावर, लाग_, _müzi, ládn,
   {{0x2ba68b86,0x200b0b87,0x49750b88,0xdb0600e1}},	// [4f0] क्या, mici_, илас, _taký,
   {{0xdd9103f8,0xddc98b89,0x63a40b8a,0xd91b0198}},	//   _بود_, _svež, afin, нье_,
   {{0x7afb80e5,0xfaf98084,0x155a01c6,0x273b046d}},	//   zzut, lbūt_, _בכתב, _fàní_,
   {{0x200b02a5,0xa29505e9,0x69d80b8b,0x26c90503}},	//   nici_, _камі, över, _krao_,
   {{0x442b026c,0xf8c9826b,0x7c3a0036,0xb5fd8084}},	//   _ikc_, _asẹ́_, ître, _atša,
   {{0x7bc78029,0x644f05a4,0x48770b8c,0x7ae98b8d}},	//   ējum, _hici, _مدرس, vyet,
   {{0x200b0b8e,0xdb1d006a,0x644f0b8f,0x2c5581a9}},	//   kici_, _ansø, _kici, _kādi_,
   {{0x7afb8b90,0x26c9025b,0x73e58ada,0x99908503}},	//   tzut, _orao_, роиз, _čaši_,
   {{0x200b0b91,0x645702f7,0x22158b92,0x5fab80d4}},	//   dici_, _luxi, ифор, _टॉयल,
   {{0x644f0b93,0xe1258615,0x7ae98b94,0x9f5900e5}},	//   _lici, импи, ryet, misù_,
   {{0x7ae98b95,0x200b0b96,0x387e8077,0x63a40b97}},	//   syet, fici_, gstr_, yfin,
   {{0x644f0b98,0x3c3a80f1,0x76438b99,0x200b0b9a}},	//   _nici, tëve_, lmny, gici_,
   {{0xaa678b9b,0x32638019,0xdb0603ec,0x32678237}},	//   _стек, _انتہ, _lakò, _стев,
   {{0x3c3a820f,0xd9458b9c,0x644f0029,0x442b01e0}},	//   rëve_, _кели, _aici, _akc_,
   {{0x442b0267,0x443d8069,0x7643808e,0x61e38b9d}},	//   _bkc_, _khw_, imny, _ionl,
   {{0x3ead803a,0x200b0b9e,0x4aa98b9f,0x61e38019}},	//   _opet_, cici_, _कहाव, _honl,
   {{0x63a40ba0,0x26c904c3,0x02060ba1,0x395600a9}},	// [500] rfin, _grao_, азан, ањет,
   {{0x69c18ba2,0x61e3810c,0x64570ba3,0x667b00be}},	//   ndle, _jonl, _fuxi, _שטיק,
   {{0x61e38ba4,0x03a60ba5,0x657c0ba6,0x60268ba7}},	//   _monl, _кино, marh, аджа,
   {{0xb8ce023c,0xe6668b02,0x443d831d,0xb8fe0054}},	//   _कह_, атко, _nhw_, _तप_,
   {{0x2fc007e2,0xddd6026f,0xfe468ba8,0xb8660061}},	//   _maig_, _zvyš, андо, _چارو,
   {{0x44320ba9,0x2d980baa,0x200b001b,0x2fc00bab}},	//   lly_, ngre_, zici_, _laig_,
   {{0x443d80dd,0xeb0e81a2,0xa2c40035,0x200b01cc}},	//   _bhw_, ाप्त_, रिव्, yici_,
   {{0x8aa68bac,0x25a9812b,0xe8d70039,0x317801ec}},	//   арод, đala_, _דולר_, _herz_,
   {{0x44320bad,0x78af011f,0x9f490315,0x61e380c3}},	//   ily_, čivš, _ilaç_, _bonl,
   {{0x2c0b89d7,0x44320bae,0x61e38baf,0xc05a81e2}},	//   _یعنی_, hly_, _conl, кім_,
   {{0x245c026f,0x61e38bb0,0x3a370039,0x65770168}},	//   _ním_, _donl, שרים_, _rexh,
   {{0x2fc001c0,0x2a7f8bb1,0xdb1d0176,0x683604e8}},	//   _caig_, bsub_, _fasè, sádn,
   {{0x200b0bb2,0x67010bb3,0x2fc00bb4,0x645701df}},	//   rici_, _लेखक_, _daig_, _suxi,
   {{0x644f0bb5,0xfaf98bb6,0x2b928065,0x442b0bb7}},	//   _sici, rbūt_, _ایکس, _skc_,
   {{0x6ab6890a,0x52b68bb8,0x644f0bb9,0xe7870bba}},	//   _अनुर, _अनुस, _pici, _купо,
   {{0x628d0bbb,0x3b55096b,0x26c9001c,0xd0f781c6}},	//   trao, скар, _trao_, _כמות_,
   {{0xa3a88bbc,0x657c0bbd,0xd2510bbe,0xa2c405ab}},	// [510] ख्य_, barh, سنا_, रिष्,
   {{0xf9930bbe,0x2ba6800c,0x6838801b,0x644f0114}},	//   تبر_, क्ता, vída, _wici,
   {{0x3ead8353,0x44320bbf,0x644f0bc0,0x2fc0022c}},	//   _spet_, bly_, _tici, _yaig_,
   {{0x442b0bc1,0xa2c40bc2,0x1ab686a7,0x628d0140}},	//   _ukc_, रिश्, _अनूठ, prao,
   {{0x44290bc3,0x683d02be,0x6fd8016f,0x7a3d80e7}},	//   moa_, céde, यातू, lète,
   {{0x44290bc4,0x7aed05ee,0x764389da,0xc5f400fc}},	//   loa_, myat, umny, _tuɓe_,
   {{0x22590bc5,0xfc3f0028,0xa3cc016f,0x764382f7}},	//   _husk_, _khí_, लाच_, rmny,
   {{0x44290bc6,0x5f948bc7,0x24898bc8,0x2a7f8bc9}},	//   noa_, _мист, čam_, tsub_,
   {{0x8d878bca,0xfc3f00f7,0x62808bcb,0x645c8019}},	//   _نشان, _mhí_, gsmo, _érin,
   {{0x44290bcc,0x20190bcd,0x20090bce,0x673b8bcf}},	//   hoa_, érin_, _amai_, _izuj,
   {{0x44290bd0,0x7aed008e,0x69c18bd1,0x62808a53}},	//   koa_, hyat, rdle, asmo,
   {{0xc5e9007c,0xfc3f00ff,0x44290bd2,0xfbdf0129}},	//   _אד_, _nhí_, joa_, _kiêu_,
   {{0x2fc0009f,0xdb098bd3,0x44290bd4,0xf3ff00ab}},	//   _vaig_, rdeó, doa_, ্কার_,
   {{0x61fa8bd5,0xfc3f0693,0x7aed0bd6,0x69dc8bd7}},	//   chtl, _ahí_, dyat, öret,
   {{0x40958307,0xfc3f0307,0x2fc0022c,0x44290bd8}},	//   _العر, _bhí_, _taig_, foa_,
   {{0x4429011e,0x3ce500f2,0xfc3f0028,0x7ff6026a}},	//   goa_, älva_, _chí_, _دستا,
   {{0x44320051,0x9ad381bc,0x68e305ec,0x77640609}},	// [520] rly_, _aịzi, ändn, _ifix,
   {{0xc3328051,0x245c000d,0x44320bd9,0x51560bda}},	//   לון_, _tím_, sly_, стау,
   {{0x44320bdb,0xef6582bb,0x2c5580eb,0x44290bdc}},	//   ply_, ğını_, _kādu_, boa_,
   {{0xef658059,0xea00801c,0x7c298123,0x22590bdd}},	//   şını_, _thầy_, joer, _fusk_,
   {{0x317802a6,0x673b8035,0x7aed018f,0x661a808e}},	//   _terz_, _czuj, cyat, _pjtk,
   {{0x99d60277,0x21f600f7,0x63b60bde,0x62960bdf}},	//   _اتحا, _اكسس, leyn, muyo,
   {{0xec098028,0x320c82d6,0x62960be0,0x44c780ff}},	//   yết_, vidy_, luyo, _cđ_,
   {{0x8fa38be1,0xc7a38be2,0x62808be3,0x62868be4}},	//   _насе, _ниск, tsmo, škom,
   {{0x6aa40be5,0x62960214,0x200900ee,0x6d43016b}},	//   ntif, nuyo, _rmai_, _únav,
   {{0x660e0be6,0x44290102,0x60ca82f7,0x200900b9}},	//   jibk, zoa_, _prfm, _smai_,
   {{0x7c298be7,0x201903a7,0xe1ff0118,0x44290122}},	//   boer, ério_, _otón_, yoa_,
   {{0x7aed0be8,0x6aa40590,0xf5378039,0x313704de}},	//   yyat, ktif, _פנאי_, מנים_,
   {{0x7336803d,0x657a80d7,0xf1c800d4,0x63b60be9}},	//   _ارائ, _keth, रयान, deyn,
   {{0x329b8bea,0xe1ff0118,0x77640118,0xe7cf8beb}},	//   _עבוד, _atón_, _efix, _सोनप,
   {{0x44290bec,0xf1a98077,0xfc3f0028,0x657a8bed}},	//   toa_, _خانه_, _phí_, _meth,
   {{0x645a8bee,0x657a8bef,0x317e81ec,0x200900b9}},	//   _muti, _leth, latz_, _umai_,
   {{0x44290bf0,0x645a8bf1,0x62960bf2,0x8af78085}},	// [530] roa_, _luti, guyo, _çəti,
   {{0x645a82be,0x44290bf3,0x7aed0bf4,0xa3a883eb}},	//   _outi, soa_, ryat, ख्त_,
   {{0xe8e00142,0x2bc40bf5,0xfbdf0129,0x3178809a}},	//   ười_, _लोका, _siêu_, órzy_,
   {{0x2d9e8bf6,0x317e8bf7,0x657a8286,0x473583a7}},	//   _acte_, hatz_, _aeth, онес,
   {{0x539a0051,0x657a8bf8,0x7c29838e,0x6aa40bf9}},	//   _דירו, _beth, voer, ctif,
   {{0x645a8bfa,0x25a9812b,0x63ab80b9,0xdc3c81a9}},	//   _buti, đalo_, _sbgn, kšēj,
   {{0x69d50bfb,0x645a802e,0x8ccc0b9f,0x7c29800b}},	//   _inze, _cuti, हियो, toer,
   {{0xfbdf0028,0x69c50bfc,0x7bc28036,0x657a8bfd}},	//   _tiêu_, ldhe, _caou, _eeth,
   {{0x7bc28bfe,0x6fdd016f,0x657a8bff,0x0ae68009}},	//   _daou, यानं, _feth, ждый_,
   {{0x69c50c00,0x200f8c01,0x88858758,0x657a8c02}},	//   ndhe, ligi_, олож, _geth,
   {{0xf9920bea,0x69c50046,0x645a8c03,0x7a300009}},	//   ורי_, idhe, _guti, mätt,
   {{0x7a300c04,0x200f8c05,0x777b80e7,0x26cd8c06}},	//   lätt, nigi_, _jeux, _kreo_,
   {{0xe9d98c07,0x3f890114,0x9f448168,0x69d50c08}},	//   _вкл_, _ddau_, _romë_, _onze,
   {{0x20190c09,0x317e83e4,0xdce8801b,0x63b60079}},	//   ansi_, catz_, _nedě, weyn,
   {{0x2c5580eb,0x7bc28c0a,0x69c50c0b,0x68e30192}},	//   _tādu_, _yaou, ddhe, ändl,
   {{0x69c38c0c,0x69d50352,0x7bc40358,0x62960c0d}},	//   _hane, _anze, udiu, tuyo,
   {{0xb4b683bb,0xe29a0c0e,0x69c38c0f,0x2c5580eb}},	// [540] _छन्_, раз_, _kane, _kāds_,
   {{0x69c38c10,0xea008104,0x69c50c11,0x62960c12}},	//   _jane, _thấy_, gdhe, ruyo,
   {{0x02b68aed,0xd91009a7,0x657a8c13,0x69c385d8}},	//   _अन्न, ریر_, _reth, _mane,
   {{0x69c3811e,0xd7dd016f,0x657a8c14,0x26cd8118}},	//   _lane, यायच, _seth, _breo_,
   {{0x26cd8c15,0x645a8c16,0x777b80e7,0x7bc28c17}},	//   _creo_, _suti, _deux, _raou,
   {{0x62860c18,0x7c36008b,0x63a98c19,0x7bc28c1a}},	//   _ivko, llyr, efen, _saou,
   {{0x63a98c1b,0x5fca0c1c,0xb5fb0c1d,0xf77f02d0}},	//   ffen, ियाल, mpát, yaç_,
   {{0x7a34809f,0x657a8c1e,0x69c38c1f,0x26cd802a}},	//   màti, _weth, _aane, _freo_,
   {{0x62840c20,0x69c38c21,0x2fc6849c,0x38698c22}},	//   nsio, _bane, mdog_, _čara_,
   {{0x094a8abe,0x645a8c23,0x914a8c24,0x3ebb84de}},	//   ични_, _tuti, ична_, _דצמב,
   {{0x69c38c25,0x645a8364,0x61e302af,0x4254803d}},	//   _dane, _uuti, önli, _کنتر,
   {{0x62840c26,0x2fc68c27,0x317e81ec,0x2ba68c28}},	//   ksio, ndog_, satz_, क्शा,
   {{0x3ea68c29,0x0aba8c2a,0x7a2f8aa2,0xead48791}},	//   ntot_, _خطاب_, tøtt, _холь,
   {{0x81f88c2b,0x62840c2c,0x2ba68c2d,0x200f8c2e}},	//   _دفتر_, dsio, क्रा, zigi_,
   {{0xd37b0c2f,0x64428c30,0x271c8028,0x09ac80ab}},	//   ича_, _khoi, ỉnh_, _কোথা,
   {{0x248d0c31,0x683f00eb,0x6b80804f,0xdb198144}},	//   čem_, _lūdz, namg, _hawá,
   {{0x2bbd8c32,0x34b78c33,0x27e90c34,0x4abc80d4}},	// [550] ्यता, _आन्द, _ioan_, ्टिव,
   {{0x69c3862f,0x78a50125,0x27e900ff,0xdb00841c}},	//   _xane, tthv, _hoan_, lemó,
   {{0x69c50c35,0x26cd82a5,0x7fd58084,0x7e698c36}},	//   rdhe, _sreo_, зілі, _step,
   {{0x764183ed,0x69c503ed,0x27e90c37,0xdb0b8176}},	//   _shly, sdhe, _joan_, _magò,
   {{0x2bc40076,0x200f8c38,0x7c2d0c39,0x7bda0039}},	//   _लोटा, rigi_, moar, _הקרו,
   {{0x7c2d0c3a,0x26cd8087,0xdd918c3b,0x1dcb0512}},	//   loar, _vreo_, روع_, ायित,
   {{0x7a300c3c,0x6442832f,0x69c38c3d,0x6ab90085}},	//   rätt, _bhoi, _rane, şafı,
   {{0x7a300c3c,0x69c3803d,0x57b48c3e,0x64428c3f}},	//   sätt, _sane, _обст, _choi,
   {{0xd5bb8c40,0x64428c41,0x63a98c42,0x3ebf8573}},	//   _все_, _dhoi, rfen, _usut_,
   {{0xdb0d0c43,0x63a98c44,0x7c2d0c45,0x1306862c}},	//   ndañ, sfen, hoar, яный_,
   {{0xf992093f,0x69c38074,0x6442861f,0x7c2d011e}},	//   ערט_, _vane, _fhoi, koar,
   {{0xb4d78c46,0x69c38c47,0xa3bb8c48,0x64428c49}},	//   ामी_, _wane, _خاطر_, _ghoi,
   {{0x7c2d0c4a,0x27e90c4b,0x64498c4c,0x24980c4d}},	//   doar, _doan_, mmei, wurm_,
   {{0x64498c4e,0x2c5580eb,0x57470a41,0x63af0163}},	//   lmei, _tāds_, язям_, _abcn,
   {{0x2eb88424,0x7981838a,0x33f60c4f,0x8cce8035}},	//   _इन्त, malw, пчас, थियो,
   {{0x62840665,0x644981e4,0x7c2d0c50,0x1e860c51}},	//   tsio, nmei, goar, _елим,
   {{0x2bad835a,0x9f448c52,0x62840110,0x26c00c53}},	// [560] झ्या, _tomé_, usio, _usio_,
   {{0x3f820500,0x79818c54,0x2bb8825e,0x200d8187}},	//   laku_, nalw, _आस्थ, _amei_,
   {{0x62840c55,0x23bd83dd,0xfbbd824c,0x201c83a7}},	//   ssio, ्याद, ्याम, évio_,
   {{0x3f820c56,0x61fe0c57,0x657e01e0,0x7a3001ec}},	//   naku_, shpl, _heph, täts,
   {{0x5fdd016f,0x78828019,0xb5fb0c58,0x442d8c59}},	//   यातल, _kívá, mpár, doe_,
   {{0x645e0c5a,0x7bc60c5b,0x64428c41,0xe5348c5c}},	//   _kupi, _haku, _shoi, мель,
   {{0x7bc60c5d,0x64428c5e,0x3ea68c5f,0xa2c40aed}},	//   _kaku, _phoi, stot_, रिक्,
   {{0x293700be,0x7bc60558,0x657e0c60,0xdb00802a}},	//   _זאלן_, _jaku, _leph, xemó,
   {{0x7bc60c61,0x3f820c62,0xdb0d008b,0x64a080c3}},	//   _maku, daku_, ndað, dšiš,
   {{0x7bc60590,0x657e0c63,0xeaaf880b,0x39588aa2}},	//   _laku, _neph, اعي_, ørs_,
   {{0x64428c64,0x3f820c65,0x6d5a8bb1,0x5f950c66}},	//   _thoi, faku_, _igta, минт,
   {{0x1ae68c67,0x3f820c68,0x04db8039,0x7c2d0102}},	//   _ноем, gaku_, _לקבל, xoar,
   {{0xa3c00c69,0x7c2d0087,0x79818c6a,0x63a28c6b}},	//   ंजन_, voar, balw, _icon,
   {{0x91e38c6c,0x09e38c6d,0x611484bd,0x7bc602d5}},	//   _поче, _почн, _одлу, _aaku,
   {{0x7c2d0c6e,0x7bc60c6f,0x69c8831d,0x69a18beb}},	//   toar, _baku, mdde, _खाती,
   {{0x645e0c70,0x7bc60c71,0x2c0d016f,0x69c88c72}},	//   _dupi, _caku, _सगळं_, ldde,
   {{0x4a550c73,0x7c2d0102,0x7bc60c74,0x32550c75}},	// [570] дкас, roar, _daku, двар,
   {{0x7c2d0c76,0x6838800d,0x69c88c77,0xa2bf8c78}},	//   soar, bídk, ndde, _वनस्,
   {{0x7bc60c79,0x2d830c7a,0x7c2d0c7b,0x61ea8144}},	//   _faku, maje_, poar, _mofl,
   {{0x2d9c04b8,0x27e987ca,0x2d830c7c,0x68360187}},	//   _över_, ðan_, laje_, tádi,
   {{0x6fa50c7d,0x63ad0c7e,0x69d880c9,0x62490c7f}},	//   _कानू, mfan, _onve, _džor,
   {{0x2d830c80,0x7bc60c81,0x63ad0c82,0x68360c83}},	//   naje_, _zaku, lfan, rádi,
   {{0x7bc60c84,0xb4d78054,0x645800e7,0x442d8c85}},	//   _yaku, ामे_, _évit, toe_,
   {{0xeb9980af,0x69d88c86,0x2bda8c87,0x63ad0c88}},	//   ции_, _anve, भाषा, nfan,
   {{0x442d8baf,0x69c70c89,0x64498c8a,0x79818c8b}},	//   roe_, _kaje, rmei, talw,
   {{0x63a28c8c,0x64498c8d,0x78a10106,0x442d852a}},	//   _econ, smei, _älvs, soe_,
   {{0x39458c8e,0x3f820c8f,0x02ba03e8,0x61ea8c06}},	//   ьног, taku_, _उन्न, _dofl,
   {{0x645e0c90,0xe73a0c91,0x657e0c92,0x69c70077}},	//   _rupi, жем_, _seph, _laje,
   {{0x7bd981bc,0x63bb8c93,0x63ad0c94,0x7c2d8c95}},	//   _inwu, meun, dfan, čard,
   {{0x2bbd87e6,0x69c70c96,0x2d830c97,0x3f820c98}},	//   ्यवा, _naje, gaje_, saku_,
   {{0x64a30c99,0x7bc60c9a,0xed570c9b,0x6286816b}},	//   кара, _paku, дор_, ákov,
   {{0x7bc98c9c,0xaac900d4,0x04430c9d,0x672401c0}},	//   ndeu, रिंक, весн, _txij,
   {{0x69c70c9e,0x6aa98c9f,0xc1ea0ca0,0x7bc60ca1}},	// [580] _baje, ntef, одаж_, _vaku,
   {{0x7c290025,0x7bc60ca2,0x69c70ca3,0x26d200b4}},	//   čera, _waku, _caje, _iryo_,
   {{0x106a0ca4,0xb4d7852a,0x7640001b,0x7bd98133}},	//   цией_, ामो_, ůmys, _onwu,
   {{0x63bb8ca5,0x680b066f,0x00000000,0x00000000}},	//   jeun, wędz, --, --,
   {{0xa3e1873c,0x69c88ca6,0x6d418748,0x6b840ca7}},	//   दान_, ydde, _azla, maig,
   {{0x6b840c5e,0x69c70ca8,0x7bd981bc,0x63a28ca9}},	//   laig, _gaje, _anwu, _scon,
   {{0xdb0b8125,0xd839012b,0x7e7b8caa,0x7bc98cab}},	//   _sagð, luče_, _ewup, fdeu,
   {{0x69c70025,0x6b840cac,0x2d830cad,0xd9430cae}},	//   _zaje, naig, zaje_, _реси,
   {{0x7e7b81bc,0x27e6810c,0x83fc8bcf,0x752d861c}},	//   _gwup, mjon_, _nuđe, ğaza,
   {{0x27e68caf,0x6b840cb0,0x765f0359,0x24f68cb1}},	//   ljon_, haig, _ruqy, _очер,
   {{0xdb1d026f,0x2d830cb2,0x69c88114,0x4422008e}},	//   _masá, vaje_, rdde, _ojk_,
   {{0x7e608cb3,0x68e30cb4,0xb8e6809a,0x63bb8118}},	//   _kump, ändi, _उन_, ceun,
   {{0x6b840cb5,0x19948cb6,0xd8390968,0x7c228cb7}},	//   daig, _заля, juče_, _ijor,
   {{0xc1c803bb,0x7c2d807d,0x69d88cb8,0x7e608cb9}},	//   रयोग, čare, _unve, _mump,
   {{0x2d830cba,0x7e608cbb,0x69c70cbc,0x63ad007b}},	//   raje_, _lump, _raje, tfan,
   {{0x2d830cbd,0xeac88028,0x25a98289,0x69c70cbe}},	//   saje_, _kỹ_, đali_, _saje,
   {{0x63ad0cbf,0x7e608cc0,0x79a70cc1,0x4caa80ab}},	// [590] rfan, _nump, дрее, কিটু,
   {{0xeac88028,0x2fc90cc2,0x7c228cc3,0x63ad0cc4}},	//   _mỹ_, _haag_, _ljor, sfan,
   {{0x6b840110,0x61e7816d,0x69c70cc5,0x63ad0cc6}},	//   baig, öjli, _vaje, pfan,
   {{0x69c703c3,0x66150cc7,0xd839026c,0x6b840cc8}},	//   _waje, lizk, buče_, caig,
   {{0x7e608cc9,0xb4d78cca,0xdb1d0ccb,0x644d0ccc}},	//   _cump, ाम्_, _ansö, mmai,
   {{0x7c228ccd,0x2fc903b2,0x7a2b02af,0xa5948081}},	//   _ajor, _laag_, hütz, връщ,
   {{0x271b0cce,0x63bb85f8,0x97a7846e,0xdce380eb}},	//   नपुर_, teun, _орал, manī,
   {{0x6aa981a3,0xee3f00e1,0x2d810ccf,0x75fd82d6}},	//   ttef, dtým_, _lehe_, _dèza,
   {{0xc6a48cd0,0x7bc98cd1,0x4ea48b02,0x7c228cd2}},	//   _архи, rdeu, _арха, _djor,
   {{0xddc4003b,0xb5fd8cd3,0xdb040cd4,0x63bb8cd5}},	//   _otiš, _buše, nfiá, seun,
   {{0x83fc803b,0x07a60112,0xf1b200be,0x6d418cd6}},	//   _suđe, нанн, נסט_, _uzla,
   {{0x7c228cd7,0x2fc90cd8,0xb5fd8cd9,0x60da0061}},	//   _gjor, _caag_, _duše, _átme,
   {{0x79850748,0x2fc90cda,0x2d810cdb,0xdce18084}},	//   kahw, _daag_, _behe_, _pelė,
   {{0x6a178065,0xd8390024,0x3ea2816d,0x27ff8114}},	//   _تبصر, vuče_, _åkte_, _llun_,
   {{0x62868cdc,0xb5fd811f,0x6b840cdd,0x7c29042b}},	//   škot, _guše, taig, čern,
   {{0x27ed8cde,0x83fc80d2,0x8b950cdf,0x7c3b820d}},	//   _noen_, _tuđe, круч, nlur,
   {{0xdb1d0ce0,0x64598ce1,0x22580084,0x49960162}},	// [5a0] _pasá, _miwi, _pirk_, ешет,
   {{0xe7ac01c4,0x6b84008c,0x644d0ce2,0x27ff8ce3}},	//   ट्रप, saig, amai, _alun_,
   {{0x644d0ce4,0x7d7b0039,0xdb1d0019,0x6d5e033e}},	//   bmai, _מניו, _vasá, _igpa,
   {{0x4ea68ce5,0x644d09c4,0xc6a68ce6,0x64598ce7}},	//   ерка, cmai, ерки, _niwi,
   {{0x44200ce8,0x27ed81d8,0x44320ce9,0x61f30aa2}},	//   mni_, _doen_, moy_, ådlø,
   {{0x27e68cde,0x443202b8,0xf2df00ff,0xf48700d7}},	//   sjon_, loy_, _ngây_, _تایی,
   {{0x44200cea,0x69dc0ceb,0xd9430cec,0x61430110}},	//   oni_, _inre, _бери, _бера,
   {{0x44200ced,0x2bba8013,0x44320cee,0x7e608cef}},	//   nni_, ساعة_, noy_, _tump,
   {{0x7ae404c3,0xe7e40cf0,0x64598cf1,0x61ee0cf2}},	//   nxit, गाना_, _diwi, _kobl,
   {{0xb5fd8503,0xfce68cf3,0x44320cf4,0x44200cf5}},	//   _puše, _позо, hoy_, hni_,
   {{0x44200cf6,0x7a2b02af,0x4432009c,0x61ee094d}},	//   kni_, tütz, koy_, _mobl,
   {{0x2d8101ec,0x6d5e02c4,0x44320cf7,0x7c3b8cf8}},	//   _sehe_, _agpa, joy_, clur,
   {{0xd6d80cf9,0x2d81026b,0x69dc0cfa,0x44320cfb}},	//   нтр_, _pehe_, _onre, doy_,
   {{0x44200cfc,0x2ee10cfd,0x6b82876d,0x84e4864a}},	//   eni_, _पपीत, _heog, _कपाट_,
   {{0x44200125,0xa4d80cfe,0x765a8cff,0x66150d00}},	//   fni_, ндру_, _mity, rizk,
   {{0x69dc0d01,0x44200d02,0x493b8039,0x44320d03}},	//   _anre, gni_, _מגוו, goy_,
   {{0x61ee0b7f,0x5a3500b3,0x23690d04,0x27ed8d05}},	// [5b0] _bobl, внат, rcaj_, _roen_,
   {{0x44200d06,0x27ed8d07,0x6b828d08,0x61ee0d09}},	//   ani_, _soen_, _leog, _cobl,
   {{0x44200d0a,0x44320d0b,0x61ee0d0c,0x69ca81bc}},	//   bni_, boy_, _dobl, _mafe,
   {{0x44200042,0x69dc0557,0x69ca8d0d,0x87e48d0e}},	//   cni_, _enre, _lafe, люче,
   {{0x539a0bea,0x6abc8996,0xf770845b,0xe5a58d0f}},	//   _קישו, ्टोर, صان_, вили,
   {{0x0c740077,0x44d101e2,0xdce88029,0x69ca8d10}},	//   _جدید, _ką_, _nedē, _nafe,
   {{0x6b828d11,0xdb04007b,0x27ed8a0f,0x44d10d12}},	//   _beog, leið, _toen_, _ją_,
   {{0xa1580d13,0xbbbd8d14,0x19580d15,0xc4478019}},	//   _часу_, ्येक, _часы_, ریشن_,
   {{0x24808025,0x7c3a00e7,0x7c3b8106,0x64598c53}},	//   ćima_, îtri, rlur, _viwi,
   {{0x44200d16,0x62898d17,0x64598077,0x33f183a8}},	//   zni_, rseo, _wiwi, _páxs_,
   {{0xd7dd053e,0x7bdd0d18,0x34948791,0x7c3b8d19}},	//   यांच, _onsu, _бахр, plur,
   {{0x5b1587eb,0x6b828d1a,0x2d8785d1,0xdb04008b}},	//   _имет, _geog, lane_, keið,
   {{0x6d450d1b,0x76488009,0x25de0d1c,0x2d878162}},	//   _azha, _yhdy, खाली_, oane_,
   {{0x44200d1d,0xa7fd0201,0x7bcb8d1e,0x69ca8135}},	//   wni_, qqın, _hagu, _gafe,
   {{0x6e3c0713,0x443200ab,0x59a68076,0x7bcb8d1f}},	//   rlrb, toy_, _खातर, _kagu,
   {{0x2d878c89,0x6b8284c3,0x44200d20,0x3e660d21}},	//   hane_, _xeog, uni_, _tôt_,
   {{0x61ee0d22,0x2d878d23,0x6b848074,0xdfd20065}},	// [5c0] _pobl, kane_, _õige, _ميں_,
   {{0x7bcb8d24,0xfe9b04de,0x6d5e0122,0x7ae68106}},	//   _lagu, _קיימ, _ugpa, äkti,
   {{0x2d878d25,0x7e640009,0x4432033e,0x83fc8d26}},	//   dane_, _huip, poy_, _luđa,
   {{0xdb0401fa,0x7bcb8d27,0x59e0000d,0x7e640d28}},	//   beið, _nagu, नाहर, _kuip,
   {{0xa2c1000f,0x779180d5,0x765a8d29,0xe7aa0321}},	//   रौद्, صیلا, _pity, _कानप,
   {{0x63a40d2a,0x2d878d2b,0x61ee00d2,0x68388187}},	//   lgin, gane_, _uobl, vídu,
   {{0x7bcb8d2c,0x6abc82ef,0x69ca8d2d,0xc0e30254}},	//   _bagu, ्ट्र, _rafe, _корк,
   {{0x63a40d2e,0x25ad0d2f,0x83fc8b80,0x69ca8d30}},	//   ngin, đeli_, _buđa, _safe,
   {{0x5a348d31,0xf4130bea,0x67ff00f1,0x7bcb8d32}},	//   лнит, יפה_, _bëjn, _dagu,
   {{0x2d878d33,0x683d0d34,0xbd8a80d7,0x320581c6}},	//   cane_, médi, _آنان_, ghly_,
   {{0x68388187,0xa99b00be,0xbb1b0162,0x61fa8d35}},	//   sídu, וביר, _neîn, rktl,
   {{0x3f848d36,0x7bcb8d37,0x63a401ed,0xc05801e2}},	//   _jemu_, _gagu, jgin, кія_,
   {{0x44d10d38,0x44268d39,0x69ca837a,0x8a0684fa}},	//   _są_, _ijo_, _tafe, _изде,
   {{0x7bc08006,0x27318028,0xb5fd842b,0xdb04008b}},	//   lemu, ỡng_, _kuša, veið,
   {{0x442688cf,0x6d5c81ac,0x20068d3a,0x7bcb8d3b}},	//   _kjo_, _úrad, khoi_, _yagu,
   {{0x2d878d3c,0x7bc08763,0x6aad0d3d,0x2ba689c8}},	//   zane_, nemu, ttaf, क्चा,
   {{0x20190d3e,0x2d878d3f,0x36d50d40,0xab840746}},	// [5d0] misi_, yane_, _сопр, руск,
   {{0x20190d41,0x44d10d42,0x26c9007d,0xdb04007b}},	//   lisi_, _tą_, _isao_, reið,
   {{0x44268d43,0x7bc08d44,0x21640d45,0x99640d46}},	//   _ojo_, kemu, ртуг, ртул,
   {{0x2d878d47,0xf8b3893f,0x20190d48,0x3f8485f5}},	//   wane_, ישע_, nisi_, _cemu_,
   {{0x4b7a0bea,0x539a0051,0x2d878d49,0x6aa084a8}},	//   _ראשו, _אירו, tane_, jumf,
   {{0xd1268d4a,0x44268d4b,0xa2b880bc,0x20190d4c}},	//   _هم_, _ajo_, ्बन्, hisi_,
   {{0x2d878d4d,0x20190d4e,0x645d0d4f,0x2baa06d4}},	//   rane_, kisi_, _kisi, ङ्का,
   {{0x7bc08d50,0x645d0d51,0x2bda816f,0x3f848d52}},	//   gemu, _jisi, भागा, _gemu_,
   {{0x20190d53,0x2d878d54,0x442682d6,0xe3b68d55}},	//   disi_, pane_, _djo_, убы_,
   {{0x44390d56,0xf99180f7,0x44268d57,0x6e350503}},	//   _lks_, حبة_, _ejo_, jozb,
   {{0x7bcb8d58,0x201906c0,0x63a40d59,0x7a3d823e}},	//   _tagu, fisi_, ygin, nèti,
   {{0x645d0d5a,0x2d858d5b,0xc50c83de,0xbb1b0162}},	//   _nisi, _hele_, _קלאָ, _reîn,
   {{0x443f8d5c,0xd24e803d,0xa3e70d5d,0x63a40850}},	//   mlu_, تنی_, पान_, vgin,
   {{0x443f8d5e,0x64a60d5f,0x2d858d60,0xdca60523}},	//   llu_, лага, _jele_, лаги,
   {{0x69c18d61,0x443f8d62,0x2d858d63,0x5e5680be}},	//   mele, olu_, _mele_, טישע_,
   {{0x69c18d64,0x2d858d65,0x66188503,0xeb9f0aa2}},	//   lele, _lele_, zivk, _smør_,
   {{0x645d0d66,0xe2970d67,0x443f8d68,0x9e5a0d69}},	// [5e0] _disi, лат_, ilu_, _проф_,
   {{0x69c18d6a,0x645d0d6b,0x44390d6c,0x3f848d6d}},	//   nele, _eisi, _eks_, _semu_,
   {{0x645d0d6e,0x443f8d6f,0x34aa0d70,0x27e00669}},	//   _fisi, klu_, _явно_, _knin_,
   {{0x69c18d71,0x2bab0d72,0x2d8a02ec,0x645d0d73}},	//   hele, _छाया, labe_, _gisi,
   {{0x69c18d74,0xa3d783b7,0x443f8d75,0x60060d76}},	//   kele, ायन_, dlu_, _góme,
   {{0x2d858c6e,0x69c18d77,0xb5fd812b,0x7c240087}},	//   _cele_, jele, _puša, lnir,
   {{0x3f848d78,0x69c18d79,0x7bc08d7a,0x2d858d7b}},	//   _temu_, dele, temu, _dele_,
   {{0x69ce0d7c,0x683d0d7d,0x2d8a0d7e,0x68e30a33}},	//   _habe, pédi, habe_, ånde,
   {{0x69ce0d7f,0x20048d80,0x6b8601a1,0x69c18d81}},	//   _kabe, _ilmi_, _mekg, fele,
   {{0x69c187b3,0x7bc08d82,0x27e00d83,0x69ce0102}},	//   gele, semu, _anin_, _jabe,
   {{0x69ce0d84,0x443f8d85,0x03148d86,0x7bc080dd}},	//   _mabe, blu_, _तेरह_, pemu,
   {{0x31570451,0x2d858052,0x44268d87,0x7c240024}},	//   טיין_, _zele_, _ujo_, jnir,
   {{0xa3e187e6,0xcaf68154,0x26c682f7,0x645d0d88}},	//   दार_, _حساب, nwoo_, _risi,
   {{0x20190d89,0x2d8a0d8a,0x645d0d8b,0x69ce0d8c}},	//   sisi_, gabe_, _sisi, _nabe,
   {{0x44390d8d,0xab5d84b7,0xe4e40d8e,0x02178039}},	//   _pks_, reże, бітн, _תחום_,
   {{0xfbdf0104,0x69a70006,0x33750d8f,0x6b8600b9}},	//   _thêm_, _चाही, ргар, _cekg,
   {{0x52150d90,0x65950d91,0x3f8b0d92,0x2d8a0d93}},	// [5f0] адат, _капу, macu_, babe_,
   {{0x69ce0510,0x9475026a,0x3b540d94,0x443f8d95}},	//   _cabe, _نگرا, скур, zlu_,
   {{0x69ce0d96,0x2d858205,0x443f8d97,0x44390d98}},	//   _dabe, _rele_, ylu_, _tks_,
   {{0x69c18d99,0x2d858d9a,0x8d74003d,0x3f8b0d9b}},	//   zele, _sele_, _پایا, nacu_,
   {{0x2d858d9c,0x66e58d9d,0xdee58d9e,0x69c18d9f}},	//   _pele_, рола, роли, yele,
   {{0x2bda8da0,0x69c18da1,0x69ce0da2,0x20048085}},	//   _मोबा, xele, _gabe, _elmi_,
   {{0x2d858da3,0x628282a3,0x7e718da4,0x7bcf0da5}},	//   _vele_, _awoo, _žepč, _kacu,
   {{0x69ce0da6,0xd6f70076,0x629b8da7,0x3f8b0da8}},	//   _zabe, ुनाथ_, truo, jacu_,
   {{0x69c18da9,0x2d858daa,0x443f8dab,0x4919016f}},	//   tele, _tele_, rlu_, _येतो_,
   {{0x7c878dac,0x443f81fa,0x2ba7835a,0xd24e80a0}},	//   _буде, slu_, _गावा, وني_,
   {{0x443f8dad,0xd9458d5f,0x61458dae,0x69c18daf}},	//   plu_, рени, рена, rele,
   {{0x20040db0,0xdcfe01a9,0x7bcf0db1,0x78a18db2}},	//   ómi_, _nepā, _nacu, rulv,
   {{0x91e58db3,0x248600e1,0x09e58db4,0xf38c83de}},	//   _воле, _ňom_, _волн, _טראָ,
   {{0x44d58db5,0x7a3002af,0xee370db6,0x216681a1}},	//   _kā_, sätz, иня_, _киши_,
   {{0x2d8a0db7,0x7bcf0db8,0x44d580eb,0x69ce0db9}},	//   rabe_, _bacu, _jā_, _rabe,
   {{0x3ced8d38,0x44d58dba,0x2d8a0dbb,0x31c58dbc}},	//   _अपने_, _mā_, sabe_, _वसुध,
   {{0xfaa60dbd,0x69ce0dbe,0xcb00009a,0x25db82f1}},	// [600] разо, _pabe, लैंड_, _गोभी_,
   {{0xb21b0bc5,0x69ce04b7,0xe1ff0dbf,0x2d960dc0}},	//   _svær, _qabe, _stór_, _трис,
   {{0x44d58dc1,0x61fe0dc2,0x44c78019,0x661c0dc3}},	//   _nā_, rkpl, _nő_, mirk,
   {{0x69ce0dc4,0x7bcf0dc5,0xb5fd811f,0x661c0dc6}},	//   _wabe, _gacu, _bušo, lirk,
   {{0xdfcf80f7,0x683d00e7,0x7bc40162,0x41a6864a}},	//   بين_, cédu, meiu, _खालस,
   {{0xa61380e8,0x2888004e,0x27350129,0xd0b3011c}},	//   оміч, _مصری_, ụng_, hşət,
   {{0x291e00f2,0x6da38dc7,0xb21b006a,0x7bcf018f}},	//   _äta_, ција, _tvær, _yacu,
   {{0x661c0057,0x3edf01bc,0x6d4884e8,0x07a38191}},	//   hirk, _stọọ_, _vzda, _масн,
   {{0x15f8085d,0xe5a68dc8,0x6da68dc9,0xb5fd826c}},	//   ुसार_, _визи, _виза, _kušl,
   {{0x44c78019,0x38600362,0x7cdc8162,0x99668dca}},	//   _fő_, _aiir_, _pără, штил,
   {{0x7e760dcb,0x6aa401ed,0xddc98dcc,0x88590087}},	//   _atyp, huif, _uteš, лиос_,
   {{0xa3d78054,0xb8868032,0xb5fc8372,0xeb978dcd}},	//   ायण_, _atíò, _diġe, _виц_,
   {{0xc7b38051,0x69a701b6,0x661c0359,0x3f8b0b80}},	//   חבר_, _चाली, firk, racu_,
   {{0x2723801c,0x661c0dce,0x7bcf0dcf,0x2bda8006}},	//   ằng_, girk, _sacu, _मोता,
   {{0x40948dd0,0xedf48996,0xe65400e8,0x7bcf0dd1}},	//   _البر, _अवैध_, івсь, _pacu,
   {{0x3ced0024,0x539800e8,0x41a68dd2,0x672d01c0}},	//   ćev_, ився_, _खाँस, _txaj,
   {{0x99670dd3,0x7bcf0dd4,0x79870101,0x24580009}},	// [610] ател, _vacu, _pejw, рать_,
   {{0x661c0dd5,0x3d178074,0x2aaf011c,0x7bcf0dd6}},	//   cirk, _भइले_, rüb_, _wacu,
   {{0x7bcf0dd7,0x35f8003d,0x92e700ab,0x61f80106}},	//   _tacu, _خريد_, বনে_, övla,
   {{0x44d58dc1,0x9ad3819d,0x7bc40162,0x4e9581a8}},	//   _rā_, _dịji, ceiu, مشتر,
   {{0xa3ea8dbc,0xd6d9809a,0x6b8d0dd8,0x645a0dd9}},	//   मान_, _była_, maag, ïtie,
   {{0xee38835f,0x44d58dc1,0x6b8d0dda,0x80af80ab}},	//   ані_, _pā_, laag, য়িত্,
   {{0x69c50ddb,0x93fb016f,0x70940ddc,0xcd9801c6}},	//   mehe, _एकाच_, _марф, בדות_,
   {{0x6b8d0ddd,0x69c50dde,0x53c98319,0x44d58dba}},	//   naag, lehe, угим_, _vā_,
   {{0xb5fb0118,0x60060333,0x7d06811c,0x65958162}},	//   bpáx, _nóma, _əksi, _газу,
   {{0x44d58341,0xa2058ddf,0x7ae984c3,0x26cd80e5}},	//   _tā_, спод, rxet, _iseo_,
   {{0x3f890de0,0x661c0de1,0x6b8d0de2,0x629d816b}},	//   _beau_, virk, kaag, ásob,
   {{0x69c50de3,0x661c0de4,0x76438de5,0x7e69804f}},	//   hehe, wirk, llny, _kuep,
   {{0x69c50de6,0x7e618009,0x661c0de7,0xaac60105}},	//   kehe, _kilp, tirk, _रैंक,
   {{0x63a98de8,0x998580f7,0x6006008b,0x3f9e0214}},	//   lgen, _الثو, _dóma, ştu_,
   {{0x61e38de9,0xeb9a0dea,0x63a98deb,0x61fc8dec}},	//   _innl, лив_, ogen, örle,
   {{0x63a98ded,0x644f0dee,0x78a504a8,0x6b8d0def}},	//   ngen, _chci, duhv, gaag,
   {{0x38b18df0,0x661c0df1,0x63b6031d,0x63a98df2}},	// [620] lár_, pirk, rfyn, igen,
   {{0xe3b203f8,0x69c50df3,0xb5fd826c,0x443d8192}},	//   _کرد_, gehe, _bušm, _lkw_,
   {{0xa3d78df4,0x395c016d,0x6d418df5,0x26cd8020}},	//   ाया_, ävs_, _nyla, _aseo_,
   {{0x6b8d0df6,0x20020009,0xddc281b9,0x7e618362}},	//   caag, nkki_, spoż, _ailp,
   {{0xadec0cce,0xa3e1823c,0x69c50df7,0x248d00eb}},	//   ञापन_, दाई_, behe, ņemt_,
   {{0x44d803bb,0x443d8133,0x64440df8,0x6d418df9}},	//   _kč_, _akw_, llii, _byla,
   {{0x38b18dfa,0x63a98dfb,0xdd99804a,0x7c29016b}},	//   jár_, fgen, рші_, červ,
   {{0x68158063,0x6d41831d,0x63a98dfc,0x83fc805c}},	//   ządz, _dyla, ggen, _tuđm,
   {{0x44d806c0,0xa3e0064a,0xaf068dfd,0x645c80e5}},	//   _lč_, _दफन_, _упал, _èrim,
   {{0x60060dfe,0xd9cf00ab,0xddcd01a1,0x98b88073}},	//   _róma, রাথম, _otaš, алот_,
   {{0x3f8900e7,0xeb9a8dff,0x2cbe82f7,0x26c0016a}},	//   _peau_, _бие_, _uptd_, _apio_,
   {{0xfaa681e2,0x3a3a0711,0x82a68705,0x394281a9}},	//   _гадо, hopp_, _гадж, āks_,
   {{0xab5d809a,0xa3e70e00,0x3ea68e01,0x3f890866}},	//   leżn, पास_, nuot_, _veau_,
   {{0x86270e02,0xddcd009a,0x6b8d0e03,0x9f44826b}},	//   сьме, _uważ, waag, _bomú_,
   {{0x61f50e04,0x6b8d0e05,0x9f448722,0x69c50e06}},	//   _rozl, taag, _comú_, vehe,
   {{0x321e8e07,0x69c5010c,0x27e482c4,0x93790162}},	//   lity_, wehe, _nnmn_, рбат_,
   {{0x7a3d8e08,0x69c502af,0x6b8d0e09,0xfaff0168}},	// [630] mètr, tehe, raag, _afër_,
   {{0x321e8e0a,0x44d80247,0xddab0e0b,0x32070e0c}},	//   nity_, _fč_, _стил_, óny_,
   {{0x094b03bd,0x201d8e0d,0x6b8d0e0e,0x69c50e0f}},	//   учаи_, tiwi_, paag, rehe,
   {{0x69c50352,0xb8f10e10,0x7e618e11,0xad1a0039}},	//   sehe, _वन_, _silp, _כותר,
   {{0x8d658e12,0x44290e13,0x38b18e14,0x7e698e15}},	//   овле, mna_, zár_, _quep,
   {{0x443b0e16,0xdc998e17,0x20090114,0x201d804f}},	//   loq_, атиш_, _llai_, siwi_,
   {{0xd7aa0e18,0xcc8684fa,0x63a98e19,0xb5fd80d2}},	//   _कालच, обще_, tgen, _hušk,
   {{0x5fd90e1a,0xdb0d0e1b,0x66838065,0x6b808122}},	//   _बोलल, leañ, _فیصل, gbmg,
   {{0xab2989e0,0x7e618e1c,0x23298e1d,0x3ebf8088}},	//   ропа_, _tilp, ропи_, _uput_,
   {{0xb5fd803b,0x44290e1e,0x63a9844e,0x38b18e1f}},	//   _mušk, hna_, sgen, tár_,
   {{0x29038298,0x44290e20,0x443d8573,0x3207816b}},	//   ája_, kna_, _tkw_, _vlny_,
   {{0xa3ea86d4,0x3ea08805,0xb4d58128,0x2ca78e21}},	//   माण_, šite_, िटी_, mund_,
   {{0x7c3b8e22,0x2ca78e23,0x20020009,0x38b18e24}},	//   mour, lund_, rkki_, sár_,
   {{0x27388028,0x321e8e25,0x44d80e26,0x386a81a8}},	//   ứng_, city_, _pč_, úirí_,
   {{0xed5a0dd3,0x44290e27,0x7c298e28,0xdbc7007b}},	//   ров_, fna_, oner, töðu,
   {{0x44290e29,0x683601ac,0xb5fd88ae,0xf1ac0cf0}},	//   gna_, hádz, _bušk, _चाहन,
   {{0xa3ea816f,0xdb118036,0x2ca784dc,0x6b8b8e2a}},	// [640] मात_, éfèr, hund_, _megg,
   {{0x44290e2b,0x6b8b8e2c,0xb5fd8390,0x44d80e2d}},	//   ana_, _legg, _dušk, _tč_,
   {{0x44290e2e,0xd6d98063,0x63af0364,0x7c3b86c0}},	//   bna_, _było_, ännö, kour,
   {{0x7c3b83d3,0x8c46002e,0x321e84e8,0x2d8e8e2f}},	//   jour, _феме, zity_, wafe_,
   {{0x44200e30,0xa3e7025e,0x7c3b8e31,0x628681d0}},	//   mii_, पार_, dour, škoz,
   {{0xd49a8abe,0x44200e32,0x2ba80e33,0xa6e3007b}},	//   ари_, lii_, गलवा, æðis,
   {{0x6b8b8e34,0x25a087d9,0x1db20740,0x798a8e35}},	//   _begg, ğil_, _जानत, _refw,
   {{0x44200e36,0x25a082d0,0x7c3b8e37,0x2d8e8e38}},	//   nii_, şil_, gour, safe_,
   {{0x24898a20,0x9c8780e1,0x6b8b81b4,0x6ab60035}},	//   ćama_, _počú, _degg, ntyf,
   {{0x44200e39,0x44290e3a,0xdb198247,0x2ca78e3b}},	//   hii_, zna_, _pawò, bund_,
   {{0x44290e3c,0xa3b58076,0x44200079,0x600605e4}},	//   yna_, _चॉक_, kii_, _cómo,
   {{0x44200e3d,0x44290e3e,0xf1ae852a,0x7c29826c}},	//   jii_, xna_, ज्जन, cner,
   {{0x44200962,0x44290e3f,0x77640698,0x6e3c0e40}},	//   dii_, vna_, държ, forb,
   {{0x6b8b8a0f,0x2d8c8e41,0x44290e42,0x60060118}},	//   _zegg, _jede_, wna_, _fómo,
   {{0xa3e7005e,0x69c88e43,0x48c500c8,0x44200e44}},	//   पाल_, mede, _এপ্র, fii_,
   {{0x44200e45,0x69c88e46,0x44290e47,0x7aed0e48}},	//   gii_, lede, una_, txat,
   {{0x4429088b,0x443b022b,0xd839011a,0xf96b0e49}},	// [650] rna_, roq_, juči_, арей_,
   {{0x7c2d80d2,0x69c88e4a,0xdb1182be,0x527b8158}},	//   čari, nede, éfér, ינמא,
   {{0x44200e4b,0x44290e4c,0x2d910e4d,0x683601ac}},	//   bii_, pna_, maze_, vádz,
   {{0x2d91012b,0x44200e4e,0x69c88e4f,0x98b38052}},	//   laze_, cii_, hede, žeći_,
   {{0x6b8b8e50,0x63ad0e51,0x2d8c8e52,0x3f8f8e53}},	//   _regg, mgan, _bede_, ragu_,
   {{0x69c88e54,0x63ad0e55,0x2ca78e56,0xe61880e8}},	//   jede, lgan, tund_, оді_,
   {{0xa3d784e5,0x7c3b8e57,0x69c88e58,0x2d8c8e59}},	//   ायल_, tour, dede, _dede_,
   {{0x63ad0e5a,0xb5fd8754,0x25db8e5b,0x2ca78e5c}},	//   ngan, _muši, _गोरी_, rund_,
   {{0x2ca78e5d,0x2d910e5e,0x2d8c8e5f,0x6b8b8357}},	//   sund_, kaze_, _fede_, _vegg,
   {{0x44200012,0xddc4003b,0x2d8c8e60,0x6b8b8e61}},	//   zii_, _stiž, _gede_, _wegg,
   {{0x6d450e62,0x442004be,0xb5fd8e63,0x9f448242}},	//   _nyha, yii_, _nuši, _anmè_,
   {{0x442002a3,0x69d50e64,0xdd8f8019,0x6e3c0192}},	//   xii_, _laze, _سوچ_, worb,
   {{0x63bb8710,0x44200e65,0x63ad0e66,0xdb1d016a}},	//   mfun, vii_, dgan, _masó,
   {{0x9c828db7,0x2d8c0e67,0x63bb80e3,0x44200079}},	//   ščen, úde_, lfun, wii_,
   {{0x44200e68,0xe1668077,0xa5070e69,0x63ad0e6a}},	//   tii_, _عضوی, пера_, fgan,
   {{0xc4d2893f,0xbc630e6b,0x6e3c0e6c,0x61e70e6d}},	//   עגן_, евск, sorb, _anjl,
   {{0x44200e6e,0x7e6d0e6f,0x2fc002b8,0xaabd81a2}},	// [660] rii_, _guap, _ibig_, ्बिक,
   {{0xa3e28e70,0x44200e71,0x2d910e72,0x25db8bb8}},	//   _फोन_, sii_, caze_, _गोली_,
   {{0x44200e73,0x38b50e23,0x2d8c8e74,0x7e7b8e75}},	//   pii_, går_, _rede_, _atup,
   {{0xdb1d0e76,0x83fc82a5,0xde6d001c,0x35b203db}},	//   _obsè, _tuđi, _hươn, _जाड़,
   {{0x69d50003,0xf8a88bb8,0x66fe0540,0x2d8c8e77}},	//   _faze, _कम्प, ॉनिक_, _pede_,
   {{0xd8390e78,0x69d50e79,0x6b840e7a,0x7c3b0da8}},	//   ruči_, _gaze, lbig, čure,
   {{0x2d8c8e7b,0xdb0f02be,0xe81d06a7,0x63bb8e7c}},	//   _vede_, _accè, _पगला_, ffun,
   {{0x8aa68adb,0xde6d001c,0x69c88e7d,0x32058366}},	//   прод, _lươn, wede, ekly_,
   {{0x62960e7e,0x69c88e7f,0x2d8c8e80,0xa3e18e81}},	//   nsyo, tede, _tede_, दाज_,
   {{0xdb0d03a7,0xde6d00ff,0x8afb0e82,0x6faa0305}},	//   sfaç, _nươn, צהיי, _काउं,
   {{0x6aa40e83,0x7e6d0ad4,0x63ad0e84,0xb4c80035}},	//   hrif, _suap, ygan, ोटो_,
   {{0x6aa40e85,0xe45a8e86,0x62960e87,0x4c16826a}},	//   krif, _уже_, ksyo, _عباس,
   {{0xf2068021,0x78a8806a,0x7e6d0299,0xeb9f0646}},	//   _няко, sudv, _quap, _fløj_,
   {{0xa2db0e88,0x7afd8e89,0x6aa4035f,0xde6d00ff}},	//   निस्, äste, drif, _cươn,
   {{0x63ad0e8a,0xde6d0028,0x69d50e8b,0x19bb8039}},	//   tgan, _dươn, _raze, _המוב,
   {{0x6aa4031d,0x6b84009c,0x9c7c812b,0x2d910e8c}},	//   frif, gbig, _grče, saze_,
   {{0x6aa40e8d,0x95cb0e8e,0x2ee00e8f,0xb03803c8}},	// [670] grif, _луна_, _grif_, _מנהג_,
   {{0x38b50bfa,0xde6d001c,0x20c80e90,0xb0c8052a}},	//   tår_, _gươn, रबंध, रबंग,
   {{0x7e7b8b24,0x6b840e91,0x29070e92,0x7e7c807a}},	//   _stup, bbig, ána_, _črpa,
   {{0x2c718e93,0x290704b7,0x6aa40e94,0x69d50e95}},	//   _rád_, ġna_, brif, _waze,
   {{0xdb1d0b2c,0x38b50bbd,0x7c2d0e96,0x603201a9}},	//   _obsé, sår_, mnar, nāma,
   {{0x6da58e97,0xde6d001c,0x2c71816b,0x38b50106}},	//   фика, _xươn, _pád_, pår_,
   {{0x2489805c,0x442f80dd,0x27e902d6,0xed568073}},	//   ćamo_, _pjg_, _onan_, мош_,
   {{0x7c2d0e98,0xdb0f0e99,0x1b1e80ab,0x67d4806d}},	//   nnar, _accé, _পড়ে_, _посу,
   {{0x63bb8e9a,0x7c2d0e9b,0x7bc98e9c,0xa7fd011c}},	//   rfun, inar, reeu, yqır,
   {{0x27e90e9d,0x3eab0e9e,0x6442811b,0xb5fd8e9f}},	//   _anan_, duct_, _ekoi, _aušv,
   {{0x63bb8ea0,0x07a601d9,0x7c2d007b,0x200d800b}},	//   pfun, манн, knar, _klei_,
   {{0x2ee0031d,0x81b580ab,0xe3b081a8,0xde6d00ff}},	//   _prif_, _চোখ_, _مره_, _sươn,
   {{0xa3ea88d4,0x7c2d0353,0x443f8ea1,0xe28e8ea2}},	//   मार_, dnar, mou_, _ша_,
   {{0x64498ea3,0x200d809f,0x7c2d0ea4,0x27e902d6}},	//   llei, _llei_, enar, _enan_,
   {{0x442d8021,0xe1f08ea5,0x3eb90613,0x9d430ea6}},	//   one_, _حسن_, atst_, верд,
   {{0x443f8ea7,0x7c2d0ea8,0x64498e5d,0x9c7c8ea9}},	//   nou_, gnar, nlei, _urče,
   {{0x442d8eaa,0xe1fa0eab,0xde6d0028,0x64498229}},	// [680] ine_, ога_, _tươn, ilei,
   {{0x6aa40eac,0x443f8ead,0x2b8c0028,0x6b8402a3}},	//   rrif, hou_, ếc_, sbig,
   {{0x443f8eae,0x442d8558,0x851c8105,0x64498eaf}},	//   kou_, kne_, _भेंट_, klei,
   {{0x442d8eb0,0xa2db05e8,0x798e00c9,0x443f8eb1}},	//   jne_, निश्, _webw, jou_,
   {{0x442d81d6,0x443f8eb2,0xee3a8eb3,0x20068168}},	//   dne_, dou_, онд_, rkoi_,
   {{0xa2db0eb4,0x6449844e,0x6e238129,0xb8140264}},	//   निर्, elei, ginb, াচিত_,
   {{0x443f8eb5,0xa3ea84c5,0x3e740106,0x1dc00eb6}},	//   fou_, माल_, _lät_, श्यत,
   {{0x442d8eb7,0x443f8e67,0x68e3013c,0x64498eb8}},	//   gne_, gou_, ænde, glei,
   {{0x61fc0eb9,0x3e740106,0x3f868eba,0x9ad301bc}},	//   _korl, _nät_, mbou_, tịim,
   {{0x442d8ebb,0x7c240ebc,0x4efb81c6,0x6449862c}},	//   ane_, hiir, _והמו, alei,
   {{0x443f8ebd,0x850684c0,0x442d8ebe,0x25eb8ebf}},	//   bou_, _توان, bne_, चारी_,
   {{0x443f8ec0,0x3f868ec1,0x62808ec2,0x60320ec3}},	//   cou_, nbou_, ppmo, tāma,
   {{0x64408ec4,0x61fc00c9,0x2bdf00d4,0x5bbc8ec5}},	//   momi, _oorl, _पोषा, ्जीव,
   {{0x64408ec6,0x61fc0ec7,0x8a038081,0x603201a9}},	//   lomi, _norl, _изче, rāma,
   {{0x92bb0a49,0x443f001c,0x7c240ec8,0x623381a1}},	//   _আছে_, _ưu_, fiir, _шешу,
   {{0x27e90ec9,0xfc300eca,0x69da8ecb,0x69d88cf7}},	//   _unan_, لحق_, ldte, _have,
   {{0xa3b685e8,0x69d88ecc,0x61fc0ecd,0x776d0118}},	// [690] _जान_, _kave, _borl, _igax,
   {{0x443f8ece,0x442d8ecf,0x69da8ed0,0x64408ed1}},	//   zou_, zne_, ndte, homi,
   {{0x442d8ed2,0x644081f6,0x69d88ed3,0x7c240ed4}},	//   yne_, komi, _mave, biir,
   {{0x44248025,0x27e98ed5,0x69d88257,0x443f8548}},	//   jim_, ñan_, _lave, xou_,
   {{0x442d8ed6,0x443f8ed7,0x9f4087ca,0x61fc0ed8}},	//   vne_, vou_, ðið_, _forl,
   {{0x7bc2804c,0x442d8063,0x61fc0ed9,0x7cd38085}},	//   _abou, wne_, _gorl, _hərə,
   {{0x443f8eda,0x442d8ed6,0x60060013,0x44248edb}},	//   tou_, tne_, _fómh, fim_,
   {{0x442d8012,0x200d8087,0x61ea8edc,0x61fc03bf}},	//   une_, _ulei_, _anfl, _zorl,
   {{0x442d8edd,0x64498357,0x63a68ede,0x69d88edf}},	//   rne_, rlei, ókna, _bave,
   {{0x443f83a8,0x442d8ee0,0xe1f18013,0x9c828ee1}},	//   sou_, sne_, اسة_, ščan,
   {{0xd8260ab5,0x602607eb,0x38690ee2,0x69d88ee3}},	//   едни, една, _biar_, _dave,
   {{0x64408ee4,0x7ae28ee5,0xa3b68ee6,0x61ea8ee7}},	//   comi, _frot, _जाय_, _enfl,
   {{0x7ae28ee8,0x7bcd0ee9,0x7c240eea,0x69d88eeb}},	//   _grot, deau, viir, _fave,
   {{0x69d88eec,0xa3d78eed,0xb5fd8582,0x2d9e0036}},	//   _gave, ायक_, _gušt, ûte_,
   {{0x7bd98eee,0x1b1d00ab,0xd00a0eef,0xa3b68ef0}},	//   _kawu, _ভুলে_, _неке_, _जाम_,
   {{0x69d88ef1,0xe73a0009,0x7bcd010c,0xb60201d0}},	//   _zave, _ней_, geau, _žádo,
   {{0x7c240ef2,0xf41280be,0x60060ef3,0x7cd38085}},	// [6a0] riir, אפן_, _nómi, _dərə,
   {{0x44248ef4,0xe9d70ef5,0x7c2402a3,0x7c3b0279}},	//   zim_, нку_, siir, čura,
   {{0xa3ea0381,0x7c240ef6,0x44248ef7,0x61fc01ec}},	//   _една_, piir, yim_, _vorl,
   {{0x44248ef8,0x61fc0051,0xfbae8670,0x7bd98ef9}},	//   xim_, _worl, _टाइम, _nawu,
   {{0xa3b685b3,0x600605e4,0x64408791,0x6d488efa}},	//   _जाब_, _cómi, vomi, _syda,
   {{0x44248efb,0xf2d3007c,0x7ae28168,0x7cd3811c}},	//   wim_, _געש_, _rrot, _zərə,
   {{0x8fa681e2,0x04668adb,0x7c2f00f7,0x9c7c8754}},	//   _паве, нтим, _áirí, _brča,
   {{0x6d488efc,0xb5fd8efd,0x961d0eed,0xccf304de}},	//   _vyda, _sušt, _नष्ट_, רכה_,
   {{0x44248efe,0xb5fd803a,0x64408eff,0x69d88f00}},	//   rim_, _pušt, romi, _pave,
   {{0x38690ad0,0x64408329,0x38b88f01,0x7afd8f02}},	//   _siar_, somi, tér_, ästa,
   {{0x0b8a825d,0x9f448f03,0x290a8019,0x64a38f04}},	//   _если_, _tomó_, ába_, _баха,
   {{0x7ae28f05,0x2c750f06,0x68e38858,0x929d8035}},	//   _trot, _råd_, _drnd, syła,
   {{0x7bcd0f07,0x7ae28f08,0x38b88f09,0x3869008e}},	//   veau, _urot, sér_, _viar_,
   {{0x61ea8176,0x8cd78f0a,0x44220f0b,0x64460c2e}},	//   _unfl, _मनमो, _amk_, _akki,
   {{0x248d003b,0x7bcd0f0c,0x7bd98f0d,0xf8a48f0e}},	//   ćemo_, teau, _yawu, _खटिय,
   {{0x59c600d4,0x60c7008e,0x210301d6,0x6b9601b4}},	//   _रॉबर, _rpjm, nčiť_, gayg,
   {{0x6b848006,0x2bc2816f,0xfbc28f0f,0x7bcd0f10}},	// [6b0] _õigu, व्या, व्यम, reau,
   {{0x7bcd0f11,0xa2a70f12,0x2bcf0035,0x210301d6}},	//   seau, _चिठ्, हजहा, hčiť_,
   {{0x7cd38086,0x5f958f13,0x7c228f14,0x6b9601b4}},	//   _tərə, виет, _omor, bayg,
   {{0xfbab0009,0x629d8061,0x9f49010c,0x200b01d0}},	//   _этой_, ások, _anaé_, nkci_,
   {{0x62830025,0x644d0f15,0x6aad00e5,0x79a70a2e}},	//   ćnos, mlai, quaf, _прве,
   {{0x62350f16,0x9c7c8024,0x2ab98247,0x62500074}},	//   _регу, _srča, vèb_, näol,
   {{0xda3401bb,0xdce1809a,0x644d0f17,0x7bd98f18}},	//   _серы, _oglą, olai, _pawu,
   {{0x644d0f19,0x8ca286b7,0x69c3808e,0x26c90390}},	//   nlai, _गिरो, _sbne, _opao_,
   {{0x7bdb8f1a,0x69c10f1b,0x68e38bcf,0x961d8ec3}},	//   rduu, र्थी, _srnd, _atņe,
   {{0xaca38870,0x644d0c5e,0x2fcf80e8,0x7c228f1c}},	//   _amụm, hlai, legg_, _emor,
   {{0x9c7c805c,0x76438f1d,0x644d0f1e,0x7bd98f1f}},	//   _trča, mony, klai, _tawu,
   {{0x9c7c8f20,0x645a0084,0x27ff8176,0x69c10f21}},	//   _krčn, įtik, _joun_, र्ती,
   {{0xa3b68f22,0x27ff8f23,0x9aa48f24,0xe9ce8f25}},	//   _जात_, _moun_, _ممنو, _кк_,
   {{0x44220f26,0xed5a0f27,0x7c228f28,0xc5d50a4c}},	//   _smk_, дог_, _zmor, лісь,
   {{0x799702c1,0x44220f29,0xdcfc00eb,0x27ed8f2a}},	//   daxw, _pmk_, varē, _onen_,
   {{0x644d0f2b,0x7ae9005c,0x69c18f2c,0x6b898f2d}},	//   glai, _šeta, lfle, nbeg,
   {{0xe2970f2e,0xee3a0f2f,0xab270320,0x76438f30}},	// [6c0] кат_, _они_, вота_, kony,
   {{0x644d0f31,0x69c18f32,0x6b89826c,0x175701c6}},	//   alai, nfle, hbeg, _בספר_,
   {{0x76438f33,0x644d0f34,0x27ff8176,0x62840f35}},	//   dony, blai, _boun_, spio,
   {{0x2d980f36,0x644d0f37,0x629b8084,0x6aa9804a}},	//   lare_, clai, ksuo, kref,
   {{0x76438f38,0x44320f39,0x37dc0264,0x2a6a011c}},	//   fony, mny_, ধাপর, _tibb_,
   {{0xa2a70f3a,0x4432096a,0x2d980f3b,0x76438f3c}},	//   _चित्, lny_, nare_, gony,
   {{0x61ee0106,0x44320f3d,0x69dc0f3e,0xb5fc81b9}},	//   _inbl, ony_, _iare, _jiġi,
   {{0x44320f3f,0x64598f40,0x2d980f41,0x69dc0f42}},	//   nny_, _chwi, hare_, _hare,
   {{0x69dc0f43,0x2d980f44,0x51868071,0x76438f45}},	//   _kare, kare_, куна, bony,
   {{0x69dc0f46,0x2d980f47,0x44320f48,0x2bae816f}},	//   _jare, jare_, hny_, _टाका,
   {{0x69dc0f49,0x25db8076,0x2d98088b,0x27ff8247}},	//   _mare, _गोटी_, dare_, _youn_,
   {{0x27ed07f4,0x44320f4a,0x2d930f4b,0x3ea986c2}},	//   ñen_, jny_, _sexe_, šate_,
   {{0x44320f4c,0x34cb0996,0x2d9800e5,0x63a28f4d}},	//   dny_, ाब्द, fare_, _idon,
   {{0x69dc0f4e,0xb8828f4f,0x2d980687,0x62828f50}},	//   _nare, üíst, gare_, _itoo,
   {{0x6d400b16,0x20d38c3b,0x65940f51,0xdd940f52}},	//   şman, _نتيج, расу, расы,
   {{0x76438f53,0x44320f54,0xec340f55,0x644d0f56}},	//   zony, gny_, ансь, ulai,
   {{0x2d980f57,0x644d0f58,0x81d580c8,0x76438f59}},	// [6d0] bare_, rlai, হার_, yony,
   {{0x2d980f5a,0x44320063,0xaca30135,0x69dc0f5b}},	//   care_, any_, _atụg, _care,
   {{0x69dc0f5c,0x26080063,0x24810748,0x9c7c807a}},	//   _dare, _सकती_, _uthm_, _srčn,
   {{0x63a28f5d,0x3f990f5e,0xa283003d,0xac1900e8}},	//   _ndon, nasu_, _نیرو, _чому_,
   {{0x44290f5f,0x501c0f60,0xf7708bbe,0x1dc000d4}},	//   mia_, וואו, زان_, श्वत,
   {{0x69dc0f61,0x63a28f62,0x6272809a,0x7bdd0f63}},	//   _gare, _adon, _młod, _hasu,
   {{0x7bdd0f64,0x6b898754,0x27ff826b,0x25a983bf}},	//   _kasu, tbeg, _toun_, ğal_,
   {{0x44290f65,0x2d980012,0x69dc0f66,0x6aa98f67}},	//   nia_, zare_, _zare, tref,
   {{0x7bdd0f68,0x69dc0f69,0x76438f6a,0x6113811c}},	//   _masu, _yare, pony, mələ,
   {{0x44290f6b,0x386d8f6c,0x6aa98f6d,0x61138201}},	//   hia_, _hier_, rref, lələ,
   {{0x44290f6e,0x2d980f6f,0x44320063,0x69c18f70}},	//   kia_, vare_, yny_, rfle,
   {{0x7bdd0f71,0x44290f72,0x98160154,0x6aa98f73}},	//   _nasu, jia_, ابدا, pref,
   {{0x66018f74,0x4432003e,0x7ae9005c,0xfaa58f75}},	//   _kolk, vny_, _šetn, _сало,
   {{0x4432009a,0x3e798247,0x61138085,0x98e580f7}},	//   wny_, _mèt_, hələ, _مكتو,
   {{0x2d980f3b,0x61138201,0x3f990f76,0x69dc0f77}},	//   rare_, kələ, basu_, _rare,
   {{0x44290f78,0x69dc0f79,0x2d980f7a,0x44e387d9}},	//   gia_, _sare, sare_, _mı_,
   {{0x79950f7b,0x2d980f7c,0x4432096a,0x3e7986c0}},	// [6e0] _bezw, pare_, rny_, _nèt_,
   {{0x7c298f7d,0x44290f7e,0x44320f7f,0x613a0f80}},	//   hier, aia_, sny_, нчер_,
   {{0x69dc0f81,0x386d8f82,0x61138085,0x7c298f83}},	//   _vare, _bier_, fələ, kier,
   {{0xe73a8364,0x765a80f1,0xb8dc03a4,0x3e798247}},	//   нее_, _shty, _आम_, _bèt_,
   {{0x69dc0f84,0xadf08f85,0x539b0039,0x386d8f86}},	//   _tare, चालन_, _איכו, _dier_,
   {{0x38bc0f87,0x61460f88,0x3f990f89,0x386d8f8a}},	//   pír_, _бега, zasu_, _eier_,
   {{0x7c298f8b,0x386d8f8c,0xa3bb0f8d,0x7bdd0f8e}},	//   fier, _fier_, _घाम_, _yasu,
   {{0x7c298f8f,0x3e798205,0x79950f90,0x61138201}},	//   gier, _fèt_, _zezw, cələ,
   {{0x66018f91,0x7ae40d7b,0x52148cc1,0xe7378037}},	//   _folk, nvit, идит, _бет_,
   {{0x44290f92,0xddcd0f93,0xa3b68006,0x66018f94}},	//   zia_, _staž, _जाव_, _golk,
   {{0x7c298f95,0x7c260f96,0x41c60670,0x59c60f97}},	//   bier, _omkr, र्यस, र्यर,
   {{0x7c298f98,0xaae68f99,0x386d0106,0x660180b9}},	//   cier, _مستو, öer_, _zolk,
   {{0x44268f9a,0x7bdd0f9b,0x6d4003bf,0x95cb0f9c}},	//   _imo_, _rasu, şmal, нува_,
   {{0x44290f9d,0x442681c5,0x7bdd0f9e,0x2731801c}},	//   wia_, _hmo_, _sasu, ạng_,
   {{0x44290f9f,0x7bdd0fa0,0x3f990fa1,0x317b810f}},	//   tia_, _pasu, pasu_, _ארומ,
   {{0xb4c50006,0x799a8fa2,0x44290fa3,0x6006008b}},	//   _एही_, latw, uia_, _dóms,
   {{0x59c603eb,0xafdb03ba,0x7bdf0fa4,0x7bdd0fa5}},	// [6f0] र्भर, sløs, rdqu, _vasu,
   {{0x44290fa6,0x7c298fa7,0x386d835f,0x7bdd0fa8}},	//   sia_, zier, _sier_, _wasu,
   {{0x4426877f,0x7bdd0006,0xc7958071,0x44290fa9}},	//   _omo_, _tasu, арлы, pia_,
   {{0xb4fa078d,0x20da807d,0x79950f90,0x2ee903ac}},	//   _ספרי, mšić_, _wezw, _kraf_,
   {{0x6b8d0faa,0x386d84eb,0x7c298fab,0x539a0039}},	//   mbag, _vier_, vier, _בירו,
   {{0x6b8d0fac,0x7c298063,0x61138201,0x69c7056f}},	//   lbag, wier, sələ, _ubje,
   {{0x6601844e,0x7c298fad,0x44390fae,0xb60584be}},	//   _volk, tier, _kjs_, _aláì,
   {{0x3e798205,0x66018faf,0x61138085,0x22458fb0}},	//   _tèt_, _wolk, qələ, wolk_,
   {{0x7c298fb1,0x2bc7016f,0xa3b68fb2,0x799a80b4}},	//   rier, ऱ्या, _जार_, fatw,
   {{0x7c298fb3,0x20da812b,0x5ec880ab,0xb4c50074}},	//   sier, kšić_, লিশে, _एहू_,
   {{0x63b60196,0x2bc2816f,0x3ea00fb4,0xdb09816a}},	//   ygyn, व्हा, _svit_, rfeñ,
   {{0x44268fb5,0xa4fa80be,0x6aad0fb6,0x2ee90428}},	//   _gmo_, _בלעט, kraf, _braf_,
   {{0x636b83bf,0x1f5601bb,0x799a8fb7,0x41c60fb8}},	//   _dönü, ртнё, batw, र्डस,
   {{0x91fc8341,0x81ab00c8,0x6aad0fb9,0x62898fba}},	//   rmāc, ক্ত_, draf, mpeo,
   {{0x3b960fbb,0xe946819f,0x2ee90fbc,0x4439041c}},	//   ијат, _پروی, _eraf_, _bjs_,
   {{0x3ea0812b,0xf8140077,0x6b8d0fbd,0xafdb0aa2}},	//   šiti_, _دستگ, gbag, slør,
   {{0xd4670fbe,0xb22601b5,0xada60fbf,0xa3d686b7}},	// [700] рите_, амал, _капл, ाजत_,
   {{0x7ae40fc0,0x27e00fc1,0x26060187,0xa3e601a2}},	//   rvit, _hain_, _vôos_, _योर_,
   {{0x27e00590,0x6b9b8fc2,0xdb0d016b,0x2fdf8fc3}},	//   _kain_, kaug, čkác, _baug_,
   {{0x7c260fc4,0x2fdf8069,0xbc7b0039,0xe3b20fc5}},	//   _umkr, _caug_, _שנכת, _برد_,
   {{0x2fdf81e2,0x27e00fc6,0xa3bb0075,0x2bdf0072}},	//   _daug_, _main_, _घात_, _पोटा,
   {{0x27e00fc7,0x7ae480f7,0x7aeb006a,0x44d802d6}},	//   _lain_, _áiti, ægte, _kō_,
   {{0xd49781e2,0x10a30fc8,0x18a30fc9,0x44268fca}},	//   ары_, _мирн, _марм, _pmo_,
   {{0xa6868fcb,0xeca78fcc,0x27e00fcd,0xa3c90fce}},	//   _влад, _गिरफ, _nain_, ल्प_,
   {{0x9c7c85f3,0xf1c60aed,0x41c60af3,0x7cca811c}},	//   _krčk, र्थन, र्थस, _qərb,
   {{0x1db2016f,0x2fdf81c5,0x38780168,0xdb0982d0}},	//   _जागत, _zaug_, _kurr_, zgeç,
   {{0x27e00fcf,0x44d802d6,0x2d9c80f1,0x20048fd0}},	//   _bain_, _nō_, mave_, _komi_,
   {{0xf1c6000d,0x2d9c8fd1,0x7c3b0c18,0x6286012b}},	//   र्तन, lave_, čurk, _otko,
   {{0x27e00fd2,0x799a8c53,0xeafa81f9,0x2c0b8fd3}},	//   _dain_, patw, _جرات_, _جعلی_,
   {{0x2d9c8fd4,0xa3b68fd5,0xa3c9001b,0x6aad00e5}},	//   nave_, _जाँ_, ल्न_, vraf,
   {{0x69ca81c0,0x44390fd6,0xf8da80c2,0x61fc8338}},	//   _ibfe, _pjs_, _बनिय, örlu,
   {{0x20048fd7,0x6aad0fd8,0x25ad0fd9,0xa3b68816}},	//   _nomi_, traf, şel_, जलि_,
   {{0x6b8d01f1,0x9c7c8fda,0x81e000c8,0x2fdf81e9}},	// [710] rbag, _brčk, থান_, _raug_,
   {{0xd9990f99,0x6aad0fdb,0x98da8770,0xf8da809a}},	//   انات_, rraf, _बनाए, _बनाय,
   {{0x20048915,0x2fdf8282,0x29070162,0x2d9c8fdc}},	//   _bomi_, _paug_, âna_, dave_,
   {{0x6aad002e,0x2ef58fdd,0x628981e0,0x2fdf8069}},	//   praf, йзер, ypeo, _qaug_,
   {{0x20048fde,0x7c2d0fdf,0x6d5a8fe0,0xadc40032}},	//   _domi_, miar, _azta, _atẹw,
   {{0x9c7c803b,0x929d809a,0x2d9c8fe1,0x41c600c2}},	//   _grčk, syłk, gave_, र्दस,
   {{0x2fdf81c5,0x20048fe2,0x6b9b8fe3,0x610a829a}},	//   _taug_, _fomi_, taug, nəld,
   {{0xf77f817b,0x2d828019,0xf5380039,0x3c3a81a9}},	//   _üç_, _őket_, ינוי_, tīva_,
   {{0xa3c90fe4,0x6d5a8102,0x6b9b8fe5,0x3f158fe6}},	//   ल्य_, _ezta, raug, _удас,
   {{0x6b9b81e2,0xe1f98fe7,0x7528009a,0x27e00fe8}},	//   saug, уго_, ździ, _sain_,
   {{0x7c2d0102,0xd24e803d,0x7c360fe9,0x799883ec}},	//   kiar, رچه_, ynyr, _devw,
   {{0xa3c90fea,0x60060feb,0x9f0601a8,0xa3e60035}},	//   ल्म_, _cómp, موجو, _यों_,
   {{0x27e00364,0x91e58381,0x7c2d0fec,0x201e01e2}},	//   _vain_, _голе, diar, ėti_,
   {{0x442d8fed,0xdce38182,0x26c20fee,0x44d80176}},	//   lie_, lanı, rtko_, _pō_,
   {{0x26c20063,0x27e00fef,0x94790ff0,0x60c10106}},	//   stko_, _tain_, исту_, _älmh,
   {{0x442d8ff1,0x2d9c8ff2,0x7c2d0ff3,0xdce383bf}},	//   nie_, zave_, giar, nanı,
   {{0x38a38459,0x63a68ff4,0x7c360084,0xb3440085}},	// [720] lır_, ókni, rnyr, _keçə,
   {{0x442d882e,0x81ab00c8,0x9c828353,0x20048ff5}},	//   hie_, ক্স_, ščin, _somi_,
   {{0x442d8ff6,0x999a893f,0x8c460ff7,0x38a38182}},	//   kie_, רבעט, _гене, nır_,
   {{0x442d8ff8,0x2d9a0ff9,0x68fc8106,0x6e2e0ffa}},	//   jie_, _hepe_, ärdi, libb,
   {{0x442d8ffb,0x2d9c8ffc,0x3ea20ffd,0x9c7c80cd}},	//   die_, tave_, nskt_, _trčk,
   {{0x6b828081,0x6e2e04b7,0x38a382d0,0x27e08ffe}},	//   _sfog, nibb, kır_, žin_,
   {{0x2d9c8fff,0xdcfc00eb,0x557700be,0x6ce68196}},	//   rave_, darī, זעצן_, сіле,
   {{0x442d9000,0x38a38b06,0x2d9c9001,0x6d5a801b}},	//   gie_, dır_, save_, _vzta,
   {{0xa3bb01b6,0x3866816d,0x34d40054,0x2d9c9002}},	//   _घास_, mmor_, दबुद, pave_,
   {{0x7c2d1003,0x442d9004,0x3860009f,0x38a382d0}},	//   ziar, aie_, _ahir_, fır_,
   {{0x442d9005,0x19589006,0x660509f8,0x2bca835f}},	//   bie_, раны_, _rohk, _було_,
   {{0x442d9007,0x28a99008,0x38601009,0x39570039}},	//   cie_, _किरि, _chir_, משים_,
   {{0x7c2d100a,0x291e900b,0x799e100c,0x6e2e0037}},	//   viar, szta_, kapw, fibb,
   {{0xdb0d03a7,0x6e2e038a,0xe84c01d0,0x38a38380}},	//   lgaç, gibb, ětší, bır_,
   {{0x7c2d100d,0x2d9a02f7,0xe65400e8,0x38600c41}},	//   tiar, _depe_, ївсь, _fhir_,
   {{0x388101e2,0x69c88a53,0x2d9a026b,0x38600362}},	//   _nėra_, lfde, _eepe_, _ghir_,
   {{0x7c2d011e,0xa3b68665,0x99990aac,0x24580009}},	// [730] riar, _जाई_, икат_, сать_,
   {{0x442d900e,0x6fb50416,0x7c2d100f,0xa3bb0e5b}},	//   zie_, _امکا, siar, _घाव_,
   {{0xdce39010,0xa25b0038,0x9f520242,0x3c590087}},	//   yanı, _spôs, _anyè_, _винэ_,
   {{0x9f558468,0x9c7c9011,0x28ba03b7,0x64498118}},	//   овеч, _grči, _उमरि, xoei,
   {{0x442d9012,0x38a38059,0xdce388c5,0x81ab00ab}},	//   vie_, zır_, vanı, ক্ষ_,
   {{0x442d9013,0x7aed805c,0xd9fd05e8,0x38a39014}},	//   wie_, _šato, _उचित_, yır_,
   {{0x442d9015,0xdce387c0,0xed599016,0x69d7002a}},	//   tie_, tanı, шок_, mexe,
   {{0x7cca8201,0x52a99017,0x3ea2039c,0xe0d200be}},	//   _qəra, авим_, yskt_, _קײן_,
   {{0x28e10076,0x2d83009a,0xdce38059,0x442b1018}},	//   फिकि, kcje_, ranı, _mmc_,
   {{0x442d9019,0x38a385c5,0x88c98009,0x38600079}},	//   sie_, tır_, алов_, _shir_,
   {{0x442d901a,0xdce38380,0x61e50014,0x999e81d0}},	//   pie_, panı, idhl, nitř_,
   {{0xa3b6901b,0xb901901c,0xa2b2835a,0x38a38059}},	//   _जाए_, _नई_, _आमच्, rır_,
   {{0xf77207bd,0x38a38214,0xe29981a1,0xb7da81c6}},	//   باد_, sır_, _тал_, בקרי,
   {{0x63bb901d,0x5fdc101e,0x7ae9901f,0x3ea21020}},	//   lgun, _बसवल, mvet, rskt_,
   {{0xc5f28039,0xfce31021,0xf3870133,0x7c3a1022}},	//   ודם_, моро, _ụtọa, étro,
   {{0x63bb9023,0x3ead1024,0x26df81a1,0x69de9025}},	//   ngun, šeta_, _osuo_, _óper,
   {{0x61e39026,0x9c7c817f,0xa2061027,0x81dc80ab}},	// [740] _kanl, _isče, опад, ডার_,
   {{0xe1f71028,0x63bb8458,0xe24601a8,0x915f1029}},	//   огу_, hgun, آخري, _sắp_,
   {{0x6026902a,0x9c7c8968,0x7ae9902b,0x7c2b821e}},	//   оджа, _trči, hvet, _omgr,
   {{0xb8f20d38,0x9c7c803e,0x61e3902c,0x2eed902d}},	//   _वह_, _urči, _lanl, _bref_,
   {{0x38668bbd,0xaad8805e,0x4e0e102e,0x6d418106}},	//   rmor_, _बैंक, _हवाई_, _axla,
   {{0x6ce589a3,0xb0a98540,0x7ae9816d,0x0caa8318}},	//   किंग_, _किंग, dvet, атии_,
   {{0x90c3102f,0xa3d686a7,0x7bc99030,0x69ce1031}},	//   _обре, ाजल_, ffeu, _ibbe,
   {{0x61e380c9,0x2fc001c5,0x63bb9032,0x8aa69033}},	//   _aanl, _ncig_, ggun, ород,
   {{0x8af78201,0xada68187,0x61e39034,0x7ae98061}},	//   _şərh, _маал, _banl, gvet,
   {{0x61e39035,0x32188063,0x7ae48267,0x799c0326}},	//   _canl, óry_, _šits, _jerw,
   {{0x61e39036,0x63bb8102,0x2ee01037,0x3207808e}},	//   _danl, bgun, _asif_, _dony_,
   {{0x68e3013c,0x27e69038,0x69ca1039,0x61ed8300}},	//   ændi, ndon_, स्ती, _ɗali,
   {{0x91e68a94,0xb90183bb,0x26c6903a,0x09e68293}},	//   _моде, _नै_, ntoo_, _модн,
   {{0xd3448077,0x63a0903b,0x32078118,0x61e38114}},	//   _ویژه_, lamn, _gony_, _ganl,
   {{0x81c200c8,0x70c90074,0x80c90035,0x27e68122}},	//   ্যা_, _रहेल, _रहें, kdon_,
   {{0x27e48687,0xe3ac80ab,0xb8670fd3,0x3cdd86ae}},	//   _namn_, ক্রব, _باتو, _कईसे_,
   {{0xd7630bca,0x799c103c,0xa3cc8aed,0x69d701df}},	// [750] _تنظی, _berw, श्य_, texe,
   {{0x3eb9103d,0xaaac103e,0x63a0903f,0x63bb9040}},	//   must_, _चिरक, hamn, zgun,
   {{0x21270142,0x69d71041,0x3eb90074,0x7ae98019}},	//   ành_, rexe, lust_, zvet,
   {{0x69d71042,0x69ce1043,0x60c50428,0x6b8400e5}},	//   sexe, _ebbe, rthm, ccig,
   {{0xd6db823a,0x799c1044,0x69d71045,0xfd4c80ff}},	//   рте_, _ferw, pexe, _triề,
   {{0xc27a0039,0x66088079,0x62728035,0x7ae982d0}},	//   _לרשי, _codk, _słon, vvet,
   {{0x1c0f09f2,0x32078176,0x91fc80eb,0x27e49046}},	//   _सवाल_, _rony_, rmāl, _famn_,
   {{0xd7c9803d,0x61e39047,0x3eb90074,0xa80601df}},	//   _دوره_, _sanl, kust_, _mañá,
   {{0x63bb9048,0x61e39049,0xeab181a8,0x7ae98162}},	//   rgun, _panl, رعة_, uvet,
   {{0x2ea806b7,0x6608904a,0x3eb9103d,0xa925904b}},	//   _कटौत, _godk, dust_, здол,
   {{0x7ae9904c,0x61e3904d,0xf1b200be,0xa3bb853d}},	//   svet, _vanl, עסט_, _ناشر_,
   {{0xb4e78540,0x63a0904e,0x22808247,0x5437853d}},	//   यटी_, camn, _fòk_, _برطر,
   {{0xa3e6104f,0x61e39050,0xe8039051,0xe7371052}},	//   _योग_, _tanl, _रचना_, зея_,
   {{0xa3c91053,0x321e9054,0x3e6086c0,0x59c29055}},	//   ल्स_, chty_, pòte_, _शायर,
   {{0xed5a1056,0x27e69057,0x1828003d,0xdbd9007b}},	//   сов_, ydon_, _وقتی_, tæðu,
   {{0x799c0d38,0x7c3b9058,0xaca3819d,0x6b9d1059}},	//   _serw, nnur, _anịm, _cesg,
   {{0x3cdd8063,0x799c105a,0xc86500f7,0xdbd9007b}},	// [760] _कैसे_, _perw, _تطوي, ræðu,
   {{0x6aa40057,0x6b84105b,0x09e3105c,0xe4760012}},	//   rsif, scig, ноун, _нумэ,
   {{0x799c105d,0x6b9d002a,0xa8060118,0x1b0400ab}},	//   _verw, _fesg, _gañá, _রেখে_,
   {{0x6281105e,0xdcf5009a,0x7985105f,0x799c1060}},	//   _člov, jczę, achw, _werw,
   {{0x44321061,0x799c1062,0x66088f66,0x27e69063}},	//   miy_, _terw, _podk, rdon_,
   {{0x26c68009,0xd49a8abe,0x98a61064,0x27e485ee}},	//   rtoo_, бри_, _ниге, _wamn_,
   {{0x39a68013,0x26c68079,0x628b8428,0xa3c9064a}},	//   hísí_, stoo_, _atgo, ल्व_,
   {{0xafe39065,0x44201066,0xb60380eb,0x320a008e}},	//   _посл, nhi_, īšan, _hoby_,
   {{0x27f7800d,0x44201067,0x2bce016f,0xa0678a4c}},	//   šení_, ihi_, ह्या, _хата_,
   {{0x59cf016f,0xe8e000ff,0x3eb90074,0x7de580f7}},	//   स्पर, _nhịp_, vust_, _يسلم,
   {{0x69bd8eed,0x44201068,0x69c10f1b,0x3eb900f3}},	//   _शारी, khi_, र्टी, wust_,
   {{0x44201069,0x3eb90006,0x29028289,0x443202ed}},	//   jhi_, tust_, ćka_, jiy_,
   {{0x4420106a,0x2d9e906b,0x6b9d106c,0x79850428}},	//   dhi_, _kete_, _resg, ychw,
   {{0x99ce00c8,0x2d9e906d,0x2b09801b,0x6b9d016a}},	//   রযুক, _jete_, िहरु_, _sesg,
   {{0x2d9e8205,0x61f8837a,0x3eb90074,0x248c8037}},	//   _mete_, _invl, sust_, _jtdm_,
   {{0x4420106e,0x69da906f,0x3eb91070,0x5c741071}},	//   ghi_, lete, pust_, елст,
   {{0x3eb91072,0x3a751073,0x78ba9074,0x320a1075}},	// [770] qust_, длар, lutv, _boby_,
   {{0x44200079,0xdce70214,0xa3cc8105,0xdcf50035}},	//   ahi_, sajı, श्त_, zczę,
   {{0x02d983bb,0x77610201,0x79851076,0x320a03c1}},	//   _भन्न, əlxa, rchw, _doby_,
   {{0x44201077,0x69da9078,0x798502af,0x98c582a5}},	//   chi_, hete, schw, žući_,
   {{0xa2a700cf,0x69da9079,0x7ae2907a,0x2d9e8102}},	//   _चिट्, kete, _nsot, _bete_,
   {{0x2d9e8052,0x69da907b,0x7bcd0bda,0x8afa01c6}},	//   _cete_, jete, lfau, _והשי,
   {{0x2d9e8eef,0xd0d40698,0x20f08904,0xe81e06a7}},	//   _dete_, _поръ, nđić_, _पतला_,
   {{0x3ea9025d,0xfcaa093f,0x61e70061,0xdb1b907c}},	//   _ovat_, קיפּ, _hajl, lgué,
   {{0x2d9e907d,0x61e70088,0x7aed107e,0x81e000ab}},	//   _fete_, _kajl, nvat, থার_,
   {{0xb33b07d9,0xdb1b907f,0x69da9080,0x44201081}},	//   _geçe, ngué, gete, zhi_,
   {{0x7aed02a5,0x7ae29082,0x61e71083,0x44201084}},	//   hvat, _esot, _majl, yhi_,
   {{0x44201085,0x7aed00d2,0x61e701c0,0xead2077f}},	//   xhi_, kvat, _lajl, fẹ́_,
   {{0x44321086,0x44201087,0x764e1088,0x7aed0bcf}},	//   viy_, vhi_, toby, jvat,
   {{0x61e71089,0x7a200019,0x59cf04c5,0xf1cf108a}},	//   _najl, _köte, स्मर, स्मन,
   {{0x4420108b,0x443202d6,0x442f8079,0x320a00e5}},	//   thi_, tiy_, _kmg_, _roby_,
   {{0x7a20016d,0x68fc908c,0xc1728039,0x4420010b}},	//   _möte, årde, _בחו_, uhi_,
   {{0xfaa3108d,0x4420108e,0x442f908f,0x2eff0192}},	// [780] като, rhi_, _mmg_, äuft_,
   {{0x44201090,0xe9d71091,0x601f0168,0x7cca829a}},	//   shi_, мку_, _vëme, _sərm,
   {{0xb4661092,0x2d9e9093,0x4420029b,0x25e71094}},	//   _окол, _rete_, phi_, _छोटी_,
   {{0x69da9095,0x9f401096,0x6d40017b,0xb33b0214}},	//   zete, _unió_, şmas, _seçe,
   {{0x61e71097,0xa3c8809a,0x63a41098,0xc7a384bd}},	//   _fajl, _लॉग_, main, тичк,
   {{0x3f9f9099,0x3f86907c,0x7a200106,0xd04c8085}},	//   _eeuu_, scou_, _böte, _əhəm,
   {{0x2d9e80f1,0x69da909a,0x28dd909b,0xf8d20075}},	//   _vete_, vete, _फैलि, _सहिय,
   {{0x2284109c,0x69da909d,0x2d9e909e,0x6b9600e8}},	//   _kök_, wete, _wete_, nbyg,
   {{0x2d9e909f,0x69c38580,0x427490a0,0xe45701c6}},	//   _tete_, _bcne, нгис, ויקט_,
   {{0x61e88713,0xf8d210a1,0x63a410a2,0xdb150036}},	//   uddl, _सहाय, hain, ébéc,
   {{0xd1308307,0x63a410a3,0x291890a4,0x69da90a5}},	//   امج_, kain, ára_, rete,
   {{0xe8df0028,0x7aed026f,0x63a410a6,0x7ae290a7}},	//   _cuộc_, yvat, jain, _tsot,
   {{0x63a410a8,0xd6d9809a,0x6b9610a9,0x78ba90aa}},	//   dain, _były_, dbyg, sutv,
   {{0xead210ab,0x7aed10ac,0x69da90ad,0x2ef20a53}},	//   rẹ́_, vvat, qete, _dryf_,
   {{0x61e70267,0x1bd50098,0xdb008511,0x2edb90a1}},	//   _rajl, новя, damé, _यन्त,
   {{0x63a40219,0x69ca8b6f,0x61e7025b,0x20f08088}},	//   gain, त्री, _sajl, rđić_,
   {{0xeabc80ab,0x61e70282,0x2bd08072,0x2ef210ae}},	// [790] _অনুম, _pajl, थ्या, _gryf_,
   {{0x6d4510af,0x27e910b0,0xdb0090b1,0x228410b2}},	//   _txha, _haan_, ramè, _dök_,
   {{0x63a410b3,0x7aed037b,0x588401bb,0xd13100f7}},	//   bain, svat, выча, دما_,
   {{0x201910b4,0x3cf48743,0x27e910b5,0x63a410b6}},	//   nksi_, ्मने_, _jaan_, cain,
   {{0x61e710b7,0x0f35804e,0x27e902a1,0x20190198}},	//   _tajl, رکرد, _maan_, iksi_,
   {{0x780c016f,0x27e910b8,0x68e3006a,0x64428198}},	//   _हक्क_, _laan_, ænds, _ajoi,
   {{0xf41f0106,0x25a110b9,0xafdb0163,0x00000000}},	//   _klä_, _mehl_, sløy, --,
   {{0x7cca8085,0x3eb28084,0x27e910ba,0x2d878174}},	//   _mərh, šyta_, _naan_, scne_,
   {{0x7c3a0073,0x9f9d007b,0x316300c3,0xf6b58019}},	//   étri, væði_, _hzjz_, _سماج,
   {{0x63a410bb,0xfdf38424,0x20190009,0x569490bc}},	//   zain, _आफिस_, eksi_, _рафт,
   {{0x6e350052,0x27e910bd,0x09e18264,0x200d8a53}},	//   dizb, _baan_, বালা, _koei_,
   {{0xcdc90051,0x80a0809a,0x59cf10be,0x2b408968}},	//   _לך_, _खबरे, स्तर, _žice_,
   {{0xef1710bf,0x63a410c0,0x27e910c1,0xcc3a80be}},	//   емя_, vain, _daan_, _צענט,
   {{0x63a410c2,0xfce60a13,0x645b90c3,0xc69283de}},	//   wain, ного, llui, ראם_,
   {{0x443f90c4,0x228404b8,0xa3cc90c5,0xa50a0d5f}},	//   onu_, _sök_, श्व_, чева_,
   {{0x443f90c6,0x27e910c7,0x6b898057,0x7dd38457}},	//   nnu_, _gaan_, nceg, lısı,
   {{0x34dc90c8,0x6b9610c9,0x7ae9016b,0x41b610ca}},	// [7a0] _मन्द, rbyg, _šetr, есет,
   {{0x69c190cb,0x6b9610cc,0x80c900ab,0x8e9701c6}},	//   ngle, sbyg, রবন্, _רדיו_,
   {{0x2d9810cd,0x63a410ce,0xf1c290cf,0x69c80214}},	//   mbre_, pain, _शासन, _ödem,
   {{0xa2b210d0,0x443f883d,0x7afb0bcf,0xcfb20264}},	//   ेंद्, jnu_, _šute, ট্রন,
   {{0x443f90d1,0xc87981cc,0x7cca8085,0xe8df819d}},	//   dnu_, _diş_, _tərk, diọm_,
   {{0x443f90d2,0x69c190d3,0x6aa990d4,0xa3c8864a}},	//   enu_, jgle, dsef, _लॉज_,
   {{0x69c18503,0x443f90d5,0x32430171,0x5fc6016f}},	//   dgle, fnu_, _серг, _वाढल,
   {{0x59c2886a,0x66e690d6,0x6b7b00be,0x25fe816f}},	//   _शाहर, _поба, ּרינ, लाही_,
   {{0xdcea90d7,0xe7d583bf,0x3edf0133,0x27e902d5}},	//   rafı, lığı, _kwụọ_, _raan_,
   {{0x27e910d8,0x69c190d9,0x443f90da,0x9fd000ab}},	//   _saan_, ggle, anu_, িযোগ,
   {{0x7c2410db,0x443f883d,0x27e910dc,0x39588366}},	//   khir, bnu_, _paan_, ærs_,
   {{0x645b90dd,0x69de10de,0x351b8039,0x2d980144}},	//   clui, hepe, _מובנ, ebre_,
   {{0x27e90364,0x69de10df,0x7cca8085,0x81ab0264}},	//   _vaan_, kepe, _sərh, ক্ট_,
   {{0xa3cc83b7,0x27e902a3,0x4992804e,0x63a290e0}},	//   श्र_, _waan_, _حیدر, _heon,
   {{0x644102be,0x63a290e1,0x69de10e2,0x6282810c}},	//   élio, _keon, depe, _huoo,
   {{0xe7d582bb,0x7c2410e3,0x63a290e4,0x61ea90e5}},	//   dığı, ghir, _jeon, _hafl,
   {{0xf1a48b85,0x63a2808e,0x7cca8085,0x61ea8ff4}},	// [7b0] _खजान, _meon, _dəri, _kafl,
   {{0x63a290e6,0xbbdd90e7,0x443f90e8,0x69de10e9}},	//   _leon, _मस्क, znu_, gepe,
   {{0x443f90ea,0x7c2410eb,0x47bc8264,0xb21b0163}},	//   ynu_, bhir, োজনী, _stæs,
   {{0x7c2410ec,0x61ea90ed,0x443f02f9,0x6e9590ee}},	//   chir, _lafl, _ñu_, виду,
   {{0x443f803a,0xdee590ef,0x44248013,0xb4e10054}},	//   vnu_, толи, dhm_, _धनु_,
   {{0x27e9803b,0xe6188163,0x69de10f0,0xed5987b6}},	//   žan_, нді_, cepe, мол_,
   {{0x443f812b,0x6d5a8035,0x7e7a810c,0x645b90f1}},	//   tnu_, _cyta, _ditp, tlui,
   {{0x2ef587eb,0x201f802e,0x7bdf041c,0x386901b9}},	//   _избр, _ului_, nequ, _nhar_,
   {{0x6b89807d,0x63a290f2,0x645b90f3,0x045680f7}},	//   rceg, _deon, rlui, خلية_,
   {{0x443f82a5,0x645b90f4,0x6aa990f5,0xd24e80a0}},	//   snu_, slui, rsef, يني_,
   {{0x69c190f6,0xd945828b,0xf1c6086a,0x25fe90f7}},	//   rgle, тени, र्टन, लारी_,
   {{0xe73a10f8,0x68fc8106,0x69c190f9,0xdb1b8333}},	//   дем_, årda, sgle, lguí,
   {{0x69c702fd,0x26160074,0x7dd3807e,0x69de10fa}},	//   _ocje, _नकदी_, pısı, yepe,
   {{0xdb1b8228,0xdd92003f,0x628003c9,0x61ea90fb}},	//   nguí, شور_, _émoi, _gafl,
   {{0xed570785,0xada310fc,0x7c2410fd,0x63a290fe}},	//   вор_, расл, thir, _yeon,
   {{0x1c4310ff,0x63a283a8,0x38691100,0x60d69101}},	//   ансм, _xeon, _ghar_, _יוצא_,
   {{0xb33b0073,0xeab10065,0x7c240c0b,0x248601d6}},	// [7c0] _peça, یعے_, rhir, _čomu_,
   {{0x7c241102,0xb21b1103,0xceb9000d,0x68f5026f}},	//   shir, _stær, áře_, _brzd,
   {{0x291c0ed7,0x69de1104,0xb33b00f1,0x7bdf1105}},	//   áva_, repe, _veça, bequ,
   {{0x6e219106,0x7bc6026c,0xf1c61107,0x7ae602c4}},	//   _allb, _ucku, र्जन, _tskt,
   {{0x44220459,0x63a2826c,0xdfcf80f7,0x3ead9108}},	//   _ilk_, _reon, تين_, _cvet_,
   {{0x6d5a8063,0x93f60201,0xaa461109,0x4a750009}},	//   _pyta, _şəhə, _регл, _быст,
   {{0x63a2910a,0xa3c9000c,0x3ead8214,0x98a3110b}},	//   _peon, ल्क_, _evet_, _висе,
   {{0x61ea831d,0x7bc4110c,0xa78580f7,0x6d5a910d}},	//   _safl, ngiu, _مشكو, _vyta,
   {{0x7c23002e,0x59cf000c,0xdee3910e,0x7ae40197}},	//   _înre, स्वर, _коти, nwit,
   {{0xaca401bc,0x610a8085,0x7e7a910f,0x63a28144}},	//   _ahọt, səlm, _uitp, _weon,
   {{0x859b82f6,0x9f4e026f,0x3ea01110,0x850688ca}},	//   _חשבו, čným_, _awit_, _جوان,
   {{0xc9530051,0x28c48540,0xaca40135,0x7ae41111}},	//   ימת_, लंबि, _chọt, kwit,
   {{0xd5c98074,0x05c98a74,0x7c229112,0x61ea9113}},	//   _रामज, _रामब, _ilor, _tafl,
   {{0xb8f480f7,0x6e940009,0x44221114,0x70d206a7}},	//   _مكتب, риру, _alk_, _सहूल,
   {{0x62728063,0x3869008c,0x7bdf1115,0x1dd206bf}},	//   _słow, _thar_, tequ, द्धत,
   {{0xd10f83b7,0x7bc40098,0xaca40135,0x41c6052a}},	//   ाहरण_, ggiu, _ghọt, र्घस,
   {{0x24580364,0xdb1d06c4,0x0cbf83b7,0x41cf8743}},	// [7d0] тать_, _absò, _एम्म, त्वस,
   {{0x7c229116,0x200b0503,0x4422038e,0xf7f48077}},	//   _llor, ljci_, _elk_, یسند,
   {{0x3ead9117,0x0cbd80c8,0x7c2290ab,0xe01e8105}},	//   _svet_, _আন্ত, _olor, पसंद_,
   {{0xa2c30540,0x76551118,0x787a801b,0x7ae41119}},	//   िंद्, lozy, _důvo, bwit,
   {{0xa3cc00d4,0x539a0039,0x3c3a80eb,0x03d61101}},	//   _शॉट_, _רישו, hīvs_, _גורם_,
   {{0x7c22911a,0x69c7111b,0x5187111c,0x6b8d111d}},	//   _alor, _ucje, _шума, lcag,
   {{0x6aad111e,0xb4b1009a,0x7c22911f,0x81cc0264}},	//   lsaf, _ऑटो_, _blor, _শোক_,
   {{0x20f30a20,0x30da00be,0x2fc901c0,0x69c51120}},	//   _ići_, _אַמע, _ncag_, lghe,
   {{0x2bd51121,0x32111122,0x2d8101bc,0x0a398190}},	//   ड्या, _kozy_, _oghe_, ечны_,
   {{0x2d810028,0x20f31123,0x7c229124,0xb33b0036}},	//   _nghe_, _kći_, _elor, _leço,
   {{0xe4cb9125,0x07a6035f,0x69c50083,0x1acf00ab}},	//   _زبان_, ланн, ighe, রিয়া,
   {{0x30da00be,0x27ed9126,0x7643808e,0xf3f081a8}},	//   ײַטע, _jaen_, lnny, _وأن_,
   {{0x25a59127,0x27ed9128,0x63a99129,0x9f8a8074}},	//   _kell_, _maen_, maen, _tööd_,
   {{0x27ed912a,0x2aba8039,0x7c22912b,0x63a9912c}},	//   _laen_, _נמצא, _zlor, laen,
   {{0x27ff9010,0x03e680c8,0xdcee080a,0x7643912d}},	//   _onun_, কারী_, tabı, inny,
   {{0x6b8d112e,0x61e1912f,0xf1cf9130,0x63a99131}},	//   gcag, lell, त्रन, naen,
   {{0xab661132,0xe1fa1133,0x764380dd,0x6826016a}},	// [7e0] увал, нга_, knny, _códe,
   {{0x55e61134,0x25a58698,0xdcee080a,0x787a801b}},	//   _сооб, _nell_, sabı, _půvo,
   {{0x7ae41135,0x61e18081,0x610a8085,0x20120041}},	//   swit, iell, vəlk, _koyi_,
   {{0x61e19136,0x6b8d1137,0xe29a1138,0x27ed9139}},	//   hell, ccag, _пам_, _caen_,
   {{0x61e1913a,0xdd92826a,0x6456113b,0x7e7e113c}},	//   kell, موش_, moyi, _kipp,
   {{0x69d3913d,0x7e7e04b7,0xc1e7019f,0x61e1913e}},	//   _बॉली, _jipp, _مکمل_, jell,
   {{0x61e1913f,0x25a59140,0x62861141,0x63a61142}},	//   dell, _dell_, _huko, _kekn,
   {{0x61ee1143,0x62861144,0xe4f70996,0x76438867}},	//   _habl, _kuko, ुमति_, anny,
   {{0x61ee1145,0x61e19146,0x7c2280f1,0xa3c9000c}},	//   _kabl, fell, _vlor, ल्ट_,
   {{0x628601d3,0x61e19147,0x61ee07df,0xddc89148}},	//   _muko, gell, _jabl, _hidž,
   {{0x5bc68bbe,0x61ee1149,0x64440009,0x63a9820d}},	//   _مقال, _mabl, knii, baen,
   {{0x6456114a,0x0eeb0009,0x61ee114b,0x26c2114c}},	//   joyi, ньги_, _labl, fuko_,
   {{0xcc57810f,0xb33b0036,0xddc88b80,0xe2968073}},	//   _גבאי_, _reço, _midž, _среќ,
   {{0x27ed114d,0x61e1914e,0x7e7e00e5,0xa2c3114f}},	//   žen_, cell, _cipp, िंस्,
   {{0xf9938039,0x69ca8144,0x62861150,0x63a61151}},	//   _פרק_, _icfe, _auko, _bekn,
   {{0x682607f4,0x62861152,0x60df8065,0x3756082e}},	//   _póde, _buko, őzmé, ọdụ_,
   {{0x5a350e17,0x92590003,0x765a8085,0x76439153}},	// [7f0] анат, ваат_, _okty, ynny,
   {{0x61ee1154,0x27ed81df,0x321e809a,0x6b8d1155}},	//   _cabl, _saen_, nkty_, scag,
   {{0xa3d51156,0xa3e58105,0x69c51157,0x6aad1158}},	//   _конч, _फसल_, rghe, ssaf,
   {{0x61e19159,0x765a915a,0x63a6115b,0x6272809a}},	//   zell, _akty, _gekn, _złot,
   {{0x69d8915c,0x61ee115d,0xddc881e2,0x62860578}},	//   _obve, _fabl, _didž, _guko,
   {{0x4429115e,0xf770915f,0x64599160,0x61e18bf9}},	//   lha_, سان_, _skwi, xell,
   {{0x62861161,0x6b9b8609,0x20f3005c,0x61e19162}},	//   _zuko, tbug, _ući_, vell,
   {{0x442907e1,0x62861163,0x25a58051,0x61e19164}},	//   nha_, _yuko, _well_, well,
   {{0x61e19165,0x62800036,0xcb1200be,0x25a58039}},	//   tell, _émot, ַלט_, _tell_,
   {{0x63a98573,0x60c1861c,0x6abb9166,0x26c21167}},	//   saen, tulm, rruf, vuko_,
   {{0x5d849168,0x645600a4,0xc5fa80be,0x44291169}},	//   _المل, yoyi, _שפעט, kha_,
   {{0x61e1916a,0x4375916b,0x26c200ad,0x60c1817b}},	//   sell, _култ, tuko_, rulm,
   {{0x4429116c,0x60c1916d,0x8c1a8039,0xe7d7916e}},	//   dha_, sulm, _שוני, ण्यप,
   {{0x7c29916f,0x51879170,0x26c21171,0xc9878389}},	//   lher, _суда, ruko_, _суди,
   {{0xed5a1172,0x64a60912,0xe8168076,0x26c21173}},	//   тов_, раба, _थकला_, suko_,
   {{0x44291174,0x1e86013a,0x20000974,0x6286005c}},	//   gha_, _клим, _unii_, _puko,

   {{0x7e7e1175,0x64561176,0x6272809a,0x6d5e009a}},	// [800] _tipp, royi, _głos, _wypa,
   {{0x6286003a,0xb33b0214,0x6d4100f7,0xc6930039}},	//   _vuko, _geçm, úlac, _ואז_,
   {{0x44291177,0x55bb0039,0x61ee007a,0x7c299178}},	//   bha_, _במיו, _vabl, kher,
   {{0x44291179,0x386d82be,0x6286117a,0xfa8880ff}},	//   cha_, _cher_, _tuko, _lừa_,
   {{0x4420117b,0x66f4917c,0x628600e4,0x386d917d}},	//   mki_, сплу, _uuko, _dher_,
   {{0x61ee0362,0x40960785,0x386d82af,0x9c7c8140}},	//   _uabl, _врат, _eher_, _isči,
   {{0xac26917e,0xdb008789,0x29070106,0xd943117f}},	//   ифик, damá, änat_, _дери,
   {{0x20e80059,0x7c299180,0x6aa28247,0x7c3b9181}},	//   _işi_, gher, _pwof, giur,
   {{0x787f00eb,0xf5ea9182,0x5a348081,0xdb0d008b}},	//   _būvn, _имал_, йнит, ngað,
   {{0x44201183,0x7a248362,0x387f8cdb,0x24780176}},	//   hki_, _bòta, _ziur_, _dōmi_,
   {{0x44201184,0x6e3c1185,0x7c298234,0xfa8880ff}},	//   kki_, dirb, bher, _dừa_,
   {{0x7c299186,0xb33b080a,0x44291187,0x44201188}},	//   cher, _seçm, xha_, jki_,
   {{0x22949189,0x4426918a,0x09e180c8,0x4420118b}},	//   _التس, _ilo_, বাজা, dki_,
   {{0x4420118c,0x4429022b,0x44268069,0xaadb83c8}},	//   eki_, wha_, _hlo_, _סחור,
   {{0x4429118d,0x4426918e,0xda05000f,0x6272809a}},	//   tha_, _klo_, रासत_, _włos,
   {{0xe97b8039,0xf21c8105,0x5bb80009,0x717b8039}},	//   _בנוש, _पकड़_, ился_, _בנוס,
   {{0x4429118f,0xb06602f1,0xf7731190,0x32d08129}},	// [810] rha_, svää, _باغ_, này_,
   {{0x44291191,0x44201192,0x44269193,0x69c8904a}},	//   sha_, aki_, _llo_, ngde,
   {{0xda781194,0x4f58026a,0x44201195,0x6f1d0176}},	//   рят_, _مجید_, bki_, lysc,
   {{0xa3ce023c,0xe8df0104,0xd1268117,0x44268091}},	//   _राय_, _quốc_, _ہم_, _nlo_,
   {{0x63ad1196,0xd9f8815c,0x161b016f,0x44390581}},	//   maan, ्ञात_, _नकार_, _ims_,
   {{0x63ad1197,0x6da28073,0x7c2981c6,0xe5a29198}},	//   laan, пиша, wher, пиши,
   {{0xa3ce1199,0x4426807a,0x7c29919a,0x2907119b}},	//   _राम_, _blo_, ther, ånad_,
   {{0x63ad119c,0x4369919d,0x4426919e,0x1be988ed}},	//   naan, лайн_, _clo_, удии_,
   {{0x7c3b919f,0x7c2991a0,0x44268247,0x44390558}},	//   riur, rher, _dlo_, _mms_,
   {{0x442691a1,0x442011a2,0x7c2991a3,0x63ad11a4}},	//   _elo_, zki_, sher, haan,
   {{0x63ad11a5,0x442691a6,0xfa888028,0x60c500dd}},	//   kaan, _flo_, _vừa_, nuhm,
   {{0x442691a7,0x5c7591a8,0xdb0091a9,0x7bd98314}},	//   _glo_, _улет, samá, _ubwu,
   {{0x44200805,0x63ad11aa,0xceb283de,0x28c9064a}},	//   vki_, daan, ּיל_, ांडि,
   {{0x44200063,0xe29c80be,0x7d1c03ed,0x519581a8}},	//   wki_, _ישׂר, tyrs, _الغذ,
   {{0x442011ab,0x823491ac,0x1d19035f,0x63ad11ad}},	//   tki_, _برنا, ають_, faan,
   {{0x63ad11ae,0x61b7816f,0x3eb28110,0x7bc991af}},	//   gaan, _आयुष, šyti_, ngeu,
   {{0x442011b0,0xe9da11b1,0x7ae991b2,0xd46711b3}},	// [820] rki_, лка_, nwet, сите_,
   {{0x645d11b4,0x7afd8198,0x27f201b4,0xdb0d01fa}},	//   _eksi, ästy, _hayn_, rgað,
   {{0xf77f03a7,0x63ad11b5,0x5a3a80be,0x442011b6}},	//   meça_, baan, נגעה, pki_,
   {{0x7ae991b7,0x63ad11b8,0xa967047f,0xf77f02df}},	//   kwet, caan, щиха_, leça_,
   {{0x2907016d,0x628f91b9,0x9ad38870,0x61e511ba}},	//   änar_, ícol, _dịkw, behl,
   {{0x442691bb,0x60c50359,0xd0420085,0x7cca8085}},	//   _slo_, buhm, rtlə, _bərp,
   {{0x645d0364,0x261991bc,0xd0420085,0xd4978110}},	//   _yksi, _बकरी_, stlə, бры_,
   {{0x290500ce,0x1e86845e,0x786a91bd,0x9c7c80c3}},	//   _šlag_, _глам, býva, _opče,
   {{0x59cf11be,0x09ac80ab,0x6a700106,0x69c811bf}},	//   स्कर, _খাবা, räff, _ödes,
   {{0x98a787d9,0xb33b0201,0x6d4003bf,0x23ad0084}},	//   _aynı_, _seçk, şmay, mųjų_,
   {{0x69dc11c0,0x63ad11c1,0x4426812b,0x69ce0176}},	//   _mbre, yaan, _tlo_, _mcbe,
   {{0x63ad02c1,0x442691c2,0x438680f7,0xbb8680f7}},	//   xaan, _ulo_, _الإق, _الإي,
   {{0x69dc11c3,0xf1a810a1,0x23ad0084,0x291886ae}},	//   _obre, गरान, nųjų_, ärab_,
   {{0x63ad11c4,0x7afd806a,0x44f880ff,0x41c70f3d}},	//   waan, æste, _kĩ_, _लाइस,
   {{0x43960a2c,0x786a83f2,0x2d910035,0xb425866f}},	//   _ọrụ_, zýva, rcze_, łżeń,
   {{0x682604c3,0x25bf11c5,0xa3cc91c6,0x53990198}},	//   _tóda, şul_, श्च_, рвая_,
   {{0x7b6711c7,0xb33b0086,0x63ad11c8,0xf77f0073}},	// [830] стве, _keçi, raan, beça_,
   {{0x63ad11c9,0x9c7c80fe,0x9ad3819d,0x69dc0362}},	//   saan, _isču, _sịkw, _cbre,
   {{0x63ad11ca,0x6826026f,0xf96b0196,0x44390198}},	//   paan, _módn, урай_, _tms_,
   {{0x69dc11cb,0x7c6711cc,0x63ad0079,0x160700d4}},	//   _ebre, _داخل, qaan, शावर_,
   {{0x7c2d11cd,0xa3ce0740,0x60c50a84,0x287c00be}},	//   mhar, _रात_, suhm, אנאמ,
   {{0xae038aed,0x7c2d11ce,0x69d80e88,0x313511cf}},	//   लाइन_, lhar, न्दी, _дегр,
   {{0xac0991d0,0x24098171,0xafdb006a,0x661702f9}},	//   инка_, инки_, rnøj, _moxk,
   {{0x7afd025b,0x7c2d11d1,0x601f020f,0xa4b80039}},	//   _krst, nhar, _fëmi, צלחה_,
   {{0xc7b98019,0x7bc980e7,0x20f78162,0x7afb05f3}},	//   _idő_, rgeu, _săi_, _šutj,
   {{0x394591d2,0x1ddb097d,0xaca311d3,0x7ae991d4}},	//   жног, म्मत, _atọg, rwet,
   {{0xa96991d5,0x7c2d11d6,0x216991d7,0x7bcf11d8}},	//   рина_, khar, рини_, _occu,
   {{0xe8df8028,0x3dc989ab,0xe8e0027d,0x20d191d9}},	//   hiệm_, ɗawa_, _chộp_, rái_,
   {{0x7c2d06df,0x442d8068,0x6d4111da,0xc7d681c6}},	//   dhar, mhe_, úlan, חורי_,
   {{0x443f91db,0xb33b07d9,0x442d8073,0x628b91dc}},	//   liu_, _geçi, lhe_, _iugo,
   {{0xf77f11dd,0x27e686ff,0x7afd11de,0x628391df}},	//   reça_, yeon_, _arst, _iino,
   {{0x443f91e0,0x7c2d11e1,0x644991e2,0x442d8073}},	//   niu_, ghar, nnei, nhe_,
   {{0xda0509a3,0x63ab8019,0x644991e3,0x987b03de}},	// [840] रांत_, _megn, inei, _דאקט,
   {{0x63ab91e4,0x442d8940,0x644991e5,0x628b820c}},	//   _legn, hhe_, hnei, _mugo,
   {{0x7afd11e6,0x7c2d11e7,0x442d91e8,0x443f8110}},	//   _erst, bhar, khe_, kiu_,
   {{0x81e70a49,0x307691e9,0x628391ea,0x68260019}},	//   ভাগ_, цузс, _lino, _módo,
   {{0x442d91eb,0x443f91ec,0x44f88028,0x087700be}},	//   dhe_, diu_, _sĩ_, קענט_,
   {{0x8c1f00c8,0xdcba8098,0x7c240074,0xa0a611ed}},	//   নোদন_, ащи_, lkir, _магд,
   {{0x25ba11ee,0x7a2001ec,0x291c02f1,0x443f91ef}},	//   _mdpl_, _nöti, ävad_, fiu_,
   {{0x09b48a49,0x442d91f0,0xb33b1010,0x443f91f1}},	//   জ্ঞা, ghe_, _seçi, giu_,
   {{0x63ab91f2,0x2d9691f3,0x628b80c3,0x63b90035}},	//   _degn, _дрес, _cugo, ówni,
   {{0x386691f4,0x628b803a,0x291e8110,0xfce691f5}},	//   llor_, _dugo, tyta_, _мозо,
   {{0xf9930051,0x443f91f6,0x69fb010f,0x7c240c56}},	//   ורת_, biu_, בליק, kkir,
   {{0x443f91f7,0x63ab91f8,0x291e91f9,0x628b91fa}},	//   ciu_, _gegn, ryta_, _fugo,
   {{0xe1ef91fb,0xc7b38051,0x38668087,0x628391fc}},	//   رسی_, ובר_, ilor_, _fino,
   {{0x765c11fd,0x7c2d11fe,0x628391ff,0x64409200}},	//   gory, whar, _gino, limi,
   {{0x7c2d1201,0x61e88bbd,0x7c2402a6,0xfe6e0180}},	//   thar, medl, fkir, دگي_,
   {{0x69da8a34,0x62839202,0xdb0080e1,0x38668b67}},	//   lfte, _zino, pamä, jlor_,
   {{0x7c2d1203,0xdceb03bf,0xf77f03a7,0x628b8118}},	// [850] rhar, ınız, meço_, _xugo,
   {{0x7c2d1204,0x61e8831d,0x64409205,0x443f9206}},	//   shar, nedl, himi, ziu_,
   {{0x64409207,0x7c2d1208,0xf8b1004e,0x442480b9}},	//   kimi, phar, عکس_, kkm_,
   {{0xdce50028,0x443f9209,0x6440920a,0x25ac802a}},	//   _nghĩ, xiu_, jimi, _aedl_,
   {{0x63ab920b,0x6605920c,0x443f920d,0x63a206a5}},	//   _regn, зпла, viu_, ñone,
   {{0x63ab8698,0x61e8920e,0x628b920f,0x7aed1210}},	//   _segn, jedl, _rugo, mwat,
   {{0x442d9211,0x443f9212,0x64409213,0x628b9214}},	//   the_, tiu_, fimi, _sugo,
   {{0x61f51215,0x64409216,0x3f891217,0xa2c2001b}},	//   _hazl, gimi, _ngau_, _लिम्,
   {{0x443f9218,0x63ab8125,0x62839219,0x442d84a9}},	//   riu_, _vegn, _pino, rhe_,
   {{0x442d921a,0x443f921b,0x7c24059f,0x61f50748}},	//   she_, siu_, zkir, _jazl,
   {{0x442d921c,0x63ab921d,0x61f5121e,0x6440921f}},	//   phe_, _tegn, _mazl, bimi,
   {{0x64409220,0x7aed0c56,0xe8df082e,0x628b9221}},	//   cimi, kwat, _ahịa_, _tugo,
   {{0x765c1222,0x62839223,0x249a03ac,0xd5d2852a}},	//   tory, _tino, _stpm_, _सामज,
   {{0x682604c3,0xa3ce000f,0x7aed1224,0xe8df01bc}},	//   _tódo, _राह_, dwat, _chịa_,
   {{0x32078035,0x7afb9225,0x7c241226,0x00000000}},	//   _inny_, lvut, tkir, --,
   {{0x5fc6035a,0x765c1227,0xc4830abe,0x7bcd0041}},	//   _वाटल, sory, елск, ggau,
   {{0x7c241228,0x6e461229,0x6fa20670,0x7aed122a}},	// [860] rkir, _неиз, _क्यू, gwat,
   {{0x7c240b0c,0x17570051,0x6440922b,0x2fdf8122}},	//   skir, _מספר_, zimi, _abug_,
   {{0x6440922c,0x2eff8359,0xae1b00be,0x7aed008e}},	//   yimi, _aruf_, _הויכ, awat,
   {{0x442b122d,0x4424001c,0x7aed0c2e,0x61e8922e}},	//   _glc_, _ôm_, bwat, zedl,
   {{0x61f507d9,0x6440922f,0x38669230,0xa2bd83dd}},	//   _fazl, vimi, rlor_, _शिष्,
   {{0xe29701a1,0x63a41231,0x442480ee,0x160386a7}},	//   _хар_, lbin, wkm_, लागर_,
   {{0xf8e00076,0x8fa69232,0x443d9233,0x61e89234}},	//   _नहिय, _наве, _bmw_, vedl,
   {{0x7afb01dd,0x60c89235,0x61e89236,0x329883a7}},	//   _šuti, vudm, wedl, овиќ_,
   {{0x63a41237,0x61f51238,0x6ab61239,0x06e40264}},	//   ibin, _yazl, nsyf, মিডি,
   {{0x27e003c3,0x80c0923a,0x3f808110,0xa2bd90be}},	//   _abin_, _विदे, žius_, _शिर्,
   {{0xdca3835f,0x64a38a1f,0x6608813c,0x859b8039}},	//   _захи, _заха, _indk, _השבו,
   {{0x7aed0063,0x35d28105,0x61e8923b,0x3207923c}},	//   ywat, _साड़, sedl, _enny_,
   {{0x7ae2803b,0xf77f0073,0x82fa853d,0x442b09c4}},	//   _upot, reço_, _دراز_, _rlc_,
   {{0x661a8364,0x4b7b81c6,0xa7fb123d,0xe3b08fd3}},	//   _jotk, _האדו, doñe, _سرچ_,
   {{0x7a2d840e,0x601f00f1,0x1c208105,0x61db82f6}},	//   _fútb, _sëmu, _बवाल_, _הקוד,
   {{0x63a4123e,0x7aed123f,0xd2510019,0x442b00e5}},	//   gbin, twat, ھنا_, _qlc_,
   {{0x3b541240,0xa3de8aed,0x7bcd1241,0x35d281ce}},	// [870] ектр, द्य_, rgau, _साढ़,
   {{0x24868013,0x91fc8029,0x661a807b,0x7c870012}},	//   _liom_, klām, _notk, _нуме,
   {{0x4fd59242,0x21270028,0xb33b0036,0x26cb1243}},	//   джет, ánh_, _reçu, luco_,
   {{0xa2bd9244,0x2eff80b9,0x35d303b7,0xa3de852a}},	//   _शिल्, _pruf_, _ताड़, द्म_,
   {{0xa7fb07f4,0xd6db9245,0x236681c0,0x26cb016a}},	//   coñe, сте_, _nyoj_, nuco_,
   {{0x2f238029,0x443d808e,0x992b1246,0x644d1247}},	//   _rīgā_, _smw_, _люба_, lnai,
   {{0x644d1248,0x3cf78035,0x80db8327,0xb33b03ed}},	//   onai, ंटें_, _बहें, _veçu,
   {{0x62870693,0x13b100ab,0xaca3819d,0x9f448037}},	//   _hijo, _ছাড়, _haịm, _lamù_,
   {{0x661a9249,0xb33b0214,0x2eff80b9,0x644d124a}},	//   _fotk, _geçt, _uruf_, inai,
   {{0x644d0083,0x7afb8074,0x26cb124b,0x2009124c}},	//   hnai, rvut, duco_, _anai_,
   {{0x7643924d,0xdb0b8019,0xd90f803d,0x63a4124e}},	//   miny, _megé, ایع_, ybin,
   {{0xa3ae8a3a,0x7643924f,0x59dd1250,0xeb0d1251}},	//   करण_, liny, न्तर, _सपूत_,
   {{0x629d01c5,0x7a201252,0xd0928201,0x09ac80ab}},	//   _ntso, _kött, _müəy, _খারা,
   {{0xfce600e8,0xdb2680d7,0x62871253,0x3e640061}},	//   мого, _توهی, _nijo, jött_,
   {{0x2101005c,0x91fc80eb,0x63a41254,0x7a201255}},	//   nčić_, klāj, tbin, _mött,
   {{0x27e002f7,0x628f1256,0x644d1257,0x601f0168}},	//   _ubin_, _buco, gnai, _dëms,
   {{0x76439258,0x4b7a8158,0x62871259,0xcb67125a}},	// [880] kiny, ַטעג, _bijo, дате_,
   {{0x644d125b,0x7643925c,0x62870b80,0x21010267}},	//   anai, jiny, _cijo, kčić_,
   {{0x7643925d,0x628707fc,0x2101011f,0x644d125e}},	//   diny, _dijo, jčić_, bnai,
   {{0xa7fb04c3,0x28c5925f,0x320984b9,0x3b0a0fdd}},	//   poñe, _विनि, _ɗaya_, _демо_,
   {{0x62870216,0x76438234,0x987b03de,0x628f018f}},	//   _fijo, finy, קאנט, _guco,
   {{0xd49a9260,0x59dd1261,0x62871262,0x9d450019}},	//   ори_, न्दर, _gijo, _آئین,
   {{0xf9831263,0x7a200338,0xa9670198,0x21671264}},	//   _агро, _dött, _жира_, _жири_,
   {{0xa8038098,0xb7fb801b,0x628702f9,0x00000000}},	//   _изсл, _एफएम_, _zijo, --,
   {{0x984600eb,0x7a20016d,0x76439265,0x998c8088}},	//   _dēļ_, _fött, biny, ridž_,
   {{0x7a201266,0x76439267,0x210100c3,0x20091268}},	//   _gött, ciny, bčić_, _snai_,
   {{0xa3c00576,0xa3ce016f,0x24868706,0x2d8c81a1}},	//   ीला_, रला_, _tiom_, _igde_,
   {{0x3e640065,0x699e800d,0x53468ada,0x2b40811f}},	//   zött_, _ख्री, _охла, _žicu_,
   {{0xa7741269,0x2ba480bc,0x63af0bda,0x4432126a}},	//   ключ, _ग्या, _recn, dhy_,
   {{0x68fc926b,0x26d90102,0xb8f480ab,0x764e126c}},	//   årds, rtso_, _হন_, gnby,
   {{0x236d026c,0x63af0669,0x628f126d,0x644d126e}},	//   _šej_, _pecn, _suco, tnai,
   {{0x7643926f,0x62871270,0x61f89271,0x20091272}},	//   ziny, _sijo, _havl, _unai_,
   {{0xf4841273,0x76439274,0x61f89275,0x0c840048}},	// [890] турн, yiny, _kavl, тырм,
   {{0x61f88025,0x644d1276,0x9c13819d,0x61fa9277}},	//   _javl, snai, _kọch, ndtl,
   {{0xa3ae8006,0x64dd9278,0x76438234,0x62871279}},	//   करा_, _महेश, viny, _vijo,
   {{0x4432127a,0x2c27035f,0x210102a5,0x628f01a1}},	//   chy_, _цьог, včić_, _tuco,
   {{0x4429127b,0x28c58bb8,0x7643927c,0xceeb803d}},	//   mka_, _विभि, tiny, تران_,
   {{0x4429127d,0xf7708416,0x321c816b,0x7876041c}},	//   lka_, جام_, _novy_, máve,
   {{0x764389ca,0x4429127e,0x7876127f,0x7a24823e}},	//   riny, oka_, láve, _gòti,
   {{0x44291280,0xa3d70d86,0x76439281,0x21010668}},	//   nka_, _साफ_, siny, rčić_,
   {{0x44291282,0xa3de8744,0x76439283,0x61f89284}},	//   ika_, द्ध_, piny, _bavl,
   {{0x80c08b6f,0xe9d99285,0x3eb9004a,0xa2c2064a}},	//   _विशे, чко_, dsst_, _लिस्,
   {{0x61f89286,0x68461287,0x44291288,0x186a1289}},	//   _davl, енна, kka_, зани_,
   {{0x44f18a8e,0xdb0601ac,0xb4fa81c6,0x7876128a}},	//   _iš_, _leká, _מפעי, káve,
   {{0xc2c88277,0x442f83a8,0xbbbd816f,0x93278f24}},	//   _قبول_, _ilg_, ोलीक, _تران,
   {{0x4429128b,0x7876128c,0x2d8c128d,0xf65200f7}},	//   eka_, dáve, øde_, ائح_,
   {{0xdb04128e,0x442902a3,0x7c29928f,0x1d071290}},	//   mbié, fka_, oker, нери_,
   {{0x44291291,0x1ddf816f,0x44f1816b,0x3c2e01d6}},	//   gka_, प्तत, _mš_, _býva_,
   {{0x7c29838e,0x28c5809a,0x290301b9,0x44f18bda}},	// [8a0] iker, _विडि, _arja_, _lš_,
   {{0x44291292,0xe1f70638,0x4a431293,0x7a2486c4}},	//   aka_, нгу_, гнув, _dòtw,
   {{0x442902c1,0x7c298d5b,0x4c861294,0x3ead9295}},	//   bka_, kker, _плов, _awet_,
   {{0x44291296,0x7c299297,0x6f041298,0x768b0035}},	//   cka_, jker, _kric, _użyc,
   {{0x68260510,0xdcfc0201,0x5fd18076,0xc8ec9299}},	//   _códi, marı, _हारल, _जन्म_,
   {{0xdcfc0b06,0x80db00ab,0xceb303c8,0x63b60079}},	//   ları, ণিজ্, ריג_, layn,
   {{0x3da5835f,0xa3d704e5,0x442f929a,0xdb1d0176}},	//   тріб, _साम_, _blg_, _adsè,
   {{0x6f040012,0x61f8929b,0x63b60079,0x7c29929c}},	//   _oric, _savl, nayn, gker,
   {{0x44f18267,0x53348087,0xa3ce01d0,0x661e129d}},	//   _eš_, тепт, _राई_, _oopk,
   {{0x4429129e,0x2d8c03f2,0x63b601b4,0xdb0f0580}},	//   zka_, ždej_, hayn, _decè,
   {{0x44290063,0xdcfc0214,0x6f04129f,0x403512a0}},	//   yka_, karı, _aric, венс,
   {{0x2fc080f7,0x7c2992a1,0x442912a2,0x63b601b4}},	//   óigh_, cker, xka_, jayn,
   {{0x61f892a3,0x6d480511,0x63b60079,0x44f1816b}},	//   _tavl, údan, dayn, _zš_,
   {{0x4429009a,0x6f04016d,0x787612a4,0xbe880198}},	//   wka_, _dric, váve, ессе_,
   {{0xf1b38051,0xcfb00264,0x2d8512a5,0xd12f804a}},	//   _עסק_, _কারন, äle_, _сх_,
   {{0x442912a6,0x6f0412a7,0xd6db1294,0x3ea004b7}},	//   uka_, _fric, _ето_, _ftit_,
   {{0x442912a8,0x78ba92a9,0xa3d7058c,0x06e880ab}},	// [8b0] rka_, lstv, _साठ_, পিডি,
   {{0x787612aa,0x51f80150,0x2296006a,0x7c298102}},	//   ráve, нную_, _dæk_, zker,
   {{0x78ba86d4,0xe8028076,0x7fd5902a,0x63b601b4}},	//   nstv, _रोहा_, вілі, bayn,
   {{0x644812ab,0x3ead809c,0x69d5009a,0x764706c0}},	//   édit, _pwet_, _wcze, lijy,
   {{0x141a098a,0xe8df001c,0xdb0b806a,0x799c0114}},	//   _חורב, _thỏa_, _udgø, _ffrw,
   {{0xf77400be,0xb5c285e9,0x628a92ac,0x442f802a}},	//   נקס_, айшл, _nifo, _slg_,
   {{0x7c2992ad,0xf402002e,0x442f92ae,0x9165003d}},	//   tker, _faţă_, _plg_, _شهره,
   {{0x130991d2,0x5fd891bc,0xd138809a,0x628a8915}},	//   дний_, _डायल, dzą_, _aifo,
   {{0x628a816d,0x56958081,0x3ed981a8,0x95d983a7}},	//   _bifo, _разт, _زواج_, _одат_,
   {{0x7c2992af,0xdcfc0059,0x32d986c0,0x6442811b}},	//   sker, zarı, rèy_, _emoi,
   {{0xa2bd885d,0x07a60554,0x442f92b0,0x2dd880f7}},	//   _शिक्, канн, _tlg_, _سبلة_,
   {{0x6f0412b1,0x63b602a3,0xdcfc0085,0x23c7826b}},	//   _pric, xayn, xarı, _dìjà_,
   {{0xe1ee92b2,0xfc46826f,0x539a82f6,0x628a8032}},	//   _кг_, ších_, _חינו, _fifo,
   {{0xceb2873a,0x63a992b3,0x2c4c801b,0x248b0144}},	//   שים_, lben, vědi_, _aicm_,
   {{0xdcfc1014,0xd1388035,0x78ba8dcc,0xa7fb016a}},	//   tarı, czą_, cstv, soña,
   {{0x2ae585e8,0x51848160,0x21888158,0x63a992b4}},	//   _कहाँ_, _суча, _אָפּ, nben,
   {{0xd4670572,0x787880a9,0x63b612b5,0x3b860048}},	// [8c0] тите_, níve, rayn, тлаг,
   {{0xa3d70d38,0x2296013c,0xdcfc0214,0x7d0892b6}},	//   _साथ_, _væk_, sarı, _jérô,
   {{0x63a992b7,0xd7fa92b8,0x28c904e5,0x64a612b9}},	//   kben, дул_, ांगि, _шана,
   {{0x63a9911b,0x26cf804f,0x63b60079,0xc95281c6}},	//   jben, fugo_, qayn, סמא_,
   {{0x63a98805,0x78ba826f,0x6378026b,0xfaa6111c}},	//   dben, zstv, _dúní, _јаго,
   {{0x71a30162,0x63a992ba,0x787881d0,0xaca40135}},	//   _варз, eben, díve, _nkịt,
   {{0x628a92bb,0xd94612bc,0xdb0f12bd,0x61fc12be}},	//   _rifo, _реви, _recé, _iarl,
   {{0x61fc12bf,0xdfd280f7,0x7a2d8019,0xab8692c0}},	//   _harl, _خير_, _búto, купк,
   {{0x61fc12c1,0xa3e4001b,0x26dd809a,0x97ea8085}},	//   _karl, प्य_, ctwo_, ışdı,
   {{0x682607a3,0x78ba90e8,0x61fe12c2,0x61fc12c3}},	//   _módu, tstv, ndpl, _jarl,
   {{0x3ea692c4,0xc4c592c5,0x1be212c6,0x02de02f1}},	//   lpot_, _متنو, खभाल_, नझुन,
   {{0xa3ce12c7,0x23ba92c8,0xa3d70fd5,0x6d5a8216}},	//   _राग_, _آداب_, _साध_, _ixta,
   {{0x6f0292c9,0xd138809a,0x682612ca,0x628a92cb}},	//   nvoc, szą_, _nódu, _tifo,
   {{0x78ba89cf,0x6f0292cc,0xa4d50d8e,0x67200338}},	//   pstv, ivoc, логі, ämja,
   {{0xfa778051,0xa3ce12cd,0x97320061,0x69c81238}},	//   _שעות_, _राख_, لکیا, _ödey,
   {{0x7876026f,0x3c31816b,0x54540425,0xc61f92ce}},	//   rávc, _káva_, авст, _भव्य_,
   {{0x2d9e8e1c,0x61fc12cf,0x337500c4,0x06d78264}},	// [8d0] _ofte_, _barl, угар, _দৈনি,
   {{0x35f5098d,0x61fc12d0,0x63a99123,0x394b003d}},	//   _спор, _carl, zben, وشاپ_,
   {{0x61fc12d1,0xdb0b80ab,0x787603b0,0x27ef83ba}},	//   _darl, _regí, láva, tegn_,
   {{0xdb0b8065,0xdb0612d2,0x61fc0039,0x28c586ae}},	//   _segí, _bekä, _earl, _विसि,
   {{0x6d5a8201,0x787612d3,0x7c2d12d4,0x78788187}},	//   _axta, náva, mkar, xíve,
   {{0xd77480f7,0x26cf92d5,0x78788187,0x7bc292d6}},	//   جامع, rugo_, víve, _adou,
   {{0xeb9992d7,0xd46992d8,0x7e6392d9,0x26dd8035}},	//   ний_, нике_, ronp, stwo_,
   {{0x200d8012,0x7876037d,0x787892da,0xdb0b8187}},	//   _unei_, káva, tíve, _negã,
   {{0xc7b28039,0x7c2d12db,0x05d3025a,0x9d238264}},	//   _לבן_, ikar, _तांब, বছেন_,
   {{0x78760a56,0x96f892dc,0x63a992dd,0x386912de}},	//   dáva, _جعفر_, sben, _akar_,
   {{0x7c2d12df,0x2ba492e0,0x78788187,0x9f4e001b}},	//   kkar, _ग्वा, síve, čním_,
   {{0x1ddf836d,0xddd5001b,0x2c098035,0xdb0a016b}},	//   प्रत, mozř, वाओं_, šnéh,
   {{0x91e592e1,0x28c58bbc,0x09e58abe,0x442d92e2}},	//   _боле, _विवि, _болн, mke_,
   {{0x442d92e3,0xdd920f99,0x386912e4,0xaf7683de}},	//   lke_, صور_, _ekar_, טערס_,
   {{0x442d92e5,0x7c3612e6,0x6e218668,0x09b200ab}},	//   oke_, thyr, _molb, _চালা,
   {{0x442d92e7,0x7c2d12e8,0x044312e9,0x8c4312ea}},	//   nke_, gkar, бесн, бесе,
   {{0x442d92eb,0x9b9300f7,0x248012ec,0x7c3612ed}},	// [8e0] ike_, إلكت, rmim_, rhyr,
   {{0xf1a903f8,0xe9d70003,0x05d292ee,0x3b8312ef}},	//   نامه_, лку_, _साइब, слуг,
   {{0x442d92f0,0x3ebf8012,0x61fe12f1,0x19b680be}},	//   kke_, _avut_, rdpl, רפער_,
   {{0x442d92f2,0x7c2d12f3,0x6aad81cd,0x61fc12f4}},	//   jke_, ckar, _ħafn, _warl,
   {{0x6e2192f5,0x61fc12f6,0xc7d70039,0x442d92f7}},	//   _bolb, _tarl, רוני_, dke_,
   {{0x442d8b3c,0x6e2192f8,0xccfa84ae,0x442212f9}},	//   eke_, _colb, ећи_, _hok_,
   {{0x6aa292fa,0x442212fb,0xf8c5825e,0x442d84b9}},	//   _stof, _kok_, _विषय, fke_,
   {{0x442212fc,0x25f0809a,0x7bd612fd,0x442d92fe}},	//   _jok_, _इसकी_, ngyu, gke_,
   {{0xa6ca89d7,0x628e12ff,0x5a349300,0xa3d70592}},	//   _سوال_, _kibo, инит, _सास_,
   {{0xa3e40e70,0xa2d501fe,0x2ba480d4,0xd6cf8f99}},	//   प्त_, यंत्, _ग्रा, _رقم_,
   {{0x8d939301,0x44221302,0x2907803b,0xf5938013}},	//   _المش, _ook_, _crna_, _المج,
   {{0x628e1303,0x764a9304,0x4422005f,0x557780be}},	//   _libo, lify, _nok_, _געבן_,
   {{0xa3ce09a3,0x09cc00c8,0x80c09305,0xe80b8beb}},	//   _राज_, র্যা, _विके, _सोफा_,
   {{0xe80b800f,0x7c229306,0x78761307,0x386681b0}},	//   _सोना_, _hoor, ráva, hoor_,
   {{0x16d19308,0x44221309,0x7c2d130a,0x7876130b}},	//   _सम्ब, _bok_, tkar, sáva,
   {{0x09cc00c8,0x44220214,0x26de0087,0x628e130c}},	//   র্মা, _cok_, ător_, _aibo,
   {{0x44220025,0x7c22930d,0x628e130e,0x5b15130f}},	// [8f0] _dok_, _moor, _bibo, шмат,
   {{0x7c2d00ad,0x442d9310,0x628e1311,0x7c229312}},	//   skar, zke_, _cibo, _loor,
   {{0x645a1313,0x44221314,0x764a9315,0x442d8be7}},	//   étic, _fok_, dify, yke_,
   {{0x7c229316,0xe8d784de,0x6e218f06,0x72d51317}},	//   _noor, רואר_, _solb, _комф,
   {{0x6e219318,0x44c101e2,0x64499319,0x27e9131a}},	//   _polb, lė_, viei, _mban_,
   {{0x09cc0a49,0x80aa8a49,0x7d0882a5,0xa1940071}},	//   র্বা, _কিন্, _brds, _гарч,
   {{0x44c101e2,0x442d931b,0x4422131c,0xa3dc131d}},	//   nė_, tke_, _yok_, _ठाम_,
   {{0x0c258aac,0x63ad131e,0x442d931f,0x6a6b0192}},	//   рмин, nban, uke_, rüfu,
   {{0x2907812b,0x78a49320,0x63ad1321,0x7c229322}},	//   _srna_, _čiva, iban, _door,
   {{0x442d9323,0x44c101e2,0x4a459324,0x27e91325}},	//   ske_, kė_, рнов, _aban_,
   {{0x69dd090a,0x7c2289f8,0xc32380c8,0x8e848013}},	//   _पानी, _foor, _বেশি_, _الله,
   {{0x7bc78110,0xdb0f03a7,0xd71c80ab,0x44c10110}},	//   ėjus, _mecâ, _দেয়া_, dė_,
   {{0x92b78013,0xf77208ca,0x290780dd,0x93948a47}},	//   _إحصا, تاد_, _wrna_, _اجما,
   {{0x44221326,0x63bb9327,0xbb3a8496,0x63ad1328}},	//   _sok_, laun, _בעני, eban,
   {{0x628e1329,0x6142932a,0xdb0f05e4,0x89da8039}},	//   _ribo, _меша, _decí, _יחסי,
   {{0x63ad132b,0x63bb932c,0x6f09932d,0x628e132e}},	//   gban, naun, _orec, _sibo,
   {{0xe9da0a08,0x386680f3,0x6d41046d,0xeb97002e}},	// [900] кка_, voor_, úlar, риу_,
   {{0x63ad132f,0x63bb8bb1,0x7af60114,0x787881d0}},	//   aban, haun, rwyt, díva,
   {{0xe0da1330,0xf1dd83eb,0x41dd8eb4,0xeaf28592}},	//   тве_, _मानन, _मानस, _अन्त_,
   {{0x35dc0665,0x6f099331,0xa3e7800d,0xdb0f002e}},	//   _बाड़, _brec, म्म_, _decâ,
   {{0x6f09840e,0x27ff8590,0xe7e8035a,0x764a9332}},	//   _crec, _daun_, ट्या_, tify,
   {{0x69dd0076,0x7c229333,0x6f099334,0x7d008019}},	//   _पायी, _soor, _drec, járá,
   {{0x01bb8a49,0x764a9335,0x7c229336,0x38669337}},	//   ংলাদ, rify, _poor, poor_,
   {{0x64561338,0x6f099339,0x27ff8763,0x69d8816f}},	//   nnyi, _frec, _gaun_, _माही,
   {{0x7c22933a,0xd37780d6,0x27e902f7,0xadba81a8}},	//   _voor, ичь_, _rban_, _لهذا_,
   {{0x7c2290f4,0x20120870,0x27e6933b,0x5a34933c}},	//   _woor, _anyi_, lfon_, снот,
   {{0xa3d703a4,0x78760a56,0x63ad133d,0xdca38088}},	//   _साल_, rávn, yban, _дахи,
   {{0x44c10110,0x3e7b8036,0x78a10061,0x63ad133e}},	//   vė_, rête_, _élve, xban,
   {{0x63a2933f,0xdb0f0118,0x200501d0,0xdb060032}},	//   _ifon, _pecí, ěli_, _eekú,
   {{0x20050063,0x20121340,0x44c101e2,0xa3e41053}},	//   śli_, _enyi_, tė_, प्स_,
   {{0x9c470791,0x3a7b83de,0x00000000,0x00000000}},	//   ахал, _שטוד, --, --,
   {{0x8f471317,0x27e91341,0x7055003d,0x1dd30105}},	//   _вход, _uban_, _دنبا, _ताकत,
   {{0x290a01e2,0x63ad1342,0xaa7b00e1,0xfb870e49}},	// [910] _arba_, rban, _opýt, рывн,
   {{0xe7e80063,0x39a71343,0x44c10110,0x63bb84b9}},	//   ट्ठा_, ршав, pė_, zaun,
   {{0x26141344,0x6f09803b,0x27ff8abf,0x63ad1345}},	//   दारी_, _srec, _paun_, pban,
   {{0xdd1c01d0,0x765a8168,0xe3b81346,0x785201a9}},	//   _nářa, _ajty, _ключ_, tāvi,
   {{0xe5a5917e,0x290a1347,0xd6db82dc,0x8c1a0039}},	//   били, _erba_, тте_, _עושי,
   {{0x644d1348,0x63a29349,0x14b8019f,0x6f0980e1}},	//   liai, _afon, _حدیث_, _vrec,
   {{0x27ff83f8,0x6f098114,0x44f88028,0x63bb934a}},	//   _taun_, _wrec, _cũ_, taun,
   {{0x6f098012,0x644d134b,0xed580039,0x62850706}},	//   _trec, niai, יבור_, lmho,
   {{0x869887eb,0x63bb934c,0x386d934d,0x6f098087}},	//   _вкус_, raun, _iker_, _urec,
   {{0x6ce7835f,0x629b82be,0xe4e7835f,0xe8f9934e}},	//   _віде, rquo, _відн, гло_,
   {{0xa3d71344,0x92d780c8,0x261989f2,0x9f5e000d}},	//   सला_, াবে_, पाठी_, ětí_,
   {{0x6601934f,0x44e19350,0x9b9580f7,0xaac704c5}},	//   _halk, mó_, _الإت, _लिंक,
   {{0x69c71351,0xbb858013,0x64561352,0x44e19353}},	//   _odje, _الشي, vnyi, ló_,
   {{0x69c7020f,0x6da31354,0x66018009,0x7bdd0118}},	//   _ndje, зира, _jalk, _acsu,
   {{0x44e19355,0x64a602df,0x2d8c0106,0x2ba6801b}},	//   nó_, саба, äde_, síců_,
   {{0x7c3b9356,0x69dc1357,0x644d1358,0x62999359}},	//   nhur, _scre, giai, _kuwo,
   {{0x290a003b,0xa3df8105,0x63b98114,0xd3b90a8e}},	// [920] _srba_, _तान_, _mewn, русі_,
   {{0xbf9b0073,0x26c2135a,0xa3e786ab,0xdb0f0980}},	//   ndên, msko_, म्त_, _decà,
   {{0x44e1935b,0x31ba8158,0x93f9816f,0x787d0019}},	//   jó_, רזענ, ्याच_, séve,
   {{0x387f8af9,0x44e1935c,0xe73a8364,0x644d135d}},	//   _chur_, dó_, лее_, ciai,
   {{0x26c20ed6,0x4432003e,0x7c3b935e,0x2f18935f}},	//   nsko_, mky_, dhur, роль_,
   {{0x443203cb,0x63a29360,0x40961361,0xceb303c8}},	//   lky_, _sfon, _грат, ליד_,
   {{0x660182c1,0x44e19362,0x1619000f,0xdc1180ab}},	//   _dalk, gó_, दातर_, িউনস_,
   {{0x44321363,0x44f88028,0x62999364,0x69c71365}},	//   nky_, _vũ_, _buwo, _zdje,
   {{0x8c1b004c,0x26c2135a,0x66019366,0x32669367}},	//   רופי, jsko_, _falk, йтов,
   {{0x41dd835a,0x8afb00be,0x660181b4,0x11d880f7}},	//   _माणस, נהיי, _galk, جودة_,
   {{0x04968013,0x44e185a4,0xdb0f02ba,0xdfd11368}},	//   _الصح, có_, _mecá, ويد_,
   {{0x4432026f,0xdb0b816d,0x44201369,0x6e250214}},	//   jky_, _begä, jji_, _sohb,
   {{0x44320a56,0x4420136a,0x447b8158,0x7c6580f7}},	//   dky_, dji_, _ענדע, _بالل,
   {{0x7ae4136b,0x4420136c,0x63b9809a,0x66018df6}},	//   dtit, eji_, _zewn, _xalk,
   {{0x90a6936d,0x644d136e,0x4432136f,0x59dd9370}},	//   _احتم, tiai, fky_, _मातर,
   {{0x442000f1,0xb4e90770,0x7c2606cb,0x44269371}},	//   gji_, _यही_, _cokr, _joo_,
   {{0x644d1372,0x2fc9108c,0x442681c5,0x44e18065}},	// [930] riai, _idag_, _moo_, zó_,
   {{0x442682c1,0x442000f6,0x386d832b,0x644d1373}},	//   _loo_, aji_, _sker_, siai,
   {{0x4432003e,0xda781374,0x6f0d026f,0x7d081375}},	//   bky_, сят_, _hrac, ådst,
   {{0x44200d38,0x44321376,0x6f0d1377,0x44e19378}},	//   cji_, cky_, _krac, vó_,
   {{0x443903d3,0x660188e5,0x9f0580f7,0xe610804e}},	//   _ils_, _palk, توشو, کشن_,
   {{0x44e18117,0xd1268154,0x4ac28072,0x2ba501d0}},	//   tó_, _قم_, _शिजव, गुरा,
   {{0x63b98063,0xe3b18013,0xfe708077,0x66019379}},	//   _pewn, ورة_, رده_, _valk,
   {{0x44e1937a,0x5ac9937b,0x386d80e8,0x6601937c}},	//   ró_, алим_, _uker_, _walk,
   {{0x44e1937d,0xe816816f,0xb4d601ce,0x27ed89bf}},	//   só_, णारा_, _सम्_, _iben_,
   {{0x7c3b937e,0x4432003e,0x4420137f,0x2fc91380}},	//   shur, zky_, zji_, _adag_,
   {{0x3ea9002e,0x9d559381,0x6f0d1382,0x261d015c}},	//   _atat_, _بنات, _arac, मानी_,
   {{0x186a1383,0xa4140264,0x44c581a9,0x69da9384}},	//   рами_, _সত্য_, mē_, agte,
   {{0x44321385,0x28c5825e,0x44c580eb,0x44201386}},	//   vky_, _विकि, lē_, vji_,
   {{0x44391387,0x7ae41388,0x5bb206a7,0x64a380c3}},	//   _als_, vtit, जर्व, _gđic,
   {{0x44321389,0x4426877f,0x27ed8352,0x8c0100c8}},	//   tky_, _yoo_, _oben_, _একজন_,
   {{0xd5dc023c,0x6a7002af,0x5baa07a1,0x7bdb938a}},	//   _बावज, häft, ркам_, nguu,
   {{0x4420138b,0x4432003e,0x4226138c,0x3b0700b3}},	// [940] rji_, rky_, одав, оето_,
   {{0x4439138d,0x44320a56,0x4420009a,0x6aa480f7}},	//   _els_, sky_, sji_, _éife,
   {{0x7ae4138e,0x10a6138f,0x4432003e,0x644b8370}},	//   stit, циен, pky_, _omgi,
   {{0xa2a2000f,0x7876026f,0x23e10935,0x7ae41390}},	//   _कंप्, dávk, _फायद, ptit,
   {{0x69da806a,0xa25b00e1,0xdb0f0144,0xaac7001b}},	//   ygte, _kvôl, _tecá, _लिएक,
   {{0x2d4e011b,0x44268962,0xa3e79391,0x27ed9392}},	//   _eнee_, _soo_, म्स_, _eben_,
   {{0xd4979006,0x44269393,0x672f009a,0xd5b98a4c}},	//   оры_, _poo_, zycj, ссі_,
   {{0x3cfe8267,0x7a2d9394,0x442682f7,0x68e3023e}},	//   _vstv_, _mútu, _qoo_, ànde,
   {{0x63a41395,0x44269396,0x69da1238,0x6a748580}},	//   icin, _voo_, _ötes, làfi,
   {{0x81d280c8,0x27e000fc,0x2004865f,0x26c08196}},	//   হ্ন_, _acin_, _hami_, šios_,
   {{0x20049397,0x63a41398,0x4a7b0158,0xc27b00be}},	//   _kami_, kcin, שריב, שריי,
   {{0x6f0d1399,0x200480a4,0x63a400d2,0x6e28826c}},	//   _prac, _jami_, jcin, _hodb,
   {{0x61ee139a,0x7bc0939b,0x78ad939c,0xa3e3864a}},	//   _obbl, mamu, _čave, _पॉट_,
   {{0x63a400eb,0x2004939d,0xdef801e2,0xddda8061}},	//   ecin, _lami_, цыю_, _kitű,
   {{0xdd940196,0x63a4026c,0x6594139e,0x6f0d139f}},	//   дары, fcin, дару, _wrac,
   {{0x320d017b,0x6f0d13a0,0x200493a1,0x7bc093a2}},	//   _şey_, _trac, _nami_, namu,
   {{0x6f0d13a3,0x44c581a9,0x97ea81cc,0x2aa08242}},	// [950] _urac, zē_, ışlı, _jòb_,
   {{0x7bc093a4,0x20048091,0x290e81a1,0xdb198176}},	//   hamu, _aami_, _krfa_, _dewè,
   {{0x31c40987,0x7bc093a5,0x26d913a6,0x200493a7}},	//   ьств, kamu, luso_, _bami_,
   {{0xdb1f0168,0xae190035,0x7bc093a8,0x200493a9}},	//   naqë, दावन_, jamu, _cami_,
   {{0xdefb8364,0x7bc093aa,0x81e700c8,0x63bd0029}},	//   рые_, damu, _মোঃ_, _iesn,
   {{0x46d30076,0xafdb00e8,0x386681a1,0xdcef8b80}},	//   _तिनह, rnøy, čora_, šečl,
   {{0x660513ab,0x20048970,0x19580190,0x6a7013ac}},	//   _mahk, _fami_, _дары_, räft,
   {{0x660513ad,0x629d13ae,0x443993af,0x69ca93b0}},	//   _lahk, _kuso, ós_, _adfe,
   {{0xf7498013,0x768b0063,0x6e28813c,0x629d13b1}},	//   _الذي_, _używ, _fodb, _juso,
   {{0x2bab8eed,0x629d13b2,0x36378077,0x63bd13b3}},	//   _ट्रा, _muso, _بررس, _lesn,
   {{0x216993b4,0x629d13b5,0x60c50168,0x7bc093b6}},	//   сини_, _luso, nshm, bamu,
   {{0xa3d71278,0x2489026c,0x26d90568,0x7bc093b7}},	//   _साग_, jmam_, fuso_, camu,
   {{0x660513b8,0x20040038,0xdb0b8019,0x7876016b}},	//   _bahk, ľmi_, _legú, návi,
   {{0x443f84b9,0x8b058063,0x629513b9,0x3d0813ba}},	//   lhu_, _częś, _nizo, हिले_,
   {{0x69c193bb,0xe3bf0e1b,0x60c500f1,0xc6928039}},	//   male, _coño_, jshm, תאם_,
   {{0x69c1805d,0x629d13bc,0xaac7009a,0x4ac70d86}},	//   lale, _buso, _लिखक, _लिखव,
   {{0x63a413bd,0xe36313be,0x6b6313bf,0x62950019}},	// [960] rcin, екти, екта, _bizo,
   {{0x69c193c0,0x629504b9,0x7bc080b4,0x63a413c1}},	//   nale, _cizo, zamu, scin,
   {{0x6d438024,0x443f829b,0x200486c0,0x7bcb80d2}},	//   jzna, khu_, _pami_, _odgu,
   {{0x38a18013,0xfc3200f7,0xdb0400f3,0x7bc08079}},	//   _mór_, _أحد_, ncië, xamu,
   {{0xfbd30051,0x69c193c2,0x7bc08006,0x629d02a0}},	//   _אתר_, kale, vamu, _guso,
   {{0xe8df0028,0x69c193c3,0x20048234,0x629513c4}},	//   _giữa_, jale, _wami_, _gizo,
   {{0x69c193c5,0x7bc093c6,0x2ee693c7,0xb5098072}},	//   dale, tamu, stof_, विषय_,
   {{0x7c2413c8,0x629d03ac,0xb0d1016f,0xf8c5824c}},	//   njir, _yuso, _हितग, _विजय,
   {{0x7bc093c9,0x69c193ca,0xdb060061,0x2a6c8163}},	//   ramu, fale, _nekü, todb_,
   {{0x69c193cb,0x7bc093cc,0x7f3b8039,0x62838219}},	//   gale, samu, _העמו, _chno,
   {{0x7bc08ce9,0x443f81f6,0x649581a1,0xf1dd8ad5}},	//   pamu, bhu_, _išin, _मारन,
   {{0xc48693cd,0x3157098a,0x660513ce,0x7d7b80be}},	//   _элек, ליין_, _sahk, _פראג,
   {{0x63bd13cf,0xe3bf01df,0xee870198,0x47340c6e}},	//   _resn, _soño_, зыво, еняс,
   {{0x69c193d0,0x38a18125,0xe3bf002a,0xd2508fd3}},	//   cale, _fór_, _poño_, _جنت_,
   {{0x776401df,0xa15793d1,0x26d913d2,0x7876026f}},	//   _exix, _нашу_, suso_, závi,
   {{0x26d913d3,0x31c6801b,0x629d13d4,0xab5d809a}},	//   puso_, bízí_, _puso, saże,
   {{0xdb0b8c15,0xdb0400e7,0x248913d5,0x60da80dd}},	// [970] _segú, nciè, rmam_, lutm,
   {{0x60c500f1,0x4ad493ba,0x61fa93d6,0xddc381ac}},	//   tshm, _दिनव, netl, konš,
   {{0x6ca413d7,0x63bd024a,0x787d0036,0x7c380333}},	//   _пряж, _tesn, névo, ñará,
   {{0x69c193d8,0x60c500f1,0x629d0365,0xf770803d}},	//   zale, rshm, _tuso, گام_,
   {{0x261993d9,0x61fa93da,0xe80e10c8,0x69c193db}},	//   पाली_, ketl, ियता_, yale,
   {{0xf7708bbe,0x61fa82fd,0x442b13dc,0x7876016b}},	//   دام_, jetl, _hoc_, rávi,
   {{0x443f93dd,0xc2120039,0x26c681b4,0x60c513de}},	//   thu_, _בהם_, asoo_, qshm,
   {{0xc9520051,0x442b13df,0x7bdf13e0,0xdb1d0168}},	//   _סמן_, _joc_, ngqu, _nesë,
   {{0xe82101fe,0x69c193e1,0x442b13e2,0xa3e505fc}},	//   याना_, tale, _moc_, _नान_,
   {{0x442b0012,0x443f93e3,0x38a193e4,0xa3df93e5}},	//   _loc_, shu_, _pór_, _ताव_,
   {{0x443f93e6,0xa2cf8c2d,0xda1f8072,0x3de30264}},	//   phu_, _दिव्, बाबत_, য়াল,
   {{0x69c193e7,0xcdc90051,0x442b1122,0x64408920}},	//   sale, _כך_, _noc_, chmi,
   {{0xa3d70e5b,0xdb060247,0xdb0401ed,0x09d500ab}},	//   _साज_, _lekò, rcië, স্যা,
   {{0x69c18234,0xf1ba00ff,0x7ae993e8,0x291113e9}},	//   qale, ươi_, mtet, _orza_,
   {{0x6a7d809f,0x443d815d,0x1d070c24,0x442b13ea}},	//   lèfo, _klw_, мери_, _boc_,
   {{0x998381e2,0x26c40019,0x6e21008b,0xdb1d13eb}},	//   ųjų_, ámos_, ölbr, _kesè,
   {{0x7ae993ec,0x7c2b8122,0x290313ed,0xfaff00eb}},	// [980] ntet, _mogr, _asja_, šīnu_,
   {{0x7c2b840e,0x291113ee,0x7ae993ef,0x6f040234}},	//   _logr, _brza_, itet, _isic,
   {{0x361b0158,0x442b13f0,0xeb9a13f1,0x26c90052}},	//   _וויד, _foc_, _мин_, _zvao_,
   {{0xdfcf8013,0x3ea013f2,0x61fa93f3,0x9f5906c0}},	//   ليم_, _kuit_, zetl, fesè_,
   {{0x61fa93f4,0xbefa826a,0x7ae98019,0x41dd83dd}},	//   yetl, تراض_, jtet, _मांस,
   {{0x768b0d38,0x28db03eb,0x2d9a80e8,0x6f04004f}},	//   _użyt, मूहि, øpe_, _msic,
   {{0xa3e513f5,0x61fa93f6,0x5e570158,0xe821000d}},	//   _नाम_, vetl, ויסע_, यामा_,
   {{0x7bc41149,0x09c6816f,0x442b023e,0xdb1d010c}},	//   naiu, लण्य, _xoc_, _besè,
   {{0xae1e83dd,0xa3df8999,0x68e100f2,0x3ea002be}},	//   पादन_, _तार_, _äldr, _nuit_,
   {{0x64408168,0xa68393f7,0x2fc00580,0xdb1d13f8}},	//   shmi, _алуд, _aeig_, _desè,
   {{0x61fa93f9,0xae220d86,0x6f0413fa,0x443d82df}},	//   retl, मानन_, _asic, _flw_,
   {{0x68e100f2,0x61fa93fb,0xf9930039,0x3ea013fc}},	//   _ålde, setl, כרת_, _buit_,
   {{0x5b36845b,0x69ce01ac,0x320790e4,0x27e480b9}},	//   _تعار, _odbe, _fany_, _mcmn_,
   {{0x3ea013fd,0x6b8293fe,0x32078176,0x683a8580}},	//   _duit_, _izog, _gany_, _oïdo,
   {{0xd3088104,0x2bd00006,0x442b009f,0x24868282}},	//   _hệ_, तृभा, _poc_, _khom_,
   {{0x7a3f80e7,0x3ea013ff,0x69ce1400,0xdb0606c0}},	//   _vête, _fuit_, _adbe, _rekò,
   {{0x52151401,0x661a8cfa,0x7d1c81fa,0x62989402}},	// [990] ндат, _ontk, _ársf, _kivo,
   {{0x7a3f8036,0x20090cda,0x24868609,0xdb060176}},	//   _tête, _haai_, _lhom_, _pekò,
   {{0x7ae99403,0xd308801c,0xa3df8f97,0xdb1d0061}},	//   ztet, _lệ_, _ताल_, _mesé,
   {{0xa2cf9404,0x7ae99405,0xec350158,0x6448009f}},	//   _दिल्, ytet, _נאָר_, èdit,
   {{0x66089406,0x2ee900b9,0x6b828a03,0x20091407}},	//   _badk, _jqaf_, _nzog, _maai_,
   {{0x62989408,0xa3cd064a,0x7c2b9409,0x2009067f}},	//   _nivo, रणव_, _sogr, _laai_,
   {{0x660882c1,0x6d4704b7,0xdfd58009,0x69c5140a}},	//   _dadk, nzja, _повы, mahe,
   {{0x9b05940b,0xcd980bea,0x2486940c,0x58878e11}},	//   езид, ודות_, _chom_, _цыга,
   {{0xed5881ac,0xfe0f140d,0x6298940e,0x443d8187}},	//   _veľa_, ायास_, _bivo, _vlw_,
   {{0x7ae9940f,0x66089410,0x69c51411,0x3ea01412}},	//   rtet, _gadk, nahe, _ruit_,
   {{0x7ae99413,0x09d500c8,0x61e10125,0x29119414}},	//   stet, স্থা, _öllu, íza_,
   {{0x7a320125,0x7878826f,0x2360816b,0x764380dd}},	//   _hætt, tívi, _žije_, lhny,
   {{0x69c513fa,0x200901b0,0x76551415,0x64859416}},	//   kahe, _daai_, fizy, róid,
   {{0xceb29417,0x09d50a49,0xfc3f062f,0x63a99418}},	//   רים_, স্তা, _alí_, lcen,
   {{0x75f38059,0xa8060457,0x7a32007b,0x69c51419}},	//   mızı, _alış, _mætt, dahe,
   {{0x3ea00998,0x98a701d0,0x2af382f1,0x52aa0081}},	//   _tuit_, šně_, _अहाँ_, звам_,
   {{0x9696141a,0x1e96018b,0xfd658028,0xfc3f00f7}},	// [9a0] _прош, _прор, _chuẩ, _dlí_,
   {{0x75f38457,0xa3dc141b,0xd94611f3,0x69c5141c}},	//   nızı, _ठाक_, нези, gahe,
   {{0xa3df941d,0x78ab802e,0x261d00c2,0xba3b023e}},	//   तला_, _învă, मारी_, _suïc,
   {{0xe29a141e,0x41e2016f,0x63a9941f,0xa0679420}},	//   _нам_, _पावस, jcen, наха_,
   {{0xe7379421,0x64561422,0x69c51423,0x2ca1026c}},	//   нец_, miyi, bahe, _zuhd_,
   {{0x64561424,0x69c5008e,0x20e0016f,0x63a99425}},	//   liyi, cahe, खंदळ_, ecen,
   {{0x62989426,0x24868069,0xdb1d1427,0x649581f4}},	//   _rivo, _phom_, _resé, _išij,
   {{0xdb0f0118,0x7643836e,0x64561428,0x04638a41}},	//   _recú, ahny, niyi, лтым,
   {{0xeaaf803d,0x81e700ab,0xa01b007b,0x6d4701b9}},	//   یعی_, _মোট_, llög, zzja,
   {{0xd3088028,0xc3330039,0x63a99429,0x20091384}},	//   _vệ_, טוח_, acen, _saai_,
   {{0xa3e881b6,0x7655142a,0xab5d809a,0x63a9942b}},	//   _बाप_, vizy, raża, bcen,
   {{0x236690af,0xfaa6942c,0x80d3142d,0x9cd782f6}},	//   _txoj_, _задо, _डिसे, _טובה_,
   {{0x644402a3,0x64560201,0xe667142e,0x61fe004a}},	//   dhii, diyi, етво, kepl,
   {{0x61fe142f,0x320a01b0,0x614680e7,0x2009067f}},	//   jepl, _naby_, _célé, _waai_,
   {{0xe821101b,0x5fd0816f,0x69c50006,0x61fe1430}},	//   यादा_, हणाल, vahe, depl,
   {{0x60de09ca,0x9f520e1b,0x765506c0,0x64440162}},	//   dupm, _cayó_, sizy, ghii,
   {{0xc2991431,0x69c50a74,0x3a7507b6,0x2fc68bb1}},	// [9b0] дках_, tahe, влар, daog_,
   {{0xddc71432,0x6467026f,0xbbeb003d,0x61fe1433}},	//   bojš, _špič, _کردم_, gepl,
   {{0x7a321434,0xe61f801c,0x659504bd,0x64561435}},	//   _rætt, _đô_, _јану, biyi,
   {{0x7a32065d,0x44cc800d,0x69c51436,0xd75984a3}},	//   _sætt, dě_, sahe, ولات_,
   {{0xd90f0117,0x320a1437,0x764380dd,0x61fe1438}},	//   _گیا_, _faby_, thny, bepl,
   {{0xee389439,0x7aed0019,0x20098110,0x657a943a}},	//   нні_, mtat, žai_, _byth,
   {{0x25e909f2,0xd90f0117,0x44290110,0x78ad8115}},	//   _जानी_, _دیا_, oja_, _čavo,
   {{0xeb99943b,0x764382f7,0x7aed00e5,0x6d58143c}},	//   мий_, shny, otat, _žvak,
   {{0xc864943d,0xe7db143e,0x248d943f,0x7a320366}},	//   _стри, _भाजप, rmem_, _tætt,
   {{0x44291440,0x63a99441,0x7aed1442,0x6aa281e0}},	//   hja_, scen, itat, _duof,
   {{0x44291443,0xa06a1444,0x7aed0168,0x186a1445}},	//   kja_, дана_, htat, дани_,
   {{0x44291446,0x2d8587d9,0x7c2f09c4,0x7bc29447}},	//   jja_, _izle_, _nocr, _geou,
   {{0xe28e9448,0x44291449,0x7c29944a,0xf092893f}},	//   _ва_, dja_, mjer, ינט_,
   {{0xc0a883f8,0xda110076,0x7c2984fe,0x7c3b944b}},	//   بایل_, _डोलत_, ljer, lkur,
   {{0x442f8bda,0x1fb6144c,0x7aed144d,0x4429144e}},	//   _kog_, _испр, etat, fja_,
   {{0x4429144f,0x442f9450,0x69c39451,0xe8df00ff}},	//   gja_, _jog_, _hene, _nhựa_,
   {{0x614683d3,0x442f822c,0x7aed02b8,0xe29a02df}},	// [9c0] _télé, _mog_, gtat, даа_,
   {{0x69c39452,0x644402a3,0x44291453,0x4a431454}},	//   _jene, shii, aja_, анув,
   {{0x44291455,0x7c3b9456,0x442f837a,0x2dd900be}},	//   bja_, kkur, _oog_, _אַרב,
   {{0x44290d38,0x44cc800d,0x442f9457,0xdefa8048}},	//   cja_, vě_, _nog_, дык_,
   {{0x7aed1458,0xb8659459,0xab5d809a,0x3aeb804a}},	//   ctat, دالو, ważn, jøp_,
   {{0x09cc00c8,0x649580d2,0x44cc801b,0x98a70087}},	//   র্জা, _ušij, tě_, ână_,
   {{0x77698118,0xe976003d,0xa2bf8035,0x4096945a}},	//   _exex, _شهرد, लीस्, _арат,
   {{0x442f81c5,0xdb0b8073,0x629c145b,0x7c29945c}},	//   _cog_, _negó, _hiro, gjer,
   {{0x629c145d,0xbea68098,0x657a831d,0x3f848289}},	//   _kiro, _разк, _wyth, _uzmu_,
   {{0x69c3945e,0x629c145f,0x44291460,0x656902d0}},	//   _cene, _jiro, zja_, şehi,
   {{0x69c39461,0x7aed1462,0x44291463,0x442f9464}},	//   _dene, ztat, yja_, _fog_,
   {{0x320a8775,0x76588010,0xc1730039,0xe53780be}},	//   žby_, livy, יחת_, _שטאט_,
   {{0x44291465,0x69c39466,0xada2807b,0x2fc480b9}},	//   vja_, _fene, _þúsu, _memg_,
   {{0x442f81e9,0x7c2f1467,0x629c1468,0x6f161469}},	//   _zog_, _socr, _niro, _dryc,
   {{0x442f946a,0x69c8946b,0xd49b146c,0x16df8bb8}},	//   _yog_, made, дра_, _नम्ब,
   {{0x030e146d,0x7aed146e,0x3d08035a,0x629c146f}},	//   सिंह_, ttat, हिजे_, _airo,
   {{0x629c1470,0x7aed1471,0x5b150791,0x34940254}},	// [9d0] _biro, utat, ымат, ратр,
   {{0x44291472,0x7aed1473,0x69c8888b,0xa3e5035a}},	//   sja_, rtat, nade, _नाव_,
   {{0x7aed1474,0x44291475,0xdb0b809f,0x629c1476}},	//   stat, pja_, _segü, _diro,
   {{0x4429020f,0x629c0029,0x7aed1477,0x69c89478}},	//   qja_, _eiro, ptat, hade,
   {{0x442f9479,0x7c29830b,0x4421801c,0x63ad147a}},	//   _rog_, vjer, _đh_, mcan,
   {{0x629c147b,0x64428364,0x6d580110,0x3ea48bbd}},	//   _giro, _aloi, _žvai, _dumt_,
   {{0x69c89313,0x7c29911b,0x442f947c,0x6442947d}},	//   dade, tjer, _pog_, _bloi,
   {{0x63ad147e,0x69c3947f,0x442f8282,0x13099480}},	//   ncan, _sene, _qog_, ений_,
   {{0x69c39481,0x7c299482,0x628a8013,0x442f9483}},	//   _pene, rjer, _bhfo, _vog_,
   {{0x69c89484,0x42259485,0x64429486,0x6f099487}},	//   gade, удов, _eloi, _isec,
   {{0xa2cf873c,0x569482df,0xe4e4804a,0x6a7d8980}},	//   _दिक्, _тафт, _вічн, nèfi,
   {{0x69c39488,0x64429489,0xb8cb9370,0x5fab81d0}},	//   _wene, _gloi, _कं_, _छलफल,
   {{0x63bb8397,0xa3e880cf,0x69c3948a,0x69c8948b}},	//   mbun, _बात_, _tene, bade,
   {{0xa2d88305,0xf1e2000d,0x63bb948c,0xfce6148d}},	//   _मित्, _पाइन, lbun, лого,
   {{0x629c148e,0xa3e503b6,0xdb1d01d0,0x290780fe}},	//   _riro, _नाश_, _desí, _usna_,
   {{0x7bc9948f,0x6f161490,0x6f0981dd,0x6e3c1491}},	//   naeu, _tryc, _osec, skrb,
   {{0x63bb82af,0x629c1492,0xa3e50327,0xc05301c6}},	// [9e0] ibun, _piro, _नार_, _לזה_,
   {{0x20020c14,0x629c0609,0x63ad1493,0x09d580ab}},	//   leki_, _qiro, acan, ত্রা,
   {{0x25e91370,0x291e0b67,0xa494003d,0x645a0036}},	//   _जाती_, _štab_, _نیست, étis,
   {{0x63ad0098,0x69c89494,0x61e5032f,0x629c1495}},	//   ccan, zade, aghl, _wiro,
   {{0x68e19496,0x69c89497,0x2ca58362,0xa2cf8c2d}},	//   huld, yade, _auld_, _दिग्,
   {{0x2480020f,0xd252015b,0x69c89498,0x64428635}},	//   llim_, _طنز_, xade, _sloi,
   {{0xa3e89499,0x69c8949a,0x7bc6059c,0x6f09949b}},	//   _बाद_, vade, _keku, _esec,
   {{0x2002061b,0x63bb949c,0x68e1949d,0x7658949e}},	//   jeki_, gbun, duld, sivy,
   {{0x38558698,0x6edb925f,0x38a880e7,0x20020214}},	//   _търс, _नियु, _sûr_, deki_,
   {{0x7bc6149f,0x2ca5813c,0xdd8f94a0,0x27e694a1}},	//   _leku, _fuld_, _کوم_, lgon_,
   {{0x63ad0086,0xe821053e,0x2ca594a2,0x6e9380f7}},	//   ycan, याला_, _guld_, _اللا,
   {{0x27e69341,0x69c894a3,0x7bc614a4,0x64858742}},	//   ngon_, sade, _neku, lóin,
   {{0xd90e8077,0x63ad02a5,0xb8cb86ae,0xa85781c6}},	//   زیک_, vcan, _कू_, ריכה_,
   {{0xdd20800d,0x539b812a,0x291801e4,0x25e8940d}},	//   _může, _ניגו, _orra_, च्ची_,
   {{0x68e183a7,0xdb1d002a,0x7bc614a5,0x63ad14a6}},	//   culd, _vesí, _beku, tcan,
   {{0x20020214,0x63ad0144,0xf1e2001b,0x93b5105c}},	//   ceki_, ucan, _पाउन, рбац,
   {{0x29180019,0x28da800d,0x63a2804f,0x32550f04}},	// [9f0] _arra_, _भिडि, _mgon, авар,
   {{0x200d80ee,0x61e501c0,0x63bb8162,0x6fc794a7}},	//   _saei_, ughl, zbun, ारभू,
   {{0x78ad817f,0xdfd181a8,0x648594a8,0x63ad14a9}},	//   _čavk, قيا_, dóin, pcan,
   {{0x63a294aa,0x7bc614ab,0xf8c9026b,0x64b181a9}},	//   _ngon, _geku, _aréè_, _jāie,
   {{0x260a016f,0x291814ac,0x61f882d4,0x65c582df}},	//   ायची_, _erra_, _obvl, абла,
   {{0x63a294ad,0xe61890ac,0x200214ae,0xed5994af}},	//   _agon, лді_, zeki_, кол_,
   {{0xce380039,0x7bc60085,0x2905047f,0x51840084}},	//   ראות_, _yeku, _èla_, _гута,
   {{0x201f8012,0x68e194b0,0x7afd0122,0x3dc594b1}},	//   _unui_, vuld, _kpst, _welw_,
   {{0x63bb89af,0x28c282f1,0xa3b483b7,0xc24594b2}},	//   rbun, वीसि, झड़_, иник,
   {{0x69c714b3,0x386914b4,0xdb0414b5,0x63a28102}},	//   _jeje, _ajar_, nciá, _egon,
   {{0x69c714b6,0xa96994b7,0x216994b8,0x7c2d14b9}},	//   _meje, тина_, тини_, kjar,
   {{0x7afd14ba,0x69c714bb,0xe73a14bc,0x20560cc1}},	//   _opst, _leje, вем_, ртор,
   {{0x387e86e3,0x81dd00c8,0x7c2d14bd,0x200214be}},	//   _être_, থ্য_, djar, reki_,
   {{0x7bc614bf,0x443f94c0,0x644994c1,0x69c7001b}},	//   _seku, lku_, lhei, _neje,
   {{0x7afd0029,0x776d0118,0x442d8110,0x7c2d007b}},	//   _apst, _exax, oje_, fjar,
   {{0x644994c2,0x660394c3,0x44f1801c,0xef1a066a}},	//   nhei, henk, _mơ_, _ами_,
   {{0x69c70065,0x645a02be,0x207b00be,0x68fc012b}},	// [a00] _beje, étiq, _באקא, _sprd,
   {{0xba2314c4,0x601b0364,0x442d94c5,0x7bc614c6}},	//   одук, _tämä, hje_, _weku,
   {{0x443f94c7,0x442d821e,0x69c714c8,0x6449879f}},	//   kku_, kje_, _deje, khei,
   {{0x1ae6025d,0x443f803b,0x644980f3,0x442d94c9}},	//   _комм, jku_, jhei, jje_,
   {{0x27e694ca,0x442d94cb,0x644994cc,0x644614cd}},	//   rgon_, dje_, dhei, _ilki,
   {{0x443f8029,0x69c71024,0x442214ce,0x660394cf}},	//   eku_, _geje, _hnk_, genk,
   {{0x44f18104,0x7ae414d0,0xb4e40540,0x644980f7}},	//   _cơ_, luit, _नमो_, fhei,
   {{0x644994d1,0x442d94d2,0x628194d3,0x443f80ee}},	//   ghei, gje_, ello, gku_,
   {{0x660394d4,0xd5c614d5,0x326694d6,0x765c14d7}},	//   benk, वराज, итов, kiry,
   {{0x442d94d8,0x443f94d9,0x7c2d14da,0x442214db}},	//   aje_, aku_, zjar, _lnk_,
   {{0x850684c0,0x443f94dc,0x442d8353,0x6449851e}},	//   _خوان, bku_, bje_, bhei,
   {{0x644994dd,0x442d8d38,0x386694de,0x443f87df}},	//   chei, cje_, nnor_, cku_,
   {{0x7c22811b,0xfe2214df,0x7c2d14e0,0x95cb0f9c}},	//   _inor, मांस_, vjar, кува_,
   {{0x7ae414e1,0xdbf880c8,0x644614e2,0x30a68ff7}},	//   duit, _অফিস_, _alki, _крив,
   {{0x69c714e3,0x0ed30072,0x44f18129,0xfda70a27}},	//   _reje, _तिकड, _xơ_, _खलीफ,
   {{0xe51785e8,0x69c714e4,0x386914e5,0x660394e6}},	//   थिति_, _seje, _ujar_, zenk,
   {{0x7ae414e7,0x7c2d14e8,0xdb1982af,0x499282e3}},	// [a10] guit, rjar, _gewä, _دیگر,
   {{0x443f827f,0xdb1d0207,0xe4e700e8,0x442d94e9}},	//   zku_, _cesá, _кімн, zje_,
   {{0x442d94ea,0x69c714eb,0x644981b0,0x3ea900ee}},	//   yje_, _veje, yhei, _huat_,
   {{0x3ea914ec,0x7ae414ed,0x386681e8,0x660394ee}},	//   _kuat_, buit, gnor_, wenk,
   {{0x660394ef,0x443f94f0,0x44f18028,0x442d94f1}},	//   tenk, vku_, _sơ_, vje_,
   {{0xc3320158,0x3ea90812,0x9f568061,0x2fc914f2}},	//   _צום_, _muat_, ágát_, _leag_,
   {{0x442d94f3,0x3ea914f4,0x644994f5,0x58d414f6}},	//   tje_, _luat_, thei, _морт,
   {{0xa2d881ab,0x442d81e2,0x660394f7,0x443f94f8}},	//   _मिश्, uje_, senk, uku_,
   {{0x644994f9,0xa3e8901c,0xa3e50054,0x66038a9e}},	//   rhei, _बार_, _नाई_, penk,
   {{0x442d94fa,0x644994fb,0xa2d894fc,0xaca38135}},	//   sje_, shei, _मिर्, _anụm,
   {{0x2fc90ad0,0x442d94fd,0x6f0d14fe,0x84678098}},	//   _beag_, pje_, _asac, _къде,
   {{0x3ea914ff,0x64409500,0x442d8168,0x66fa8ec3}},	//   _buat_, ckmi, qje_, bākā,
   {{0x44d3009a,0x683f00f1,0xac7480f7,0x02a78cdf}},	//   eć_, _mëdh, _بالش, _трем,
   {{0xed5a1501,0x6d4e0192,0xa3e501a2,0x7c229502}},	//   гог_, tzba, _नाउ_, _znor,
   {{0x50b590f8,0x25e9123a,0xf1ca026f,0x38669503}},	//   _услу, _जारी_, ntáž_, ynor_,
   {{0x7ae41504,0xb603827f,0x47c61505,0x68e50122}},	//   tuit, _hráč, _убив, duhd,
   {{0xab271506,0x23271507,0xe1fa1508,0x44d30035}},	// [a20] бота_, боти_, лга_, ać_,
   {{0x78a908ae,0x3ea101f4,0x15461509,0x78a0950a}},	//   _čevr, _giht_, _геом, _simv,
   {{0x0ce2950b,0xa3e88128,0x7ae4150c,0x20120300}},	//   _মন্ত, _बाल_, suit, _kayi_,
   {{0xa2d8800c,0xdd2c8110,0x32058061,0xd6cf01f9}},	//   _मिल्, _nėšt, hely_, _تقی_,
   {{0x3866950d,0xa2a20540,0x78bb10d3,0x6ecb150e}},	//   rnor_, _कंट्, _čuve, तीपु,
   {{0x6f1b82af,0x20120041,0xdb1d0366,0x6459950f}},	//   _druc, _layi_, _besæ, _amwi,
   {{0xd132045b,0x6f1b819d,0x48e31510,0xa3cc00d4}},	//   _عمر_, _eruc, _норв, _रजा_,
   {{0xf0639511,0x6f1b9512,0xe8e0001c,0xa2b48993}},	//   _експ, _fruc, _chụp_, обич,
   {{0x25e91513,0x6440807b,0x66118198,0x2fc90037}},	//   _जाली_, rkmi, ökkä, _reag_,
   {{0xd90e84c0,0x64408074,0x683f03ed,0x66fa81a9}},	//   فیت_, skmi, _zëdh, rākā,
   {{0x20121514,0x5d868013,0x5316815b,0x28f8804a}},	//   _bayi_, _الال, _گذار, шень_,
   {{0x96eb0084,0x9f991515,0x6f0d1516,0x673d062c}},	//   льга_, ивну_, _psac, tysj,
   {{0x21270129,0x3c388036,0x32059517,0x6c7b83de}},	//   ̣nh_, _févr_, bely_, _גראד,
   {{0x6d1401fe,0x1bf89518,0xe6671519,0x25a51277}},	//   डिंग_, ्जवल_, стмо, øll_,
   {{0x3211009a,0x4035151a,0x64a3817f,0x20120db1}},	//   _razy_, _мекс, _uđit, _fayi_,
   {{0x0ca8151b,0x20120326,0x6b828c2e,0x6495936f}},	//   стри_, _gayi_, _kyog, _ušit,
   {{0x5a35151c,0xe7cc8035,0x6f0d113b,0x69ca951d}},	// [a30] онат, ारनप, _usac, _kefe,
   {{0xa3e5146d,0x6b82951e,0x27ed951f,0x69ca9520}},	//   _नाक_, _myog, _scen_, _jefe,
   {{0x201200a4,0x69ca826b,0x66070088,0xa3e89521}},	//   _yayi_, _mefe, mejk, बला_,
   {{0xac190765,0x69ca9522,0x753a0192,0x06ed064a}},	//   _тому_, _lefe, ätze, _जमाव_,
   {{0x644d1523,0x69ca80c9,0xd6db8aac,0x171c00be}},	//   mhai, _oefe, уте_, ָווע,
   {{0xf7708c48,0x644d1524,0x5bb38beb,0x30a71525}},	//   ران_, lhai, ीर्व, _грав,
   {{0xb0660009,0x32059526,0x91fc80eb,0x6b828c56}},	//   ntää, vely_, rnāl, _ayog,
   {{0x69d89527,0x628504b7,0x6b829528,0x69ca85ee}},	//   _adve, llho, _byog, _aefe,
   {{0x52a691e9,0x32058e25,0x69ca9529,0x290e8118}},	//   овым_, tely_, _befe, _asfa_,
   {{0xe8f9952a,0x2012152b,0x6b8282c4,0x5f1d152c}},	//   ало_, _sayi_, _dyog, मिन्_,
   {{0x386d8db7,0x69d80073,0x644d152d,0x69ca952e}},	//   _kjer_, óvei, khai, _defe,
   {{0xdb1d0364,0x76438aa2,0x645980b4,0xa3e50107}},	//   _kesä, lkny, _umwi, _नाग_,
   {{0x644d152f,0x7bcb80eb,0x3205816b,0x7643808e}},	//   dhai, _iegu, pely_, okny,
   {{0x76439530,0x69ca9531,0xe7e607e6,0xceb283de}},	//   nkny, _gefe, _काका_, ויך_,
   {{0x69c19532,0x2d8c0370,0x7bcb8812,0x6da30ae7}},	//   mble, åde_, _kegu, дира,
   {{0x644d1523,0xe3ba067c,0x62851533,0x76a0077f}},	//   ghai, рба_, elho, _báyì,
   {{0xe7ff8b04,0x764380dd,0xd0420085,0x764b0084}},	// [a40] ोजना_, kkny, xslə, _įgyv,
   {{0x7bcb9534,0xa7fb04c3,0x69c19535,0x25fb8bb8}},	//   _legu, riñe, nble, ल्मी_,
   {{0x644d1523,0x60c70282,0x03a60e97,0x6aa381b9}},	//   bhai, _cwjm, _мино, _minf,
   {{0x644d1536,0xef1a9537,0x6edb83eb,0xa7fb002a}},	//   chai, име_, _निशु, piñe,
   {{0x7c261538,0x2f189539,0x63b40035,0x386d89c4}},	//   _inkr, соль_, ągną, _djer_,
   {{0x644402a3,0x386d813c,0x6aa3953a,0x78a407b8}},	//   lkii, _ejer_, _ninf, _liiv,
   {{0x69ca953b,0x3af4039c,0xdd9381e5,0x69c182c4}},	//   _refe, läp_, машы, dble,
   {{0x6444153c,0xdee6953d,0x69ca953e,0x69c1953f}},	//   nkii, _моби, _sefe, eble,
   {{0x7e7c1540,0x16668098,0x9e669541,0x213e8114}},	//   korp, _двам, _двад, wyth_,
   {{0x7af601e2,0x76439542,0x645f05e7,0x7bcb8091}},	//   ityt, ckny, ziqi, _eegu,
   {{0x7c261543,0x6e371544,0x3a3800b9,0x644d1545}},	//   _onkr, _roxb, _morp_, yhai,
   {{0x69ba83eb,0x6aa39546,0x644d01c5,0x7bcb9547}},	//   _श्री, _einf, xhai, _gegu,
   {{0xdefb0196,0x09d500ab,0x44269548,0x64440079}},	//   шын_, স্টা, _ino_, dkii,
   {{0x44269549,0x3f850029,0x7c26154a,0x46dc154b}},	//   _hno_, ālu_, _ankr, _बिरह,
   {{0x644d154c,0x6607154d,0x7bcb954e,0x3495154f}},	//   thai, rejk, _yegu, завр,
   {{0xe019853e,0x68e89550,0x4426808e,0x8cdc12c6}},	//   _नोंद_, mudd, _jno_, _फिरो,
   {{0xa3e89551,0x68e89552,0x644d1553,0xb0660009}},	// [a50] _बाई_, ludd, rhai, stää,
   {{0x7c260353,0x09e300ab,0x65950139,0x387f9554}},	//   _enkr, ন্না, _напу, _skur_,
   {{0xdb098013,0x3a38037a,0x68e89555,0xceb981d0}},	//   iceá, _dorp_, nudd, _stř_,
   {{0x26c90010,0x44268365,0x670081bc,0x645f1556}},	//   _kwao_, _nno_, _ịkag, qiqi,
   {{0x7bcb9557,0x645d1558,0x68e89559,0x870780d7}},	//   _regu, _imsi, hudd, تبال,
   {{0x4426955a,0x4439120b,0x68e8955b,0x2cac955c}},	//   _ano_, _hos_, kudd, _budd_,
   {{0x4439155d,0x7bcb955e,0x7643955f,0x6aa38d02}},	//   _kos_, _pegu, rkny, _rinf,
   {{0x44391560,0x387f885c,0x7643808e,0x44268706}},	//   _jos_, _ukur_, skny, _cno_,
   {{0x44391561,0x9f4f8e1b,0xab659562,0x27ff8122}},	//   _mos_, regó_, явил, _ibun_,
   {{0x44391563,0x44269564,0x7e55803f,0x68e88c2e}},	//   _los_, _eno_, _عناص, fudd,
   {{0x2cac9565,0x7bcb9566,0x3ead9567,0x69c19568}},	//   _gudd_, _tegu, _huet_, rble,
   {{0x44d7802e,0xe8df001c,0xbbaa1370,0x69c18192}},	//   mă_, _chứa_, _कलेक, sble,
   {{0x7d1e09cf,0x644b9569,0x44d7802e,0x2fcd81c0}},	//   _srps, _ilgi, lă_, _meeg_,
   {{0x2fcd956a,0x4439156b,0x68e8956c,0x629d801b}},	//   _leeg_, _aos_, budd, ůsob,
   {{0x44d78012,0x7ae9956d,0x44268114,0x78a4156e}},	//   nă_, luet, _yno_, _tiiv,
   {{0x4426040e,0x2fcd90af,0x4439156f,0x5baa1570}},	//   ño_, _neeg_, _cos_, скам_,
   {{0x44391571,0x78bb003b,0xe9da11b1,0x64440079}},	// [a60] _dos_, _čuva, йка_, rkii,
   {{0xa7fb04c3,0x64441572,0x7c399106,0x27ff8041}},	//   miña, skii, _lowr, _abun_,
   {{0xe821035a,0xe8fa12e1,0x7af61573,0xa3e50f12}},	//   याचा_, сле_, styt, _नाच_,
   {{0xa3ea800c,0x1bea809a,0x44391574,0xafdb0257}},	//   _टाइप_, _टाइल_, _gos_, lhør,
   {{0x9cf880ab,0x7bc41575,0x2fcd9576,0xdfcf80a0}},	//   _আছেন_, mbiu, _deeg_, ايه_,
   {{0x443901c5,0x644b8084,0x44268b81,0x412a1577}},	//   _zos_, _algi, _sno_, _лого_,
   {{0xe7ed035a,0x44390282,0x44d78087,0x69dc00e8}},	//   _झाला_, _yos_, gă_, _idre,
   {{0xb6038029,0x44391578,0x68e302ba,0x69ce1579}},	//   ēšan, _xos_, ánde, _hebe,
   {{0x69ce0393,0x7ae9957a,0x7ae41434,0x66e3957b}},	//   _kebe, guet, nrit, _пота,
   {{0x64aa800d,0x69ce06ec,0x78ad957c,0x25fb80d4}},	//   _přid, _jebe, _čavr, ल्दी_,
   {{0x69ce157d,0x44d78012,0x6e28813c,0x7ae402af}},	//   _mebe, că_, _indb, hrit,
   {{0x4426957e,0x69ce157f,0x68e89580,0x5f1383ca}},	//   _uno_, _lebe, rudd, _धनम्_,
   {{0x69dc0025,0x44391581,0x68e89582,0x7ae98661}},	//   _odre, _ros_, sudd, cuet,
   {{0x8cb109a3,0x69ce1583,0xc6a41584,0x6266845a}},	//   _आंदो, _nebe, ерси, _عاشق,
   {{0x92e900c8,0x44391585,0x7ae40074,0x6fcc816f}},	//   _মনে_, _pos_, erit, ारां,
   {{0x69dc1586,0x7ae41587,0x765e1588,0x69ce011b}},	//   _adre, frit, _empy, _aebe,
   {{0x44391589,0x69ce158a,0x44d78012,0xe3b007bd}},	// [a70] _vos_, _bebe, ză_, ارف_,
   {{0x19ab03a7,0x4439158b,0x6d5909ab,0x200b158c}},	//   стап_, _wos_, _ƙwad, leci_,
   {{0x69ce158d,0x4439158e,0x3947158f,0x7ae400e5}},	//   _debe, _tos_, áns_, arit,
   {{0x44d78087,0x645d01f6,0x4add8d86,0x2fcd822c}},	//   vă_, _umsi, _मिलव, _qeeg_,
   {{0x3ea58074,0x24891217,0x2fc08333,0x66171590}},	//   _pilt_, mlam_, ñiga_, _kaxk,
   {{0x69ce1591,0x44d78012,0x1dbf0f97,0x6e3a8362}},	//   _gebe, tă_, ्रित, _cotb,
   {{0x7bcf059c,0x78a2826f,0x661702a3,0x7c39809a}},	//   _kecu, ňova, _maxk, _powr,
   {{0x44d78012,0x3ea58613,0x200b120e,0xa01b016d}},	//   ră_, _wilt_, jeci_, slöj,
   {{0x44d7802e,0x4add816f,0x1dbf016f,0x7bcf1592}},	//   să_, _मिळव, ्रात, _mecu,
   {{0xe0d99593,0x39459594,0x2d85809a,0x44d78087}},	//   ово_, дног, _tyle_, pă_,
   {{0x24891595,0x69c501e4,0x7ae401ac,0x7ae98cdb}},	//   klam_, ibhe, zrit, suet,
   {{0xb9220870,0x25c601cb,0x7bcf0087,0xa7fb002a}},	//   _akpọ_, वर्ण, _necu, tiña,
   {{0x6d439596,0xba558081,0x99830196,0x00000000}},	//   lyna, _откъ, _kojų_, --,
   {{0xc87902bb,0xa7fb04c3,0x09e300ab,0xdb218216}},	//   duğu_, riña, ন্তা, _ñuño,
   {{0xbea31597,0x7bcf1598,0x9872016b,0xa7fb03a8}},	//   тарк, _becu, láč_, siña,
   {{0x69ce1599,0xd9f0159a,0xd7ff002e,0x7e63826c}},	//   _sebe, _चाहत_, şări_, hinp,
   {{0x78ae159b,0x64bc0024,0x78bc026c,0x7bcf159c}},	// [a80] _subv, _očig, _strv, _decu,
   {{0x7ae4159d,0x2489159e,0x1cba003f,0xe8df001c}},	//   rrit, alam_, _واجب_, _chữa_,
   {{0xdb1d01df,0xfbc6159f,0x7bcf15a0,0x2d9615a1}},	//   _xesú, _обно, _fecu, _юрис,
   {{0xab2a153d,0x31368158,0x248915a2,0x7d1c808b}},	//   _дома_, ונעם_, clam_, _ársi,
   {{0x69ce15a3,0x09e300ab,0x394601a9,0xe73795a4}},	//   _tebe, ন্ধা, ņos_, мец_,
   {{0x69dc15a5,0x65948162,0xdcba95a6,0x69ce0192}},	//   _udre, налу, ощи_, _uebe,
   {{0x0ee0835a,0x2df980d7,0x6935128a,0xdb060646}},	//   _निवड, سبوک_, _přeš, _afkø,
   {{0x3218008e,0x25de0d14,0xdb1d0511,0x64aa801b}},	//   _hary_, कृती_, _resú, _přib,
   {{0x41e68d13,0xa3c10074,0xc5e600ab,0x25fb95a7}},	//   міна, ुरत_, খ্যা_, ल्ही_,
   {{0xd25095a8,0xd62695a9,0x6d4395aa,0x2fc680e4}},	//   اند_, _تعري, byna, lbog_,
   {{0x6d4395ab,0xc87f0192,0xa01b0198,0x321801c6}},	//   cyna, toß_, llöi, _mary_,
   {{0xa3e8800d,0xc32a80f7,0xb9068af3,0xd5b1827d}},	//   _बाट_, _وكان_, _पि_, _tác_,
   {{0xa2d88105,0xdca395ac,0xd78b00f7,0x7bcf15ad}},	//   _मिट्, _раци, تخدم_, _recu,
   {{0x200b0025,0x386015ae,0x3eb985a4,0x7bcf079a}},	//   seci_, _emir_, _éste_, _secu,
   {{0x38b701cd,0x248915af,0x6d550037,0x320c95b0}},	//   _oħra_, tlam_, uzza, medy_,
   {{0xa7fb04c3,0xd49815b1,0xfc150071,0x28d815b2}},	//   miño, дру_, эмбэ, _डिजि,
   {{0x7bcf00eb,0x6d43809a,0x2fc6806a,0x32180a7a}},	// [a90] _vecu, zyna, dbog_, _bary_,
   {{0x321815b3,0x248915b4,0xae0082f1,0xa2b00a27}},	//   _cary_, slam_, ल्मन_, _अंर्,
   {{0xa3c38b6f,0x1bd515b5,0x24890214,0x69c5125b}},	//   ्रम_, _поня, plam_, rbhe,
   {{0x3f8904b9,0x61fe1384,0x2fc695b6,0x64bc0362}},	//   _kyau_, afpl, gbog_, _dčid,
   {{0xe4560159,0xdb028028,0xa3e88fb2,0x320c81ac}},	//   _נישט_, _ngoà, _बाज_, kedy_,
   {{0x2451827f,0x7aed03ac,0x46e082f1,0x645a01a9}},	//   _máme_, muat, _निरह, ītie,
   {{0x7aed0be5,0x82b881bc,0xc98415b7,0x7e6395b8}},	//   luat, _rịịl_, _аути, rinp,
   {{0xe7f9800d,0xdb1d0b40,0xa19415b9,0xa3c10697}},	//   _एउटा_, _besø, _расч, ुरि_,
   {{0x442b06cb,0x7e6395ba,0x2ef48098,0x25a9803d}},	//   _mnc_, pinp, _изтр, _فضای_,
   {{0x442b0122,0x291e0084,0x850f001b,0x4ae2052a}},	//   _lnc_, _štai_, ाबाट_, _पिसव,
   {{0x7aed15bb,0xa3c115bc,0xf8660a13,0x3f8909ab}},	//   huat, ुरा_, евно, _ayau_,
   {{0x7aed15bd,0x66e615be,0x9ac48372,0xdee615bf}},	//   kuat, нома, _boċċ, номи,
   {{0xe801835a,0x7aed15c0,0x7c2b95c1,0x64498192}},	//   ळ्या_, juat, _ingr, mkei,
   {{0x443d8051,0x78a995c2,0x95860088,0x442b15c3}},	//   _how_, _liev, елге, _anc_,
   {{0xa7fb062f,0x628195c4,0xda020a0d,0x26d915c5}},	//   ciño, molo, र्फत_, asso_,
   {{0x7aed022e,0x628195c6,0x78a995c7,0x7c3d00b9}},	//   fuat, lolo, _niev, _cosr,
   {{0x3b070698,0xae008e5b,0xfe720065,0x2c01809a}},	// [aa0] нето_, ल्डन_, _مدد_, व्यू_,
   {{0x9b9300f7,0x443d8039,0x98d38ad5,0xb77b01c6}},	//   الكت, _low_, _दबाए, _מאפש,
   {{0x26c0120e,0x644995c8,0x61fe016d,0x7c2b95c9}},	//   _htio_, kkei, rfpl, _ongr,
   {{0x672415ca,0x443d8051,0xdfcf8013,0x7aed09ca}},	//   _krij, _now_, ميم_, buat,
   {{0x78a995cb,0x91fc80eb,0x7bd615cc,0x7aed15cd}},	//   _diev, onāt, mayu, cuat,
   {{0x25fb901b,0x7c2b95ce,0x628195cf,0x7bd615d0}},	//   ल्ली_, _angr, jolo, layu,
   {{0xa3e40740,0xafe695d1,0x291e01fa,0x7c3d0748}},	//   _नया_, _повл, _éta_, _yosr,
   {{0x64498352,0x98a395d2,0x78a995d3,0x7bd615d4}},	//   gkei, _бисе, _giev, nayu,
   {{0x0edc01ce,0x7afb90c1,0xdb1981ec,0x68e10106}},	//   _बिगड, gtut, _gewü, _åldr,
   {{0x628195d5,0x27e015d6,0x7bd615d7,0xef178110}},	//   golo, _adin_, hayu, _яму_,
   {{0x694680fe,0xa3b3801b,0x7afb8cdb,0x320c95d8}},	//   _očeš, जुङ_, atut, redy_,
   {{0x44fa88cf,0x672415d9,0x661a826c,0xa7fb05e4}},	//   më_, _brij, _hatk, riño,
   {{0x62818042,0xff0415da,0x44fa80f1,0x672415db}},	//   bolo, лярн, lë_, _crij,
   {{0x661a8364,0x672403e9,0x27e015dc,0x442b047f}},	//   _jatk, _drij, _edin_, _snc_,
   {{0x44fa88cf,0x661a95dd,0x25a500f2,0x7c3d0805}},	//   në_, _matk, äll_, _posr,
   {{0x6d588353,0x27e0017f,0x672415de,0x7aed15df}},	//   izva, _gdin_, _frij, tuat,
   {{0xc6a715e0,0x672415e1,0x44fa80f1,0x6aaa95e2}},	// [ab0] _прои, _grij, hë_, _kiff,
   {{0x78a98029,0xda7815e3,0x44fa80f1,0x6aaa81b9}},	//   _siev, нях_, kë_, _jiff,
   {{0xdd9115e4,0x78a98029,0x7aed0867,0x44fa820f}},	//   _خود_, _piev, suat, jë_,
   {{0x644f15e5,0x648580f7,0x7aed15e6,0x44fa83ed}},	//   _ulci, hóir, puat, dë_,
   {{0x628195e7,0x661a8267,0xdb070009,0x44fa81b0}},	//   yolo, _batk, ämäs, eë_,
   {{0x443d95e8,0x628195e9,0x99d40154,0x9f4f8077}},	//   _sow_, xolo, _متفا, nggé_,
   {{0x628195ea,0x92a60063,0x648580f7,0xdd918065}},	//   volo, _dołą, dóir, گوں_,
   {{0x628195eb,0x7afb8098,0x38668087,0xed6404e8}},	//   wolo, ttut, cior_, loží_,
   {{0x644995ec,0xdd918065,0x661a8168,0x200f95ed}},	//   rkei, دوں_, _fatk, megi_,
   {{0x7afb95ee,0x644995ef,0x69d704c3,0x200f95f0}},	//   rtut, skei, naxe, legi_,
   {{0x7afb95f1,0x6aaa8806,0x672402fd,0xa3c380c2}},	//   stut, _diff, _srij, ्रद_,
   {{0x672415f2,0x20040a56,0xa3d284c5,0xd5648638}},	//   _prij, ými_, वरण_, _ступ,
   {{0x628195f3,0x6aaa95f4,0x6e3e01a1,0xddd8807a}},	//   polo, _fiff, _popb, lovš,
   {{0x672415f5,0x248d95f6,0x63bb8098,0xfce615f7}},	//   _vrij, llem_, lcun, кого,
   {{0x6b8b95f8,0x7ae995f9,0x7bd615fa,0xe81d15fb}},	//   _hygg, lret, tayu, _बोका_,
   {{0xc9528051,0x27e0015d,0x15ee0035,0x7bc98d35}},	//   _כמו_, _udin_, _जाकर_, nbeu,
   {{0xdca315fc,0x64a30110,0xcb6715fd,0x0b4315fe}},	// [ac0] рати, рата, вате_, антн,
   {{0x7bd604a7,0x7ae9802a,0x6b8b92f1,0xbea615ff}},	//   sayu, iret, _mygg, _шапк,
   {{0x661a8009,0xfe370039,0xa3c3873c,0x249f9600}},	//   _ratk, _סרטי_, ्रा_, kmum_,
   {{0x69469601,0x628700b9,0xddd8824a,0x44fa8168}},	//   _učeš, _ekjo, dovš, vë_,
   {{0x248d9602,0x92a6009a,0x69ca008b,0x38669603}},	//   dlem_, _połą, ðfes, rior_,
   {{0x44fa88cf,0x7ae98620,0x68e88114,0x629d9412}},	//   të_, dret, yrdd, ïsol,
   {{0x81d780ab,0x38668106,0x7ae99604,0x200f9605}},	//   িলা_, pior_, eret, begi_,
   {{0x44fa88cf,0x6aaa9606,0x43948b69,0x291800a4}},	//   rë_, _siff, лайс, _isra_,
   {{0x44fa88cf,0x661a8359,0x6d47009a,0x648580f7}},	//   së_, _tatk, zyja, tóir,
   {{0x91fc8029,0x5ea68b76,0x3eb985a4,0x60c49607}},	//   ciāl, _شمال, _ésta_, _čimb,
   {{0x67229608,0x248d9609,0x648580f7,0xb6a38162}},	//   lvoj, blem_, róir, _тифл,
   {{0xdb04160a,0x7ae9960b,0x4bda819f,0x648581a8}},	//   nció, bret, _آباد_, sóir,
   {{0x7336845b,0xf09f023e,0x7ae9960c,0xdb040333}},	//   _جرائ, rmà_, cret, ició,
   {{0x52d78039,0x201b00dd,0xceb383c8,0x200f960d}},	//   _יודע_, _waqi_, ייש_, zegi_,
   {{0x4fc70652,0x984f009a,0x3eac8aa2,0x201b0187}},	//   _испа, jęć_, _midt_, _taqi_,
   {{0x3eac8022,0x62870370,0x57f5160e,0x3dd88264}},	//   _lidt_, _skjo, _спит, _সাফল,
   {{0xb275160f,0x3a750162,0x2d8c9610,0x667200d7}},	// [ad0] глаш, глар, _lyde_, شگیر,
   {{0x6722803a,0x68e302ba,0x7aef809f,0x78ad01c0}},	//   dvoj, ándo, àcti, _hiav,
   {{0x200f9611,0xa3d28076,0xf1a71612,0x2d8c8366}},	//   tegi_, वरा_, тран, _nyde_,
   {{0x25ff05fc,0x69d71613,0x69ca007b,0xa01b1614}},	//   श्री_, saxe, ðfer, mlös,
   {{0x7c2f1615,0x200f9616,0x64aa801b,0xd6db9617}},	//   _incr, regi_, _přin, фте_,
   {{0xe29a8104,0xdb04040e,0x6b8b8bfa,0x644d0364}},	//   _như_, ació, _rygg, lkai,
   {{0x91fc8029,0x62851618,0x58d41619,0x30a7961a}},	//   riāl, moho, _вост, _арав,
   {{0xdb04161b,0x69d5161c,0x6285161d,0xc1720039}},	//   cció, _heze, loho, _החל_,
   {{0x69d50065,0x248d961e,0x6f098754,0xac9680f7}},	//   _keze, rlem_, _upec, دنيا_,
   {{0x7ae9961f,0x3f7a8158,0x69d51620,0x63bb9621}},	//   rret, _אָבע, _jeze, scun,
   {{0x10a600c4,0x644d0009,0x69d51622,0x2ba483db}},	//   лион, kkai, _meze, खेबा,
   {{0xcea9093f,0x69d51623,0x7ae98558,0xf99204de}},	//   _זי_, _leze, pret, מרי_,
   {{0x442f896c,0xe28e9624,0x78ad1625,0x643a81c6}},	//   _ing_, _га_, _diav, _רעננ,
   {{0x69d51626,0xa01b01ec,0x7c2f1627,0x644d0196}},	//   _neze, flös, _ancr, ekai,
   {{0xa5070fbf,0x2d8c013c,0xed5a1628,0xdb0b806a}},	//   лера_, æde_, хов_, _afgø,
   {{0x7c3b8886,0x644d1629,0x442f962a,0x78ad162b}},	//   njur, gkai, _jng_, _giav,
   {{0x69d5162c,0x28d78f97,0x33d5021e,0x2ca002f1}},	// [ae0] _beze, _भौति, ріст, rmid_,
   {{0x64560578,0x442f820d,0x62851486,0x2ca0162d}},	//   shyi, _lng_, goho, smid_,
   {{0x442f962e,0x69d5162f,0x4fea9630,0x00e61631}},	//   _ong_, _deze, емен_, ужен,
   {{0x6493029a,0x442f85ee,0xf3f98493,0x644d0196}},	//   nçil, _nng_, biţi_, ckai,
   {{0xdb040c15,0x44201632,0x62851633,0xbe8a9634}},	//   rció, mdi_, boho, нске_,
   {{0x442f9635,0x69d51636,0x20d18390,0x67229637}},	//   _ang_, _geze, kši_, rvoj,
   {{0xdb04040e,0x442f862f,0x20d18db7,0x78b502a5}},	//   pció, _bng_, jši_, _guzv,
   {{0x33269638,0x661e0110,0x26c69639,0x44de81b9}},	//   _prox_, _lapk, ppoo_, rċ_,
   {{0x76418065,0x4420163a,0x442f963b,0x78ad047f}},	//   _foly, idi_, _dng_, _riav,
   {{0x7641831d,0x78a2963c,0x644d011e,0x4420163d}},	//   _goly, lmov, zkai, hdi_,
   {{0xd48f963e,0x1994963f,0x2d8c009a,0x7413803d}},	//   _гр_, раня, żdej_, _گونا,
   {{0x4d7b8f60,0x44201640,0x78a28333,0xd0e5800c}},	//   _ארבע, jdi_, nmov, _किरण_,
   {{0xa2b005e8,0xead49641,0x44201642,0xe29a8028}},	//   _अंग्, _толь, ddi_, _thư_,
   {{0x44201643,0x98bc001b,0x2bd2940d,0x64429151}},	//   edi_, ávě_, सरवा, _hooi,
   {{0x69da9644,0x442f8355,0x644d0364,0x78a28353}},	//   mate, _yng_, tkai, kmov,
   {{0x69da9645,0x78a280ce,0x44201646,0xa01b1647}},	//   late, jmov, gdi_, rlös,
   {{0x644d0483,0x644282d8,0x90980c48,0xa01b12d2}},	// [af0] rkai, _mooi, _حضور_, slös,
   {{0x644d1648,0x629c0c3f,0x44201649,0x7d1a964a}},	//   skai, _chro, adi_, _osts,
   {{0x21270104,0x69d5164b,0x442002a3,0x3915164c}},	//   ính_, _veze, bdi_, рмер,
   {{0x644290f4,0x69d5164d,0x69da964e,0x628500b4}},	//   _nooi, _weze, hate, soho,
   {{0x7bda0496,0xfe7f023e,0x2d9c01d6,0xf6e7964f}},	//   _בקרו, buït_, _úver_, уцен,
   {{0x20d71650,0x7aed1651,0xf6259652,0x4e00864a}},	//   _مترج, mrat, рдко, ल्लई_,
   {{0xe3b18307,0x69da9653,0xa3b91094,0x76419654}},	//   يرة_, date, _चला_, _voly,
   {{0x20d1803b,0x6ee780d5,0x1309835f,0x7bcd1655}},	//   vši_, _مسئل, вний_, nbau,
   {{0x7c3b9656,0x92020054,0x69da8428,0x64429657}},	//   rjur, र्वज_, fate, _dooi,
   {{0x2480803b,0x7aed1658,0x212789da,0xf41f016d}},	//   čima_, irat, _prnh_, _skäl_,
   {{0x44201659,0x6493080a,0xdddc025b,0x27e0808b}},	//   ydi_, tçil, jorš, ðing_,
   {{0x442f965a,0x186a0153,0x20d193cf,0x6729965b}},	//   _ung_, тами_, rši_, _krej,
   {{0x69da965c,0x442001b9,0x7aed026c,0x6c8481a8}},	//   bate, vdi_, jrat, _النم,
   {{0x69da8039,0xfed780ab,0x8cb10035,0x78a284e8}},	//   cate, _সমাধ, _आंखो, zmov,
   {{0xada6165d,0xdb1207ca,0x4420011c,0x6da614b8}},	//   равл, _ágús, tdi_, рива,
   {{0x4420165e,0x3b00022b,0x6729965f,0x2b099660}},	//   udi_, ttiq_, _orej, _वहाँ_,
   {{0x44201661,0x5baa06d2,0xfe7f0722,0x62661662}},	// [b00] rdi_, ткам_, tuït_, аваа,
   {{0x2bb80076,0x09e61663,0x2243026c,0x91e600bf}},	//   _अलवा, рожн, _cojk_, роже,
   {{0x2cf49664,0x290100f7,0x44201665,0x78a29666}},	//   _इमेल_, gtha_, pdi_, tmov,
   {{0x67299667,0x69da9668,0x44201669,0x64aa928a}},	//   _brej, zate, qdi_, _přim,
   {{0x2bd301fe,0x629c0051,0x78a2826f,0x69da966a}},	//   तररा, _thro, rmov, yate,
   {{0x672988cf,0xa11600d7,0x69da966b,0x2901166c}},	//   _drej, _پورت, xate, btha_,
   {{0x69da966d,0x2508819f,0xafdb0aa2,0x320a0118}},	//   vate, ارتی_, ljøe, _ibby_,
   {{0x69da966e,0x67299554,0x6d4a966f,0x249d9670}},	//   wate, _frej, ryfa, _chwm_,
   {{0x67299671,0x69da9672,0xa2b38198,0xd1ca9673}},	//   _grej, tate, обыч, кунд_,
   {{0x38ba9674,0x6f029675,0x16639676,0x32549677}},	//   _për_, mtoc, _двум, свор,
   {{0xa3d60816,0x6f0d1678,0x672980e1,0x91a980ff}},	//   हरा_, _spac, _zrej, _đã_,
   {{0x69da9679,0x64bc0088,0xa3c38eb6,0x7aed0071}},	//   sate, _pčin, ्रः_, yrat,
   {{0x69da967a,0x98be8196,0xfe7f0980,0x00000000}},	//   pate, dytą_, duïr_, --,
   {{0x7aed07aa,0x9f4002af,0x2d840214,0x69d8007b}},	//   vrat, _weiß_, ğmen_, ðvel,
   {{0x0467167b,0x25fb9513,0x7aed0372,0x24920114}},	//   атам, ल्टी_, wrat, flym_,
   {{0x7aed167c,0x200900b9,0x6f02967d,0x69d8967e}},	//   trat, _ubai_, ktoc, _heve,
   {{0x7bcd167f,0x6f0d0397,0x64aa801b,0x69d89680}},	// [b10] rbau, _upac, _přij, _keve,
   {{0x62888114,0xe9ab07d2,0x35f50a13,0x290100b9}},	//   nodo, ندان_, _упор, ttha_,
   {{0xdfd180f7,0x69d88722,0x38690506,0x66151681}},	//   كيا_, _meve, _kmar_, mezk,
   {{0x69d89682,0x67299683,0x62889684,0x7aed1685}},	//   _leve, _prej, hodo, prat,
   {{0x53350158,0x29011686,0xdefb8198,0x48dd8074}},	//   _האָב_, stha_, тые_, _कौनो_,
   {{0x9e648cde,0xb6079687,0x69d89688,0xddc3802e}},	//   овід, рядк, _neve, dinţ,
   {{0x7ae280eb,0x62889689,0xd469968a,0x48ab81e5}},	//   _avot, dodo, лике_, _атам_,
   {{0xeb99968b,0x6729968c,0xfd5501bc,0xdd2801a9}},	//   лий_, _trej, _slaị, nēša,
   {{0x69d8968d,0x67298353,0x9f44080a,0x62888114}},	//   _beve, _urej, ümü_, fodo,
   {{0x38690727,0x2fdd822c,0x69d8968e,0x00000000}},	//   _amar_, lawg_, _ceve, --,
   {{0x69d8968f,0xf5958013,0x8d958013,0x6615011e}},	//   _deve, _الاج, _الاش, dezk,
   {{0x20560a14,0xa856038c,0x3d01809a,0x6e219690}},	//   стор, стој, mów_, _halb,
   {{0x6e219691,0x62889692,0x41a7016f,0x443f9693}},	//   _kalb, bodo, केतस, mju_,
   {{0x69d882d8,0x6615011b,0xb6cc8380,0x645b9694}},	//   _geve, gezk, _şükü, lhui,
   {{0x3d018063,0x7bd983ac,0xc69283c8,0x443f8084}},	//   nów_, _kewu, פאל_, oju_,
   {{0x645b9695,0x69d89696,0x78a38cfa,0xd5b18129}},	//   nhui, _zeve, ïnvl, _cái_,
   {{0x7bd98057,0x04431697,0x3aba80be,0x03a30d91}},	// [b20] _mewu, четн, ָמענ, зито,
   {{0x3d018d38,0x64bc0fda,0x443f8074,0x3f920300}},	//   ków_, _učio, hju_, _iyyu_,
   {{0x24891698,0x499a0a14,0x3d018035,0x645b9699}},	//   boam_, утая_, jów_, khui,
   {{0x7bd989b6,0x3d01809a,0x6e21813c,0x6f02969a}},	//   _newu, dów_, _aalb, ttoc,
   {{0x443f969b,0xf3ff80ab,0x645b969c,0x8bff80ab}},	//   dju_, ্যার_, dhui, ্যান_,
   {{0x4422059e,0x7c24169d,0x443f969e,0x6446169f}},	//   _hak_, ldir, eju_, _hoki,
   {{0x6f0296a0,0x44220988,0x644601e2,0x7bd996a1}},	//   stoc, _kak_, _koki, _bewu,
   {{0x44221308,0x7c24158a,0x644616a2,0xa3a980bc}},	//   _jak_, ndir, _joki, _गृह_,
   {{0x442216a3,0x35fa845b,0x6e2181e4,0x64460110}},	//   _mak_, _مراد_, _falb, _moki,
   {{0xc333004c,0x69d8820f,0x6e2196a4,0x6e9696a5}},	//   פות_, _qeve, _galb, _الطا,
   {{0x443f96a6,0x3d01809a,0x78b88713,0xa3b90006}},	//   bju_, ców_, _quvv, _चलल_,
   {{0x442216a7,0x443f8699,0x645b96a8,0x69de16a9}},	//   _nak_, cju_, chui, hape,
   {{0x7645003e,0x628896aa,0x69d896ab,0x69de16ac}},	//   _pohy, podo, _teve, kape,
   {{0x3dd900c8,0x7aef86a5,0x7c22810c,0xdce500e1}},	//   _তাহল, ácte, _haor, _vzhľ,
   {{0x69de16ad,0x64aa800d,0xe57300f7,0x66150102}},	//   dape, _přih, سطس_, rezk,
   {{0x386916ae,0x7c2416af,0x60c781d0,0x2fdd822c}},	//   _umar_, gdir, íjme, xawg_,
   {{0x7c2296b0,0x644616b1,0x27e903c3,0x442216b2}},	// [b30] _maor, _doki, _idan_, _dak_,
   {{0x443f84b7,0x7b7400f7,0xb9210870,0x765c16b3}},	//   zju_, أطفا, _gasị_, chry,
   {{0x7c2416b4,0xbebd96b5,0x672d03c1,0xf6520039}},	//   bdir, _trūk, _hraj, _חצי_,
   {{0x442216b6,0x7c228052,0x64bc005c,0x6e2196b7}},	//   _gak_, _naor, _očij, _salb,
   {{0x443f96b8,0x69de16b9,0xe73996ba,0x3d018035}},	//   vju_, bape, рел_, wów_,
   {{0xdb1d04b8,0x3d018063,0x6e2196bb,0xc332010f}},	//   _besö, tów_, _qalb, _קום_,
   {{0x443f96bc,0x442216bd,0xed5996be,0xf53280a9}},	//   tju_, _yak_, рой_, дејќ,
   {{0x3d018063,0x6e2182a3,0x7bdf16bf,0x7c2296c0}},	//   rów_, _walb, naqu, _caor,
   {{0x443f96c1,0x3d018063,0x6e2196c2,0x645b83b2}},	//   rju_, sów_, _talb, rhui,
   {{0xe9d985f1,0x27e916c3,0xda6580e8,0x443f96c4}},	//   шко_, _adan_, івни, sju_,
   {{0x69c196c5,0x26c9008e,0x443f96c6,0xd94596c7}},	//   rcle, _atao_, pju_, цени,
   {{0x672d16c8,0x60cd8267,0x69de16c9,0x1faa05f1}},	//   _braj, _čamd, zape, икни_,
   {{0x442216ca,0x7bdf16cb,0xb69b16cc,0x644616cd}},	//   _rak_, daqu, rtân, _roki,
   {{0x442216ce,0x8aa796cf,0x672d16d0,0xb69b16cc}},	//   _sak_, _уред, _draj, stân,
   {{0x442216d1,0xa3bd835a,0x644601ac,0x69de16d2}},	//   _pak_, _आला_, _poki, vape,
   {{0x69de16d3,0x7c228118,0xdb1d041c,0x7c240037}},	//   wape, _xaor, _lesõ, udir,
   {{0xe9da16d4,0x7c2416d5,0x20050201,0xf41282f6}},	// [b40] ика_, rdir, əli_, ופן_,
   {{0x442216d6,0x22478a53,0x7c2416d7,0x4996066c}},	//   _wak_, _jonk_, sdir, ошет,
   {{0x69de16d8,0x6da616d9,0x644616da,0x8c4616db}},	//   rape, _фина, _toki, _дене,
   {{0xdd0f0214,0x7c24011c,0x9f4800ff,0x7bdf16dc}},	//   lışt, qdir, _điêu_, caqu,
   {{0x9eaa8ba1,0xcfbc00ab,0x245c0061,0x4ea696dd}},	//   авда_, _অজান, _címe_, орка,
   {{0xe29716de,0x7c22808c,0x412a16df,0x7ae401a8}},	//   _мая_, _saor, _кого_, msit,
   {{0x910315e0,0xf9878f24,0xd90d019f,0x7ae400f7}},	//   _опре, _آب_, _میل_, lsit,
   {{0x7bc416e0,0xfd530091,0x6ee381bc,0x7ae416e1}},	//   nciu, _aifọ, _ọber, osit,
   {{0x69dc01f9,0x6fd08105,0x7ae416e2,0x224796e3}},	//   _kere, _ड्यू, nsit, _bonk_,
   {{0x245181a8,0x20000362,0x442482f7,0x7ae416e4}},	//   _lámh_, _acii_, sdm_, isit,
   {{0x69dc045c,0x224796e5,0x26c902a5,0x7bdf16e6}},	//   _mere, _donk_, _stao_, yaqu,
   {{0x69dc16e7,0x672d16e8,0x7ae416e9,0xe0cf87d2}},	//   _lere, _praj, ksit, کزی_,
   {{0x7648808e,0xfd530032,0x674701e2,0x2005066f}},	//   _kody, _fifọ, цэнз, ęli_,
   {{0x248980e1,0x7bc616ea,0x76488242,0x672d16eb}},	//   čame_, _afku, _jody, _vraj,
   {{0x7bdf00e7,0xa3c80135,0x2bc80133,0x764896ec}},	//   taqu, _ọbịa_, _ọjị_, _mody,
   {{0x672d16ed,0xd6db0364,0x69dc0081,0x67209351}},	//   _traj, _кто_, _aere, _osmj,
   {{0x69dc16ee,0x201916ef,0x7ae400e4,0x7bdf16f0}},	// [b50] _bere, mesi_, gsit, raqu,
   {{0x201916f1,0x661896f2,0x69dc079a,0x7bc401e8}},	//   lesi_, jevk, _cere, aciu,
   {{0x69dc005f,0x7bdf16f3,0xc0158009,0x7d0d8035}},	//   _dere, paqu, змещ, łasz,
   {{0x765a96f4,0x201916f5,0x78bc16f6,0x7ae416f7}},	//   _alty, nesi_, _durv, bsit,
   {{0x2ca916f8,0x27e0807b,0x69dc16f9,0x7bdd02f9}},	//   mmad_, ðina_, _fere, _iesu,
   {{0x69dc16fa,0x7bdd16fb,0x518716fc,0x2ca916fd}},	//   _gere, _hesu, _дуба, lmad_,
   {{0xdfd596fe,0x7bdd0859,0x69c516ff,0xdb1b81df}},	//   _новы, _kesu, mche, rcuí,
   {{0x69c51700,0x7bdd1701,0x0b458081,0x7d7c00be}},	//   lche, _jesu, знин, ינוו,
   {{0x2bdc0076,0x7bdd1702,0x69dc1703,0x76d580f7}},	//   बरता, _mesu, _yere, _رياض,
   {{0x69dc1704,0x7bdd1705,0x69c51706,0x09af00ab}},	//   _xere, _lesu, nche, _চ্যা,
   {{0x69c51707,0x20191708,0x2c0c0054,0xdcef8084}},	//   iche, fesi_, ड्डू_, _įdėt,
   {{0x2458837d,0x7bdd01e2,0x315600be,0x20191709}},	//   _téma_, _nesu, פירן_, gesi_,
   {{0x2451970a,0x64aa81d0,0x2905970b,0x69cc970c}},	//   _námi_, _přiv, stla_, _द्वी,
   {{0xfe79801b,0x6e25170d,0x69c5170e,0x68e7082c}},	//   _svůj_, _cahb, jche, _ovjd,
   {{0x61e18364,0x2019026e,0x386d970f,0x7bdd1710}},	//   mall, besi_, _omer_, _besu,
   {{0x7ae41711,0x20191712,0x61e19713,0x248d81b0}},	//   tsit, cesi_, lall, noem_,
   {{0x69dc1714,0x7bdd006a,0x7bc40019,0x2d9e026f}},	// [b60] _pere, _desu, rciu, ťte_,
   {{0x7bc40098,0xba231715,0x27e200dd,0x78bc0612}},	//   sciu, ндук, lakn_, _purv,
   {{0x7ae41716,0x76488110,0xda0204c5,0x7bc41717}},	//   ssit, _rody, र्गत_, pciu,
   {{0x69dc1718,0x61e19719,0x7bdd171a,0x7ae4171b}},	//   _were, hall, _gesu, psit,
   {{0x61e1971c,0x387f816d,0xddcf801b,0x69c5171d}},	//   kall, _djur_, _řeše, bche,
   {{0x69c50098,0x78bc037b,0x61e1971e,0x7bdd09b6}},	//   cche, _turv, jall, _zesu,
   {{0x2019171f,0x20c18104,0x7bdd1720,0x7c261721}},	//   yesi_, _nói_, _yesu, _kakr,
   {{0x321a009a,0x9e66826a,0x7bdd03a8,0xadc30032}},	//   lepy_, _کارن, _xesu, _diẹd,
   {{0x66188038,0x61e19722,0x6720920e,0x20191723}},	//   pevk, fall, _usmj, vesi_,
   {{0x20191724,0x61e19725,0x7aef9726,0xe3bf1727}},	//   wesi_, gall, ácta, _maña_,
   {{0x20191728,0x60cd82a5,0x6e251729,0x69c3007a}},	//   tesi_, _čamc, _rahb, žneg,
   {{0x78a4172a,0x7c26172b,0x7ac6841c,0xe3a78019}},	//   _chiv, _nakr, _еске, _کشمی,
   {{0x2bd29513,0x61e1972c,0x2019172d,0xaa7b01d0}},	//   _ध्या, ball, resi_, _svým,
   {{0x7bdd0393,0x4426972e,0x61e1972f,0x80d200ab}},	//   _sesu, _hao_, call, _হিন্,
   {{0x4426803a,0x20c1801c,0x7bdd08e5,0x20191730}},	//   _kao_, _gói_, _pesu, pesi_,
   {{0x7c260cc0,0x9584009a,0xbebd96b5,0x6e2500b9}},	//   _cakr, _łącz, _krūt, _wahb,
   {{0xd6d78a49,0x4426951e,0x69c51731,0xe3bf06a5}},	// [b70] _সম্প, _mao_, tche, _caña_,
   {{0x44269732,0x27e08125,0x69c51733,0x386d9734}},	//   _lao_, ðinn_, uche, _smer_,
   {{0x69c506f8,0x7bdd1735,0x291906e2,0xfaa801a8}},	//   rche, _tesu, تقاد_, أهلي_,
   {{0x69c51736,0x44269737,0xd75980f7,0x61e19738}},	//   sche, _nao_, يلات_, zall,
   {{0x44291739,0x4439173a,0x69c5173b,0x61e1973c}},	//   mda_, _ins_, pche, yall,
   {{0x4439173d,0x7c260491,0x5fce8327,0x61e1973e}},	//   _hns_, _zakr, हुबल, xall,
   {{0x442902a3,0x44268028,0xc10515a9,0x7c3a0174}},	//   oda_, _bao_, _توزي, _úcrá,
   {{0x4429173f,0x44268104,0x61e19740,0xf53800be}},	//   nda_, _cao_, wall, לטור_,
   {{0x61e1855b,0x27ed9741,0xdb0982d0,0x20c18129}},	//   tall, _iden_, _önüm, _sói_,
   {{0x44291742,0x81bc81a9,0x25a0928a,0x7ea01743}},	//   hda_, ldēj, řila_, köpa,
   {{0x44391744,0x44291745,0x26cd82ee,0x61e19746}},	//   _ons_, kda_, _hteo_, rall,
   {{0x61e19747,0x44291748,0xd36e8077,0x2fdf867f}},	//   sall, jda_, اهی_, _jeug_,
   {{0x442912a8,0x61e19749,0xe28e974a,0xbebd80eb}},	//   dda_, pall, _аа_, _grūt,
   {{0x4439174b,0x4429174c,0x4426822e,0x6da609b8}},	//   _ans_, eda_, _zao_, дига,
   {{0x4426822e,0x7afb84a2,0x7c260110,0x27e200dd}},	//   _yao_, luut, _pakr, pakn_,
   {{0x4429174d,0x26cd825b,0x5ed380ab,0x442680ff}},	//   gda_, _oteo_, _সিনে, _xao_,
   {{0x1e860615,0x644b974e,0xeb97174f,0x7c299750}},	// [b80] _олим, _mogi, дит_, ider,
   {{0x44391751,0x44261752,0x645d1753,0x7c26004f}},	//   _ens_, žo_, _elsi, _wakr,
   {{0x44291754,0x661c1755,0x27e00352,0x7c261756}},	//   bda_, merk, _kein_, _takr,
   {{0x7c299757,0x7afb9758,0x442902a3,0x3ebf9759}},	//   jder, kuut, cda_, _buut_,
   {{0x27e00352,0x44268028,0x2fdf81e4,0xdd8f00d7}},	//   _mein_, _rao_, _deug_, _موی_,
   {{0x4426975a,0x27ed975b,0x7c29975c,0x27e0031d}},	//   _sao_, _eden_, eder, _lein_,
   {{0xda0e80ff,0x2ee680b9,0xa3aa01d0,0xa3cb175d}},	//   _bỏng_, ssof_, गेर_, रुव_,
   {{0xe9a3175e,0x6724175f,0x644b9760,0x27e010f6}},	//   _расп, _osij, _cogi, _nein_,
   {{0x1dcf863a,0x60cd8289,0x7afb9761,0x44269762}},	//   _स्वत, _čama, guut, _vao_,
   {{0x4426822e,0x2489805c,0xdb22809a,0x64aa801b}},	//   _wao_, čama_, _źród, _přis,
   {{0x44269763,0x09f70051,0x44291764,0xd48f8012}},	//   _tao_, ומים_, yda_, _ар_,
   {{0x442902a3,0xdbd604a2,0x7afb9765,0x26c0047f}},	//   xda_, _jääd, buut, _buio_,
   {{0x27e002af,0xfe730154,0x26c00118,0x6e2880b9}},	//   _dein_, ندس_, _cuio_, _kadb,
   {{0x44390eef,0x661c1766,0x44291767,0x63a29768}},	//   _sns_, gerk, wda_, _izon,
   {{0x44290085,0x27e01769,0x44390b99,0x6fde8006}},	//   tda_, _fein_, _pns_, मरां,
   {{0xd5b8176a,0xaa7b026f,0x7af60168,0x4429176b}},	//   ься_, _zvýh, fryt, uda_,
   {{0x6e3a83b2,0xa3aa016f,0xf0940039,0xfc3f0216}},	// [b90] _ontb, गेल_, _בנק_, _chía_,
   {{0x4429176c,0x6e28976d,0x27e0011e,0x7674176e}},	//   sda_, _nadb, _zein_, _альф,
   {{0x7c29976f,0x80e080ab,0x66051770,0xdb0d016a}},	//   yder, পূর্, _ichk, rcañ,
   {{0x44291771,0x44391772,0x245c0125,0x7af61773}},	//   qda_, _uns_, _tíma_, bryt,
   {{0x6e288079,0x22940106,0x6d550061,0xa3c29774}},	//   _badb, täkt_, lyza, ंशन_,
   {{0xe5a58e8e,0xceb8809a,0x603e8087,0x6da59775}},	//   нили, _cię_, _pămâ, нила,
   {{0x63a28065,0x61e51776,0xdc3a82d0,0x2ca68706}},	//   _azon, mahl, _açıs, _bhod_,
   {{0x03259777,0x27ed8022,0x69ca9778,0x61e51779}},	//   един, _uden_, _affe, lahl,
   {{0x7c29977a,0x27e0177b,0xe61082e3,0x661c177c}},	//   rder, _rein_, _چشم_, yerk,
   {{0x27e0177d,0x7c299045,0x63a2977e,0x3945977f}},	//   _sein_, sder, _dzon, еног,
   {{0x661c088b,0x7afb9780,0x9f4200d7,0x644b838a}},	//   verk, suut, maké_, _togi,
   {{0xed56893f,0x661c1781,0xe7308065,0x6e288035}},	//   _אבער_, werk, _حصہ_, _zadb,
   {{0x661c1782,0x443e001c,0x3a2786c0,0x61e50234}},	//   terk, _đt_, _tanp_, kahl,
   {{0xe3bf1783,0x64bc1784,0x2cad9785,0x7ae99786}},	//   _baño_, _očit, lmed_, mset,
   {{0x40960676,0x61e5010b,0xa97980be,0x7ae99787}},	//   _прит, dahl, _מאַכ, lset,
   {{0x46ea0698,0xe3bf06a5,0xfc3f001c,0x7bc99788}},	//   _един_, _daño_, _phía_, nceu,
   {{0x7ae99789,0x9f4203f8,0x27450168,0x3860178a}},	// [ba0] nset, kaké_, _vënë_, _ilir_,
   {{0x7ae9978b,0x2cad978c,0x9f42026f,0x99858019}},	//   iset, hmed_, jaké_, lelő_,
   {{0x7ae99266,0xf77f041c,0x50ba0060,0x6e28978d}},	//   hset, maça_, سداد_, _radb,
   {{0xceb88610,0x27e0978e,0x2002178f,0xe3a7845b}},	//   _się_, úin_, ngki_, _مر_,
   {{0xe8050c28,0x2cad8074,0x61e51790,0x7ae99791}},	//   ष्टा_, dmed_, bahl, jset,
   {{0x7ae99792,0xf77f023e,0x9c7c80c3,0xae040072}},	//   dset, naça_, _ivči, श्चन_,
   {{0xf653010f,0x6e28807a,0x7ae99793,0xa9a301a1}},	//   רצו_, _vadb, eset, _бирд,
   {{0x7ae99794,0x25a081d0,0x2bd3001b,0x69a51795}},	//   fset, řilo_, धुपा, _करती,
   {{0x6e2883ac,0x087780be,0x3f8188c5,0x7ae99796}},	//   _tadb, _נעמט_, şhur_, gset,
   {{0x27e69797,0xdb2381a8,0x38601798,0x3eba1799}},	//   laon_, órái, _alir_, _nipt_,
   {{0x3860179a,0xd5a484e5,0x88bc801b,0x67d500e8}},	//   _blir_, _ओरिज, jvět, кону,
   {{0x248000ce,0x27e6979b,0x61e5179c,0xa3b103dd}},	//   jnim_, naon_, zahl, टेड_,
   {{0x24800025,0x64bc179d,0xe784179e,0x3ce30072}},	//   dnim_, _očis, гуро, टीने_,
   {{0xbb3b8451,0x09e380ab,0xfc3f00ff,0xe3bf0388}},	//   _מעדי, _মাথা, _chín_, _paño_,
   {{0xceb380be,0x321e9122,0x27e68bb1,0x89338481}},	//   טיש_, mety_, kaon_, _معيا,
   {{0xd49814d6,0x6d55009a,0x321e89a4,0x61e5179f}},	//   еру_, ryza, lety_, wahl,
   {{0x200c0201,0x29180037,0x09e38264,0xf77f02df}},	// [bb0] ədi_, _apra_, _মাতা, baça_,
   {{0x7afd809f,0x248017a0,0x9e6701a8,0xa15917a1}},	//   àsti, anim_, _ساخن, мазу_,
   {{0xa3e08fd5,0xdfd180f7,0x61e517a2,0xf7730019}},	//   थरा_, ليا_, rahl, _جاں_,
   {{0x24800052,0x1b1780ab,0x2918008e,0xddc88bcf}},	//   cnim_, তিতে_, _dpra_, _ćoša,
   {{0xd9ad97a3,0x321e826f,0x7c2d17a4,0x58b881a8}},	//   _घण्ट, kety_, mdar, رامج_,
   {{0x7c2d17a5,0x7ae997a6,0x442b17a7,0x644f17a8}},	//   ldar, vset, _hac_, _hoci,
   {{0x644f17a9,0x64aa800d,0x64bc17aa,0xfc3180f7}},	//   _koci, _přip, _učit, لحة_,
   {{0x2489881d,0x7ae997ab,0x63a217ac,0xf3ff02df}},	//   čamo_, tset, żone, _imãs_,
   {{0x644f17ad,0x1c4297ae,0x9f42003d,0x2cad97af}},	//   _moci, рным, paké_, rmed_,
   {{0xa77480e9,0x7ae997b0,0x248000ce,0x7c2d17b1}},	//   _случ, rset, znim_, hdar,
   {{0x320b809a,0x442b0980,0x7c2d17b2,0x09e38264}},	//   ęcy_, _oac_, kdar, _মাদা,
   {{0x442b0114,0x7c2d17b3,0x7ae997b4,0x26df8135}},	//   _nac_, jdar, pset, _kwuo_,
   {{0x7c2d17b5,0x442d8b0b,0xf8b28158,0xe813816f}},	//   ddar, mde_, ישט_, ण्या_,
   {{0xf1b1053f,0x23690035,0xa3d40072,0x99858061}},	//   जधान, dzaj_, सुन_, selő_,
   {{0x1d070dae,0xfc3f0118,0x442b17b6,0x7c2b97b7}},	//   кери_, _chío_, _bac_, _kagr,
   {{0x644f040e,0x7c2d020d,0x442b17b8,0xc48310ca}},	//   _coci, gdar, _cac_, алск,
   {{0x7c2b97b9,0xa3e317ba,0xc0530039,0x628186cb}},	// [bc0] _magr, _नजर_, _כזה_, onlo,
   {{0x248002a5,0x442d8364,0x7c2b97bb,0x60c397bc}},	//   snim_, hde_, _lagr, _kunm,
   {{0x442b0012,0x27e69049,0x442d97bd,0x7c2d17be}},	//   _fac_, taon_, kde_, bdar,
   {{0x442d97bf,0x38608013,0xd00f8eca,0x7e6197c0}},	//   jde_, óir_, قلم_, _allp,
   {{0x442d97c1,0xe1e784c0,0x442017c2,0x27e697c3}},	//   dde_, _پس_, mei_, raon_,
   {{0x442017c4,0x442d97c5,0x290c8085,0x765c17c6}},	//   lei_, ede_, ytda_, nkry,
   {{0x442d90f4,0x614317c7,0x3cfd801b,0xa8068256}},	//   fde_, _кера, रूले_, _извл,
   {{0x6abb0118,0x409597c8,0x78bb97c9,0x442b027d}},	//   _éufr, _брут, _giuv, _xac_,
   {{0x68e1013c,0x26df819d,0xd7078087,0x799c0114}},	//   _ældr, _gwuo_, _инте_, _hyrw,
   {{0x386680a9,0x7c2b97ca,0x442017cb,0x7c2d17cc}},	//   lhor_, _eagr, hei_, zdar,
   {{0x442017cd,0x26c497ce,0xdd1f81ac,0x5ec780ab}},	//   kei_, _humo_, píšt, রীদে,
   {{0xf9930051,0x386683a7,0x68e31735,0x7c2b80d7}},	//   ירת_, nhor_, ândi, _gagr,
   {{0x442017cf,0x6d588110,0x260980d4,0x321e89a4}},	//   dei_, lyva, _सामी_, pety_,
   {{0x7c2b97d0,0xdce50038,0x27e4802e,0x61e397d1}},	//   _zagr, _vyhľ, _lemn_, _genl,
   {{0x644f0a7a,0x241901bb,0x61e897d2,0x40350a08}},	//   _poci, новы_, madl, _бейс,
   {{0xfbd304c0,0x69ce0a0f,0x7c2d14e4,0x442017d3}},	//   شتر_, _afbe, udar, gei_,
   {{0x521517d4,0x386697d5,0x644f17d6,0x6d4a0706}},	// [bd0] лдат, dhor_, _voci, _àfan,
   {{0x442d97d7,0xf09f009f,0xa2c381a2,0x78bb8084}},	//   zde_, llà_, रदत्, _siuv,
   {{0xf770096c,0x442017d8,0x21270104,0x6d5d8201}},	//   _های_, bei_, ình_, _əsas,
   {{0x61e897d9,0xcfde80c8,0x24868a20,0x442017da}},	//   hadl, _ডাউন, _njom_, cei_,
   {{0x442d97db,0xd9e386a7,0x61e897dc,0xdbd102f1}},	//   vde_, _ग़लत_, kadl, _müüd,
   {{0x442d97dd,0x6abc0609,0x26c482ed,0x6a6001fa}},	//   wde_, _girf, _dumo_, _höfn,
   {{0x7c2b97de,0x2609816f,0x61e897df,0x442d97e0}},	//   _pagr, _साठी_, dadl, tde_,
   {{0x6281862d,0x61e397e1,0x290117e2,0x26c497e3}},	//   wnlo, _senl, muha_, _fumo_,
   {{0x442d97e4,0x60c397e5,0x7aed11e6,0x78660693}},	//   rde_, _sunm, nsat, _jóve,
   {{0x442d9313,0xb7bd802e,0x78660073,0x672997e6}},	//   sde_, _naţi, _móve, _isej,
   {{0x61e397e7,0x7c2b97e8,0x26c497e9,0x290117ea}},	//   _venl, _tagr, _zumo_, nuha_,
   {{0x44e181e2,0xbf9b0073,0x442017eb,0x6f1b8133}},	//   mų_, rgên, xei_, _kpuc,
   {{0x442017ec,0x7866007b,0x44e18110,0x7bdb97ed}},	//   vei_, _nóve, lų_, mbuu,
   {{0x249f97ee,0x290117ef,0x442017f0,0x38ca8077}},	//   llum_, kuha_, wei_, بایی_,
   {{0x44e181e2,0x765c17f1,0x7cd180eb,0x7afb84dc}},	//   nų_, rkry, _dārg, lrut,
   {{0x765c079f,0x78660e15,0xa3e68105,0x290117f2}},	//   skry, _bóve, _बड़ा_, duha_,
   {{0xfc3f003e,0x7aed17f3,0xcb6717f4,0x64a3076a}},	// [be0] _dní_, gsat, гате_, сата,
   {{0x442017f5,0x44e181e2,0xfeba0277,0x6b9d031d}},	//   sei_, kų_, _ثابت_, _dysg,
   {{0x44e181e2,0x629e17f6,0x442017f7,0x249f97f8}},	//   jų_, rlpo, pei_, klum_,
   {{0x8c4617f9,0x7afb97fa,0x44e18110,0x6abc17fb}},	//   _семе, krut, dų_, _wirf,
   {{0x09e800ab,0x7aed1380,0x7e788b67,0xe3b2015b}},	//   _পাঠা, csat, tivp, _درد_,
   {{0x2ca017fc,0x290117fd,0x6d588084,0xb5e20264}},	//   llid_, buha_, tyva, _বাঁচ,
   {{0x386697fe,0x2cc981ac,0x61e897ff,0x44e18110}},	//   phor_, _ľudí_, vadl, gų_,
   {{0x7afb9800,0x260981c4,0x7bdb9801,0x26c49802}},	//   frut, _साथी_, gbuu, _tumo_,
   {{0x68f5803e,0x3075831f,0x61e89803,0x41e68221}},	//   ázdn, _турс, tadl, ліна,
   {{0x471b80be,0x39148329,0xdbd10074,0xfd5d8870}},	//   _אומג, амор, _süüd, _jizọ,
   {{0x3de2150b,0x26098e18,0x69da9175,0x2ca00074}},	//   _বাংল, _साती_, rbte, klid_,
   {{0x7aed02a3,0xfc3f001c,0x7afb9804,0x3ebe9805}},	//   ysat, _phím_, brut, _hitt_,
   {{0x543b8158,0x7afb9806,0x61e89807,0xf77f03a7}},	//   _רעדא, crut, padl, raço_,
   {{0x26e5000f,0xcf9381c6,0x6d498035,0x6a60008b}},	//   _कबीर_, מטר_, ślał, _söfn,
   {{0x3ebe9808,0xf77f0073,0x6d4a07b6,0xf09f0980}},	//   _mitt_, paço_, _àfal, plà_,
   {{0x3ebe8cde,0x248d1809,0x7aed180a,0x2ca002f1}},	//   _litt_, čemo_, tsat, glid_,
   {{0x3a75180b,0x78ad180c,0xb27501a1,0x998c0b80}},	// [bf0] алар, _ihav, алаш, _ćoše_,
   {{0x7aef840e,0x7ed40013,0x5ed380c8,0x7bcd180d}},	//   ácti, _ازيا, _সিলে, scau,
   {{0x7aed180e,0x66758077,0xf1a7180f,0xc9841810}},	//   ssat, یدتر, уран, буци,
   {{0x29011811,0x2c27035f,0x7aed1812,0x2ca01813}},	//   ruha_, _сьог, psat, clid_,
   {{0xb8170768,0xe81701b6,0xf7459814,0x26009815}},	//   ध्यम_, ध्या_, рело, _राखी_,
   {{0x62830259,0x44e181e2,0x09df00ab,0x7bc28176}},	//   čnos, tų_, _ঢাকা, _agou,
   {{0x3ebe9816,0xd6580051,0x58d4153d,0x7ae29817}},	//   _ditt_, ריות_, _гост, _awot,
   {{0xeb999687,0x99840013,0x7afb9818,0x44e18110}},	//   кий_, _الفو, trut, rų_,
   {{0x6f1b8024,0x09e800ab,0xc8649819,0x6729981a}},	//   _upuc, _পাতা, _утри, _usej,
   {{0x6285181b,0x7cd18029,0x7afb981c,0x7c2f117e}},	//   nnho, _pārd, rrut, _lacr,
   {{0xa06a181d,0x61e7181e,0x888608cc,0x186a181f}},	//   вана_, _mejl, илож, вани_,
   {{0xb4c19094,0xfa2580c8,0x7cd18029,0x78ad1820}},	//   ंदी_, বাইল_, _vārd, _chav,
   {{0xe9ce9821,0x2ca01822,0x7ae29823,0x7d039824}},	//   _мк_, vlid_, _gwot, luns,
   {{0x442f9825,0x61e7000d,0x3ebe09df,0x6e239826}},	//   _hag_, _nejl, ött_, nenb,
   {{0x442f9827,0xc62800ab,0xfd5d81bc,0x7d039828}},	//   _kag_, মালা_, _rizọ, nuns,
   {{0x442f84b5,0xbc630ab5,0xa3ac8935,0x26c41829}},	//   _jag_, овск, _गरम_, ímos_,

   {{0xa3b1016f,0x62970118,0x91fc80eb,0x6e23982a}},	// [c00] टेल_, foxo, bkād, kenb,
   {{0xe9d700bf,0x442f982b,0x7ea0016d,0xd0e68fd3}},	//   ику_, _lag_, köpi, _حکیم_,
   {{0x3f9f982c,0x61e7013c,0x7d038669,0xa926182d}},	//   _ayuu_, _dejl, juns, рдел,
   {{0x442f982e,0x3ebe888b,0x7d03982f,0x60c7082c}},	//   _nag_, _sitt_, duns, _dujm,
   {{0x7c2407e1,0x61e71830,0x6e239831,0x2d9e9832}},	//   meir, _fejl, fenb, _syte_,
   {{0x7c241833,0xb4c19834,0x6e239835,0x7c2f012b}},	//   leir, ंदू_, genb, _zacr,
   {{0x394700f2,0x3ebe9836,0xddc8809a,0xafe68110}},	//   änst_, _vitt_, _podł, _вобл,
   {{0x7c24156b,0x442f9837,0x7ae28247,0x44321838}},	//   neir, _cag_, _pwot, ndy_,
   {{0x15e6000f,0x27e0807b,0x6e239839,0xd5b180ff}},	//   करार_, ðinu_, benb, _máy_,
   {{0x80ca8935,0x7d1e035f,0xf1aa0035,0x2d96983a}},	//   _संदे, _opps, _करान, _крес,
   {{0x3a370051,0x4432003e,0x442f983b,0xd57580e8}},	//   ברים_, kdy_, _fag_, _луць,
   {{0x442f983c,0x7c240ba3,0x69c3983d,0x1b1d0264}},	//   _gag_, jeir, _egne, নিতে_,
   {{0x7c24183e,0x4424983f,0x7ad486e2,0x629c1840}},	//   deir, mem_, _اقتص, _okro,
   {{0xa2c386a7,0x442f9841,0x78a2816b,0x443200e1}},	//   रदर्, _zag_, hlov, edy_,
   {{0x7c24031d,0x58871842,0x78a2816b,0xa4d5004a}},	//   feir, _выпа, klov, собі,
   {{0x44249843,0x61300117,0x78a28d11,0x7c241844}},	//   nem_, zólá, jlov, geir,
   {{0x78a29845,0x44249846,0x644d1847,0xa3b10035}},	// [c10] dlov, iem_, rjai, टें_,
   {{0x44249848,0x62851849,0xa3cb184a,0x6e23984b}},	//   hem_, unho, रुज_, xenb,
   {{0x4424984c,0x61e7013c,0x7c24184d,0x6285184e}},	//   kem_, _vejl, beir, rnho,
   {{0x7c24184f,0x60c084b9,0x27e91850,0x9ef581a8}},	//   ceir, _cimm, _jean_, مستش,
   {{0x44249851,0x6e239852,0x442f9853,0x2b470071}},	//   dem_, tenb, _rag_, _тэнг,
   {{0x64428307,0x442f9854,0x7d039855,0x672d004f}},	//   _anoi, _sag_, tuns, _msaj,
   {{0x442f9856,0x78a28b67,0x60c0807b,0x40358098}},	//   _pag_, blov, _fimm, _левс,
   {{0x44249857,0x7d039858,0x7cd180eb,0x213e00f7}},	//   gem_, runs, _pārb, _átha_,
   {{0x442f9859,0x6e23985a,0x7d03985b,0x753a8102}},	//   _vag_, penb, suns, _ertz,
   {{0x4432185c,0x442f985d,0x60c082af,0x7d038077}},	//   zdy_, _wag_, _zimm, puns,
   {{0x236d8063,0x442f8252,0x4424985e,0x2913011b}},	//   szej_, _tag_, bem_, ntxa_,
   {{0x4424985f,0x7c24184f,0x442f81c0,0x245c008b}},	//   cem_, xeir, _uag_, _tími_,
   {{0x7c240548,0x43749860,0x6d410502,0x6d5c0428}},	//   veir, _мушт, ålan, wyra,
   {{0xda0305b3,0x6d5c1861,0xa3bd1862,0x69c39863}},	//   _लागत_, tyra, ेखन_, _ugne,
   {{0x7c241864,0x78a29865,0x98a7928a,0x27e91866}},	//   teir, ylov, íně_, _fean_,
   {{0x27e91867,0x29059868,0x3fe609a5,0xe8171869}},	//   _gean_, mula_, _ужив, ध्दा_,
   {{0x2905986a,0x7c24186b,0x387d8114,0x64aa81d0}},	// [c20] lula_, reir, diwr_, _přiz,
   {{0x7c24186c,0x09e800ab,0x0f3701c6,0x200d8493}},	//   seir, _পাহা, _פריט_, _acei_,
   {{0x7d1e186d,0xed5a07ff,0xe8fa186e,0x27e900b9}},	//   _upps, _сон_, уле_, _yean_,
   {{0x4424986f,0x673b8ca3,0x3a259870,0x16058006}},	//   xem_, _bruj, help_, _राउर_,
   {{0x44249871,0x78a29872,0x29059873,0x7bc60122}},	//   vem_, rlov, hula_, _igku,
   {{0x78a29874,0x412a0cde,0x29059875,0xa3d40075}},	//   slov, _його_, kula_, सुर_,
   {{0x60c09876,0x26098701,0x7bc60122,0x9ac301b9}},	//   _timm, _सारी_, _kgku, ċċes,
   {{0x29059877,0xbf4d81d0,0x6d5900fc,0xafdb1277}},	//   dula_, _šířk, _ƙwaz, hjør,
   {{0xe7378364,0x53349878,0x673b9879,0x66e3987a}},	//   _лет_, цепт, _gruj, _нота,
   {{0x4424987b,0x3d190d38,0x6f060ebf,0x2905987c}},	//   sem_, _पहले_, dukc, fula_,
   {{0x2905987d,0x6e93987e,0x44248873,0x3a370039}},	//   gula_, _علما, pem_, זרים_,
   {{0x6ca6826a,0xc867187f,0x5edd0264,0xc95301c6}},	//   _اصطل, стои, _বিবে, למת_,
   {{0xa3bc9880,0x27e91881,0x26c1033e,0xb8ef86ae}},	//   _आणि_, _vean_, _piho_, _वू_,
   {{0x29058a40,0x63a29882,0xafdb00e8,0x161b8c28}},	//   bula_, _iyon, gjør, प्पर_,
   {{0x29059883,0x865b898a,0x63a2808e,0x280401d0}},	//   cula_, נדלי, _hyon, ásné_,
   {{0xd49b0912,0xd5d901ce,0x81c000ab,0x213f026c}},	//   ург_, _ब्रज, ীরা_, _čuh_,
   {{0x32550a13,0x672d004f,0x62889884,0x26099885}},	// [c30] овар, _usaj, ondo, _साली_,
   {{0x62889886,0x80db80ab,0x98bf0084,0xf8c9827d}},	//   nndo, _ভিত্, tytė_, _mẩn_,
   {{0x38691887,0x63a29888,0x62889447,0x09e80264}},	//   _klar_, _lyon, indo, _পাশা,
   {{0x629a9889,0xf77080d5,0x6e27188a,0x27e9988b}},	//   hoto, کام_, lejb, úan_,
   {{0xddc5835f,0x290594e6,0x2489188c,0x61f8988d}},	//   обли, zula_, mnam_, _odvl,
   {{0xe61890ac,0xdce8817b,0x38690722,0x673b81a1}},	//   йді_, _aydı, _llar_, _vruj,
   {{0xe80a00cf,0x38690201,0x69c7035f,0x2489188e}},	//   _वाला_, _olar_, _igje, onam_,
   {{0x06d880ab,0x63a28c56,0xe459988f,0x29058234}},	//   _সিরি, _byon, ржи_, vula_,
   {{0x24891890,0x29059891,0xf8c980ff,0x60ca81ec}},	//   inam_, wula_, _cẩn_, _aufm,
   {{0x29059892,0x629a9893,0x63a286c4,0x38691894}},	//   tula_, goto, _dyon, _alar_,
   {{0x6026076a,0xd8261895,0x63a29896,0x38691897}},	//   одна, одни, _eyon, _blar_,
   {{0x29059898,0x38691899,0xe73a07c4,0x27ef80dd}},	//   rula_, _clar_, аем_, nagn_,
   {{0x2905989a,0x63a28365,0x6235957b,0xde888133}},	//   sula_, _gyon, _меду, lịa_,
   {{0x2905989b,0x61ea989c,0x629a989d,0x2489189e}},	//   pula_, _gefl, coto, enam_,
   {{0xdd920a47,0x8c7a0081,0x2c6706ae,0x66010789}},	//   ذور_, ащат_, _sõda_, ólka,
   {{0x60c91482,0x69c700f1,0x69d501ed,0x2489189f}},	//   _čemp, _agje, _afze, gnam_,
   {{0xd46718a0,0x161b00d4,0xc88916a5,0x03a30729}},	// [c40] ците_, _पॉवर_, _دخول_, дито,
   {{0xae0e8aed,0xafdb054f,0x78a618a1,0x25ad06d4}},	//   _साधन_, ljøp, llkv, řela_,
   {{0x4fc698a2,0x38cb00d5,0x7cf081a8,0xc7c698a3}},	//   осла, لانی_, _mórá, осли,
   {{0xdca60e97,0x69da18a4,0x629a804f,0x09aa0072}},	//   _фами, _प्री, zoto, _करीय,
   {{0x41c9800c,0x644618a5,0x3ced0024,0x629a8010}},	//   रशास, _inki, ćeve_, yoto,
   {{0x72c30364,0x4733835f,0x6b849024,0xa3dc8072}},	//   _обяз, ьніс, _žigo, तुन_,
   {{0x629a98a6,0x26120074,0x78660118,0x68ed8035}},	//   voto, _तानी_, _nóvo, _ładn,
   {{0x69c7020f,0x7c3618a7,0x629a98a8,0x6ab298a9}},	//   _zgje, ndyr, woto, ँग्र,
   {{0x3ce9803b,0x629a82b8,0x38690362,0x3e6b8163}},	//   ćava_, toto, _rlar_, _søte_,
   {{0x2489105e,0xd25a80c4,0x24800079,0x7afd98aa}},	//   znam_, рци_, hiim_, ásta,
   {{0xaca401bc,0x2bac8424,0x628884fe,0x64460198}},	//   _alọt, _चरवा, rndo, _onki,
   {{0x0b4698ab,0x7ea00106,0x63a298ac,0x6f0298ad}},	//   _мнен, köps, _tyon, oroc,
   {{0x629a8c93,0x60c418ae,0x628f8866,0x06cc8264}},	//   poto, _diim, écoc, রীরি,
   {{0x5edd00ab,0x628e026c,0x22580102,0x644618af}},	//   _বিদে, _njbo, _nork_, _anki,
   {{0xd7fb18b0,0x64c518b1,0x60c418b2,0x6b60826b}},	//   _куп_, वदेश, _fiim, _fágú,
   {{0x38690458,0xd14b004e,0x60c418b3,0x6f0298b4}},	//   _ular_, یشان_, _giim, kroc,
   {{0x248918b5,0x3f8c0085,0x27ef98b6,0x22580d05}},	// [c50] rnam_, şdur_, vagn_, _bork_,
   {{0xe80d85b3,0x644618b7,0x9388102a,0xe817064a}},	//   _हाहा_, _enki, іста_, ध्रा_,
   {{0xf7d88133,0x47d881bc,0xb11301bc,0x7ea4823e}},	//   _ịrụp, _ịzụk, pụmk, còpi,
   {{0xb8f318b8,0xc95380be,0x6f028037,0x2ee900fc}},	//   _हं_, ומע_, froc, _kwaf_,
   {{0x442918b9,0xe73998ba,0x6f0298bb,0x872781a8}},	//   mea_, сел_, groc, تعام,
   {{0x442918bc,0x27ef9277,0xb9010264,0x9605914f}},	//   lea_, sagn_, _দি_, रलेट_,
   {{0x308588ca,0x224998bd,0x3b0900b9,0x2fc902c4}},	//   _فلسف, _đak_, luaq_, _ogag_,
   {{0x442918be,0x6f0298bf,0x2fc90420,0x68ed8035}},	//   nea_, broc, _ngag_, _łado,
   {{0x4ea7838c,0xa3bd001b,0xeda8001b,0x225818c0}},	//   _држа, ेखि_, _गर्छ, _york_,
   {{0x28cf81b6,0x442918c1,0x27ed83b2,0xcb120496}},	//   _संदि, hea_, _heen_, עלי_,
   {{0x44290bec,0xd945919d,0x60c418c2,0x98a60087}},	//   kea_, чени, _piim, зине,
   {{0x26c5822e,0xc4d28039,0x442918c3,0x60c40079}},	//   _hilo_, _נגד_, jea_, _qiim,
   {{0x442918c4,0x60c418c5,0xeb8e98c6,0x27ed98c7}},	//   dea_, _viim, _чи_, _meen_,
   {{0xc4c60013,0xd35684de,0x27ed98c8,0xbb3a82f6}},	//   كترو, _מיני_, _leen_, _לעני,
   {{0xceb28051,0xc1aa009a,0x442918c9,0x44f701b9}},	//   גים_, _करेग, fea_, għ_,
   {{0x7c2998ca,0x26c584be,0x442918cb,0x6f0298cc}},	//   neer, _lilo_, gea_, yroc,
   {{0x2ee900fc,0x20120a03,0x2d850866,0x26c58f3e}},	// [c60] _gwaf_, _icyi_, ûler_, _oilo_,
   {{0x628198cd,0x26c590ab,0x7c2998ce,0x69de8074}},	//   nilo, _nilo_, heer, _õpet,
   {{0x2366003b,0x27ed98cf,0x7c2998d0,0x35a618d1}},	//   šoj_, _been_, keer, _ханг,
   {{0x69c388fd,0x225818d2,0x442918d3,0xc18c80be}},	//   _रणनी, _work_, cea_, סטאָ,
   {{0x628198d4,0xbea68160,0x225818d5,0x7c2998d6}},	//   kilo, падк, _tork_, deer,
   {{0x6b8907ca,0x98ac880a,0x26c580c3,0xa3b10054}},	//   _þega, ılır_, _cilo_, _ओरत_,
   {{0x7c2998d7,0x628198d8,0x26c598d9,0x645998da}},	//   feer, dilo, _dilo_, _bowi,
   {{0x27ed98db,0x7c2998dc,0x629e18dd,0x67240267}},	//   _geen_, geer, lopo, _opij,
   {{0x6459809a,0x26c598de,0x61ee18df,0xd00f98e0}},	//   _dowi, _filo_, _kebl, _حلق_,
   {{0x442918e1,0x628198e2,0x25a58b64,0x26c589c4}},	//   zea_, gilo, _fyll_, _gilo_,
   {{0x7c298c56,0x764898e3,0x442918e4,0x61ee009a}},	//   beer, _indy, yea_, _mebl,
   {{0xa3e6800f,0x629e18e5,0x7c298a0f,0x27ed01df}},	//   _बजट_, hopo, ceer, úen_,
   {{0xb8d398e6,0x6a600125,0x629e18e7,0x765a98e8}},	//   _जी_, _höfu, kopo, _koty,
   {{0xcad78051,0x628198e9,0x61ee0084,0x20f8026c}},	//   _צוות_, cilo, _nebl, kči_,
   {{0x442918ea,0x765a98eb,0x20f8050b,0x629e0cd9}},	//   tea_, _moty, jči_, dopo,
   {{0xa3d4000d,0x81e900ab,0x4fc70fe6,0xea0000ff}},	//   सँग_, _যাই_, _эска, _đạn_,
   {{0x442918ec,0xe7e30d38,0x261a035a,0x245818ed}},	// [c70] rea_, _क्या_, म्ही_, чать_,
   {{0x32d2801c,0x765a98ee,0x61fc0122,0x7d0a88ae}},	//   _mây_, _noty, _cdrl, kufs,
   {{0x442918ef,0x80a404c0,0x30158009,0x26c58122}},	//   pea_, _زمین, ддер, _rilo_,
   {{0x2c090077,0x7c2998f0,0x5ee18264,0x9f4b18f1}},	//   _بعدی_, xeer, _নিবে, hací_,
   {{0x7c2998f2,0x61ee18f3,0x2ca918f4,0x67f80019}},	//   veer, _febl, mlad_, lújí,
   {{0x2ca918f5,0xe5a598f6,0x645998f7,0x7c2998f8}},	//   llad_, мили, _sowi, weer,
   {{0x64598d38,0x765a98f9,0x7c2998fa,0x27ed98fb}},	//   _powi, _doty, teer, _teen_,
   {{0x386680f2,0x61e48eef,0x32d2801c,0xccf8801b}},	//   ckor_, _đila, _bây_, _dvě_,
   {{0x7c2998fc,0x06e200c8,0x628198fd,0x32d28028}},	//   reer, _বিভি, tilo, _cây_,
   {{0x7c2998fe,0xe8f998ff,0x32d2801c,0x2ca91900}},	//   seer, оло_, _dây_, hlad_,
   {{0x62818c6e,0x2ca91901,0xa6dd00c8,0x7c299902}},	//   rilo, klad_, _বিষয়, peer,
   {{0x6d419903,0x200f9904,0x06e200ab,0x1de61905}},	//   _irla, nggi_, _বিবি, कर्ष_,
   {{0x28cf80bc,0x32d28028,0x2ca91906,0x6279816b}},	//   _संवि, _gây_, dlad_, dňov,
   {{0x5edd00c8,0x248d9907,0x7cd50110,0x753c01d0}},	//   _বিশে, lnem_, _sąra, tvrz,
   {{0x64a61908,0xddd8811f,0x248d9909,0x6da30fe7}},	//   дава, nivš, onem_, вира,
   {{0x248d990a,0x161f0bb8,0x629e190b,0x4e1f03a4}},	//   nnem_, म्बर_, wopo, म्बई_,
   {{0xa5a485e8,0x64a31444,0x3ced0067,0xf1fa190c}},	// [c80] _चुनौ, тата, ćeva_, قعات_,
   {{0x9f44803e,0x7cd180eb,0x1e83012f,0x386d8580}},	//   _nemá_, _pārl, _альм, _aler_,
   {{0x629e190d,0x85bb0065,0x2ca9190e,0x20f8190f}},	//   ropo, _واپس_, blad_, uči_,
   {{0x20d38028,0x61ee1910,0x7bcb803d,0x248d9911}},	//   _mãi_, _webl, _nggu, jnem_,
   {{0x248d9640,0x6d419912,0x629e1913,0x38669914}},	//   dnem_, _arla, popo, rkor_,
   {{0x38669915,0x2ca01916,0xa3bd0540,0x7bcb9917}},	//   skor_, loid_, ेखर_, _aggu,
   {{0x386d9918,0x9f4b03cb,0xceb30158,0xa06a9071}},	//   _fler_, vací_, דיג_, _дава_,
   {{0x38b58e23,0x7d0a81ec,0x60cd826c,0xe0438dca}},	//   gård_, rufs, _čamp, _инси,
   {{0x6d419919,0x27e6991a,0xc5f400ab,0xd62680f7}},	//   _erla, mbon_, _জানা_, _يعطي,
   {{0x20d380ff,0x78a4191b,0x27e6811b,0xd90e815b}},	//   _bãi_, _akiv, lbon_, لیت_,
   {{0x248d991c,0xddd88699,0x9f4b03c1,0x20d380ff}},	//   bnem_, civš, rací_, _cãi_,
   {{0x32d28028,0x27e68bfe,0xfe0e8424,0x20d3827d}},	//   _tây_, nbon_, _साँस_, _dãi_,
   {{0x7c22991d,0x80ca87e6,0x2ca9191e,0x2905991f}},	//   _ibor, _संके, vlad_, arla_,
   {{0x2ca91920,0x2005061c,0x6456022c,0x7ea4823e}},	//   wlad_, şli_, ejyi, còpt,
   {{0xda659921,0x6279816b,0x44220cdb,0x200f808b}},	//   _ثاني, tňov, _bbk_, yggi_,
   {{0x8af00086,0x6e3702a3,0x290c9922,0x2ca002c4}},	//   yyət, _waxb, muda_, goid_,
   {{0xfe0e8fd5,0x290c9923,0x7b180198,0x291801b9}},	// [c90] _सांस_, luda_, мотр_, _aqra_,
   {{0xd5a48117,0x248d9924,0xe3b001a8,0x627984e8}},	//   _نہ_, znem_, شرق_, sňov,
   {{0x7c229925,0x6279826f,0x38b21926,0x7cd181a9}},	//   _obor, pňov, lára_, _pārm,
   {{0xddd8812b,0x5f959927,0x5f008074,0x4422008e}},	//   vivš, ниет, _रिश्_, _gbk_,
   {{0xf6259928,0x248d8353,0x7c2d1929,0x38b5816d}},	//   едло, vnem_, mear, vård_,
   {{0x4439192a,0xddd8812b,0x7c2d192b,0x645d038a}},	//   _has_, tivš, lear, _hosi,
   {{0x44390f29,0x248d8353,0xe5a280e8,0x79a4018b}},	//   _kas_, tnem_, лиши, _арте,
   {{0x645d192c,0x7c2d192d,0x6285192e,0x387f8397}},	//   _josi, near, liho, _umur_,
   {{0x4439022c,0x248d992f,0x9985801b,0x6d4301a1}},	//   _mas_, rnem_, telů_, _šnal,
   {{0x44391930,0x7c2d008c,0x78a40e23,0x38b21931}},	//   _las_, hear, _skiv, dára_,
   {{0x290c9932,0x6d419933,0x60c99934,0x443908dc}},	//   guda_, _urla, _kiem, _oas_,
   {{0x60c98110,0x7aeb81c0,0x6a6d80e1,0x20d38129}},	//   _jiem, _twgt, _dúfa, _vãi_,
   {{0xe28e9935,0x60c985b4,0x442d9936,0x7c2d1937}},	//   _ба_, _miem, mee_, dear,
   {{0x442d9938,0x786605b4,0x60c99939,0x4422193a}},	//   lee_, _móvi, _liem, _sbk_,
   {{0x4439193b,0x6fa0146d,0x645d0114,0x27ff90ab}},	//   _bas_, _गुरू, _bosi, _odun_,
   {{0x4439193c,0x442d993d,0x60c9993e,0x7c2d193f}},	//   _cas_, nee_, _niem, gear,
   {{0x44391940,0x645d1941,0x7c39831d,0x644b80dd}},	// [ca0] _das_, _dosi, _mawr, _mngi,
   {{0x442d9942,0x27ff85a3,0x6aa1831d,0xae0e809a}},	//   hee_, _adun_, nolf, _साइन_,
   {{0x442d9943,0x26d2022e,0x44391944,0x7c2d1945}},	//   kee_, _huyo_, _fas_, bear,
   {{0x645d0870,0x60c99946,0x7c2d1947,0x78660118}},	//   _gosi, _ciem, cear, _bóvi,
   {{0x765e1948,0x442d9949,0xe818000f,0x3a380110}},	//   _kopy, dee_, _थाना_, _tarp_,
   {{0x4420194a,0x644b994b,0x27ff994c,0x27e6994d}},	//   lfi_, _angi, _edun_, sbon_,
   {{0x442d8135,0x4439194e,0x7ae4194f,0x69ce10ab}},	//   fee_, _yas_, lpit, _igbe,
   {{0x8fa69950,0x442d9951,0x44390069,0x7c3b820d}},	//   _забе, gee_, _xas_, gdur,
   {{0x7ae41952,0x7c399953,0xddcf81d0,0x44200286}},	//   npit, _dawr, řešn, ifi_,
   {{0x60c99954,0x290c9955,0x442009ca,0x644b9956}},	//   _ziem, tuda_, hfi_, _engi,
   {{0xd48f9957,0x69ce0133,0x06d88264,0xa1949958}},	//   _бр_, _mgbe, _সিটি, танч,
   {{0x290c9959,0x7ae4195a,0x7c22995b,0x442d995c}},	//   ruda_, kpit, _ubor, cee_,
   {{0x69dc040e,0x645d195d,0x26d205a4,0xc6f80221}},	//   _ofre, _rosi, _cuyo_, ннях_,
   {{0x62850144,0x2b400824,0x6e2e0061,0xb9068264}},	//   xiho, dvic_, gebb, _পি_,
   {{0x4439195e,0xa8a71264,0x4420195f,0x7c2d1960}},	//   _pas_, _прик, ffi_, tear,
   {{0x44391961,0x69dc1962,0x69ce10ab,0xa01b0106}},	//   _qas_, _afre, _agbe, rnös,
   {{0xe4ed023c,0x7c2d1963,0x60c99964,0x7cd180eb}},	// [cb0] _जबकि_, rear, _riem, _pārk,
   {{0x44391965,0x60c99966,0x7c2d1967,0x442d9968}},	//   _was_, _siem, sear, zee_,
   {{0x44391969,0x60c9996a,0x442d996b,0x645d0364}},	//   _tas_, _piem, yee_, _tosi,
   {{0x443910af,0x6285196c,0x69ce0091,0xdddc0110}},	//   _uas_, siho, _egbe, mirš,
   {{0xd366996d,0x6f1d196e,0xb8d80105,0xab87196f}},	//   _ئه_, ntsc, _घी_, _чунк,
   {{0x442d9970,0x6d4a00f7,0x6f1d0192,0x60c99971}},	//   wee_, _áfac, itsc, _wiem,
   {{0x60c99972,0x442d9973,0x6e3a831d,0x78a2826c}},	//   _tiem, tee_, _datb, boov,
   {{0xdd8e8013,0x20d7007e,0x6e3a82c4,0xa8a49974}},	//   توى_, _içi_, _eatb, _брук,
   {{0x2ba705e8,0x36d5835f,0x442d8051,0x2612154b}},	//   _कुमा, _розр, ree_, _ताली_,
   {{0x6f0f1975,0x39459976,0x442d9977,0xcb1400be}},	//   ducc, вног, see_, אלץ_,
   {{0x442d9978,0x26d21979,0x4420197a,0x35558277}},	//   pee_, _suyo_, yfi_, _جناز,
   {{0xcc148077,0x644b997b,0x6e2e03f7,0x60dc802a}},	//   _مذهب, _ungi, webb, írma,
   {{0xa3a8816f,0x6e2e197c,0x69c390a1,0x547a81c6}},	//   _खुप_, tebb, _रणवी, _קטנו,
   {{0x27f202a3,0x2cad8051,0x6d4500dd,0xdee3197d}},	//   _weyn_, lled_, _brha, рори,
   {{0xe5a61401,0x7afd197e,0x6e2e0698,0x6da6018b}},	//   тиви, _avst, rebb, тива,
   {{0x64be0778,0xb4ac016f,0x26d2197f,0x7f441980}},	//   ्देश, गते_, _tuyo_, _triq,
   {{0x44201981,0xe3631982,0x7d0e1983,0x6d4502af}},	// [cc0] rfi_, акти, subs, _erha,
   {{0x2cbf9984,0x2cad801b,0x63ab82c4,0x7ae41985}},	//   hmud_, hled_, _mygn, rpit,
   {{0x2ba70076,0x6e3c9986,0xa3ea02c7,0x7ae41987}},	//   _कुठा, _órbi, _одна_, spit,
   {{0xdee68ba1,0x66e69988,0x248202f7,0x7afb9989}},	//   води, вода, _umkm_, ksut,
   {{0x44fe01e2,0x2cad8428,0x628381d6,0x6e3a89c4}},	//   lį_, dled_, _omno, _patb,
   {{0x2492198a,0x2cad822b,0xb7d280ab,0x20ee81d0}},	//   lnym_, eled_, ারেট, yři_,
   {{0x44fe01e2,0xda188076,0x660101fa,0x6e3a998b}},	//   nį_, _दाबत_, ólki, _vatb,
   {{0x2492198c,0x386002be,0x63ab8bc5,0x39470366}},	//   nnym_, _noir_, _bygn, ænse_,
   {{0x63ab8358,0x7afb998d,0xaec68196,0xa7a7998e}},	//   _cygn, gsut, _абал, _акта_,
   {{0x63ab816d,0x44fe0084,0x3860198f,0xf8ca027d}},	//   _dygn, kį_, _aoir_, _mẩu_,
   {{0xd6e200c8,0x26179990,0x2cad8039,0x38600706}},	//   _বিষয, _नाती_, bled_, _boir_,
   {{0x2cad9991,0x38600635,0xb4ac016f,0x6f0f01e8}},	//   cled_, _coir_, गतो_, tucc,
   {{0x44269992,0xf8bf02be,0x24920dee,0x38600706}},	//   _ibo_, rmé_, dnym_, _doir_,
   {{0x6f1d1993,0x6f0f05dc,0x2c75013c,0xb7e3085d}},	//   rtsc, rucc, _måde_, _क्रम_,
   {{0x26cc9994,0x7cd180eb,0x2bc51995,0x6f1d1996}},	//   _mido_, _pāri, लेना, stsc,
   {{0x48150139,0x91f282f1,0x588701e5,0x38601997}},	//   _смис, _आजुओ_, _шыла, _goir_,
   {{0x201e0086,0x44269998,0x09bd1107,0x9cc801e5}},	// [cd0] əti_, _mbo_, ्ख्य, тыра_,
   {{0x62889999,0x7afd8510,0x7ae28010,0x9967199a}},	//   nido, ásti, _mtot, ктел,
   {{0xdfd18013,0x4426999b,0x60cd199c,0x6729999d}},	//   ميا_, _obo_, _kiam, _spej,
   {{0x2c750f06,0x245881ac,0x4426999e,0x60cd199f}},	//   _både_, _témy_, _nbo_, _jiam,
   {{0x60cd19a0,0xb8fa19a1,0x26cc8135,0x160e816f}},	//   _miam, _डू_, _bido_, _साखर_,
   {{0x442699a2,0x7c3d19a3,0xa3e58beb,0x98b3817b}},	//   _abo_, _hasr, बुन_, ıdır_,
   {{0x62888510,0x261b0665,0xc2120039,0x6ed506b7}},	//   dido, _बानी_, _להם_, _यूसु,
   {{0x394999a4,0x60cd19a5,0x248919a6,0x26cc81df}},	//   _čas_, _niam, niam_, _eido_,
   {{0x408499a7,0x291e99a8,0x89f585a8,0x7c3181a1}},	//   _турб, etta_, лянц, _čerč,
   {{0x628899a9,0x386019aa,0x442699ab,0x7afb99ac}},	//   gido, _soir_, _ebo_, rsut,
   {{0x7afb99ad,0xe73c07d9,0x78bb81c0,0x60cd0176}},	//   ssut, _küçü, _khuv, _biam,
   {{0x60cd01e4,0x05a70105,0x442690ab,0x7c8499ae}},	//   _ciam, _गड़ब, _gbo_, _куче,
   {{0x386006e3,0x7e6199af,0x60cd19b0,0x248919b1}},	//   _voir_, _kolp, _diam, diam_,
   {{0x62889313,0x443f99b2,0x443d99b3,0x26cc8118}},	//   cido, ldu_, _haw_, _xido_,
   {{0x443d99b4,0x443f99b5,0xff1400ab,0x60cd19b6}},	//   _kaw_, odu_, িবেশ_, _fiam,
   {{0x60cd19b7,0x38b90019,0x44fe0110,0x7c3d01b4}},	//   _giam, tére_, rį_, _casr,
   {{0x4bd9176a,0x443d8114,0x422619b8,0x3b071182}},	// [ce0] ться_, _maw_, лдав, лето_,
   {{0xe74719b9,0x78a619ba,0x443d8039,0x44fe0084}},	//   ções_, lokv, _law_, pį_,
   {{0x090619bb,0x9f520205,0x38b90019,0x26cc99bc}},	//   упен, _seyè_, sére_, _rido_,
   {{0x26cc99bd,0x38608125,0x78bb8548,0x443f816b}},	//   _sido_, ðir_, _chuv, jdu_,
   {{0x443f99be,0x26cc99bf,0x443219c0,0x7e6199c1}},	//   ddu_, _pido_, mey_, _bolp,
   {{0x0f370051,0x628883a8,0x7e6199c2,0x443f99c3}},	//   טרנט_, xido, _colp, edu_,
   {{0xe29707b6,0x60d50661,0xad268c2a,0x443d99c4}},	//   _сар_, _guzm, ارتو, _baw_,
   {{0xdd0401e2,0x443d8069,0x443219c5,0x7c2419c6}},	//   ūrėt, _caw_, ney_, nfir,
   {{0x62889313,0x443d99c7,0x26cc99c8,0xf743932a}},	//   tido, _daw_, _tido_, _лето,
   {{0x60cd19c9,0x59b804e5,0x7e6190dd,0xc3330051}},	//   _siam, _अरार, _golp, צות_,
   {{0x7c2419ca,0xc27b00be,0x291e8009,0x443f82a6}},	//   kfir, גריי, utta_, bdu_,
   {{0xf5378051,0x7cd18029,0x60cd0748,0x628899cb}},	//   _תנאי_, _pārv, _qiam, sido,
   {{0x443202a3,0x7c3d19cc,0x248919cd,0x442480b9}},	//   dey_, _rasr, viam_, mfm_,
   {{0xbb3b8158,0x2489009a,0x7ead80e1,0x35a986a7}},	//   _רעגי, wiam_, túpi, _चुड़,
   {{0x248919ce,0x60cd0069,0x61fa8201,0x7c2419cf}},	//   tiam_, _tiam, matl, ffir,
   {{0x61fa99d0,0x6d4899d1,0x44320079,0x644099d2}},	//   latl, _mrda, gey_, ndmi,
   {{0x248919d3,0x99900289,0x50b8006b,0xf77302e3}},	// [cf0] riam_, _čaša_, _حدود_, _داغ_,
   {{0x7cd18029,0x61fa99d4,0xbbd186b7,0x443f99d5}},	//   _kārt, natl, _हल्क, zdu_,
   {{0x394719d6,0x443f99d7,0x7c3d19d8,0x7e61867f}},	//   íns_, ydu_, _tasr, _rolp,
   {{0x26179880,0x61fa85b2,0x443219d9,0x644f19da}},	//   _नाही_, hatl, cey_, _unci,
   {{0x6d4899db,0xe73999dc,0x443f99dd,0x61fa99de}},	//   _arda, тел_, vdu_, katl,
   {{0xa5098fe6,0x8d6580af,0x26dc00be,0x61fa99df}},	//   века_, ивле, עקומ, jatl,
   {{0xed5999e0,0x443d8e35,0x61fa99e1,0x7e6199e2}},	//   той_, _paw_, datl, _volp,
   {{0x443f99e3,0x3e7419e4,0xc60680ab,0xf0bb8fd3}},	//   udu_, _mäta_, ল্লা_, _سازش_,
   {{0xa3a8823c,0x443f99e5,0xfc3f07ca,0x290c85a4}},	//   _खुद_, rdu_, _maí_, erda_,
   {{0xc6a799e6,0x61fa99e7,0xea2490ab,0x2bd185fc}},	//   _срби, gatl, ẹ́rẹ, _हलका,
   {{0x443202c1,0x3ea799e8,0x443d99e9,0xf99180f7}},	//   yey_, mont_, _taw_, تبة_,
   {{0x18a60364,0x44320079,0x443f99ea,0x92a60035}},	//   рамм, xey_, qdu_, _załą,
   {{0x61fa899b,0xa3d919eb,0x290c99ec,0xbca499ed}},	//   batl, ाशन_, arda_, _امني,
   {{0x4b7a8158,0x443219ee,0x7ae999ef,0x200c0085}},	//   _באנו, wey_, mpet, şdi_,
   {{0x44320079,0x44f38087,0x8d630615,0xa3dc98a9}},	//   tey_, nţ_, овре, तुक_,
   {{0xb05b19f0,0x673b8bcf,0xd91a8e82,0x261219f1}},	//   lmän, _osuj, _סופל, _ताकी_,
   {{0x443219f2,0x7c2419f3,0x7ae999f4,0x3ea799f5}},	// [d00] rey_, rfir, npet, kont_,
   {{0x14b8016f,0xab2719f6,0x7bdf01e8,0xf2df00ff}},	//   _आठवण, рофа_, acqu, _trân_,
   {{0xd00f19f7,0x7f498388,0x33200372,0x261b0074}},	//   _علی_, _areq, stix_, _बाती_,
   {{0x03a600e8,0x8c4619f8,0x044619f9,0x09d2801b}},	//   _вимо, _теме, _темн, _सल्य,
   {{0x27e985b4,0x61fa83bf,0x6d48812b,0xbb4300e8}},	//   ñana_, yatl, _srda, _деяк,
   {{0x2913002a,0xa01b0198,0xa3e206ae,0x290c9388}},	//   buxa_, riöi, नुर_, yrda_,
   {{0x61fa99fa,0x442499fb,0xd49a99fc,0x261795bc}},	//   vatl, tfm_, кри_, _नारी_,
   {{0x61fa80dd,0x290c8140,0xa0678dc0,0x7f4999fd}},	//   watl, vrda_, _каса_, _freq,
   {{0x7f4980f1,0xc1788110,0xa06799fe,0x3ced192c}},	//   _greq, ybės_, _тата_, ćevi_,
   {{0xaa668d91,0x7cd180eb,0x09ca00ab,0x672299ff}},	//   ртик, _pārt, _ল্যা, mtoj,
   {{0x61fa9a00,0xfce38c3e,0xd2578e11,0x6d489a01}},	//   ratl, _дохо, рцы_, _urda,
   {{0x67228110,0x7cd181a9,0x2c78826b,0x61fa9a02}},	//   otoj, _vārt, _béde_, satl,
   {{0x67229608,0x628001e2,0xb7141194,0xab838eef}},	//   ntoj, _įmon, одящ, _мушк,
   {{0xea000104,0x61fa811c,0xfc3f041c,0x67228a14}},	//   _đến_, qatl, _saí_, itoj,
   {{0xb2bb8051,0xa5f81a03,0x28d01862,0xbd680012}},	//   _שמור, ресу_, _संचि, арте_,
   {{0x2c7500f2,0x67229a04,0xdb0f016a,0xb8670019}},	//   _båda_, ktoj, _azcá, _خاتو,
   {{0x4aba8074,0x3a750088,0xaaba8105,0x67228168}},	// [d10] _उठाव, блар, _उठाक, jtoj,
   {{0x29130118,0x6d4300fe,0x3e740338,0xe7e300ba}},	//   tuxa_, _šnau, _täta_, कुरा_,
   {{0x2ba7000d,0xc5f20039,0xdd911a05,0x61f89a06}},	//   _कुरा, _מדי_, _روح_, _mevl,
   {{0x20190455,0x31578158,0x272086c0,0x67228168}},	//   ngsi_, ייבן_, fòn_, ftoj,
   {{0xf7459a07,0xb4b300d4,0xc8d0016f,0x27209a08}},	//   село, टती_, _संघट, gòn_,
   {{0x2ca9062d,0x78a2803e,0xbb3a00be,0x14b5016f}},	//   load_, čova, _געשי, ंतवण,
   {{0xfbdb0076,0x3ea782be,0x442b1a09,0x28f802c7}},	//   _भलाम, ront_, _kbc_, _весь_,
   {{0x1ee7826a,0x7ae980ce,0x2901004f,0x4adb1a0a}},	//   _نوری_, tpet, msha_, _बढाव,
   {{0x7cd18029,0x3ea78019,0x4aa99a0b,0x7ae99a0c}},	//   _pārs, pont_, лкин_, upet,
   {{0xfc3f800d,0x38bc9a0d,0x78ad1a0e,0x7aed8085}},	//   ží_, ríre_, _akav, _çatm,
   {{0x61f89a0f,0x7ae99a10,0x186a1324,0xa06a1a11}},	//   _devl, spet, гани_, гана_,
   {{0xf9920039,0xb1138133,0x764181b4,0x29011a12}},	//   לרי_, _kụzu, _haly, isha_,
   {{0x248d8341,0x3b098d69,0x76419a13,0x7205803d}},	//   miem_, _село_, _kaly, _هوشم,
   {{0x78ad00d2,0x248d80eb,0x61f8874c,0xb05b0198}},	//   _ekav, liem_, _gevl, lmäl,
   {{0x442b1a14,0xceb29a15,0xd5b21a16,0xd9c580ab}},	//   _bbc_, פיל_, سفر_, _শ্রম,
   {{0x248d9a17,0x672281e2,0xb05b016d,0x6d4a0118}},	//   niem_, ytoj, nmäl, _áfam,
   {{0xe29a041c,0xe3ba1a18,0x045700f7,0xf1bf81d0}},	// [d20] гаа_, уба_, حلقة_, řád_,
   {{0x6f040e78,0x6f0483f2,0x248d9a19,0x76419a1a}},	//   _ivic, šick, hiem_, _naly,
   {{0xfe370051,0x248d9a1b,0x2b4b0326,0x64a60084}},	//   _פרטי_, kiem_, _ercc_, _гана,
   {{0x248d8341,0x91fc80eb,0x17fa80f7,0x6f041a1c}},	//   jiem_, nkār, اراة_, _kvic,
   {{0x248d8029,0x501b0bea,0x76419a1d,0xb4c4009a}},	//   diem_, רונו, _baly, एगी_,
   {{0x67229a1e,0x1ae31a1f,0xbea39a20,0xa2e31a21}},	//   rtoj, _хорм, пачк, _хорд,
   {{0x67228828,0x764181e2,0x261b1a22,0x394a0580}},	//   stoj, _daly, _बासी_, _urbs_,
   {{0x248d9a23,0x64440c56,0x7c361a24,0x67228168}},	//   giem_, ndii, neyr, ptoj,
   {{0xa3a897ba,0x7cd181a9,0x3e799a25,0x9e658061}},	//   _खुश_, _pārr, _sète_, _ڈالن,
   {{0x9e658013,0xc3330039,0x0665803d,0x78ad1a26}},	//   _والن, לוח_, _والپ, _skav,
   {{0xd0110199,0x6f029a27,0xa3a8852a,0x248d8ec3}},	//   ولد_, lsoc, _खुर_, biem_,
   {{0xc19b0158,0x248d9a28,0x764185ee,0x13b00264}},	//   רשטי, ciem_, _zaly, চেয়,
   {{0x61fe1a29,0x6f029a2a,0x64441a2b,0x5f940081}},	//   kapl, nsoc, ddii, зият,
   {{0x6f040267,0x64429a2c,0x442b0df6,0x29010df6}},	//   _dvic, _haoi, _sbc_, ysha_,
   {{0x90e69a2d,0x7c36008b,0xe5c40081,0x61fe1a2e}},	//   _استن, feyr, зсто, dapl,
   {{0x38b902be,0xb4b3016f,0x644402d5,0x629c03ed}},	//   méro_, टते_, gdii, _ajro,
   {{0x64429a2f,0x5eb800ab,0x290101b4,0xd9f901ae}},	// [d30] _maoi, _ইংরে, wsha_, инац_,
   {{0x61fe1a30,0x7f4d1a31,0x60c09a32,0x2901005d}},	//   gapl, _iraq, _ahmm, tsha_,
   {{0x6f040168,0x200900b9,0x442b1a33,0xb05b0198}},	//   _zvic, _kdai_, _tbc_, ymäl,
   {{0x6d400029,0xdd00800d,0xdb0f00e7,0x442b1a34}},	//   āmat, štěn, _lycé, _ubc_,
   {{0x3ced02a5,0x248d9a35,0xa3a88105,0x76418110}},	//   ćevu_, viem_, _खुल_, _paly,
   {{0xf1c88bb8,0x999e8065,0x60c0808e,0x248d8035}},	//   रधान, hető_, _ehmm, wiem_,
   {{0x248d8029,0x9f40007b,0x76419a36,0x76439a37}},	//   tiem_, _leið_, _valy, rdny,
   {{0x13099a38,0x44291a39,0x6442832f,0x26d30ba3}},	//   аний_, nfa_, _caoi, _lixo_,
   {{0x6442803c,0x290a8065,0x248d9a35,0x7aed1a3a}},	//   _daoi, ában_, riem_, npat,
   {{0x248d8029,0x090580e8,0x2009004f,0x38bc84e8}},	//   siem_, опон, _adai_, míra_,
   {{0xdd9b8153,0x64428068,0x644402a3,0x6f04190f}},	//   _сша_, _faoi, ydii, _svic,
   {{0xc5e90bea,0x43759a3b,0x290b9a3c,0x64428c49}},	//   _יד_, _мулт, čca_, _gaoi,
   {{0x99980289,0x4429031d,0xdd1e81ac,0xe28e9a3d}},	//   _marš_, dfa_, _víťa, _жа_,
   {{0x7c298e5d,0x3e708706,0xa3e586ae,0x7aed066b}},	//   lfer, _càth_, बुर_, dpat,
   {{0x26d304c3,0x7aed0858,0x61fe0214,0xa3c18540}},	//   _dixo_, epat, vapl, ंधक_,
   {{0x13ea0196,0x74161a3e,0x26d30ba3,0x6f0480e1}},	//   рмай_, تورا, _eixo_, šici,
   {{0xe1fa0d69,0x26d31a3f,0x7aed1066,0x7c36007b}},	// [d40] ига_, _fixo_, gpat, reyr,
   {{0x44291a40,0xf22186a7,0x63b6804a,0x41b61821}},	//   afa_, _माफ़_, _øyne, осет,
   {{0xda218e18,0x27241a41,0x649780eb,0x05a99a42}},	//   _मानत_, lön_, rģij, _चुलब,
   {{0x5ee180c8,0x7c2980f3,0x61fe02d0,0x4429018e}},	//   _নিজে, jfer, sapl, cfa_,
   {{0xee3a8012,0xaf369a43,0xd00f8199,0x7c299670}},	//   инд_, ترات, ئله_, dfer,
   {{0x6442808c,0x999e8019,0x6f029a44,0x7c298192}},	//   _saoi, zető_, rsoc, efer,
   {{0x7c299a45,0x27241a46,0x7cd180eb,0x61fc1384}},	//   ffer, hön_, _pārp, _ierl,
   {{0x61fc1a47,0x2c78803d,0x61e90bda,0x60c082d5}},	//   _herl, _béda_, _đeli, _uhmm,
   {{0x60dc1a48,0x7a3f8110,0x27241a49,0x61fc1a4a}},	//   _hurm, kštė, jön_, _kerl,
   {{0x60dc1a4b,0x61fc09a6,0x026a80e8,0x5ee18264}},	//   _kurm, _jerl, рший_, _নিচে,
   {{0x44291a4c,0x3a370496,0x64428834,0x8cd61a4d}},	//   yfa_, חרים_, _taoi, _मंगो,
   {{0xab2a9a4e,0x26dc00ce,0x7c298118,0x6724022b}},	//   _вода_, _čvor_, cfer, _bqij,
   {{0xd90e89d7,0xa09b80be,0xe29a84ae,0x7d1c92f1}},	//   ریک_, שיכט, _кад_, _årsb,
   {{0x29070019,0x628a8234,0x25e601d0,0x63a282f9}},	//   ának_, _umfo, जुली_, _ixon,
   {{0x7e689a4f,0x44291a50,0x45d41a51,0x60dc1a52}},	//   _modp, tfa_, дорс, _nurm,
   {{0xa01b1a53,0xd5b80e02,0xe57180be,0x44291a54}},	//   riös, юся_, ײַל_, ufa_,
   {{0x61fc1a55,0x44291a56,0x6d5a1a57,0x3a750088}},	// [d50] _berl, rfa_, ätar, плар,
   {{0x44291a58,0x4eac80ab,0x656e0061,0x68e301df}},	//   sfa_, গগুল, ínhá, índo,
   {{0x05a98540,0x60dc1a59,0x38690573,0x442900b4}},	//   _चुंब, _curm, _koar_, pfa_,
   {{0x7aed1a5a,0x61fc037a,0x60dc1a5b,0x63a2808e}},	//   ppat, _eerl, _durm, _oxon,
   {{0x66c01836,0x61fc1a5c,0x76451a5d,0xdb07861c}},	//   söke, _ferl, _kahy, ümüz,
   {{0x61fc1a5e,0x60dc01b4,0x0e648558,0x3e798176}},	//   _gerl, _furm, мкін, _bèta_,
   {{0xc6940158,0x7c2982af,0x60dc1a5f,0xf3ff03a7}},	//   ואס_, tfer, _gurm, _joão_,
   {{0x629a9a60,0x320102ed,0x61e50428,0xab6582ac}},	//   ento, lahy_, lchl, звил,
   {{0x7c299a61,0x61fc084a,0x5f94835f,0xa3ce0107}},	//   rfer, _yerl, _житт, षेप_,
   {{0x61e50635,0x60dc008e,0x320110ba,0x62800196}},	//   nchl, _yurm, nahy_, _įmok,
   {{0x27e084c4,0x850580d5,0x91fc80eb,0xa92281e5}},	//   žine_, _روشن, rkāp, ндэл,
   {{0x7e688efc,0x201d81b9,0x27240009,0x629a99b3}},	//   _zodp, ngwi_, tön_, anto,
   {{0x38690012,0xacaa8117,0xc31980c8,0x31b80526}},	//   _doar_, _اپنے_, _তৈরি_, _अर्ध,
   {{0x27241a62,0x2b4f826c,0x7645111f,0x9f5d8077}},	//   rön_, _irgc_, _cahy, gawé_,
   {{0x491283bb,0xbea3014c,0xdd921a63,0x61e51a64}},	//   _थियो_, харк, رور_, dchl,
   {{0x442f807d,0x61fc1a65,0x6d4180dd,0x3869010c}},	//   _jbg_, _serl, _msla, _goar_,
   {{0x61fc0455,0x20021a66,0xd46711b3,0x60dc1a67}},	// [d60] _perl, maki_, чите_, _surm,
   {{0x20021a68,0x6d4194f0,0x60dc1a69,0x2c71826b}},	//   laki_, _osla, _purm, _dádi_,
   {{0xceb31a6a,0x61fc04eb,0x29059a6b,0xd5b00065}},	//   _איז_, _verl, nsla_, _شہر_,
   {{0x20021a6c,0x38cb8416,0xc6048540,0x64a61a6d}},	//   naki_, مانی_, रण्य_, _хама,
   {{0x61fc1a6e,0xe81f0006,0x6d419a6f,0x60dc1a70}},	//   _terl, _भासा_, _asla, _wurm,
   {{0x442f810b,0x20021a71,0x2907817f,0x7bd9819d}},	//   _abg_, haki_, _ovna_, _agwu,
   {{0xdb078a56,0x628e1a72,0x20020041,0xe9a31a73}},	//   _člán, _imbo, kaki_, _зарп,
   {{0x64461a74,0x20020f28,0x2cad83b2,0x399b0039}},	//   _jaki, jaki_, goed_, _הילד,
   {{0x200207d9,0x6d41957a,0x6b841a75,0x64461a76}},	//   daki_, _esla, nzig, _maki,
   {{0x64461a77,0x2a6a1a78,0xb05b0364,0x27e69a79}},	//   _laki, _jobb_, mmäi, lcon_,
   {{0x2bb9053f,0xa6e98028,0x24978077,0xbbb9146d}},	//   _आर्थ, _chươ, _کنند_, _आर्क,
   {{0x64461a7a,0x76451a7b,0x442f8338,0x63a20035}},	//   _naki, _sahy, _gbg_, żony,
   {{0x60c41a7c,0x6b840a0f,0x628e0b81,0x24800168}},	//   _dhim, jzig, _ombo, dhim_,
   {{0x291a1a7d,0x2c7181d0,0x64461a7e,0x442208dc}},	//   kupa_, _rádi_, _aaki, _ack_,
   {{0x64461a7f,0x20021a80,0x7647006a,0xa2c00b04}},	//   _baki, baki_, rdjy, वतन्,
   {{0x628e1313,0x76450397,0x64461a81,0x30a401e2}},	//   _ambo, _wahy, _caki, _прыв,
   {{0x64461a82,0x3f9e0214,0x4e1c801b,0x76451a83}},	// [d70] _daki, ştur_, नलाई_, _tahy,
   {{0x291a0c53,0x6d41008b,0x78af1a84,0x60c40326}},	//   fupa_, ælas, locv, _zhim,
   {{0x7c229a85,0x2907001b,0x2509003d,0x4422006a}},	//   _ocor, éna_, _برخی_, _fck_,
   {{0x628e1a86,0x61e50352,0x386987ca,0xdfd180f7}},	//   _embo, schl, ðar_, نيا_,
   {{0x7c2d1a87,0x64978162,0x2cad9384,0x36699a88}},	//   mfar, nţie, voed_, жало_,
   {{0x442f9a89,0x443b00b9,0x20021a8a,0xed599a8b}},	//   _sbg_, leq_, zaki_, жок_,
   {{0xa9341a8c,0x20021a8d,0x291a1a8e,0xdd918019}},	//   _перш, yaki_, cupa_, کوں_,
   {{0xe81f1a8f,0x7c2d1a90,0x14bf0c78,0x443b1a91}},	//   _भाषा_, nfar, ्षिण, neq_,
   {{0x200d9a92,0x20021a93,0xaca38133,0xddd48088}},	//   _idei_, vaki_, _nkụj, čaši,
   {{0x60c41a94,0xa6e98028,0x2002054e,0xddc18493}},	//   _shim, _phươ, waki_, _colţ,
   {{0x20021a95,0x66039a96,0x19c59a97,0xa0a601a1}},	//   taki_, mank, ьбом, данд,
   {{0x1620023c,0x60d60201,0x27ff9a98,0x7d1c8257}},	//   _बाहर_, _qiym, _jeun_, _årsa,
   {{0xeaae8012,0x20021a99,0xb9048a74,0x6449831d}},	//   _ай_, raki_, _भू_, mdei,
   {{0x64461a9a,0x442d8352,0xa6e98104,0x7c3b9a9b}},	//   _saki, lfe_, _thươ, leur,
   {{0xceb281db,0x20021a9c,0x6d58017f,0x2a6a1a9d}},	//   דים_, paki_, _švab, _robb_,
   {{0x64499a9e,0x6b840b90,0x442d9a9f,0x7c2d1aa0}},	//   ndei, tzig, nfe_, gfar,
   {{0x66039aa1,0x64461aa2,0xfc3f026b,0x64978087}},	// [d80] kank, _vaki, _akís_, cţie,
   {{0x64461aa3,0x7c3b9aa4,0x248000f1,0x6281805d}},	//   _waki, heur, shim_, nhlo,
   {{0x66039aa5,0x64461aa6,0x7c3b83b2,0x6f098216}},	//   dank, _taki, keur, _avec,
   {{0x291a1aa7,0x7d1c1aa8,0x22479aa9,0x7c3b8036}},	//   rupa_, murs, _lank_, jeur,
   {{0x9c7c8499,0x073a9381,0x6f099aaa,0x98a7012b}},	//   _juče, تساب_, _cvec, žića_,
   {{0x44201aab,0x628e1aac,0x26c59aad,0x66039aae}},	//   lgi_, _umbo, _chlo_, gank,
   {{0x442d9aaf,0x69dc0548,0x7c3b9ab0,0xe81f06ae}},	//   ffe_, _igre, feur, _भाला_,
   {{0x3ae400f2,0x6e3c1ab1,0x27ff9ab2,0x7c3b9ab3}},	//   _köp_, herb, _geun_, geur,
   {{0x44201ab4,0x22479ab5,0x7ae20174,0xcf469ab6}},	//   igi_, _bank_, íoth, _юнай,
   {{0x66039ab7,0x64499396,0x22478db1,0x38668338}},	//   cank, adei, _cank_, ljor_,
   {{0x7c3b85f8,0x22479ab8,0x765a9ab9,0x021704de}},	//   beur, _dank_, _inty, וחים_,
   {{0x7d1c1aba,0xb4d80697,0x1c1d0ebf,0x38669abb}},	//   durs, ादो_, _फाइल_, njor_,
   {{0x69dc1abc,0x3f869abd,0x6e3c1abe,0x76489abf}},	//   _ogre, nzou_, ferb, _kady,
   {{0xf98f99f7,0x62819ac0,0x64830006,0xddda800d}},	//   ابی_, chlo, _kõig, _potř,
   {{0xf1aa803d,0x76489ac1,0x7d1c1ac2,0xc34880ff}},	//   _باشه_, _mady, gurs, _hổ_,
   {{0x44201ac3,0x261b1551,0x66039ac4,0x69dc1ac5}},	//   ggi_, _बाकी_, zank, _agre,
   {{0x3ec71ac6,0x66c000f2,0x443b1ac7,0x439404bd}},	// [d90] _особ, söka, req_, ватс,
   {{0x27ff81b0,0x7648923c,0x68fc0114,0xc34880ff}},	//   _seun_, _nady, _bwrd, _mổ_,
   {{0x6f1d002a,0x332901b9,0x30159ac8,0x48159ac9}},	//   lusc, stax_, едер, емес,
   {{0x6d451aca,0x66039acb,0x765a9acc,0x8c3d8087}},	//   _isha, wank, _anty, noşt,
   {{0xa3b608fd,0xb4bd009a,0x76489acd,0xc34880ff}},	//   _चुप_, ेगी_, _bady, _nổ_,
   {{0x68fc0428,0x171c03de,0x64598362,0x764890ba}},	//   _fwrd, קווע, _snwi, _cady,
   {{0x7ce787d9,0x7bc29ace,0x7c3b90b6,0x3f868118}},	//   _bıra, _azou, teur, azou_,
   {{0x93459acf,0x0b459537,0xc348801c,0x61ea9ad0}},	//   ение, енин, _bổ_, _affl,
   {{0x442d9ad1,0xc3488028,0x6f09825b,0x7c3b9ad2}},	//   rfe_, _cổ_, _uvec, reur,
   {{0x272982ba,0x764883ec,0xaa459ad3,0x66038079}},	//   mún_, _gady, хеол, qank,
   {{0xa3b601ce,0x02db09c8,0x9c7c9123,0x6d451ad4}},	//   _चुन_, बदुन, _suče, _nsha,
   {{0x386d8216,0x6e3c02af,0xf09f0580,0x6f1d0037}},	//   _joer_, werb, gnà_, fusc,
   {{0x66019ad5,0x6d451ad6,0x44200059,0xda0f016f}},	//   _kelk, _asha, vgi_, ाणात_,
   {{0x7d1c1434,0x9c7c992c,0x386d867f,0xb4d81ad7}},	//   turs, _vuče, _loer_, ाद्_,
   {{0x387f82bb,0x66019ad8,0x7afd1ad9,0xed571ada}},	//   _olur_, _melk, _awst, нор_,
   {{0x69c3803b,0x249f8125,0x6e3c1adb,0x04431adc}},	//   _izne, nnum_, serb, лесн,
   {{0x6d451add,0xc34880ff,0x249f808b,0xb09b1101}},	// [da0] _esha, _xổ_, inum_, _מיקר,
   {{0x6d4500f1,0x387f9ade,0x44201adf,0xc7d701c6}},	//   _fsha, _alur_, sgi_, _אופי_,
   {{0x387f8358,0x76489ae0,0x386d9ae1,0x7cd180eb}},	//   _blur_, _rady, _boer_, _dārz,
   {{0xd7068767,0x7648820d,0x5f069ae2,0xfbc78277}},	//   езди, _sady, езда, _مت_,
   {{0x27299ae3,0x08e68a49,0x61368065,0x66019ae4}},	//   gún_, _কিছু_, _külö, _belk,
   {{0x66018a56,0x7ce782bb,0x3f86802a,0xdd949ae5}},	//   _celk, _sıra, rzou_, калы,
   {{0xc348801c,0x44fe001b,0x2ca01ae6,0x249f807b}},	//   _sổ_, nů_, onid_, fnum_,
   {{0x249f807b,0x54549ae7,0x26da1ae8,0xf8ca00ff}},	//   gnum_, твит, _lipo_, _tẩy_,
   {{0xb05b016d,0x66019ae9,0xc7a39aea,0x764880e4}},	//   lläg, _felk, _битк, _tady,
   {{0xdee39aeb,0xd90e8bca,0x2c7c0511,0x44fe01d0}},	//   _софи, میت_, _oído_, ků_,
   {{0x2d878d38,0xb05b00f2,0x44fe001b,0x2b9100e1}},	//   czne_, nläg, jů_, môcť_,
   {{0xc3488028,0x44fe001b,0x6fd6880a,0xbebb0168}},	//   _tổ_, dů_, _gücü, ntëv,
   {{0x44269aec,0xb05b01ec,0xfebb01a8,0x98741aed}},	//   _ico_, hläg, كاست_, уляц,
   {{0x66c0016d,0x6f1d1aee,0xa01b0192,0x7aef802a}},	//   sökn, rusc, chön, ícte,
   {{0xb606026c,0x5558002e,0x26da0091,0x7ae29aef}},	//   dušč, наря_, _dipo_, _huot,
   {{0xdcb80698,0x6f1d159c,0xb05b0338,0x6d450299}},	//   ещу_, pusc, dläg, _vsha,
   {{0x291e80df,0x64978087,0x61fb026c,0x386d800b}},	// [db0] luta_, nţia, _đulb, _roer_,
   {{0x979c004c,0x6d4510af,0x64830006,0x7ae28009}},	//   _משחק, _tsha, _sõid, _muot,
   {{0x291e81dd,0x3b0902a6,0x6d451af0,0xf1a7153d}},	//   nuta_, ssaq_, _usha, хран,
   {{0x442681e9,0x6f0d017f,0x66018009,0x26da004f}},	//   _nco_, _kvac, _selk, _zipo_,
   {{0x54541af1,0x7ae281e2,0xf7459af2,0x66018009}},	//   _свят, _nuot, тело, _pelk,
   {{0x291e9af3,0x66071af4,0x27299af5,0x644d1af6}},	//   kuta_, najk, rún_, ldai,
   {{0x66019af7,0xd65802f6,0x32059af8,0x291e9af9}},	//   _velk, תיות_, valy_, juta_,
   {{0x66019afa,0x6f0d0503,0x291e9afb,0x3e740799}},	//   _welk, _ovac, duta_, _hätt_,
   {{0x7ae280ab,0x249f807b,0x32059afc,0x5ba99afd}},	//   _cuot, rnum_, taly_, ьким_,
   {{0x291e9afe,0x644d0014,0xc3320039,0x7ae28084}},	//   futa_, hdai, סוי_, _duot,
   {{0x60c98748,0xb05b1aff,0x645d1b00,0x60db804f}},	//   _khem, kläd, _onsi, _kium,
   {{0x3e7400f2,0x32059b01,0x66e61b02,0x26da1b03}},	//   _lätt_, saly_, кома, _sipo_,
   {{0x26da1b04,0x443f9b05,0x6ec58b04,0x80cb80ab}},	//   _pipo_, meu_, ितपु, িদপ্,
   {{0x6da61b06,0x443f9b07,0x291e80a4,0x644b9b08}},	//   вига, leu_, buta_, _hagi,
   {{0xceb28f60,0x291e802e,0x644b9b09,0x6f0d1b0a}},	//   ייך_, cuta_, _kagi, _evac,
   {{0x443f809f,0x44fe001b,0x7f8600f7,0x224a00ee}},	//   neu_, rů_, _للبن, _sabk_,
   {{0x644b9b0b,0x44fe001b,0x6b899b0c,0x443f9b0d}},	// [dc0] _magi, sů_, nzeg, ieu_,
   {{0x645d1b0e,0x644b9b0f,0x644d1a2f,0xaa7b008b}},	//   _ensi, _lagi, adai, _stýr,
   {{0xaca40135,0x44e700ff,0x9c7c8b80,0x68e382df}},	//   _amụt, _gõ_, _luča, _jund,
   {{0x644b9b10,0x60db9b11,0x63a4807b,0xb05b1b12}},	//   _nagi, _cium, _þing, rläg,
   {{0x443f9b13,0x68e39b14,0x16160b86,0x60db9b15}},	//   deu_, _lund, _तयार_, _dium,
   {{0x7bc60db7,0x7ae284fa,0x7c240110,0x291e9b16}},	//   _izku, _ruot, lgir, yuta_,
   {{0x644b9b17,0x92de80c8,0xc5d580c8,0x60db8081}},	//   _bagi, _তবে_, _স্বপ, _fium,
   {{0x7c2419a2,0x38c884c0,0x291e9b18,0x443f809f}},	//   ngir, _سازی_, vuta_, geu_,
   {{0x7ae29b19,0x44269b1a,0xb05b1b1b,0x394781a1}},	//   _quot, _vco_, kmär, _asns_,
   {{0x7ae29b1c,0x291e80ad,0x3a279b1d,0x68e39b1e}},	//   _vuot, tuta_, _ccnp_, _bund,
   {{0x2004820f,0x443f9b1f,0x68e39b20,0x38b90019}},	//   _kemi_, beu_, _cund, kért_,
   {{0x7ae2825d,0x291e9b21,0x443f9b22,0x200480f1}},	//   _tuot, ruta_, ceu_, _jemi_,
   {{0x6b898063,0xda3491e9,0x291e9b23,0x644082d0}},	//   czeg, _белы, suta_, memi,
   {{0x64409b24,0x27e000ad,0x291e8870,0xd9548277}},	//   lemi, _egin_, puta_, _منتخ,
   {{0x3e7404b8,0x660700d2,0x644b9b25,0x7bc60cdb}},	//   _rätt_, rajk, _yagi, _azku,
   {{0x64409b26,0x3e7404b8,0x200480a4,0x7c241b27}},	//   nemi, _sätt_, _nemi_, ggir,
   {{0x4ea71b28,0xe3740196,0x644d1b29,0x5a351354}},	// [dd0] _арна, алты, rdai, лнат,
   {{0x60c99b2a,0x443f9b2b,0xf8bf1b2c,0x64409b2d}},	//   _shem, zeu_, llé_, hemi,
   {{0x60db9b2e,0x60c981c0,0x39151b2f,0x7bc6011b}},	//   _pium, _phem, умер, _ezku,
   {{0x2bae12ee,0x443f823e,0x33200722,0x645d1b30}},	//   _झुका, xeu_, buix_, _unsi,
   {{0x644b9b31,0x443f9b32,0x20049b33,0x60db804f}},	//   _ragi, veu_, _demi_, _vium,
   {{0x644b9b34,0x9c7c805c,0xe5a59b35,0x2004826b}},	//   _sagi, _ruča, лили, _eemi_,
   {{0x644b9b36,0x443f9b37,0x60c99b38,0x78a29b39}},	//   _pagi, teu_, _them, bnov,
   {{0x64409b3a,0x68e38558,0x69c7135a,0x332d84b7}},	//   gemi, _rund, _izje, ttex_,
   {{0x443f9b3b,0x2cb9008e,0x91e59b3c,0xbebb0168}},	//   reu_, _mksd_, лопе, ntës,
   {{0x443f9b3d,0x68e39b3e,0x644b9b3f,0x20049b40}},	//   seu_, _pund, _wagi, _zemi_,
   {{0x644b9b41,0xab5b0065,0xe4e7835f,0x6b899b42}},	//   _tagi, _szül, _різн, szeg,
   {{0x9b458277,0xa35592dc,0x68e38982,0x672d0372}},	//   _منصو, _مختص, _vund, _bqaj,
   {{0x9cd68039,0xbebb00f1,0x68e39b43,0x6d571b44}},	//   _עונה_, jtës, _wund, _arxa,
   {{0x68e39b45,0x78a29b46,0x539a83c8,0x6d5c81a8}},	//   _tund, znov, _אינו, _árac,
   {{0x9c7c811f,0x78a29b47,0x64978087,0xf8bf1b48}},	//   _mučn, ynov, nţio, blé_,
   {{0xb05b0074,0x2121008e,0xdd8f01a8,0x672d0197}},	//   smär, duhh_, سوق_, _fqaj,
   {{0x74130077,0x20048301,0xb05b016d,0x78a29b49}},	// [de0] صولا, _remi_, pmär, vnov,
   {{0xddb615a9,0x64409b4a,0x7c241b4b,0xe3b7146c}},	//   _محجب, zemi, sgir, убу_,
   {{0x64409b4c,0x7a7a80be,0x7c240980,0xdce801a9}},	//   yemi, ערעס, pgir, ēlēt,
   {{0xe3a78077,0xdee6997d,0x644082f9,0xd70a9b4d}},	//   _هر_, годи, xemi, енде_,
   {{0xb8eb058c,0x78a29b4e,0x2bba00f7,0x9c7c811a}},	//   _री_, rnov, _ساحة_, _bučn,
   {{0x91e31b4f,0x09e30652,0x7d1c9b50,0x69dc8ec3}},	//   _горе, _горн, _årsk, žrei,
   {{0x644087d9,0xafdb0aa2,0x20f3026c,0x3a2a0267}},	//   temi, ndør, _aćif_, _icbp_,
   {{0x64978087,0x78a2816b,0x3ae98129,0x115b03de}},	//   sţin, čovs, _búp_, _אדלע,
   {{0x6d580da8,0xb5fc8609,0x3ae98129,0x543b03de}},	//   _šval, _anġe, _cúp_, געפא,
   {{0x7ae61b51,0x86c681a8,0x67228084,0x64409b52}},	//   _mukt, _صيان, muoj, semi,
   {{0x27e98353,0x64409b53,0x3cf800e1,0x64978087}},	//   žane_, pemi, jprv_, cţio,
   {{0xf99304de,0x64978087,0x81d600ab,0x1fdf064a}},	//   מרת_, nţil, _সভা_, नखेड,
   {{0x44ea9b54,0x67228110,0xf4878065,0x26de9b55}},	//   _hù_, nuoj, _حالی, _kito_,
   {{0xc7b382f6,0x81d49b56,0xe45f0106,0xb05b1b57}},	//   מבר_, _колх, _snö_, fläc,
   {{0x629a9b58,0x7ae61b59,0x44ea877f,0x6ca71b5a}},	//   mito, _aukt, _jù_, граж,
   {{0x44ea9b5b,0x7ae6085c,0x26de9b5c,0x1f750a0e}},	//   _mù_, _bukt, _lito_, _влия,
   {{0x44ea8091,0x3a3807cf,0x26de8548,0x3a2a0088}},	// [df0] _lù_, _bbrp_, _oito_, _bcbp_,
   {{0x44ea83d3,0x26de9882,0x195911e9,0x7ae61b5d}},	//   _où_, _nito_, казы_, _dukt,
   {{0x60cd1b5e,0x9c7c9b5f,0x81b680ab,0x2121008e}},	//   _kham, _ručn, চের_, uuhh_,
   {{0xb4fa0158,0x26de9b60,0x89340013,0xa565803d}},	//   _שפרי, _aito_, إعلا, یگان,
   {{0x629a9b61,0xde059b62,0x2489198f,0xe758804a}},	//   kito, апли, mham_, лиці_,
   {{0x44ea9b5b,0x644f1b63,0x629a9b64,0x24891b65}},	//   _bù_, _haci, jito, lham_,
   {{0x26de82b8,0x200b1b66,0x44ea9b67,0x6f1d01ec}},	//   _dito_, kaci_, _cù_, hrsc,
   {{0x644f1b68,0xaf349125,0x24891b69,0x44ea9b6a}},	//   _jaci, _گرفت, nham_, _dù_,
   {{0x200b003b,0x26de80a4,0x9c7c9b6b,0x6b8d1b6c}},	//   daci_, _fito_, _tučn, nzag,
   {{0x644f1b6d,0x68e700f1,0x60cd0518,0x659592b8}},	//   _laci, _kujd, _aham, _казу,
   {{0x76439b6e,0xf8661b6f,0x44391b70,0x644f0118}},	//   meny, авно, _obs_, _oaci,
   {{0x44391b71,0x60cd1b72,0x442b1b73,0x23608267}},	//   _nbs_, _cham, _ncc_, _šije_,
   {{0x60cd1b74,0x24891916,0x6b8d017f,0xdee61b75}},	//   _dham, dham_, jzag, роги,
   {{0x44391b76,0x78a98582,0x76438365,0x96200035}},	//   _abs_, _ljev, neny, बलेट_,
   {{0x442b1b77,0x7c961b78,0x75239b79,0xf4961b7a}},	//   _bcc_, арац, nunz, араю,
   {{0x3d0880cf,0x44391b7b,0x644f1b7c,0x24891b7d}},	//   _सबसे_, _cbs_, _caci, gham_,
   {{0x4439011b,0x644f1b7e,0x76439b7f,0x0206028b}},	// [e00] _dbs_, _daci, keny, изан,
   {{0x442b0098,0xe1f700bf,0x75238ab4,0x61e380ee}},	//   _ecc_, игу_, kunz, _jgnl,
   {{0x2bb80105,0x26de809c,0x644f1b80,0xfe3700be}},	//   _आडवा, _rito_, _faci, _דריי_,
   {{0x26de8698,0x60cd1b81,0x6288820f,0x629a9b82}},	//   _sito_, _xham, zhdo, zito,
   {{0x78a982fd,0x26de9b83,0x44ea9b84,0x629a9b85}},	//   _djev, _pito_, _sù_, yito,
   {{0x75239b86,0x629a8118,0x76439b87,0x67228110}},	//   funz, xito, geny, ruoj,
   {{0x6d581b88,0x629a9b89,0x3218809a,0xe9671b3c}},	//   _švaj, vito, órym_, _карл_,
   {{0xc0e31b8a,0x7c360789,0x26de804f,0x644f03a8}},	//   _фотк, nfyr, _wito_, _xaci,
   {{0x8aa69b8b,0x629a9b8c,0x76439b8d,0x26de9b8e}},	//   ирод, tito, beny, _tito_,
   {{0x32078f4c,0x60cd1b8f,0xab5b0065,0xc3330bea}},	//   _ceny_, _sham, _szük, קות_,
   {{0xa3d80076,0x2d968d91,0x60cd005d,0x68e08059}},	//   ाधड_, _трас, _pham, _kimd,
   {{0x629a9b90,0x66088041,0x859b81c6,0x5faa8072}},	//   sito, _hedk, _בשבו, _कशाल,
   {{0xc7c7117f,0x2bd29b91,0x3eb81b92,0x4fc70071}},	//   рсни, देशा, fort_, рсна,
   {{0x644f1b93,0x6f1d1b94,0x6d5a8f28,0x60c281f6}},	//   _saci, rrsc, _krta, hlom,
   {{0xa3ea853e,0x241901bb,0x60cd1b95,0x200b1b96}},	//   _मला_, ловы_, _tham, paci_,
   {{0x6d5a805c,0x60cd1b97,0x320c8831,0x3d180fd5}},	//   _mrta, _uham, lady_, _फिरे_,
   {{0x644f1b98,0x2284016d,0x24868282,0xa3ca816f}},	// [e10] _vaci, _söka_, _mlom_, ळेच_,
   {{0x6d5a82bb,0x78a9920e,0x78bb939c,0x62868168}},	//   _orta, _sjev, _skuv, ëkoh,
   {{0x78a98499,0xbebb00f1,0x27e482f7,0x644f1b99}},	//   _pjev, rrëd, _bgmn_, _taci,
   {{0x76439b9a,0x320c84e8,0x60c29b9b,0x442b1b9c}},	//   weny, hady_, glom, _ucc_,
   {{0x44291b9d,0x6d5a8b0b,0xfd4c80ff,0x78a985f3}},	//   mga_, _arta, _thiể, _vjev,
   {{0x75239b9e,0x528500f7,0x6d5a80dd,0x7bda0039}},	//   tunz, _السك, _brta, _תקשו,
   {{0x6d5a805c,0x76439b9f,0x44291ba0,0x24869ba1}},	//   _crta, reny, oga_, _blom_,
   {{0x44291ba2,0x76439ba3,0x68e08110,0x78bb9ba4}},	//   nga_, seny, _gimd, _ukuv,
   {{0x291e85a4,0x6d5a9ba5,0x75239ba6,0x6d5c9ba7}},	//   erta_, _erta, sunz, _áran,
   {{0xf67480f7,0x6d5a826c,0x752380b4,0x25478061}},	//   _والخ, _frta, punz, _től_,
   {{0xd9459ba8,0xb4e60321,0x3eb81ba9,0xd00a1baa}},	//   щени, _पढे_, vort_, лене_,
   {{0x3eb802af,0xb7bd802e,0x20090162,0xb5fc8372}},	//   wort_, _acţi, _ceai_, _inġa,
   {{0xd12e84c0,0x44291a27,0x42d580e8,0x291e9bab}},	//   ومی_, dga_, _ліку, arta_,
   {{0x201e1bac,0x44291bad,0x20090362,0x24869bae}},	//   şti_, ega_, _eeai_, _zlom_,
   {{0xe8f59baf,0x291e8289,0x22459bb0,0x2d7e042b}},	//   _استخ, crta_, melk_, _oćeš_,
   {{0x44291bb1,0x27e08796,0xb05b1bb2,0xdb23807b}},	//   gga_, žini_, llän, _þróu,
   {{0xf8b31bb3,0x3eb81bb4,0x7afb9bb5,0x24801bb6}},	// [e20] _משה_, port_, nput, rkim_,
   {{0x34d3809a,0xb05b1614,0xa96a1bb7,0x3d0882f1}},	//   दगुद, nlän, лиза_, _सबले_,
   {{0x7c299bb8,0x6608807a,0xc6930039,0x7afb89da}},	//   kger, _redk, _מאז_, hput,
   {{0x660e01b4,0x53a6161a,0x7c2981ed,0x0aea01a8}},	//   labk, _гамб, jger, _مرسي_,
   {{0x60c2815d,0x68fb1bb9,0xb05b0338,0x8c468085}},	//   rlom, _čude, klän, qişə,
   {{0x44ee0104,0xfd650028,0x6d5a808e,0xacf89bba}},	//   _ký_, _nguồ, _prta, анку_,
   {{0x99860307,0x27e9803a,0xb05b016d,0x5d7a00be}},	//   _الأو, žana_, dlän, טאַק,
   {{0x7c299bbb,0x629e1bbc,0x6d5a9bbd,0x66089bbe}},	//   gger, lipo, _vrta, _wedk,
   {{0x44ee0104,0xeaf78077,0xc445803d,0x320a01ac}},	//   _lý_, یریت_, زیون_, _keby_,
   {{0xaa669bbf,0x27328087,0x33770039,0x39149bc0}},	//   стик, mân_, צעים_, омор,
   {{0x44291bc1,0x27329bc2,0x6d5a8102,0x44ee007b}},	//   yga_, lân_, _urta, _ný_,
   {{0x320c9bc3,0x4429002a,0x9c7c8115,0x629d8036}},	//   sady_, xga_, _mučk, ésor,
   {{0x629e1bc4,0x320c8690,0x9c7c8805,0xeb33804e}},	//   kipo, pady_, _lučk, _فروخ,
   {{0x442902a3,0x62819bc5,0x249900b9,0xacf91bc6}},	//   wga_, cklo, _smsm_, ингу_,
   {{0x40351056,0x787f00f1,0x629e1bc7,0x7a538591}},	//   _дейс, _lëvi, dipo, _رضوا,
   {{0x44291bc8,0xce330077,0xcd02809a,0xa0a400a9}},	//   uga_, _کودک, mość_, _најд,
   {{0x4429078a,0x660e1bc9,0x320a1bca,0x3a7515b7}},	// [e30] rga_, babk, _beby_, олар,
   {{0x9e071bcb,0x660e02a3,0x2eb40074,0x5b7b80be}},	//   _учил, cabk, ंकृत, ארמא,
   {{0xcd02809a,0x320a1bcc,0x9c7c811f,0x7c298be7}},	//   ność_, _deby_, _vučj, yger,
   {{0x50c90107,0xf8c90bb8,0x657a148c,0xdbd982df}},	//   रतिष, रतिय, äthe, nção,
   {{0x7aed0609,0x2ca91bcd,0x320a008e,0x62819bce}},	//   qqat, mnad_, _feby_, yklo,
   {{0x45199bcf,0xcd02809a,0xee3880e8,0x9c7c80c3}},	//   ация_, kość_, йні_, _fučk,
   {{0x20c9016f,0x7bc29bd0,0x648306ae,0x22458ec3}},	//   रताध, _ayou, _lõim, velk_,
   {{0xa2b90a0d,0x2ca91bd1,0x23608267,0x7c29823e}},	//   ्तव्, nnad_, _šija_, uger,
   {{0x2d8c157a,0xb05b148c,0xf09f023e,0x200f9bd2}},	//   údez_, tlän, dià_, magi_,
   {{0x200f9bd3,0x7afb9bd4,0x7c299bd5,0x78ad07b8}},	//   lagi_, rput, sger, _ajav,
   {{0x68461bd6,0xb05b1bd7,0xe0461bd8,0x62819bd9}},	//   онна, rlän, онни, rklo,
   {{0x660e010b,0x6d419bda,0x200f8074,0x61fc880a}},	//   wabk, _ipla, nagi_, ırla,
   {{0x61c6024c,0x3f841bdb,0xc1c6024c,0x3b099bdc}},	//   _वर्ष, ámu_, _वर्ग, _тело_,
   {{0x200f9882,0x7c2f1bdd,0x96ba069b,0x3f8c0035}},	//   hagi_, _accr, руму_, ądu_,
   {{0xa50a0ae7,0x649a1bde,0x7ae39bdf,0x200f9be0}},	//   реба_, атар_, _iint, kagi_,
   {{0x90c31056,0x9c7c811f,0x660e1be1,0x248d9be2}},	//   _обще, _ručk, sabk, nhem_,
   {{0x200f8006,0x7ae39be3,0x8c3d8201,0xab2a1be4}},	// [e40] dagi_, _kint, mişd, роза_,
   {{0x7ae39be5,0x6d419be6,0x9c7c9be7,0x66c01be8}},	//   _jint, _opla, _pučk, töku,
   {{0x629e1be9,0x6d418069,0xdb060106,0x443d82ec}},	//   ripo, _npla, _nykö, _obw_,
   {{0x7ae39bea,0x629e1beb,0x69c3831d,0x442f83a8}},	//   _lint, sipo, _myne, _ncg_,
   {{0xa2cb06bf,0x7ae39bec,0x052680ab,0x249f9bed}},	//   _तीव्, _oint, _মনের_, dium_,
   {{0x7ae39bee,0x0576845b,0x63a481e2,0xddc18353}},	//   _nint, قاعد, _žino, _dolž,
   {{0xa2b900bc,0x200f9bef,0x443d9bf0,0x442f838a}},	//   ्तर्, bagi_, _bbw_, _bcg_,
   {{0x69ce1bf1,0x6d5c9bf2,0x68e41bf3,0x7aeb9bf4}},	//   _izbe, _áram, _niid, _bugt,
   {{0x0a6a80c4,0xcd02809a,0x926a9bf5,0xc4d30039}},	//   арни_, wość_, арна_, וגה_,
   {{0x7ae38859,0x539b0bea,0x34a708fd,0xd90e87d2}},	//   _cint, ייפו, _गद्द, نیت_,
   {{0x7ae39bf6,0x9c7c842b,0x68e41bf7,0x2b4200b9}},	//   _dint, _luči, _biid, _lpkc_,
   {{0x68e402c1,0x8c468628,0x7ae39bf8,0x248d9bf9}},	//   _ciid, _феде, _eint, chem_,
   {{0x98b3811f,0x68e41bfa,0x629c1bfb,0xf09f0722}},	//   žeća_, _diid, _omro, rià_,
   {{0x64830665,0x7d1c9bfc,0x7ae39bfd,0x6d5e008e}},	//   _võim, _årss, _gint, _brpa,
   {{0xd49b1bfe,0x2d85027f,0x66cd81ac,0x29119bff}},	//   ара_, ále_, núka, ázat_,
   {{0xd7fb0698,0x7ae39c00,0xbca501a8,0x7aeb8c27}},	//   _тук_, _zint, أمري, _yugt,
   {{0x2d850289,0x7de705a8,0x5334047f,0x6d5e02d5}},	// [e50] šle_, _мінд, метт, _erpa,
   {{0xe7f90076,0x64830006,0x249f9c01,0xa3e70d86}},	//   ंडवा_, _kõik, zium_, _पलक_,
   {{0x7583004e,0xdcef01a9,0x37f881bc,0x2ca91c02}},	//   _غیرم, ēdēt, _ịkụz, pnad_,
   {{0x92ab00c8,0x27e900dd,0xa2cb0aed,0x66c00106}},	//   খতে_, _jgan_, _तीर्, sökt,
   {{0x200f9c03,0x69ce1c04,0x64830074,0xae1f123a}},	//   ragi_, _ezbe, _lõik, _बयान_,
   {{0xe7e3146d,0x442f9c05,0x7bda0039,0x200f9c06}},	//   _गणना_, _scg_, _לקרו, sagi_,
   {{0x7ae39c07,0x442f8118,0x200f8c2e,0x8c3d9c08}},	//   _rint, _pcg_, pagi_, yişd,
   {{0x67228025,0x27e91c09,0x69c38035,0x8c3d82d0}},	//   broj, _ngan_, _ryne, kişe,
   {{0x69c386be,0x68e418c2,0x248d91bf,0xdd918019}},	//   _syne, _riid, rhem_, بوں_,
   {{0x27e9035a,0x248d80f1,0x7c2d0114,0x68e41c0a}},	//   _agan_, shem_, hgar, _siid,
   {{0x63ad9c0b,0x648e8362,0x7c2d0299,0x8c3d829a}},	//   _žand, _bùid, kgar, tişd,
   {{0x2eb60d72,0x628a8019,0xdb0f01b3,0x7aeb9c0c}},	//   ृत्त, _elfo, _excé, _tugt,
   {{0xe28e8abe,0x44f180a9,0x6d5e173d,0x68e40406}},	//   _за_, _há_, _srpa, _viid,
   {{0x442d854f,0x27e91c0d,0x44f190ab,0x7c3b9c0e}},	//   lge_, _egan_, _ká_, lfur,
   {{0x44f19c0f,0x2ca002f9,0xf4840180,0x68e41c10}},	//   _já_, tiid_, واری, _tiid,
   {{0x7c2d1c11,0x7c3b9c12,0x768f804a,0xb5fc822b}},	//   ggar, nfur, _høyd, _anġl,
   {{0x44f19c13,0x442d9c14,0x20d200f7,0x2ca01c15}},	// [e60] _lá_, ige_, ráid_, riid_,
   {{0x9c7c8eef,0x7c2d01e4,0x394302f7,0x20d201a8}},	//   _vuči, agar, _bpjs_, sáid_,
   {{0x44f19c16,0xd7fa8530,0x66c0016d,0x867b0039}},	//   _ná_, бул_, söks, _הריו,
   {{0x67229c17,0x9c7c826c,0xc8799c18,0x6aa181ec}},	//   troj, _tuči, _coş_, hilf,
   {{0xd00f9baf,0x27e08009,0x442d8039,0x44f19c19}},	//   اله_, äin_, dge_, _aá_,
   {{0x44f18324,0x628504b8,0x629c1c1a,0x67229c1b}},	//   _bá_, ckho, _umro, rroj,
   {{0xd9431c1c,0x44f19c1d,0x7c3b9c1e,0x61430a8e}},	//   _пери, _cá_, ffur, _пера,
   {{0x44f19c1f,0x442d9c20,0xd00f866e,0x61fb0b80}},	//   _dá_, gge_, _ملف_, _đuli,
   {{0x3d088b9f,0x76900198,0x6aa18789,0x7ce79238}},	//   _सबके_, _käyd, filf, _sırt,
   {{0xaabe1c21,0x44f19c22,0x442d9c23,0x7c2d1c24}},	//   ्तिक, _fá_, age_, zgar,
   {{0x44f19c25,0xe8e0001c,0x7c2d1c26,0x6f0981ec}},	//   _gá_, _ngồi_, ygar, _zwec,
   {{0xab2a96fe,0xd90e803d,0x64830074,0x7c3b8122}},	//   _года_, پیک_, _võik, cfur,
   {{0x2bdb800f,0xaabe14a7,0x7ce78214,0x4df083eb}},	//   मेदा, ्ताक, _fırs, _चलाई_,
   {{0x68fc00eb,0x1df80a14,0x2ee50192,0xddc5128a}},	//   _otrd, зеры_, ölf_, _zahř,
   {{0x291c0065,0xd23b8039,0xdb1d01d0,0x7e6880ee}},	//   ával_, _הגול, _vysí, _mndp,
   {{0x7c2d1c27,0x5d541c28,0xd1388196,0xb4fb8e82}},	//   ugar, экст, mtą_, מפלי,
   {{0x7c2d1c29,0x64978162,0x768f80e8,0x386901a8}},	// [e70] rgar, cţiu, _høye, _inar_,
   {{0x09e080c8,0x7c2d1c2a,0xedf88c1c,0x6ce700e8}},	//   _ম্যা, sgar, ुरोध_, _німе,
   {{0x349502cb,0xc5fb1094,0xd1388110,0x62851c2b}},	//   _жанр, ्रीय_, ntą_, rkho,
   {{0x44f19c2c,0x9c7c88ae,0x78a280e5,0xdbf181d0}},	//   _rá_, _kuču, giov, třík,
   {{0x291804ae,0x2d8301e2,0xb8f406a7,0x44f19c2d}},	//   _evra_, lyje_, _सी_, _sá_,
   {{0x44f19c2e,0xd1388110,0x61ea810c,0xb05b1c2f}},	//   _pá_, ktą_, _ngfl, fläk,
   {{0x442d8813,0x2d830110,0x38690f3e,0xe61099ed}},	//   tge_, nyje_, _onar_, اشه_,
   {{0x44f19c30,0xdbf1801b,0x442d9c31,0x78a29c32}},	//   _vá_, přík, uge_, ciov,
   {{0x44f1877f,0x6aa19c33,0x7c3b9c34,0x26c7816b}},	//   _wá_, tilf, rfur, plno_,
   {{0x44f19301,0x6d451c35,0x66020d11,0x38691c36}},	//   _tá_, _opha, _đoko, _anar_,
   {{0x6fd9816f,0x386900dd,0x6d450282,0xbebb03ed}},	//   बेरं, _bnar_, _npha, trën,
   {{0xc689093f,0xbe2500ab,0x6724817f,0x768b0214}},	//   _דא_, ম্মদ_, šije, _rüya,
   {{0x6d4501f6,0x2cad9c37,0x38b904e8,0x3ea31799}},	//   _apha, mned_, néry_, fijt_,
   {{0x2cbf9c38,0xdce38084,0xcb1281c6,0xdd920180}},	//   loud_, tynė, _ילד_, پور_,
   {{0xdee31c39,0x7afd1c3a,0x66e31c3b,0xe810800d}},	//   тори, _atst, тора, ारमा_,
   {{0x69da0073,0x68ee0326,0x2cad9c3c,0x78a2802a}},	//   _útei, _rubd, nned_, xiov,
   {{0x60c41c3d,0x7ae71c3e,0xaca3819d,0x6d450234}},	// [e80] _ikim, _bijt, _nfọm, _epha,
   {{0x2cbf85f8,0x7bc61c3f,0xab5b0019,0x68ee1c40}},	//   houd_, _vyku, _gyüm, _pubd,
   {{0xceb30158,0xbebb0168,0x63a9007b,0x994a04a3}},	//   _ביז_, ytëz, _þenn, تلال_,
   {{0x2a698326,0x7aef0493,0x672b9c41,0xb4b781d0}},	//   _ɗaba_, _fuct, fugj, चको_,
   {{0x7e7a803a,0x78a29c42,0x76900009,0x3b04026b}},	//   _potp, riov, _täyd, _dépò_,
   {{0xd1389c43,0xa9261c44,0x6b840db1,0x6eeb0197}},	//   ytą_, _одгл, myig, _użbe,
   {{0x98a69c45,0x25078061,0x68fc0824,0x60c403f7}},	//   _живе, ورٹی_, _utrd, _okim,
   {{0x2cad9c46,0x22581c47,0x628e00e1,0x3d1103b7}},	//   gned_, _hark_, _hlbo, _तबसे_,
   {{0x6b840f18,0xb05b0338,0x628e1c48,0x752a8326}},	//   nyig, släk, _klbo, sufz,
   {{0x6f0285a4,0x60c41c49,0x38691c4a,0x32549138}},	//   mpoc, _akim, _snar_, хвор,
   {{0x29189c4b,0xaca4019d,0x22580039,0x6f028118}},	//   éra_, _anọt, _mark_, lpoc,
   {{0xd1389c4c,0x60d6031d,0x2d830196,0x3af29c4d}},	//   rtą_, _chym, vyje_, _tâp_,
   {{0xd1388d42,0x27ed1874,0x649798ad,0x00000000}},	//   stą_, ženo_, rţit, --,
   {{0x60c41c4e,0x2bd5015c,0x2d830110,0x9c7c8da8}},	//   _ekim, _दरबा, tyje_, _vuču,
   {{0x7aef81ac,0x7aef1c4f,0x68fb135a,0x6d581c50}},	//   íctv, _suct, _čudo, _švar,
   {{0x628e1c51,0x76570079,0x961480ab,0x2d830110}},	//   _albo, _waxy, সলিম_, ryje_,
   {{0x3f4f04b7,0x628e016b,0x7ebf01d0,0x3ea3090d}},	// [e90] _użu_, _blbo, tápě, pijt_,
   {{0xdddc00d2,0x2d830084,0x6f0d00b4,0x2fc902c4}},	//   skrš, pyje_, _iwac, _iyag_,
   {{0x6d450234,0x22581c52,0x66151c53,0x6b841a1a}},	//   _upha, _dark_, mazk, ayig,
   {{0x3869840e,0xc87982bb,0x8c3d8201,0x6f0d1c54}},	//   ñar_, _kişi_, kişa, _kwac,
   {{0x59d40e18,0x7afd068f,0x24891c55,0xfc3f0061}},	//   _थरथर, _utst, mkam_, _amíg_,
   {{0x8d559c56,0x644283c9,0xed599c57,0xaa450009}},	//   етич, _aboi, зок_, ävää_,
   {{0xa2c282f1,0xaabe1c58,0x20e8807e,0x3f898084}},	//   रकन्, ्तरक, _işin_, šau_,
   {{0x44f51c59,0xa3ba8b9f,0x24891c5a,0xa2b90ec5}},	//   _må_, _आँख_, nkam_, ्तक्,
   {{0x27ed9c5b,0x44f50aa2,0x2cbf9c5c,0x2cad8039}},	//   _igen_, _lå_, roud_, rned_,
   {{0x2cbf9c5d,0x644d1c5e,0x17fa1c5f,0x00000000}},	//   soud_, heai, ूर्व_, --,
   {{0x44f50cde,0x68e98063,0xa9699c60,0xaca38870}},	//   _nå_, _kied, чина_, _ajụj,
   {{0xf1b203c8,0x228082d6,0x6f0d0314,0x2bb88a74}},	//   רסט_, _bòks_, _bwac, _उँचा,
   {{0xeb8e891e,0x68e99c61,0x66150748,0x6f0d05ee}},	//   _си_, _mied, fazk, _cwac,
   {{0x52398158,0x443f9c62,0x68e99c63,0x6615011e}},	//   _זײַנ, lfu_, _lied, gazk,
   {{0x49bb83f8,0xfaff020f,0x04461c64,0x64599c65}},	//   _باشد_, _atë_, невн, _kawi,
   {{0x44f51c66,0x68e99c67,0x63a48110,0x60c40010}},	//   _då_, _nied, _žini, _ukim,
   {{0x6d4107d9,0x64598010,0x22581c68,0xfc3f0032}},	// [ea0] çlar, _mawi, _park_, _ajís_,
   {{0x44f50082,0x78a61c69,0x27ed8590,0x77641c6a}},	//   _få_, likv, _agen_, _irix,
   {{0x44f50082,0x68e99c6b,0xe5a6028b,0x35c486a7}},	//   _gå_, _bied, _чини, _लुढ़,
   {{0x7e7e0502,0x6459809a,0x78a61c6c,0xb5fc822b}},	//   _hopp, _nawi, nikv, _inġi,
   {{0x7e7e0422,0xde5885e9,0x17548198,0x225806ae}},	//   _kopp, далі_, твля, _tark_,
   {{0x20120032,0x27ed9c6d,0x443f874b,0x7e7e1c6e}},	//   _leyi_, _egen_, efu_, _jopp,
   {{0x80d100c8,0x52be1c6f,0x64830074,0x7e7e052e}},	//   _সংস্, ्तीस, _võiv, _mopp,
   {{0x7764062f,0x7e7e1c70,0xd4978ca4,0x44321c71}},	//   _orix, _lopp, ерь_, ngy_,
   {{0x64599c72,0x82a68d55,0x61f303ed,0x764e1c73}},	//   _dawi, ешне, _çelë, keby,
   {{0x2d969c74,0x68e980eb,0x60c28074,0x2012026b}},	//   _прес, _zied, loom, _aeyi_,
   {{0xddc88754,0x6f1b8024,0x39478b99,0x78a61c75}},	//   _hodž, _zvuc, _cpns_, fikv,
   {{0x645982b8,0x765a80b9,0xddc8817f,0x27ed04d6}},	//   _gawi, _haty, _kodž, øen_,
   {{0x44f50bfa,0x765a9c76,0x66150102,0x77641c77}},	//   _så_, _katy, tazk, _crix,
   {{0x44f50082,0x36d51c78,0x64598063,0xa6e780ff}},	//   _på_, тогр, _zawi, _nhữ,
   {{0xd5b81c79,0xb81081fe,0x66150cc7,0x7e7e1c7a}},	//   ест_, ाराम_, razk, _dopp,
   {{0x77641041,0x39138098,0x3f868176,0x765a9c7b}},	//   _frix, _смър, kyou_, _laty,
   {{0x68e99c7c,0x60c282a3,0x439417c8,0x77640118}},	// [eb0] _ried, doom, гатс, _grix,
   {{0x6d488022,0x765a9c7d,0x68e99c7e,0x66d2007b}},	//   _opda, _naty, _sied, lækn,
   {{0x68e99c7f,0x673d1388,0x7aea81b9,0x39470722}},	//   _pied, ltsj, _mift, ïns_,
   {{0x20d20307,0x26c5826f,0xe0df1c80,0x7e7e00e5}},	//   háin_, _sklo_, nmò_, _zopp,
   {{0x64599c81,0x23d50f12,0x68e99c82,0x765a9c83}},	//   _rawi, _दरिद, _vied, _baty,
   {{0x68e99c84,0x64599c85,0x945d809a,0x7aea9c86}},	//   _wied, _sawi, końc, _nift,
   {{0x68e98364,0x64599c87,0xd6580039,0x443f9c88}},	//   _tied, _pawi, גיות_, tfu_,
   {{0x2d51800d,0x67249c89,0x27ed806a,0x0b459c8a}},	//   _vše_, šija, _ugen_, внин,
   {{0x645b9c8b,0xe2998e9f,0x443f9c8c,0x6f1b8699}},	//   rdui, дап_, rfu_, _uvuc,
   {{0x64598010,0x09e500ab,0x765a9c8d,0x443f9c8e}},	//   _wawi, _প্যা, _gaty, sfu_,
   {{0x81c98a49,0x20120f23,0xe9d98987,0x3ea78019}},	//   লেন_, _peyi_, ько_, mint_,
   {{0x387f83d3,0x7e0a0076,0x3ea79c8f,0x64830006}},	//   _jour_, वर्ग_, lint_, _mõis,
   {{0xa4d4835f,0x80d100ab,0x087680be,0x2d879c90}},	//   _соці, _সংশ্, דערט_, lyne_,
   {{0x9f9e0073,0x3ea79c91,0x60c29c92,0x78a61c93}},	//   _ação_, nint_, zoom, sikv,
   {{0x69ca8355,0x2d8c1c94,0x764e1c95,0x765c1c96}},	//   _gyfe, áde_, reby, rdry,
   {{0x29059c97,0x09b000ab,0x764e1c98,0x765c1c99}},	//   mpla_, _করলা, seby, sdry,
   {{0x7e7e12f1,0xf4128158,0x753c0063,0xfce3137b}},	// [ec0] _topp, יפן_, strz, рото,
   {{0x64830074,0xddc89c9a,0x386d83ba,0xdee61c9b}},	//   _sõit, _rodž, _aner_, _шопи,
   {{0xfbc78077,0x386d9142,0x3ea79c9c,0xa2b31c9d}},	//   _چت_, _bner_, dint_, _आदर्,
   {{0xfbc7880b,0x2eca8bb3,0x387f80e7,0x765a9c9e}},	//   _نت_, ित्त, _cour_, _saty,
   {{0x765a8110,0x64830006,0x69d50019,0x387f9c9f}},	//   _paty, _võit, _ezze, _dour_,
   {{0x3ea79ca0,0x6f0207d9,0x649580f7,0x60c29ca1}},	//   gint_, _çocu, _láid, soom,
   {{0x82a30071,0x64b38087,0xfaa31b3c,0xc60b80ab}},	//   _тарж, răin, _таро, _রাখা_,
   {{0x44221ca2,0xb4cc816f,0x69ca8428,0x70569ca3}},	//   _jdk_, ळते_, _ryfe, _جنرا,
   {{0xee3a9ca4,0x44221ca5,0x8c3d880a,0x20d201a8}},	//   _она_, _mdk_, mişl, táin_,
   {{0x63a90110,0x3ea79ca6,0x7c2900eb,0x44221ca7}},	//   _ženk, cint_, _ķerm, _ldk_,
   {{0x387f873a,0x6d488add,0x63ad8125,0xe1348196}},	//   _your_, _upda, _þann, ынны,
   {{0x387f1ca8,0x20d20013,0x63a481e2,0x386d04c3}},	//   ður_, sáin_, _žinu, ñer_,
   {{0x26c31ca9,0x7aea84b7,0x7c229caa,0x66d2006a}},	//   tojo_, _tift, _idor, rækn,
   {{0x44f890ab,0x39580267,0x6d5c81a8,0x6fe901a9}},	//   _ké_, _osrs_, _áras, _rīcī,
   {{0x44f8877f,0x44220359,0x3958026c,0x673d1cab}},	//   _jé_, _bdk_, _nsrs_, stsj,
   {{0x44f89cac,0x273b8104,0x65650267,0x80d10264}},	//   _mé_, yên_, _vrhh, _সূর্,
   {{0x44f88324,0x20191cad,0x1af41cae,0x26c31caf}},	// [ed0] _lé_, masi_, иптя, pojo_,
   {{0x20d20013,0x7e5500e8,0x68ed0362,0x44f881a8}},	//   háil_, _своє, _hiad, _oé_,
   {{0x387f9cb0,0x6618826f,0x68ed0019,0x3ea79cb1}},	//   _pour_, davk, _kiad, vint_,
   {{0x64830074,0x66020da8,0xdb1d0198,0x22840106}},	//   _võis, _đoki, _pysä, _sökt_,
   {{0xfeb80288,0x9cd60f60,0x20d200f7,0x3ea79cb2}},	//   _سایت_, _תורה_, dáil_, tint_,
   {{0x44f89cb3,0x645d1cb4,0x0ccb8eed,0x2ca9031d}},	//   _bé_, _hasi, ात्म, liad_,
   {{0x20191cb5,0x44f88013,0x88838077,0x3ea79cb6}},	//   kasi_, _cé_, _پیشن, rint_,
   {{0x2366803b,0x44f89cb7,0x20d20013,0x2ca9031d}},	//   _broj_, _dé_, gáil_, niad_,
   {{0x645d1cb8,0x661890d3,0x44391cb9,0x69da01d0}},	//   _masi, bavk, _mcs_, _úter,
   {{0x44f8877f,0x2019002e,0x4439038a,0x7c228f3e}},	//   _fé_, easi_, _lcs_, _edor,
   {{0x2019022e,0x44f8877f,0xa29f8006,0x68ed01e4}},	//   fasi_, _gé_, गोष्, _biad,
   {{0x645d1cba,0x20191cbb,0x68f51cbc,0x20d200f7}},	//   _nasi, gasi_, _muzd, cáil_,
   {{0x7bcb87d9,0x32458767,0x68ed1cbd,0x2ca90355}},	//   _uygu, _белг, _diad, diad_,
   {{0xed5a0b30,0xb4be1cbe,0x248d801b,0x29059cbf}},	//   ног_, ेत्_, lkem_, ppla_,
   {{0x68ed1cc0,0x2ca9031d,0x68f500d2,0x20191cc1}},	//   _fiad, fiad_, _nuzd, basi_,
   {{0x6abe0f1b,0x68ed1cc2,0x2ca9031d,0x64a31cc3}},	//   ्त्र, _giad, giad_, баса,
   {{0x6b899cc4,0xab6607ac,0x645d1cc5,0x2fcd822c}},	// [ee0] nyeg, ывал, _dasi, _nyeg_,
   {{0x248d8006,0x68ed1cc6,0x60c98deb,0x60db9cc7}},	//   hkem_, _ziad, _akem, _ahum,
   {{0x645d1cc8,0x44221cc9,0x60db9cca,0xb05b01ec}},	//   _fasi, _tdk_, _bhum, plät,
   {{0x60db9ccb,0x44f89ccc,0x645d1ccd,0xb05b1cce}},	//   _chum, _ré_, _gasi, llär,
   {{0x44f89ccf,0x43751cd0,0x60db8077,0x8c3d861c}},	//   _sé_, _курт, _dhum, rişl,
   {{0x44f88324,0x4ab8000c,0x645d1cd1,0x248d81ed}},	//   _pé_, _आदिव, _zasi, ekem_,
   {{0x20191014,0x645d0309,0x20d20013,0x765e004f}},	//   yasi_, _yasi, táil_, _mapy,
   {{0x6f04007d,0x44f8801c,0x60db80b9,0x765e02d5}},	//   _otic, _vé_, _ghum, _lapy,
   {{0x36368277,0x2019059e,0xe80a835a,0x20d20013}},	//   _مراس, vasi_, _ह्या_, ráil_,
   {{0x44f89cd2,0x20191cd3,0xfaff0168,0x20d200f7}},	//   _té_, wasi_, _orën_, sáil_,
   {{0x6f041cd4,0x68ed1cd5,0xe3af89a7,0x32638084}},	//   _atic, _piad, قری_, стыв,
   {{0x6d5a9cd6,0x68e29cd7,0x60db9cd8,0x6f1d1cd9}},	//   _ista, nmod, _xhum, tssc,
   {{0xb4c0823c,0xb4c2835a,0x2ca6813c,0x68ed1cda}},	//   ंकी_, ृती_, _imod_, _viad,
   {{0x20191cdb,0x68ed1cdc,0x256387d9,0x645d1cdd}},	//   sasi_, _wiad, _yıl_, _sasi,
   {{0x645d1cde,0x68ed1cdf,0x6f040b87,0x201910e1}},	//   _pasi, _tiad, _etic, pasi_,
   {{0x69d89ce0,0x245802c7,0x752801ac,0x645d1ce1}},	//   _izve, лась_, ádza, _qasi,
   {{0x645d1ce2,0x2ca91ce3,0x68f51ce4,0x291e9ce5}},	// [ef0] _vasi, riad_, _suzd, lsta_,
   {{0x60db8b18,0x645d1ce6,0x60c99ce7,0x291e9ce8}},	//   _shum, _wasi, _skem, osta_,
   {{0x645d1ce9,0x6d5a9cea,0x41551ceb,0x81e68264}},	//   _tasi, _nsta, рвес, যুর_,
   {{0x291e913f,0x765e009a,0x3cfb8035,0x69ce0366}},	//   ista_, _zapy, _लंबे_, _dybe,
   {{0x8335093f,0x65689cec,0x6d5a9ced,0x2b401cee}},	//   _דאָס_, _ardh, _asta, ctic_,
   {{0x291e9cef,0x7aee01ec,0x83fd8019,0x68f51cf0}},	//   ksta_, _gibt, zdőd, _tuzd,
   {{0x248d8419,0xd61881a8,0x291c01d0,0x2ca68197}},	//   tkem_, اتها_, ávat_, _bmod_,
   {{0x03258abe,0x291e8106,0x9f05803d,0xac858037}},	//   адин, dsta_, _نورو, ргил,
   {{0x291e9cf1,0x6d5a8c8c,0x656880f1,0xeb998530}},	//   esta_, _esta, _erdh, тип_,
   {{0xea899cf2,0x78ab8aa2,0x7aa59cf3,0x64878388}},	//   тбол_, ligv, риоз, _añit,
   {{0xe807053e,0xd9459cf4,0xe0da1cf5,0x26c79cf6}},	//   _व्हा_, шени, кво_, mono_,
   {{0xaca301bc,0x6e250014,0x26c79cf7,0x290381a9}},	//   _brọd, _adhb, lono_, īja_,
   {{0xe28e9cf8,0x291e9cf9,0xb8fc9cfa,0x765e06c0}},	//   _да_, asta_, _ती_, _papy,
   {{0x91e59cfb,0x6d5a8114,0x26c78365,0x539a8039}},	//   _коле, _ysta, nono_, _בינו,
   {{0xb05b08dc,0x26c7847f,0x5fd80072,0x68e29bc2}},	//   rlär, iono_, _ठरवल, ymod,
   {{0xdd8f0eca,0x77860098,0x62839cfc,0x765e004f}},	//   ذوق_, _влиз, _hono, _wapy,
   {{0x6f041601,0xd3871cfd,0x26c79cfe,0x23e00424}},	// [f00] _utic, айте_, kono_, पेंद,
   {{0x26c78110,0x2b401cff,0xa01b1d00,0x64440162}},	//   jono_, rtic_, sköt, sfii,
   {{0x2b401d01,0x628380e5,0xd83a81e5,0xf67b0158}},	//   stic_, _mono, вэл_, _סאטמ,
   {{0x2b401d02,0x69ce003e,0x504685fa,0x650201bc}},	//   ptic_, _vybe, редб, _ọkwụ,
   {{0x26c79d03,0xdfcf8013,0xbebb00f1,0x44fc1d04}},	//   fono_, ويم_, rrëv, _hí_,
   {{0x44fc0324,0x62839d05,0x661c1d06,0x68e284fe}},	//   _kí_, _nono, nark, smod,
   {{0x44fc1d07,0xb87b000d,0xa01b0106,0xa3e3864a}},	//   _jí_, dmín, ljöe, फेस_,
   {{0x44fc1d08,0x661c011e,0x3218008e,0x38601d09}},	//   _mí_, hark, _hery_, _nair_,
   {{0xf749803d,0xa2c2816f,0xb7fd0424,0x321800b9}},	//   _مجله_, रकल्, _एलबम_, _kery_,
   {{0x62839d0a,0x26c79d0b,0x661c1d0c,0x7f3b825f}},	//   _cono, cono_, jark, _בעמו,
   {{0x44fc1d0d,0x6d5a9d0e,0x62839d0f,0x7c261d10}},	//   _ní_, _usta, _dono, _odkr,
   {{0x291e9d11,0x38601d12,0xdcee0110,0x66171d13}},	//   rsta_, _cair_, mybė, _sexk,
   {{0x44269d14,0x661c1d15,0x44fc1d16,0x38601d17}},	//   _ido_, fark, _aí_, _dair_,
   {{0x44fc1d18,0x661c1d19,0x3f4280ff,0x27fe01d0}},	//   _bí_, gark, _mưu_, ětna_,
   {{0x3f428028,0x44269d1a,0x88d600ab,0xdcee0084}},	//   _lưu_, _kdo_, _সংরক, nybė,
   {{0x44fc1d1b,0x316d1d1c,0x30150187,0xd4981d1d}},	//   _dí_, _čez_, _удир, ару_,
   {{0x26c7861b,0x60cd1d1e,0x69ca8a74,0x24581d1f}},	// [f10] yono_, _ikam, _सुती, шать_,
   {{0x99671d20,0x661c1d21,0xdcee0084,0x3b09011c}},	//   ител, cark, kybė, rpaq_,
   {{0xd3668288,0x44269d22,0x161a8063,0x26c78098}},	//   _که_, _odo_, _नज़र_, vono_,
   {{0x776984c3,0xa3cc81a2,0x44269d23,0x40359d24}},	//   _prex, _शुभ_, _ndo_, седс,
   {{0x26c79d25,0x753501b9,0x32181d26,0x60cd0c53}},	//   tono_, luzz, _fery_, _mkam,
   {{0xc9871d27,0x51871d28,0xee3880e8,0x76551d29}},	//   _куби, _куба, ині_, nezy,
   {{0x09e50a49,0x31e500c8,0x99850013,0x01e500c8}},	//   _প্রা, _প্রশ, _الزو, _প্রদ,
   {{0x69ca9d2a,0xa8a48160,0x442680f1,0xe5709a3e}},	//   _सुधी, _друк, _cdo_, بطه_,
   {{0x6b8d1d2b,0x26c79d2c,0x661c1d2d,0x201d95d7}},	//   nyag, pono_, yark, mawi_,
   {{0x60cd1b9e,0x44269d2e,0x81c280c8,0x38601d2f}},	//   _akam, _edo_, ্ধন_, _sair_,
   {{0xb87b026f,0x69ca8441,0xec15803d,0x661c1d30}},	//   rmín, _सुदी, _هواد, vark,
   {{0x656e8307,0x44fc077f,0x201d83f8,0x62839d31}},	//   _ábha, _rí_, nawi_, _wono,
   {{0x44fc1d32,0x2d8a834a,0x6d439d33,0xafdb013c}},	//   _sí_, _über_, ltna, lføj,
   {{0x629a9d34,0xb05b0106,0x201d9d35,0x7e63808e}},	//   chto, släp, hawi_, ndnp,
   {{0x7e619d36,0x661c02a3,0x201d9d37,0x7c961d38}},	//   _malp, rark, kawi_, брац,
   {{0x661c1d39,0x3860003c,0x201d9d3a,0x44fc1d3b}},	//   sark, _uair_, jawi_, _ví_,
   {{0xd4671194,0xc9f600f7,0x201d80ee,0xb2260e02}},	// [f20] щите_, مساع, dawi_, ймал,
   {{0x44fc1d3c,0xe8108526,0x753501b9,0x2bac0072}},	//   _tí_, ार्थ_, buzz, _घेणा,
   {{0x81c98a49,0x32180051,0x3f42801c,0x75351d3d}},	//   লের_, _very_, _sưu_, cuzz,
   {{0xa01b016d,0x443d9d3e,0x26ca0234,0x7f4280e5}},	//   nköp, _ncw_, lobo_, ttoq,
   {{0x20020bda,0x645601cc,0x6d4380ff,0x649c8174}},	//   icki_, meyi, etna, _héig,
   {{0xa01b0364,0x2480005c,0x7e619d3f,0xdcee0110}},	//   hköp, ljim_, _calp, tybė,
   {{0x201d82e7,0x7f4281b9,0x2cad9d40,0x25e39d41}},	//   bawi_, stoq, fied_, टेली_,
   {{0x69dc1d42,0x64561d43,0x44269d44,0xdcee0084}},	//   _izre, neyi, _qdo_, rybė,
   {{0x6d698029,0x4426856c,0x57fb810f,0x26ca1d45}},	//   _īpaš, _vdo_, _תלמו, kobo_,
   {{0x60cd1d46,0x6d5e1d47,0x321881ac,0xe810801b}},	//   _skam, _ospa, úry_, ारका_,
   {{0x2cad8b3c,0x44269d48,0x67240da8,0x20f3026c}},	//   bied_, _tdo_, _avij, _ućit_,
   {{0x55778158,0x44269d49,0x661a837b,0x629a80f1}},	//   _לעבן_, _udo_, _hetk, shto,
   {{0x6724003a,0x6d5181dd,0x29079d4a,0x24800503}},	//   _cvij, čkaš, _etna_, djim_,
   {{0x672402fd,0x69dc017f,0x24868282,0x753504b7}},	//   _dvij, _ozre, _hoom_, tuzz,
   {{0x248681e9,0x59cf8aed,0x321e9d4b,0xdd940048}},	//   _koom_, _सुपर, maty_, пары,
   {{0x753512bb,0x8c3d87d9,0x60cd1d4c,0x6b8d1d4d}},	//   ruzz, tişi, _ukam, tyag,
   {{0x6d5e1d4e,0x26ca1d4f,0xfbd30154,0x69dc00ee}},	// [f30] _espa, bobo_, ستر_, _azre,
   {{0x63a9095e,0x661a9d50,0x201d9d51,0xbebb0168}},	//   _žens, _netk, wawi_, rrës,
   {{0x6724120e,0x2bd50d86,0x201d9d52,0x6f160035}},	//   _zvij, _दरका, tawi_, _zwyc,
   {{0x2ec186bf,0x24868282,0x6e289d53,0x4fd58171}},	//   शक्त, _noom_, _addb, ожет,
   {{0xf1cf8105,0x643a00be,0x201b008e,0xddda81a1}},	//   _सुनन, _דערנ, _meqi_, _rotš,
   {{0x3eae8e23,0x661a80d2,0x6d439d54,0x443d8079}},	//   gift_, _cetk, ttna, _scw_,
   {{0x7e619d55,0x78bb8711,0x7d0201d6,0x201d876d}},	//   _valp, _tjuv, _čosk, pawi_,
   {{0x62988aa2,0xcc898bda,0x6d439d56,0x672281c0}},	//   _alvo, рбие_, rtna, bsoj,
   {{0x6287003a,0x6d439d57,0x7e619d58,0x254e811c}},	//   _kojo, stna, _talp, _cəlb_,
   {{0xa9259d59,0x24800bda,0x6f099086,0x4ea78a2e}},	//   одол, zjim_, _itec, _урба,
   {{0x6724030b,0x3f8f8355,0x2d678024,0x24868069}},	//   _svij, lygu_, _uđe_, _foom_,
   {{0x649c8174,0xa91100d4,0x6287046d,0x7de00032}},	//   _réig, डीएफ_, _lojo, _lásí,
   {{0x661a8457,0x321e9d5a,0x776d00e5,0x2d851d5b}},	//   _yetk, baty_, _crax, älen_,
   {{0x21699d5c,0x64499d5d,0xa9699d5e,0xfc3f023e}},	//   _вики_, lfei, _вика_, _ací_,
   {{0x649c8307,0x26ca1d5f,0xa2ba03dd,0x249902f7}},	//   _féid, robo_, ्वस्, _blsm_,
   {{0x7c3b9d60,0x24869d61,0x26ca1d62,0x2fc0022c}},	//   ngur, _xoom_, sobo_, _txig_,
   {{0x6724030b,0x62871d63,0x776d1d64,0x52aa0471}},	// [f40] _uvij, _bojo, _grax, авам_,
   {{0x62871d65,0x649c80f7,0x64561d66,0x1ae31d67}},	//   _cojo, _téig, seyi, доум,
   {{0x661a9d68,0x6f0980e5,0xa01b0106,0x62871d69}},	//   _retk, _atec, ljöa, _dojo,
   {{0x50ca009a,0x661a9d6a,0x20ca001b,0x67228198}},	//   रविष, _setk, रविध, tsoj,
   {{0x44201d6b,0x661a84c4,0x24868039,0xe8e08129}},	//   mai_, _petk, _room_, hiệt_,
   {{0x2a630267,0x24869d6c,0x6b8b0106,0x6d5c02ed}},	//   _gajb_, _soom_, ägge, owra,
   {{0xd49a80c4,0x24869d6d,0x661a9d6e,0x69dc01a9}},	//   ири_, _poom_, _vetk, _uzre,
   {{0x44201d6f,0xb19880ff,0x734a8087,0x672d9d70}},	//   nai_, _ngưỡ, ачов_, šaja,
   {{0x68fc1d71,0x61ef8085,0x649c81a8,0x1fd180ab}},	//   _hurd, əklə, _réid, ়েবস,
   {{0x68fc1d72,0x38669d73,0x7c3b9d74,0x20e89238}},	//   _kurd, ldor_, agur, _eşit_,
   {{0x44201d75,0x69ca946d,0xe45a835f,0x24868282}},	//   kai_, _सुशी, _вже_, _toom_,
   {{0x44201d76,0x68fc1d77,0x776d1d78,0x290a0267}},	//   jai_, _murd, _prax, _mtba_,
   {{0x44201d79,0x69ca864d,0x610180eb,0xe6671229}},	//   dai_, _सुरी, _vēla, отво,
   {{0x81c980ab,0x2455001c,0x7658804f,0x809f0035}},	//   লেই_, _ấm_, nevy, खोजे,
   {{0x44201d7a,0xbd681d7b,0x62870388,0x00950162}},	//   fai_, орте_, _rojo, _никэ,
   {{0x44201d7c,0x776d062f,0x628700a4,0x7c209d7d}},	//   gai_, _trax, _sojo, namr,
   {{0x62871d31,0x8c3d8214,0x1eab00f7,0x7bc10035}},	// [f50] _pojo, mişt, _نادي_, _ślub,
   {{0x8c3d9d7e,0x7afd9d7f,0x1b040264,0x68fc1d80}},	//   lişt, ísti, _লিখে_, _burd,
   {{0x44201d81,0x6f099d82,0x7c209d83,0xad27003d}},	//   bai_, _stec, kamr, _برخو,
   {{0xe8f806b5,0x649580f7,0x8c3d8087,0x68fc1d84}},	//   ілі_, _cáil, nişt, _durd,
   {{0xb9020076,0xb4d7016f,0xcb4400a9,0x62871d85}},	//   _नी_, िती_, _охри, _tojo,
   {{0x81cd00c8,0x7afd1d86,0x8afa01c6,0x24678129}},	//   শেষ_, _iust, _להשי, _ốm_,
   {{0xceb40158,0x6d471d87,0x855780d5,0x649580f7}},	//   ויס_, ntja, تیار_, _fáil,
   {{0x7af50102,0x81c28264,0x442b1d88,0x00000000}},	//   _hizt, ্ধা_, _jdc_, --,
   {{0xbf1592dc,0x64499d89,0x7c3b9d8a,0xe3b180f7}},	//   _رواب, rfei, rgur, عرب_,
   {{0x78ad1d8b,0x64499d8c,0x7c3b9d8d,0x44201d8e}},	//   _amav, sfei, sgur, zai_,
   {{0x81cd00c8,0x44201d8f,0x68fc04c3,0x644f1d90}},	//   শের_, yai_, _xurd, _obci,
   {{0xa3ac0665,0x7c2081a1,0x44201d91,0x29e1841c}},	//   _कइल_, camr, xai_, _açaí_,
   {{0x442006f7,0x7afd01e2,0xb4c9816f,0xf77201a8}},	//   vai_, _nust, ोती_, راح_,
   {{0x44201d92,0x59cf86a7,0x91fc81a9,0x200d811c}},	//   wai_, _सुथर, ndāl, əmiş_,
   {{0x44201d93,0x7c960160,0x649580f7,0x442b00e5}},	//   tai_, прац, _láim, _bdc_,
   {{0x2be292ee,0x249f80a9,0x7afd1d94,0xa3e28074}},	//   _परमा, nhum_, _bust, _धरम_,
   {{0x7af51d95,0x44201d96,0x59cf8076,0x7afd1d97}},	// [f60] _bizt, rai_, _सुतर, _cust,
   {{0x44201d98,0x7c2080ee,0x2bce954b,0x7afd1d99}},	//   sai_, zamr, _हँसा, _dust,
   {{0x68e40ad4,0x442b03f7,0xa3ac11bc,0x2be29d9a}},	//   _khid, _fdc_, _केर_, _परभा,
   {{0x7afd1d9b,0x20d21d9c,0x68fc054f,0x69d51d9d}},	//   _fust, máis_, _vurd, _dyze,
   {{0x7afd1d9e,0x68fc034a,0x6726035f,0x672d812b}},	//   _gust, _wurd, nskj, šajn,
   {{0x425503bd,0x68fc1d9f,0x63a41da0,0x543600d7}},	//   _отст, _turd, mzin, _برگر,
   {{0x7afd1da1,0x63a41da2,0x649581a8,0x321c9da3}},	//   _zust, lzin, _táil, _revy_,
   {{0x2ca0076d,0x7de70019,0xf7469b4d,0xc5f301c6}},	//   nhid_, lésé, _небо, עדה_,
   {{0x7afd062f,0x8fa39da4,0xe45703de,0x7de2826b}},	//   _xust, _зате, ליקט_, _bísí,
   {{0x63a41da5,0x3a749da6,0xcb1301c6,0x8f9b825f}},	//   izin, флор, עלת_, _הימי,
   {{0xa3cc8076,0x4035072a,0xade89da7,0xfbc400ab}},	//   _शुर_, менс, टेशन_, ্ধিত,
   {{0x290a8341,0x68e41da8,0x7bc30162,0x20d21da9}},	//   ība_, _chid, şnui, dáis_,
   {{0x68e41daa,0x442b1dab,0x63a400f3,0x8c3d9dac}},	//   _dhid, _rdc_, jzin, rişt,
   {{0x63a41dad,0x7afd1dae,0x442b0267,0x6d471daf}},	//   dzin, _rust, _sdc_, ttja,
   {{0xe5c4079e,0xd49b1db0,0x71f78154,0x78ad026f}},	//   есто, бра_, _عروس_, _tmav,
   {{0xb4d70e18,0xe45f0125,0x6d471db1,0x68e41db2}},	//   िते_, _mjög_, rtja, _ghid,
   {{0x6d4704a4,0x628a9db3,0xc62280ab,0xa3e71db4}},	// [f70] stja, _kofo, _নানা_, यें_,
   {{0x6f0d1db5,0xbd020144,0x8f9c01c6,0x628a8e06}},	//   _itac, ñéca, _ליחי, _jofo,
   {{0xb5fc84b7,0x78bd1db6,0x442b006a,0x20d21db7}},	//   _paġn, onsv, _tdc_, cáis_,
   {{0x442b1db8,0xddde1601,0x69d501ac,0x2ca01db9}},	//   _udc_, _uopš, _vyze, chid_,
   {{0x644d00b9,0xf7459dba,0x5f94804a,0x7afd03ca}},	//   mfai, фело, ницт, _uust,
   {{0x628a81a9,0x20d200f7,0x6442802a,0x644d1dbb}},	//   _nofo, náir_, _acoi, lfai,
   {{0x236d0858,0x249f9670,0x7d1a9670,0x24e99dbc}},	//   _šejh_, thum_, _cwts, омки_,
   {{0x644d1dbd,0x649580f7,0x9f6500e1,0xfd5e801c}},	//   nfai, _táim, _štýl_, _huyề,
   {{0x7690025d,0x6f0d1dbe,0x80c900ab,0x32059dbf}},	//   _käyt, _ntac, রগঞ্, tcly_,
   {{0x09059bbf,0x68e41dc0,0xd0480085,0x20d20216}},	//   мпон, _shid, əməy, yáis_,
   {{0x63a40098,0x661e1dc1,0x6e239dc2,0xdd9b8087}},	//   zzin, _repk, manb, _уша_,
   {{0x644280f7,0x7de70019,0x6f1b81bc,0xf485853d}},	//   _gcoi, zésé, _kwuc, _تائی,
   {{0x644d00f7,0xe3ae89a8,0x628a9dc3,0x10a31dc4}},	//   dfai, _рб_, _fofo, тиян,
   {{0x76900364,0x7afd9dc5,0x12fa8039,0xddc38019}},	//   _näyt, ístu, _והסב, lenő,
   {{0x2ca00014,0x644d1dc6,0x768f804a,0x2c0b0135}},	//   thid_, ffai, _høys, _ụjọ_,
   {{0x443f9dc7,0x63a41dc8,0x672981ca,0x20d200f7}},	//   ngu_, tzin, _ovej, ráis_,
   {{0xc61d00c8,0x6e239dc9,0x7de70019,0x236d806a}},	// [f80] _তারা_, kanb, tésé, nvej_,
   {{0x248b00b9,0x2ca01dca,0xe45f0106,0x6b8b0106}},	//   _eocm_, shid_, _sköt_, ägga,
   {{0x64a6014c,0x443f8ad4,0x81d600ab,0xc5fa02f1}},	//   _жана, kgu_, াইভ_, ंशीय_,
   {{0x765c1dcb,0x753c1dcc,0x38ab0035,0x644d01a8}},	//   lery, murz, _górę_, cfai,
   {{0x7c240f2b,0x201f808e,0x2b490aae,0x672981a1}},	//   mair, _deui_, ctac_, _cvej,
   {{0x7c241dcd,0x64428013,0x443f9dce,0x2458801c}},	//   lair, _scoi, egu_, _ẩm_,
   {{0x26ce9dcf,0xa01b007b,0x3d12016f,0xaca401bc}},	//   rofo_, fjöl, धीचे_, _naịt,
   {{0x7c241dd0,0x628a82af,0x7764002a,0x2be28fb2}},	//   nair, _sofo, _osix, _परदा,
   {{0x9ce88117,0x6e239dd1,0xd00f9dd2,0x648e8229}},	//   _ہوئے_, banb, _خلق_, _bùir,
   {{0x7c241dd3,0x765c1dd4,0x648e851e,0xee379dd5}},	//   hair, jery, _cùir, _ону_,
   {{0x3a37078d,0x7c241dd6,0x60cf0087,0xe873003d}},	//   ורים_, kair, tocm, نندگ,
   {{0x78a29dd7,0x6f00804f,0x645b9dd8,0x2baf8b99}},	//   nhov, _kumc, ceui, _जेवा,
   {{0x7c241dd9,0xb90582ef,0x23e295a7,0x628a8915}},	//   dair, _बी_, _परिद, _tofo,
   {{0x44249dda,0xb4d70054,0x768f835f,0x59cf8f21}},	//   lam_, ित्_, _høyr, _सुवर,
   {{0x77641ddb,0xa2cb86b7,0x20c70be2,0x3ce68069}},	//   _esix, सकर्, _осиг, _khov_,
   {{0x44249ddc,0x64409ddd,0x7c240c5e,0xa3e29344}},	//   nam_, ngmi, gair, _धरा_,
   {{0xf8bf0efc,0x644d1dde,0x69d880f3,0x765c02ec}},	// [f90] mné_, rfai, _hyve, bery,
   {{0x44249ddf,0x386901d8,0xf8bf03cb,0xfd5e8028}},	//   ham_, _haar_, lné_, _quyề,
   {{0x44249de0,0x6729811f,0x443f9de1,0x59d482f1}},	//   kam_, _svej, ygu_, _ठुमर,
   {{0xf8bf1de2,0x3869133a,0x7c241de3,0x656500b9}},	//   nné_, _jaar_, cair, _ishh,
   {{0x38691de4,0x6e239de5,0x76900364,0xe0d880e8}},	//   _maar_, tanb, _täyt, єві_,
   {{0x81c980ab,0x451989b5,0xa01b0061,0x6d4a9de6}},	//   লেট_, пция_, gköz, ftfa,
   {{0xf8bf1de7,0x44249de8,0xddde0035,0x645b9de9}},	//   kné_, fam_, _zapł, teui,
   {{0x38691dea,0x78a28775,0x6ac79516,0xf8bf027f}},	//   _naar_, chov, रक्र, jné_,
   {{0xf8bf0a56,0x610180eb,0x254e8085,0xaca40870}},	//   dné_, _vēlm, _həll_, _saịt,
   {{0x443f831d,0x961e001b,0x236d806a,0xf1bf81d6}},	//   sgu_, _बजेट_, rvej_, ášok_,
   {{0xe9d98098,0xae748065,0x236d806a,0xf99181a8}},	//   яко_, _جھنڈ, svej_, ابخ_,
   {{0x6e21811e,0x3ce681c0,0xf8bf00e7,0x7cc180eb}},	//   _helb, _ghov_, gné_, mēro,
   {{0x386901d8,0x442f9deb,0x9f4c080a,0x7c2400eb}},	//   _daar_, _idg_, _ölüm_, vair,
   {{0x78a2826f,0x2cbf8074,0xade406ae,0x7ce58144}},	//   zhov, lnud_, _गरदन_, sórd,
   {{0x7c241dec,0x69d88a8e,0xf8bf1ded,0xc692810f}},	//   tair, _gyve, bné_, נאל_,
   {{0x386902a3,0xf8bf026f,0x23ce800d,0x765c1dee}},	//   _gaar_, cné_, _हुँद, sery,
   {{0x7c241def,0x765c1df0,0xfa3607c3,0x26d11df1}},	// [fa0] rair, pery, فراد, bozo_,
   {{0x7c241df2,0x2be29344,0x0566046a,0x4a431df3}},	//   sair, _परसा, _звон, лнув,
   {{0x44249df4,0x442f979d,0x6f009df5,0xf29683de}},	//   yam_, _odg_, _sumc, עכער_,
   {{0xafdb0bc5,0x76900009,0x38a201ac,0x44249df6}},	//   mfør, _täys, _fóre_, xam_,
   {{0xa01b0019,0x2cbf8074,0x78a29df7,0x76450114}},	//   tköz, dnud_, rhov, _ychy,
   {{0x7d0182a3,0xf8bf03fb,0x44221df8,0x60c401a1}},	//   _buls, zné_, _hek_, _ljim,
   {{0xb7bd802e,0xa0a680e8,0x78a2816d,0x6e218bbd}},	//   _reţe, _завд, phov, _delb,
   {{0x6d4a8e23,0x3ce6946a,0x442f85db,0xb4ca858c}},	//   rtfa, _qhov_, _cdg_, लके_,
   {{0xf8bf0ed7,0x64408006,0xe7378785,0x628e1df9}},	//   vné_, rgmi, _пет_, _kobo,
   {{0xc3331dfa,0x44248304,0x628e1dfb,0x6e219dfc}},	//   נות_, sam_, _jobo, _gelb,
   {{0xf8bf0a56,0x386914f9,0x7afd826f,0x3ce681e9}},	//   tné_, _paar_, ístr, _thov_,
   {{0x26f909a3,0x44221dfd,0xdd8f817e,0x386902a3}},	//   ंद्र_, _nek_, _دوم_, _qaar_,
   {{0xf8bf1dfe,0x6108801b,0x7af89dff,0x60c41e00}},	//   rné_, _děla, _tivt, _djim,
   {{0x386901d8,0xf8bf003e,0x7c2280f7,0x65650267}},	//   _waar_, sné_, _heor, _pshh,
   {{0xf8bf003e,0xf1d00128,0x7c22808e,0xafdb1e01}},	//   pné_, _तुलन, _keor, gfør,
   {{0x11db8051,0x44221e02,0x629a9e03,0x7c22808e}},	//   _מחוב, _cek_, lkto, _jeor,
   {{0x628e1e04,0x213e9a34,0x2a7c890d,0x7c2f92ca}},	// [fb0] _bobo, luth_, _knvb_, ócri,
   {{0xd0198935,0x44221e05,0x629a9e06,0x628e1e07}},	//   दर्भ_, _eek_, nkto, _cobo,
   {{0x628e1e08,0x649c8036,0xb8128264,0x2bd1052a}},	//   _dobo, _réin, _হয়ত_, _थुरा,
   {{0x6e218352,0xb4ca83bb,0x7cc180eb,0x89341e09}},	//   _selb, लको_, vēro, اعلا,
   {{0x6e219cdf,0x7d019e0a,0x4f0890ac,0x36699e0b}},	//   _pelb, _suls, енін_, дало_,
   {{0x628e02c1,0xed599016,0x44221e0c,0x442f9e0d}},	//   _gobo, док_, _zek_, _sdg_,
   {{0x6abf0770,0x2cbf8074,0xa158054c,0x6e219e0e}},	//   ्वीर, tnud_, _пару_, _velb,
   {{0x24891e0f,0x628e1e10,0x629a9e11,0x6e219e12}},	//   njam_, _zobo, ekto, _welb,
   {{0x6e219e13,0x7c229e14,0x2ef59e15,0xd0498326}},	//   _telb, _deor, _азар, _sheɗ,
   {{0x3da79e16,0x29030010,0xb87b01d0,0x60d60338}},	//   _преб, _kuja_, hlíd, _skym,
   {{0x10a600e8,0x98a61e17,0x7c228706,0x290313de}},	//   винн, вине, _feor, _juja_,
   {{0x92c380c8,0x61fa1e18,0x2efa026c,0x7c229e19}},	//   ্ষে_, _útle, _sipf_, _geor,
   {{0xeb8e964f,0x672d026c,0xc62600ab,0xda658088}},	//   _ти_, _cvaj, _বাবা_, _авли,
   {{0x76438393,0x44221e1a,0xa7fb04c3,0x66e61e1b}},	//   ngny, _sek_, xeñe, тога,
   {{0xceb29a15,0x2a6a1e1c,0x44220214,0x27ff90ab}},	//   בים_, _rabb_, _pek_, _ogun_,
   {{0xafdb0257,0x7c2283a8,0x6fb601a8,0x3958018e}},	//   rfør, _xeor, _لمعا, _rprs_,
   {{0x63a99e1d,0xb87b1e1e,0xe8d71e1f,0x44221e20}},	// [fc0] nzen, rmít, _בוקר_, _vek_,
   {{0x68e99e21,0x63a981ed,0xafdb004a,0x27ff810c}},	//   _ahed, izen, pfør, _agun_,
   {{0x44221e22,0x68e98362,0x29030187,0x68fb8084}},	//   _tek_, _bhed, _cuja_, _biud,
   {{0x68fb9e23,0x7794803d,0xb87b03a8,0x649c81a8}},	//   _ciud, هیزا, lmír, _céil,
   {{0xdfd280f7,0x63a981ed,0x649c81a8,0x2d980061}},	//   جيش_, jzen, _déil, lyre_,
   {{0x63a99e24,0x7c2294ff,0x27ff80ad,0x6e9481a8}},	//   dzen, _seor, _egun_, طلبا,
   {{0xd9e605b3,0x68469e25,0x649c80f7,0x7c229e26}},	//   _करित_, _инва, _féil, _peor,
   {{0x61e307d9,0x68fb8098,0x68e98c9f,0x7afc1e27}},	//   ünle, _giud, _ghed, _hirt,
   {{0x69dc016d,0x69ca8fd5,0x7afc1e28,0x3dd28035}},	//   _hyre, _सुजी, _kirt, ływ_,
   {{0xbbe283eb,0x7afc02a3,0x60c29e29,0x5be29008}},	//   _परीक, _jirt, lnom, _परीव,
   {{0xe6be1513,0x672d0110,0x5d869e2a,0x2d9803ed}},	//   ोवैज, _svaj, _جلال, jyre_,
   {{0x6f0400f7,0x60c29e2b,0x213e9e2c,0x6d5a8214}},	//   _buic, nnom, ruth_, _ipta,
   {{0x63a98d38,0x7afc0c41,0xb4be9a22,0x59b2801b}},	//   czen, _oirt, ँची_, ुपहर,
   {{0x6f041e2d,0x7ce59e2e,0x71749abb,0x3f8682df}},	//   _duic, móra, _مهتا, ixou_,
   {{0xddda801b,0x5c071e2f,0x69dc006f,0xb5fc81b9}},	//   _patř, вяза, _nyre, _baġi,
   {{0x7afc0013,0x3eb80083,0x672d80eb,0x2fc901c0}},	//   _airt, airt_, šaji, _txag_,
   {{0x649c80f7,0x24891e30,0xb87b1e31,0x56951246}},	// [fd0] _réil, rjam_, smís, _бапт,
   {{0x22470065,0x6d5a9e32,0x68e99e33,0x29031e34}},	//   ünk_, _opta, _shed, _puja_,
   {{0xa3e70076,0xa2ba0f21,0x2d8c03ba,0xddc89e35}},	//   येज_, ्वज्, ødet_, _andž,
   {{0x69dc1e36,0xf8d180c8,0x60c29e37,0x7afc1e38}},	//   _dyre, িষ্ঠ, gnom, _eirt,
   {{0x44291e39,0xc43a0051,0x6d5a8df1,0x68fb9e3a}},	//   maa_, _אתרי, _apta, _viud,
   {{0xf7708c2a,0x44291e3b,0x64958013,0x4aa71e3c}},	//   غان_, laa_, _láit, _गतिव,
   {{0x68e99e3d,0x20d91e3e,0x200981df,0xb87b0187}},	//   _thed, néis_, ñais_, ilíb,
   {{0x44291e3f,0x63a99e40,0x2005009a,0x7d051e41}},	//   naa_, tzen, ślij_, _muhs,
   {{0xddc183bb,0x7b758199,0xaca38133,0xe8949e42}},	//   _dalš, اطبا, _ntụl, _тать,
   {{0x63a99e43,0x44291e3f,0x45459e44,0xd90c8065}},	//   rzen, haa_, _منطق, ڈیو_,
   {{0x44291e45,0x63a99e46,0x26c30353,0xaca38135}},	//   kaa_, szen, dnjo_, _atụl,
   {{0xe73a1e47,0x44291e48,0x20d91e49,0x3da49e4a}},	//   нем_, jaa_, déis_, _труб,
   {{0x442902a3,0xb8cc1e4b,0x7c299e4c,0x6f040039}},	//   daa_, _गत_, maer, _quic,
   {{0x2d9800f1,0x25ef035a,0x66e3816f,0x386d867f}},	//   tyre_, _आणखी_, गतिक_, _laer_,
   {{0x09be00c8,0xada307b6,0x44291e4d,0x6da31e4e}},	//   _অর্থ, барл, faa_, бира,
   {{0x38a21e4f,0x442902a3,0x7afc1e50,0xb87b1e51}},	//   _fóra_, gaa_, _sirt, smír,
   {{0x2d9e15d8,0x09be1664,0x38a2009a,0x7afc1e52}},	// [fe0] šte_, ्थ्य, _góra_, _pirt,
   {{0x7c298114,0x649c80f7,0x0e661e53,0x20d91e54}},	//   haer, _réim, _скон, béis_,
   {{0x386d8358,0x44291e55,0x20d90e1b,0x7c298102}},	//   _baer_, baa_, céis_, kaer,
   {{0x7afc1e56,0x386d9e57,0x00da8eca,0x4fa69e58}},	//   _wirt, _caer_, ربات_, лиев,
   {{0xbbe2801b,0x386d9e59,0x7c299e5a,0x7afc1e5b}},	//   _परेक, _daer_, daer, _tirt,
   {{0x7afc01a8,0x20d901a8,0x3fcb9e5c,0x78a40580}},	//   _uirt, néir_, ردنی_, _lliv,
   {{0xf9879e5d,0x2aa40065,0x64958013,0x7c2606cb}},	//   _اب_, _több_, _náis, _kekr,
   {{0xa01b1e5e,0x386d8286,0x7c299e5f,0xb4de8072}},	//   ljöv, _gaer_, gaer, णते_,
   {{0x40938064,0x649580f7,0x7c261e60,0x26da01bc}},	//   _القر, _ráit, _mekr, _okpo_,
   {{0x415498a2,0x78a41e61,0x59b8102e,0x629e1e62}},	//   авос, _aliv, _आधार, nkpo,
   {{0x78a41e63,0x442902c1,0x7c2982c4,0x6e250214}},	//   _bliv, yaa_, baer, _rehb,
   {{0x44290962,0x7c26003a,0x26da0133,0xe3bf0511}},	//   xaa_, _nekr, _akpo_, _leña_,
   {{0x44291e64,0xe29a81e2,0xe0df00e5,0x91fc81a9}},	//   vaa_, _пад_, rlò_, edāt,
   {{0x44291e65,0x20d91e66,0x386d1e67,0x442680ff}},	//   waa_, téis_, žer_, _heo_,
   {{0x44291e68,0x44269e69,0x78a40609,0x254e811c}},	//   taa_, _keo_, _fliv, _bəli_,
   {{0x442682a5,0x649580f7,0x26da01bc,0x20d91e6a}},	//   _jeo_, _háir, _ekpo_, réis_,
   {{0x44291e6b,0x7c261e6c,0x20d91e6d,0xbbe281a2}},	// [ff0] raa_, _dekr, séis_, _परोक,
   {{0x44291e6e,0x44269e6f,0x27e900ad,0x7ce58125}},	//   saa_, _leo_, _izan_, jórn,
   {{0x44291e70,0x68ed1e71,0x649581a8,0x64ac0162}},	//   paa_, _khad, _máir, rşir,
   {{0x44268046,0x7c2600c9,0x04671e72,0xb4c0800d}},	//   _neo_, _gekr, _стом, ूको_,
   {{0xd366896c,0xddd70201,0x68ed1e73,0x2ca900f7}},	//   _به_, _yaxş, _mhad, mhad_,
   {{0x1eea80d5,0xca49003d,0x63ad036a,0x9a870a4c}},	//   نونی_, _جلسه_, mzan, _сумл,
   {{0x44269e74,0x63ad1e75,0x1ddb00d4,0x41e4102a}},	//   _beo_, lzan, _मुमत, _гіта,
   {{0x61fa01fa,0x68ed1e76,0x27e91e77,0x44269e78}},	//   _útla, _nhad, _ozan_, _ceo_,
   {{0x63ad1e79,0x44269e7a,0xbf159e7b,0x7c2982ec}},	//   nzan, _deo_, _ضواب, raer,
   {{0xdfd88698,0x60c98a38,0xa7fb01df,0x68ed004f}},	//   _със_, _hjem, xeña, _ahad,
   {{0x008609a0,0x78a40a20,0x27e91e7c,0x442681ca}},	//   ално, _pliv, _azan_, _feo_,
   {{0x7e639e7d,0x672d8042,0xac199e7e,0x44269e7f}},	//   lenp, šaju, _роду_, _geo_,
   {{0x6d439e80,0x81bd80c8,0x63ad0669,0x249f81e0}},	//   luna, _আরও_, jzan, mkum_,
   {{0xe2969e81,0x63ad198a,0xbb3a8039,0x8f9a83de}},	//   _ваш_, dzan, _יעני, דישי,
   {{0x6d439e82,0x60db9e83,0x68ed008c,0x20d900f7}},	//   nuna, _okum, _fhad, réir_,
   {{0x60c99351,0xa7fb040e,0x68ed1e84,0x44269e85}},	//   _njem, seña, _ghad, _xeo_,

   {{0xd4670572,0x3b071927,0x6d439341,0xe3bf1e86}},	// [1000] шите_, ието_, huna, _peña_,
   {{0x29079e87,0x3ce01e88,0x60c9846d,0x248d83ba}},	//   _kuna_, sliv_, _ajem, hjem_,
   {{0x6d439e89,0x29079e8a,0x249f808b,0x64599e8b}},	//   juna, _juna_, kkum_, _obwi,
   {{0x3ea59e8c,0x29079e8d,0x26d81e8e,0x315680be}},	//   _allt_, _muna_, loro_, ייען_,
   {{0x29079e8f,0xe3bf04c3,0x63ad009a,0x60c98168}},	//   _luna_, _teña_, czan, _djem,
   {{0x44269e90,0x8d768416,0x60c985b4,0x64599e91}},	//   _seo_, لاعا, _ejem, _abwi,
   {{0x6d439e92,0x290783c3,0x7d78803d,0x6e2a9e93}},	//   guna, _nuna_, امبر_, rafb,
   {{0x26d81e94,0xd7668065,0x60c99e95,0x2ca01e96}},	//   horo_, _پارٹ, _gjem, nkid_,
   {{0x44269e97,0x64958013,0x29079e98,0xb5fc81b9}},	//   _veo_, _páir, _auna_, _raġu,
   {{0x29079e99,0x781f0e00,0x6d5e1e9a,0x3a278118}},	//   _buna_, पर्क_, _oppa, _cenp_,
   {{0x26d81e9b,0x44269e9c,0x63ad1e9d,0x27e004b9}},	//   doro_, _teo_, zzan, _ayin_,
   {{0xd83f83c1,0x7ae19e9e,0x644b8122,0x6b9b9e9f}},	//   _účtu_, allt, _gcgi, byug,
   {{0x6d5e1ea0,0x64958013,0x61050110,0x27e0008e}},	//   _appa, _táir, _vėli, _cyin_,
   {{0x26d81ea1,0x7d089ea2,0xd0650085,0x291a008e}},	//   goro_, _kuds, _əsər, kppa_,
   {{0x29078057,0x6e289ea3,0x68ed1ea4,0x3cf3016f}},	//   _guna_, _medb, _thad, ंगले_,
   {{0x1b1980c8,0x63ad1ea5,0x7d089b7d,0x7cc180eb}},	//   _দিতে_, tzan, _muds, tēri,
   {{0x26d81ea6,0x6d439ea7,0x2ca91ea8,0x78bd1ea9}},	// [1010] boro_, zuna, rhad_, misv,
   {{0x26d81eaa,0x60c995db,0x29079eab,0x6d4397e2}},	//   coro_, _sjem, _yuna_, yuna,
   {{0xceb20159,0x2f0b8022,0x83fd8019,0x249f9eac}},	//   _זיי_, _søg_, ndőr, ykum_,
   {{0x6d438365,0x78bd1ead,0x68e29eae,0xa49b07f1}},	//   vuna, nisv, glod, _diòc,
   {{0x95e90065,0x7c2d1eaf,0x7e639eb0,0x7ae19eb1}},	//   _جبکہ_, maar, tenp, yllt,
   {{0x7c2d1eb2,0x6d439eb3,0x7d089eb4,0x22950174}},	//   laar, tuna, _buds, _الآس,
   {{0x365c0039,0x2ca681a3,0x60c9942f,0x248d807a}},	//   דכונ, _blod_, _tjem, tjem_,
   {{0x58d49eb5,0x7c2d1eb6,0x60db9eb7,0x26d801bc}},	//   _дост, naar, _ukum, zoro_,
   {{0x290783c3,0x6d439eb8,0xf77384c0,0x248d9eb9}},	//   _suna_, suna, _باز_, rjem_,
   {{0x6d439eba,0x249f9ebb,0x7c2d1ebc,0x29000074}},	//   puna, skum_, haar, _siia_,
   {{0xf769004c,0x26d80698,0x6f0986a5,0x6f161ebd}},	//   _רק_, voro_, _huec, _styc,
   {{0x26d81ebe,0x7c2d1ebf,0x645982a0,0x290780fe}},	//   woro_, jaar, _ubwi, _vuna_,
   {{0x442d9ec0,0x6f0981ca,0x7c2d1ec1,0x290002f1}},	//   mae_, _juec, daar, _viia_,
   {{0x442d9ec2,0x64499ec3,0x6f098144,0xc7d6807c}},	//   lae_, lgei, _muec, מורי_,
   {{0x26d81ec4,0x776d03a8,0xf1cf8651,0x62839ec5}},	//   roro_, _esax, _सुचन, _inno,
   {{0x7c2d1ec6,0x26d81ec7,0x64499ec8,0xdd8f1ec9}},	//   gaar, soro_, ngei, روق_,
   {{0x09b500c8,0x2ca000ee,0x442d8118,0xbebb00f1}},	// [1020] _জুলা, rkid_, iae_, rsër,
   {{0x442d9eca,0xe3a78065,0x2ca01ecb,0xe7db8327}},	//   hae_, _ہر_, skid_, _बड़प,
   {{0x7c2d1ecc,0x9e7b00be,0xed4594a0,0x04ca00f7}},	//   baar, _ענטפ, _تھ_, _مودي_,
   {{0x6c861ecd,0x6e2e1ece,0x777b9ecf,0x7c2d0079}},	//   _الحم, labb, _brux, caar,
   {{0x44201ed0,0x3ebc8bfa,0x7d08803a,0x442d9ed1}},	//   mbi_, tivt_, _suds, dae_,
   {{0xcd2909d7,0x6e2e1ed2,0x6f099ed3,0x62951ed4}},	//   _حسین_, nabb, _duec, _gozo,
   {{0x7d088359,0x61431ed5,0x649581a8,0x2b401ed6}},	//   _quds, _нера, _páip, lric_,
   {{0x62839ed7,0x5b148d91,0x6e2e1ed8,0x44201ed9}},	//   _anno, омит, habb, nbi_,
   {{0xdc9b0158,0x213e831d,0x78a2816b,0x657a8114}},	//   טיקל, wrth_, mkov, _wrth,
   {{0x290a1eda,0x78a29edb,0xd91a9edc,0x6e2e1edd}},	//   _kuba_, lkov, льм_, jabb,
   {{0xd48f9ede,0x7c2d02a3,0x290a1edf,0x442d82b8}},	//   _ер_, yaar, _juba_, bae_,
   {{0x442000fe,0x7d1c016b,0x62838c2e,0x2ca68122}},	//   jbi_, dprs, _enno, _ulod_,
   {{0x7c2d1ee0,0x44200805,0x2bd811bc,0xa7fb165f}},	//   vaar, dbi_, _भुला, reño,
   {{0x442d1234,0x29181ee1,0x7c2d02b5,0xae1405fc}},	//   _že_, _otra_, waar, तुलन_,
   {{0x3abb804c,0x7c2d1ee2,0x8af00201,0x6ca702eb}},	//   _תמונ, taar, ktəb, браж,
   {{0x44201ee3,0x94191d20,0xfbe98326,0xd4981ee4}},	//   gbi_, ржат_, _øªù_, бру_,
   {{0x7c2d1ee5,0x61150201,0x78a2826f,0x6e2e1ee6}},	// [1030] raar, _işlə, dkov, babb,
   {{0x7c2d1ee7,0x7d028068,0xf8bf0036,0xff5001a8}},	//   saar, _lios, lié_, _أخي_,
   {{0x290a1083,0xe3bf04c3,0x6f099ee8,0x44201ee9}},	//   _cuba_, _teño_, _suec, bbi_,
   {{0x290a00a4,0x6d471eea,0xec6b0a0e,0xfc3f128a}},	//   _duba_, muja, _срок_, _zlín_,
   {{0x7c208713,0x6d4704be,0x6d5500ad,0x44391eeb}},	//   dbmr, luja, ltza, _ids_,
   {{0x442d9eec,0x442b1eed,0x29071571,0x44391eee}},	//   wae_, _hec_, ínas_, _hds_,
   {{0x6d5500ad,0x442b0101,0x290a1eef,0x6d47007a}},	//   ntza, _kec_, _guba_, nuja,
   {{0x6e2e1ef0,0xdfd58790,0x78a29ef1,0x6d550102}},	//   zabb, _добы, ckov, itza,
   {{0x442d9ef2,0x290a1ef3,0x7d029ef4,0x442b1ef5}},	//   rae_, _zuba_, _dios, _mec_,
   {{0xadf9000f,0x442b01a9,0x6d471ef6,0x27ed8102}},	//   ंधान_, _lec_, kuja, _izen_,
   {{0xf8bf02be,0xa88a1ef7,0x44391ef8,0x7d028046}},	//   fié_, айна_, _ods_, _fios,
   {{0x25d6893f,0x44391ef9,0x442b1efa,0x6d4701ac}},	//   _ווען_, _nds_, _nec_, duja,
   {{0x2cad813c,0x78a99efb,0x6e2e1efc,0x60cd1efd}},	//   mhed_, _mlev, tabb, _djam,
   {{0x78a99efe,0x05db0105,0x78a2826f,0x9c130135}},	//   _llev, _मुहब, zkov, _kọwa,
   {{0x6e2e1eff,0x78a983ff,0xde03035f,0xfc3f0118}},	//   rabb, _olev, дпри, _clío_,
   {{0x03260698,0x44201f00,0x2cad806a,0x290a1f01}},	//   ждан, ubi_, nhed_, _ruba_,
   {{0x78a29f02,0x290a1f03,0x7c2b9f04,0x3eba09ca}},	// [1040] vkov, _suba_, _megr, _tmpt_,
   {{0x44201f05,0x645d0609,0x644f047f,0xa01b0106}},	//   sbi_, _ebsi, _ecci, ljöp,
   {{0x78a294f0,0x78a98022,0x38669f06,0x2d780289}},	//   tkov, _blev, teor_, _uče_,
   {{0xddc89f07,0x290a00b4,0x7a400091,0x803703de}},	//   _nadš, _vuba_, _bátà, ַנצע_,
   {{0x78a294f0,0xf8b30051,0x7d0281a8,0x61e38366}},	//   rkov, ושא_, _rios, _lynl,
   {{0x7d029f08,0x290a1f09,0x877b010f,0x7b091f0a}},	//   _sios, _tuba_, יאני, _džud,
   {{0x7c2b9f0b,0x78a285b7,0x27ed9f0c,0x98a69f0d}},	//   _begr, pkov, _ezen_, _диве,
   {{0x61ee012b,0x442b1f0e,0x2cad9f0f,0x78a987f1}},	//   _izbl, _xec_, ghed_, _glev,
   {{0x7cc18029,0xccf302f6,0x320d080a,0xf8bf1f10}},	//   vērt, וכה_, _şeyi_, vié_,
   {{0x23620748,0x7d029f11,0x290483e4,0x60cd1f12}},	//   _mpkj_, _wios, _hima_, _sjam,
   {{0x61e38355,0xc27b010f,0x29049f13,0x291880f1}},	//   _cynl, בריי, _kima_, ëra_,
   {{0x7c2b96a1,0xb87b00f7,0x29049f14,0xbb8695a9}},	//   _gegr, rlío, _jima_, _ولاي,
   {{0x24869f15,0x29189482,0x29049dc1,0x81d600ab}},	//   _inom_, ūra_, _mima_, াইট_,
   {{0x26dc8289,0x6d471f16,0x442b1f17,0x6f1d0bfd}},	//   novo_, tuja, _sec_, rpsc,
   {{0xdcbb1f18,0x442b1f19,0xf8bf1f1a,0x61e38114}},	//   аща_, _pec_, pié_, _gynl,
   {{0x29048353,0x62988efc,0x5b151f1b,0x6d55011e}},	//   _nima_, _hovo, змат, rtza,
   {{0x442b0c79,0x62989c3f,0x2486805c,0x63a09f1c}},	// [1050] _vec_, _kovo, _mnom_, nymn,
   {{0x78a9800d,0x2904826b,0x291e808e,0x78bb8088}},	//   _slev, _aima_, opta_, _smuv,
   {{0x24868052,0x29049f1d,0x89d900f7,0x26dc9f1e}},	//   _onom_, _bima_, حوار_, dovo_,
   {{0xf7718307,0x29049092,0x44391f1f,0x644f0081}},	//   فات_, _cima_, _uds_, _ucci,
   {{0x8e859f20,0x7c2205e4,0xddc883f2,0x7c2b9f21}},	//   згле, ñore, _radš, _regr,
   {{0xa1370077,0x7ce59f22,0xd6db9f23,0x31351715}},	//   _ورزش, móri, ште_, _негр,
   {{0x62871f24,0x6f0d008c,0x78a9826c,0x2cad9f25}},	//   _injo, _luac, _tlev, thed_,
   {{0x644d1f26,0x7cc180eb,0x78bb80b4,0x29049f27}},	//   ngai, vērs, _umuv, _gima_,
   {{0x6f0d0013,0x2cad813c,0x649c80f7,0x61e38370}},	//   _nuac, rhed_, _réit, _synl,
   {{0xd2a98009,0x2cad8051,0x649c9f28,0x62989f29}},	//   ское_, shed_, _béis, _covo,
   {{0x62989f2a,0xa9699f2b,0x21699f2c,0x2b490144}},	//   _dovo, щина_, щини_, huac_,
   {{0x2009002a,0x6f0d0834,0x92cb80ab,0x67299f2d}},	//   _cgai_, _buac, লতে_, _kwej,
   {{0x61fe803e,0x291e8087,0x7ea200e7,0x2d8512f1}},	//   _úpln, apta_, _hôpi, ålen_,
   {{0x6d439f2e,0x6f0d03ac,0xe3b0826a,0x59bd047d}},	//   orna, _duac, _جرم_, ्पार,
   {{0xb7bd8087,0xf3f98087,0xa5d606a7,0x10a61f2f}},	//   _deţi, deţi_, _मुखौ, _никн,
   {{0x649c80f7,0x62871f30,0x6ab406a7,0x5f761f31}},	//   _héir, _anjo, ंफ्र, _فاخر,
   {{0x7ce59f32,0x6b6309c7,0x7cd38162,0x69c3002a}},	// [1060] góri, нкта, căre, únen,
   {{0x6d410013,0x644d008c,0xe2970162,0x6d438bcf}},	//   álac, agai, пау_, krna,
   {{0xfe9b00be,0x386001b9,0xd24f1f33,0x80669f34}},	//   _היימ, _kbir_, انم_, звеж,
   {{0x649c8013,0x62871f35,0xe7f3001b,0x2f10823e}},	//   _léir, _enjo, _घरमा_, _pàg_,
   {{0x44321f36,0x7c241f37,0x66e69f38,0x6d439f39}},	//   may_, mbir, пода, erna,
   {{0x7f429f3a,0x44321f3b,0x332001e0,0xb603816b}},	//   rroq, lay_, mpix_, _otáč,
   {{0x29048503,0x6298817f,0xacf881e2,0x490b801b}},	//   _tima_, _rovo, онку_, _ठूलो_,
   {{0x44321f3c,0x26dc825b,0x7c241f3d,0x649c9997}},	//   nay_, sovo_, nbir, _réis,
   {{0x62989f3e,0x7d061f3f,0x33200e23,0x6d438427}},	//   _povo, _miks, npix_, arna,
   {{0x44321f40,0x2cfa05fc,0x7d061f41,0x60c29f42}},	//   hay_, ्दुल_, _liks, liom,
   {{0x05db0576,0xcc128133,0x80b083eb,0xb7bd8087}},	//   _मुंब, _bọtị, ंसपे, _reţi,
   {{0x48ab1f43,0x7d061f44,0x24868bb1,0x75d381a8}},	//   стом_, _niks, _unom_, _ثيما,
   {{0x7c241f45,0x44321f46,0x6298807a,0x765c0428}},	//   dbir, day_, _tovo, ffry,
   {{0xd24f80a0,0x7c241f47,0x9c13019d,0x291e9f48}},	//   _منه_, ebir, _lọta, ppta_,
   {{0x443201b4,0xda5b8496,0x6d4a9f49,0xc9869f4a}},	//   fay_, _הכול, nufa, _хули,
   {{0x44321f4b,0x7ce580a9,0xb4d7023c,0x7c241f4c}},	//   gay_, tóri, ाके_, gbir,
   {{0x2d8c1f4d,0x7d061f4e,0xf3f9802e,0xddde011c}},	// [1070] äder_, _diks, teţi_, _tapş,
   {{0x78ad0a56,0x290e9f4f,0x6d4a9f50,0x644d1f51}},	//   _hlav, _kufa_, kufa, sgai,
   {{0x44321f52,0x7c241f53,0xa9071f54,0x7ce58187}},	//   bay_, bbir, سبان, sóri,
   {{0x443202c1,0x26c31f55,0xd138102a,0x6d4a9f56}},	//   cay_, lijo_, яху_, dufa,
   {{0x3b640021,0x7eaf80e8,0x9c1301bc,0xb4e90ec5}},	//   _първ, _løpe, _dọta, यती_,
   {{0x78ad1f57,0x6d4382a5,0x26c30353,0x628704b7}},	//   _llav, trna, nijo_, _unjo,
   {{0x60c29f58,0x672480eb,0x2d571f59,0x290e89ab}},	//   biom, ģija, nçe_, _nufa_,
   {{0xc9520039,0x60c28706,0xdb009a25,0x6729838a}},	//   _שמן_, ciom, lymè, _twej,
   {{0x1ee7819f,0x2d570214,0x81df00ab,0x8f55803d}},	//   _فوری_, hçe_, দেশ_, _زناش,
   {{0x44321f5a,0xb4e91f5b,0x2d5702d0,0x26c31f5c}},	//   zay_, यतु_, kçe_, jijo_,
   {{0x81df150b,0x443202c1,0x26c31f5d,0x78ad1f5e}},	//   দের_, yay_, dijo_, _blav,
   {{0xcea91a6a,0x443202c1,0xb4d703bb,0x78ad0018}},	//   _די_, xay_, ाको_, _clav,
   {{0x610c07d9,0x44320205,0x7d061f5f,0x26c3007a}},	//   _işle, vay_, _riks, fijo_,
   {{0x44321f60,0x60c2809a,0x78ad1f61,0x7d061f62}},	//   way_, ziom, _elav, _siks,
   {{0x44321f63,0x998583f8,0xfce61f64,0x7d060077}},	//   tay_, _آلبو, дово, _piks,
   {{0x442f9f65,0x1ad580ab,0x3ce91f66,0x61fa008b}},	//   _jeg_, _হওয়া, glav_, _útli,
   {{0x442f9f67,0xa8570051,0x7c241f68,0x44321f69}},	// [1080] _meg_, _חיפה_, rbir, ray_,
   {{0x44321f6a,0x26c30db7,0x7c241503,0x7d060242}},	//   say_, cijo_, sbir, _wiks,
   {{0x44321f6b,0xa96a045b,0x7d061f6c,0xd91000d7}},	//   pay_, تمام_, _tiks, ایر_,
   {{0x442f86c0,0x44320079,0x53ad83eb,0x7c2f1f6d}},	//   _neg_, qay_, टनाश, _gecr,
   {{0x3eac82c4,0x69d51f6e,0x7ae8805f,0x7ae385ee}},	//   _pldt_, _exze, yldt, _oknt,
   {{0xd25212dc,0x442f8006,0x6d589f6f,0x60c29f70}},	//   _جنس_, _aeg_, ttva, siom,
   {{0x442f9f71,0xafdb0edd,0x20569a21,0x443d8609}},	//   _beg_, ngør, _отар, _bdw_,
   {{0x63a402a3,0x442f8069,0x290e9f72,0x26c3007a}},	//   oyin, _ceg_, _rufa_, zijo_,
   {{0x63a41f73,0x442f9f74,0x629c1f75,0x9c13019d}},	//   nyin, _deg_, _koro, _kọra,
   {{0x68e41f76,0x629c1f77,0x395801c0,0x3b0780e7}},	//   _akid, _joro, _kqrs_, _cinq_,
   {{0x67228029,0x6da6845a,0x629c1f78,0x26c30353}},	//   lpoj, _تمام, _moro, vijo_,
   {{0x629c0397,0xa9c380e8,0x3f861f79,0x3cfa0035}},	//   _loro, тськ, _šoua_, ्दों_,
   {{0xceeb1c2c,0x26c3007a,0xe81e0035,0x7c2f1f7a}},	//   قرآن_, tijo_, पड़ा_, _recr,
   {{0x629c1f7b,0x442f80f3,0xb4d709c1,0x290e9f7c}},	//   _noro, _zeg_, ाक्_, _tufa_,
   {{0xd49b1f7d,0x26c30353,0x6f08951e,0x26ce9f7e}},	//   ора_, rijo_, _midc, info_,
   {{0xb4e91885,0x6b829f7f,0x9f5500e8,0x26c3007a}},	//   यते_, _krog, _звич, sijo_,
   {{0x629c1f80,0x7ce580f7,0x7c220511,0x26c3007a}},	// [1090] _boro, mórt, ñora, pijo_,
   {{0x27e91f81,0xddc38162,0x672d04be,0x68fd1f82}},	//   _iyan_, nenţ, _iwaj, lmsd,
   {{0x610c080a,0x629c1f83,0x7c2f0214,0x2a781f84}},	//   _oğlu, _doro, _tecr, _darb_,
   {{0x6b829f85,0x2cb2031d,0x27e900a4,0x38a21f86}},	//   _orog, chyd_, _kyan_, _fóru_,
   {{0x442f9f87,0x63b60063,0x629c1f88,0xb8d78105}},	//   _reg_, czyn, _foro, _छत_,
   {{0x442f8cde,0xd3560051,0x629c1f89,0x9c13019d}},	//   _seg_, _אישי_, _goro, _tọsa,
   {{0x26c981dd,0xddc3802e,0x201281a8,0x672d1f8a}},	//   đao_, denţ, íniú_, _lwaj,
   {{0x628a9f8b,0xf1b200be,0xeb999f8c,0x394c82c4}},	//   _anfo, _עסן_, зии_, duds_,
   {{0x27e9076d,0x68f60114,0x6b829f8d,0x442f9f8e}},	//   _nyan_, _rhyd, _crog, _veg_,
   {{0x442f9f8f,0xddc38087,0x291101d4,0x2ef49ac8}},	//   _weg_, genţ, _kuza_, _азур,
   {{0x442f9f90,0x6b829f91,0xa6db007b,0x2a6300b9}},	//   _teg_, _erog, nuðu, _mbjb_,
   {{0x6b829f92,0x2d98809f,0x8cc10327,0xb4e9103e}},	//   _frog, _àrea_, रोमो, यतो_,
   {{0xc00000c8,0x1b1980c8,0xd85001bc,0x7ba780f7}},	//   ূর্ণ_, _দিকে_, _fọnt_, _تصام,
   {{0x539a8451,0x2f1400f2,0x27e9020d,0xafdb0366}},	//   _מינו, _väg_, _dyan_, tgør,
   {{0x629c049c,0x98a781d0,0xcc128133,0x672d0032}},	//   _roro, éně_, _kọpị, _ewaj,
   {{0x68e40067,0x629c1f93,0x63a41f94,0xfce301a1}},	//   _ukid, _soro, tyin, госо,
   {{0xca860071,0x27e91f95,0x672d0041,0xd8d700be}},	// [10a0] нгай, _gyan_, _gwaj, _רופט_,
   {{0x63b6009a,0x29111f96,0xddc18609,0x996e811c}},	//   rzyn, _buza_, _balż, nəş_,
   {{0xc8798086,0xdca61612,0x065700be,0xc8669f97}},	//   _baş_, _зани, _אייך_, етли,
   {{0x60c60867,0x2ca9016d,0x7ae19f98,0x6d4e1f99}},	//   nikm, ckad_, holt, muba,
   {{0x7ae19f9a,0x629c1f9b,0x6d4e1f9c,0xb05b1f9d}},	//   kolt, _toro, luba, onär,
   {{0x26ce9f9e,0x7cd38087,0x7e7c0267,0x1fdf80ab}},	//   unfo_, văra, ndrp, _বৃহস,
   {{0x23668669,0x2911011f,0xddc38087,0x7ae19f9f}},	//   _spoj_, _guza_, venţ, dolt,
   {{0x91e31fa0,0x6d5c1fa1,0x67228198,0x39470118}},	//   _сосе, itra, ppoj, ánse_,
   {{0x290901e0,0x6d4e1fa2,0xddc38087,0x68e29fa3}},	//   _riaa_, huba, tenţ, mood,
   {{0x6d4e1fa4,0x8af00085,0x394c8722,0x3f99841c}},	//   kuba, xtəl, tuds_, _àsua_,
   {{0xe3af84c0,0x6d5c0503,0x0c2685e9,0xc87983bf}},	//   لری_, jtra, _змен, _yaş_,
   {{0xeb9a81f3,0x01370039,0xe61f8028,0x6d4e1fa5}},	//   _ние_, ערכת_, _đôi_, duba,
   {{0x7ae18ede,0xb4be9fa6,0x28c006b7,0xdefb0009}},	//   bolt, ुची_, शोधि, зыв_,
   {{0x7ae19fa7,0x68e28079,0x6d5c1fa8,0x38a200f7}},	//   colt, hood, ftra, _sórt_,
   {{0x6d5c1fa9,0x68e28ebc,0x45d41faa,0x6e350968}},	//   gtra, kood, горс, razb,
   {{0xdef804b7,0x8af00085,0x7e7a808e,0x29111fab}},	//   ċċa_, stəl, _latp, _ruza_,
   {{0x68e282a3,0x2911005c,0x6d5c1fac,0x2ca91fad}},	// [10b0] dood, _suza_, atra, rkad_,
   {{0x7e7a805c,0x644800eb,0x6d4e1fae,0x2ca91faf}},	//   _natp, _ēdie, buba, skad_,
   {{0x7c361fb0,0xc9841fb1,0x3f849fb2,0x6720810c}},	//   bayr, луци, _armu_, _atmj,
   {{0xc5f2078d,0x68e28079,0x90e780d7,0x7ae18061}},	//   _כדי_, good, رسان, zolt,
   {{0x44291fb3,0x4c9a04de,0xef18804a,0x643603de}},	//   mba_, _חברו, емі_, _בארא_,
   {{0x44291fb4,0x07a29d38,0x7bdc8457,0x8fa29fb5}},	//   lba_, рашн, ğrul, раше,
   {{0x691780eb,0x44291fb6,0xc87982d0,0x68e29fb7}},	//   _aģen, oba_, _taş_, bood,
   {{0xfebb8077,0x44291fb8,0x4c859631,0xc48581a1}},	//   _کارت_, nba_, тлив, тлик,
   {{0xe803000d,0x44291fb9,0xa3de8105,0x6d4e1fba}},	//   रेमा_, iba_, _दुआ_, zuba,
   {{0x6d4e1fbb,0x44291fbc,0x6d5c1fbd,0x2b4d87f1}},	//   yuba, hba_, ytra, ruec_,
   {{0x26c79fbe,0x61ea8355,0x60c61fbf,0x44290019}},	//   mino_, _cyfl, tikm, kba_,
   {{0x44291fc0,0x7ae19fc1,0xf4858065,0x6d5c1fc2}},	//   jba_, solt, _جائی, vtra,
   {{0x7fd610ac,0x2d858699,0x98bf1fc3,0x3f84001b}},	//   тіні, _hrle_, nutę_, ímu_,
   {{0xaa458002,0x6d5c1fc4,0x44291fc5,0x26c79fc6}},	//   _рекл, ttra, eba_, nino_,
   {{0xed571fc7,0x61ea831d,0x68e28079,0x7d0b8122}},	//   кор_, _gyfl, yood, _kigs,
   {{0x44291fc8,0x6d4e1fc9,0x7d0b9fca,0x26c79fcb}},	//   gba_, ruba, _jigs, hino_,
   {{0x26c79fcc,0x6d4e1fcd,0x7c299fce,0x387d8428}},	// [10c0] kino_, suba, iber, ddwr_,
   {{0xb2231bbf,0x44291fcf,0x68e29fd0,0x7c299fd1}},	//   имул, aba_, wood, hber,
   {{0x44291fd2,0xf8c617a3,0xa3de800d,0x644b1fd3}},	//   bba_, _लगाय, _दुई_, ógic,
   {{0x64a61fd4,0x7e7a9d31,0x44291fd5,0x251e0135}},	//   _рама, _satp, cba_, _ọnwụ_,
   {{0xdfcf8307,0x68e29fd6,0x7c299fd7,0xddc39fd8}},	//   ييم_, rood, dber, venš,
   {{0x26c79fd9,0x656880b9,0xb87b0061,0x3ce6806a}},	//   gino_, _ppdh, llít, _skov_,
   {{0xceb30051,0x3cde98b8,0x628e1fda,0x127b00be}},	//   שיו_, खवले_, _inbo, _קאלע,
   {{0x7c299fdb,0x98a38ae7,0x7d0b8267,0xb4be93e5}},	//   gber, _кисе, _cigs, ुचे_,
   {{0x26c79fdc,0x2d859fdd,0x6ef20366,0xaf068196}},	//   bino_, _erle_, væbn, _апал,
   {{0x26c79fde,0xc3330039,0x44291fdf,0x7c299fe0}},	//   cino_, סות_, zba_, aber,
   {{0x7c299fe1,0x44291fe2,0x2d85817f,0x40351fe3}},	//   bber, yba_, _grle_, ленс,
   {{0x30a71fe4,0x44290079,0x93469fe5,0x6abf03eb}},	//   тров, xba_, _анде, _एग्र,
   {{0x2d8c0e23,0x58d41194,0x44291fe6,0x64429fe7}},	//   åden_, роят, vba_, _idoi,
   {{0x41dd9094,0xddda8110,0x60c40c2e,0x442910ba}},	//   _नुकस, _natū, _emim, wba_,
   {{0x55581fe8,0x7b091fe9,0x26cd00ce,0xd3088129}},	//   каря_, _džul, đeo_, _dệt_,
   {{0x629a825b,0x628e1fea,0x44291feb,0xa7750012}},	//   ljto, _anbo, uba_, _блич,
   {{0x09bd06bf,0x1be30327,0x93f51fec,0x6d4a81ec}},	// [10d0] ्प्य, _कुशल_, упац, hrfa,
   {{0x44291fed,0xf1a71fee,0xdd03007e,0x6d481fef}},	//   sba_, крен, ırıc, ádac,
   {{0x26c79ff0,0xd011936d,0x81e480ab,0x7c299ff1}},	//   vino_, ملا_, পের_, yber,
   {{0x673b0fda,0xf1c30110,0x26c79ff2,0x7fd58196}},	//   šuju, _rašė_, wino_, лілі,
   {{0x78a089d1,0x3ea10074,0xb4c10701,0x7d0b8366}},	//   _domv, _koht_, ्ची_, _rigs,
   {{0x644284c3,0x7d0b8123,0x4df59ff3,0x7c299ff4}},	//   _adoi, _sigs, ляйт, wber,
   {{0x26c79ff5,0x7d0b9400,0x3ced9ff6,0xfc3f1b9c}},	//   rino_, _pigs, tlev_, _flít_,
   {{0x7eb487f1,0xf7738e06,0xb87b0174,0x0cd18264}},	//   _ràpe, _پار_, ilís, াত্ত,
   {{0x26c79ff7,0x68e9846d,0x81e800ab,0x13099ff8}},	//   pino_, _iked, মেদ_, нний_,
   {{0xd7f89ff9,0x3cff81c0,0x3ced9ffa,0x6b6701a9}},	//   _рус_, smuv_, slev_, mīgā,
   {{0x2455806b,0xb87b0c52,0x27fa809a,0xa0a61ae5}},	//   _مناس, roín, ępne_, ганд,
   {{0xc32400ab,0x5fc502f1,0xd308827d,0x00000000}},	//   _পিসি_, _लेहल, _sệt_, --,
   {{0x7ae5043d,0x4c9a8e82,0x2a7c87f1,0x27ed8176}},	//   koht, _רבנו, _favb_, _jyen_,
   {{0x1bb888ca,0x99858061,0x7ae50198,0x63bb9ffb}},	//   _جامع_, _ملتو, joht, mzun,
   {{0x27ed8205,0x270f80bc,0xc8798214,0x8af00085}},	//   _lyen_, ादुर_, _ekşi_, stək,
   {{0x7b090858,0x60c41ffc,0x27ed8144,0x2cad9ffd}},	//   _džum, _umim, _oyen_, nked_,
   {{0x63a99ffe,0x63bb9fff,0x2f1986c0,0x27ed8db1}},	// [10e0] nyen, nzun, _nèg_, _nyen_,
   {{0xfeba0077,0xb87b016b,0x290d8300,0x68e9a000}},	//   _ساخت_, slít, _aiea_, _aked,
   {{0xe5a61d27,0x35a60071,0x673b007a,0x6da61ad3}},	//   _сини, _санг, šujt, _сина,
   {{0x270f8076,0xd7faa001,0x25a51bb2,0x68fba002}},	//   ादूर_, нул_, älle_, _chud,
   {{0xe3b22003,0x7e7e2004,0xbea6854c,0x6e3884e8}},	//   _طرح_, _kapp, ладк, tavb,
   {{0x7e7e04b7,0xddc71f07,0xf12400d5,0x68e981bc}},	//   _japp, lejš, _نظری, _eked,
   {{0x7e7e2005,0x7b09173d,0xccf8801b,0x21752006}},	//   _mapp, _ožuj, _opět_, _кутр,
   {{0xddc72007,0x24802008,0x26ca2009,0x645600fc}},	//   nejš, ndim_, hibo_, ngyi,
   {{0xa3de85e8,0x63a9a00a,0x26ca200b,0x1bd4802e}},	//   _दुख_, gyen, kibo_, ропя,
   {{0x7e7e200c,0x5a34a00d,0x9e65853d,0xf126a00e}},	//   _napp, шнот, _نامن, льмо,
   {{0xddc88fda,0x67240091,0x23ba846d,0xd9178198}},	//   _hadž, _atij, _bàjé_, лья_,
   {{0x657a810c,0x7e7e200f,0x2cad8039,0x63a9a010}},	//   _isth, _aapp, cked_, byen,
   {{0xa3e401a2,0x0a94a011,0x7e7e02f7,0x248002a6}},	//   _पुल_, _валю, _bapp, ddim_,
   {{0x4b7b80be,0x7e7e2012,0xddc881c8,0x29022013}},	//   _נאוו, _capp, _madž, amka_,
   {{0x7e7e2014,0xccfb04ae,0x61ee0338,0x291c04e8}},	//   _dapp, ећа_, _nybl, íval_,
   {{0xb4c10361,0x64562015,0x38c90065,0x61f5a016}},	//   ्चे_, ggyi, _جاتی_, üzle,
   {{0x36d50364,0x5a352017,0xddc880d2,0x26ca02ec}},	// [10f0] _вопр, инат, _nadž, bibo_,
   {{0x26ca2018,0x2f198247,0xccf8801b,0x68fb89ab}},	//   cibo_, _règ_, _zpět_, _shud,
   {{0x657a822c,0x386901b9,0x65951246,0x7ae52019}},	//   _nsth, _kbar_, _тану, roht,
   {{0xf77185ff,0x7e7e201a,0xddc7201b,0x6b670ec3}},	//   قات_, _zapp, cejš, tīgā,
   {{0x7c2d201c,0x443b0086,0x69dc201d,0x2ab60646}},	//   mbar, maq_, _exre, _sæbe_,
   {{0x443b201e,0x3a29826c,0x6b6700eb,0x171c00be}},	//   laq_, _đapo_, rīgā, עווע,
   {{0x7d0f0065,0x5e5800be,0x40358530,0x68fba01f}},	//   _kics, טיגע_, _вебс, _thud,
   {{0x0b4585c2,0x63bba020,0x443b0085,0x68fb826c}},	//   анин, tzun, naq_, _uhud,
   {{0x3f8901c0,0x2cada021,0x60cba022,0x7c2d2023}},	//   _nrau_, rked_, migm, ibar,
   {{0x4e7887bd,0x2cada024,0x52a9a025,0x63a9a026}},	//   _محمد_, sked_, твом_, ryen,
   {{0x63a9a027,0x67242028,0x7c2d2029,0x7e7e202a}},	//   syen, _stij, kbar, _rapp,
   {{0x254101e2,0xa3b510c5,0x7e7e202b,0x7645008e}},	//   dėl_, जना_, _sapp, _adhy,
   {{0x442da02c,0x7e7e202d,0xddc7202e,0x26ca202f}},	//   mbe_, _papp, vejš, tibo_,
   {{0x7c3b97ec,0x442da030,0x7b0901a1,0x6b8401e8}},	//   laur, lbe_, _džuk, vvig,
   {{0xceb28bea,0x3f89002e,0x3cfd81c5,0x3c420019}},	//   חים_, _erau_, _khwv_, _lévő_,
   {{0x0c262031,0x7c2d2032,0x442da033,0x3f890384}},	//   рман, gbar, nbe_, _frau_,
   {{0x442da034,0x3f892035,0x24802036,0x032308cc}},	// [1100] ibe_, _grau_, rdim_, ждун,
   {{0x236000f3,0x7c3b8010,0x6b842037,0x6281a038}},	//   rtij_, haur, rvig, ndlo,
   {{0x6e3c0370,0x6aa39eaa,0x7c2d2039,0x7c3ba03a}},	//   marb, _monf, bbar, kaur,
   {{0x443b0086,0x442da03b,0x24800085,0x6e3c203c}},	//   caq_, jbe_, qdim_, larb,
   {{0x7d04203d,0x442d8ee1,0x6fd680f7,0x7ccd80eb}},	//   mmis, dbe_, جزائ, _mērķ,
   {{0x4420203e,0x7d04203f,0x6b8b013c,0xddc8a040}},	//   lci_, lmis, ægge, _vadž,
   {{0x40969285,0x61430972,0x38568081,0xd9432041}},	//   _крат, _мера, _възс, _мери,
   {{0x44202042,0x442d877f,0x387f811e,0x8fa68056}},	//   nci_, gbe_, _gaur_, _кабе,
   {{0x7d042043,0x44250085,0x3d16809a,0x29182044}},	//   imis, _əl_, _पूरे_, _hura_,
   {{0x29182045,0xf1eb0424,0x2ee78362,0x6d411d70}},	//   _kura_, _जुड़_, conf_, šlai,
   {{0x6e3c2046,0x442da047,0x81e800c8,0x44202048}},	//   darb, bbe_, মের_, kci_,
   {{0x3866a049,0x2918204a,0x7c2d0079,0xd5778039}},	//   nfor_, _mura_, xbar, _כתבה_,
   {{0x2918204b,0x7c22a04c,0x7d040074,0x4ea7204d}},	//   _lura_, _ifor, dmis, арва,
   {{0x44200063,0xa15886d2,0x6e3c204e,0x7d04204f}},	//   eci_, _баку_, garb, emis,
   {{0x29182050,0x7c22a051,0x7d0f2052,0x78b6005f}},	//   _nura_, _kfor, _pics, _flyv,
   {{0x7d042053,0x44220144,0x7c2d2054,0xb0350251}},	//   gmis, _cfk_, ubar, _униш,
   {{0x7c2d2055,0x443b2056,0x68ed2057,0x8afd800d}},	// [1110] rbar, raq_, _ikad, stře,
   {{0x7c2d2058,0x442da059,0x7d040009,0x2918205a}},	//   sbar, zbe_, amis, _bura_,
   {{0x2918205b,0xa2d81344,0x7c228503,0x4420205c}},	//   _cura_, _मदर्, _ofor, bci_,
   {{0x4420205d,0x38698789,0x7c9500f7,0x6d55205e}},	//   cci_, ýar_, _الحص, muza,
   {{0x3cf405b3,0x29181351,0x4439205f,0x6d418668}},	//   ंतरे_, _eura_, _ies_, _svla,
   {{0x7c22a060,0x44392061,0x29182062,0x7cd3802e}},	//   _afor, _hes_, _fura_, mări,
   {{0x44392063,0x20d20038,0x63ad2064,0x29182065}},	//   _kes_, lšie_, lyan, _gura_,
   {{0xec798dea,0x442d81ec,0x3cfd8282,0x9c5986d2}},	//   упи_, ube_, _qhwv_, ушку_,
   {{0x7c220511,0x6d552066,0x60db804f,0x69ce80e1}},	//   ñori, huza, _ijum, úben,
   {{0x44392067,0x7c3ba068,0x442da069,0x2b4d809f}},	//   _les_, saur, sbe_, rrec_,
   {{0x7c22831d,0x4439031d,0x63ad206a,0x6281a06b}},	//   _ffor, _oes_, hyan, rdlo,
   {{0x4439206c,0x63ad206d,0x3ea5a06e,0x9c14019d}},	//   _nes_, kyan, _holt_, _pọmp,
   {{0xef198063,0x20d20038,0x442006d4,0x6e3c206f}},	//   _już_, jšie_, vci_, tarb,
   {{0xed5a2070,0x63ad10c1,0x249fa071,0x6d552072}},	//   лог_, dyan, ljum_, fuza,
   {{0x3ea58813,0x7d040006,0x78a40364,0x6e3c0456}},	//   _molt_, tmis, _toiv, rarb,
   {{0x44392073,0x25a500f2,0x44202074,0xfd56819d}},	//   _ces_, älla_, uci_, _albọ,
   {{0x44392075,0x44202076,0x7e750f4c,0x64a31d38}},	// [1120] _des_, rci_, bezp, чата,
   {{0x44202077,0x3f8f0073,0x44392078,0x29122079}},	//   sci_, _água_, _ees_, _hiya_,
   {{0xc6930051,0x4439207a,0x290001c0,0x8fc5003d}},	//   _זאת_, _fes_, _khia_, _هزین,
   {{0x92d800c8,0x4439207b,0x7c3987d8,0xa14b0065}},	//   াতে_, _ges_, _newr, اسلے_,
   {{0x38668a38,0x63ad207c,0x80ca80ab,0x7cd38087}},	//   rfor_, cyan, িকল্, cări,
   {{0x7c22a07d,0x60c9a07e,0x291800a4,0x29120077}},	//   _sfor, _emem, _tura_, _liya_,
   {{0x05868087,0x11da00f7,0x29121142,0x237d80ee}},	//   сулм, _صورة_, _oiya_, _aswj_,
   {{0x0cb880c8,0x291204d2,0x3ce0812b,0x44390069}},	//   ুক্ত, _niya_, čivo_, _xes_,
   {{0xdfcf8013,0x99858084,0xe4fb114f,0x6d55207f}},	//   _كيف_, kalų_, ्षति_, zuza,
   {{0x25618065,0x68ed08f8,0x9e66803d,0x29000870}},	//   ból_, _skad, _دارن, _ahia_,
   {{0xf09f009f,0x29122080,0x7648831d,0x7cd38087}},	//   tjà_, _biya_, _iddy, zări,
   {{0x29000028,0x63ad03c3,0x7c228aa2,0x9c14019d}},	//   _chia_, yyan, _ufor, _dọkp,
   {{0x29002081,0x7d1a8102,0x33f6936d,0x29121e00}},	//   _dhia_, _huts, _اساس, _diya_,
   {{0x44392082,0x7d1aa083,0x20d201ac,0x6d552084}},	//   _ses_, _kuts, všie_, tuza,
   {{0x443901c0,0x3b110609,0x29122085,0x7cfe8168}},	//   _pes_, _rizq_, _fiya_, përd,
   {{0x44392086,0x63ad2087,0x7d1aa088,0x6d551caa}},	//   _qes_, tyan, _muts, ruza,
   {{0x44392089,0xab870098,0x76489d5a,0x7b141612}},	// [1130] _ves_, щувк, _oddy, здух,
   {{0x2d8ca08a,0x63ad208b,0x4439208c,0x20d200e1}},	//   _orde_, ryan, _wes_, ršie_,
   {{0x4439208d,0x63ad208e,0x7d1aa08f,0x97d8015b}},	//   _tes_, syan, _nuts, _نظیر_,
   {{0x7648831d,0x20d201ac,0x515b83c8,0x43950098}},	//   _addy, pšie_, רכאו, _дамс,
   {{0x291e0118,0xf7458087,0x63ad00b9,0x2d8c9339}},	//   _étan_, цело, qyan, _arde_,
   {{0x25618065,0x6b8d911b,0x7d1a8db1,0xa3d60a75}},	//   tól_, _šago, _buts, िपर_,
   {{0x3ea58117,0x62952090,0x2ca6a091,0x045981a8}},	//   _volt_, _inzo, _bood_, للغة_,
   {{0xc325a092,0x25618065,0x60dba093,0x0325a094}},	//   омик, ról_, _ujum, один,
   {{0x2ca6a095,0x7b09026c,0x249f807b,0x290001c0}},	//   _dood_, _džuv, rjum_, _rhia_,
   {{0x62852096,0x291204d2,0x02c5835f,0x29002097}},	//   ndho, _siya_, ійно, _shia_,
   {{0xe0da0b9c,0x7d1aa098,0xd4e7835f,0x2bd00ebf}},	//   иво_, _guts, _люди, _सेना,
   {{0x2ca68051,0x290010af,0x3f8d8168,0x237d81c5}},	//   _good_, _qhia_, _kreu_, _tswj_,
   {{0x443fa099,0x03a58a13,0x2bd08074,0x6d439345}},	//   mau_, _фило, _तइया, lsna,
   {{0x443fa09a,0x645ba09b,0x6729a09c,0x6b89a09d}},	//   lau_, lgui, _mtej, mveg,
   {{0x2900209e,0x2d8c209f,0x62850197,0x386da0a0}},	//   _thia_, íde_, ddho, _ober_,
   {{0x443fa0a1,0x62851175,0x3f8601a1,0x645ba0a2}},	//   nau_, edho, _šouu_, ngui,
   {{0x42ca20a3,0x5aca01bb,0x6b89a0a4,0x6283a0a5}},	// [1140] аган_, алам_, nveg, _kano,
   {{0x386d834a,0x443fa0a6,0x2ca020a7,0x7cd38087}},	//   _aber_, hau_, sjid_, măru,
   {{0x443fa0a8,0xdca620a9,0x64a604ae,0x6729a0aa}},	//   kau_, _дани, _дана, _atej,
   {{0x186aa0ab,0x443fa0ac,0xa06aa0ad,0x7d1aa0ae}},	//   ради_, jau_, рада_, _ruts,
   {{0x443fa0af,0x27e0a0b0,0x614020b1,0x3f8da0b2}},	//   dau_, çin_, _bálá, _creu_,
   {{0x443220b3,0x29068102,0x9f610019,0x27e081b9}},	//   lby_, smoa_, ését_, ħin_,
   {{0x68eb9148,0x443220b4,0x443f8114,0x672981bc}},	//   bogd, oby_, fau_, _etej,
   {{0xa3ae07e6,0x7c2420b5,0x443f831d,0x5c988098}},	//   _कथा_, ncir, gau_, ския_,
   {{0x3f8da0b6,0xae7a8364,0x6283a0b7,0x7d1a80fc}},	//   _greu_, _всех_, _bano, _wuts,
   {{0x62839670,0x78a285a2,0x7d1aa0b8,0x645b906c}},	//   _cano, ljov, _tuts, agui,
   {{0x443fa0b9,0xe29a8104,0x69c120ba,0x60cf0079}},	//   bau_, _chưa_, _žlez, ticm,
   {{0x78a281a1,0x6d58a0bb,0x443220bc,0x00000000}},	//   njov, muva, jby_, --,
   {{0x44268870,0x6440a0bd,0x443220be,0x6d588406}},	//   _ifo_, mami, dby_, luva,
   {{0x6283a0bf,0x3ce98088,0x2bd08054,0xdea88041}},	//   _gano, čave_, _तेया, _ƙoƙa,
   {{0xa3d020c0,0xeca709a5,0x9c8301d0,0x64408c53}},	//   _वेब_, ојан, íčov, oami,
   {{0x443220c1,0xd49820c2,0x6aaa01ec,0x19bb8039}},	//   gby_, ору_, öffn, _כמוב,
   {{0x628394be,0x7cd38162,0xdfd101bd,0x6d58a0c3}},	// [1150] _yano, căru, _سيد_, huva,
   {{0x291ca0c4,0x6440a0c5,0x6d58a0c6,0x4424801c}},	//   _kuva_, hami, kuva, hcm_,
   {{0xceb2093f,0x6440805b,0x6729800d,0xe2a68125}},	//   _ניט_, kami, _stej, _áður_,
   {{0x5d7a00be,0x3f8d809f,0x26d120c7,0x6d589ae6}},	//   _פארק, _preu_, lizo_, duva,
   {{0x6440a0c8,0x443f8110,0x291ca0c9,0x7b6419a8}},	//   dami, vau_, _luva_, _отре,
   {{0x8af00201,0x4426a0ca,0x6d43a0cb,0x443fa0cc}},	//   stər, _afo_, tsna, wau_,
   {{0x443fa0cd,0x60cd20ce,0x645ba0cf,0x7d02a0d0}},	//   tau_, _omam, tgui, _bhos,
   {{0x6440a0d1,0x62838364,0x6d43a0d2,0x3f8da0d3}},	//   gami, _sano, rsna, _treu_,
   {{0x443f8355,0x6d43a0d4,0x7c3d20d5,0x38a2009a}},	//   rau_, ssna, _mesr, _góry_,
   {{0x60cd20d6,0x443fa0d7,0x78a985f8,0x6283a0d8}},	//   _amam, sau_, _hoev, _qano,
   {{0x443220d9,0x6283a0da,0x443fa0db,0x7d028083}},	//   yby_, _vano, pau_, _fhos,
   {{0x6283a0dc,0x291c8b80,0x44248c53,0x7d02a0dd}},	//   _wano, _duva_, ccm_, _ghos,
   {{0x7d09a0de,0x69c18065,0x628382b8,0x4432003e}},	//   mmes, szle, _tano, vby_,
   {{0x7d09a0df,0x78bb85a4,0x26d120e0,0xe29a80ff}},	//   lmes, _lluv, gizo_, _thưa_,
   {{0x4432026f,0xde0320e1,0x6da620e2,0x443d83ec}},	//   tby_, епри, чива, _kew_,
   {{0xdca31e58,0x7d098214,0x03260009,0x61fc8214}},	//   наси, nmes, здан, ürle,
   {{0x443220e3,0x26d11eda,0xeb9720e4,0x6d4101fa}},	// [1160] rby_, bizo_, пит_, álar,
   {{0x443220e5,0x09e60ae7,0xb87b20e6,0x7c2420e7}},	//   sby_, позн, gníf, scir,
   {{0x7d09a0e8,0x644099a2,0x78a28144,0x7cfe83ed}},	//   kmes, yami, tjov, hëra,
   {{0x443d804c,0xd12f1e7b,0x6440a0e9,0x60cd00b9}},	//   _new_, امن_, xami, _xmam,
   {{0x6440a0ea,0x8af00085,0x2cbf80e4,0x7d09a0eb}},	//   vami, stəq, dhud_, dmes,
   {{0x6d58a0ec,0xab270698,0xd94620ed,0x33fb01c6}},	//   tuva, _хора_, _неги, _להכנ,
   {{0x7d02a0ee,0xda788038,0x6440a0ef,0x205699fe}},	//   _phos, veď_, tami, _нтар,
   {{0x6d58a0f0,0x443d808e,0x78bba0f1,0x89db01c6}},	//   ruva, _cew_, _gluv, _החלי,
   {{0x6440a0f2,0xe7378364,0x6d58a0f3,0x291c9ae6}},	//   rami, _нет_, suva, _suva_,
   {{0xc333004c,0x6440a0f4,0xbebb03ed,0x6d58a0c3}},	//   עות_, sami, hpër, puva,
   {{0x7d02a0f5,0x2eeea0f6,0x443d8039,0x705519ed}},	//   _thos, moff_, _few_, وندا,
   {{0x443da0f7,0xf8bf01d0,0x38bb03ed,0x644085e7}},	//   _gew_, uhé_, _bëra_, qami,
   {{0x26d1022e,0xb8e503ca,0x2d8c0366,0xdcb10129}},	//   tizo_, _एत_, æden_, ểm_,
   {{0xba178013,0x2eeea0f8,0x7bc41c43,0x6b82a0f9}},	//   _فيها_, noff_, dziu, _isog,
   {{0xdd940084,0x26d120fa,0x443da0fb,0x35e400e8}},	//   нары, rizo_, _yew_, ецтв,
   {{0x6aaaa0fc,0x26d120fd,0x60cd20fe,0x20d201d6}},	//   _hoff, sizo_, _umam, pšia_,
   {{0x6aaaa0ff,0x2bc70c78,0xe803064a,0xa3d009a9}},	// [1170] _koff, _रेखा, रेखा_, _वेद_,
   {{0x7b09025b,0x672d2100,0x6aaaa101,0x6d488253}},	//   _ažur, _itaj, _joff, _ovda,
   {{0x2d8c0082,0x6aaaa102,0x7d09a103,0x2d812104}},	//   ådet_, _moff, ymes, _ushe_,
   {{0x92bf00ab,0x6d55192c,0xcfd20091,0x98a60162}},	//   ুকে_, mrza, _apẹẹ, mplă_,
   {{0x2489009c,0x7b09026c,0x629883b2,0x7feba105}},	//   mdam_, _džur, _onvo, حراف_,
   {{0x443d81b9,0x6b8d0314,0x24892106,0x672d0c53}},	//   _sew_, mvag, ldam_, _mtaj,
   {{0xa3b50063,0x78a9838e,0x58d5835f,0x23692107}},	//   जनक_, _toev, _жовт, ltaj_,
   {{0x645f01f6,0x672d2108,0xb87b0118,0xe3b9a109}},	//   ngqi, _otaj, alíz, жби_,
   {{0xa3e7890a,0x2369210a,0xf770803f,0x7d09a10b}},	//   _मुख_, ntaj_, _مال_, rmes,
   {{0x88bd000d,0xeab180f7,0x25e88321,0x7d09a10c}},	//   zpět, ئعة_, _चुकी_, smes,
   {{0x7643a10d,0x6b82a10e,0x41b4896b,0x672d210f}},	//   many, _esog, есят, _ataj,
   {{0x6298a110,0x6d550042,0x62872111,0x7643a112}},	//   _envo, drza, _lajo, lany,
   {{0xa49b0104,0x7d1e0024,0x6d55066f,0x9b94862c}},	//   _phòn, _sups, erza, _пицц,
   {{0x7643a113,0x62870b48,0x6aaaa114,0x24890dba}},	//   nany, _najo, _goff, edam_,
   {{0x672d2115,0x9fa00cab,0x24890901,0x236918ad}},	//   _etaj, _méér_, fdam_, etaj_,
   {{0x7643a116,0xc10600f7,0x38bb03ed,0x7bc402f9}},	//   hany, _توبي, _tëra_, tziu,
   {{0x7643a117,0x52aa176e,0xcb672118,0x248601ac}},	// [1180] kany, овам_, мате_, ľom_,
   {{0x62872119,0x7643a11a,0x0f5701c6,0x63ab1d5b}},	//   _cajo, jany, _קיים_, ägna,
   {{0x7643a11b,0x7e7c211c,0x673ba11d,0x5e9b01c6}},	//   dany, merp, _awuj, _וביק,
   {{0x6d5c211e,0x6aaa9c9d,0x628705ee,0x673b818e}},	//   mura, _चक्र, _eajo, _bwuj,
   {{0x7643a11f,0x6d5c0886,0x62888355,0xb906a120}},	//   fany, lura, yddo, _पद_,
   {{0x395a2121,0x7643a122,0x3ced0503,0x67002123}},	//   pups_, gany, čeve_, ोगिक_,
   {{0x6d5c2124,0xf9832125,0x6aaaa126,0x99878196}},	//   nura, _игро, _roff, _menų_,
   {{0x2ebb0894,0x6aaaa127,0x2eee8748,0x7e7c2128}},	//   _उत्त, _soff, soff_, herp,
   {{0x7643a129,0x7eb48580,0x60c29a25,0xda7a847f}},	//   bany, _làpi, mhom, оян_,
   {{0x3ce9803b,0xd2508077,0x764382a0,0x60c2a12a}},	//   čava_, دند_, cany, lhom,
   {{0x28f905e9,0x6288831d,0x6444212b,0x7e7c212c}},	//   зень_, rddo, kaii, derp,
   {{0x6d5c212d,0x2369009a,0x6720a12e,0x049381a8}},	//   dura, ytaj_, _kumj, _للمح,
   {{0x6aaaa12f,0x6f17008e,0xfc3f0144,0x60dd2130}},	//   _toff, _pixc, _reí_, rnsm,
   {{0x6d5c0010,0x7e7c2131,0x62988192,0x68ef0df6}},	//   fura, gerp, _unvo, socd,
   {{0x62872132,0x60c2805d,0x7eb487f1,0xa49b0706}},	//   _rajo, khom, _càpi, _fhòl,
   {{0x7643a133,0x6d472134,0xb4fb2135,0x3f8481a1}},	//   zany, rsja, ्षेप_, _osmu_,
   {{0x24892136,0x7643a137,0x2d9e02af,0x2d8c0aa2}},	// [1190] rdam_, yany, äter_, åder_,
   {{0x6d5c2137,0x23692138,0x9af500f7,0xb87b0144}},	//   bura, rtaj_, ركات, coír,
   {{0x23692139,0x7643a13a,0x6d5c213b,0x6b8d213c}},	//   staj_, vany, cura, svag,
   {{0x7643a13d,0x2bd0213e,0xe80c213f,0xe0df01e8}},	//   wany, _सेवा, सेवा_, nnò_,
   {{0x7643a140,0x7d0d2141,0xf388801c,0x62872142}},	//   tany, mmas, _nợ_, _tajo,
   {{0x7d0d2143,0x44292144,0xddde2145,0x69c586ae}},	//   lmas, lca_, _hapš, _üheg,
   {{0x7643a146,0x3f8480eb,0x442907b6,0x00000000}},	//   rany, _esmu_, oca_, --,
   {{0x7d0d2147,0x7643a148,0x60c2a149,0xb385a14a}},	//   nmas, sany, chom, елил,
   {{0x7643a14b,0x7cfe80f1,0x7d0d214c,0x375580d7}},	//   pany, përn, imas, _سپاس,
   {{0x3eac805f,0x13068364,0x6d5c214d,0xde97806b}},	//   _godt_, нный_, yura, _تجرب,
   {{0xd12e817e,0xe4a7802e,0x98bf0110,0x644f1660}},	//   یمی_, _ордо, nutė_, _odci,
   {{0x76418117,0xf9920158,0xb4e9000d,0x7eb4809f}},	//   _hely, ארט_, मको_, _ràpi,
   {{0x4429214e,0xe8df8870,0x42cd80ab,0x6d5c214f}},	//   dca_, _abịa_, রকৌশ, wura,
   {{0x91e591c7,0x09e5a150,0x6d5c2151,0xa3d0081f}},	//   _поле, _полн, tura, _वेष_,
   {{0x7641a152,0x44292153,0xa3d3864a,0x998581a8}},	//   _mely, fca_, _हेत_, _ألبو,
   {{0x44290af8,0x442b2154,0x7d0d2155,0x78ad0176}},	//   gca_, _cfc_, gmas, _goav,
   {{0x68e40133,0x245a82d0,0x42562156,0x6b8900fe}},	// [11a0] _ijid, lümü_, етет, _šegr,
   {{0x6d5c2157,0x44292158,0x160f897d,0xb05b1b57}},	//   pura, aca_, ाधार_, nhän,
   {{0x60c2805d,0x2726001c,0x442b0140,0x8c462159}},	//   thom, _hôn_, _ffc_, _пене,
   {{0x4429215a,0x70f680f7,0x7eb00074,0x03a6215b}},	//   cca_, رسائ, _täps, _зимо,
   {{0xb87b001b,0x20d2007a,0xa2b4801b,0x74160061}},	//   lníc, jšim_, ेसम्, _سوسا,
   {{0x7cfe80f1,0x60c2a15c,0x2726215d,0x7c2ba15e}},	//   tëro, shom, _môn_, _afgr,
   {{0x91e61cf8,0xf388801c,0x629c215f,0x27262160}},	//   _чове, _sợ_, _inro, _lôn_,
   {{0x7ae381a1,0x75218661,0x68e401bc,0x7c29823e}},	//   _ajnt, _dulz, _njid, gcer,
   {{0xdcfa8087,0x63a42161,0x2245a162,0x69080118}},	//   _astă, nxin, falk_, iñed,
   {{0x44292163,0xf3888028,0x7641a164,0x68e4026b}},	//   zca_, _vợ_, _gely, _ajid,
   {{0x7cfe80f1,0x6d1f0424,0x1dcf0105,0x44292165}},	//   qëro, _मूंग_, _हेंत, yca_,
   {{0xb87b003e,0x8d5595e3,0x7c29a166,0x254c81d0}},	//   dníc, _штуч, ccer, měl_,
   {{0xe29aa167,0xe80c05b3,0xb05b01ec,0x68e40b80}},	//   _над_, सेला_, bhän, _djid,
   {{0x68e40133,0x4429009a,0x6f1d8037,0x6da189ab}},	//   _ejid, wca_, _èsce, mɓar,
   {{0x6f1aa168,0x7d0d2169,0x4429216a,0x212d01d0}},	//   _mitc, tmas, tca_, _čeho_,
   {{0x4429216b,0xdc88002e,0xccf80eef,0x629c216c}},	//   uca_, нсул_, ећу_, _anro,
   {{0x4429216d,0x7d0d0859,0x98bf002e,0x628aa16e}},	// [11b0] rca_, rmas, astă_, _kafo,
   {{0xa3d0035a,0xb87b03fb,0x68fd216f,0x6d4a8b81}},	//   _वेळ_, bníc, llsd, ksfa,
   {{0x395e809f,0x7641a170,0x442b2171,0xd99900f7}},	//   nuts_, _rely, _tfc_, بنات_,
   {{0x7641a172,0x5fd28074,0x64429997,0x628aa173}},	//   _sely, _देहल, _neoi, _lafo,
   {{0x81bc81a9,0x27260129,0x2bd08072,0x7eb02174}},	//   ucēj, _xôn_, _तेला, _käpp,
   {{0x7521a175,0x20d20503,0x69d5016f,0xf6538065}},	//   _pulz, všim_, _येथी, ائش_,
   {{0xada58098,0x644280f7,0x6d4aa176,0x395e8106}},	//   тайл, _beoi, gsfa, juts_,
   {{0xe7d2a177,0xeb9993f1,0x644281a8,0x3ce98796}},	//   _देवप, дии_, _ceoi, čavo_,
   {{0xb87b026f,0x26c103a7,0xe3b180f7,0x248b00b9}},	//   zníc, _olho_, شرة_, _macm_,
   {{0x290902c1,0x68f62178,0x628a8114,0x7eb0156e}},	//   _ahaa_, _skyd, _cafo, _näpp,
   {{0x395e8722,0x628aa179,0x27260428,0xbbeb8019}},	//   guts_, _dafo, _sôn_, _کرام_,
   {{0x2d988510,0xb87b027f,0x6442a17a,0x290901bc}},	//   _área_, vníc, _geoi, _chaa_,
   {{0xb05b00f2,0x6a85a17b,0xb90a0424,0x773a0b79}},	//   mhäl, _алла, _मद_, ьянс_,
   {{0xb87b003e,0x395e87fa,0x7982009a,0x628a8114}},	//   tníc, buts_, łowi, _gafo,
   {{0xe643217c,0x26c100e1,0x200400e1,0xbea309a5}},	//   респ, _dlho_, ťmi_, шарк,
   {{0x248da17d,0xb87b026f,0x2726001c,0x29090133}},	//   ndem_, rníc, _tôn_, _ghaa_,
   {{0x46ea0b88,0xb87b016b,0x2c070a27,0x236d8069}},	// [11c0] _один_, sníc, _शरणं_, ntej_,
   {{0x63a40509,0x3ce001c0,0x63a68106,0x6d4803a2}},	//   rxin, sniv_, äkni, ádas,
   {{0x26d80365,0x67240198,0xae5701c6,0xc96606d2}},	//   miro_, _huij, _בסיס_, твей,
   {{0x7995009a,0x26d802ec,0x38cb9190,0x6d4a84fe}},	//   _drzw, liro_, وانی_, vsfa,
   {{0x6d5a0110,0xf093007c,0xe7d28072,0x23d08035}},	//   štad, ינא_, _देशप, _तेंद,
   {{0x26d802a0,0x248d81b9,0x6d4a848d,0x6d58816b}},	//   niro_, edem_, tsfa, trva,
   {{0xe9a3217e,0x628a808b,0x71a301a1,0x7cfe83ed}},	//   _карп, _rafo, _карз, sërm,
   {{0x7cfe80f1,0x26d800b4,0xb866826a,0x628a831d}},	//   përm, hiro_, _جاسو, _safo,
   {{0x2c6d0019,0x2004805c,0xc4d30039,0x26d8020c}},	//   lódó_, _uzmi_, יגה_, kiro_,
   {{0xbe858bbe,0x395ea17f,0x248005e1,0x69c882af}},	//   _مجمو, tuts_, heim_, tzde,
   {{0x9f4f007b,0x6442a180,0x24802181,0xc8b682f1}},	//   _ágú_, _teoi, keim_, _अकाट,
   {{0x26d82182,0x9f352183,0xe3baa184,0x68e28428}},	//   eiro_, лемі, _обе_, nnod,
   {{0x35a8800f,0x26d8106c,0x26c1022c,0x68e28118}},	//   _कपड़, firo_, _plho_, inod,
   {{0x26d82185,0xbc1b8039,0x6b842186,0x7a4801a9}},	//   giro_, _חודש, dwig, nūtē,
   {{0x1df817ae,0x2ca902f1,0x20d20bcf,0x51f380d7}},	//   веры_, tjad_, kših_, _پسور,
   {{0x20d20353,0x851b082e,0x2d1b01bc,0xa3d683ca}},	//   jših_, _ụgbọ_, _ụgbụ_, _सधा_,
   {{0x68e2803e,0xc2992187,0x26d82188,0x3a752189}},	// [11d0] dnod, нках_, biro_, ллар,
   {{0x26d802a0,0x3f89026c,0x5a34218a,0x78bd218b}},	//   ciro_, _isau_, инут, lksv,
   {{0x68e382ba,0x68e2831d,0xceb204de,0x7bc98338}},	//   éndo, fnod, _היי_, zzeu,
   {{0x61fc218c,0x78bd0bfd,0x68e28286,0x6b84018f}},	//   _dyrl, nksv, gnod, bwig,
   {{0xb9ff81b6,0x78bd0a0f,0xe9ff00ff,0x8afd81d0}},	//   _उर्फ_, iksv, _trắc_, stři,
   {{0x7d1d1010,0x7c2d17d6,0x62340992,0x7e6381c0}},	//   _hiss, lcar, _веру, ugnp,
   {{0x68e2a18d,0xc984218e,0x4519a18f,0xb05b01ec}},	//   bnod, _кути, нция_, thäl,
   {{0x7c2d2190,0x7d1d01b9,0xdb1e016b,0xa49b051e}},	//   ncar, _jiss, _švéd, _bhòi,
   {{0x7d1d2191,0x248da192,0xb05b1b57,0x26d82193}},	//   _miss, rdem_, rhäl, yiro_,
   {{0x248d8573,0x7bc981ec,0x236da194,0x27e081a8}},	//   sdem_, rzeu, rtej_, úine_,
   {{0x291e02be,0xdd918e06,0x50460071,0x186a151a}},	//   _état_, _دوا_, ленб, нани_,
   {{0x7c2d2195,0xd5ba80be,0x26d82196,0x25f700c2}},	//   jcar, _אזעל, wiro_, _एड़ी_,
   {{0xe28e8934,0x1cb88077,0x26d82197,0x7c2d2198}},	//   _ла_, _جالب_, tiro_, dcar,
   {{0x442da199,0x7c3ba19a,0x7d1d219b,0x35d886a7}},	//   lce_, lbur, _aiss, _भेड़,
   {{0x649a00ae,0x6281a19c,0x26d81b25,0x7d1d219d}},	//   нтар_, melo, riro_, _biss,
   {{0x442da19e,0x7786219f,0x6281a1a0,0x7d1d21a1}},	//   nce_, _близ, lelo, _ciss,
   {{0x68e2811f,0x7c3ba1a2,0x60c421a3,0xe29a0073}},	// [11e0] vnod, ibur, _ilim, наа_,
   {{0xc3328051,0x6281a1a4,0x7bc00201,0x21a61e0b}},	//   צוב_, nelo, _ümum, лизм,
   {{0x442d800d,0x2d9619e6,0x7d1d21a5,0x25a50004}},	//   kce_, _српс, _fiss, ällt_,
   {{0x64a621a6,0xdca621a7,0x7c2d21a8,0x7d1d21a9}},	//   _сама, _сами, ccar, _giss,
   {{0x442da1aa,0x6281a1ab,0x7c3ba1ac,0x6d4e21ad}},	//   dce_, kelo, dbur, lsba,
   {{0x5694a1ae,0x6281a1af,0x7cfe83ed,0x6d5c21b0}},	//   ракт, jelo, mëri, orra,
   {{0x6281a1b1,0x644621b2,0x442202f7,0x628e02c4}},	//   delo, _keki, _kgk_, _iabo,
   {{0x7c3b8135,0x442fa1b3,0x644621b4,0x628e21b5}},	//   gbur, _cfg_, _jeki, _habo,
   {{0x28a80b75,0x628e21b6,0xb4e4873c,0x6281a1b7}},	//   गानि, _kabo, _नदी_, felo,
   {{0x49749663,0x6281a1b8,0x442da1b9,0x26c7801b}},	//   алос, gelo, ace_, chno_,
   {{0x60c421ba,0x442d801b,0x628e21bb,0x6d41831d}},	//   _blim, bce_, _mabo, _gwla,
   {{0x442da1bc,0x3866a1bd,0x7cfe80f1,0x442221be}},	//   cce_, ngor_, këri, _ngk_,
   {{0xb4c08592,0xb9098870,0x7c22a1bf,0x78bd21c0}},	//   ँसी_, _achọ_, _igor, rksv,
   {{0x442d0d38,0x7d1d0006,0x628e1c95,0x442221c1}},	//   _że_, _siss, _nabo, _agk_,
   {{0x64460586,0x60c404b7,0x7c2d21c2,0x40350470}},	//   _beki, _flim, tcar, _кейс,
   {{0x60c421c3,0x644621c4,0x4422008e,0x3f890282}},	//   _glim, _ceki, _cgk_, _tsau_,
   {{0x7d1d21c5,0x6d5c21c6,0x628e21c7,0x6d4e21c8}},	// [11f0] _viss, arra, _babo, asba,
   {{0x7d1d21c9,0x442da1ca,0x628e106c,0xf8bf001b}},	//   _wiss, zce_, _cabo, lké_,
   {{0x7d1d21cb,0xb87b00f7,0x628e21cc,0x442da1cd}},	//   _tiss, nnío, _dabo, yce_,
   {{0xf8bf21ce,0x7c22a1cf,0x6281a1d0,0x38bb0168}},	//   nké_, _ngor, zelo, _bëri_,
   {{0x442da1d1,0x07a5981f,0x8fa5a1d2,0x36698db3}},	//   vce_, ралн, рале, вало_,
   {{0x7c22a1d3,0x8d5584db,0x628e21d4,0x3869a1d5}},	//   _agor, атич, _gabo, żar_,
   {{0x6281a1d6,0x442d909b,0x56b800be,0x499321d7}},	//   velo, tce_, רפון_, _دیار,
   {{0x628e012b,0xed64026f,0x47359f2c,0x442da1d8}},	//   _zabo, leží_, _внас, uce_,
   {{0x62818162,0x442da1d9,0xe7308f24,0x6449a1da}},	//   telo, rce_, _فصل_, raei,
   {{0x442da1db,0x7c3ba1dc,0x60c421dd,0x7c22a1de}},	//   sce_, sbur, _slim, _egor,
   {{0x6281a1df,0xceb8809a,0x442d90d1,0xaca38133}},	//   relo, _więc_, pce_, _agụm,
   {{0x62818049,0x65638187,0x272b806a,0x8af0011c}},	//   selo, munh, _køn_, stəx,
   {{0x7bcd21e0,0x644621e1,0xfaa5a1e2,0x68e98168}},	//   jzau, _reki, _вало, _mjed,
   {{0x644621e3,0x41b511bc,0x98ab0029,0x7c228353}},	//   _seki, ंहास, ībā_, _zgor,
   {{0x68fba1e4,0x628e21e5,0xb8cc00ab,0x63bba1e6}},	//   _okud, _rabo, _গত_, lyun,
   {{0xf8bf21e7,0x628e03c3,0xdcfc0025,0x27ffa1e8}},	//   cké_, _sabo, tvrđ, _oyun_,
   {{0x63bba1e9,0x63a9a1ea,0x26c581df,0x628e21eb}},	// [1200] nyun, nxen, _ollo_, _pabo,
   {{0xc8798201,0x644607fb,0x68e98388,0xed4602c7}},	//   _abş_, _weki, _ajed, _кноп,
   {{0x644621ec,0x44220ad4,0x63bb8573,0x27ffa1ed}},	//   _teki, _tgk_, hyun, _ayun_,
   {{0x7cfe820f,0x290d81df,0x26c58098,0x628e21ee}},	//   përi, _chea_, _allo_, _wabo,
   {{0x628e21ef,0x7cfe80f1,0x68e982ce,0x16348098}},	//   _tabo, qëri, _djed, беля,
   {{0x68e9a1f0,0xf8bf01d0,0x7c22a1f1,0x629801d6}},	//   _ejed, zké_, _sgor, ôvod,
   {{0x6563862f,0x91e321f2,0x09e307b6,0x20d201d6}},	//   gunh, _доре, _дорн, lšiu_,
   {{0x26c585b4,0x5fa6016f,0xb4c09513,0x320a21f3}},	//   _ello_, खमाल, ँसे_, _izby_,
   {{0xef1a98a0,0x041800ab,0x63bb8019,0x63a98234}},	//   _ама_, ধুরী_, gyun, gxen,
   {{0x291f802e,0xb27381bb,0x657e00e8,0x290221f4}},	//   _ziua_, ольш, _opph, elka_,
   {{0xd90f03f8,0x2247a1f5,0x26dca1f6,0xadf20768}},	//   ویت_, _denk_, mivo_, _आँगन_,
   {{0x64a3a1f7,0x26dca1f8,0xddc501d0,0x5fdb8a27}},	//   _маха, livo_, _schů, _मेडल,
   {{0xdb028352,0x69c58074,0x27ed0214,0x752880dd}},	//   _groß, _ühen, çen_, _hudz,
   {{0xf8bf03cb,0x7648809a,0x2247a1f9,0x29020079}},	//   ské_, _jedy, _genk_, alka_,
   {{0xe3e88a49,0xd5b81957,0x7528a1fa,0x2000026b}},	//   _পরিব, аст_, _judz, _eyii_,
   {{0x75288267,0xc05b035f,0x7bcd21fb,0x25de8074}},	//   _mudz, _рік_, tzau, _कइनी_,
   {{0x75288063,0x2bba0035,0x5399062c,0x2d9a0299}},	// [1210] _ludz, jącą_, ывая_, _erpe_,
   {{0x68e9a1fc,0x68fba1fd,0x69c102f1,0xd7fc01c6}},	//   _sjed, _skud, _ülek, _בהחל,
   {{0x272b8aa2,0x248481b9,0xc8ab8098,0x63a4802a}},	//   _søn_, kemm_, къде_, _áinf,
   {{0xf7719301,0x9c13019d,0xa49b0a2a,0xe0d081a8}},	//   كات_, _jọka, _chòt, وزن_,
   {{0x2bde13d9,0x644d04a2,0x2d8c83a8,0x752880eb}},	//   _नेपा, maai, _asde_, _audz,
   {{0x6563a1fe,0x644d21ff,0xb87b01d0,0x20d201a1}},	//   tunh, laai, dním, lšit_,
   {{0x68e982fd,0xa8a7a200,0x785782e3,0x7528a201}},	//   _tjed, _крак, _نیاز_, _cudz,
   {{0x68e98025,0x6563a202,0x224786c0,0x60dd2203}},	//   _ujed, runh, _senk_, jism,
   {{0x1c4281bb,0xfd488133,0x7b06808b,0x6f1d8037}},	//   чным, _kemị, rðun, _èsco,
   {{0x63a984c3,0x2cad82ce,0x6563a204,0x62852205}},	//   rxen, sjed_, punh, neho,
   {{0x63bb96fb,0x386d8140,0x66c201d6,0x95c8a206}},	//   syun, _kcer_, _dôkl, _куца_,
   {{0xe73a0ab5,0x297a012a,0x6721a207,0x397a0039}},	//   лем_, נטרא, _hilj, נטרנ,
   {{0xeaae9156,0x443fa208,0x8ca4809a,0x6d450122}},	//   _ей_, mbu_, कारो, _awha,
   {{0x443fa209,0x6285029b,0x6b89a20a,0x6d4502c4}},	//   lbu_, jeho, mweg, _bwha,
   {{0x80b880c8,0xdca6220b,0x2d950ff7,0x6285013c}},	//   _আগস্, бави, ортс, deho,
   {{0x70b6800f,0x443fa20c,0x6721a20d,0x0c26030d}},	//   _अकेल, nbu_, _lilj, сман,
   {{0x03a30e97,0x6b89a20e,0x78a406c0,0x443fa20f}},	// [1220] пито, nweg, _iniv, ibu_,
   {{0x443f8609,0x62851854,0x2d9a0042,0xa49b06c4}},	//   hbu_, geho, _trpe_, _akòd,
   {{0x657e2210,0x78a40e23,0x499a17ae,0x764895ab}},	//   _upph, _kniv, ытая_, _redy,
   {{0x764e0365,0x443f822b,0x7648a211,0x7528a212}},	//   laby, jbu_, _sedy, _rudz,
   {{0x7d042213,0x7528a214,0x5fd28074,0x4b550081}},	//   mlis, _sudz, _देखल, _мърт,
   {{0x7d042215,0x66fa0a74,0xf1ca800d,0xdfa580f7}},	//   llis, ृतिक_, ानमन, تحمي,
   {{0x171b0158,0x26dca216,0x6721a217,0x2d982218}},	//   נוצע, rivo_, _dilj, nvre_,
   {{0x6cd4a219,0x7d04221a,0x44320051,0x60dd221b}},	//   تقبا, nlis, ncy_, xism,
   {{0xe81a1c6f,0x60c2a20d,0x26dca21c,0x47c680a9}},	//   नेमा_, mkom, pivo_, _убав,
   {{0x60c292f1,0x7d04221d,0x6601835f,0x39ae8085}},	//   lkom, hlis, _fylk, ləsi_,
   {{0x443fa21e,0x8afb00be,0x69c582f1,0x63a4a21f}},	//   bbu_, רהיי, _ühel, _šind,
   {{0x23602220,0x7d042221,0x66cb0214,0x26da2222}},	//   krij_, jlis, _müke, _ampo_,
   {{0x4426a223,0xe6c48125,0xb87b026f,0x7d0401ac}},	//   _igo_, _þjóð, lník, dlis,
   {{0x7d1600e1,0xf1a69ada,0x60dd0558,0x39ae8085}},	//   emys, _грин, sism, həsi_,
   {{0x6d5a003b,0x60c2a224,0xb87b00e1,0x7afaa225}},	//   štan, kkom, nník, mott,
   {{0xd904a003,0x60c2a226,0xf98f80f7,0x7d042227}},	//   _سی_, jkom, _أبو_, glis,
   {{0x2d8c013c,0x60c28370,0x764e2228,0x644d2229}},	// [1230] æder_, dkom, baby, raai,
   {{0x7d04222a,0x443fa22b,0x7afa84fa,0x3255222c}},	//   alis, zbu_, nott, івер,
   {{0x7d04222d,0x4426a22e,0x443fa22f,0x6ab500ff}},	//   blis, _ogo_, ybu_, _vozf,
   {{0x4426a230,0x60c282b8,0x212a0083,0xb87b026f}},	//   _ngo_, gkom, _dubh_, dník,
   {{0xd366a231,0x672985a4,0x443f826f,0x7afaa232}},	//   _ته_, _quej, vbu_, kott,
   {{0x24ab00ab,0x60c2a233,0xa3be8dd2,0x3ce90162}},	//   _ঐতিহ, akom, ीनन_, lnav_,
   {{0x7afaa234,0x6721a235,0x68ed2236,0x442682c4}},	//   dott, _vilj, _ojad, _bgo_,
   {{0x6b89a237,0x39ae811c,0x60c2a238,0xa0c5a239}},	//   tweg, cəsi_, ckom, _بيرو,
   {{0x443fa23a,0x7b1001ec,0x44268144,0x6b89890d}},	//   rbu_, bäud, _dgo_, uweg,
   {{0x44268a2c,0x66018d38,0x443fa23b,0xb87b05b9}},	//   _ego_, _tylk, sbu_, bník,
   {{0x0086223c,0x7d04223d,0x6b8981ec,0xb87b04e8}},	//   олно, ylis, sweg, cník,
   {{0x2eb4223e,0xc952007c,0x9c1301bc,0x7d0402ed}},	//   ुस्त, ומט_, _tọha, xlis,
   {{0xfc4601ac,0x764e223f,0x68ed2240,0xbebb0168}},	//   šíka_, taby, _djad, jqës,
   {{0x4432009a,0x7afaa241,0x6145a242,0x7d042243}},	//   wcy_, cott, _дека, wlis,
   {{0x60c9a244,0x644ba245,0x7d040b81,0x764e2246}},	//   _olem, _kegi, tlis, raby,
   {{0x78a42247,0x764e1b25,0x0ce800ab,0xb05b1a57}},	//   _univ, saby, পত্ত, lkän,
   {{0x272f084a,0x7d042248,0xb87b003e,0xeb970009}},	// [1240] _gün_, rlis, zník, оит_,
   {{0xda6600f7,0x4432009a,0xdc3c9e51,0x60dba249}},	//   تاري, scy_, váčk, _amum,
   {{0x7d04224a,0x6459809a,0x60c29151,0x1d0a0703}},	//   plis, _odwi, tkom, _вени_,
   {{0xb87b003e,0x7afa8019,0x6fdb80d4,0x53a6161a}},	//   vník, zott, _मेहं, _дамб,
   {{0x39ae8085,0x2bd9a24b,0x888d00be,0x60c9810c}},	//   rəsi_, _बेला, טראַ, _dlem,
   {{0x8f9b1bb3,0xb87b026f,0x60c2a24c,0x66cb224d}},	//   ייני, tník, skom, _tüke,
   {{0x2bde00ba,0xb05b016d,0x7afaa24e,0x60c9a24f}},	//   _नेता, dkän, vott, _flem,
   {{0x41272250,0x60c98bc5,0xb87b1c32,0x644ba251}},	//   _фото_, _glem, rník, _cegi,
   {{0x7afa8065,0x2aaa9285,0x8e76a252,0x644ba253}},	//   tott, атно_, _мужч, _degi,
   {{0x7cfe80f1,0x6459a254,0x3ce00074,0x8af00085}},	//   tërs, _edwi, hiiv_, qsəd,
   {{0x2730a255,0x7afaa256,0xe8950087,0x644ba257}},	//   _hàn_, rott, пань, _fegi,
   {{0x6ab70a74,0x4426a258,0x2d9ea259,0xbebb0168}},	//   _आक्र, _ugo_, _irte_, yqës,
   {{0x6d5a0b48,0x69c10074,0x3ce902d4,0xdb2482f1}},	//   štal, _ülev, vnav_, öpäe,
   {{0x20050029,0x27308028,0xdefb0d15,0x2bd5001b}},	//   āli_, _màn_, рым_, _ठेगा,
   {{0x2730a25a,0x6288a25b,0xc8bc9a42,0x2ebc80ab}},	//   _làn_, medo, ्घाट, _অগাষ,
   {{0x6288a25c,0x70b98074,0x63ad225d,0x68ed225e}},	//   ledo, _आवेल, txan, _ujad,
   {{0x60c0225f,0xb87b001b,0x68fd0168,0x27308129}},	// [1250] ömme, vníh, mosd, _nàn_,
   {{0x6288a260,0x63ad2261,0x21248706,0x2d9e8192}},	//   nedo, rxan, _aimh_, _orte_,
   {{0xdc3f026f,0x672d0168,0xb87b01d0,0x59ca98b1}},	//   líčk, _huaj, tníh, ानिर,
   {{0xd04f0201,0x2730a262,0x628881bc,0x26f5a263}},	//   ticə, _bàn_, hedo, ेत्र_,
   {{0x2d9ea264,0x6d488079,0xf745a265,0x23d98127}},	//   _arte_, _awda, чело, _बेंद,
   {{0x2730a266,0x644ba267,0x62889351,0x672d00f1}},	//   _dàn_, _segi, jedo, _muaj,
   {{0x6288a268,0x6b8d0a0f,0x672d0168,0x2d9e812b}},	//   dedo, lwag, _luaj, _crte_,
   {{0x60dba269,0x60c9a26a,0x6295018e,0x29190088}},	//   _umum, _ulem, _hazo, jmsa_,
   {{0x6295226b,0x6b8d226c,0x644b808b,0x7cfe8168}},	//   _kazo, nwag, _vegi, tërr,
   {{0xdd959006,0x3ed580f7,0x6295226d,0x6288a26e}},	//   _назы, _عقار, _jazo, gedo,
   {{0x644ba26f,0x62952270,0xb05b1a57,0x236901c5}},	//   _tegi, _mazo, rkän, huaj_,
   {{0x6b8d1b9a,0x62952271,0xb05b0338,0x68fd2272}},	//   kwag, _lazo, skän, gosd,
   {{0x24892273,0xe299a274,0xa3d3816f,0x6288a275}},	//   deam_, _гал_, _हेच_, bedo,
   {{0x6d5a0904,0x2cb90706,0x62889f21,0x672d03ed}},	//   štam, _aosd_, cedo, _duaj,
   {{0x2d9e003e,0x6da31a1f,0xada30071,0x764380dd}},	//   íte_, нира, нарл, ibny,
   {{0x01c300c8,0x5fbd8651,0xd7bd8072,0x2cb90706}},	//   ্পাদ, ्नाल, ्नाच, _cosd_,
   {{0x62952276,0x672d0fe2,0x673b8282,0xe45f0106}},	// [1260] _bazo, _guaj, _ntuj, _glöm_,
   {{0x479b0051,0x0e660009,0x3f922277,0x6295016a}},	//   _פייס, _экон, _isyu_, _cazo,
   {{0x2730a278,0x69c1a279,0x98b08289,0x3ebb0039}},	//   _sàn_, nyle, šači_, _הציב,
   {{0x7762a27a,0xa06aa27b,0x7ae1a27c,0x6b8d227d}},	//   trox, сада_, hilt, bwag,
   {{0x7ae1a27e,0xfc3f1727,0x6444227f,0x65638192}},	//   kilt, _unía_, mbii, ernh,
   {{0x628897ad,0x996401d0,0x62952280,0x2b4014a9}},	//   xedo, může_, _gazo, mpic_,
   {{0x28af06b7,0x6b82a281,0x515519dc,0xb0cc1c9d}},	//   टामि, _spog, _отту, ासाग,
   {{0x2d9e8042,0x2124a282,0x6288831d,0x2730a283}},	//   _vrte_, _uimh_, wedo, _tàn_,
   {{0xfc3f82ba,0x62952284,0x66cb06ae,0xbbb88c28}},	//   ñía_, _yazo, _lüka, ेनेक,
   {{0x7ae1a285,0xb6c88065,0x7afe2286,0x7f3b8039}},	//   gilt, _بارے_, nopt, _לעמו,
   {{0x6d5a003b,0x2d9e811e,0x68fd2287,0x6b8d2288}},	//   štaj, _urte_, tosd, zwag,
   {{0xeafa0670,0x68e2a289,0x2ca6a28a,0xab5d8035}},	//   ्तुत_, niod, _unod_, wyże,
   {{0x7ae1a28b,0xfaa68391,0x672d00f1,0x6288a28c}},	//   bilt, _надо, _quaj, pedo,
   {{0x628880f1,0x0ebe8b9f,0x672d0168,0x6d55228d}},	//   qedo, ्सिड, _vuaj, tsza,
   {{0x2489228e,0x672504a2,0xf2978496,0x3ebe18b6}},	//   team_, _vihj, _זכור_, ötta_,
   {{0x6d55228f,0x23692290,0x6b8d2291,0xfbde016f}},	//   rsza, tuaj_, twag, _नेहम,
   {{0x6d550065,0x62952292,0x68e2a293,0xa3be852a}},	// [1270] ssza, _pazo, diod, ीनि_,
   {{0x6b8d2294,0x60cd2295,0x88bd8035,0x92940162}},	//   rwag, _hlam, _ciśn, науц,
   {{0xc1788110,0x673b80dd,0x64440365,0x7d028061}},	//   ntė_, _stuj, bbii, _okos,
   {{0xa3be823c,0xc5f2004c,0x2ec5a296,0xc1788110}},	//   ीना_, _ידי_, वस्त, itė_,
   {{0x629501e0,0x635e0162,0x644f01a9,0x041b0264}},	//   _tazo, tănţ, _ieci, _ফ্রী_,
   {{0x60cd2297,0x7d02a298,0x25de800d,0x7afe2299}},	//   _llam, _akos, _केही_, copt,
   {{0x644f1a6e,0xf6508154,0x68e2826b,0x60cd02d0}},	//   _keci, ائه_, biod, _olam,
   {{0x68e2802e,0x2ee301ed,0x387f81bf,0xe8948110}},	//   ciod, hijf_, _ubur_, _пась,
   {{0x644f229a,0x7ae1a29b,0xeb99a29c,0x645d0144}},	//   _meci, tilt, цип_, _mdsi,
   {{0x78bba29d,0x69c10074,0x66cf80e8,0xb05b1743}},	//   _houv, _üles, _bøke, skäl,
   {{0x78bba29e,0x7ae1a29f,0x44390174,0xa88a22a0}},	//   _kouv, rilt, _ofs_, ойна_,
   {{0xafe6035f,0xa3ad001b,0x7ae1a2a1,0x15e3850a}},	//   домл, कमा_, silt, _केयर_,
   {{0x78bba2a2,0xb8e61c9d,0x66d0016d,0x7d09a2a3}},	//   _mouv, _एव_, _läke, mles,
   {{0x78bba2a4,0x60cd22a5,0x7d09938e,0x644f22a6}},	//   _louv, _elam, lles, _aeci,
   {{0xcb128051,0x644f003d,0x66d00009,0x999801a1}},	//   _שלו_, _beci, _näke, _serž_,
   {{0x78bba2a7,0x7afe02d6,0x68e2802a,0xb05b22a8}},	//   _nouv, wopt, xiod, shär,
   {{0x7d09a2a9,0x073a00f7,0xb05b01ec,0x443902ed}},	// [1280] iles, _بسبب_, phär, _dfs_,
   {{0x244c001c,0x7d09a2aa,0x273b8162,0x05000264}},	//   ếm_, hles, _mână_, ্দের_,
   {{0x27340364,0x2d9c0019,0x63a904b7,0x644f22ab}},	//   _hän_, _éve_, _ġene, _feci,
   {{0x588381bb,0x78bb82be,0x7d098019,0x60cd00b9}},	//   выша, _couv, jles, _xlam,
   {{0x78bb83ec,0x2d8582d6,0xd5af80d7,0x711b03de}},	//   _douv, _aple_, یفه_, קונפ,
   {{0x273400f2,0x68e2a2ac,0xbea38652,0x44390299}},	//   _män_, siod, качк, _zfs_,
   {{0x2734016d,0x7d09a2ad,0x3d0a8072,0x26198075}},	//   _län_, fles, ातले_, येली_,
   {{0x78bba2ae,0x1ee88117,0x6abc007b,0x9972801b}},	//   _gouv, _کوئی_, _horf, těže_,
   {{0x66cf80e8,0x69c106ae,0x2d85a2af,0x60cd0229}},	//   _søke, _üler, _eple_, _rlam,
   {{0x60cd22b0,0xf743a2b1,0x7d1ba2b2,0xf7d7807c}},	//   _slam, _рефо, amus, _חומש_,
   {{0x7c398428,0xa50a8087,0xb05b1d5b,0xa2d4a2b3}},	//   _ffwr, _дежа_, skäm, योग्,
   {{0x7d09a2b4,0x2bd981b6,0x22498904,0xc1788110}},	//   cles, _बेका, _đake_, rtė_,
   {{0xad1b8158,0xe81a101e,0x644f22b5,0x6d588e51}},	//   _וואר, नेला_, _reci, lsva,
   {{0x644f22b6,0x32078114,0x443922b7,0x63a2a2b8}},	//   _seci, _fyny_, _sfs_, _iron,
   {{0x63a2a2b9,0x6728a2ba,0x6d58a2bb,0x27fa809a}},	//   _hron, _midj, nsva, ępny_,
   {{0x60cd0812,0x629aa2bc,0x6ee900ce,0xc983802e}},	//   _ulam, ldto, džbe, _руши,
   {{0x66d004b8,0xbf0ea2bd,0x5b1522be,0x63a28077}},	// [1290] _säke, िताभ_, емат, _jron,
   {{0xd251045b,0x67160996,0x78bba2bf,0x6abc0114}},	//   انا_, _दीपक_, _souv, _corf,
   {{0x78bba2c0,0x25de835a,0x7d00a2c1,0x44390358}},	//   _pouv, _केली_, koms, _tfs_,
   {{0x62988021,0x63a2a2c2,0x90158221,0x7d0904b7}},	//   _lavo, _oron, нфлі, ċess,
   {{0x6abc22c3,0x8e8590ca,0xe8d803c8,0x6d5aa205}},	//   _forf, егле, וואר_, _avta,
   {{0x6abc031d,0x2bd986a7,0x7a318061,0x7f4d02a6}},	//   _gorf, _बेगा, _műté, _mwaq,
   {{0xdce88182,0x63a2a2c4,0xd5b192c8,0x7d09a2c5}},	//   _ardı, _aron, افع_, tles,
   {{0x273b802e,0x9f518019,0x212900b9,0x6aaa8428}},	//   _până_, ából_, _niah_, _anff,
   {{0x7d09a2c6,0x65938085,0x20092240,0x03259b02}},	//   rles, _məhə, _nyai_, ндин,
   {{0xeab18013,0x39458987,0xaad9809a,0x7dee0019}},	//   اعة_, нног, योंक, nősé,
   {{0x6298a2c7,0x212900b9,0x69c522c8,0x7d1ba2c9}},	//   _davo, _biah_, nyhe, pmus,
   {{0x0ef80540,0xf9da00be,0x629aa2ca,0x6d438372}},	//   ंक्स_, פֿיל, adto, mpna,
   {{0x63a2a2cb,0x21290359,0xbbeb9ca3,0x6d43a2cc}},	//   _gron, _diah_, _برام_, lpna,
   {{0x248d856c,0x2734016d,0xe3b080d5,0x290b017f}},	//   leem_, _vän_, _خرم_, alca_,
   {{0x57bd83bb,0xdd92187e,0x2cbda2cd,0x24990493}},	//   ्नुह, دوز_, _kowd_, _basm_,
   {{0x248d879f,0x050000ab,0x91fc81a9,0x94260087}},	//   neem_, ্দ্র_, rgāt, ембе,
   {{0x38600068,0x290222ce,0x6abc22cf,0xc4d280be}},	// [12a0] _idir_, moka_, _porf, אגן_,
   {{0x248d8069,0x290222d0,0x68e622d1,0xe29722d2}},	//   heem_, loka_, likd, нау_,
   {{0xa3bc04e5,0x67288699,0xa84a81a8,0x6abc22d3}},	//   _अथक_, _ridj, كلام_, _vorf,
   {{0x25a5006a,0x26150816,0x26ca00b9,0x6d58a0e5}},	//   ælle_, _धरती_, lkbo_, vsva,
   {{0x66e69383,0x656e22d4,0x1c1c22d5,0x6abc22d6}},	//   нода, lubh, पेशल_, _torf,
   {{0x645622d7,0x6d58a2d8,0x290200b4,0x6d4122d9}},	//   layi, tsva, hoka_, ílag,
   {{0x6728a2da,0x29020365,0xe9f980ff,0x248d81c0}},	//   _vidj, koka_, _đế_, feem_,
   {{0x6298a2db,0x6d589da3,0x645622dc,0x6728a2dd}},	//   _savo, rsva, nayi, _widj,
   {{0x290222de,0x6298a2df,0x1e86a2e0,0x7d00a2e1}},	//   doka_, _pavo, _плам, roms,
   {{0x6456005d,0x656e0234,0xdce380eb,0x2fc681c0}},	//   hayi, kubh, runā, myog_,
   {{0xfbcf82e3,0x200900dd,0x290222e2,0x212900b9}},	//   لتی_, _syai_, foka_, _piah_,
   {{0x63a28142,0x38600362,0x290222e3,0x3cfa0035}},	//   _tron, _cdir_, goka_, ंवों_,
   {{0x09dd0b6f,0xbfa82001,0x6298a2e4,0x249900b9}},	//   _मध्य, нтре_, _tavo, _rasm_,
   {{0x38600086,0x63ad8390,0x61eb8019,0x3ebea2e5}},	//   _edir_, _šang, állá, _jott_,
   {{0x290222e6,0x3a3780be,0xe29b80be,0x3eac808e}},	//   boka_, _ארום_, _זשור, _mndt_,
   {{0x3ebea2e7,0x645622e8,0xade38074,0xb05b0198}},	//   _lott_, gayi, _कइसन_, kkäi,
   {{0x3a7522e9,0x7dee0065,0xe7e081ce,0x66cb0059}},	// [12b0] клар, tősé, _खेला_, _yükl,
   {{0x6911a2ea,0x63bd8aa2,0x3ebe81a1,0x257a83ed}},	//   gåen, øsni, _nott_, kël_,
   {{0x645622eb,0xa5f92184,0x1df90009,0x7ae522ec}},	//   bayi, _цену_, _цены_, riht,
   {{0xf7718124,0xa90784c1,0x248d822c,0x69c50a53}},	//   لات_, ربان, xeem_, ryhe,
   {{0x7d0d22ed,0x3ebea2ee,0x57bd81d0,0x23c722ef}},	//   mlas, _bott_, ्नेह, _díjú_,
   {{0x290222f0,0x66d00338,0xdb029407,0xaca78061}},	//   zoka_, _käka, _droë, کھئے_,
   {{0x6d5a0025,0x257a80f1,0x1af422f1,0x3ebe847f}},	//   štav, gël_, _спря, _dott_,
   {{0x7d0d22f2,0x2fc68420,0x6b848162,0x3eac9277}},	//   nlas, byog_, _ţiga, _endt_,
   {{0x66d000f2,0x3f8901c5,0x98a80087,0x07359bd8}},	//   _läka, _npau_, _lună_, _резю,
   {{0x7d0d073b,0x3ebea2f3,0x78ad22f4,0x248da2f5}},	//   hlas, _gott_, _anav, seem_,
   {{0x290222f6,0xa06a22f7,0x3de100c8,0x7d0d043c}},	//   toka_, мана_, _মুসল, klas,
   {{0x48e60381,0x6f03a2f8,0xa2a1a2f9,0x23690304}},	//   томв, lonc, _कोर्, kraj_,
   {{0x29020ee1,0xe28ea2fa,0x2bd98105,0x6449a2fb}},	//   roka_, _ка_, _बेचा, mbei,
   {{0x6f03a2fc,0x8a059a1f,0x98a80087,0x6449a2fd}},	//   nonc, _изле, _bună_, lbei,
   {{0x645622fe,0x290222ff,0xfc3f01d6,0xceb28e82}},	//   tayi, poka_, _kníh_, סיל_,
   {{0x320a0690,0x6449a300,0x443d808e,0x7c3b8888}},	//   _ryby_, nbei, _jfw_, ncur,
   {{0x6f039122,0x64562301,0xa5072302,0x6911a303}},	// [12c0] konc, rayi, тета_, tåen,
   {{0x6281822b,0x64562304,0x4a431819,0x69c582f1}},	//   nflo, sayi, инув, _ühes,
   {{0x6d4182a6,0x64562305,0x3ebea306,0x00000000}},	//   _ntla, payi, _rott_, --,
   {{0xf7468256,0x3ebea307,0x00e68081,0x2d3e0870}},	//   ведо, _sott_, ъжен, _ọgwụ_,
   {{0xd7ef8013,0x6f0380e7,0x7d042308,0x3ebea309}},	//   يكم_, fonc, mois, _pott_,
   {{0x7d04230a,0xa2a1a30b,0x6d5a01ac,0x442f8752}},	//   lois, _कोल्, štau, _agg_,
   {{0x180f035a,0x6d5c048d,0x68e4230c,0x1ae319a8}},	//   _सर्व_, nsra, _omid, _торм,
   {{0x629c1a83,0x7d04230d,0x22498904,0x6d5c230e}},	//   _haro, nois, _đaka_, isra,
   {{0x629c230f,0xcb678fbb,0x4f268196,0x613e80eb}},	//   _karo, вање_, _адаб, _mīle,
   {{0x60c0a310,0x629c185c,0x629e2311,0x02a6a312}},	//   _homm, _jaro, ndpo, трим,
   {{0x629c2076,0xf4848077,0x7d040364,0xd48f8ba8}},	//   _maro, _ماشی, kois, _кр_,
   {{0x629c009c,0xcfa98019,0x7793003d,0x6d5c2313}},	//   _laro, _تاہم_, لیبا, dsra,
   {{0x248680fc,0x7d042314,0xb4c09130,0x98a80493}},	//   _ibom_, dois, ुसी_, _sună_,
   {{0x752b802a,0x76588010,0x60c0a315,0x68e42316}},	//   _zigz, navy, _lomm, _emid,
   {{0x2fcd003b,0xd6d8035f,0xe5c411a8,0x7d0d2317}},	//   šeg_, ття_, асто, tlas,
   {{0x60c0a318,0x78ad0c93,0x23692319,0x4aa6864a}},	//   _nomm, _unav, traj_, _कोतव,
   {{0x629c231a,0x7b32809a,0x7d0d231b,0x69c8a31c}},	// [12d0] _baro, _dług, rlas, lyde,
   {{0x7d0d231d,0xade38074,0xfde38074,0x629c231e}},	//   slas, _कइलन_, _कइलस_, _caro,
   {{0x7d0d231f,0x7d041009,0x6f0380c3,0x6f0200f7}},	//   plas, bois, vonc, _íoca,
   {{0x60c0a320,0xf09f2321,0x7d0d20d8,0x48e180ab}},	//   _comm, ndà_, qlas, যক্র,
   {{0x6f0385b4,0x973580d5,0x60c0a322,0x26c1016b}},	//   tonc, اکرا, _domm, _koho_,
   {{0x629c2323,0x60c08b99,0x26c103e4,0x69c88646}},	//   _garo, _eomm, _joho_, kyde,
   {{0xceb40451,0x26c11abb,0xf0758019,0x60c08372}},	//   ייס_, _moho_, _میاں_, _fomm,
   {{0x60c0a324,0x290901bc,0x394601a1,0x7c3b82df}},	//   _gomm, _nkaa_, ćost_, ucur,
   {{0x6449a325,0x7c3b8012,0x57f5a326,0x27e080f7}},	//   rbei, rcur, _спат, úint_,
   {{0x3ce901e9,0x68e42327,0xa3bb0006,0x29092328}},	//   hiav_, _smid, _अपन_, _akaa_,
   {{0x6281a329,0xaad98770,0x59ca90be,0x6d41a32a}},	//   rflo, योगक, ानगर, _utla,
   {{0x6281808b,0xf7460293,0x20c201a8,0x6fa78697}},	//   sflo, лемо, _cóip_, चिपू,
   {{0x6b65a32b,0x2d0f835a,0x7b06807b,0x4b7980be}},	//   _скла, ातील_, rður, _נאַו,
   {{0x249fa32c,0xe2968226,0x249d81c5,0x7ae381f6}},	//   ldum_, _баш_, _hawm_, _umnt,
   {{0xa0a6232d,0x7d040009,0x249d81e9,0x69118370}},	//   _байд, tois, _kawm_, tåel,
   {{0x249f8125,0x68e4232e,0x97c61ec9,0x212d8359}},	//   ndum_, _umid, _مقبو, _nieh_,
   {{0xcb67023a,0x60c0a32f,0x237fa330,0xdd038084}},	// [12e0] лате_, _romm, ntuj_, ūrėj,
   {{0xda650013,0x249d90af,0x6d5a04c3,0x8f9b0039}},	//   لامي, _lawm_, átas, _טיפי,
   {{0x629c2331,0x60c0a332,0x2cafa333,0x7d042334}},	//   _varo, _pomm, _ongd_, pois,
   {{0x249d81c0,0xa09a81a8,0x629c2335,0x237f9d4b}},	//   _nawm_, عضاء_, _waro, ktuj_,
   {{0x629c00a4,0x44240014,0x69c88035,0x69da8216}},	//   _taro, _àm_, zyde, zzte,
   {{0xb8cba336,0x2ca00074,0x3b0a0009,0x4e7a00be}},	//   _को_, ldid_, _чего_, גאַצ,
   {{0x60c0a337,0x57d001d0,0x2ca006ae,0xf8bf1a25}},	//   _tomm, हनुह, odid_, lmée_,
   {{0x7ae8a338,0xbd878624,0x2ca02339,0x249d8069}},	//   widt, انين_, ndid_, _cawm_,
   {{0xc6768060,0xe646a33a,0x63a4233b,0x66d000f2}},	//   _مطاب, _безп, nvin, _räkn,
   {{0x69c88bfa,0x69da8352,0x63ad826f,0xe45f0009}},	//   tyde, tzte, _šanc, _ylös_,
   {{0x249d81c0,0x26c1233c,0xd2b70039,0x7c8689a0}},	//   _fawm_, _roho_, אלית_, _буле,
   {{0xa3e50665,0x8dfb8039,0x249d81c0,0x69c8a33d}},	//   _भइल_, _אהבת, _gawm_, ryde,
   {{0x69da8065,0x63a40a0f,0x81bc00c8,0xf09f009f}},	//   szte, jvin, েছি_, rdà_,
   {{0x11d6803f,0x3ce68282,0x99d68277,0x539b84de}},	//   _متعد, _hmov_, _متعا, _ניוו,
   {{0x7f441883,0x58d50009,0x249d8069,0x1df8076a}},	//   _etiq, _войт, _yawm_, геры_,
   {{0x290f01a8,0x20f88084,0x2bd18b99,0x290903e4}},	//   _óga_, yčia_, दैवा, _ukaa_,
   {{0x26c10a56,0x395e8341,0x63a4233e,0x4a552109}},	// [12f0] _toho_, lsts_, gvin, икас,
   {{0xb05b01ec,0x66d00106,0x3ce901c0,0x2739a33f}},	//   rkäu, _jäkl, siav_, _rèn_,
   {{0x46150077,0x66d0016d,0x6d5a2340,0xb035a265}},	//   _خودر, _mäkl, štar, анеш,
   {{0x6d452341,0x237f8035,0x395ea342,0x5c07047f}},	//   _itha, ytuj_, ists_, _бяга,
   {{0x644d2343,0x249d822c,0xb4c30bbc,0xb05b0198}},	//   mbai, _rawm_, ्सी_, lkäs,
   {{0x395e8029,0x644d2344,0xddc5a345,0x249d8282}},	//   ksts_, lbai, ибли, _sawm_,
   {{0xa56480f7,0xfc3180f7,0xb05b0198,0x249f811c}},	//   مدين, يحة_, nkäs, tdum_,
   {{0xff1580c8,0x644d0102,0x386080f7,0xdb06010c}},	//   াদেশ_, nbai, óirt_, _arkè,
   {{0x395e87e2,0x249f8457,0x6d450122,0x7d1d010c}},	//   ests_, rdum_, _ltha, _mhss,
   {{0x752f0063,0x644d03ac,0x237f809a,0x6d452346}},	//   _licz, hbai, rtuj_, _otha,
   {{0x249d81e9,0x6d45022c,0x2a760039,0x25b98199}},	//   _tawm_, _ntha, בעתך_, _جهاد_,
   {{0x68eb8cfa,0x63a403c7,0x752f0035,0x25de81d0}},	//   nigd, yvin, _nicz, _केटी_,
   {{0x6d452347,0xb8ee000f,0xa3e50074,0x26d82348}},	//   _atha, _शक_, _भेल_, thro_,
   {{0x443fa349,0x63a40197,0x7d1d0706,0x68eb8420}},	//   lcu_, vvin, _ahss, higd,
   {{0x2d53802e,0xa01b0019,0x50460037,0xddc3234a}},	//   nţe_, lföl, _кейб, обри,
   {{0x1c46234b,0x8a14803d,0x6d450706,0x47c6004a}},	//   рнам, _اظها, _dtha, _вбив,
   {{0x6d45234c,0x6f07017f,0x68eba34d,0x2ca00074}},	// [1300] _etha, bojc, digd, rdid_,
   {{0x55e6234e,0xf8bf0036,0x0ea49370,0x3ce981d6}},	//   _вооб, rmée_, _गोंड, čavy_,
   {{0x765c234f,0x2d9a095e,0x644d2350,0xf0aa046d}},	//   mary, _uspe_, bbai, _gbàá_,
   {{0x270e8c78,0x64a62351,0x39a58029,0x4fc68bba}},	//   ित्र_, _тама, _mēs_, исла,
   {{0x443fa352,0x02b580c2,0x98a62353,0x3f82136f}},	//   dcu_, _अचंभ, nslı_, ntku_,
   {{0x765c2354,0x5d66a355,0x658a8201,0x236da356}},	//   nary, атиз, _rəhb, drej_,
   {{0xdce18214,0x69c7806a,0x6d450706,0x290683e4}},	//   _aslı, øjel, _xtha, pooa_,
   {{0x399b012a,0x0ca78009,0x656e0c5e,0x765c2357}},	//   _בילד, атьи_, irbh, hary,
   {{0xf743a358,0x765c2359,0x225800c9,0xdb0609c4}},	//   _мето, kary, _kerk_, _arké,
   {{0x78a2a35a,0x79a6a35b,0x0f7b83c8,0xb4d203ca}},	//   ldov, арме, _באמב, वसु_,
   {{0x3a370051,0x765c01e2,0x2258235c,0x6f070024}},	//   ירים_, dary, _merk_, vojc,
   {{0x60c40c64,0x1bea9f8c,0x395ea35d,0x69de011b}},	//   _coim, _идеи_, rsts_, izpe,
   {{0x77f4a35e,0x3949a35f,0x60c42360,0xd7fb0530}},	//   _अशोक_, _čase_, _doim, тун_,
   {{0x0eeb2361,0x28dd82f1,0xb05b062c,0x7e78a362}},	//   тьми_, _मतभि, tkäs, ngvp,
   {{0x3f822363,0x7afda364,0xeda400e8,0xd2f88019}},	//   atku_, éste, ошто, _لکھا_,
   {{0x04c900f7,0x78a2a365,0xdce7009a,0x60d62366}},	//   دوري_, jdov, kują, _glym,
   {{0x644d2367,0x656e0c41,0x765c2368,0x78a281e8}},	// [1310] rbai, arbh, bary, ddov,
   {{0x6e950013,0xf1a71ff3,0x644d0014,0xf6992369}},	//   _الدا, ирен, sbai, _свој_,
   {{0x6d45005d,0x20f8811f,0x28cc109b,0x3ce781ab}},	//   _utha, rčin_, ासचि, _जगले_,
   {{0xa3c7a36a,0x628501a8,0x271f847d,0x273d04be}},	//   _उथल_, sfho, यग्र_, _kìn_,
   {{0x443f8289,0xa3bb152c,0x2d8300f3,0x60c0236b}},	//   vcu_, _अपि_, ltje_, ömmi,
   {{0x4aa68076,0xaaa6a36c,0x6b9d002a,0x236d8b80}},	//   _कोलव, _कोलक, _issg, vrej_,
   {{0x2d83236d,0xad5897ae,0x443fa36e,0x645b888b}},	//   ntje_, арых_, tcu_, taui,
   {{0xfdf80039,0x66cf813c,0x84f900d4,0x20f8826f}},	//   ימוש_, _køkk, ्किट_, nčil_,
   {{0x60c40068,0x68e9a36f,0x443fa370,0xe3e9803d}},	//   _roim, _imed, rcu_, دکان_,
   {{0x443f8012,0x236da371,0xa01b2372,0x9f958074}},	//   scu_, rrej_, rföl, _müüa_,
   {{0x66cf813c,0x98a62373,0x60d62374,0x39e9a375}},	//   _løkk, бине, _plym, удно_,
   {{0x236d8353,0xa01b0106,0xfd1f0129,0x693a8197}},	//   prej_, pföl, _nhì_, _kċej,
   {{0x60c40009,0xfaa581e2,0x6f1e0118,0x66cf80e8}},	//   _voim, _гало, _phpc, _nøkk,
   {{0x3f822376,0x78a2a1f8,0x291f81c0,0xe7371ad3}},	//   rtku_, zdov, _lhua_, сер_,
   {{0x60c40181,0x645990e1,0x68e98106,0x3f820696}},	//   _toim, _kewi, _omed, stku_,
   {{0xeb9a10ac,0x26c5a377,0xb05b0b8b,0xb4d20075}},	//   либ_, _lolo_, skär, वसे_,
   {{0x63bb862f,0x765c010c,0x2d8300f3,0x22582378}},	// [1320] nxun, pary, atje_, _perk_,
   {{0x68fba379,0x6459a37a,0xf4128451,0x78a0a37b}},	//   _ajud, _lewi, לפן_, _samv,
   {{0x68fb816d,0x2722801c,0xdb04237c,0x63a48118}},	//   _bjud, _hưng_, nvié, _áinv,
   {{0x225801d8,0x291fa37d,0x6459831d,0x2cbfa37e}},	//   _werk_, _chua_, _newi, jjud_,
   {{0x0eea835f,0x26c58038,0x7d09a37f,0x96eaa380}},	//   льки_, _bolo_, does, лька_,
   {{0x527519b8,0xdb028187,0xdce70035,0x20f880c3}},	//   _мусу, _proí, rują, mčim_,
   {{0x2b46a381,0x6443009a,0x6b842382,0x64599781}},	//   _stoc_, śnie, ltig, _bewi,
   {{0x63ab82f7,0xdce70035,0xa7fb0118,0xd497a383}},	//   _brgn, pują, lañe, брь_,
   {{0x68e380f1,0xd2508013,0x6459831d,0x940d0326}},	//   ënde, ونة_, _dewi, ɓoɓi_,
   {{0x63ab006a,0x63a92384,0x6b842385,0x6d4a8711}},	//   ågni, _šenk, itig, ppfa,
   {{0x2d98a386,0x20120326,0x6b842387,0x7d09a388}},	//   _ère_, _ayyi_, htig, boes,
   {{0x2d9e8042,0x6459a389,0x6b84238a,0x2ed10beb}},	//   _iste_, _gewi, ktig, हस्त,
   {{0xdfd80098,0x61e00085,0x765a8168,0x272280ff}},	//   бър_, _əmla, _kety, _cưng_,
   {{0x81de00c8,0xd9fa01cb,0xf40000ab,0xeaf58c33}},	//   _তখন_, ्थात_, ্ধার_, ीकृत_,
   {{0x2d9e800d,0x765aa38b,0x6b8406a8,0x691881ca}},	//   _jste_, _mety, etig, víen,
   {{0x2d830a0f,0x2eeea38c,0x62889e12,0x753a8db1}},	//   rtje_, hiff_, lfdo, _mutz,
   {{0x6b84238d,0x2d83238e,0x38690041,0x3ea1238f}},	// [1330] gtig, stje_, _idar_, _taht_,
   {{0x68e9a390,0x8c1b8bea,0x290b2391,0x765aa392}},	//   _smed, רומי, loca_, _nety,
   {{0xfd1f0104,0x399aa393,0x753a8352,0x6b842394}},	//   _thì_, _jūs_, _nutz, atig,
   {{0x26c5a395,0x7e688216,0x291f8069,0x399a81a9}},	//   _solo_, _addp, _qhua_, _mūs_,
   {{0x66048182,0x765a904a,0x4918010f,0x2d9e8102}},	//   şikl, _bety, זקאל_, _aste_,
   {{0x26c581b4,0x35c98284,0x321c9075,0x6459a396}},	//   _qolo_, игло_, _ozvy_, _sewi,
   {{0x765a820f,0x26c5a397,0x291fa398,0xd05d0085}},	//   _dety, _volo_, _thua_, sisə,
   {{0x62972399,0x9345a39a,0x645f0085,0xf9921101}},	//   lexo, оние, naqi, _קרן_,
   {{0x2d9ea39b,0x8c6480f7,0xdcfc00eb,0x03a5a39c}},	//   _este_, سطين, ntrā, ципо,
   {{0x05ba239d,0x399a8029,0xdddc0019,0x3869239e}},	//   _उपलब, _būs_, zerű, _adar_,
   {{0xe8fa239f,0x290319ba,0x7d09a3a0,0x63bb8118}},	//   ило_, čkan_, poes, sxun,
   {{0x160400d4,0x297a00be,0x79850114,0x63ab8669}},	//   _शुगर_, סטרא, ithw, _trgn,
   {{0xa3bb815b,0x68fd0216,0x940580d7,0x63ab8037}},	//   _حاضر_, érda, _بوشه, _urgn,
   {{0x673b8079,0x386923a1,0x63a9a3a2,0xa8030118}},	//   _muuj, _edar_, mven, úñas,
   {{0x63a9a3a3,0x62971075,0x845a23a4,0x6da31bb7}},	//   lven, dexo, ират_, мира,
   {{0x63a9a3a5,0x9e3c9c32,0x6aa38114,0x161e80c2}},	//   oven, _maďa, _hanf, येटर_,
   {{0xb6a60ff7,0x0aea1b7a,0xab6600e8,0x6aa38300}},	// [1340] _дипл, адай_, ювал, _kanf,
   {{0x6b8423a6,0x78a40282,0x63a9a3a7,0x386904e8}},	//   rtig, _haiv, iven, _zdar_,
   {{0x6aa38590,0x28af000d,0x78a40198,0x9e3c80e1}},	//   _manf, _जोडि, _kaiv, _naďa,
   {{0x765aa3a8,0x6aa3a3a9,0xac760019,0x78a40144}},	//   _sety, _lanf, _بادش, _jaiv,
   {{0x78a40282,0x765aa3aa,0x63a980f3,0x6b840079}},	//   _maiv, _pety, jven, qtig,
   {{0x63a9a3ab,0x78a423ac,0x645d807b,0x356a9e17}},	//   dven, _laiv, ðsin, арин_,
   {{0x20d7a3ad,0xd54780a9,0xa96723ae,0xe6da8105}},	//   _için_, опје_, _мира_, _भतीज,
   {{0x66cb0459,0x6aa3826b,0xdb0b841c,0x2fcf804a}},	//   _yüks, _aanf, _urgê, bygg_,
   {{0x3949a3af,0xaca401bc,0xfb868110,0xdb040580}},	//   _časa_, _ndọt, цыйн, nviï,
   {{0xcb1a80a9,0x63a4a3b0,0x386900b9,0x6aa38114}},	//   јќи_, _šins, _sdar_, _canf,
   {{0x09f88013,0x7afd85e4,0xaca40133,0x3f868548}},	//   صفحة_, ésta, _adọt, ltou_,
   {{0x63a9959b,0x7aef82ba,0x29030289,0x78a40037}},	//   bven, éctr, čkao_, _caiv,
   {{0x3f86a3b1,0x4ea723b2,0x63a9802e,0x60358085}},	//   ntou_, орва, cven, _həmç,
   {{0xa3ae0df4,0x387f23b3,0x3f86a3b4,0x66d9046d}},	//   किन_, żur_, itou_, _bìka,
   {{0x78178a74,0x290b2031,0x7b1001ec,0x58d5091e}},	//   _तर्क_, poca_, häus, _нокт,
   {{0x628e23b5,0xd5a48986,0x38690024,0x6aa3a3b6}},	//   _abbo, _یہ_, _udar_, _zanf,
   {{0x28ab9a42,0x3d0b8076,0x645f00f1,0xb87b0118}},	// [1350] _घोषि, ावते_, raqi, rhíd,
   {{0x7e990019,0x238e00eb,0x2489026c,0xb87b0118}},	//   _اندر_, dējā_, sfam_, eníx,
   {{0xdcfc0029,0x6297002a,0x39580114,0x0e9a01c6}},	//   strā, rexo, _cwrs_, _השתל,
   {{0x23668025,0x798523b7,0x6ee923b8,0x629723b9}},	//   _ovoj_, rthw, džbi, sexo,
   {{0x7d0d002e,0x68ed0a2c,0x645d23ba,0xba7700f7}},	//   moas, _mmad, _iesi, _واست,
   {{0x645d23bb,0x6da59bb7,0x7d0d08b0,0x60dd0168}},	//   _hesi, зика, loas, ërmj,
   {{0xb14603f8,0x645d23bc,0x6aa383ec,0x68ed02f1}},	//   _فیلم_, _kesi, _ranf, _omad,
   {{0x7d0d0ca4,0xdd8e80f7,0x2ec819eb,0x66d00198}},	//   noas, اوي_, _रक्त, _väki,
   {{0x645d23bd,0x3f86a3be,0x6aa3a3bf,0x63a980e7}},	//   _mesi, ctou_, _panf, uven,
   {{0x68ed23c0,0x645d23c1,0x443923c2,0x6721a3c3}},	//   _amad, _lesi, _lgs_, _uhlj,
   {{0x60db84dc,0x4efa80be,0xaf0881a8,0x3ea58366}},	//   _klum, _פלעג, _بقلم_, _ialt_,
   {{0x21060c78,0x645d23c4,0x44390420,0x7522a3c5}},	//   रवेश_, _nesi, _ngs_, _ghoz,
   {{0x087680be,0x78a423c6,0xe45680be,0x3ea5a3c7}},	//   הערט_, _vaiv, _זינט_, _kalt_,
   {{0x443923c8,0x7529a3c9,0x60dba3ca,0x68ed23cb}},	//   _ags_, lmez, _llum, _emad,
   {{0x60dba3cc,0x2cf91344,0x645d23cd,0x78a423ce}},	//   _olum, ्कूल_, _besi, _taiv,
   {{0x645d0baf,0x0b4604db,0x60c9a3cf,0x201e0201}},	//   _cesi, знан, _noem, ətin_,
   {{0x7d1604fe,0x2d8782f1,0x644423d0,0xdb0b87b6}},	// [1360] rlys, htne_, rcii, _argé,
   {{0x60db88e9,0x2d87a3d1,0x645d1312,0x691d0866}},	//   _alum, ktne_, _eesi, néen,
   {{0x7d161cab,0x60dba3d2,0x2d930118,0x60c9a3d3}},	//   plys, _blum, _gpxe_, _boem,
   {{0xe04396d9,0x645d23d4,0x7d0d23d5,0xa7fb0118}},	//   енци, _gesi, coas, laña,
   {{0xdc370158,0x765e23d6,0x3f86802a,0x6d45a3d7}},	//   _מאכט_, _kepy, utou_, íhan,
   {{0x645d23d8,0xa3e50d14,0xdee3a3d9,0x2d878390}},	//   _zesi, _भेट_, ночи, ftne_,
   {{0x23668ee0,0x3f86a3da,0x645d005d,0x3ea5a3db}},	//   _svoj_, stou_, _yesi, _dalt_,
   {{0x60db803a,0x2900022e,0x3f86a3dc,0x18a38254}},	//   _glum, _njia_, ptou_, _пасм,
   {{0x613a001b,0x3ea5804a,0x6f0e0326,0x66dd89c4}},	//   _důle, _falt_, kobc, _sèke,
   {{0x3ea5a3dd,0xfc3f0118,0x68ed23de,0x6da68ab2}},	//   _galt_, _maía_, _smad, _низа,
   {{0xa7fb0216,0xdd8f866e,0x1ea9a3df,0x7416a3e0}},	//   daña, _مول_, _باقي_, _کوشا,
   {{0x69370499,0xfce3a3e1,0x236697aa,0x09f701c6}},	//   _kćer, _похо, _tvoj_, למים_,
   {{0x645d23e2,0xa3cd8701,0x44390196,0xbff80470}},	//   _resi, रहण_, _rgs_, зеях_,
   {{0x645d23e3,0x63a2a3e4,0xa7fb23e5,0x29120365}},	//   _sesi, _ison, gaña, _ekya_,
   {{0xa3e5000f,0x56780009,0x7d0d23e6,0x765e0176}},	//   _भेज_, ября_, toas, _depy,
   {{0x5fbea3e7,0x68ed0079,0x7aee01ed,0xc8ab86a7}},	//   ्हाल, _umad, _ambt, _घोंट,
   {{0xd90f09d7,0x645d23e8,0x7d0d002e,0xa7fb15c7}},	// [1370] _لیگ_, _vesi, roas, baña,
   {{0x60dba3e9,0x7f4d23ea,0x63a28c53,0x645d005d}},	//   _slum, _itaq, _mson, _wesi,
   {{0x645d23eb,0x63a282f7,0x68fd23ec,0x60db8e79}},	//   _tesi, _lson, onsd, _plum,
   {{0x3ce023ed,0x63a2a3ee,0x629aa3ef,0x68fd23f0}},	//   chiv_, _oson, heto, nnsd,
   {{0x6d4a00f1,0xdcfc0087,0x63a2a3f1,0x6d5a85ee}},	//   _çfar, stră, _nson, _awta,
   {{0x629aa3f2,0x658a8201,0x2ca923f3,0x63ad23f4}},	//   jeto, _təhl, ldad_, mvan,
   {{0x3ea5a3f5,0xa1941182,0x63a2a3f6,0x60db9d6a}},	//   _valt_, _парч, _ason, _tlum,
   {{0x2d87a3f7,0x60db80ee,0x63ad23f8,0x66d00106}},	//   rtne_, _ulum, ovan, _häkt,
   {{0x290f8867,0x752984b7,0x63ad23f9,0x2d87a3fa}},	//   moga_, rmez, nvan, stne_,
   {{0xa3ae146d,0x3945a00e,0x2bdf001b,0xe3ca8144}},	//   कित_, мног, पैया, _soñó_,
   {{0x7f4d0510,0x66d00106,0x6dd5804e,0x63a2a3fb}},	//   _ataq, _mäkt, _تقاض, _eson,
   {{0x290fa3fc,0x63ad1434,0x3940811a,0x2ca682c4}},	//   noga_, kvan, _čist_, _gaod_,
   {{0x2ca923fd,0x691d00e7,0x272401ec,0xe79c02d0}},	//   ddad_, péen, höne_, _düğü,
   {{0x63ad23fe,0x2ca90144,0x6b89a3ff,0x629aa400}},	//   dvan, edad_, mteg, ceto,
   {{0x386d834a,0x290f812b,0x6f0e003e,0x6b89811e}},	//   _oder_, koga_, robc, lteg,
   {{0xf8e2141b,0x386d8168,0x2eda84c5,0xa7fb0144}},	//   _पतिय, _nder_, _भत्त, saña,
   {{0xfa8e801c,0x6aa701a1,0x59cb8127,0xccf28039}},	// [1380] _mừng_, _bajf, ाहवर, דכן_,
   {{0x386d80ee,0xe297002e,0xb05b1cce,0x63a6a401}},	//   _ader_, мау_, hjäl, ækni,
   {{0xe8208076,0xd62a01bb,0x88868a13,0xa87a00be}},	//   _बरहा_, _фоне_, длеж, ַאַר,
   {{0xa3bf86a7,0xa3cda402,0x61ee8118,0x657c062c}},	//   ीहा_, रहा_, úbli, murh,
   {{0x3860021e,0x6aa8831d,0x8cdb00d4,0x629aa403}},	//   _meir_, yddf, नसरो, yeto,
   {{0x386da404,0x473380e8,0x38602405,0x629a8118}},	//   _eder_, вніс, _leir_, xeto,
   {{0xc6930051,0xe8208076,0x290fa406,0x657c00b9}},	//   דאו_, _बरवा_, boga_, nurh,
   {{0x24802407,0x3eba00b9,0xdc13807e,0x629a9588}},	//   ngim_, _lnpt_, _ağır, weto,
   {{0xd90d8288,0x629aa408,0xa6868293,0xfa8e80ff}},	//   _این_, teto, _олад, _dừng_,
   {{0xb6cb8117,0x7b32809a,0x38600174,0x68e2936f}},	//   _والے_, _tłum, _aeir_, lhod,
   {{0x629aa409,0x658a8201,0x6b89a40a,0x66d018c2}},	//   reto, _məhk, ateg, _läks,
   {{0xa3de0fcc,0x63ad03bf,0x75498019,0x38600114}},	//   तना_, yvan, őszö, _ceir_,
   {{0x27e684b9,0x63a2a40b,0x386000f7,0x9f59077f}},	//   nzon_, _uson, _deir_, ìyàn_,
   {{0xe1ef95e4,0x7ce30006,0x3eba0118,0x63ad240c}},	//   اسی_, _kõrg, _cnpt_, vvan,
   {{0x9f34035f,0xdc3a07d9,0xc32780f7,0x290fa40d}},	//   тері, _açık, _تكون_, yoga_,
   {{0x63ad240e,0xadf18665,0x26cc846d,0x4422240f}},	//   tvan, _अइसन_, _lodo_, _bzk_,
   {{0x2ca91726,0x68e284c4,0x290f86ec,0xa7fb0511}},	// [1390] rdad_, dhod, voga_, maño,
   {{0x26cca410,0xcf2715a9,0x63ad1457,0xa7fb0216}},	//   _nodo_, _تربي, rvan, laño,
   {{0x63ad2411,0x6b898102,0x290fa412,0x7e63a413}},	//   svan, zteg, toga_, vanp,
   {{0x63ad01ed,0xf86981a8,0x2fe402d0,0x7e6381e0}},	//   pvan, سمتي_, _örgü_, wanp,
   {{0x26cc8db7,0x6aa7069f,0xfa8e801c,0x752d2414}},	//   _bodo_, _tajf, _rừng_, mmaz,
   {{0x752d0065,0x26cc8333,0x290fa415,0xaaad86a7}},	//   lmaz, _codo_, soga_, _झोंक,
   {{0x26cca416,0x0445a417,0x68e281f6,0x3d0ba418}},	//   _dodo_, нейн, bhod, ावले_,
   {{0x68e28f4c,0x27e682d0,0x752d2353,0x2f16008b}},	//   chod, bzon_, nmaz, lægt_,
   {{0x7e63a419,0x248d8669,0xe3b18c3b,0x3860241a}},	//   panp, rfem_, ارب_, _reir_,
   {{0x7c22a41b,0x5fbe950e,0x3860241c,0x1eea8061}},	//   _dzor, ्हरल, _seir_, _فوقی_,
   {{0x6b89a41d,0xfa8e8028,0xaca38870,0x7c22a41e}},	//   steg, _từng_, _azụm, _ezor,
   {{0xc689073a,0x26c7803a,0x98b880eb,0x7e61a41f}},	//   _לא_, ljno_, _kurā_, _help,
   {{0xbd2c893f,0x95228117,0x6d41a420,0x752d0904}},	//   _וואָ, _حکوم, _hula, dmaz,
   {{0x68e28a56,0x7d1ba421,0x78a9a422,0xd36ea423}},	//   zhod, llus, _laev, _اهو_,
   {{0x6d41a424,0x38602425,0x7d0902a5,0x44222426}},	//   _jula, _teir_, česn, _szk_,
   {{0x6d41a427,0x64a32428,0xdca30af0,0x7693861c}},	//   _mula, ласа, ласи, lıyı,
   {{0xac070056,0x68e29ded,0x24070c24,0xeb97023a}},	// [13a0] ента_, vhod, енти_, нит_,
   {{0xe9ff8104,0x6281a429,0x7d1ba42a,0x7e6181bf}},	//   _giải_, nglo, hlus, _nelp,
   {{0x7d1ba42b,0xae5b0051,0xd9108065,0x6d41a211}},	//   klus, _מכיר, لیس_, _nula,
   {{0xa01b00f2,0x38608013,0x26cca42c,0x443da42d}},	//   mför, úir_, _sodo_, _ngw_,
   {{0x6d41a42e,0xa01b016d,0x26cca42f,0x7d1b82f1}},	//   _aula, lför, _podo_, dlus,
   {{0x6d41a430,0x27e6a431,0x6e94a432,0x644b806a}},	//   _bula, rzon_, тику, _afgi,
   {{0x68e28efd,0x40969db0,0xa01b2433,0x26cc8353}},	//   phod, _прат, nför, _vodo_,
   {{0x629e2434,0x6d41a435,0xf8bf0019,0x7ce302f1}},	//   lepo, _dula, rmék_, _võrg,
   {{0x26cc90dd,0xa2c40e70,0x6d41a436,0x2904a437}},	//   _todo_, राप्, _eula, _ijma_,
   {{0x7c229234,0x6d41a438,0x60cd1613,0xa01b016d}},	//   _vzor, _fula, _soam, kför,
   {{0x6d41a439,0x7c228035,0x5cd6804a,0x7d1ba43a}},	//   _gula, _wzor, _підх, blus,
   {{0x73e6a43b,0x660907d9,0xa01b016d,0x7d1ba43c}},	//   _поез, şekk, dför, clus,
   {{0x7c228a20,0x6d5e026b,0x6d41a43d,0xddcc01d0}},	//   _uzor, _awpa, _zula, _čišt,
   {{0x629e243e,0x66d0016d,0x661aa43f,0x673a8372}},	//   jepo, _säkr, _kytk, _jitj,
   {{0xdd940048,0xa7fb128e,0x65942440,0xa2c42441}},	//   лары, paño, лару, रान्,
   {{0x752d0118,0x57b52442,0x6aaa86b1,0x5183a443}},	//   umaz, _абит, _haff, _суша,
   {{0x752d2444,0x6aaaa445,0x2f160366,0xd3711f33}},	// [13b0] rmaz, _kaff, tægt_, شها_,
   {{0x6aaaa446,0x629e2447,0xff5001a8,0x78a9852a}},	//   _jaff, gepo, _اخي_, _saev,
   {{0x073601c6,0x7d1b8428,0x317ea448,0x661a862c}},	//   _שאתם_, ylus, nutz_, _nytk,
   {{0x6ee200e1,0x6d41a449,0x98bd02d6,0x00000000}},	//   _vôbe, _rula, _ouvč_, --,
   {{0x6d41a44a,0x07a58fe7,0x317e81ec,0x7ce30074}},	//   _sula, талн, hutz_, _võrd,
   {{0x6d419397,0xa3ae0665,0xcf9400be,0x7e6705f3}},	//   _pula, किर_, רטס_, najp,
   {{0xf2d20159,0xdcfa884a,0x6b8d0601,0x7d1b8006}},	//   _דעם_, _artı, ltag, tlus,
   {{0xdb060884,0x6281a44b,0x24868706,0x673a890d}},	//   _erkä, wglo, _ccom_, _eitj,
   {{0x7d1ba44c,0x7e61a44d,0x6aaa8365,0x6b8d1b80}},	//   rlus, _telp, _baff, ntag,
   {{0x6d41a44e,0x6aaaa44f,0x7d1ba450,0x9e678065}},	//   _tula, _caff, slus, _سائن,
   {{0x7d1ba451,0x0574a452,0x6d41876d,0xc0e60a41}},	//   plus, _ماند, _uula, вонк,
   {{0x63ad88ae,0xa01b0106,0x6b8d2453,0x62819670}},	//   _šanu, vför, ktag, sglo,
   {{0xa8568039,0x66048457,0x62952454,0x9cd681c6}},	//   כירה_, şikt, _obzo, _שונה_,
   {{0xe1f183f8,0x6b8d2455,0x658a8201,0x6aaaa456}},	//   _پست_, dtag, _səhi, _gaff,
   {{0xe7372457,0x213b2458,0x8d6304ae,0x925881a8}},	//   тер_, _fiqh_, ивре, _أشهر_,
   {{0xa3ae023c,0xa01b2459,0x6aaaa45a,0x2cada45b}},	//   किल_, rför, _zaff, nded_,
   {{0x9343245c,0xa01b00f2,0x6b8d10c1,0xcb67245d}},	// [13c0] инте, sför, gtag, кате_,
   {{0xf1fa245e,0x249fa45f,0xa01b0106,0xd0f20032}},	//   وعات_, heum_, pför, _faṣẹ,
   {{0x629e2460,0xfaa31cf2,0xcb1283c8,0xa2c41513}},	//   repo, рахо, סלב_, राब्,
   {{0xb91a0032,0x673aa461,0x080a80d7,0xdcfa82a6}},	//   _aifẹ_, _sitj, وزشي_, _istħ,
   {{0x2cada462,0x673aa463,0x2ca00074,0xdb0b823e}},	//   dded_, _pitj, meid_, _orgà,
   {{0xc7d70051,0x2ca02464,0xf4130039,0x63a41ec7}},	//   כוני_, leid_, _כפר_, mwin,
   {{0x6aaaa465,0x63a4005d,0x5fa9000f,0x888482e3}},	//   _raff, lwin, _चैनल, _میان,
   {{0x4420801c,0x2ca002f1,0xfd0f81a8,0xef1f0061}},	//   _ơi_, neid_, يجي_, ttük_,
   {{0xccf30051,0x2b4600f7,0xf746a466,0x63a42467}},	//   יכה_, íoch_, _резо, nwin,
   {{0x2ca02468,0x21292469,0x2d9a0aa2,0x63ab006a}},	//   heid_, _shah_, _oppe_, ægni,
   {{0x60f9246a,0xc486a46b,0x63a4246c,0xfbcf8bca}},	//   ення_, _алек, hwin, متی_,
   {{0x6aaaa46d,0x63a4246e,0x6b8d246f,0xcd368481}},	//   _waff, kwin, ytag, _شراب,
   {{0x6aaa82a6,0x442080ff,0x2ca002f1,0x64430035}},	//   _taff, _ái_, deid_, śnik,
   {{0x29022470,0x442682a0,0x2d472471,0x6b8d2472}},	//   anka_, _izo_, _põe_, vtag,
   {{0x63a42473,0x69dca474,0x6b8085ee,0x00000000}},	//   ewin, øred, lumg, --,
   {{0x6b8d2475,0x200901c0,0x2ca0052a,0xba3781c6}},	//   ttag, _txai_, geid_, _בטוח_,
   {{0xbab902cb,0x3949807a,0x63a42476,0x613a928a}},	// [13d0] нгах_, _časi_, gwin, _půln,
   {{0x6b8d2477,0x24730028,0x7a40026f,0xbb1900f7}},	//   rtag, ệm_, vští, رياض_,
   {{0x6b8d2478,0x2ca02479,0x7afda47a,0x249f808e}},	//   stag, beid_, ésti, yeum_,
   {{0xf7719a05,0x44268870,0xf2df002e,0x2ca00362}},	//   مات_, _ozo_, _atât_, ceid_,
   {{0x747a0039,0x78ad02f1,0x6d45247b,0x7f198110}},	//   _אנרג, _maav, _huha, ніку_,
   {{0x6d45247c,0x753d247d,0x6f15247e,0x3ebea47f}},	//   _kuha, _hisz, nozc, _cntt_,
   {{0x4426a480,0x6d450406,0x753d0019,0x29880dc7}},	//   _azo_, _juha, _kisz, _исто_,
   {{0x644d2481,0xf3f98087,0x60dd090d,0xd9288162}},	//   ncai, laţi_, jksm, _ацул_,
   {{0xe796853d,0x2cada482,0xf4959e5c,0x644d2483}},	//   _مالک, rded_, نشکد, icai,
   {{0x63ad803b,0xdb0400a9,0x62852484,0x2fd9031d}},	//   _šans, rviç, ngho, dysg_,
   {{0x63a42485,0x5dd58875,0x4426a486,0xa2c403dd}},	//   zwin, _حقائ, _ezo_, रात्,
   {{0xcea90bea,0x78ad002a,0x29020079,0x63a40123}},	//   _מי_, _caav, unka_, ywin,
   {{0x645ba487,0x7f441ee8,0x776081c0,0xe2a880d7}},	//   mbui, _quiq, _xwmx, راین_,
   {{0x6d452488,0x201e00eb,0x99d581ad,0xf3f98162}},	//   _buha, āti_, _متبا, jaţi_,
   {{0xfce62489,0x2ca00074,0x63a4248a,0xe2968098}},	//   гово, teid_, wwin, _сащ_,
   {{0x30ae80ab,0x6d45248b,0x03a613f7,0x78ad1a1a}},	//   _কক্স, _duha, либо, _gaav,
   {{0x68e4248c,0x2ca0248d,0x6d45248e,0x0c26248f}},	// [13e0] _ilid, reid_, _euha, уман,
   {{0xa2c42490,0x2ca00006,0x63a4044e,0x6aa1808e}},	//   राध्, seid_, rwin, nelf,
   {{0x3f822491,0x394f802e,0x6d4502a0,0x2d9a016d}},	//   luku_, _însă_, _guha, _uppe_,
   {{0x7d7b012a,0x74550698,0xa3e3809a,0x600a8110}},	//   _אנטו, _върх, नना_, ннем_,
   {{0x7d042492,0xa2c40697,0x6d452493,0x3f822494}},	//   mnis, राद्, _zuha, nuku_,
   {{0xf3f9802e,0x765c2495,0xe16601a8,0x716601a8}},	//   caţi_, nbry, _مدري, _مارك,
   {{0x91e60134,0x7d0d9234,0x3f822496,0x68e42497}},	//   _сове, časn, huku_, _olid,
   {{0x33749630,0x7d04138e,0x44268140,0x7981a498}},	//   агир, nnis, _pzo_, dulw,
   {{0x7d042499,0xd70a81f3,0x3f82126a,0x1616249a}},	//   inis, _знае_, juku_, _दुसर_,
   {{0xbda68077,0x78ad01c2,0x7d04249b,0x68e4249c}},	//   _محصو, _saav, hnis, _alid,
   {{0x7d040e51,0x527b00be,0x765c1da3,0x6f1504e8}},	//   knis, ענטא, dbry, vozc,
   {{0x27e6249d,0x33869c9b,0x6d45249e,0x2ba510d0}},	//   _żona_, _букв, _ruha, _ऑनला,
   {{0x44268870,0x6d450239,0x3f82249f,0x60dd24a0}},	//   _uzo_, _suha, guku_, rksm,
   {{0x6d4524a1,0x68e401f6,0x7d0424a2,0x02a3847f}},	//   _puha, _elid, enis, _гръм,
   {{0x59a40063,0x753d24a3,0x78ad14c7,0x7afaa4a4}},	//   _गैलर, _pisz, _taav, mitt,
   {{0x7afaa4a5,0x3f820904,0x545524a6,0x6d4524a7}},	//   litt, buku_, рват, _vuha,
   {{0x753d0065,0x644d24a8,0xf3f98087,0xe0208105}},	// [13f0] _visz, rcai, taţi_, _बरगद_,
   {{0x644d24a9,0x7afaa4aa,0x320b0d8f,0x657a0174}},	//   scai, nitt, нхен_, áthc,
   {{0x753d0065,0x7d0402af,0x658a8085,0xad27004e}},	//   _tisz, bnis, _məhs, _مرحو,
   {{0x7afaa4ab,0x6aa18a0f,0xe82082f1,0x3ea32175}},	//   hitt, zelf, _बरखा_, lejt_,
   {{0x62989807,0x2d910102,0xd5b88dc1,0x938b24ac}},	//   _obvo, ltze_, _arā_, _ясна_,
   {{0xd9f68075,0x4b7a03de,0x60c082d6,0x261a0075}},	//   ुपात_, _באשו, _enmm, _मुडी_,
   {{0x2d8309a4,0x7afaa4ad,0x249900b9,0x2d91011b}},	//   nuje_, ditt, _kbsm_, ntze_,
   {{0x09e10770,0x2909004f,0x67d58a42,0x7d0d94f0}},	//   पनीय, _njaa_, _кобу, časo,
   {{0x2d830bfb,0xb4d58b9f,0xe787a4ae,0x645ba4af}},	//   huje_, _सकी_, _љубо, rbui,
   {{0x3ae400f2,0x6442a4b0,0x7afaa4b1,0x3f820289}},	//   _köpa_, _egoi, gitt, vuku_,
   {{0x410624b2,0xdeba83c8,0x7d0424b3,0x8a388198}},	//   изов, _שמעל, ynis, ляют_,
   {{0x3c478013,0x3f8224b4,0x6aa1879f,0xab9580e8}},	//   _إضاف, tuku_, self, _виді,
   {{0x3949a1f6,0x7d04007d,0x7d04a4b5,0xf74624b6}},	//   _času_, vnis, čist, рего,
   {{0x3f82003a,0x69daa4b7,0x26d30118,0x7afa847f}},	//   ruku_, byte, _coxo_, citt,
   {{0x7d0424b8,0x3f8224b9,0x6da602c7,0x765c24ba}},	//   tnis, suku_, шива, rbry,
   {{0x3f8224bb,0x81bd00ab,0x26f28697,0x7ce302f1}},	//   puku_, েনা_, _अग्र_, _põra,

   {{0x26d303a8,0x7d041162,0x234800d7,0x39478580}},	// [1400] _foxo_, rnis, اسری_, _huns_,
   {{0x2d8324bc,0x42562118,0x3947867f,0x658a811c}},	//   buje_, ртат, _kuns_, _məhr,
   {{0x50669ad3,0x867b00be,0x7e7b0039,0xc6930039}},	//   атла, _בריו, _באיז, _ואת_,
   {{0xd7faa4bd,0xe7b30bca,0xa2c40aed,0x7afaa4be}},	//   кул_, _امید, राह्, zitt,
   {{0x27e08307,0x3947862f,0x442424bf,0x212d81b4}},	//   áin_, _luns_, _ám_, _dheh_,
   {{0x78a2a4c0,0x64428046,0xa2e60009,0xdd9aa4c1}},	//   seov, _sgoi, _тогд, вши_,
   {{0x35678048,0x3947a4c2,0x7afa95c8,0xf8bf00e7}},	//   арын_, _nuns_, vitt, llée_,
   {{0x3d10a4c3,0xd94324c4,0x63b99670,0x658a811c}},	//   ावें_, _фети, _brwn, _bəhr,
   {{0x66768077,0x7afaa4c5,0xb4d6816f,0x2b4680ff}},	//   _ندار, titt, _हवी_, _quoc_,
   {{0xf2d300be,0xf2df00ff,0x69daa4c6,0x4ac90f3a}},	//   ַער_, _luân_, tyte, रायव,
   {{0x7afaa4c7,0x394783a8,0x26d3247a,0x6f18a4c8}},	//   ritt, _cuns_, _roxo_, movc,
   {{0x7afaa4c9,0x2d83003e,0x3949811f,0x394784c3}},	//   sitt, vuje_, _čast_, _duns_,
   {{0xcb548277,0x658a8201,0x893780be,0x61ff8085}},	//   _انتظ, _təhs, ירטע_, _əylə,
   {{0x6f18a4ca,0x6d48a4cb,0xdefb01e2,0x3ce681c0}},	//   novc, _kuda, тым_, _hlov_,
   {{0x998480f7,0x69da8168,0x272981a8,0x3ea30168}},	//   _العو, qyte, núna_, rejt_,
   {{0x6d48a4cc,0x3ea324cd,0x657a00f7,0xf8bf24ce}},	//   _muda, sejt_, átha, rmés_,
   {{0xc2991b7a,0x3ea300f1,0x26d3002a,0x213f8359}},	// [1410] лках_, pejt_, _toxo_, _riuh_,
   {{0xa2c40778,0x291924cf,0x68fd24d0,0xddc38087}},	//   राष्, losa_, lisd, nanţ,
   {{0xf9f901a8,0x6f18936f,0x80cb81a2,0x80c38072}},	//   دفاع_, dovc, _सचदे, ळाले,
   {{0x68fd24d1,0xb4d5a120,0x6d57011b,0x112880e8}},	//   nisd, _सके_, _itxa, аючи_,
   {{0x38691e14,0x2d9ea4d2,0x395a02c4,0x6d48016b}},	//   _mear_, _apte_, apps_, ídav,
   {{0x6d48a4d3,0xef188a8e,0x386901a8,0x9a840251}},	//   _buda, амі_, _lear_, _мусл,
   {{0x291924d4,0x6d48a4d5,0xa2c40c46,0x7ae700b9}},	//   kosa_, _cuda, रार्, _iljt,
   {{0x6d48a4d6,0x248924d7,0xf2df001c,0xe91980e8}},	//   _duda, ngam_, _xuân_, _собі_,
   {{0xdd0205f3,0x6d48a4d8,0x394024d9,0x658a811c}},	//   šuću, _euda, _riis_, _qəhr,
   {{0x394024da,0x7645031d,0xf3ff0187,0xcac98d15}},	//   _siis_, _nghy, _leão_, угое_,
   {{0x6d48a4db,0xa06a24dc,0x6d5701c5,0x186a24dd}},	//   _guda, лана_, _ntxa, лани_,
   {{0xcd968039,0x386924de,0x291924df,0x62889e12}},	//   _לדעת_, _cear_, gosa_, agdo,
   {{0xe8f724e0,0x39400074,0x6d570cdb,0xe2999c8a}},	//   сля_, _viis_, _atxa, _бал_,
   {{0x7c2b8025,0x63a9a4e1,0x6d48a1ba,0xddc38087}},	//   _izgr, mwen, _yuda, canţ,
   {{0x63a9805d,0x394024e2,0x386924e3,0x8db5004a}},	//   lwen, _tiis_, _fear_, ості,
   {{0x3991a4e4,0xf2df0028,0x6b8424e5,0xb4d5954b}},	//   más_, _quân_, tuig, _सको_,
   {{0x39918117,0x60c424e6,0xe29a02df,0x63a9a4e7}},	// [1420] lás_, _inim, лаа_, nwen,
   {{0x16aa00af,0xfd690133,0x20ef0326,0x7b1d823e}},	//   _свои_, _jupụ, nƙin_, cèut,
   {{0xe29702cb,0x38690051,0x63a9a4e8,0xbed700be}},	//   сах_, _year_, hwen, _הויז_,
   {{0xb4d68e1a,0x6d5c0cd4,0x63a9a4e9,0x6d48a4ea}},	//   _हवे_, mpra, kwen, _ruda,
   {{0x6d48a4eb,0x351b0051,0xdefa8a41,0x64460122}},	//   _suda, _תוכנ, лык_, _igki,
   {{0x3ce6826f,0x3991a4ec,0x752424ed,0x6ffc00eb}},	//   _slov_, kás_, lliz, mācī,
   {{0x6d5c0247,0xfe6f8060,0x291924ee,0x6f18a4ef}},	//   npra, ردو_, yosa_, rovc,
   {{0x39918065,0x4422079f,0x3b548652,0xdbdd00e1}},	//   dás_, _kyk_, окир, zšír,
   {{0xddc3802e,0x96969c60,0x64460359,0xfd69019d}},	//   tanţ, _греш, _mgki, _bupụ,
   {{0x6d48a4f0,0x4974a4b6,0x38690229,0x2ca4a4f1}},	//   _tuda, олос, _sear_, semd_,
   {{0x629c020f,0x4422079f,0xddc38087,0xba9b03de}},	//   _mbro, _lyk_, ranţ, נסטי,
   {{0x23c802f1,0x7aef8722,0x3ce6a4f2,0x6d5c24f3}},	//   रमाद, èctr, _ulov_, dpra,
   {{0x7afe0125,0x752424f4,0x6c36a452,0x5f9424f5}},	//   kipt, dliz, _افشا, пият,
   {{0xb5fc84b7,0x39918019,0x60c424f6,0xddc3826c}},	//   _reġj, bás_, _enim, lanš,
   {{0x291924f7,0x1dbd881f,0x6d5c2053,0xf3ff02df}},	//   posa_, ्मयत, gpra, _peão_,
   {{0x99860063,0x442224f8,0xddc380eb,0x657c854f}},	//   łoś_, _byk_, nanš, _århu,
   {{0x8b5801a8,0x629c0362,0x248924f9,0x2d7301a1}},	// [1430] مجلس_, _bbro, rgam_, sće_,
   {{0x752424fa,0x2d7324fb,0x3f868118,0x442224fc}},	//   aliz, pće_, duou_, _dyk_,
   {{0x752424fd,0x66d00009,0x7f3c00be,0x1a9b80be}},	//   bliz, _näky, _געזו, ריבע,
   {{0xad270416,0x38698125,0x9bc7027e,0xfc3f01df}},	//   _درخو, úar_, _лёгк, _saíu_,
   {{0x39918065,0x7c229eec,0x7f49a4fe,0x39580580}},	//   zás_, _nyor, _queq, _etrs_,
   {{0x7afe059c,0xab5b02af,0x8d558056,0xe739a4ff}},	//   cipt, _prüf, отич, шел_,
   {{0x6d42a500,0xc05b8558,0xed598150,0x63bd008e}},	//   _bioa, _біз_, шой_, _hrsn,
   {{0x6d42a501,0x7cfe9482,0x68e2a502,0x63bd025b}},	//   _cioa, tūra, ckod, _krsn,
   {{0x69dc8bc5,0x68e9a503,0x63a98a0f,0x63bb00fe}},	//   øren, _iled, uwen, _šunj,
   {{0x60c4003b,0x3991a504,0x81d480c8,0x68e9800d}},	//   _snim, tás_, _সেই_, _hled,
   {{0x3ea785ef,0x68e9a505,0x63a9805d,0x54558323}},	//   ment_, _kled, swen, _двет,
   {{0x2d87a506,0x3ea08067,0x6d5c007a,0x3ea7a507}},	//   mune_, đite_, vpra, lent_,
   {{0x7c228065,0x7d248009,0x7c2ba508,0xb05b016d}},	//   _gyor, _эффе, _uzgr, tjär,
   {{0x4422067f,0x6d5c2509,0x68e2a50a,0x7d1ba50b}},	//   _ryk_, tpra, zkod, lous,
   {{0x3ea782be,0x8237826a,0x7d09a50c,0x290d802a}},	//   ient_, _ارشا, ones, _ojea_,
   {{0x3958250d,0xe45a0323,0x3ea7a50e,0x2a6a00ee}},	//   _rtrs_, ржа_, hent_, _sebb_,
   {{0x3ea7a50f,0xa11300f7,0x75242510,0x2a78008e}},	// [1440] kent_, _تويت, rliz, _pdrb_,
   {{0x6d5c2511,0x3ea7a512,0x63bd1b49,0x68e9816a}},	//   ppra, jent_, _drsn, _aled,
   {{0x7afe2513,0x3ea7a247,0x8c46054c,0x2d87a514}},	//   ript, dent_, _мене, june_,
   {{0x4fc681bb,0x3f868ece,0xa99a80be,0x2d87a515}},	//   жска, tuou_, יבער, dune_,
   {{0x7d1b81df,0x7d090669,0xddc38088,0xbba8886a}},	//   dous, čest, vanš, _कनेक,
   {{0x7afe08cf,0x3ea78bf9,0x68e2a516,0x68e9a517}},	//   qipt, gent_, skod, _eled,
   {{0xbb4311d2,0xc448819f,0xf9878277,0xa2cda518}},	//   _церк, میان_, _تب_, तान्,
   {{0xd4978012,0x7d1ba519,0x151780f7,0xd25080d7}},	//   орь_, gous, يزية_, کند_,
   {{0x3ea7a51a,0x39448101,0xe7a90035,0xcb0a81a4}},	//   bent_, _iims_, _चैंप, иход_,
   {{0x21268b50,0x3ea7a51b,0xb5fc81b9,0x7d0981e8}},	//   lloh_, cent_, _leġi, anes,
   {{0x2d87a51c,0x3958a51d,0x6e93803d,0x7d1ba51e}},	//   cune_, ërs_, _آلما, bous,
   {{0x7d1ba51f,0xeb9a8a94,0x6d5aa520,0x6ec283ca}},	//   cous, _вид_, _itta, लाकु,
   {{0x7762011c,0x6f1c2521,0x5ead8264,0x7c228db1}},	//   _çoxl, forc, চারে, _uyor,
   {{0x3f508028,0x6f1c0024,0x61318370,0x63a2826b}},	//   _màu_, gorc, måle, _ipon,
   {{0xd5b81cf8,0x3eb30085,0xfc3f801b,0x2b4b01e8}},	//   ост_, _vaxt_, žít_, _succ_,
   {{0x3ea7a522,0x7d00880a,0x1fa72523,0x63bd1bae}},	//   zent_, nims, _дрог, _prsn,
   {{0x964701e5,0x200c0201,0x3ea7a524,0x43940251}},	// [1450] _мэнд, şdir_, yent_, матс,
   {{0x7d09a525,0x6d5a919d,0x68fba526,0x63bd0042}},	//   znes, _otta, _smud, _vrsn,
   {{0xaca301bc,0x3ea7a527,0x7d00a528,0xdcf50035}},	//   _ahụb, vent_, kims, erzą,
   {{0x3ea7a529,0x63a287c6,0x76550035,0x39448980}},	//   went_, _opon, lczy, _cims_,
   {{0x6d5aa52a,0x7d098aa2,0x98c60289,0x995401d0}},	//   _atta, vnes, šući_, _výše_,
   {{0x63ad0555,0x643a0158,0x2d87a52b,0x2ca9252c}},	//   mwan, _לערנ, tune_, lead_,
   {{0x7d1ba52d,0x3ea7a1d6,0x63ad252e,0x63a2a52f}},	//   tous, rent_, lwan, _apon,
   {{0x3ea7a530,0x68fba531,0x2ca92532,0x2d87a533}},	//   sent_, _umud, nead_, rune_,
   {{0xff538b53,0x7d1ba534,0x291da535,0x6d5a82ec}},	//   _آخر_, rous, mowa_, _etta,
   {{0x2ca92536,0x63a000f2,0xdd008029,0x7d09a537}},	//   head_, _ämne, ētāj, snes,
   {{0x63ad2538,0x386da539,0x7d1ba53a,0x63a2a53b}},	//   hwan, _keer_, pous, _epon,
   {{0x63ad253c,0x0d848048,0x386d8079,0x23759459}},	//   kwan, _ілін, _jeer_, _فاتح,
   {{0x386d9302,0xb5fc84b7,0x63ad253d,0x7cee8362}},	//   _meer_, _reġi, jwan, _dùrd,
   {{0x386da53e,0x63ad253f,0x27328087,0x248d9e30}},	//   _leer_, dwan, când_, lgem_,
   {{0x1dbd88af,0xa928826f,0x291da540,0x09e581e5}},	//   ्मित, ližš, kowa_, _хойн,
   {{0x2ca90706,0x7afc06d4,0x6f1c016a,0x386d837a}},	//   gead_, _smrt, sorc, _neer_,
   {{0xfc3f04c3,0x291da541,0x63ad2542,0x2d832543}},	// [1460] _saír_, dowa_, gwan, arje_,
   {{0x29022544,0xe81f8740,0x78b60214,0x6b96016d}},	//   lika_, _बड़ा_, _hayv, rtyg,
   {{0xb87b0876,0x5ba880d4,0x399504e1,0x6edb01c6}},	//   chís, _कन्व, gås_, _החיפ,
   {{0x29020288,0x63ad2545,0x2fc001a3,0x3eaa0192}},	//   nika_, bwan, _krig_, lebt_,
   {{0x4cbb0051,0xdcfc0029,0x2d982546,0x6b898264}},	//   _הזכו, strē, ltre_, jueg,
   {{0x29022547,0x6d462548,0xb4b48105,0x6b842549}},	//   hika_, _hika, _छोड़_, mrig,
   {{0x2902254a,0x2d98254b,0x6d46254c,0x291da54d}},	//   kika_, ntre_, _kika, bowa_,
   {{0xe05591fb,0x94aa8bac,0x6eeb0201,0x6d4616f8}},	//   _قیمت_, стка_, _müba, _jika,
   {{0x2902254e,0x6d46254f,0x6b842550,0x7f4a826a}},	//   dika_, _mika, nrig, _طلاق_,
   {{0x6d462551,0x386d8a0f,0x61e1a552,0x248d83a7}},	//   _lika, _zeer_, fyll, agem_,
   {{0x29022553,0x63ad2554,0x6b8402af,0x6d5a8b64}},	//   fika_, zwan, hrig, _utta,
   {{0xc0580a4c,0x63ad0063,0x2fc0031d,0x6b840bbd}},	//   зір_, ywan, _brig_, krig,
   {{0x613f0029,0x3869808b,0xb4db0722,0x27328087}},	//   _jūli, ðari_, _diàl, pând_,
   {{0x4426a555,0x6d462556,0xa3c209a3,0xa3c00540}},	//   _iyo_, _aika, ्मन_, ंटन_,
   {{0x26da0698,0xcb138158,0x6d462557,0x2902028d}},	//   _dopo_, _אלס_, _bika, bika_,
   {{0x6d462558,0x44268365,0xe81e123a,0x2d8300f1}},	//   _cika, _kyo_, _युवा_, rrje_,
   {{0x2d9c1918,0x6d46059c,0xa87c0051,0x386d82a3}},	// [1470] _även_, _dika, _האחר, _reer_,
   {{0x63ad0578,0x6eef8022,0x7cea003e,0x291da559}},	//   rwan, _købe, _výra, wowa_,
   {{0x68ed07df,0x63ad255a,0x6d46255b,0x291da55c}},	//   _klad, swan, _fika, towa_,
   {{0xf1c00104,0xf77185ff,0x399500f2,0xddde001b}},	//   ương_, نات_, rås_, _nepř,
   {{0x68ed15d8,0x6eef813c,0x4426a55d,0x611200eb}},	//   _mlad, _løbe, _nyo_, nāla,
   {{0x386d81d8,0x6da5a55e,0x291da55f,0x6d4621ee}},	//   _weer_, дика, sowa_, _zika,
   {{0xfe708d4a,0x68ed046d,0x4426a560,0xc984246b}},	//   اده_, _olad, _ayo_, _пути,
   {{0x7d0d2561,0x44268e4d,0x29022562,0x61120ec3}},	//   nnas, _byo_, xika_, kāla,
   {{0x248da563,0x442682a0,0xdb1d2564,0x61e18114}},	//   rgem_, _cyo_, _arsé, wyll,
   {{0x6721803b,0x68ed2565,0x7cf12566,0x7d0d031d}},	//   _uklj, _alad, _hård, hnas,
   {{0x29022567,0x68ed0cda,0x60db8247,0x6f038098}},	//   tika_, _blad, _koum, minc,
   {{0x68ed2568,0x61e1a569,0x7d0d026c,0xe45f0106}},	//   _clad, ryll, jnas, _snön_,
   {{0x2902256a,0x61e18355,0x6d46256b,0xdb0f256c}},	//   rika_, syll, _rika, _escé,
   {{0x2d98256d,0x68ed256e,0x2902256f,0x7529a570}},	//   ttre_, _elad, sika_, llez,
   {{0xceb2878d,0xf7432571,0x29022572,0x31160a0e}},	//   כים_, теро, pika_, _офис,
   {{0xd1320b76,0x2d982573,0x7d0d007b,0x60dba574}},	//   _جمع_, rtre_, gnas, _noum,
   {{0x26da2575,0xeb972576,0xddc72577,0x442681c0}},	// [1480] _topo_, мит_, rajš, _xyo_,
   {{0x6d46009c,0xa01b2578,0x7c26016b,0x7d0d0706}},	//   _wika, rgöt, _vykr, anas,
   {{0x6d460341,0x6f03a579,0x644b81e8,0x810206a7}},	//   _tika, dinc, _oggi, _लगाओ_,
   {{0x6b84257a,0x61e30edd,0x236000f3,0xa3bf801b}},	//   prig, ønla, ppij_, ुमा_,
   {{0x4f579ec9,0x60db8bfe,0x6f03a57b,0x75298da8}},	//   وجود_, _doum, finc, dlez,
   {{0x644b8698,0x7d04257c,0x75228353,0x75298010}},	//   _aggi, liis, _skoz, elez,
   {{0x1ea980f7,0x7ae30009,0xa01b257d,0x4096a57e}},	//   ثاني_, önte, ngör, _орат,
   {{0x7529a57f,0x2902816d,0x44268683,0x629e2580}},	//   glez, _öka_, _pyo_, lfpo,
   {{0x3866a581,0x6f0385a3,0xdb04002a,0xd00781a1}},	//   mbor_, binc, lviñ, _жете_,
   {{0x68ed077b,0x6d5e003a,0x2b47809f,0x7d040079}},	//   _slad, _otpa, _cinc_, hiis,
   {{0x6d5ea582,0x68ed0022,0x7d042583,0x7cf1104a}},	//   ípad, _plad, kiis, _håre,
   {{0x80e080c8,0x4426a584,0x7cf11cab,0x63a61384}},	//   পোর্, _tyo_, _kåre, _opkn,
   {{0x68ed0289,0x7d0402a3,0x6d5e2585,0x59b0805e}},	//   _vlad, diis, _atpa, _जनवर,
   {{0xe8df801c,0x68ed2586,0x3f992587,0x69c101a1}},	//   _miền_, _wlad, rtsu_, _šlem,
   {{0x442d2588,0xc3488028,0xe8df801c,0x7d0d2589}},	//   _še_, _nổi_, _liền_, tnas,
   {{0x3998a58a,0x6f03a58b,0x7d04258c,0x30a704bd}},	//   més_, zinc, giis, _цркв,
   {{0xe667017a,0x3998a58d,0x6e2883ba,0x60dba58e}},	// [1490] _отно, lés_, _lydb, _roum,
   {{0x7d0d258f,0x4ac9000f,0x3f8687b1,0x35b52590}},	//   snas, राइव, drou_, _збор,
   {{0x6f03a591,0x7d042592,0x3998a593,0xa2c42594}},	//   vinc, biis, nés_, राज्,
   {{0x7d0401b4,0xa8158162,0x4f958087,0x61360144}},	//   ciis, ндеш, ерку, rálg,
   {{0x3f868ece,0x7cf100f2,0x39492595,0x399880e7}},	//   grou_, _vård, _mias_, hés_,
   {{0x39490282,0x8ca1809a,0x6d580036,0x6b8d0c53}},	//   _lias_, क्नो, _évac, muag,
   {{0x6f03a596,0x7bc2a597,0x60dba598,0xada5a599}},	//   rinc, _arou, _toum, хайл,
   {{0x6234259a,0x60c9a59b,0x39490069,0x3998a59c}},	//   _ресу, _unem, _nias_, dés_,
   {{0xa2c4016f,0x7bc2a59d,0x6136016b,0x7529890d}},	//   राच्, _crou, nále, rlez,
   {{0xa3c20c78,0x7529928a,0x394906ae,0xaad20b84}},	//   ्मत_, slez, _aias_, सायक,
   {{0x3949259e,0x3998a59f,0x2b47874a,0x290f8db1}},	//   _bias_, gés_, _vinc_, onga_,
   {{0x290f81e0,0x7bc284cc,0xf8bf003e,0x394925a0}},	//   nnga_, _frou, blém_, _cias_,
   {{0x394925a1,0x7bc2a5a2,0x2b47809f,0x7d042244}},	//   _dias_, _grou, _tinc_, viis,
   {{0xfbd08065,0x6136026f,0x2cad8079,0x3998a5a3}},	//   _ختم_, dále, leed_, bés_,
   {{0x18a615e3,0x64a625a4,0x399887e2,0x7d0425a5}},	//   _займ, нава, cés_, tiis,
   {{0x7cea0a56,0x2d878c41,0x290025a6,0x2cad81b4}},	//   _výro, irne_, _umia_, need_,
   {{0x7d0425a7,0x613625a8,0x6b9ba5a9,0xccf280be}},	// [14a0] riis, ráld, ntug, אכן_,
   {{0x7d0418dc,0x2cb90118,0x2cada5aa,0x39490282}},	//   siis, _easd_, heed_, _zias_,
   {{0x39490282,0x7cf1120b,0x8886a5ab,0x7d0425ac}},	//   _yias_, _såre, ележ, piis,
   {{0xa3c206a7,0x70538077,0x3f86a5ad,0xdd2f001b}},	//   ्मद_, هنما, trou_, pěšn,
   {{0x39988065,0x2d87a5ae,0x78a425af,0x3c7701c6}},	//   zés_, erne_, _mbiv, _אתכם_,
   {{0x290fa5b0,0x399880e7,0x7bc48110,0x7cf10b64}},	//   anga_, yés_, _šiuo, _våre,
   {{0xf9879e09,0x2cada5b1,0xc69300be,0x212b0114}},	//   _حب_, feed_, טאג_, ylch_,
   {{0xe8df8104,0x2cad8079,0x61469cae,0x7cee8362}},	//   _tiền_, geed_, _чеба, _bùra,
   {{0x02e401ce,0xdccf8028,0x394925b2,0x69c3a5b3}},	//   _गवाह_, _tỉnh_, _rias_, _arne,
   {{0x3998a5b4,0x7bc2a539,0x93fb03c8,0x78a425b5}},	//   tés_, _vrou, פליי, _abiv,
   {{0x0d868847,0x394925b6,0xb05b0338,0xfaa38048}},	//   _член, _pias_, ndäg, ушын,
   {{0x39989b0d,0xa3c21299,0xfc648bca,0x7bc2a5b7}},	//   rés_, ्मा_, _شخصی, _trou,
   {{0x3998a58d,0x394925b8,0xa30b8117,0xa2e69cf4}},	//   sés_, _vias_, _کرنے_, _подд,
   {{0x3998a5b9,0x8c4395d2,0x26de804f,0x9f35004a}},	//   pés_, _сече, _joto_, тегі,
   {{0x394910af,0x3eba25ba,0x62830511,0x7e7525bb}},	//   _tias_, _dapt_, ónom, razp,
   {{0x6b8d25bc,0x0ccf00ab,0x81d60264,0x7cf1006f}},	//   tuag, রস্ত, িনা_, _sårb,
   {{0x60cd02a0,0x3eba002e,0x26cca5bd,0x7d02826c}},	// [14b0] _inam, _fapt_, _ondo_, _mmos,
   {{0x78bd04fe,0x78a415db,0x26dea5be,0x6b8d25bf}},	//   ldsv, _zbiv, _noto_, ruag,
   {{0x2cad82c1,0xab5b02af,0x290f8bb1,0x7d02a5c0}},	//   yeed_, _grün, tnga_, _omos,
   {{0x82341301,0x78bd0bcb,0xa95400e8,0xd47900be}},	//   اركا, ndsv, укці, _קאָל,
   {{0x27e68065,0x78bd0fb0,0x60cd004f,0x26dea5c1}},	//   gyon_, idsv, _mnam, _boto_,
   {{0x7d02a5c2,0xe8df8028,0x752d25c3,0x26de8333}},	//   _amos, _biển_, llaz, _coto_,
   {{0x30a7a5c4,0xa8a799bb,0x62340ca0,0x387f808e}},	//   _прав, _прак, _беру, _tdur_,
   {{0x6b9ba5c5,0x7cf58661,0x09e480ab,0x81c88264}},	//   ttug, _márg, _ফেভা, োনা_,
   {{0x249fa5c6,0x2cada5c7,0xf69984ae,0x69dca5c8}},	//   rfum_, reed_, _овај_, ären,
   {{0x6b9ba5c9,0x60cd25ca,0x78bba5cb,0x752d23d8}},	//   rtug, _anam, _hauv, hlaz,
   {{0x3f8fa5cc,0x6723822b,0x6b9ba5cd,0x60cd0144}},	//   lugu_, monj, stug, _bnam,
   {{0x6723a5ce,0x60cd0362,0xa3d1001b,0x69c382d4}},	//   lonj, _cnam, वमा_, _vrne,
   {{0x3ae4016d,0x78bb80e7,0xe29983a7,0x442b25cf}},	//   _köpt_, _mauv, _жал_, _nyc_,
   {{0x290680ad,0x6d4ba5d0,0x60cd25d1,0x6723a5d2}},	//   zioa_, _higa, _enam, nonj,
   {{0x3f8f8578,0x6d4ba5d3,0x27e6942a,0x752d25d4}},	//   hugu_, _kiga, zyon_, flaz,
   {{0x6d4b8300,0x3f8fa5d5,0xfbe700ff,0x7cfea5d6}},	//   _jiga, kugu_, _thể_, tūri,
   {{0x6d4ba5d7,0x69c1a5d8,0x032625d9,0x442b00ee}},	// [14c0] _miga, lvle, вдан, _cyc_,
   {{0x6d4ba5da,0x394a026f,0x3f8fa5db,0x6b89802a}},	//   _liga, _časy_, dugu_, ireg,
   {{0xe2971a97,0x26dea5dc,0x6723a5dd,0x752d25de}},	//   тах_, _roto_, donj, blaz,
   {{0x26dea5df,0x6b8980f3,0xe78681e2,0xa9670adb}},	//   _soto_, kreg, вуко, тица_,
   {{0xa2b2835a,0x26dea5e0,0xa8570039,0x752425e1}},	//   _असल्, _poto_, דינה_, moiz,
   {{0x6b898620,0x6723a5e2,0x57fb0039,0x7bc6022b}},	//   dreg, gonj, ולנו, _irku,
   {{0x27e6a5e3,0x6d4ba5e4,0xe29725e5,0x7bc081c0}},	//   syon_, _biga, _шар_, wvmu,
   {{0x399c0722,0x6abc25e6,0x6b89a5e7,0x753982d6}},	//   mís_, _harf, freg, _chwz,
   {{0x26de803e,0x6d4b859e,0x6b89a5e8,0x6abc00a4}},	//   _toto_, _diga, greg, _karf,
   {{0x613184b8,0x78bb805c,0x60cd25e9,0x78a2a5ea}},	//   håll, _zauv, _snam, lfov,
   {{0xa2c30f21,0x399c25eb,0x6abc25ec,0x68e0a5ed}},	//   रयत्, nís_, _marf, _komd,
   {{0x6d4b84a7,0x7bc625ee,0x7cf581ca,0x92ae00ab}},	//   _giga, _orku, _cárd, কায়_,
   {{0xe9ff8104,0x399c00f7,0x7bd601c0,0x53b6a5ef}},	//   _phải_, hís_, jxyu, _अनिश,
   {{0x6d4ba5f0,0x3d9525f1,0x28a4864a,0x659525f2}},	//   _ziga, лигр, _गॉसि, лагу,
   {{0x5e58035f,0x7bc625f3,0x2904a5f4,0x09e384bd}},	//   тися_, _arku, _omma_, _војн,
   {{0x5183a5f5,0x60cd25f6,0xc9838468,0x399c25f7}},	//   _туша, _unam, _туши, dís_,
   {{0x6d408009,0x6abc25f8,0xe9ff80ff,0x6d580866}},	// [14d0] imma, _barf, _thải_, _évan,
   {{0x2904a5f9,0x78bb82be,0xe8df8028,0x61360125}},	//   _amma_, _sauv, _miễn_, mála,
   {{0x6abc25fa,0xce330bca,0x22470884,0xd36680d7}},	//   _darf, _خودک, änk_, _گه_,
   {{0xf8bf25fb,0xfc640698,0x3f8fa5fc,0xfc3f06a5}},	//   ndé_, _върн, tugu_, _maíz_,
   {{0xd3668154,0x70848048,0x6abc25fd,0x6d4ba5fe}},	//   _ده_, ргіз, _farf, _riga,
   {{0x6d4b883a,0x6abc25ff,0x7e7880eb,0x539a04de}},	//   _siga, _garf, gavp, _אישו,
   {{0x613600f7,0x399c2600,0xdcef81a1,0x6d4ba601}},	//   hála, cís_, _žeđa, _piga,
   {{0x6b89a602,0x2602816f,0xe3b9a523,0x69c7008e}},	//   treg, _वेळी_, еби_, _irje,
   {{0x6d4ba603,0x6723a604,0x032581cf,0xecc50264}},	//   _viga, ponj, лдин, _একাড,
   {{0x6b89a605,0xe8df8104,0x61e8831d,0x645ba606}},	//   rreg, _diễn_, fydl, scui,
   {{0x04959e7b,0x394d8b3c,0x6d4ba607,0x7c2b809a}},	//   _ملاح, _kies_, _tiga, _wygr,
   {{0x6b898e67,0x69c1a608,0xa6e28125,0x2d910234}},	//   preg, rvle, _öðru, duze_,
   {{0x7d09a609,0x394d9405,0xfaa5a60a,0x7524007d}},	//   mies, _mies_, _бало, voiz,
   {{0x272981df,0x69c7260b,0xe299a60c,0x24990122}},	//   múns_, _orje, _чак_, _acsm_,
   {{0x52398158,0xd33681c6,0x26ca8118,0x2d91260d}},	//   _אײַנ, _גרסה_, _óboe_, guze_,
   {{0x7d09a60e,0x399c260f,0x394d84b7,0xa3c00540}},	//   nies, vís_, _nies_, ंटल_,
   {{0x42ca02df,0x4ab7835a,0x7cf5a610,0x2d8a026c}},	// [14e0] нган_, _असाव, _kárb, srbe_,
   {{0x80a005e8,0xe2970087,0xa3d48063,0x2cbd8282}},	//   ग्रे, лау_, हमत_, _lawd_,
   {{0x6abc2611,0x869b012a,0x8cbf0327,0x7ce30074}},	//   _varf, _אייז, _लोको, _võrr,
   {{0x399c2321,0x2cbd822c,0x6ae0801b,0x50ba8199}},	//   rís_, _nawd_, _पक्र, عداد_,
   {{0xb8dc9d2a,0x394da612,0xdee6a613,0x7d09a614}},	//   _अस_, _dies_, лоди, dies,
   {{0x2d808029,0xd5ba9324,0x3f598580,0x394d821e}},	//   ņiem_, еси_, _dèu_, _eies_,
   {{0x7d09a615,0xc693025f,0x69c705f3,0xd13281a8}},	//   fies, צאה_, _grje, _همس_,
   {{0x2904a616,0xfc3f05e4,0x7d09a617,0x62838114}},	//   _umma_, _raíz_, gies, _adno,
   {{0x4e968307,0x2729862f,0xd2508013,0x12e68071}},	//   _مشار, gúns_, ينة_, гінг,
   {{0x7cf804c3,0x61e8816d,0xe8df801c,0x61360019}},	//   _fírg, tydl, _viễn_, vála,
   {{0x7d09a618,0x391524b2,0x6eef83ba,0x28f92619}},	//   bies, имор, _møbl, вень_,
   {{0x2d9102a0,0x8c3d802e,0x3ebe80e8,0x7d09a61a}},	//   vuze_, teşt, _hatt_, cies,
   {{0x8cbf0063,0xead48678,0x3ebea61b,0xf8bf261c}},	//   _लोगो, _воль, _katt_, rdé_,
   {{0x8c3d802e,0x43839e09,0x613600f7,0xef1f07c0}},	//   reşt, _الوق, rála, mrük_,
   {{0x6136261d,0x8c3d802e,0x6d5802be,0x4a5b83c8}},	//   máln, seşt, _éval, _אדוו,
   {{0x69c700f1,0x628a0511,0xdb1981ec,0xa99b81c6}},	//   _rrje, ófon, _erwä, _נבחר,
   {{0xe8df8104,0x3a750087,0x1bd40081,0xa3e48075}},	// [14f0] _hiện_, илар, ботя, नहि_,
   {{0x6136037d,0xe8df8028,0x7d0986d7,0x3ebe8b64}},	//   náln, _kiện_, zies, _natt_,
   {{0x38600125,0xc3338051,0xa2c9016f,0x28c6904f}},	//   _yfir_, צוע_, _होण्, _रोहि,
   {{0x290b04ef,0x7cf58019,0x80d80beb,0x2fc901b0}},	//   nica_, _márc, याये, _krag_,
   {{0x394da61e,0xdb0f05e4,0x7d09a61f,0x61362620}},	//   _vies_, _escá, vies, káln,
   {{0x236902ee,0x7d09a621,0x2cbd81de,0xb4db0229}},	//   mpaj_, wies, _sawd_, _bhàg,
   {{0x7d09a622,0x1dc58697,0x45199bcf,0x6d4f10e1}},	//   ties, विधत, кция_, _kica,
   {{0x2bc912ee,0xa2c9016f,0x6d570079,0x7cf81520}},	//   रिपा, _होत्, _muxa, _vírg,
   {{0x6e95a623,0x3ebe81b9,0x3ced9b49,0x2fc901c0}},	//   _визу, _fatt_, rkev_, _nrag_,
   {{0x6d4f01c5,0x7d09a624,0x7cf5988b,0x4255824b}},	//   _lica, sies, _bárc, штит,
   {{0x290b2625,0x7cf80065,0x6b8d08b3,0x7cf585e4}},	//   fica_, _híre, hrag, _cárc,
   {{0xe8df8028,0x61fa0006,0x6fdc80ab,0xe0462626}},	//   _diện_, _ütle, _মেয়ে, инни,
   {{0xf36792b2,0x08360678,0x61360c83,0x69dc8257}},	//   _стен, рхня, báln, ører,
   {{0xfc3f046d,0x7d0600ee,0x7cf801a8,0x2fc92627}},	//   _abío_, _smks, _míre, _drag_,
   {{0x7ae38307,0x6d4f1258,0x649a2628,0x2d9e00e7}},	//   _iont, _bica, ктар_, îte_,
   {{0x6b8d2629,0xb4e3816f,0xa2cd816f,0x05550012}},	//   frag, _नको_, ताक्, стря,
   {{0x6d4f262a,0xdbd98187,0x61360019,0x42561df3}},	// [1500] _dica, _açúc, lálo, атет,
   {{0x8ccc8063,0x68e40406,0x6d57002a,0xff7b00be}},	//   _दोनो, _hoid, _fuxa, _שטימ,
   {{0x6d4f00a9,0x613614b5,0x442f8084,0x3ebea126}},	//   _fica, nálo, _lyg_, _ratt_,
   {{0x7ae3a62b,0xdbdc003e,0x3ead0024,0x3ebe83e5}},	//   _lont, lšíc, đete_, _satt_,
   {{0x3ebe822b,0xc7a3964f,0x3869a62c,0x684a0196}},	//   _patt_, жичк, ñara_, būdž,
   {{0x7ae3a62d,0x7cf80013,0x290b002e,0xdfcf80f7}},	//   _nont, _díre, zica_, بيه_,
   {{0x442f808e,0x6ef48a2a,0x7cf80174,0x6d4f09ae}},	//   _ayg_, _càba, _tírd, _yica,
   {{0x290b062f,0x7ae3861f,0x3ea0801b,0x628303f2}},	//   xica_, _aont, řit_, ónov,
   {{0x2bc91a4d,0x6136003e,0x60c2a62e,0x3ebe80e8}},	//   रिया, táln, mdom, _tatt_,
   {{0xdbdc026f,0x60c28110,0x3958262f,0x68e42630}},	//   jšíc, ldom, _kurs_, _aoid,
   {{0x60c089ab,0x61362631,0x7ae3a632,0x7e7700b9}},	//   _kamm, ráln, _dont, _rexp,
   {{0xb35689d7,0x03a68767,0x68e404c3,0x60c0a633}},	//   _پیدا_, _видо, _coid, _jamm,
   {{0x6d4f2634,0xe8010a43,0x7cf10b40,0x68e40187}},	//   _rica, _लेखा_, _dårl, _doid,
   {{0xe8df8028,0x6d4f2635,0x6b8d2636,0x6d57247a}},	//   _tiện_, _sica, vrag, _puxa,
   {{0xe5c40af2,0x5bb68ebf,0x13b699eb,0xab5b2637}},	//   осто, _अनुव, _अनुभ, _trük,
   {{0x2fc68025,0x60c0a638,0x987515d1,0xb4c10074}},	//   kvog_, _namm, _улиц, ंये_,
   {{0x56952639,0xa2cb8072,0x7cf58061,0xdd2f128a}},	// [1510] _лапт, _थोड्, _jára, _těžb,
   {{0x6b8d263a,0x60c08df6,0xf9c71ff8,0x6d4f263b}},	//   rrag, _aamm, ищен, _wica,
   {{0x3958263c,0x6d4f263d,0x60c08c2e,0xb4db263e}},	//   _curs_, _tica, _bamm, _diàr,
   {{0x6b82803a,0x60c2904a,0x60c0a63f,0x39582640}},	//   _ovog, gdom, _camm, _durs_,
   {{0x7d0d009a,0x7cf58a21,0x23668282,0x60c0888b}},	//   mias, _nára, _ntoj_, _damm,
   {{0xaf0480e8,0x39582641,0x442fa642,0x60c28035}},	//   опіл, _furs_, _ryg_, adom,
   {{0x7ae3a643,0x6b8281df,0x29090009,0x645a0087}},	//   _ront, _avog, _omaa_, _ştii,
   {{0x7d0d0048,0x61360061,0x201e0087,0xeb999ae7}},	//   nias, gáll, ştii_, гии_,
   {{0x7ae3a644,0x69ca831d,0xb4db0706,0x57f583a7}},	//   _pont, _arfe, _ghàe, _упат,
   {{0x81e280c8,0x7d0d2645,0x61360510,0x6b828289}},	//   _নেই_, hias, tálo, _dvog,
   {{0x68e42646,0x7e7c007b,0x7ae3a647,0x60c0a648}},	//   _poid, varp, _vont, _yamm,
   {{0x5f0503bb,0x7ae38288,0x26d301df,0x673e00f1}},	//   होस्_, _wont, _anxo_, _shpj,
   {{0x68e40009,0x7e7c2649,0x6b65946c,0x69ca874c}},	//   _void, tarp, _укла, _erfe,
   {{0x7afaa64a,0x60c2a64b,0x61fb09ab,0x613d264c}},	//   chtt, zdom, _ƙull, véle,
   {{0xf8bf040e,0x99858624,0xa2db264d,0x61462167}},	//   glés_, _البو, नान्, _лека,
   {{0x6ab78a74,0x3d08016f,0x2b59002a,0x7e7c039c}},	//   _असुर, _सगळे_, _busc_, sarp,
   {{0x6d44264e,0x60c08e51,0x7cfc8065,0xdbdc026f}},	// [1520] rmia, _ramm, _férf, pšíc,
   {{0x60c08f06,0x3f820052,0x6d44264f,0x212d8077}},	//   _samm, msku_, smia, _akeh_,
   {{0x7cf807a3,0x7d0d2650,0xc879880a,0x394001c0}},	//   _círc, bias, _beş_, _khis_,
   {{0x60c2a651,0x03a61630,0x27328087,0x2bbc82f1}},	//   udom, _лимо, mâni_, ्टमा,
   {{0x3f822652,0x44240028,0x81e600ab,0xbbb6824c}},	//   nsku_, _âm_, _বেশ_, _अनेक,
   {{0xb8ef901b,0x63a42653,0x3ce0011a,0xe3e88019}},	//   _वो_, mtin, ljiv_, یکشن_,
   {{0x7bcba654,0xa3c2000c,0x6b82a655,0x60c088e5}},	//   _argu, ्मक_, _svog, _tamm,
   {{0xdb1d016d,0x18a38468,0x3ce0011f,0x26c30267}},	//   _ersä, _насм, njiv_, zdjo_,
   {{0x3f820025,0x241881bb,0xda7a9ef7,0xe73a8073}},	//   jsku_, ропы_, лян_, _беа_,
   {{0x3f82005c,0x4ace0327,0x3f5d00ff,0x27f98074}},	//   dsku_, _होमव, _rìu_, _üsna_,
   {{0x63a42656,0xd2508c48,0x7bcba657,0x68fd03ed}},	//   htin, بند_, _ergu, ërdo,
   {{0x3a370051,0x63a42658,0x6b828042,0x463b80be}},	//   מרים_, ktin, _tvog, _געבע,
   {{0x6d5aa659,0x7bcb811f,0x3946a272,0xc1a50778}},	//   _huta, _grgu, imos_, _गङ्ग,
   {{0x6d5aa65a,0x61360019,0xdb1d0187,0x28cfa594}},	//   _kuta, nálj, _essê, _सोनि,
   {{0xc27b893f,0x6d5a8304,0x3ce6822c,0x2b59026c}},	//   _גרוי, _juta, _koov_, _susc_,
   {{0x6d5aa65b,0x26c1018e,0xdb060019,0xa4f102d0}},	//   _muta, _waho_, _eskü, _dışı_,
   {{0x28d61a42,0x63a4265c,0x3ce6a65d,0x26c1265e}},	// [1530] धारि, gtin, _moov_, _taho_,
   {{0x629aa65f,0x7d0d2660,0xda670013,0x39468876}},	//   ngto, sias, صائي, emos_,
   {{0x7cfc8117,0xb9b50872,0x6d5aa661,0x9962026f}},	//   _kérd, تماع, _nuta, _píše_,
   {{0x3835a662,0x212b2663,0xd011803f,0xb4db0362}},	//   онер, noch_, ولا_, _dhàc,
   {{0x6d5aa664,0x656880f1,0x63a42665,0x7d1d01ed}},	//   _auta, _atdh, ctin, _ijss,
   {{0x6d5aa666,0x39838214,0x7cf58333,0x212b2667}},	//   _buta, yıs_, _cárn, hoch_,
   {{0x78ad0025,0x6d5a80a4,0x2d832668,0x212b01ac}},	//   _obav, _cuta, nsje_, koch_,
   {{0x3f8201b4,0x6d5a8314,0x2d8301ed,0x212b01d6}},	//   ysku_, _duta, isje_, joch_,
   {{0x212b2669,0xeab99da6,0x290fa66a,0x7529a66b}},	//   doch_, айп_, miga_, roez,
   {{0x290fa66c,0xf6f5817e,0xdb1d016d,0x78ad266d}},	//   liga_, _بزرگ, _ursä, _abav,
   {{0xd946266e,0x6d5aa66f,0xf7488013,0x7ae70669}},	//   жени, _guta, _اللي_, _mojt,
   {{0x63a42670,0x3f82003a,0x290fa671,0xa4f7803d}},	//   ytin, tsku_, niga_, _دکتر_,
   {{0x3f8403cb,0xe73a2672,0x7cf58019,0xbbeb803f}},	//   ému_, ием_, _háro, _حرام_,
   {{0x7f5b82a3,0x3f822673,0x290fa674,0x7cf58019}},	//   _muuq, rsku_, higa_, _káro,
   {{0x3940073a,0xdd920277,0x7bc9a675,0x290fa676}},	//   _this_, ظور_, lveu, kiga_,
   {{0x63a42677,0x3f820067,0x4c6a2678,0x212b2679}},	//   ttin, psku_, риан_, coch_,
   {{0x290fa67a,0x63a4267b,0x6ef00074,0x130a0110}},	// [1540] diga_, utin, _läbi, анай_,
   {{0x63a4267c,0x2d91009a,0xdcfc00eb,0x78ad267d}},	//   rtin, brze_, turē, _zbav,
   {{0x7cf5803e,0x5bb6800d,0x60c4267e,0xfce6267f}},	//   _náro, _अन्व, _kaim, _доно,
   {{0x6d5aa680,0x63bb8870,0x63a42681,0xeb9a0c9d}},	//   _ruta, kwun, ptin, _ким_,
   {{0x3946a682,0x60c42683,0x6d5aa684,0xdb0406a8}},	//   rmos_, _maim, _suta, ntië,
   {{0x39469313,0x6d5aa685,0x24802686,0x60c42687}},	//   smos_, _puta, laim_, _laim,
   {{0x2d982688,0x290fa689,0x6b84268a,0x7cfc83a8}},	//   nure_, biga_, lsig, _lére,
   {{0x443d82af,0x3eb801ec,0x6d5ca68b,0x290fa68c}},	//   _bzw_, hert_, _éram, ciga_,
   {{0x3eb8268d,0x6b84268e,0xa686838d,0x14a68d72}},	//   kert_, nsig, _млад, क्षण,
   {{0x6d5aa68f,0x61360019,0x2d982690,0x212b01ec}},	//   _tuta, lálh, kure_, woch_,
   {{0xa2db1a42,0xd62a8009,0x7cfca691,0x3eb82692}},	//   नात्, _тоже_, _pérd, dert_,
   {{0x60c4051e,0x613d007b,0x61360019,0x69c88106}},	//   _caim, féla, nálh, rvde,
   {{0xd83b01e5,0x60c42693,0x6b840042,0x7cf585b9}},	//   рэн_, _daim, jsig, _záro,
   {{0x6b842694,0x290f8f8e,0x2d83090d,0x3eb801e3}},	//   dsig, ziga_, tsje_, gert_,
   {{0x290fa695,0x6d42801c,0x7ae72696,0x2d982697}},	//   yiga_, _khoa, _rojt, gure_,
   {{0x24f80fe6,0x245802c7,0x7aea80eb,0x290fa698}},	//   онсы_, жать_, žotā, xiga_,
   {{0x20020063,0x7cfc80e7,0x69de2699,0x290fa69a}},	// [1550] czki_, _gére, expe, viga_,
   {{0x3eb807f1,0xdb040036,0x2d980a03,0x28ac06a7}},	//   cert_, ntiè, bure_, ट्ठि,
   {{0x7ae7269b,0x80b000c8,0x6b8418dc,0x6d35269c}},	//   _vojt, য়ার্, asig, _неоф,
   {{0x52b7a69d,0x02b783ca,0x6b840079,0x7cf8002a}},	//   _अस्स, _अस्न, bsig, _tíra,
   {{0x290fa69e,0x3f99269f,0x69ce26a0,0x6b840079}},	//   riga_, nusu_, _erbe, csig,
   {{0x290fa6a1,0x6d429fe7,0x7cf5a6a2,0xed5986c8}},	//   siga_, _ahoa, _páro, бок_,
   {{0x3f9900f6,0x290f822e,0x2bc90f97,0x6d428362}},	//   husu_, piga_, रिवा, _bhoa,
   {{0x7cf58065,0xd5ae80f7,0x6136016b,0x7bcf01a1}},	//   _váro, افي_, rálk, _krcu,
   {{0x2d9826a3,0x2d98816d,0x3ec48009,0x48fa80be}},	//   zure_, _åren_, östä_, _פּלא,
   {{0x613626a4,0x60c426a5,0x7bc980e7,0x613d26a6}},	//   máli, _saim, rveu, véla,
   {{0x3eb826a7,0x7c2280ee,0x60c426a8,0x7bc9826c}},	//   vert_, _exor, _paim, sveu,
   {{0x3ea126a9,0x3eb802af,0x7cfc91b9,0x6b8426aa}},	//   _acht_, wert_, _pére, ysig,
   {{0x26c5835a,0xe28ea6ab,0x68e9998b,0x3eb826ac}},	//   _kalo_, _па_, _moed, tert_,
   {{0xb8f305e8,0x2d9826ad,0x26c58a6e,0x60c426ae}},	//   _हो_, ture_, _jalo_, _waim,
   {{0x26c58b5d,0x6281a6af,0x60c426b0,0x57b8809a}},	//   _malo_, malo, _taim, _इन्ह,
   {{0x3ea126b1,0xab66076a,0x7d1ba6b2,0x3eb8035f}},	//   _echt_, звал, nnus, sert_,
   {{0x7cfc8c52,0x24800c5e,0x2d982320,0x6d498c41}},	// [1560] _hérc, raim_, sure_, imea,
   {{0x2d980098,0x6b8426b3,0x26c5a6b4,0x6d4981a8}},	//   pure_, rsig, _nalo_, hmea,
   {{0x68fba6b5,0x68e9831e,0x14bd824c,0xdb040144}},	//   _blud, _boed, ्याण, ntié,
   {{0x7cfc862f,0x7cf58019,0x7e7e26b6,0x00e68009}},	//   _mérc, _bárm, _hepp, яжен,
   {{0x7e7e007b,0x26c5a6b7,0x68e281b9,0x68e98114}},	//   _kepp, _balo_, rjod, _doed,
   {{0x6d5e26b8,0x62818503,0x6daa8201,0xf1db89c2}},	//   _kupa, jalo, _fəal, यमान,
   {{0x434326b9,0x6281a6ba,0xbb4326bb,0x69da00e1}},	//   _черв, dalo, _черк, _štef,
   {{0x68e9a6bc,0x7e7e26bd,0x7cf59986,0x7d1ba6be}},	//   _goed, _lepp, _fárm, gnus,
   {{0x6d5e26bf,0x26c5a6c0,0x613612ca,0x38668118}},	//   _lupa, _falo_, cáli, mcor_,
   {{0x6281a6c1,0xe3afa6c2,0x26c5a6c3,0x6d42a6c4}},	//   galo, اري_, _galo_, _whoa,
   {{0xd48fa6c5,0x386d0876,0x672e0353,0x3f86a3be}},	//   _пр_, ñero_, dobj, lsou_,
   {{0x64a68048,0x26c5a6c6,0x3f9926c7,0xdca6a6c8}},	//   _хада, _zalo_, tusu_, _хади,
   {{0x6d5e26c9,0xddc8826c,0x7e7e01e8,0x3f86a6ca}},	//   _aupa, _jedž, _bepp, nsou_,
   {{0xb4db26cb,0xddc881e2,0x628a813c,0x6d5e0e60}},	//   _chàn, _medž, _udfo, _bupa,
   {{0x28dd0663,0xa2a1816f,0x3f9926cc,0x7e7e26cd}},	//   यादि, _खात्, susu_, _depp,
   {{0x2eb9823c,0x645a0087,0x291ca6ce,0x5d5422b1}},	//   _इस्त, _ştir, éval_, екст,
   {{0x68e98355,0x201e07d9,0xddc888ae,0x3f86801b}},	// [1570] _roed, ştir_, _nedž, jsou_,
   {{0x68fb80eb,0x7cf80019,0x79850234,0x7bcd8084}},	//   _slud, _hírl, tshw, _šauk,
   {{0x68fba6cf,0xaaae8bc2,0x68e9a6d0,0xf1c201a9}},	//   _plud, ज्यक, _poed, jušā_,
   {{0x26c580a4,0xf9901dd2,0x613626d1,0x7e7e26d2}},	//   _salo_, ابل_, táli, _zepp,
   {{0x2b9319f7,0x68e985f8,0x7e7e04e6,0x37ab938c}},	//   _سیاس, _voed, _yepp, стен_,
   {{0xe8da00a5,0x2bb68105,0xddc88267,0x68e98cfa}},	//   _बच्च, _अनजा, _dedž, _woed,
   {{0x68e9a6d3,0x7cf80144,0x7bc28176,0x27328162}},	//   _toed, _oírl, _asou, vânt_,
   {{0xddc8826c,0xed568098,0x69da0088,0x68fb82d0}},	//   _fedž, мощ_, _šteg, _ulud,
   {{0x6d4984bc,0x26c5a6d4,0xa2a18aed,0xddc8a6d5}},	//   rmea, _talo_, _खाद्, _gedž,
   {{0xff5380f7,0x386926d6,0x3cff8901,0x6d49a17a}},	//   _أخر_, _afar_, shuv_, smea,
   {{0x387f800b,0x7bc2a6d7,0x7aeaa6d8,0x7cee851e}},	//   _keur_, _esou, _doft, _cùrs,
   {{0x6281a6d9,0x6d5e26da,0xc689007c,0xdb040020}},	//   salo, _rupa, _כא_, rtié,
   {{0x6d5e26db,0x387fa6dc,0xfaa59612,0x69dc8338}},	//   _supa, _meur_, _жало, ärer,
   {{0x387f83d3,0x3cfd81c0,0x2bbc801b,0x6ef48362}},	//   _leur_, _hlwv_, ्टरा, _càbh,
   {{0x63a9a6dd,0x64a626de,0x7cfca6a6,0xe7371505}},	//   lten, мава, _héra, фер_,
   {{0x249f8125,0x205626df,0x7cf826e0,0x6eef8366}},	//   ngum_, _отпр, _víro, _købs,
   {{0xb4db0142,0xe8df8104,0xb4be009a,0x7e7e26e1}},	// [1580] _thàn, _chọn_, _इसी_, _tepp,
   {{0x6138a6e2,0xb0c68aad,0x2d878aa2,0x63a9a6e3}},	//   míli, _रोजग, ksne_, iten,
   {{0xddd882a5,0x63a9a6e4,0x80a5103e,0x2d878c18}},	//   kavš, hten, _कामे, jsne_,
   {{0x7cf5801b,0x63a9a6e5,0x69c381a1,0x0cd88264}},	//   _dárk, kten, _msne, _তত্ত,
   {{0x387fa6e6,0xddd882a5,0x6ef48722,0x3866a6e7}},	//   _deur_, davš, _hàbi, rcor_,
   {{0x386687d0,0x6136007b,0xbd6aa6e8,0x6b9ba6e9}},	//   scor_, málu, орие_, duug,
   {{0x63a9802e,0x94188201,0xf9878117,0xceb30039}},	//   eten, ərə_, _جب_, דיו_,
   {{0x7aea96f7,0x387fa6ea,0x67211809,0x2ca026eb}},	//   _soft, _geur_, člji, ngid_,
   {{0x63a9a6ec,0x7aea8087,0x7cfc8036,0x290201b4}},	//   gten, _poft, _céra, dhka_,
   {{0x7aea80f1,0x78a403a8,0x69c80118,0x7cfc8036}},	//   _qoft, _aciv, _ádes, _déra,
   {{0xb4db0362,0x611c82d4,0x612802d0,0xdee38081}},	//   _bhàl, včlj, kıld, _шофи,
   {{0x61e3016d,0x63a9a6ed,0xb4db0362,0x6cd3a6ee}},	//   änli, bten, _chàl, _لقما,
   {{0x628e26ef,0x69c3a6f0,0x63a9a6f1,0x7cfca6f2}},	//   _odbo, _esne, cten, _géra,
   {{0xaff980be,0x4426a6f3,0xa3d2175d,0x2fd226f4}},	//   פּרי, _ixo_, विन_, _dryg_,
   {{0x6d46008e,0x9e341be4,0xe93b07c3,0xb4db0362}},	//   _bhka, верч, _وسعت_, _fhàl,
   {{0x3ea98668,0x2b5826f5,0x628e0114,0x26da06c4}},	//   đati_, _airc_, _adbo, _enpo_,
   {{0x6138a6f6,0x7cfc8118,0x2b5800c3,0xa87c01c6}},	// [1590] cíli, _xéra, _birc_, _ואחר,
   {{0x2d8506a5,0x7bcd156e,0x28dd1869,0x31670118}},	//   áles_, rvau, यावि, ínzo_,
   {{0x63a9a6f7,0x387f80e7,0x2d9ca6f8,0x68ed011b}},	//   zten, _peur_, juve_, _koad,
   {{0x78bd26f9,0x63a9a6fa,0xf77180a0,0x09b100ab}},	//   nesv, yten, هات_, ছিলা,
   {{0x6d4d26fb,0x2b580118,0x645d0420,0x68ed033e}},	//   mmaa, _firc_, _igsi, _moad,
   {{0xd246a6fc,0x6d4d26fd,0x68ed26fe,0x61360019}},	//   _من_, lmaa, _load, lált,
   {{0x628526ff,0x6138a700,0xddd8811f,0x442682df}},	//   maho, zíli, tavš, _axo_,
   {{0xd658004c,0x62852701,0x6d4d06d9,0x61360019}},	//   ויות_, laho, nmaa, nált,
   {{0x3834a702,0x60dba703,0x7522826c,0x249fa704}},	//   _антр, _inum, _djoz, rgum_,
   {{0x62852705,0xe3c88028,0x7cf5a706,0x6442826c}},	//   naho, _dự_, _mári, _dzoi,
   {{0x44392707,0xc332010f,0x442690e4,0x7cf581a8}},	//   _lys_, רוי_, _exo_, _lári,
   {{0xcea9004c,0xb4be2708,0x7cfca709,0x68ed040d}},	//   _לי_, _इसे_, _hérn, _coad,
   {{0xb8e80063,0x68ed1d64,0x6285270a,0x6d59820d}},	//   _उस_, _doad, kaho, _iiwa,
   {{0x6d46020f,0x6561a70b,0x2902270c,0x6d59a70d}},	//   _shka, _kulh, shka_, _hiwa,
   {{0x65618073,0x6d59a70e,0x6138a70f,0x386b00f7}},	//   _julh, _kiwa, síli, éirí_,
   {{0x656180a9,0x6d4d2710,0x6b962711,0x6d598458}},	//   _mulh, gmaa, tryg, _jiwa,
   {{0x44260003,0x7cf5a712,0x6128080a,0xf1c9801c}},	// [15a0] ço_, _cári, rıld, _hạ_,
   {{0x60dba713,0x28ac2714,0x6d599110,0xa8570039}},	//   _anum, ट्रि, _liwa, _איפה_,
   {{0x753b826f,0x29002715,0x5ec880ab,0x61280457}},	//   kluz, _klia_, লামে, pıld,
   {{0x6d59a716,0x6d4d0079,0x60c9816a,0x6d460198}},	//   _niwa, cmaa, _caem, _uhka,
   {{0xf1c9801c,0xe73a9505,0x62852717,0x087700be}},	//   _lạ_, пед_, baho, גענט_,
   {{0x8f9b00be,0xe5c6a18e,0x6d5984b9,0xe8020d86}},	//   פיצי, есио, _aiwa, रैया_,
   {{0xe3c88104,0xaa430adb,0x2bd28f12,0x6d5998a8}},	//   _sự_, _берл, तिभा, _biwa,
   {{0x2d9815a0,0x6d59a718,0x60c9808e,0xed5784ae}},	//   irre_, _ciwa, _gaem, ној_,
   {{0x53c904e5,0xd90d8416,0x6b898073,0xe8b5817b}},	//   रिएश, _بین_, gseg, lışı,
   {{0x68ed002a,0xf1c980ff,0x291203f7,0x23d283ca}},	//   _soad, _bạ_, _amya_, तिबद,
   {{0xf8dd10be,0xe8b588c5,0x7d040234,0x13170039}},	//   यालय, nışı, khis, תחיל_,
   {{0xe3c88104,0x78a2827f,0x7d042719,0x6b89a71a}},	//   _tự_, ngov, jhis, bseg,
   {{0x66f48076,0x04578013,0x7d04271b,0x6285271c}},	//   _अवाक_, _كلمة_, dhis, yaho,
   {{0x3ea50019,0x4439271d,0x6d599fa4,0x1ee7003d}},	//   ült_, _rys_, _ziwa, روزی_,
   {{0x7bc600f1,0x6d4d271e,0x645d0122,0x29000144}},	//   _asku, tmaa, _pgsi, _flia_,
   {{0x7d04271f,0xf98f9c2c,0x23b79094,0x9a3b8039}},	//   ghis, _ابو_, _अहमद, _מתוק,
   {{0x6d4d2720,0x61361e09,0x60c9808e,0x54550323}},	// [15b0] rmaa, rált, _raem, тват,
   {{0x2d8ca721,0x6d4d2722,0x7cf58073,0x60c9a723}},	//   _ovde_, smaa, _vári, _saem,
   {{0x7bc600ad,0x39491e92,0x4439079f,0x7d042724}},	//   _esku, _khas_, _wys_, bhis,
   {{0x7d042725,0x62852726,0x4439009a,0x38c98019}},	//   chis, saho, _tys_, بائی_,
   {{0x6d59a727,0x6561a728,0x2d8c826c,0x7cfc80e7}},	//   _riwa, _sulh, _avde_, _aéro,
   {{0x63ad04a7,0x6d59a729,0xa3c006b7,0x7cfc810c}},	//   mtan, _siwa, ूटर_, _béro,
   {{0x50b111bc,0x60c9a72a,0x6916016b,0x656180ee}},	//   जभाष, _taem, dšen, _qulh,
   {{0x9258272b,0x7cfca72c,0x69c7272d,0x6b89a72e}},	//   _част_, _déro, _isje, tseg,
   {{0x6d598010,0x3f8b009a,0x2d8c82d0,0xd46881a8}},	//   _viwa, jscu_, _evde_, رحيم_,
   {{0x466ba72f,0xdb0081fa,0x6d59a730,0xa3d2090f}},	//   _храм_, ttmá, _wiwa, वित_,
   {{0x6b89a731,0x29002732,0x63ad2733,0x39492734}},	//   sseg, _plia_, htan, _bhas_,
   {{0x69d51024,0xdb00826f,0x39492735,0xdddc0088}},	//   _mrze, rtmá, _chas_, jarš,
   {{0x63ad2736,0xaca301bc,0xc95280be,0x7529017f}},	//   jtan, _chọb, ימט_, čezl,
   {{0x69c7030b,0x78a2803a,0x2cbfa737,0x69d50035}},	//   _osje, zgov, leud_, _orze,
   {{0x7d042738,0x2d8c2739,0x386da73a,0x28aa06ab}},	//   this, éde_, _ofer_, _कापि,
   {{0x2cbf831d,0x6283976f,0x7aee023e,0xbddc0032}},	//   neud_, _heno, _sobt, _aṣòf,
   {{0x63ad273b,0xa3d2024c,0x628389c4,0x7aee022c}},	// [15c0] gtan, विध_, _keno, _pobt,
   {{0x7d04273c,0x130320ad,0x6283a73d,0x386da73e}},	//   shis, азум, _jeno, _afer_,
   {{0x62839a60,0x7d04273f,0x63ad2740,0x7cf808f1}},	//   _meno, phis, atan, _líri,
   {{0x63ad2741,0xe8b5817b,0x69d50035,0x6f0190ba}},	//   btan, rışı, _drze, _allc,
   {{0x10a39e17,0x7bc62742,0x98a38a0e,0x69d52743}},	//   ричн, _usku, риче, _erze,
   {{0x6283a744,0xa3d58c87,0x47338221,0x7cfca745}},	//   _neno, हिन_, аніс, _péro,
   {{0x91e324f5,0x78b6026f,0xe29700a9,0x27e0802e}},	//   _коре, _obyv, _јас_, ţin_,
   {{0x7cfca746,0x80ca8bb8,0x3f4f0197,0xaae001d0}},	//   _véro, _सोचे, _jżur_, नावक,
   {{0x62838c77,0xfd0f8077,0x9eaa80a9,0xf8bf00e7}},	//   _beno, تجو_, _оваа_, nnée_,
   {{0x80a50006,0x38602747,0x7cf801a8,0xe6c581a8}},	//   _काहे, _agir_, _díri, _متمي,
   {{0x69240052,0x26dea748,0xe8169094,0x63ad0102}},	//   rđen, _into_, _देता_, ztan,
   {{0x63ad127a,0xd90f026a,0x2906a749,0x26cca74a}},	//   ytan, تیب_, nhoa_, _hado_,
   {{0x26cca74b,0x6916274c,0x7d02a74d,0xd83801e5}},	//   _kado_, pšen, _ilos, вэр_,
   {{0x6283a74e,0xd7f8176e,0xb8fa274f,0x8c438991}},	//   _geno, тую_, _डो_, _тече,
   {{0x6288a750,0x26cca751,0xdddc026f,0x8233815b}},	//   mado, _mado_, tarš, _پروا,
   {{0x26cc8510,0x69242752,0xd49823d9,0xf8bf0118}},	//   _lado_, nđel, кру_, roés_,
   {{0x29192753,0x63ad2754,0x63a089ca,0xf8bf00e7}},	// [15d0] misa_, utan, numn, gnée_,
   {{0x69d50610,0x6288a755,0x29192756,0x63ad2757}},	//   _prze, nado, lisa_, rtan,
   {{0x7d02a758,0xc8aa0076,0x7cf5a759,0xf8aa0105}},	//   _olos, _कामट, _záru, _कामय,
   {{0x29190418,0x63ad275a,0x63a0a75b,0x60cd275c}},	//   nisa_, ptan, kumn, _jaam,
   {{0x60cd275d,0xb8cb91bc,0x26cc822e,0x7cf596a5}},	//   _maam, _खा_, _bado_, _márt,
   {{0x6288a75e,0x69d50063,0xa3d69a42,0x2489275f}},	//   jado, _trze, ाटन_, laam_,
   {{0x26cc90dd,0x29192760,0x7cf82761,0x69c705f3}},	//   _dado_, kisa_, _síri, _usje,
   {{0x23ab813c,0x7d028051,0x2906a762,0x248903b2}},	//   tøj_, _clos, choa_, naam_,
   {{0x6b8d0003,0x6283a0d7,0x29192763,0x7cfca764}},	//   nsag, _peno, disa_, _kérj,
   {{0x6d5d0665,0x61280059,0x26cca765,0xa3ab00c2}},	//   _lisa, dıla, _gado_, _गमन_,
   {{0x60cd2766,0x628380e1,0x29192767,0x0596804e}},	//   _baam, _veno, fisa_, _مانگ,
   {{0x6d5d0668,0x7cf580f7,0x29190365,0xc19a03de}},	//   _nisa, _cárt, gisa_, עשרי,
   {{0x3ce08076,0x776404c3,0xb4db0046,0xe8f72768}},	//   कारे_, _quix, _ghài, уля_,
   {{0x6288a769,0xe5a60d9e,0x6d5d0091,0x7d02805c}},	//   cado, лиги, _aisa, _zlos,
   {{0x6d5d1341,0x291911b7,0x60cd276a,0x78a980d2}},	//   _bisa, bisa_, _faam, _ocev,
   {{0x2919276b,0x6d5d276c,0x6565010c,0x6f188bcf}},	//   cisa_, _cisa, _duhh, zivc,
   {{0x612805c5,0x03261958,0x6d5d19b0,0x93aa045b}},	// [15e0] cıla, гдан, _disa, عارف_,
   {{0xf8bf02be,0x78a98333,0x6565276d,0x3cda86a7}},	//   rnée_, _acev, _fuhh, _खोने_,
   {{0x6d5d276e,0x2d950249,0x60cd276f,0xaaa6a770}},	//   _fisa, _кряс, _yaam, _खासक,
   {{0x613d0acf,0x6d5d2771,0xbfaaa772,0x7cfc8118}},	//   téli, _gisa, етке_, _pérm,
   {{0x6f188052,0x6288a773,0xb4c02774,0x75242775}},	//   tivc, yado, ंजी_, mniz,
   {{0xa3c12776,0x6288a777,0x29192778,0x918607c3}},	//   ंबर_, xado, zisa_, _مجرم,
   {{0xe1e7a779,0x612802bb,0x7d03002e,0x6d4b826c}},	//   _اس_, zıla, _însc, _bhga,
   {{0x7cfca018,0x6288a77a,0x80d408fd,0xb88704c3}},	//   _térm, wado, _बोले, _muíñ,
   {{0x62888510,0x2904a77b,0x60cd09f8,0x2919155f}},	//   tado, _ilma_, _raam, visa_,
   {{0x248900f3,0xc87987c0,0x443d8428,0x2919277c}},	//   zaam_, _inşa_, _dyw_, wisa_,
   {{0x63a0811f,0x2919277d,0x69160110,0x2258a77e}},	//   sumn, tisa_, pšel, ärk_,
   {{0x612803bf,0x6b8d277f,0x6b9ba780,0x60cd057b}},	//   tıla, ysag, brug, _qaam,
   {{0x628883f8,0x29192781,0x60cd2782,0x68fd2783}},	//   pado, risa_, _vaam, rksd,
   {{0x61280182,0x6d5d0744,0x29190234,0x60cd2784}},	//   rıla, _sisa, sisa_, _waam,
   {{0x60cd2785,0xbcfb00e7,0xb887002a,0x69da2786}},	//   _taam, _liée, _cuíñ, _šten,
   {{0x612807d9,0x69ca81b9,0x2fc901c0,0x6b8d2787}},	//   pıla, _isfe, _tsag_, tsag,
   {{0x6d5d2788,0x5b152789,0x6d4083ff,0x28aa278a}},	// [15f0] _visa, амат, ilma, _काति,
   {{0x6d5d278b,0xa3d58519,0x2bb78105,0x6b8d278c}},	//   _wisa, हित_, _अहसा, rsag,
   {{0x6b8d114e,0x6d5d278d,0x26c3278e,0x06cd80ab}},	//   ssag, _tisa, mejo_, লামি,
   {{0x26c3278f,0x60c28358,0xc91380ab,0xe8168c28}},	//   lejo_, geom, িক্ত_, _देहा_,
   {{0xdb042790,0xa2d0016f,0xafe5a791,0x21290299}},	//   stiá, _डोक्, ролл, _mjah_,
   {{0x26c32792,0xa3d206b7,0x26d1026c,0x6b4b02af}},	//   nejo_, विर_, ndzo_, füge,
   {{0x6ead000d,0xba740065,0x5a440a8e,0x6b828242}},	//   _जानु, _چاہت, _гэта, _awog,
   {{0x2d67811f,0x6b9ba793,0x2d9e1f79,0x62950140}},	//   _uđem_, trug, šteg_, _hdzo,
   {{0x69d8a794,0xf7708077,0x62872795,0x28d91c9d}},	//   _arve, _فال_, _kejo, _बोधि,
   {{0x26c30db7,0x6b9ba796,0x21290b99,0x98148a47}},	//   jejo_, rrug, _ajah_, _طبقا,
   {{0x62872797,0x69d8803b,0x394d8282,0x26c32798}},	//   _mejo, _crve, _khes_, dejo_,
   {{0x69d8803b,0x6b9b803a,0x69de81ac,0x62872799}},	//   _drve, prug, _špec, _lejo,
   {{0x95548bca,0x21290267,0x290c0110,0x3cff81c0}},	//   _اخلا, _djah_, ėda_, mkuv_,
   {{0x7cf58065,0xe2999577,0x3ced9e0f,0x6287001b}},	//   _társ, _рак_, ljev_, _nejo,
   {{0x2d988cd7,0x2cb90706,0x2d5182d4,0x21a58037}},	//   _året_, _bbsd_, _ušes_, _тийм,
   {{0x25ed8df4,0x88830081,0x9426279a,0x7d09a79b}},	//   _अपनी_, _длъж, амбе, nhes,
   {{0xf77207bd,0xed57279c,0x26c3279d,0x03a6279e}},	// [1600] _باب_, рот_, bejo_, ризо,
   {{0x7d1ba79f,0x7cf58511,0x752400b9,0x31679500}},	//   hius, _márq, sniz, _kunz_,
   {{0x7d1ba7a0,0x395f8359,0xa2a700c2,0x41aa0ae7}},	//   kius, _bius_, _चार्, твен_,
   {{0x613d27a1,0x53a621d2,0x3cff81c0,0x6f1c0037}},	//   bélu, _камб, jkuv_, lirc,
   {{0x7d09a7a2,0x3ced85f3,0x395f823e,0x67d49fb1}},	//   dhes, djev_, _dius_, солу,
   {{0x98ab009a,0x628727a3,0x63a427a4,0x7cfc8019}},	//   mocą_, _gejo, muin, _térk,
   {{0x63a427a5,0x7d1b8118,0xb23a00f7,0x4420802e}},	//   luin, fius, _شكرا_, _ţi_,
   {{0x6b828247,0x92a6009a,0x7d1b847f,0x395f8037}},	//   _pwog, _wyłą, gius, _gius_,
   {{0x6f1c27a6,0x7cf5988b,0xdcef011f,0x6d40808b}},	//   kirc, _párr, žeće, rlma,
   {{0x7cfca7a7,0x2d9c81d0,0x6f1c09ab,0x2fc99a25}},	//   _méri, prve_, jirc, çage_,
   {{0x63a41581,0x7d1ba7a8,0x3ced826c,0xf2d900be}},	//   huin, bius, bjev_, אַרל,
   {{0x7d09a7a9,0x7d1ba7aa,0x63a427ab,0xb4c503db}},	//   ches, cius, kuin, _एसे_,
   {{0x315780be,0x8c43a369,0x7cf58144,0x6568a7ac}},	//   ייטן_, _деце, _tárr, _hudh,
   {{0x63a427ad,0x6568a7ae,0x31678037,0x46de27af}},	//   duin, _kudh, _funz_, मागह,
   {{0x26d10063,0x628727b0,0x26c327b1,0x518693bf}},	//   rdzo_, _rejo, rejo_, _тула,
   {{0x26c327b2,0x6568a7b3,0x3f8f8114,0x7cfc9a98}},	//   sejo_, _mudh, ysgu_, _béri,
   {{0x63a4107f,0x2d5802c7,0x26c327b4,0x62870088}},	// [1610] guin, рить_, pejo_, _pejo,
   {{0x883c0039,0x6e2d8214,0x67389351,0x7cfc80e7}},	//   _בתחו, şabi, jovj, _déri,
   {{0x75d50199,0xb4db051e,0x6738a7b5,0x656888f9}},	//   _ايجا, _bhàt, dovj, _nudh,
   {{0x7cfca7b6,0xa3d6873c,0xb12580ab,0xb4db0362}},	//   _féri, ाटा_, বত্ব_, _chàt,
   {{0x63a40087,0x395f823e,0xb0aa0035,0x3cff822c}},	//   cuin, _vius_, _कासग, vkuv_,
   {{0x6568a7b7,0x67388639,0x16a9a7b8,0xa3d581ab}},	//   _budh, govj, увки_, हिस_,
   {{0x394da7b9,0xa19427ba,0xdcfb1a42,0x21390168}},	//   _thes_, _марч, _एकाध_, kosh_,
   {{0x2ca927bb,0x28cf9513,0xd5d827bc,0x51840cc1}},	//   ngad_, _सोचि, डितज, _фура,
   {{0x291d80f6,0x3ced8db7,0x7d1ba7bd,0x7d09a7be}},	//   miwa_, rjev_, rius, rhes,
   {{0x291d80f6,0xddde21f8,0xfe708b76,0x7305943d}},	//   liwa_, _lepš, _قدم_, споз,
   {{0xdb0403a7,0x7d09a7bf,0x657701e9,0x6568a7c0}},	//   stiç, phes, _ntxh, _gudh,
   {{0x291d804f,0x213912ec,0x05090264,0x14ca9abb}},	//   niwa_, gosh_, রচুর_, _مهمی_,
   {{0xeb99a361,0xdb0b806a,0xc50c80be,0x9fd60264}},	//   _сил_, _opgø, _בלאָ, সঙ্গ,
   {{0xa3c10935,0x65689d31,0x291da7c1,0x644ba7c2}},	//   ंबई_, _yudh, hiwa_, _izgi,
   {{0x7ae3a7c3,0x291d80f6,0x7cfca7c4,0x6b5004b8}},	//   _innt, kiwa_, _séri, lägg,
   {{0xb466044f,0x7cfca7c5,0x2ca9016d,0x291d8010}},	//   скал, _péri, ggad_, jiwa_,
   {{0x09b201fe,0x612805c5,0x68e41e0a,0x291d8010}},	// [1620] ीब्य, nılm, _inid, diwa_,
   {{0x63a4125b,0x7cfc82be,0xb4db0229,0x2ca902c4}},	//   ruin, _véri, _bhàs, agad_,
   {{0x63a427c6,0x28dd016f,0x8db600e8,0x291d804f}},	//   suin, याचि, _успі, fiwa_,
   {{0x98a68cdf,0x612802d0,0x291da7c7,0xb4db0a2a}},	//   сиде, kılm, giwa_, _dhàs,
   {{0x6568a7c8,0x29020009,0x31b18019,0xc7a38992}},	//   _sudh, ikka_, ház_, зичк,
   {{0x61280085,0x6d4427c9,0x4dbe80ab,0xa3bd00c2}},	//   dılm, llia, ্মসূ, _आहत_,
   {{0x38698052,0x6d44031d,0x6738a7ca,0x291da7cb}},	//   žara_, olia, rovj, biwa_,
   {{0x5398a6e8,0xbb748992,0x69ce01b4,0x7ae3851e}},	//   авия_, огиј, _isbe, _annt,
   {{0x2d8502ba,0x673882ce,0x656890e1,0x442f83a8}},	//   ález_, povj, _wudh, _cxg_,
   {{0x6d4423bd,0x78ad27cc,0x68e427cd,0x37be0264}},	//   hlia, _scav, _anid, ইটার,
   {{0xe3afa003,0xdd928077,0x6d440110,0x81b600ab}},	//   وری_, _روش_, klia, জিক_,
   {{0xd84304e8,0x00000000,0x00000000,0x00000000}},	//   _ničí_, --, --, --,
   {{0x2d910063,0xb0aa000f,0x28aa097d,0x6d440114}},	//   wsze_, _कारग, _कारि, dlia,
   {{0x291da7ce,0xa3d5a7cf,0x69dc27d0,0x98be00eb}},	//   ziwa_, हिर_, _orre, ētā_,
   {{0x7af50e04,0x8cda016f,0x291da7d1,0x2d8527d2}},	//   _rozt, _पोहो, yiwa_, èle_,
   {{0x6d440698,0x2d91247d,0x65628326,0x183a01bc}},	//   glia, rsze_, _jioh, ọmụm,
   {{0x290902a3,0x69dc27d3,0x36d527d4,0x7af527d5}},	// [1630] _ilaa_, _arre, _допр, _pozt,
   {{0x32672184,0x2d91009a,0xaa6727d6,0x6d4427d7}},	//   став, psze_, стак, alia,
   {{0x291d8010,0x612803bf,0x7d030162,0xdb098174}},	//   tiwa_, zılm, _înso, nteá,
   {{0xdb0980f7,0x6128080a,0x628a8061,0x6ca727d8}},	//   iteá, yılm, _lefo, _урож,
   {{0x69dc27d9,0x6298a7da,0x291da7db,0xcf9b84ae}},	//   _erre, _odvo, riwa_, ује_,
   {{0x7d0d0065,0x291da7dc,0xab5b0019,0xe81c0074}},	//   lhas, siwa_, _csüt, _पइसा_,
   {{0x24e98698,0xace9a7dd,0xceb404de,0x28aa0ebf}},	//   имки_, имка_, פיק_, _कालि,
   {{0x28d90b75,0x61280457,0x2fcd81e9,0x6abc01a1}},	//   _बोलि, tılm, _tseg_, _zbrf,
   {{0x628aa7de,0x68e427df,0xa49b0176,0x130985a5}},	//   _befo, _rnid, _alòk, иний_,
   {{0x61280182,0x69060118,0x4225a489,0x68f60850}},	//   rılm, _cóen, ждов, _soyd,
   {{0x90c60364,0x7d0d27e0,0x60c600eb,0x6d440114}},	//   обне, khas, tekm, ylia,
   {{0xf9920051,0x7bcf27e1,0x612813da,0x69da27e2}},	//   ורט_, _oscu, pılm, _štek,
   {{0x3c47803f,0x7529802e,0x6b500884,0x7d0d27e3}},	//   _اضاف, mnez, läge, dhas,
   {{0x2bcf901c,0x26c78010,0xa3d689f2,0x628aa7e4}},	//   _तैया, neno_, ाटर_, _gefo,
   {{0x6281a7e5,0x7bcf002e,0x9663120c,0x2ee580b9}},	//   mblo, _ascu, дкре, _mnlf_,
   {{0x68e40510,0xd4671c78,0x7d0d27e6,0x6281a7e7}},	//   _unid, жите_, ghas, lblo,
   {{0x2ee58079,0x8c430e8e,0x248027e8,0xdb00804a}},	// [1640] _onlf_, дете, rbim_, ttmø,
   {{0x681c0029,0xc8aa0327,0xb0aa18a9,0xe29a2432}},	//   rādī, _काँट, _काँग, раж_,
   {{0x673c27e9,0x506682df,0x7d0d27ea,0x26c78ef1}},	//   morj, отла, bhas, deno_,
   {{0x7d0d0870,0xdb0400f7,0x31ba80be,0x7cfc9abb}},	//   chas, ntiú, יזענ, _yéru,
   {{0xa3ce09a3,0x765f8201,0x1eca81a1,0x7529a7eb}},	//   _शनि_, əyyə, илди_, dnez,
   {{0x7d040009,0x26c780e5,0xdd9a97c8,0xa49b026b}},	//   lkis, geno_, аши_, _alòh,
   {{0xb0aa27ec,0x69dc27ed,0xd9a8800f,0x4c94a7ee}},	//   _कांग, _urre, _कमेट, пийс,
   {{0x61e10065,0x3ea0a7ef,0x7d0427f0,0x394001c0}},	//   _álla, şit_, nkis, _nkis_,
   {{0xd0078ae7,0x63b627f1,0x2f0b806a,0x3946a7f2}},	//   _дете_, ntyn, _søge_, mlos_,
   {{0x3946840e,0x26c7a7f3,0x2909004f,0x39400084}},	//   llos_, ceno_, _slaa_, _akis_,
   {{0xd48fa7f4,0x26d327f5,0x7d0427f6,0xdb040216}},	//   _ор_, _raxo_, kkis, guié,
   {{0x394682af,0x26d327f7,0x88b10180,0x657a8061}},	//   nlos_, _saxo_, ریخچ, _itth,
   {{0xc86400e8,0xdb0981a8,0xab2a86f9,0x6281a7f8}},	//   дтри, steá, _кода_, bblo,
   {{0x3ce681c5,0x6298812b,0x39401400,0x7c2da7f9}},	//   _hnov_, _udvo, _ekis_, _žarg,
   {{0x7d0d27fa,0xf27b8051,0x394681e2,0x7cfc8c52}},	//   thas, _דרוש, klos_, _fért,
   {{0xdb0400f7,0x26c79620,0x394681c0,0x80a527fb}},	//   ctiú, zeno_, jlos_, _काटे,
   {{0x7d0d27fc,0x6b4f806a,0x394689ed,0xdb0d00f7}},	// [1650] rhas, søge, dlos_, staí,
   {{0x7d0d27fd,0x657a8019,0x26c783a8,0x39468020}},	//   shas, _otth, xeno_, elos_,
   {{0xceb20451,0x69240d11,0x69160353,0x7d0401de}},	//   _איי_, rđev, ršev, bkis,
   {{0x6b50016d,0x3946a7fe,0x7d0427ff,0x55da00be}},	//   väge, glos_, ckis, _פֿינ,
   {{0x657a8748,0x26c7a800,0x60dc00be,0x66e580ae}},	//   _atth, teno_, יקאנ, зола,
   {{0x6281813c,0x644f01a9,0x39468118,0xf8bf01d0}},	//   xblo, _izci, alos_, dném_,
   {{0x26c7812b,0x80ac035a,0x39468ae5,0x7bc2a801}},	//   reno_, _झाले, blos_, _apou,
   {{0x39468c52,0x61360065,0x673c007a,0x6b5001ec}},	//   clos_, bály, zorj, räge,
   {{0x76450009,0x6281a802,0x39520428,0x26c7a803}},	//   _lyhy, tblo, _rhys_, peno_,
   {{0x386913b8,0x13098d15,0x753b928a,0x7cfca804}},	//   _agar_, сной_, souz, _sért,
   {{0x753b811f,0x7d040082,0x7bc2a218,0x673c007a}},	//   pouz, ykis, _epou, vorj,
   {{0x2fdf805c,0x69d083eb,0x63b60198,0xbcfb0216}},	//   _krug_, धिजी, ytyn, _sién,
   {{0x673c2805,0xb4d7864a,0x4aac0072,0x69da81c0}},	//   torj, ायी_, _चालव, avte,
   {{0x4e1f85e8,0x3f9e026f,0x7bda8039,0x657a8388}},	//   _बधाई_, čtu_, _לקנו, _ytth,
   {{0x386d0301,0x7d042806,0xdb040036,0x649a0071}},	//   žera_, tkis, quié, йтар_,
   {{0x2571807b,0x63b60009,0x673c2807,0x61fc8338}},	//   _mál_, ttyn, sorj, ärle,
   {{0xf42a01ac,0x2fdf8282,0x7d042808,0xfbdf02df}},	// [1660] _opäť_, _nrug_, rkis, _crê_,
   {{0x7d042809,0x27e0280a,0xa3dc853f,0x60d6280b}},	//   skis, _irin_, डित_, _haym,
   {{0x63b6280c,0x9d462523,0x60d6280d,0x2c75019d}},	//   styn, _неод, _kaym, _ụde_,
   {{0x2fdf8022,0x63a9a80e,0x63b6280f,0x7ae70168}},	//   _brug_, kuen, ptyn, _enjt,
   {{0x3946a810,0xe81683a4,0x09a8800c,0x2efa01ec}},	//   rlos_, _देखा_, _कम्य, _kopf_,
   {{0x69c38fb0,0x26ca2811,0xf67a00be,0x290b00eb}},	//   _opne, nebo_, זאַמ, ībai_,
   {{0x629c2812,0x7bc2a813,0x25718118,0x3946a814}},	//   _idro, _spou, _cál_, plos_,
   {{0x27e0077f,0x399b0039,0x2571801b,0x63a995a0}},	//   _orin_, _לילד, _dál_, fuen,
   {{0x63a42815,0x63a9a816,0x628e0587,0x7cfc8125}},	//   nrin, guen, _kebo, _sérs,
   {{0xa3ab8063,0x63a42817,0x628e2818,0x877b83c8}},	//   गढ़_, irin, _jebo, _לאמי,
   {{0x63a42819,0x6446007b,0x26ca026b,0x27e0281a}},	//   hrin, _lyki, debo_, _arin_,
   {{0x63a9a81b,0x2906a81c,0x27e0281d,0x60d6281e}},	//   buen, nkoa_, _brin_, _caym,
   {{0xd83b01e5,0x63a9960a,0x5f940098,0x7cfc8207}},	//   сэн_, cuen, ният, _férr,
   {{0x628e14f0,0x27e0281f,0xa3e00327,0xf8bf0036}},	//   _nebo, _drin_, थिन_, diée_,
   {{0x27e02820,0x2d9e003a,0x29068009,0x160420c0}},	//   _erin_, šten_, kkoa_, रनगर_,
   {{0xca478013,0x63a42821,0x629c031d,0xf8bf00e7}},	//   _عليه_, frin, _adro, fiée_,
   {{0x63a42822,0xa3d58063,0x24580009,0x628e2823}},	// [1670] grin, हिए_, зать_, _bebo,
   {{0x26ca2824,0x628e1e31,0x629c01e0,0x6d428326}},	//   cebo_, _cebo, _cdro, _lkoa,
   {{0x32072825,0x65662826,0x644600b9,0x16351d38}},	//   ány_, _fikh, _eyki, _ценя,
   {{0x25e0858c,0x6ebf800d,0xf42a01ac,0x5fb103db}},	//   किनी_, ल्नु, _späť_, _जमाल,
   {{0xf8bf0036,0x2571a827,0x61360118,0x32071517}},	//   ciée_, _sál_, rálx, šny_,
   {{0x628e105d,0x290fa828,0x6d42826b,0x670d03eb}},	//   _gebo, shga_, _akoa, हसिक_,
   {{0x69da0db7,0x30a7a829,0x20020035,0x60dd8144}},	//   _štev, _нрав, zyki_, _ósmo,
   {{0x58d4a82a,0x629c09a4,0x63a98102,0x26d80690}},	//   _пост, _zdro, tuen, zdro_,
   {{0x2be00f97,0x2fdf808e,0x68e9a82b,0x19588196}},	//   निया, _urug_, _ined, _хаты_,
   {{0x68fba82c,0x63a9a82d,0x7c26807b,0x68e980e1}},	//   _houd, ruen, úkra, _hned,
   {{0x68fba82e,0x80d700ab,0x2bdb820e,0x60d6282f}},	//   _koud, ধান্, बिहा, _paym,
   {{0x27e00c6e,0x26c10267,0x2002009a,0x63a42830}},	//   _prin_, _abho_, tyki_, yrin,
   {{0x21221083,0x63a9a831,0x6d5b836e,0xeb8e8934}},	//   rikh_, quen, mmua, _ши_,
   {{0x6d49a832,0x672394e4,0x2906811e,0x6566005d}},	//   llea, ninj, zkoa_, _sikh,
   {{0xdd1c026f,0x63a42833,0x644f817f,0xed168019}},	//   _vážn, wrin, škić, _رہیں_,
   {{0x628e2834,0x27e02835,0x6d4990a2,0x752d2836}},	//   _sebo, _trin_, nlea, gnaz,
   {{0x6d49a837,0xab66096b,0x59d584c5,0xc9530039}},	// [1680] ilea, двал, धिकर, _במה_,
   {{0x290da838,0x63a42839,0x03a301a1,0xf8bf0036}},	//   _alea_, rrin, тифо, riée_,
   {{0x68fba218,0x63a4283a,0x68e9822b,0xd46a283b}},	//   _boud, srin, _bned, _мине_,
   {{0x6d5b822c,0x628e03fb,0xc7c68af2,0x8fa69182}},	//   jmua, _webo, дски, даде,
   {{0x628e283c,0x68fba83d,0x29068bf0,0x4c3601e2}},	//   _tebo, _doud, rkoa_, _цэнт,
   {{0xf8bf0019,0x291f80b9,0x2906811b,0x68e9a83e}},	//   tnék_, _emua_, skoa_, _ened,
   {{0x6263283f,0x68fb8866,0x7afc02f9,0xdd1d136f}},	//   _авра, _foud, _iort, lášs,
   {{0x25a0a840,0x7afc2841,0x68fba842,0xe81f84e5}},	//   čil_, _hort, _goud, _मेवा_,
   {{0x6723a843,0x6843a844,0x644e8035,0xaf2aa845}},	//   binj, _анта, ębio, _джаз_,
   {{0x67238052,0x68fb8a0f,0xadba80f7,0xe45703de}},	//   cinj, _zoud, _وهذا_, ויפט_,
   {{0x6d49a846,0xf2d30039,0x36068199,0xbcfb010c}},	//   blea, דעת_, _تواف, _diéj,
   {{0x7afc011e,0xcb6a8323,0xb4db0032,0xf78702df}},	//   _lort, _даде_, _akàn, íços_,
   {{0xac978077,0x6d4082d6,0x7afc01b0,0x2d9e2847}},	//   _آنها_, moma, _oort, štel_,
   {{0x6d409619,0x7afc160c,0xdce280c3,0x75e401bc}},	//   loma, _nort, _mioč, _ọzay,
   {{0xa3d689a3,0xdb0081ca,0x7bc601a9,0x6455866f}},	//   ाटक_, cumá, _apku, ęzie,
   {{0x6d40a848,0x50670abe,0x6b500106,0x66f802d0}},	//   noma, _отпа, väga, _aşkı,
   {{0x752d2849,0xdb0d0073,0x7afc0687,0x3b550012}},	// [1690] rnaz, ntaç, _bort, екар,
   {{0x6d40a84a,0x68fba84b,0x291fa84c,0xdb0d0187}},	//   homa, _soud, _smua_, itaç,
   {{0x6d40a84d,0x68fba84e,0x7afc284f,0xda0e80a5}},	//   koma, _poud, _dort, ानित_,
   {{0x2d8301ed,0xa49b0362,0xe7f3866f,0x3835a850}},	//   mpje_, _clòt, _आपदा_, ннер,
   {{0x67238025,0x69da003b,0x68fb80e7,0x2575016d}},	//   tinj, _štet, _voud, _hål_,
   {{0x63ad2851,0x7afc2852,0xe7339dd2,0x68fb9412}},	//   muan, _gort, خصص_, _woud,
   {{0x67238db7,0x63ad2853,0xe81fa854,0x6d40a855}},	//   rinj, luan, _मेरा_, foma,
   {{0x25750082,0x6723a856,0xdfd597ae,0x67d5a5d9}},	//   _mål_, sinj, _побы, _побу,
   {{0x6d49a857,0x6d5ba858,0x77688118,0x386da859}},	//   rlea, rmua, _fidx, _iger_,
   {{0xa3e0090f,0x6d49a85a,0xcb1200be,0x7afc285b}},	//   थित_, slea, ָלט_, _xort,
   {{0x6d498e6f,0x7648a85c,0x7d0f0019,0x6d40a85d}},	//   plea, _gydy, _olcs, boma,
   {{0x6d40a85e,0xdb0980a9,0xe8f7176e,0x75d38201}},	//   coma, nteú, елю_, _nəzə,
   {{0xa3d58076,0x3169285f,0xfaa5a432,0x7d098c9a}},	//   हिओ_, _diaz_, _зало, mkes,
   {{0x63ad0057,0x2d9e005c,0x7d09a860,0x69c705f3}},	//   duan, štem_, lkes, _opje,
   {{0x63bba861,0x2f1400f2,0x2d8c2862,0xed5a0d0e}},	//   ltun, _lägg_, ède_, зов_,
   {{0x7afc2863,0xc5f280be,0x69a48072,0x1da78035}},	//   _sort, נדן_, _किती, _गिनत,
   {{0x63bb885c,0x63ad2864,0xfd648a2c,0x03a32865}},	// [16a0] ntun, guan, _akwụ, лито,
   {{0x28c10054,0x7afc2866,0x63bba867,0x06860110}},	//   ष्ठि, _qort, itun, _ягон,
   {{0x63bba868,0x7afc11e6,0x6d40a869,0x7d09a86a}},	//   htun, _vort, yoma, kkes,
   {{0x26da022e,0x7648831d,0x7afc286b,0x61fca86c}},	//   _hapo_, _rydy, _wort, ørli,
   {{0xe7e3286d,0x6d46286e,0x63ad0144,0x7afc286f}},	//   खिया_, _ikka, cuan, _tort,
   {{0x6b842870,0x6d40a871,0x386da872,0x2d8c80e4}},	//   mpig, woma, _eger_, _pwde_,
   {{0x60c42873,0x2d9a9bff,0xceb300be,0x63bba874}},	//   _obim, épe_, טיג_, etun,
   {{0x63bba875,0x75d38085,0xc5f30039,0xd9e386a7}},	//   ftun, _xəzə, רדה_, गिनत_,
   {{0x6d40a876,0x63bba877,0xd4e38009,0xdb040036}},	//   roma, gtun, ующи, triè,
   {{0x2d6e800d,0x6b4f813c,0xdb0d2878,0x26da2879}},	//   _před_, søgn, rtaç, _napo_,
   {{0x6d46287a,0xdb0402be,0xdb0d03a7,0x95caa87b}},	//   _okka, rriè, staç, _хлеб_,
   {{0x6d40a87c,0x69b1809a,0xdb0d0187,0xdcdf03db}},	//   qoma, _अमरी, ptaç, _पोंछ,
   {{0xb8d90576,0xa3e4800d,0xa2c106af,0xdb040118}},	//   _चा_, _पछि_, र्ड्, ntió,
   {{0x5453835f,0x6d46287d,0x26da287e,0xd04089ab}},	//   _світ, _akka, _capo_, _hamɓ,
   {{0x0dc81506,0x95c8028b,0x3942287f,0x26da026b}},	//   нути_, нута_, boks_, _dapo_,
   {{0x290b0341,0x63ad2880,0x2b582881,0x394200b9}},	//   ības_, tuan, _ahrc_, coks_,
   {{0x8aa70153,0x69c72882,0xfaa704fa,0x6b84076d}},	// [16b0] еред, _spje, ешен, gpig,
   {{0x60dd0a64,0x2fc902e8,0x6d460365,0x25750106}},	//   ldsm, _ipag_, _ekka, _tål_,
   {{0xf99307bd,0x799aa883,0x63bba6f7,0x67270267}},	//   ابط_, nstw, ztun, mijj,
   {{0x60dd2445,0x21268358,0x2fc902d5,0x2d812884}},	//   ndsm, gioh_, _kpag_, _ithe_,
   {{0xb8c9a885,0x63ad2886,0x69d5009a,0x389c00be}},	//   _गए_, quan, _wsze, ליאנ,
   {{0x6d4d2887,0x6da5867c,0x443901e0,0x6727026c}},	//   llaa, вика, _ixs_, nijj,
   {{0x53341c56,0xa3b3816f,0x68ed2888,0x7d09a889}},	//   _серт, जून_, _onad, tkes,
   {{0x63bba88a,0x68ff02a3,0x386d813c,0x60dd006a}},	//   ttun, _noqd, _uger_, jdsm,
   {{0x63bb8009,0x7d09a88b,0xd9d9801b,0xa2c11869}},	//   utun, rkes, बट्ट, र्थ्,
   {{0x613d0065,0x7d09a88c,0x63bb8367,0x68ed288d}},	//   mély, skes, rtun, _anad,
   {{0x63bba88e,0x6d4d288f,0x3f80002e,0x2d81022c}},	//   stun, klaa, _stiu_, _nthe_,
   {{0x60db809f,0xdb2689a7,0x26da2890,0x2d9e2891}},	//   _jaum, _یونی, _sapo_, štek_,
   {{0x889a8039,0x26da2892,0x2f14016d,0x60db804f}},	//   וברי, _papo_, _läge_, _maum,
   {{0x4ad78117,0x4ed52893,0xdb0402be,0xfaa5a894}},	//   _ساتھ_, люст, prié, _рако,
   {{0xceb29a15,0x63a9a895,0x656ba896,0xcb1281c6}},	//   יים_, lren, _kigh, _דלג_,
   {{0x6d4d2897,0x26da004f,0x63a9a898,0x656b819d}},	//   glaa, _wapo_, oren, _jigh,
   {{0x26da0110,0x656b8039,0xb46601e5,0x2d812899}},	// [16c0] _tapo_, _migh, ткал, _ethe_,
   {{0x656ba89a,0x613d0019,0x68ed05f3,0x6d4d289b}},	//   _ligh, dély, _znad, alaa,
   {{0x2be00076,0x63a9a89c,0x644b8110,0x60db9655}},	//   निहा, hren, _lygi, _baum,
   {{0x63a982a5,0xfbab1344,0x656ba89d,0x2900289e}},	//   kren, _चमचम, _nigh, _joia_,
   {{0x7c2da89f,0x68438a14,0xb4c00beb,0x087700be}},	//   _žarn, анца, ूजी_, דענט_,
   {{0xa3c1009a,0x3cda8592,0x656b832f,0x7f4381e0}},	//   ूबर_, _खोजे_, _aigh, gonq,
   {{0xdb04040e,0x63a9a8a0,0x28dd92c6,0x2be0170c}},	//   stió, eren, _नोकि, निवा,
   {{0x6d59a8a1,0x290028a2,0x60dba8a3,0x6d4428a4}},	//   _chwa, _noia_, _gaum, noia,
   {{0xa7668be1,0x63a9906f,0x656ba8a5,0x6b9b84a7}},	//   _акад, gren, _digh, gsug,
   {{0x6d5983ac,0x68ed001b,0xbcfb0118,0x29120c2e}},	//   _ehwa, _snad, _viéi, _alya_,
   {{0xdb0404c3,0x7c2d807b,0x63a9a8a6,0x6727026c}},	//   ntiñ, _þarn, aren, vijj,
   {{0x0c26a8a7,0xe8e00028,0x799a809a,0x94268009}},	//   _имен, _trời_, rstw, _имее,
   {{0x692b000d,0x6727026c,0x60dd0cd7,0x6d4428a8}},	//   třeb, tijj, rdsm, doia,
   {{0xf8bf06a5,0x656b81bc,0x68ed0326,0x2912038a}},	//   cién_, _zigh, _wnad, _elya_,
   {{0x7e280d13,0xdb00816d,0xf62800e8,0x6d4d28a9}},	//   віта_, rumä, віти_, tlaa,
   {{0xe7f3816f,0x6727026c,0x69d8a8aa,0x68ed01f8}},	//   _आपला_, sijj, _isve, _unad,
   {{0x545528ab,0xdc550003,0x6d4d28ac,0x60dba8ad}},	// [16d0] уват, увањ, rlaa, _raum,
   {{0x6d4d0b3c,0xf1b6a7fb,0xe3b001a8,0x22950481}},	//   slaa, _अमान, ترف_, الاس,
   {{0x6d4d28ae,0x26d128af,0x60dba8b0,0x63a9a8b1}},	//   plaa, mezo_, _paum, zren,
   {{0x26d128b2,0xe0df28b3,0x3015a8b4,0x2600001b}},	//   lezo_, ndò_, лдер, रहरी_,
   {{0xe8d90104,0x656b8051,0xd91c0158,0x251a0039}},	//   _chỉ_, _righ, וואל, _נושא,
   {{0x69d893f6,0xb87b12ca,0x60db804f,0x26d128b5}},	//   _osve, ndíb, _waum, nezo_,
   {{0x99678e9f,0x60dba8b6,0xdb040c52,0xf8bf00e7}},	//   _атал, _taum, quiá, nnés_,
   {{0x7d0d28b7,0x26d128b8,0x6b9ba8b9,0x39490282}},	//   nkas, hezo_, tsug, _nkas_,
   {{0x26d128ba,0x0b45841c,0x63a9a8bb,0x69ca81ec}},	//   kezo_, лнин, uren, _apfe,
   {{0xe1f98364,0x63a9a8bc,0x656ba8bd,0x25788019}},	//   его_, rren, _wigh, _fél_,
   {{0x7d0d28be,0xa2ca28bf,0xaca30032,0x26d10118}},	//   kkas, _सॉफ्, _akọb, dezo_,
   {{0x38698699,0x69a48beb,0x64558085,0x61f828c0}},	//   žaru_, _किरी, əzin, ävli,
   {{0x03a58258,0x53a587b6,0x7d0d28c1,0x69d88580}},	//   _сило, _салб, dkas, _esve,
   {{0x629528c2,0x26d121bb,0x7529a8c3,0xfd65027d}},	//   _nezo, gezo_, liez, _truồ,
   {{0xdca6223c,0x64a628c4,0xc0e628c5,0xdd1d01d0}},	//   лави, лава, _бойк, lářs,
   {{0x7d0d043b,0xa3e028c6,0x7e7c0216,0x7529a8c7}},	//   gkas, थिल_, scrp, niez,
   {{0x0aea1be4,0x629528c8,0x6eac009a,0x6d4428c9}},	// [16e0] ндай_, _bezo, _जयपु, roia,
   {{0x7d0d0009,0xb46328ca,0xdb00a8cb,0x6d4428cc}},	//   akas, скул, stmö, soia,
   {{0x629528cd,0xd24f00f7,0x88868098,0x9abc84b7}},	//   _dezo, كنك_, глеж, fiċj,
   {{0xdb0401df,0xc0968290,0x25aa804a,0x31bc0118}},	//   rtiñ, اجات, _åbli_, ríz_,
   {{0xa3d28610,0x316da8ce,0xdb0428cf,0x6ac900ab}},	//   _हैं_, _diez_, stiñ, রয়ো,
   {{0x629528d0,0x6f01a8d1,0xaa461d38,0xa85701c6}},	//   _gezo, _colc, _бегл, ניסה_,
   {{0x645d8125,0x6f018098,0xceb30039,0xe5c69821}},	//   ýsin, _dolc, ציה_, усло,
   {{0xd1328b76,0x386d28d2,0x78a4004f,0x75298cdb}},	//   _امر_, žeri_, _ndiv, giez,
   {{0x28dd800f,0x5b14a55e,0x6f01a8d3,0xdb040187}},	//   _नोटि, имит, _folc, guiç,
   {{0x3946a8d4,0x78a428d5,0x2578a8d6,0x9bbb00be}},	//   loos_, _adiv, _tél_, עציפ,
   {{0xaac628d7,0x80de00c8,0xd2508077,0x7d0d28d8}},	//   र्यक, যান্, تند_, ykas,
   {{0xdb0403a7,0x3f84808e,0xaca301bc,0x26de8a03}},	//   buiç, _ktmu_, _kwụd, _hato_,
   {{0xe8d90104,0xa3b3823c,0x26dea8d9,0xed579bbf}},	//   _giờ_, जूद_, _kato_, _соц_,
   {{0x7d0282a3,0x8c1b8039,0x26de82df,0xaca3019d}},	//   _hoos, _אודי, _jato_, _mwụd,
   {{0x629528da,0xc27b893f,0x7d0289f8,0x26d128db}},	//   _rezo, _ארוי, _koos, rezo_,
   {{0x99838307,0x629aa8dc,0xf1a9809a,0x26dea8dd}},	//   _اليو, lato, _कितन, _lato_,
   {{0x62950216,0x26d10333,0x24180fe6,0x3946a8de}},	// [16f0] _pezo, pezo_, готы_, doos_,
   {{0x212b034a,0x27e928df,0x7d0d28e0,0x830500ab}},	//   lich_, _iran_, skas, োচ্চ_,
   {{0xe8d900ff,0xa2c128e1,0x8027881b,0xc1e8084b}},	//   _nhị_, र्ष्, گرام, льце_,
   {{0x629aa8e2,0x212b01e4,0x32641132,0x6f01a8e3}},	//   hato, nich_, стув, _solc,
   {{0x26dea8e4,0x4ac48651,0xe8d901bc,0x35ab06a7}},	//   _bato_, वभाव, _ahị_, _छिड़,
   {{0x7ceb04b8,0x656f28e5,0x66e5a8e6,0xaec480e8}},	//   _förä, _hich, рока, йбіл,
   {{0x212b0063,0x26dea8e7,0x6f01a0e6,0x656f28e8}},	//   kich_, _dato_, _volc, _kich,
   {{0x212b0775,0xdb040073,0x63ad28e9,0x27e928ea}},	//   jich_, tuiç, oran, _oran_,
   {{0x656f28eb,0x212b0229,0x26de83a7,0x9ed98098}},	//   _mich, dich_, _fato_, _имат_,
   {{0x656f28ec,0x26dea8ed,0x13098009,0x03259138}},	//   _lich, _gato_, тной_, рдон,
   {{0x63ad28ee,0x7529a8ef,0x69de826f,0xcb140039}},	//   hran, piez, _šper, מלץ_,
   {{0x656f0943,0x212b28f0,0x95678698,0x75ca8201}},	//   _nich, gich_, _създ, _qəze,
   {{0x26de8091,0x63ad0289,0x248d83a7,0x5edf00ab}},	//   _yato_, jran, mbem_, মানে,
   {{0x7d02822c,0x656f28f1,0x6b89a8f2,0x27e901ec}},	//   _zoos, _aich, mpeg, _dran_,
   {{0x63ad28f3,0xde0326c5,0x27e928f4,0x656f106c}},	//   eran, опри, _eran_, _bich,
   {{0x63ad28f5,0x212b01ac,0x69c1a8f6,0x7de08019}},	//   fran, cich_, mtle, lásá,
   {{0x656f28f7,0x27e928f8,0x998d243e,0x032628f9}},	// [1700] _dich, _gran_, _ćeš_, адан,
   {{0x6d5d28fa,0x656f1fce,0xfaa628fb,0x60c9a8fc}},	//   _ehsa, _eich, ражо, _abem,
   {{0x63ad1897,0xa2bd80bc,0x60c9838a,0xb87b016a}},	//   aran, _शान्, _bbem, ldía,
   {{0x629aa8fd,0x2ba6901c,0x26dea8fe,0xfce628ff}},	//   zato, _खिला, _sato_, _томо,
   {{0x26dea900,0x7d0298d6,0xb87b05e4,0xdb09816a}},	//   _pato_, _roos, ndía, nteó,
   {{0x656f2901,0x69c19da3,0xadc30032,0x3d118091}},	//   _zich, ktle, _atẹg, _báwo_,
   {{0x656f2104,0xfaa32902,0xdd978048,0x7de08019}},	//   _yich, _фасо, ашы_, dásá,
   {{0x629a8077,0x26de80a4,0x3d11846d,0x44f4a903}},	//   wato, _wato_, _dáwo_, спис,
   {{0x26de801b,0x2fc0022c,0x629aa904,0x69c18035}},	//   _tato_, _nqig_, tato, etle,
   {{0x68e0a905,0xe8d90104,0x5b148364,0x31782906}},	//   _hamd, _thị_, смот, _kurz_,
   {{0x2904a907,0x257c0013,0x13cf00c8,0xbcfb2908}},	//   _koma_, _níl_, রিয়, _miér,
   {{0x68e2a909,0x27e90205,0x2904a90a,0x644686ae}},	//   ndod, _pran_, _joma_, ükis,
   {{0x212b290b,0x2f1400f2,0x656f290c,0xd83b0048}},	//   rich_, _säga_, _rich, тэн_,
   {{0x656f290d,0x212b01e4,0x69dc007a,0x69ce290e}},	//   _sich, sich_, _osre, _opbe,
   {{0x656f022e,0x2d8505f8,0x35e405a8,0x69c1890d}},	//   _pich, ële_, оцтв, ctle,
   {{0x2f140006,0x2904829b,0x5c750a95,0xfc3f002a}},	//   _väga_, _noma_, слат, _adía_,
   {{0x63ad290f,0x2129036e,0x656f2910,0x68e2831d}},	// [1710] uran, _imah_, _vich, ddod,
   {{0xf1da8063,0x656f02af,0x59da92ee,0x63ad2911}},	//   _बनान, _wich, _बनार, rran,
   {{0x656f2912,0x63ad16b2,0x644f009a,0xc69202f6}},	//   _tich, sran, _wyci, _מאי_,
   {{0x2904a913,0x63ad2914,0xc8798059,0x68e08114}},	//   _coma_, pran, _başa_, _camd,
   {{0x27e9a915,0x68e0809c,0x752d2916,0x6b5d8866}},	//   ían_, _damd, miaz, lège,
   {{0x6298a917,0x81cd80c8,0x7bdd0051,0x752d2918}},	//   _nevo, রিত_, _issu, liaz,
   {{0x63a2a919,0xe7f38063,0x816b8071,0x692b001b}},	//   _avon, _आपका_, _араб_, vřen,
   {{0xce380bea,0x2904a91a,0x752d291b,0x25a9a91c}},	//   יאות_, _goma_, niaz, čal_,
   {{0x629894f9,0xe784a91d,0x7de08065,0x3015a4dc}},	//   _bevo, _духо, tásá, _удар,
   {{0x69c1a91e,0xf7708013,0x6b89a91f,0xc2e98065}},	//   ttle, _قال_, rpeg, اعظم_,
   {{0x7c3b0125,0x395f81c0,0x6b89a920,0x6298a921}},	//   _þurf, _khus_, speg, _devo,
   {{0xa3d281ce,0x443d81c0,0x628e807b,0xc8798850}},	//   _हैक_, _txw_, ðbor, _yaşa_,
   {{0xe28e8ae7,0x43858307,0x752d2922,0x7d1ba923}},	//   _на_, _التق, diaz, mhus,
   {{0x6298a539,0xe7fa816f,0x7d1ba924,0x68e2a925}},	//   _gevo, ्हता_, lhus, zdod,
   {{0xba9a8051,0x63a2883d,0x7bdd19c6,0x1a65853d}},	//   _עסקי, _zvon, _assu, _دیدی_,
   {{0x31a382bb,0x6143120c,0x2bac0a27,0x6281a926}},	//   mız_, _неща, _चिदा, lclo,
   {{0x2904a927,0x68e0a928,0xed5700a9,0xdb098216}},	// [1720] _roma_, _ramd, сот_, lteñ,
   {{0xb87b2929,0x2904a92a,0x6281a92b,0x394d810c}},	//   ndín, _soma_, nclo, _akes_,
   {{0x31a3a92c,0x58868084,0x7bdd0c56,0xdb0984c3}},	//   nız_, была, _essu, nteñ,
   {{0x752d292d,0x395fa92e,0x75ca8085,0x61fc85ec}},	//   ciaz, _chus_, _nəza, ärli,
   {{0xe1e789d7,0x68e2a92f,0x7d1ba930,0xc7968190}},	//   _کس_, rdod, dhus, ёрды,
   {{0x2904913b,0x44202931,0xdb04016a,0x99760049}},	//   _woma_, mzi_, briá, _гуаш,
   {{0x63a28125,0x69dc0a20,0x6d410125,0xacf891d2}},	//   _svon, _usre, élag, инку_,
   {{0x629e2932,0x7d1ba933,0x75ca8085,0x186aa934}},	//   lapo, ghus, _cəza, _баби_,
   {{0x44201167,0x7d0601e2,0xa3b383b7,0x77e20a27}},	//   nzi_, _moks, जूल_, गटोक_,
   {{0xbea3a935,0x629e2936,0x752d2937,0x6281a938}},	//   _наук, napo, ziaz, gclo,
   {{0x60f92939,0x9cca8b71,0x14ca8009,0x8afb007c}},	//   ання_, _была_, _были_, אליז,
   {{0xeb9a87b6,0x629e02e8,0xe8d900ff,0x63a282f7}},	//   _бид_, hapo, _thọ_, _tvon,
   {{0x2571805c,0x629e293a,0x6ebf800f,0x6298a93b}},	//   _ušla_, kapo, ल्कु, _tevo,
   {{0x4420293c,0x657a94aa,0x543b80be,0x1ddc9834}},	//   dzi_, _kuth, _געדא, _मनात,
   {{0x918688ca,0x4420293d,0x50c8864a,0x752d293e}},	//   _اجتم, ezi_, रभाष, tiaz,
   {{0x2129293f,0x7a0a8085,0xa3e50327,0x2f0b821e}},	//   _umah_, rətd, पटल_, _høgt_,
   {{0x2d580153,0x60cd2940,0x752d0f92,0x657aa941}},	// [1730] сить_, _ibam, riaz, _luth,
   {{0x629e2942,0x3f890187,0x394b1ed6,0x249902c4}},	//   gapo, _itau_, locs_, _wesm_,
   {{0xe5c7235b,0x395f81c0,0x44202943,0x657a89c4}},	//   _успо, _phus_, azi_, _nuth,
   {{0x63b62944,0x764482d0,0xe1f001a8,0xfbd00061}},	//   buyn, ğiyl, عسل_, بتہ_,
   {{0x7bc413df,0x2b930bca,0x657a8051,0xb4db026b}},	//   ctiu, _ریاس, _auth, _ajàg,
   {{0x6b8d2945,0x079c0039,0xdb231a57,0x31a3807e}},	//   mpag, נסול, örän, yız_,
   {{0x4519a39a,0x6b8d2946,0xe8d90028,0x7d060214}},	//   иция_, lpag, _nhỏ_, _yoks,
   {{0x69c52947,0x75ca8085,0x394b023e,0xdb1b8118}},	//   mthe, _qəza, jocs_, rtuí,
   {{0xfc318307,0x31d184e5,0x3f8910af,0x7d1b8370}},	//   بحث_, तब्ध, _ntau_, rhus,
   {{0x657a91e8,0x693c9807,0x60cd2948,0x7d1ba949}},	//   _futh, nčen, _abam, shus,
   {{0x4420294a,0x3f89048f,0xb87b294b,0x657aa94c}},	//   zzi_, _atau_, rdín, _guth,
   {{0xc689294d,0xe56e835f,0x69c50cac,0x291d8683}},	//   _יא_, _із_, ithe, nhwa_,
   {{0x31a383bf,0x81c100ab,0xfaa58196,0x2f10851e}},	//   sız_, ্টি_, _дало, _bàgh_,
   {{0x6b8d0f33,0x212f81e4,0xe3b0a94e,0x69c5294f}},	//   dpag, high_, _سره_, kthe,
   {{0x693c816b,0x366a27d4,0x78a9a950,0xdb098661}},	//   dčen, раво_, _odev, nreí,
   {{0x7ae3a951,0x4420011e,0x2d78017f,0x81c100ab}},	//   _hant, tzi_, _očev_, ্টা_,
   {{0x7ae3861b,0x629e049f,0x66e60003,0x7d060b40}},	// [1740] _kant, tapo, _допа, _voks,
   {{0x78a98012,0x249f81c5,0x7bc42952,0x44200235}},	//   _adev, haum_, rtiu, rzi_,
   {{0x44200065,0x7bc42953,0x68e42954,0xe9da2955}},	//   szi_, stiu, _kaid, рке_,
   {{0x6b8d2956,0x26d82957,0x777b8079,0x29020796}},	//   bpag, lero_, _buux, njka_,
   {{0x2ca02958,0x657aa959,0x795d03f8,0x27ed9c6a}},	//   maid_, _suth, néwa, _cren_,
   {{0x26d8295a,0xfdfe0e18,0xf413004c,0x7ae3a95b}},	//   nero_, _उपास_, _חפש_, _nant,
   {{0x63a4295c,0x27eda95d,0x629c0029,0xd5b080f7}},	//   lsin, _eren_, _iero, رفة_,
   {{0x7ae382b5,0x68e40046,0x291da95e,0xf1c303fb}},	//   _aant, _naid, chwa_, žší_,
   {{0x7ae3a148,0xa2ca2714,0x629c295f,0xdddc01dd}},	//   _bant, स्थ्, _kero, jbrž,
   {{0x26d82960,0xbcfb00f7,0x3d1880d7,0xdb0d0118}},	//   jero_, _mhéa, _déwa_, traé,
   {{0x7ae3a961,0x26d82962,0x629c2963,0x27e02964}},	//   _dant, dero_, _mero, _asin_,
   {{0x645c8086,0x2ca00074,0x7c65803d,0x68e42965}},	//   ərin, jaid_, _کامل, _caid,
   {{0xb4d69344,0x26d82966,0xc05b0558,0xb4b6a967}},	//   ाजी_, fero_, рін_, जली_,
   {{0xa3d785e8,0x629c1c17,0x26d80e4d,0xf6518065}},	//   ाबर_, _nero, gero_, _آئے_,
   {{0xd49b0ae7,0x6b8d2968,0x27e004be,0x68e42969}},	//   ира_, wpag, _esin_, _faid,
   {{0x68e4296a,0x7ae3a96b,0x25ad1fd8,0x63a4296c}},	//   _gaid, _zant, čel_, fsin,
   {{0xbcfb0013,0x63a4296d,0x26d8296e,0x7ae3a96f}},	// [1750] _chéa, gsin, bero_, _yant,
   {{0x68e400f6,0xbcfb0307,0xa3ac000f,0x6b8d2970}},	//   _zaid, _dhéa, _गिर_, rpag,
   {{0xa2bd81ab,0x212f80f7,0x26c10133,0x291d805d}},	//   _शास्, tigh_, _icho_, thwa_,
   {{0xa2ca824c,0xbcfb0013,0x2ca02971,0x69c52972}},	//   त्त्, _fhéa, caid_, rthe,
   {{0x629c2973,0xf484003d,0x212f8c5e,0x2fc6a974}},	//   _fero, _تاپی, righ_, gtog_,
   {{0x291d9af0,0x629c2975,0x69c52976,0x212f81a8}},	//   shwa_, _gero, pthe, sigh_,
   {{0x7ae3a977,0x6ecd000c,0x6d44a978,0x61ee01a1}},	//   _rant, द्यु, čian, _grbl,
   {{0x7ae3933b,0x27eda979,0x6285297a,0xd4d9835f}},	//   _sant, _tren_, lcho, ські_,
   {{0x26c105a4,0x629c0c2e,0x26d8297b,0x27eda97c}},	//   _ocho_, _yero, yero_, _uren_,
   {{0x6285297d,0x68e4297e,0x26c1022c,0x629c297f}},	//   ncho, _said, _ncho_, _xero,
   {{0xdb0d02ba,0x26d815a4,0x68e42980,0x63a42981}},	//   ntañ, vero_, _paid, zsin,
   {{0x26c12982,0x7c2d9be7,0x9f4481df,0x63a42983}},	//   _acho_, _žaru, _irmá_, ysin,
   {{0x26d82984,0x2ca00006,0x68e42985,0x62852986}},	//   tero_, vaid_, _vaid, kcho,
   {{0x7ae38282,0x62852987,0x25ac026f,0xbbe9804e}},	//   _uant, jcho, ádlo_, _پرچم_,
   {{0x26d82988,0x62852989,0xdb0d00e7,0x68e4298a}},	//   rero_, dcho, traî, _taid,
   {{0x63a4298b,0x629c298c,0x26d8298d,0xb4e606af}},	//   tsin, _sero, sero_, पये_,
   {{0xa5070098,0xd46710ca,0x61ee298e,0x1d07235b}},	// [1760] чета_, зите_, _srbl, чети_,
   {{0x63a4298f,0x2ca02990,0x6b50016d,0x6aa18b81}},	//   rsin, said_, vägs, nalf,
   {{0x629c2991,0x2ca017f6,0x63a41527,0xc8b50019}},	//   _vero, paid_, ssin, _علیک,
   {{0x63a42992,0xbcfb00f7,0x629c2993,0x00000000}},	//   psin, _théa, _wero, --,
   {{0x28c110be,0x629c2994,0x4abda296,0x6285016b}},	//   ष्टि, _tero, ्भाव, bcho,
   {{0x656280f1,0x657e005d,0x45d4a995,0x6285051e}},	//   _shoh, _kuph, докс, ccho,
   {{0x3981a996,0xc1da800f,0xdb04016d,0x7c240087}},	//   _nós_, _बनेग, rriä, lzir,
   {{0xdce42997,0x48e38af2,0xb4d693e5,0x7d042998}},	//   kmič, _посв, ाजे_, njis,
   {{0xd943838d,0x7c242999,0xa2bd9834,0x614389b5}},	//   _чети, nzir, _शाश्, _чета,
   {{0x645c8201,0xdce426b5,0xfbcf80a0,0xef178009}},	//   əril, dmič, اتي_, _ему_,
   {{0xa2c10540,0x58d90b79,0x6562a99a,0x867581e2}},	//   र्ट्, одня_, _thoh, _жыцц,
   {{0xdb1ba99b,0x2d570214,0x69cd86a7,0x62850690}},	//   rtuá, rçek_, _तहरी, zcho,
   {{0x506404ae,0xdb1b8187,0x75ca8085,0x6aa18c0b}},	//   етра, stuá, _məzm, balf,
   {{0x39818013,0x7c24299c,0x6aa1823e,0xf53f021e}},	//   _fós_, dzir, calf, _sjå_,
   {{0x78a28a9e,0x6614128a,0x97579101,0x9f44128a}},	//   kaov, _čeká, פילו_, ímá_,
   {{0xd23b804c,0x7d04020f,0xe945026a,0x2a3b81c6}},	//   _לגול, gjis, _ترتی, _לעומ,
   {{0x6285299d,0x2b510267,0x3ce681a1,0x6f010061}},	// [1770] tcho, _pkzc_, _maov_, ölcs,
   {{0x212da99e,0x501c01c6,0x628513ff,0x4424a99f}},	//   _smeh_, _לוחו, ucho, izm_,
   {{0xceb2093f,0x628529a0,0xcb138158,0x69c887f1}},	//   _ביי_, rcho, עלע_, ntde,
   {{0x628529a1,0xf8bf29a2,0x7c240bcf,0xb4d68327}},	//   scho, ngé_, bzir, ाजो_,
   {{0xdb0d0ef3,0x31648115,0xf8bf0036,0xc615a9a3}},	//   stañ, _dhmz_, liés_, तन्य_,
   {{0x8ae4035f,0x3ea329a4,0xdb0d0187,0x6440050b}},	//   _післ, najt_, duaç, _žmig,
   {{0x3164826c,0xa3e5000d,0x77770609,0xdb0d01a8}},	//   _fhmz_, पटक_, _mixx, nraí,
   {{0xfdf80039,0x7ae729a5,0x78ad0a03,0x3d18810c}},	//   לצות_, _hajt, _ndav, _déwo_,
   {{0x6aa1a9a6,0x04778065,0x7ae7007a,0x6569a9a7}},	//   talf, _ہلاک_, _kajt, rmeh,
   {{0x394f80eb,0x398183a7,0x6569a9a8,0xc9a98198}},	//   logs_, _pós_, smeh, овое_,
   {{0xd946266e,0x7ae729a9,0x7d1d29aa,0x645c8085}},	//   дени, _majt, _olss, ərim,
   {{0xcea9004c,0x7ae729ab,0xf8bf29ac,0x3981a777}},	//   _כי_, _lajt, ggé_, _vós_,
   {{0xd9aa01a2,0xbcfb00e7,0xe7f0881f,0xbbeb80d7}},	//   _चट्ट, _phén, चिया_, _درام_,
   {{0xdb0980f7,0x69d500f3,0xf8bf0036,0xdce429ad}},	//   breá, _opze, fiés_, rmič,
   {{0xbb5284e3,0xdb0d0013,0xc10600f7,0x63bba9ae}},	//   _جنوب, graí, _يوتي, luun,
   {{0x2cbf8074,0x29190168,0x7d0b8061,0x2d53a9af}},	//   ngud_, ërat_, _jogs, mães_,
   {{0x3ce60038,0x7bc9a9b0,0x7d0429b1,0x63bba9b2}},	// [1780] ľov_, nteu, rjis, nuun,
   {{0xe8d90142,0xa3cf1a8f,0x44630073,0x3ce600e1}},	//   _thể_, _शहर_, твув, žov_,
   {{0xaacfa8d7,0xa50a29b3,0x3ce9151e,0x7ae729b4}},	//   त्यक, _дена_, bdav_, _dajt,
   {{0xdb0d007b,0x7bc9a9b5,0x3cf90118,0x693c81d6}},	//   stað, kteu, _gnsv_, mček,
   {{0xd12f83f8,0x10a3a9b6,0x98a38991,0x87da9c2c}},	//   جمن_, тичн, тиче, تباس_,
   {{0x6d448110,0x63bb8079,0xaacf8107,0x644602f9}},	//   čiam, duun, त्मक, _ixki,
   {{0x7d0ba9b7,0x60c402a5,0x98a9026c,0x69c8a9b8}},	//   _bogs, _ocim, _smač_, xtde,
   {{0xdb0d0073,0x7ae72577,0x63bba9b9,0xfbaa862c}},	//   tuaç, _zajt, fuun, отой_,
   {{0x7d0b81e0,0x7ae701c0,0xaec6a9ba,0x693c928a}},	//   _dogs, _yajt, _обал, yčej,
   {{0x60c40073,0x764d8182,0x1f63a2e9,0x59d205fb}},	//   _acim, şaya, _акум, _सहार,
   {{0xe13529bb,0x195901bb,0xdb0429bc,0x81d68264}},	//   енны, заны_, friú, সিভ_,
   {{0x26dca9bd,0x7d0b80b9,0x27f229be,0xdb040036}},	//   levo_, _gogs, _bryn_, ssiè,
   {{0x7bc9a9bf,0x78a09142,0xf8bf00e7,0x69c8a9c0}},	//   cteu, _memv, rgé_, stde,
   {{0xdef8053b,0xdb0d29c1,0x26dc80e5,0xf8bf0866}},	//   мыс_, traí, nevo_, tiés_,
   {{0xcad78051,0x7ae70019,0x3ea329c2,0x7d1d02c4}},	//   _חוות_, _rajt, rajt_, _plss,
   {{0x7ae729c3,0xa2ca8d14,0xf8bf00e7,0x3ea329c4}},	//   _sajt, त्र्, riés_, sajt_,
   {{0x29190029,0x24580009,0x7ae729c5,0x60dd0123}},	// [1790] ūras_, дать_, _pajt, mesm,
   {{0x60dd29c6,0x26dca9c7,0xbcfb00e7,0xc8798087}},	//   lesm, jevo_, _théo, _iaşi_,
   {{0x7ae729c8,0x26dca9c9,0x51840110,0x85750009}},	//   _vajt, devo_, вуча, _плох,
   {{0x25f4825e,0x60dd29ca,0x2561808b,0x63b629cb}},	//   ्मनी_, nesm, kóla_, bryn,
   {{0x24b600be,0x63bb8079,0xf8bf00e7,0x7ae729cc}},	//   _אהרן_, xuun, chée_, _tajt,
   {{0x656d29cd,0x2b0003eb,0x2f188198,0x62830088}},	//   lmah, राणु_, мочь_, žnob,
   {{0x60dd29ce,0x6aa529cf,0x62888216,0x9f400362}},	//   kesm, mahf, dcdo, _criù_,
   {{0x7bc9a9d0,0x656d29d1,0x63bba9d2,0x3ea129d3}},	//   tteu, nmah, tuun, _leht_,
   {{0x3134a159,0x2fc901c0,0x656d011b,0x6d4280c3}},	//   _ретр, _nqag_, imah, _djoa,
   {{0x291f8282,0x656d29d4,0x26dc847f,0x7bc9a9d5}},	//   _hlua_, hmah, cevo_, rteu,
   {{0x68e99083,0x656d09ca,0xf2d200be,0x68fba9d6}},	//   _kaed, kmah, נעט_, _knud,
   {{0xaacf024c,0x4acf06bf,0x7bc980e7,0x656d026c}},	//   स्तक, स्तव, pteu, jmah,
   {{0x7c3b29d7,0x395e00eb,0x653a80be,0x6aa500b9}},	//   _žurn, ēts_, _צענד, kahf,
   {{0x6d5b820f,0x6446008e,0x63a9a9d8,0xbcfb09c4}},	//   llua, _rxki, msen, _dhém,
   {{0xceb29a15,0x63a99da3,0xf8bf026f,0x24f61444}},	//   טים_, lsen, riér_, нчар,
   {{0x2edc800d,0x63b629d9,0xfce30171,0x693c81ac}},	//   _यस्त, tryn, лосо, rček,
   {{0x63a9a9da,0x6d5ba9db,0x6b4b0061,0xab6629dc}},	// [17a0] nsen, ilua, lügy, евал,
   {{0x3ea10352,0x63a9a9dd,0x68fba9de,0x291f8f3e}},	//   _geht_, isen, _anud, _alua_,
   {{0x64a6260a,0xda0f83eb,0x81cd80ab,0x26dca9df}},	//   _пана, ाहित_, রিক_, vevo_,
   {{0x92c20a49,0xc7c69b1c,0x63a9a9e0,0x4fc68103}},	//   ্যে_, ески, ksen, еска,
   {{0xb05b0106,0x26dca9e1,0x98ab0087,0x6d5ba9e2}},	//   lfär, tevo_, lică_, dlua,
   {{0x63a9a9e3,0x290d8176,0xde588084,0x36d4a9e4}},	//   dsen, _eoea_, малі_, токр,
   {{0xd91099f7,0xe3570451,0x78a6003a,0x434329e5}},	//   _پیش_, _נשלח_, kakv, _серв,
   {{0xafe69631,0x628a826c,0x26dc8267,0xd90d881b}},	//   _побл, _sffo, sevo_, _ویل_,
   {{0xcf469af1,0x6459a9e6,0x26dc847f,0x60c281f6}},	//   _знай, _cywi, pevo_, mgom,
   {{0x21200455,0x9ad281bc,0x7a0a8085,0xef1981b9}},	//   _alih_, _bịag, bətl, _tuża_,
   {{0x2258813c,0x6d5ba9e7,0x673500f1,0x75d395a9}},	//   ærk_, blua, vizj, _ميلا,
   {{0x60c2a9e8,0x28c60ebf,0x98ab0087,0x67350035}},	//   ngom, _वाणि, dică_, wizj,
   {{0x60dd29e9,0xac9781a8,0x2d8129ea,0x64598114}},	//   resm, _أنها_, _suhe_, _gywi,
   {{0x98ab0087,0xb05b05ec,0xb6e4096b,0x60dd29eb}},	//   fică_, ffär, люск, sesm,
   {{0x248901e0,0xa01b0019,0x6d408a53,0xaa57a9ec}},	//   tcam_, nböz, onma, _пишу_,
   {{0x7aeaa9ed,0x6d40a9ee,0x81cd80c8,0x92bd00ab}},	//   _haft, nnma, রিখ_, _আসে_,
   {{0x248929ef,0x7aeaa9f0,0x7ff701a8,0x6d40a9f1}},	// [17b0] rcam_, _kaft, _أسعا, inma,
   {{0xdbc78074,0x656d29cd,0x248929f2,0xdb098187}},	//   _tööp, smah, scam_, rreç,
   {{0x6b828098,0xc3338039,0x248929f3,0xaca30133}},	//   _luog, נוע_, pcam_, _amụb,
   {{0x752429f4,0x7aeaa9f5,0x9f5206c4,0x41d201a2}},	//   chiz, _laft, _aryè_, _सहरस,
   {{0x2571812b,0x5eaa80ab,0x3d0489c8,0x672380f1}},	//   _ušli_, চ্ছে, वाने_, thnj,
   {{0x44290010,0x6d40a9f6,0x141a01c6,0x63bf0037}},	//   mza_, enma, _חושב, muqn,
   {{0x7d0f0061,0xb89581a8,0x661881d6,0x777a9fe7}},	//   _kocs, _للأع, _čaká, _ditx,
   {{0x63a9a9f7,0x442929f8,0x67238168,0x7a0a8085}},	//   tsen, oza_, shnj, rətl,
   {{0x6d5b8867,0x777aa9f9,0x25a0812b,0x98ab0087}},	//   rlua, _fitx, ćila_, zică_,
   {{0x442929fa,0x765a80f1,0x7aea8bfe,0x777a8cdb}},	//   iza_, _fyty, _caft, _gitx,
   {{0x7aeaa9fb,0x3ea7a9fc,0x63a9a9fd,0x7bcd0198}},	//   _daft, mant_, ssen, htau,
   {{0x3ea79702,0x63a98721,0x61f50ee1,0x27260129}},	//   lant_, psen, _mrzl, _kông_,
   {{0xa3e593d9,0x7d09920e,0x442929fe,0x88e300ab}},	//   _पनि_, mjes, jza_, যাংক,
   {{0x3ea7a9ff,0x7d09aa00,0x44292a01,0x98ab002e}},	//   nant_, ljes, dza_, tică_,
   {{0x7d0f2a02,0x44292a03,0x80d28b75,0xed5a2a04}},	//   _bocs, eza_, ण्डे, дов_,
   {{0xed431982,0x98ab0087,0x3d0483db,0x7d09aa05}},	//   ансп, rică_, वाये_, njes,
   {{0x75ca8201,0xed570003,0x2726001c,0x7d0f0706}},	// [17c0] _vəzi, тот_, _nông_, _docs,
   {{0x693caa06,0x3ea7aa07,0x752400b4,0x81bc80eb}},	//   nčev, jant_, shiz, dzēj,
   {{0x44290012,0x3ea7aa08,0x7d1baa09,0x7d09aa0a}},	//   aza_, dant_, kkus, kjes,
   {{0x6ec4a774,0x272600ff,0x44292a0b,0xb87b2a0c}},	//   _राहु, _bông_, bza_, rdív,
   {{0x27260142,0x44290063,0xb91d01bc,0x2ba90ad5}},	//   _công_, cza_, _anyụ_, _चौपा,
   {{0x3ea7aa0d,0xcf9300be,0xef19809a,0x272600ff}},	//   gant_, סטו_, _dużo_, _dông_,
   {{0x20008c6e,0x644e8085,0x7afe823e,0xdb0401df}},	//   ţii_, əbiy, _òpti, quiñ,
   {{0x7aea84dc,0x7d09aa0e,0x7d1baa0f,0xaacf909b}},	//   _saft, gjes, gkus, त्सक,
   {{0x3ea7aa10,0x6aa3aa11,0x6d408d1a,0xafe397c7}},	//   bant_, _benf, rnma, _котл,
   {{0x3ea7aa12,0x5186aa13,0x2d6e801b,0xd764803d}},	//   cant_, кума, _přes_, _صنای,
   {{0xc333004c,0x691387d9,0x44292a14,0xaad40c1c}},	//   שות_, _içer, zza_, ठ्यक,
   {{0x78a412f5,0x3f84aa15,0x44292a16,0x7bcd0084}},	//   _ceiv, _kumu_, yza_, ytau,
   {{0xead49641,0x99640071,0x3f849325,0x7c298035}},	//   _боль, ртэл, _jumu_, czer,
   {{0x7bc0aa17,0x07a40048,0x3f8482ec,0x7f942274}},	//   mumu, раён, _mumu_, рарх,
   {{0x5faf0076,0x4b7b80be,0x3f848c2e,0xd37b8e82}},	//   _झटकल, _קאוו, _lumu_, _קרוט,
   {{0x44292a18,0x7bcd2a19,0x3ea7aa1a,0xaac618b1}},	//   tza_, ttau, zant_, र्घक,
   {{0x2d580364,0x44292a1b,0x3ea7aa1c,0x8aa70b5b}},	// [17d0] тить_, uza_, yant_, вред,
   {{0xd5a48986,0x27e9026b,0x8c3d82bb,0x7bcd2a1d}},	//   _وہ_, _isan_, daşl, rtau,
   {{0x3ea7aa1e,0x44292a1f,0x68ed2a20,0x8af78201}},	//   vant_, sza_, _kaad, _şəki,
   {{0x7bc0aa21,0x4429008e,0xb7d5846d,0x213901c6}},	//   kumu, pza_, _aṣaw, nish_,
   {{0x7bc0aa22,0x68ed2a23,0x7d09920e,0x2ca92a24}},	//   jumu, _maad, vjes, maad_,
   {{0x68ed2a25,0x2ca90079,0x39ae8084,0xdce98267}},	//   _laad, laad_, kęs_, rmeč,
   {{0x3ea7aa26,0x657d2a27,0xed59aa28,0x41e40084}},	//   rant_, _kish, нок_, _кіта,
   {{0x7983aa29,0x3ea7aa2a,0x61fa0019,0x272600ff}},	//   _runw, sant_, _átla, _tông_,
   {{0x657d2a2b,0x7d09aa2c,0x60c98267,0xbcfb0013}},	//   _mish, rjes, _icem, _chéi,
   {{0x657d26b4,0x63ad2a2d,0x78a42a2e,0x645d2a2f}},	//   _lish, isan, _seiv, _mysi,
   {{0x68ed2a30,0x7c298117,0xc6928158,0xa0a61e0b}},	//   _baad, szer, _האב_, ланд,
   {{0x3ea59c6d,0x63ad2a31,0x8c3d8182,0x657d2a32}},	//   _helt_, ksan, laşm, _nish,
   {{0xb8ec131d,0x7bc0aa33,0x6d59aa34,0x68ed2a35}},	//   _ला_, cumu, _ikwa, _daad,
   {{0x2d85aa36,0x63ad2a37,0x248daa38,0xf53981ac}},	//   _kule_, dsan, lcem_, liť_,
   {{0x27e92a39,0x1dc6820e,0x63bb80eb,0x7ae1aa3a}},	//   _esan_, रूपत, lrun, melt,
   {{0x28d30076,0xaacf86de,0x68ed0ef2,0xf53981ac}},	//   ध्दि, त्रक, _gaad, niť_,
   {{0x69c1aa3b,0xb7be80c8,0x63ad2a3c,0x2fcd81c0}},	// [17e0] lule, _ইন্ট, gsan, _nqeg_,
   {{0x7ae1aa3d,0x29000282,0xb87b0019,0x81d680ab}},	//   nelt, _hnia_, rdít, সির_,
   {{0x2b898104,0x63bb8352,0x69c1aa3e,0xe8d90028}},	//   _lúc_, hrun, nule, _nhớ_,
   {{0x645d1da3,0x657d2a3f,0x6d598870,0x29120388}},	//   _fysi, _gish, _nkwa, _joya_,
   {{0x69c18fc4,0xf53981ac,0x7ae1aa40,0x63ad2a41}},	//   hule, diť_, kelt, csan,
   {{0x6d441c4c,0x6d59aa42,0x69c1aa43,0x6d5602ed}},	//   lnia, _akwa, kule, loya,
   {{0x63bb82af,0x25a082a5,0x657d0ab4,0xb87b2a44}},	//   erun, ćilo_, _yish, ndír,
   {{0x69c1aa45,0x7bc0aa46,0x6d442a47,0x39ae8110}},	//   dule, tumu, nnia, vęs_,
   {{0x68ed2a48,0x63bb8a64,0xd90d8065,0x6d442a49}},	//   _raad, grun, _تین_, inia,
   {{0x68ed2a4a,0x7bc0aa4b,0x29002a4c,0x6d562a4d}},	//   _saad, rumu, _ania_, hoya,
   {{0x69c1aa4e,0x29122a4f,0xdd8f8077,0x7bc0aa50}},	//   gule, _boya_, _فول_, sumu,
   {{0x68ed02c1,0x6d440069,0x2ca902a3,0x63ad2a51}},	//   _qaad, jnia, xaad_, ysan,
   {{0x9cd78051,0x657d2a52,0x68ed09f8,0x2900009a}},	//   _תודה_, _rish, _vaad, _dnia_,
   {{0x69dc2a53,0x69c1aa54,0x2d858010,0x6d448110}},	//   _opre, bule, _yule_, čiau,
   {{0x69c1aa55,0x693caa56,0x291200ee,0xfa558019}},	//   cule, nčes, _foya_, _پروگ,
   {{0x657d2a57,0x6d562a58,0x349501e5,0x636b2a59}},	//   _qish, goya, раар, zünd,
   {{0x2ca91ecc,0x27e91e26,0x2b89801c,0x9f400144}},	// [17f0] raad_, _usan_, _xúc_, _crió_,
   {{0x61f8811f,0xf5398038,0x6b5d8722,0x63a2aa5a}},	//   _krvl, ziť_, tègi, _mwon,
   {{0x6d442a5b,0x645d2a5c,0x7aee01c5,0x69dc2a5d}},	//   bnia, _wysi, _dabt, _cpre,
   {{0x417480f7,0x57f58568,0x2ba91513,0x645d0035}},	//   مانس, ипет, _चौथा, _tysi,
   {{0x69dc2a5e,0xf5398038,0x69c1aa5f,0x2d85aa60}},	//   _epre, viť_, zule, _sule_,
   {{0x7d0d2a61,0xc5f980c8,0x2d85aa62,0xbcfb1727}},	//   ljas, _অথবা_, _pule_, _chév,
   {{0xf53981ac,0x28c603eb,0x2ba9000d,0x7c2d2a63}},	//   tiť_, _वालि, _चौता, lzar,
   {{0xdb042a64,0x3ea582af,0xa3b90105,0xa3e922d5}},	//   brió, _welt_, _घटा_, _मना_,
   {{0x7c2d2a65,0xdcfa8029,0x7ae1aa66,0xf53981ac}},	//   nzar, _attē, telt, riť_,
   {{0x69c1aa67,0xadf7015c,0x63bbaa68,0x2d85837b}},	//   tule, ुमान_, rrun, _tule_,
   {{0x6d44031d,0x8e848013,0xf53981ac,0xa2ca06ce}},	//   ynia, _المه, piť_, स्ट्,
   {{0x69c1a09d,0x63bbaa69,0x61f8817f,0x7ae1aa6a}},	//   rule, prun, _drvl, selt,
   {{0xe28e828b,0x53a582fb,0x6d442a6b,0x6d4481ac}},	//   _ма_, _талб, vnia, čiat,
   {{0x69c1aa6c,0xf7721e09,0x38690239,0x6d442a6d}},	//   pule, تاج_, _dzar_, wnia,
   {{0xada61a97,0xe8d90028,0x7aee16bb,0x442daa6e}},	//   рабл, _giữ_, _rabt, lze_,
   {{0x7aee2a6f,0x06af80ab,0xef861e4e,0x7d0d1443}},	//   _sabt, চ্চি, _клип, gjas,

   {{0x69dc2a70,0x2d982a71,0x6d442a72,0xafe61878}},	// [1800] _spre, spre_, rnia, _топл,
   {{0x7aee02a3,0x6aa7026c,0x2561808b,0x442daa73}},	//   _qabt, _cejf, fólk_, ize_,
   {{0x09e604fa,0xfc3f01ca,0x6d562a74,0x7d0d026c}},	//   роен, _veía_, poya, bjas,
   {{0x316d83d3,0x442d8831,0xdb04188b,0x2900a3e5}},	//   _chez_, kze_, trió, ñia_,
   {{0x7aee2a75,0x442daa76,0xe8d9001c,0x3d048075}},	//   _tabt, jze_, _nhờ_, वासे_,
   {{0x6b8480f7,0x442daa77,0xd83f016b,0xe2970a42}},	//   _éigi, dze_, _účel_, _вар_,
   {{0xe1e78064,0x32070009,0x69dc00e1,0x6136017f}},	//   _بس_, änyt_, _upre, ršlj,
   {{0x7c3b02a5,0x6283aa78,0x387f017f,0x7529aa79}},	//   _žuri, _agno, žuri_, ghez,
   {{0x673c01c2,0x394682ba,0xe8d90028,0x6eb681a8}},	//   kirj, mnos_, _chờ_, _نصائ,
   {{0x3d0483b7,0xdb040118,0x7dfc8162,0x661c1235}},	//   वाहे_, oriñ, _păsă, kyrk,
   {{0x7980aa7a,0xdb098020,0x442d838a,0x7c2d0ca9}},	//   _kimw, gueñ, aze_, zzar,
   {{0x7529822e,0x3946aa7b,0x63a29528,0x6d44aa7c}},	//   chez, nnos_, _twon, čias,
   {{0x442d8d38,0x7d02aa7d,0x63a2aa7e,0xdce88110}},	//   cze_, _inos, _uwon, _sudė,
   {{0xdced026f,0xa2c2000d,0x7bdb83c8,0xadc3826b}},	//   rmač, _लाग्, _סקוו, _alẹm,
   {{0xdb00aa7f,0xa6978039,0xeca70226,0x28d7aa80}},	//   gsmå, שכלה_, ијан, ण्डि,
   {{0x7c2d2a81,0xdb0401df,0x80c1016f,0x39468019}},	//   tzar, driñ, _वाटे, jnos_,
   {{0x29e8002e,0x39592a82,0x7bc42a83,0x67da81a9}},	// [1810] _aşa_, moss_, guiu, nājā,
   {{0x7d0d2a84,0x3946aa85,0xd543026b,0xa91d80c3}},	//   sjas, enos_, _bẹ́n, _miže,
   {{0x442daa86,0x6ecd8beb,0x7c2d2a87,0x798080b4}},	//   zze_, _साबु, szar, _bimw,
   {{0x3946aa88,0xe45f0198,0xed4680d7,0x645d82f1}},	//   gnos_, _työ_, _رپ_, üsik,
   {{0x6126007b,0xa91d80ce,0x6d5d1400,0x693c81a1}},	//   _jóla, _niže, _iksa, tčer,
   {{0x66e59d38,0x39469fd3,0xc69500be,0xdee59033}},	//   сока, anos_, זאַ_, соки,
   {{0x7afa008b,0xa3a9a770,0x2d680799,0x3f8917c9}},	//   _ótta, गीन_, ißen_, _luau_,
   {{0x442daa89,0x4c698037,0x7ae508e5,0x69c51a0e}},	//   tze_, лийн_, leht, muhe,
   {{0x3d080076,0xc9528bea,0x442daa8a,0x60dbaa8b}},	//   हाते_, _זמן_, uze_, _ibum,
   {{0x442d8b04,0x7d028353,0x78a9aa8c,0xb87b2a8d}},	//   rze_, _enos, _heev, teín,
   {{0x442daa8e,0x5d8580f7,0x7529805d,0x673c007a}},	//   sze_, _الصل, phez, virj,
   {{0x61262a8f,0x2d6802af,0xf09f077f,0xe8d900ff}},	//   _bóla, eßen_, gbà_, _thờ_,
   {{0xdb0981ca,0xed59807a,0x249f82df,0x3d04aa90}},	//   sueñ, mož_, mbum_, वारे_,
   {{0x6d5d2a91,0x539a8051,0x612619bd,0x249faa92}},	//   _aksa, _עיצו, _dóla, lbum_,
   {{0xdb098c15,0x637012d2,0xd6270af0,0xe164003d}},	//   queñ, läng, боре_, _وضعی,
   {{0x6ab79094,0x2ba9000f,0x4c861db0,0x8a168039}},	//   _आयुर, _चौहा, слав, _לחצו_,
   {{0xd6c30019,0x798080b4,0x673c007a,0x63620187}},	// [1820] _کمپی, _rimw, pirj, lôni,
   {{0xadf985e8,0x27e00091,0x6ac600f7,0x6d5d17ab}},	//   ्मान_, _ipin_, إقام, _eksa,
   {{0x63702a93,0x1efb00be,0x27ed86c4,0xed59aa94}},	//   häng, _עלטע, _asen_, kož_,
   {{0xa2d80540,0xdb042a95,0x78a98282,0x1d0a2a96}},	//   _नॉर्, rriñ, _ceev, _семи_,
   {{0x3946a8d5,0xaab8026a,0x33b50a14,0x7bc42a97}},	//   rnos_, _نگار_, _мёрт, quiu,
   {{0x26ca2a98,0x7d028d11,0x65642a99,0x3946a7aa}},	//   ngbo_, _snos, llih, snos_,
   {{0x3d04800c,0xe7af009a,0x2d822a9a,0x877b03de}},	//   वाले_, _जौनप, _kike_, נאצי,
   {{0x27e02a9b,0x71268277,0xf8b0803d,0x77868009}},	//   _opin_, _ارسل, _آکا_, _глаз,
   {{0x63702a9c,0x7d02807a,0xa3cb073c,0xa2d8001b}},	//   gäng, _vnos, रूप_, न्थ्,
   {{0x2d822a9d,0xaaa8036d,0x636203a7,0x7b39816b}},	//   _like_, गरिक, fôni, lňuj,
   {{0xd5b9835f,0xfbcf826a,0x712700f7,0x23a986a7}},	//   _всі_, وتی_, مرحل, चीबद,
   {{0x59c92a9e,0xa2d80023,0x7d028024,0x63701bd7}},	//   ांतर, न्त्, _unos, länd,
   {{0xa2d3a776,0xdc8e81bc,0x39592a9f,0x26d82aa0}},	//   _बॉक्, _dịtụ_, ross_, ffro_,
   {{0x43748077,0x4ac700d4,0x2d820300,0xe5c70a08}},	//   _بهتر, _लाइव, _aike_, йсбо,
   {{0xa3cb09c8,0xd0470085,0xe18980ff,0x2d822aa1}},	//   रंभ_, _əməl, _hẳn_, _bike_,
   {{0x3eae8352,0x637012d2,0x2d820041,0x6aaaaaa2}},	//   haft_, händ, _cike_, _heff,
   {{0x2d822aa3,0x78a9aaa4,0x06e400ab,0xe50986a7}},	// [1830] _dike_, _reev, মাজি, वाति_,
   {{0x9a8706d2,0xbcfb2aa5,0x2d822aa6,0x8c1b81c6}},	//   суал, _chér, _eike_, אומי,
   {{0x3cfe8076,0x78a9822c,0xa3a909f2,0xd91b99bb}},	//   _शोभे_, _peev, _गौर_, льд_,
   {{0x69c52aa7,0x69c080d4,0x6aaa8198,0x5c070bac}},	//   ruhe, _विनी, _leff, _ляга,
   {{0xf7719168,0xd009aaa8,0xe8d911d3,0x6362041c}},	//   وات_, реле_, _nkọ_, zôni,
   {{0xa2d80bb8,0xb6a593b4,0x2d959e15,0x6aaaaaa9}},	//   न्द्, цикл, орис, _neff,
   {{0x2129059c,0x171c0158,0xe8d92aaa,0x78a9aaab}},	//   _olah_, רווע, _akọ_, _teev,
   {{0x58d48e8e,0x60dbaaac,0x6370016d,0xa63c0039}},	//   _ност, _ubum, täng, טגור,
   {{0x98178077,0x798a81ec,0x395f8102,0x6aaaaaad}},	//   _ابزا, _aufw, _ikus_, _beff,
   {{0x63700884,0xdb160009,0x63620187,0xe9d98eef}},	//   räng, styö, tôni, ако_,
   {{0x9f4901ec,0x7a699324,0x6aaaaaae,0x63702aaf}},	//   _spaß_, ринг_, _deff, säng,
   {{0x628300e1,0x637005ec,0x6362041c,0x6f05027d}},	//   ľnoh, mäne, rôni, _anhc,
   {{0x6d49aab0,0x2d822ab1,0xbf87801c,0xeaaeaab2}},	//   mnea, _rike_, _điển_, _ой_,
   {{0xe299917c,0x1ddd80d4,0x321eaab3,0xd5b800eb}},	//   _так_, _महात, byty_, šām_,
   {{0x6b83aab4,0x395faab5,0x6d49a8a8,0xad3a004a}},	//   _iing, _okus_, onea, ачає_,
   {{0x6d49aab6,0x6b838f68,0x39b580eb,0x6b8baab7}},	//   nnea, _hing, mās_, _kugg,
   {{0x65640877,0x6f172ab8,0x6d498068,0x39b58029}},	// [1840] rlih, _foxc, inea, lās_,
   {{0x6b83aab9,0x6b8baaba,0x6d498083,0xf77212c8}},	//   _jing, _mugg, hnea, _تاب_,
   {{0x63701918,0x39b58341,0x6b83aabb,0xa3a98128}},	//   vänd, nās_, _ming, गीत_,
   {{0x6b83aabc,0x752d2abd,0x69c1832f,0x80668081}},	//   _ling, chaz, irle, овеж,
   {{0x63702a93,0x394d826c,0xbcfb0036,0x69c181ec}},	//   tänd, _djes_, _thér, hrle,
   {{0x6b83aabe,0xd5ba84ad,0x39b58029,0x394daabf}},	//   _ning, аси_, kās_, _ejes_,
   {{0x39b58341,0x63702ac0,0x44200019,0x386d9403}},	//   jās_, ränd, lyi_, _ezer_,
   {{0x6d499581,0x6b83aac1,0x39b580eb,0x6370016d}},	//   gnea, _aing, dās_, sänd,
   {{0x44202ac2,0x6b83aac3,0x25a9805c,0x73fa80ab}},	//   nyi_, _bing, ćala_, েন্ট_,
   {{0x37d000ab,0x2129111e,0xda7aa7ee,0xa3cb0ad5}},	//   িবার, _slah_, иян_, रंत_,
   {{0x39b580eb,0xaacf047d,0x9258aac4,0x28f91b62}},	//   gās_, स्टक, сант_, бень_,
   {{0x394d0003,0x6b83aac5,0xe8d90028,0x6b8baac6}},	//   ões_, _eing, _phố_, _fugg,
   {{0xb97b812a,0x442002a0,0x2129026c,0x6b8baac7}},	//   ינטי, jyi_, _vlah_, _gugg,
   {{0x7d060110,0x4432009a,0x39b581a9,0xa49b07f1}},	//   _anks, dzy_, bās_, _enòl,
   {{0x2129015d,0x752d005d,0x39b580eb,0x61262ac8}},	//   _tlah_, thaz, cās_, _gólo,
   {{0x6d40aac9,0x6b83aaca,0x21292acb,0x4add0a27}},	//   nima, _zing, _ulah_, न्नव,
   {{0x2d8c812b,0x6b83aacc,0x44200019,0x61260118}},	// [1850] _lude_, _ying, gyi_, _móll,
   {{0x6d40a933,0x2d8c8a0f,0x74150019,0x6b83aacd}},	//   hima, _oude_, _ہوجا, _xing,
   {{0x6d40aace,0x69c8aacf,0x7c20831d,0x752d0234}},	//   kima, nude, hymr, phaz,
   {{0x6d4081e2,0xdb098013,0x7c208aa2,0x442000b4}},	//   jima, iseá, kymr, byi_,
   {{0x44320063,0x6d40aad0,0x3d08000f,0x2d8caad1}},	//   czy_, dima, हारे_, _aude_,
   {{0x2d8caad2,0x78ad2ad3,0x68fa00eb,0x3eba00ee}},	//   _bude_, _leav, ētdi, _xdpt_,
   {{0x6d408079,0x69c8aad4,0x6b8b914e,0x6d498cb5}},	//   fima, jude, _sugg, tnea,
   {{0x6b83aad5,0x395f8024,0x39b580eb,0x6126002a}},	//   _sing, _ukus_, vās_, _cóll,
   {{0x6b83aad6,0x3eac806a,0x7f5c0216,0xb4e91d6a}},	//   _ping, _fedt_, yorq, _यसै_,
   {{0x39b58029,0x49c994bc,0x27ffaad7,0x6d498c49}},	//   tās_, блон_, _irun_, snea,
   {{0x644d81e2,0x6b83aad8,0xc4cb009a,0x44322ad9}},	//   _žaid, _ving, िलाओ, zzy_,
   {{0x69c18915,0x70c6016f,0xdce99487,0x39b580eb}},	//   rrle, वलेल, dmeć, rās_,
   {{0x3f85aada,0x39b581a9,0x3f8d8980,0x7f5c1d88}},	//   _kilu_, sās_, _jueu_, torq,
   {{0x2d9611c7,0x7d19aadb,0x69c8aadc,0x6b838010}},	//   зрас, _hows, bude, _uing,
   {{0x80ab0a49,0xe737200d,0x78bb805c,0x69d7022c}},	//   _কার্, чер_, _oduv, jtxe,
   {{0x80da00ab,0x3f85aadd,0x44322ade,0x78ad01ed}},	//   _বোর্, _lilu_, tzy_, _geav,
   {{0x75242adf,0xc1db80d4,0x3b182ae0,0x7af50102}},	// [1860] rkiz, _बहुग, _porq_, _bazt,
   {{0x44321d4b,0x6d40aae1,0x39422ae2,0x3f85930c}},	//   rzy_, zima, liks_, _nilu_,
   {{0x27308104,0xe9da2ae3,0x44320063,0x68f62ae4}},	//   _hàng_, ске_, szy_, _kayd,
   {{0x3f8d81df,0xd910804e,0x39422ae5,0x68f62ae6}},	//   _bueu_, خیر_, niks_, _jayd,
   {{0x6d40aae7,0x68f62ae8,0xa3cb0424,0x78a2aae9}},	//   vima, _mayd, रूद_, rbov,
   {{0x7af500ad,0x2d8caaea,0x273080ff,0x28d186a7}},	//   _gazt, _pude_, _màng_, _हाथि,
   {{0x91e32aeb,0x6d40aaec,0x09e30811,0x7d1981e0}},	//   _поре, tima, _порн, _bows,
   {{0x5398aaed,0xdb98a6bb,0x69c88687,0x2cb201b4}},	//   овия_, ович_, vude, nayd_,
   {{0x27308028,0x7bc9aaee,0x7ae89b59,0x63b6006f}},	//   _nàng_, gueu, tedt, nsyn,
   {{0x59d00063,0xaacc2aef,0x6d40aaf0,0x798e2af1}},	//   _हमार, ालिक, sima, _kubw,
   {{0xc4869895,0x6d40aaf2,0x68f60079,0x78ad0074}},	//   _елек, pima, _bayd, _peav,
   {{0x6f1aa8bd,0x68f601b4,0xa91d80c3,0x27308129}},	//   _hotc, _cayd, _ližn, _bàng_,
   {{0xc05b0196,0xb4e88074,0x27308028,0x69c8aaf3}},	//   сін_, मजी_, _càng_, sude,
   {{0x2730801c,0x7bc40084,0xdb098144,0x69c8aaf4}},	//   _dàng_, driu, breñ, pude,
   {{0x68f603bf,0x78ad2af5,0x7bc40074,0xa4d50b73}},	//   _fayd, _teav, eriu, мові,
   {{0x7bc40037,0x5ec58264,0x68f610ba,0x8d7405de}},	//   friu, ল্পে, _gayd, فاقا,
   {{0x6c54243b,0xdcfa8029,0xc1580051,0x31ae80ab}},	// [1870] екту, _attī, _משהו_, _কমিশ,
   {{0x798e03f7,0x60dd2af6,0x6f1a9e78,0x00000000}},	//   _bubw, lfsm, _notc, --,
   {{0xa3b906af,0x79a42af7,0xa2cfaaf8,0x69c80163}},	//   _घटक_, ерче, _दास्, _ådel,
   {{0x9c13819d,0x3f8584ef,0x81df0264,0x68f62af9}},	//   _kọti, _silu_, তিল_, _xayd,
   {{0xe0d08f24,0x7bc4009f,0x7d199770,0x6d4d02f1}},	//   ازم_, criu, _rows, mnaa,
   {{0xdb1b8548,0x05b1016f,0xdce181b9,0x82371e5c}},	//   truí, _जबाब, _kulħ, _فرزا,
   {{0x25a982a5,0x7d19809a,0x6d4d2afa,0xc5d58a4c}},	//   ćalo_, _pows, onaa, філь,
   {{0x6d4d2afb,0x27ff826c,0xe8d9001c,0xa3e10072}},	//   nnaa, _trun_, _khổ_, _दहा_,
   {{0x47d58013,0x3f85aafc,0x68eb8bda,0x6ece016f}},	//   _زيار, _tilu_, megd, _तालु,
   {{0x81c200c8,0x29092afd,0x80d9800c,0x273080ff}},	//   ্বর_, _anaa_, फ्रे, _ràng_,
   {{0x68f62afe,0x13e600c8,0x39422aff,0x1dc68424}},	//   _payd, নিয়, tiks_, रूआत,
   {{0xd7d1ab00,0x254580eb,0x68f60085,0xe7d181a2}},	//   _समाच, tēlu_, _qayd, _समाप,
   {{0x636b080a,0x39422b01,0x69c501ec,0x7bc98036}},	//   tünl, riks_, hrhe, queu,
   {{0x27308028,0x68f60079,0x6d4d2b02,0x6569805f}},	//   _vàng_, _wayd, enaa, lleh,
   {{0x212d848f,0x4ac700d4,0xa91d8bcf,0x63700106}},	//   _oleh_, _लाजव, _nižo, jäna,
   {{0x6d4d2b03,0x273080ff,0xadf08074,0x798e018f}},	//   gnaa, _tàng_, _अईसन_, _rubw,
   {{0xd467067c,0x04432167,0x3b8601e8,0x6b8700f3}},	// [1880] дите_, ветн, длаг, _bijg,
   {{0x63b60aa2,0x212d8118,0xdcfd00eb,0xd7760b53}},	//   rsyn, _aleh_, _visā, _تابع,
   {{0x212d83ac,0x2eaa016f,0xfe7201a8,0x63b62b04}},	//   _bleh_, करीत, _جدة_, ssyn,
   {{0xeb9f0aa2,0x7bc42b05,0x2d5701b9,0x53a90072}},	//   _brød_, priu, għed_, _चौकश,
   {{0x69c503b2,0x6f1aab06,0x9f4907f1,0xd84f019d}},	//   arhe, _potc, _graó_, lọra_,
   {{0x212d80b9,0xdd9a9577,0x2d868114,0xa91d82d4}},	//   _eleh_, оши_, _sioe_, _fižo,
   {{0x66e00074,0xdce4016b,0x80cf001b,0xa3b0ab07}},	//   ख्यक_, hlič, _थाले, टीन_,
   {{0x6ba5016d,0xdce4007a,0x9c1381bc,0xe73f041c}},	//   _åtgä, klič, _nọsi, mpõe_,
   {{0xf863ab08,0x7c242b09,0xd8d78158,0xa3a98072}},	//   _авто, nyir, _קומט_, गील_,
   {{0x61260125,0x394002be,0x7f4381e8,0xdce4016b}},	//   _fólk, _amis_, cinq, dlič,
   {{0x8e4a80f7,0x656981e0,0x28f92b0a,0xa2cf8cf0}},	//   _بلاك_, bleh, пень_, _दार्,
   {{0xf3888028,0x212d80ee,0xfd4f81bc,0x0c26802e}},	//   _lợi_, _xleh_, _mejọ, _омен,
   {{0x1bf289a3,0xdce4026f,0x60dd007b,0x28d1a120}},	//   _अनिल_, glič, rfsm, _हासि,
   {{0xf53f13c2,0x399383a7,0x4424809a,0x636f8aa2}},	//   _små_, _fãs_, mym_, lønn,
   {{0x1df811e9,0x4424ab0b,0x569402d3,0x6d4d2b0c}},	//   меры_, lym_, таст, tnaa,
   {{0xdce42b0d,0x7af8ab0e,0xa91d8988,0xe8d9001c}},	//   blič, _havt, _rižo, _phổ_,
   {{0x4424ab0f,0x4ea7143d,0x6d4d2b10,0x7af881c0}},	// [1890] nym_, _орна, rnaa, _kavt,
   {{0xdb1606c0,0x656081a8,0x2fc6ab11,0x2d9e806a}},	//   nsyè, homh, drog_, _otte_,
   {{0x69da8009,0x212d81f4,0x69cf8035,0x29d88866}},	//   ntte, _pleh_, ąceg, néa_,
   {{0x69da8364,0x3cfe80d4,0x7c2400b4,0xe8d900ff}},	//   itte, _शोले_, byir, _thổ_,
   {{0x7feb87bd,0x93270b76,0x68ebab12,0x6370089c}},	//   تراف_, _قرآن, regd, männ,
   {{0x4424831d,0x7d1d0019,0x7af8ab13,0x7df38085}},	//   dym_, _hoss, _navt, _həsə,
   {{0x628301ac,0xf388801c,0x212d82d4,0x7f43811c}},	//   ľnos, _gợi_, _tleh_, rinq,
   {{0x6283105e,0x2fc6805c,0x7d1d0364,0x98a01487}},	//   žnos, brog_, _joss, _ilić_,
   {{0x7d1d2b14,0x7df38201,0x2d9e8006,0x3d048540}},	//   _moss, _məsə, _ette_, वाजे_,
   {{0x8c9f80d4,0x3f9f808e,0x7af88115,0x6569ab15}},	//   _ग्रो, _ituu_, _cavt, sleh,
   {{0xa96a18ba,0xcb1204de,0x63702b16,0x38692b17}},	//   зина_, אלי_, känn, _ayar_,
   {{0x7d1d0003,0xfe6e803d,0xdce4007a,0x4424939f}},	//   _noss, _اگه_, tlič, bym_,
   {{0xb4278c2a,0x4424809a,0xdce40289,0x7d0b80d7}},	//   _تعاو, cym_, ulič, _ings,
   {{0xdb1b8e14,0x75298019,0x798981b0,0x8c1a825f}},	//   bruá, lkez, _liew, _מוני,
   {{0x7bdbab18,0xdd920277,0x3d04816f,0x6146031a}},	//   ltuu, اور_, वाचे_, _пека,
   {{0x7989809a,0x7d1d2b19,0xdce41320,0x5ec10264}},	//   _niew, _coss, plič, শ্লে,
   {{0x7d1d2b1a,0x98a0190f,0x7bdbab1b,0x68e42b1c}},	// [18a0] _doss, _alić_, ntuu, _ibid,
   {{0x7d0b82f7,0x3ced822c,0x42562432,0x272b8163}},	//   _lngs, heev_, нтет, _sønn_,
   {{0x7d1d1260,0x3cfb0c28,0x3f920010,0xe8d9001c}},	//   _foss, _लोके_, _huyu_, _chỗ_,
   {{0x69c305e4,0x7bdbab1d,0x2fc68d2f,0x59d228bf}},	//   ánea, ktuu, trog_, दंबर,
   {{0x68e40135,0x7f469a73,0xd43600f7,0xe73f0187}},	//   _mbid, недж, _أعجب, spõe_,
   {{0x69daab1e,0xa8478b53,0x442484e8,0x57f38eef}},	//   ytte, علوم_, vym_, упшт,
   {{0x44248063,0x61262b1f,0x68e42b20,0x63a42b21}},	//   wym_, _eóli, _obid, lpin,
   {{0x612603b0,0x7d1d01df,0x68e42b22,0x98a92b23}},	//   _fóli, _xoss, _nbid, _plač_,
   {{0x3946ab24,0x27340106,0x63a42b25,0x849780f7}},	//   mios_, _känd_, npin, رئيس_,
   {{0x656086be,0x39468196,0x68e42b26,0x3075ab27}},	//   somh, lios_, _abid, _русс,
   {{0xc3331dfa,0x19590a14,0x2bc29244,0xfbc2ab28}},	//   רות_, даны_, _शिवा, _शिवम,
   {{0x3946ab29,0x69daab2a,0x98a900e1,0x6374823e}},	//   nios_, rtte, _tlač_, fànc,
   {{0x7d1d2b2b,0x629c00f1,0x7bdb80f3,0x628e04be}},	//   _ross, _ofro, ctuu, _ogbo,
   {{0x68e42b2c,0x6566008e,0x999e8019,0x254c81d0}},	//   _ebid, _akkh, sztő_, děli_,
   {{0x7d1d2b2d,0x39468110,0x7d0bab2e,0x80a21b91}},	//   _poss, kios_, _yngs, _क्वे,
   {{0x9d180fe7,0x59c5800c,0xc4cb06b7,0x628e2b2f}},	//   ност_, _वितर, िलेख, _agbo,
   {{0x39469986,0xeb93030f,0xf2c704ad,0xdb0d03a7}},	// [18b0] dios_, اظر_, есен, nsaç,
   {{0x69c882d8,0xdb0d2915,0x7989ab30,0xd011804e}},	//   orde, trañ, _siew, یلا_,
   {{0xa2d88b6f,0x2004ab31,0xa7fd8019,0x3946ab32}},	//   _मान्, _armi_, _gyűj, fios_,
   {{0x68fd2b33,0x3946ab34,0x69c88635,0x628e0135}},	//   ndsd, gios_, irde, _egbo,
   {{0x79898051,0x2ca91eb2,0x69c8ab35,0x80098019}},	//   _view, mbad_, hrde, براہ_,
   {{0x2d8b0264,0x2ca90bb1,0x3669a0e4,0xb87b0144}},	//   _hice_, lbad_, мало_, leís,
   {{0x75298065,0x8d558729,0x7d0b826c,0xed59a4b6}},	//   tkez, ктич, _pngs, мок_,
   {{0x394690dd,0x7bdb8198,0x68fd2b36,0x2ca92b37}},	//   cios_, ttuu, jdsd, nbad_,
   {{0x80a22b38,0x7529ab39,0x69c880c9,0x2d932b3a}},	//   _क्षे, rkez, erde, _luxe_,
   {{0x2d8b003b,0x7bdbab3b,0x3eb32b3c,0x69ca03a7}},	//   _lice_, rtuu, _next_, áfeg,
   {{0x7bdb8f1a,0x81df00c8,0x68fbab3d,0x27e904a7}},	//   stuu, তিক_, _kaud, _apan_,
   {{0x61460b9c,0x2eaa04c5,0xfeac877f,0x63748722}},	//   тема, कर्त, _iṣẹ_, tànc,
   {{0x69c89699,0x656d026f,0x20042b3e,0x68fbab3f}},	//   arde, dlah, ími_, _maud,
   {{0x2d8b0083,0x27e900dd,0x80a20701,0x3946ab40}},	//   _aice_, _dpan_, _क्रे, zios_,
   {{0xa3d4035a,0x63bd0186,0x2d8b2b41,0x165924b6}},	//   सून_, _avsn, _bice_, ерть_,
   {{0x2be5959a,0x291f802e,0x68fbab42,0x394684c3}},	//   _कहां_, _noua_, _naud, xios_,
   {{0x3cf4881f,0xb87b2b43,0x63bbab44,0x3946a5dc}},	// [18c0] ्यते_, rfíc, nsun, vios_,
   {{0x63a42b45,0x6f1e02ce,0x5fb70039,0x81e480ab}},	//   rpin, _uopc, _שהיא_, নির_,
   {{0x39468511,0x63a42b46,0x68fbab47,0x2d8b0041}},	//   tios_, spin, _baud, _fice_,
   {{0x63a42b48,0x3eb81bfc,0xd5b80029,0xc7c69da4}},	//   ppin, lart_, šās_, вски,
   {{0x3946ab49,0x68fbab4a,0x291f8012,0x2d802b4b}},	//   rios_, _daud, _doua_, mmie_,
   {{0x394681e2,0x63bbab4c,0xfaa31958,0x2d8b0087}},	//   sios_, dsun, _варо, _zice_,
   {{0x39469f9e,0x41aa0221,0x68fb80e7,0x7afc0af6}},	//   pios_, _іван_, _faud, _iart,
   {{0x7afc2b4d,0x29dc040e,0x68fbab4e,0x3eb80046}},	//   _hart, mía_, _gaud, hart_,
   {{0x29dc2915,0x63bbab4f,0x06b800ab,0x3eb82b50}},	//   lía_, gsun, _জানি, kart_,
   {{0x68fbab51,0x7afc0102,0x77638118,0xc1808135}},	//   _zaud, _jart, conx, _ịghọ,
   {{0x27e901b0,0x29dc040e,0x69c880c9,0x7c3a0201}},	//   _span_, nía_, urde, _ətra,
   {{0xdca6902f,0x7afc020f,0xf8bf0019,0x64a69958}},	//   _ради, _lart, mkék_, _рада,
   {{0xb8eb0076,0xdb04040e,0xb4ae9da7,0x29dc2b52}},	//   _लय_, nsió, करी_, hía_,
   {{0x0ccb0b85,0xcf9380be,0x63a282b8,0x3eb82b53}},	//   िल्म, יטש_, _iton, gart_,
   {{0xd5b80be1,0x80d3800f,0x29dc01ca,0xb8d90264}},	//   кст_, _डाले, jía_, _চা_,
   {{0x29dc02ba,0xa3e6816f,0xdb1b8073,0x7afc2b54}},	//   día_, _पहा_, truç, _aart,
   {{0x3eb32b55,0x3eb80502,0x5c750b01,0x656d0057}},	// [18d0] _text_, bart_, улат, rlah,
   {{0x29dc040e,0x7afc2b56,0xe4e281c4,0x69de2651}},	//   fía_, _cart, क्ति_, ftpe,
   {{0x9a872b57,0x29dc0c15,0x2d8b0025,0xaca301bc}},	//   туал, gía_, _tice_, _alụb,
   {{0x63a2ab58,0x59c59834,0x7afc2b59,0x23c2825a}},	//   _oton, _विसर, _eart, _शिंद,
   {{0xb8db8424,0x3f8c81b9,0x69dc2b5a,0x63a28542}},	//   _आज_, _bidu_, _eqre, _nton,
   {{0x7afc2b5b,0x29dc040e,0x44292b5c,0x543a00be}},	//   _gart, bía_, mya_, _טערא,
   {{0x29dc040e,0x63a2ab5d,0x74d78035,0x02af20c0}},	//   cía_, _aton, _यादृ, टरीन,
   {{0x7afc2b5e,0x7bc9ab5f,0x16b00105,0x752d01f6}},	//   _zart, treu, _जज्ब, nkaz,
   {{0xa855a829,0x7bc980e7,0x0ed300d4,0xbab581bb}},	//   _скач, ureu, _तांड, лёны,
   {{0x63bbab60,0x89a99b4f,0x386dab61,0x7bc9ab62}},	//   rsun, нков_, _iyer_, rreu,
   {{0x63bbab63,0x44292b64,0x3eb82b65,0x63a2ab66}},	//   ssun, hya_, vart_, _eton,
   {{0x7fd605e9,0x44292b67,0x7bc9802e,0x798d02f7}},	//   лігі, kya_, preu, _ciaw,
   {{0xa2e587b6,0x59c594a7,0x6721ab68,0x44290578}},	//   _болд, _विवर, _kolj, jya_,
   {{0x3cfd81c0,0x7d1bab69,0x6d49ab6a,0xa03a83de}},	//   _hawv_, ljus, liea, געשפ,
   {{0xceb29a15,0xa2d88913,0x29dc07f4,0x3cfd81c0}},	//   מים_, _मात्, xía_, _kawv_,
   {{0x7afc2b6b,0xb4ce2b6c,0x29dc040e,0xb4c00c33}},	//   _sart, रले_, vía_, ीले_,
   {{0x7c29ab6d,0x7c3bab6e,0x44292b6f,0x3eb81a25}},	// [18e0] nyer, nzur, gya_, part_,
   {{0x57fb0051,0x3cfd90af,0x7d1b8006,0x7afc00f1}},	//   _טלפו, _lawv_, hjus, _qart,
   {{0x7afc0b71,0x386dab70,0xf77200d5,0xdce28743}},	//   _vart, _ayer_, _پاک_, _skoč,
   {{0x29dc161b,0x7afc2b71,0x44292b72,0x3cfd8069}},	//   ría_, _wart, bya_, _nawv_,
   {{0x7afc2b73,0x6d460182,0x29dc02ba,0x23658042}},	//   _tart, _imka, sía_, kolj_,
   {{0xa2d88fe4,0xdb04160a,0x29dc2b74,0x78b60216}},	//   _माध्, rsió, pía_, _leyv,
   {{0xf41f825d,0x7afeab49,0x672180ce,0x3d8a8198}},	//   ään_, _ópti, _dolj, нщин_,
   {{0xb4ae89a3,0x60c42b75,0x3cfd8069,0x80d6016f}},	//   करे_, _ndim, _cawv_, _भाषे,
   {{0x7c29ab76,0x3cfd81c0,0x6721a9c2,0x14d5866b}},	//   gyer, _dawv_, _folj, _धारण,
   {{0xa3b585b3,0xef83867c,0x60c42b77,0x2365911b}},	//   _जबर_, _глуп, _adim, golj_,
   {{0xe6938307,0x6e938013,0x5e938013,0x41551016}},	//   _المد, _الما, _المط, ивос,
   {{0x4429280a,0x3cfd81c0,0x7c29ab78,0x67218267}},	//   yya_, _gawv_, byer, _zolj,
   {{0x63a2ab79,0x752d2b7a,0x69c090be,0x386d0366}},	//   _uton, vkaz, _विकी, æer_,
   {{0x88bd809a,0x7bfb8039,0x7dea8085,0x4429004f}},	//   _kośc, _נפוצ, _təsd, vya_,
   {{0x2bc71834,0x4429010c,0xd2b7ab7b,0x6aba9a26}},	//   _लिहा, wya_, _גלות_, matf,
   {{0x44292b7c,0x7982809a,0x06c600ab,0x752d01d6}},	//   tya_, jmow, শ্লি, ukaz,
   {{0x752281c0,0x44290176,0xdb04002a,0x394b2b7d}},	// [18f0] _mooz, uya_, esiñ, mics_,
   {{0xd25b0ab2,0x44292b7e,0x394b2b7f,0x752d0010}},	//   нце_, rya_, lics_, skaz,
   {{0x3207026f,0xeb9f0edd,0xdb580009,0x7c3b81e8}},	//   íny_, _grøn_, уют_, zzur,
   {{0x200929cf,0xb4ae83ca,0x394b2b80,0x7c3b8035}},	//   _krai_, करो_, nics_, yzur,
   {{0xe8d90028,0x06b800ab,0xb9658032,0x3cfd8282}},	//   _chứ_, _জাতি, _adìé, _rawv_,
   {{0x3cfd81e9,0x92940048,0x8cad01d0,0x394b1e78}},	//   _sawv_, _гарц, जरको, hics_,
   {{0x23658353,0x3cfd81c0,0x7bcd008b,0x61ed8b80}},	//   volj_, _pawv_, lrau, _ćalo,
   {{0x20090110,0x7c29ab81,0x7c3bab82,0xf8b986ae}},	//   _orai_, tyer, tzur, _उजिय,
   {{0x75ec0065,0xa3cb0540,0x36d5ab83,0x394b2b84}},	//   _közö, रंट_, _возр, dics_,
   {{0xff538013,0xef678098,0x81e800ab,0x7c298d18}},	//   _اخر_, _събо, বির_, ryer,
   {{0x394b2b85,0x88bd809a,0xb0b983eb,0x7bcd2b86}},	//   fics_, _gośc, _उजाग, hrau,
   {{0x637000f2,0x291d9af0,0x394b0722,0x7bcd2b87}},	//   tänk, njwa_, gics_, krau,
   {{0xa0760071,0x273989c4,0x23658b80,0xe7b389ab}},	//   рынш, _cèng_, polj_, _ƙaƙƙ,
   {{0xfaa59ac6,0x82a58364,0x7bcd2b88,0x20092b89}},	//   _тако, _такж, drau, _drai_,
   {{0x29560698,0x63a9ab8a,0x99d700ab,0x28a7223e}},	//   _въпр, lpen, সবুক, _क्वि,
   {{0xf3888104,0x27edab8b,0x63a9ab8c,0x2d8f82d6}},	//   _hợp_, _open_, open, _jige_,
   {{0x63a9ab8d,0x2912019d,0x7bcd2b8e,0x29002b8f}},	// [1900] npen, _inya_, grau, _iaia_,
   {{0x2d8fab90,0x60dbab91,0x29122b92,0x68e9ab93}},	//   _lige_, _acum, _hnya_, _abed,
   {{0xa2d880d4,0xe9da0604,0x80a68c2a,0xaadd858c}},	//   _मास्, тке_, لمان, _मानक,
   {{0x7bcd2b94,0xa3e68bb8,0x3be586a7,0xdb04002a}},	//   brau, _पहल_, _कहूँ_, rsiñ,
   {{0xdefa8364,0x7982809a,0x7600ab95,0xbcfb0091}},	//   вый_, rmow, kázá, _akéw,
   {{0x2d8f8ad0,0xd00f9a3e,0x29002b96,0xe80703eb}},	//   _aige_, بله_, _laia_, शिता_,
   {{0x636b05c5,0xd5b7ab97,0x6d560079,0x2d8fab98}},	//   rünt, асы_, onya, _bige_,
   {{0xe8d90028,0x6d562b99,0xa3ea0327,0x29002b9a}},	//   _thứ_, nnya, _महा_, _naia_,
   {{0x8fa39383,0x61e90024,0x63a9ab9b,0x2d8f8326}},	//   _мате, _ćeli, gpen, _dige_,
   {{0x29120a2c,0x8ca680d4,0x29020079,0x320a016b}},	//   _anya_, _ट्रो, edka_, _krby_,
   {{0x2bc29199,0x6d562b9c,0x29002b9d,0x7522826c}},	//   _शिका, knya, _baia_, _tooz,
   {{0x38c9026a,0xdd8f806b,0x29002b9e,0x5fba86a7}},	//   دادی_, _قول_, _caia_, _उबाल,
   {{0xc05b0163,0xe53b8051,0x2006ab9f,0x2912008e}},	//   тін_, _בתאר, nvoi_, _dnya_,
   {{0x28a70aed,0x29122ba0,0x394b2ba1,0x200902be}},	//   _क्रि, _enya_, sics_, _vrai_,
   {{0x68ff2ba2,0x68930077,0x3cdd864a,0x29002ba3}},	//   _taqd, _ویدئ, क्के_, _faia_,
   {{0x7bcd2ba4,0x20090028,0x29000102,0xc0cb2ba5}},	//   trau, _trai_, _gaia_, _руке_,
   {{0x39490025,0xe4f9aba6,0x3cde8035,0x44980198}},	// [1910] _imas_, ्यति_, _गाने_, рвую_,
   {{0x27340006,0x6d562ba7,0x60db8087,0xfaa70196}},	//   _täna_, anya, _scum, ршан,
   {{0x81e480ab,0xa3cb11bc,0xa2dd125f,0x63a98102}},	//   নিক_, रूज_, _पाठ्, zpen,
   {{0x2912008e,0x27398036,0x637daba8,0x21248427}},	//   _xnya_, _mène_, mène, _comh_,
   {{0x838711e9,0x2d8faba9,0x98e481a8,0x21248427}},	//   _выве, _rige_, تكنو, _domh_,
   {{0x2d8fabaa,0x394901c0,0x7bc0874d,0x2d84862c}},	//   _sige_, _lmas_, dsmu, emme_,
   {{0x80c200c8,0x2cadabab,0x78bd2bac,0x2d8f806a}},	//   ষ্ট্, tbed_, kasv, _pige_,
   {{0x2608035a,0x28a70a3a,0x68e982ee,0x58d4abad}},	//   हिती_, _क्लि, _ubed, _мост,
   {{0x7c2d2bae,0x40349cf4,0xe29982df,0x2cadabaf}},	//   nyar, _детс, лап_, rbed_,
   {{0x7de7835f,0x39492bb0,0xf5e780e8,0x29002bb1}},	//   _відд, _amas_, _відм, _saia_,
   {{0xa2d8abb2,0xe8d90028,0x291209da,0x7c2d2bb3}},	//   _मार्, _chữ_, _pnya_, hyar,
   {{0x637005ec,0x3cde86a7,0x6d9581d6,0x049581a8}},	//   räni, _गाये_, _všad, _الإح,
   {{0x290001df,0x6c8580f7,0xdced082c,0x7c2d0314}},	//   _vaia_, _الشم, jmađ, jyar,
   {{0x39491e92,0x442dabb4,0xdced011c,0x6d50866f}},	//   _emas_, mye_, tmağ, ądał,
   {{0x442dabb5,0xe5a60628,0x6f01abb6,0x29120359}},	//   lye_, сиби, _malc, _tnya_,
   {{0x6d4d16d5,0xdced2bb7,0x29122bb8,0xe0da04ae}},	//   giaa, rmağ, _unya_, _сви_,
   {{0x442dabb9,0x7c2d0065,0x443fabba,0xec7a16d9}},	// [1920] nye_, gyar, nzu_, упа_,
   {{0xa2dd1fa6,0x8a3a0009,0x7c248014,0x5fd18072}},	//   _पाण्, ляет_, _àire, _समजल,
   {{0xb4f981ab,0xd9108077,0xdce400ce,0x442d8168}},	//   ्याय_, ویس_, jlić, hye_,
   {{0x7c2d2a7a,0x6d4d0a0f,0x442dabbb,0x69c1abbc}},	//   byar, ciaa, kye_, isle,
   {{0xa2d8908a,0x572509a7,0x291283bf,0x442d8c97}},	//   _माल्, _طریق, ıya_, jye_,
   {{0x7d042bbd,0x443f80eb,0x442dabbe,0x290088fc}},	//   ldis, dzu_, dye_, žia_,
   {{0xe7f48b85,0xa2dd09c2,0xa3d40540,0x9c13819d}},	//   _इनका_, _पात्, सूर_, _gọzi,
   {{0x7d042bbf,0xc0e39d7b,0x442d8247,0x7bc68110}},	//   ndis, _носк, fye_, škum,
   {{0x442dabc0,0x7d042bc1,0x78a2816b,0x6f01abc2}},	//   gye_, idis, mcov, _falc,
   {{0xdced012b,0x7d040009,0x78a2816b,0xd6d29dd2}},	//   vlač, hdis, lcov, _رقص_,
   {{0x69c1a15e,0x9952001b,0x442dabc3,0x78bd2bc4}},	//   gsle, lář_, aye_, tasv,
   {{0x78a2803e,0x442da122,0xd25786b5,0x753b8010}},	//   ncov, bye_, сць_, chuz,
   {{0x7d042bc5,0x67250364,0xc8671194,0x506711b1}},	//   ddis, _pohj, стни, стна,
   {{0x6d5a2bc6,0x7bd62bc7,0xd6d80a42,0xa85781c6}},	//   étan, duyu, йтс_, מיכה_,
   {{0xdced0289,0x6d4d2bc8,0x80d88f3d,0x9577003d}},	//   slač, tiaa, डलाइ, مدرض,
   {{0x2d9a2bc9,0xdced0353,0x394903a7,0x7d042bca}},	//   _dupe_, plač, _umas_, gdis,
   {{0xac18215b,0x241813cd,0x6d4d2bcb,0xa3d40c28}},	// [1930] боту_, боты_, riaa, सूल_,
   {{0x6d4d2bcc,0x70d18105,0x7c2d2bcd,0x7d02abce}},	//   siaa, हल्ल, ryar, _laos,
   {{0x7c2d059c,0x637d809f,0x442d83ec,0x4c952125}},	//   syar, lènc, zye_, _минс,
   {{0x27308104,0x26de82ba,0x442dabcf,0x7bd6008e}},	//   _hành_, _acto_, yye_, buyu,
   {{0x68ed2a1b,0xe8d901bc,0x675402e3,0x81e480ab}},	//   _mbad, _ajị_, _ذخیر, নিট_,
   {{0x7a3f8065,0xe7369c45,0x442dabd0,0xf6500065}},	//   _játé, жеш_, vye_, _آئی_,
   {{0xf7708077,0x68ed2bd1,0x6f01abd2,0x78a2abd3}},	//   راه_, _obad, _valc, bcov,
   {{0x442d8247,0x443f8102,0xa159abd4,0x273080ff}},	//   tye_, tzu_, _табу_, _lành_,
   {{0x63ad2bd5,0x60c9811f,0x4ad4835a,0xe8d92bd6}},	//   npan, _idem, _दाखव, _ejị_,
   {{0x443fabd7,0xa1c58676,0x68ed2bd8,0x442dabd9}},	//   rzu_, обод, _abad, rye_,
   {{0x442dabda,0x2d5701cd,0x63ad008e,0x5f1d1a4d}},	//   sye_, għek_, hpan, मान्_,
   {{0xa3ea09f2,0x63ad2bdb,0x69c18e1c,0x3eba2bdc}},	//   _महल_, kpan, rsle, _sept_,
   {{0x41c583b7,0x637d8722,0x3cde80d4,0x6d4b8197}},	//   _विकस, gènc, _गाते_, _imga,
   {{0x69c380eb,0x2cbfabdd,0x2a8e8085,0x6d5d01a1}},	//   _tvne, laud_, bəb_, _ajsa,
   {{0x27308028,0x7d041849,0x78bb80e7,0x6da3197d}},	//   _dành_, tdis, _oeuv, диса,
   {{0x78bbabde,0x2fcd0353,0x0d9917ae,0x95990a95}},	//   _neuv, šega_, стры_, стру_,
   {{0xccf2836b,0x637d809f,0x63ad1341,0x78a2816b}},	// [1940] וכן_, cènc, gpan, vcov,
   {{0x60c9960a,0x91eda123,0x7bd6080a,0x20000870}},	//   _adem, _जहाज_, ruyu, _isii_,
   {{0x6d4babdf,0xe1fa2be0,0x63ad01a8,0x48e10054}},	//   _omga, рге_, apan, _कामो_,
   {{0x7d0402c1,0xa50a1878,0x1d0a2be1,0x200dabe2}},	//   qdis, _тема_, _теми_, _brei_,
   {{0x78a2abe3,0x200dabe4,0x60c9abe5,0x3860811c}},	//   rcov, _crei_, _ddem, çir_,
   {{0x60c9abe6,0x200d82af,0x7d02abe7,0x78a2abe8}},	//   _edem, _drei_, _saos, scov,
   {{0xa3dc825a,0x64490125,0x3f4d026c,0x27ff846d}},	//   तून_, _þeir, džul_, _esun_,
   {{0x200d81ec,0x6374823e,0x7bc40084,0x64408799}},	//   _frei_, màni, osiu, tzmi,
   {{0x81bc0a49,0x7bc42be9,0x741480f7,0x6440812b}},	//   _আমি_, nsiu, سودا, uzmi,
   {{0x290490fe,0x799c02a0,0x637d8722,0x6d4babea}},	//   _hama_, _kurw, vènc, _emga,
   {{0x2904abeb,0x81e800ab,0x13b300ab,0x6abc0197}},	//   _kama_, বিক_, টওয়, _merf,
   {{0x290483c3,0x09cf00c8,0xe8d90028,0x2906abec}},	//   _jama_, _রহমা, _thử_, ndoa_,
   {{0x644080b9,0x6abc2bed,0x81b700fc,0x6370062c}},	//   qzmi, _oerf, ɓɓuk, näns,
   {{0x2904aa6f,0x637d87e2,0x6abc2bee,0x26dc8048}},	//   _lama_, rènc, _nerf, ngvo_,
   {{0x56940a7c,0xe8d9001c,0x637d809f,0xdcbb22f1}},	//   дарт, _chợ_, sènc, ища_,
   {{0x5c992bef,0xa3ae8b75,0x27e6abf0,0x68ed13e3}},	//   ская_, _ओझा_, kton_, _ubad,
   {{0x6abc103c,0x6370016d,0x63ad2bf1,0xdfdb0098}},	// [1950] _berf, jäns, upan, _тъй_,
   {{0xc7b22bf2,0xd3711baf,0x63ad2bf3,0xb2ab096b}},	//   _רבי_, رها_, rpan, ртаж_,
   {{0x6abc0a38,0x78bb82be,0x2904abf4,0x63702bf5}},	//   _derf, _peuv, _bama_, vänt,
   {{0x7af72bf6,0x2904a8d1,0x61e52bf7,0x644004b7}},	//   sext, _cama_, rthl, _żmie,
   {{0x290480a4,0x01e080c8,0xd009802e,0x251a04de}},	//   _dama_, ববিদ, селе_, _הורא,
   {{0x200d802e,0xe3b200be,0x69d703a8,0x27398176}},	//   _vrei_, _אױך_, puxe, _bèna_,
   {{0x27e6825d,0x67288025,0x2904abf8,0x09af80ab}},	//   aton_, _dodj, _fama_, _কিভা,
   {{0x2904abf9,0x200d802e,0x2ee12472,0x6b9d2bfa}},	//   _gama_, _trei_, _lchf_, _kusg,
   {{0xdb1b841c,0x27ff83db,0x1c0e01a2,0x4ea78162}},	//   ssuí, _usun_, सियल_, _дреа,
   {{0x290483c3,0x4a45a865,0x6b9d2bfb,0x466b8878}},	//   _zama_, знов, _musg, _крем_,
   {{0xe8038c78,0xc86900be,0x69c52bfc,0x2904abfd}},	//   लिका_, _ען_, nshe, _yama_,
   {{0x6723abfe,0x7dea8085,0x21290144,0x6d4babff}},	//   ljnj, _məsl, _coah_, _umga,
   {{0x88bd809a,0x200f1520,0x246483ed,0x69c52c00}},	//   _rośl, _ágil_, rëmë_, hshe,
   {{0x69c702ce,0x395f816d,0x26080072,0x2904026c}},	//   _ovje, _ljus_, हिली_, žma_,
   {{0x6b9d0352,0x69c52c01,0x6b402c02,0x7dea829a}},	//   _ausg, jshe, _högg, _nəsl,
   {{0xe9a89baf,0x6d5bac03,0x2bc713ba,0xc4d60072}},	//   _بدون_, nnua, _लिखा, धलेख,
   {{0x2904ac04,0x42ca01e5,0x2ef82c05,0xf99301c6}},	// [1960] _rama_, йган_, perf_, _ארה_,
   {{0x799c2c06,0x7bc42768,0x63748722,0x1ddb8424}},	//   _purw, rsiu, tàni, _यमंत,
   {{0xa2dd2c07,0x6abc2c08,0x4ae2035a,0x67288067}},	//   _पार्, _verf, _पाठव, _rodj,
   {{0x2367173d,0x69c7111b,0x0edc001b,0x27e6ac09}},	//   čnja_, _dvje, _बाँड, tton_,
   {{0x67288f28,0x2904803a,0x2906ac0a,0x6abc20d7}},	//   _podj, _vama_, rdoa_, _terf,
   {{0x395f86c4,0x63701743,0x2904ac0b,0x7d062c0c}},	//   _ejus_, räns, _wama_, _haks,
   {{0x2904ac0d,0x7d062c0e,0x27e6ac0f,0x6728a800}},	//   _tama_, _kaks, ston_, _vodj,
   {{0x7d062c10,0x06c600ab,0x27e6ac11,0x75242c12}},	//   _jaks, শ্চি, pton_, njiz,
   {{0x7d062c13,0x69c72c14,0x0edc047d,0x64440365}},	//   _maks, _zvje, _बांड, nzii,
   {{0x3cde8e18,0x883b8039,0xbec280eb,0x44200722}},	//   _गावे_, _התמו, šība, ixi_,
   {{0x76438063,0x75240590,0x58d512b2,0x26cc831d}},	//   czny, kjiz, монт, _iddo_,
   {{0xf487819f,0x60c2804f,0x3ebeac15,0x44320198}},	//   _کامی, naom, _hett_, kyy_,
   {{0xfc3f2c16,0xa2dd2c17,0xfc2fa105,0x798409c4}},	//   _afín_, _पाल्, _محو_, _dhiw,
   {{0x3da72c18,0x7d0600e4,0x2d9e8129,0x44200118}},	//   зраб, _aaks, _kute_, dxi_,
   {{0x7afaac19,0x249900b9,0x2d9eac1a,0x3ebeac1b}},	//   mett, _pgsm_, _jute_, _mett_,
   {{0x3ebeac1c,0x69daac1d,0xb4c9000d,0xb4d7024c}},	//   _lett_, mute, ैले_, सले_,
   {{0x69c7030b,0x60cd2c1e,0x69daac1f,0x2d8909c4}},	// [1970] _svje, _idam, lute, rmae_,
   {{0x7afaac20,0x69c5029b,0x2bd49094,0x394d822b}},	//   nett, tshe, _दिना, _smes_,
   {{0x26c3007a,0x6d40ac21,0x6aa52c22,0x7afa847f}},	//   majo_, khma, rchf, iett,
   {{0x69c52c23,0x7afaac24,0x26c3007a,0xac192c25}},	//   rshe, hett, lajo_, _дому_,
   {{0x4addac26,0x7afaaa6a,0x69c52c27,0xb4db0091}},	//   _मालव, kett, sshe, _alàg,
   {{0x69daac28,0x2d9eac29,0x26c32c2a,0x7afaa4ad}},	//   kute, _bute_, najo_, jett,
   {{0x69c7030b,0x69daac2b,0x41778416,0x7afaac2c}},	//   _uvje, jute, _فارس, dett,
   {{0x2d9e80ad,0x69daac2d,0x60cd2c2e,0xbe3c01c6}},	//   _dute_, dute, _ndam, מעות,
   {{0x7afaac2f,0xb4ad901c,0x387fac30,0x6d5b8102}},	//   fett, _कभी_, _uzur_, rnua,
   {{0x60cd2c31,0x7afaac32,0x6fd2800f,0x26c30db7}},	//   _adam, gett, _सितं, jajo_,
   {{0x2d9e9b43,0x26c30353,0x69daac33,0x7764823e}},	//   _gute_, dajo_, gute, éixe,
   {{0x6d4082af,0x2734016d,0x604301bc,0x7e7eac34}},	//   chma, _tänk_, _ọmaj, üppe,
   {{0x7d060341,0x442004b7,0x6b40016d,0x7afaac35}},	//   _raks, xxi_, _höge, bett,
   {{0x7afaac36,0xdb0b816d,0x6d4f2c37,0x26c3007a}},	//   cett, _avgö, _amca, gajo_,
   {{0x7d062c38,0x2d962c39,0x2d9e02be,0x7d09ac3a}},	//   _paks, драс, ête_, odes,
   {{0x44200102,0xe3ba2109,0x44320198,0x2bd495bc}},	//   txi_, жба_, tyy_, _दिमा,
   {{0x26c31220,0x7dea8201,0x7d06021e,0x73060084}},	// [1980] bajo_, _rəsm, _vaks, мпаз,
   {{0x7d098009,0x5fd306a7,0x753d0061,0x60c2804f}},	//   hdes, _तितल, _elsz, waom,
   {{0x7d062c3b,0x00e6835f,0xf1a50558,0x3ebe821e}},	//   _taks, джен, ерін, _rett_,
   {{0x2d9eac3c,0x3ebe8558,0x7d09ac3d,0x3cf98035}},	//   _rute_, _sett_, jdes, ्यों_,
   {{0x2d9e8c7b,0x69daac3e,0x7afaac3f,0x8fa38cf3}},	//   _sute_, zute, yett, ваче,
   {{0x69daac40,0xeb9f0bc5,0x437500e8,0xb86587c3}},	//   yute, _prøv_, _зуст, رانو,
   {{0x7afaac41,0x629c01dd,0x7d09874c,0x8a031285}},	//   vett, _igro, fdes, _изре,
   {{0x7afaac42,0xdc8e81bc,0x7d09ac43,0x490686a7}},	//   wett, _dịnụ_, gdes, _सोचो_,
   {{0x7afaac44,0x671e89a3,0x3ebeac45,0x63a42c46}},	//   tett, पादक_, _tett_, nqin,
   {{0x60c0ac47,0x48e10076,0xf7729e09,0x6d40ac48}},	//   _hemm, _काहो_, _شاء_, shma,
   {{0x7afaac49,0x60c082a6,0x7d09ac4a,0x26c30353}},	//   rett, _kemm, bdes, vajo_,
   {{0x92be80c8,0x69daac4b,0x60c0822b,0x914b0d8e}},	//   ইলে_, rute, _jemm, ічна_,
   {{0xb9072c4c,0x7afaac4d,0x629c2c4e,0x60c0ac4f}},	//   _पा_, pett, _ogro, _memm,
   {{0x69daac50,0x60c0ac51,0xb8d60beb,0xdce98503}},	//   pute, _lemm, _च्_, tleć,
   {{0xe5c41e16,0x26c32c52,0x2d86801c,0xf2068098}},	//   ксто, rajo_, _khoe_, _цяло,
   {{0x60c0ac53,0x9d180081,0xab5d8035,0xd7fb2c54}},	//   _nemm, мост_, duży, _дуо_,
   {{0xdce982a5,0x63adac55,0x2139008e,0x21268da8}},	// [1990] sleć, _çant, mksh_, djoh_,
   {{0x32110063,0x68fd2c56,0xdb098187,0x629c0362}},	//   _przy_, lesd, mpeã, _cgro,
   {{0xe8d90104,0xe8070c78,0xd25b0746,0x7d098009}},	//   _chủ_, शिका_, цца_, ydes,
   {{0xa2d8853e,0x6562820f,0x60c0ac57,0x290b0162}},	//   _माझ्, _njoh, _cemm, ndca_,
   {{0x7ac7013a,0x60c0ac58,0xdce40214,0x6f08810c}},	//   _осве, _demm, lliğ, _badc,
   {{0x26c10775,0xaadd8996,0xdc1480c8,0x6d9101ac}},	//   _jeho_, _माइक, িহাস_, _sťah,
   {{0x60c0ac59,0x58d58293,0x3d108105,0x2d992c5a}},	//   _femm, _повт, _दोहे_, _kise_,
   {{0x60c0ac5b,0x69c8ac5c,0x28db2c5d,0x7d098198}},	//   _gemm, dsde, _भागि, udes,
   {{0x2d992c5e,0x47d58013,0x7d09ac5f,0x6d5a02be}},	//   _mise_, _سيار, rdes, étai,
   {{0x4225ac60,0x26c100e1,0x2d992c61,0xdce402d0}},	//   едов, _neho_, _lise_, kliğ,
   {{0x78a4ac62,0x4ae21391,0x9f8a8009,0x443980eb}},	//   žive, _पासव, töön_, šs_,
   {{0x2d992c63,0x68fd2c64,0x186a2c65,0xa06a02ee}},	//   _nise_, gesd, зами_, зама_,
   {{0x2d8dac66,0x26c102c4,0x98a481a9,0x66052c67}},	//   mmee_, _beho_, _jomā_, _ashk,
   {{0xa3578077,0x613a823e,0x2d992c68,0xa3d401d0}},	//   _تخصص, _aïll, _aise_, संघ_,
   {{0xe6170554,0xf53f0370,0xa3e2123a,0x2d992c69}},	//   ндр_, _blå_, नून_, _bise_,
   {{0x6283803a,0x68e42c6a,0x6d95811f,0x2d99117d}},	//   _izno, _ucid, _ošam, _cise_,
   {{0x4ad384e5,0x2d992c6b,0xe7da80c8,0x7bc9ac6c}},	// [19a0] _दयाव, _dise_, _ধন্য, nseu,
   {{0x60c0ac6d,0x394001c5,0xe8d9001c,0xd83f05b9}},	//   _semm, _hlis_, _phủ_, íček_,
   {{0xdebb010f,0x53368158,0xda1f8ebf,0x60c0808e}},	//   _ממיל, ענען_, यमित_, _pemm,
   {{0xe1ff809a,0xeb9a2c6e,0x5976803d,0x7bd58035}},	//   łów_, _ним_, رداز, ązuj,
   {{0x6d562c6f,0x7bcfac70,0x63a4011c,0xed50803d}},	//   miya, ácul, qqin, یپت_,
   {{0x6d562c71,0x629c003b,0xe8d92c72,0x9e068087}},	//   liya, _ugro, _thủ_, ечил,
   {{0x7bcbac73,0xe3630f2e,0xceb30051,0x60c0ac74}},	//   _avgu, _скри, ניה_, _temm,
   {{0xe2972c75,0x6d562c76,0x60c62c77,0x6d442c78}},	//   _час_, niya, jakm, nhia,
   {{0xe3af84c0,0x60c609da,0x69de2c79,0xdce402d0}},	//   یری_, dakm, lupe, zliğ,
   {{0x6d562c7a,0xfd1f0028,0x39402c7b,0x3f9a0573}},	//   hiya, _nhìn_, _alis_, _nipu_,
   {{0x6d562c7c,0x6d440590,0x4dd6ac7d,0x68fd2c7e}},	//   kiya, khia, _ستاس, tesd,
   {{0xfc668098,0x6d562c7f,0x88bd809a,0x68e2ac80}},	//   _пълн, jiya, _dośw, ngod,
   {{0x6d562c81,0x54338154,0xb4bc801b,0x557780be}},	//   diya, _مرور, अरी_, _װעגן_,
   {{0x2d992c82,0xb9c68013,0xae0d0076,0xa3ea01ce}},	//   _sise_, _كتبه, हिलन_, _महज_,
   {{0x2d990052,0x63a2ac83,0xe8d90a2c,0x6d562c84}},	//   _pise_, _huon, _ahụ_, fiya,
   {{0x63a280f6,0x6d562c85,0x6d4426e8,0xdce40214}},	//   _kuon, giya, ghia, rliğ,
   {{0x2ca901b4,0x63a28198,0x26c12c86,0x656094f2}},	// [19b0] rcad_, _juon, _teho_, inmh,
   {{0xaa672c87,0x63a2ac88,0x5f950eef,0x3a2b027d}},	//   нтек, _muon, _шипт, _đểđă,
   {{0x6d562c89,0x63a2ac8a,0xda6700f7,0xcad781c6}},	//   biya, _luon, رائي, תובת_,
   {{0x6d442c8b,0xa2dd0f8d,0x6d561d15,0x637d8247}},	//   chia, _पाक्, ciya, vènm,
   {{0x7c8418f6,0x63a2ac8c,0xdee5951a,0x7d0d008b}},	//   _буре, _nuon, воли, mdas,
   {{0x98a90267,0xbec280eb,0x7d0d2c8d,0x68e28118}},	//   _mlađ_, šīna, ldas, agod,
   {{0xae14023c,0x7bdf0388,0xc1790110,0x7764802a}},	//   डियन_, luqu, ntės_, éixa,
   {{0x63a2ac8e,0x7d0d2c8f,0x2734016d,0xacbb00e7}},	//   _buon, ndas, _hänt_, _goût,
   {{0x2d8d8b3c,0x27340106,0x6b400106,0x63a280ff}},	//   rmee_, _känt_, _höga, _cuon,
   {{0x6d562c90,0x7bc9ac91,0x63a2ac92,0x78ad0722}},	//   ziya, rseu, _duon, _afav,
   {{0x216a20ab,0xa96a18b0,0xd9460b01,0x7bc9ac93}},	//   дини_, дина_, вени, sseu,
   {{0x26c7ac94,0x7afe1919,0x8fa62c95,0x6d562c96}},	//   lano_, zept, каме, xiya,
   {{0xeb8ea6b9,0xf9928158,0x7d0d2c97,0xa3a8835a}},	//   _ви_, ירט_, ddas, _खूप_,
   {{0x26c7ac98,0x7529a43e,0x41d1213e,0x9a15ac99}},	//   nano_, ljez, _हिंस, _афиш,
   {{0x6d562c9a,0x6d44031d,0xb87b0020,0x65c32c9b}},	//   tiya, thia, rgía, ибра,
   {{0xe8d90028,0x26c7ac9c,0x7d0d2c9d,0xb4dc2b6c}},	//   _phụ_, hano_, gdas, ठले_,
   {{0x26c78f45,0x7d0ba705,0x7afe002e,0x644982af}},	// [19c0] kano_, _mags, tept, nzei,
   {{0x6d4401c5,0x6d562c9e,0x60c42c9f,0x7c2680f2}},	//   shia, siya, _heim, äkri,
   {{0xb6d90158,0x60c41203,0x7dea8085,0x3ed900be}},	//   _אַרט, _keim, _təsi, _אַרא,
   {{0xa3e201b6,0x7d0baca0,0x7afe2ca1,0x7989aca2}},	//   नंद_, _nags, sept, _chew,
   {{0xb90aaca3,0x26c7aca4,0x79898077,0x87e38198}},	//   _मा_, fano_, _dhew, ающе,
   {{0x6a861b3c,0x4add816f,0x3d16020e,0xdbdb808b}},	//   _алга, _मागव, _पोते_, _ráðg,
   {{0x2d9c0065,0x63a2aca5,0x248080eb,0x7d0baca6}},	//   _éves_, _suon, _šim_, _bags,
   {{0x3d19852a,0x644981ec,0x6b9c01b4,0x6b448176}},	//   भागे_, fzei, _hirg, _mòge,
   {{0x7d0b92fa,0x07a684a9,0x46ea81a1,0x6b9c2ca7}},	//   _dags, _разн, _одан_, _kirg,
   {{0xdced003b,0x39468073,0x63a2aca8,0x7d0d0019}},	//   plać, lhos_, _vuon, zdas,
   {{0x2bd48f85,0x53d4816f,0x7d0d07c0,0x7d0baca9}},	//   _दिवा, _दिवश, ydas, _fags,
   {{0x394680a9,0xdd968277,0x63a2acaa,0xa9210085}},	//   nhos_, _شجاع, _tuon, _şöbə,
   {{0x93468e97,0x14d7812a,0xf7730c2a,0xdb098013}},	//   _инде, _יואל_, لاس_, speá,
   {{0x69d300d4,0x5333acab,0x6b9c2cac,0xf09381c6}},	//   _डिली, _вешт, _nirg, ינר_,
   {{0x752f0063,0xa4d5035f,0x7e86801b,0x2fc02cad}},	//   _pocz, лові, _úspě, _ewig_,
   {{0xb4cd016f,0x60c42cae,0xe7d280d4,0xd7d2970c}},	//   रणे_, _geim, _सिंप, _सिंच,
   {{0x65940a4c,0x24580364,0x7d0d2caf,0xdd940084}},	// [19d0] рату, вать_, rdas, раты,
   {{0x26c79041,0x7d0d01e0,0x7cde0087,0x79899ca2}},	//   xano_, sdas, tărâ, _shew,
   {{0x26c7acb0,0x6b9c2cb1,0xfaa40f27,0xe659002e}},	//   vano_, _dirg, ршун, _чинч_,
   {{0x69da808c,0x26c7acb2,0x06d800ab,0x7d009b89}},	//   irte, wano_, দ্দি, jems,
   {{0x26c7acb3,0x7d0080d2,0x3869acb4,0x69da81ec}},	//   tano_, dems, çar_, hrte,
   {{0x386981cd,0x6b9c2cb5,0xa03c0039,0x7d0bacb6}},	//   ħar_, _girg, ועדפ, _sags,
   {{0x78a48025,0x7d0bacb7,0xa3a88b85,0xa2b8801b}},	//   živa, _pags, _खूब_, ोरन्,
   {{0xf3ffacb8,0x3946acb9,0xb4ad835a,0x97c58013}},	//   ção_, chos_, कडे_, _مقرو,
   {{0xeb99acba,0x26c7acbb,0x69daacbc,0x290dacbd}},	//   нии_, pano_, erte, _iaea_,
   {{0x64498352,0x4add8023,0x60c42cbe,0x753b801b}},	//   rzei, _माओव, _seim, skuz,
   {{0x7d0bacbf,0x52d000c8,0x2bc486b7,0x6449acc0}},	//   _tags, স্কৃ, लीबा, szei,
   {{0xe4cb803d,0x26c59920,0xb87b2cc1,0x2e3a80be}},	//   _آبان_, _helo_, rgín, _אגענ,
   {{0x69daacc2,0xb4df816f,0xdb0f0511,0xfd1f00ff}},	//   arte, तली_, _etcé, _chìm_,
   {{0x25a581cd,0xe8e081d0,0x26c5805c,0x200900ee}},	//   _kull_, _पञ्च, _jelo_, _dsai_,
   {{0x26c5acc3,0x60c42cc4,0x16098aed,0x68e98904}},	//   _melo_, _teim, विटर_, _oced,
   {{0x2d8b09a4,0x2cad8039,0xf8a80105,0x61e1acc5}},	//   _chce_, nced_, _गलिय, mull,
   {{0x61e1acc6,0xc9530051,0x7bcd1849,0xac860d45}},	// [19e0] lull, _למה_, gsau, угал,
   {{0x7d00a22b,0x29022cc7,0x491c000d,0x68e989b2}},	//   zems, leka_, याको_, _aced,
   {{0x61e1acc8,0xe0da94d6,0xaca401bc,0x248600e1}},	//   null, еве_, _alụs, ťom_,
   {{0x29022cc9,0x69ce9d64,0x9fca8009,0x26ca2cca}},	//   neka_, ábei, егда_, labo_,
   {{0x6b9c0029,0x26c5accb,0x7e7e2ccc,0x2d802ccd}},	//   _tirg, _belo_, _hypp, mlie_,
   {{0x61e1820f,0x26c5a3af,0x26ca2cce,0x643b00be}},	//   kull, _celo_, nabo_, _טעכנ,
   {{0x21200025,0x26c5accf,0x394681e0,0x63a60267}},	//   _onih_, _delo_, phos_, _hukn,
   {{0x9d220a49,0x29020499,0x61e1acd0,0xa534802e}},	//   _নতুন_, jeka_, dull, рнич,
   {{0x7866acd1,0x26c5acd2,0x26ca1486,0x7d00acd3}},	//   _сказ, _felo_, kabo_, rems,
   {{0x25a5acd4,0x69da807a,0x3d19816f,0x26c5acd5}},	//   _full_, trte, _मोठे_, _gelo_,
   {{0x61e1acd6,0x63a62cd7,0x037701c6,0x26ca2cd8}},	//   gull, _lukn, רתית_, dabo_,
   {{0x26c58db7,0x613f13de,0x7dea8201,0x29020555}},	//   _zelo_, _gëll, _dəst, geka_,
   {{0x3f9eacd9,0x54369dd2,0x63a602c4,0x26c5acda}},	//   _kitu_, _حرار, _nukn, _yelo_,
   {{0x26ca2cdb,0x3f9e800e,0xa29485e9,0x26c58118}},	//   gabo_, _jitu_, _калі, _xelo_,
   {{0x1df801bb,0x2902005d,0x61e1acdc,0x3f9e8074}},	//   леры_, beka_, cull, _mitu_,
   {{0x2d800b91,0x20090041,0x7bcd2cdd,0x29022cde}},	//   glie_, _tsai_, tsau, ceka_,
   {{0x20092cdf,0x5c990a14,0x36d52489,0x3b551b3c}},	// [19f0] _usai_, ткая_, _копр, акар,
   {{0xd4982ce0,0x7bcd2ce1,0x3ea10122,0x6d5a2ce2}},	//   урс_, rsau, _ught_, étar,
   {{0x7bcd2ce3,0x798d2ce4,0x2d800de0,0x7dea8085}},	//   ssau, _khaw, blie_, _xəst,
   {{0x26c58503,0x30158012,0x98c780f7,0x25a5ace5}},	//   _selo_, идер, اغان, _rull_,
   {{0xf7719301,0x26c58003,0x25a58098,0xd0098012}},	//   يات_, _pelo_, _sull_, теле_,
   {{0x29022ce6,0x3f9e80eb,0x61e1ace7,0xddc88084}},	//   zeka_, _citu_, yull, _dydž,
   {{0x6b400352,0x3f9e80ad,0xed5983fb,0x26c5ace8}},	//   _mögl, _ditu_, tiž_, _velo_,
   {{0xd6580051,0xb4df8b86,0x613f00f1,0x61e1ace9}},	//   טיות_, तले_, _qëll, vull,
   {{0xa3e591bc,0xa3dc8076,0x9345acea,0x26c59117}},	//   बंध_, तंग_, иние, _telo_,
   {{0x61e1aceb,0x2902022e,0x3f9e8877,0x44292cec}},	//   tull, weka_, _gitu_, ixa_,
   {{0x29022ced,0x69261ff9,0x7c42811f,0x656401b4}},	//   teka_, амна, _čvrš, ynih,
   {{0x273d0104,0x798d01c5,0x5c7591c7,0x60cb97ea}},	//   _hình_, _chaw, _клет, nagm,
   {{0x29022cee,0x798d2cef,0x6d498ad0,0x26ca2cf0}},	//   reka_, _dhaw, mhea, tabo_,
   {{0x61e1acf1,0x29022cf2,0x63a62cf3,0x644d00dd}},	//   pull, seka_, _rukn, dzai,
   {{0x273d0104,0x26ca2cf4,0x63a62cf5,0x3f8400eb}},	//   _mình_, rabo_, _sukn, ēmu_,
   {{0x20560d31,0x63a62cf6,0x26ca2cf7,0x59da86ae}},	//   _втор, _pukn, sabo_, _भितर,
   {{0x6f03ac3d,0x7c3b9437,0x78a92a06,0x7c298980}},	// [1a00] kenc, nyur, ževc, nxer,
   {{0x6f03acf8,0xdcfb811f,0x973c80fe,0x6d958084}},	//   jenc, dluč, _kiće, _išau,
   {{0x6f03acf9,0x6edb0039,0xa3e5a774,0x2d801a25}},	//   denc, _בחיפ, बूत_, plie_,
   {{0xebe6119d,0xaae2035a,0x3f9e835e,0xdb060168}},	//   _комп, _पाकक, _situ_, _kukë,
   {{0x6d498782,0x273d0104,0x7d042cfa,0xe81911bc}},	//   dhea, _bình_, meis, दिया_,
   {{0x7d042cfb,0x2612acfc,0x69c38039,0xed5900e1}},	//   leis, थिली_, _owne, ďže_,
   {{0x3f9e8010,0x6fd280d4,0x645d808b,0xbd6a898d}},	//   _vitu_, _सिकं, úsin, крие_,
   {{0x6d49acfd,0xc0e3a3e1,0x7d040009,0x2b582cfe}},	//   ghea, _моск, neis, _hmrc_,
   {{0x3f9eacff,0x6f03ad00,0xdee6ad01,0x798d2d02}},	//   _titu_, benc, _вози, _rhaw,
   {{0x7d041276,0x798d00a4,0x79828051,0x973c9487}},	//   heis, _shaw, llow, _biće,
   {{0x6d498083,0x7d0407ac,0x6b400106,0x798d1236}},	//   bhea, keis, _rögl, _phaw,
   {{0x6d498782,0x798d022c,0x7bc286c0,0x85568061}},	//   chea, _qhaw, _twou, _خیبر_,
   {{0x58870196,0x7522ad03,0x442904b7,0x3202801b}},	//   рына, _inoz, xxa_, ňky_,
   {{0x6d462d04,0x6d40ad05,0x973c80c3,0xc05800e8}},	//   _alka, lkma, _fiće, рію_,
   {{0xd378803a,0x798d01e9,0x69c38355,0xdcfbad06}},	//   moć_, _thaw, _gwne, zluč,
   {{0x929b8051,0x7d042d07,0x644d00ad,0x44292d08}},	//   _ביות, geis, tzai, txa_,
   {{0xf8bf2d09,0xdfd100f7,0xfaa72d0a,0x69d8016b}},	// [1a10] mbé_, _عيد_, ашен, áven,
   {{0x6d462d0b,0xd378825b,0x44292d0c,0x6f0384c3}},	//   _elka, noć_, rxa_, xenc,
   {{0x3f83003b,0x387f9142,0x7d0f2d0d,0x98bf8699}},	//   mlju_, _syur_, _tacs, _smuđ_,
   {{0x6d498362,0xae1a0039,0x6d40ad0e,0x3e1603de}},	//   xhea, _עורכ, jkma, _פֿיל_,
   {{0xd3788d26,0x6b818114,0x1b0f00ab,0xf807a29c}},	//   koć_, yllg, সাবে_, рчен,
   {{0xd246803f,0x38ad8032,0x7522ad0f,0x6d409151}},	//   _فن_, _bóró_, _anoz, ekma,
   {{0x6d49954c,0x6f03ad10,0xed59a59a,0x60cb820d}},	//   thea, renc, лок_, pagm,
   {{0x23672cf6,0x7c29ad11,0x61e5005d,0x6f03ad12}},	//   čnju_, txer, muhl, senc,
   {{0x273d0104,0x68fb99ab,0x973c8088,0x63ad2d13}},	//   _tình_, _ibud, _siće, nqan,
   {{0x6aa4817b,0x6d49ad14,0x60c998f0,0x973c811f}},	//   _şifr, shea, _heem, _piće,
   {{0x7d042d15,0xdce9ad16,0x60c9ad17,0x6d4980f5}},	//   yeis, sleđ, _keem, phea,
   {{0x7522826c,0x973c81a1,0xa3e201a2,0xfc339ca3}},	//   _gnoz, _viće, नूँ_, _وحش_,
   {{0x442983d3,0x8d748872,0x7d042d18,0x057480f7}},	//   _ça_, _بالا, veis, _بالد,
   {{0x63bb8dab,0x2cbf86be,0x02398b76,0x7d0402af}},	//   mpun, lbud_, _مثبت_, weis,
   {{0x68fbad19,0x7d042d1a,0x78a90db7,0x19b59ec9}},	//   _obud, teis, ževa, _احتج,
   {{0x60c9ad1b,0x90c61df3,0x68fb8135,0x2b5800c3}},	//   _neem, _убие, _nbud, _smrc_,
   {{0x3f830a20,0x63bbad1c,0x44260073,0xa3e20beb}},	// [1a20] blju_, npun, ão_, नूं_,
   {{0x29122d1d,0x7d040406,0xd24f003d,0xe6462d1e}},	//   _haya_, seis, کنم_, _геоп,
   {{0x29122d1f,0x60c9ad20,0x993a8221,0x2cbf81bf}},	//   _kaya_, _beem, ляду_, kbud_,
   {{0xc6930051,0x2912059c,0x63bbad21,0x68fb8362}},	//   _מאת_, _jaya_, kpun, _cbud,
   {{0x8ff78013,0xe73a8785,0xdfcf80f7,0xbcfb026b}},	//   مرور_, лед_, فين_, _ajéw,
   {{0x6d59ad22,0x68fbad23,0x63bbad24,0x29122d25}},	//   _amwa, _ebud, dpun, _laya_,
   {{0x60c981c0,0x200dad26,0xceb303c8,0x8f9b0e82}},	//   _feem, _esei_, ליג_, ניצי,
   {{0x29122d27,0x63bba580,0xfc4684e8,0x60c9ad28}},	//   _naya_, fpun, šími_, _geem,
   {{0x63bbad29,0x6d40ad2a,0x61fb01a1,0x2906ab8c}},	//   gpun, rkma, _ćuli, meoa_,
   {{0xdb042d2b,0x68ed14ed,0x29122d2c,0x6d40ad2d}},	//   mpió, _scad, _aaya_, skma,
   {{0x291200a4,0x3f83003a,0x7c248110,0x8e8680f7}},	//   _baya_, vlju_, _šird, _الاه,
   {{0x291200ee,0x60c981c0,0xddcb01b9,0x73e681e2}},	//   _caya_, _xeem, ġiżl, _годз,
   {{0x291203c3,0x637d823e,0x27e6833e,0x3f830bcf}},	//   _daya_, tènt, nuon_, tlju_,
   {{0xc90580c2,0x83030264,0x2e1806c4,0xf8bf0061}},	//   _रस्म_, _উচ্চ_, _bčf_, sbé_,
   {{0x2c748019,0x29122d2e,0x2bc483eb,0x44b601bc}},	//   _دیکھ_, _faya_, लीरा, _ọsụ_,
   {{0x29122d2f,0x52838013,0x78a4920e,0x27e68420}},	//   _gaya_, _عليك, živj, kuon_,
   {{0xfd4f0028,0x994800a0,0x26ce85ee,0x3f830390}},	// [1a30] _khiế, _دليل_, kafo_, plju_,
   {{0x63ad2d30,0x3949016b,0x60c9ad31,0x27e6ad32}},	//   rqan, _hlas_, _seem, duon_,
   {{0x39492d33,0x56952d34,0x27ff802e,0x29122d35}},	//   _klas_, _фант, _spun_, _yaya_,
   {{0x61e52d36,0x2cbf8338,0x63bbad37,0x399b2d38}},	//   ruhl, xbud_, ypun, _būsi_,
   {{0xb4e501ab,0x63ad2d39,0x6aa90162,0x9f99ad3a}},	//   नली_, qqan, _şefu, авду_,
   {{0x70b52d3b,0x60c98c2e,0x3949016a,0xfd4f00ff}},	//   ंडुल, _weem, _llas_, _nhiế,
   {{0x60c9ad3c,0x27ff80b9,0x39492d3d,0x2cbfad3e}},	//   _teem, _wpun_, _olas_, tbud_,
   {{0x63bb803a,0x2bd4901c,0x68fbad3f,0x6d4d2d40}},	//   tpun, _दिखा, _ubud, nhaa,
   {{0x29122d41,0x6fe081fe,0x69da04b8,0x2cbf81a3}},	//   _raya_, _नियं, _åter, rbud_,
   {{0x2912048f,0xfd4f0104,0x6d4d2d42,0x63bbad43}},	//   _saya_, _chiế, hhaa, rpun,
   {{0x63bbad44,0x29120695,0x7cd98019,0x39492d45}},	//   spun, _paya_, _نواز_, _blas_,
   {{0x78a902a5,0x6d598578,0x39492d46,0x7c248a20}},	//   ževn, _umwa, _clas_, _šire,
   {{0x6d4d2d47,0x291215c7,0x224d01d0,0x232984dd}},	//   dhaa, _vaya_, _řekl_, _воли_,
   {{0x39492d48,0x6da62d49,0x6569ad4a,0x973c81a1}},	//   _elas_, жива, lneh, _kića,
   {{0x63abad4b,0xa3e58105,0xad5a2d4c,0x29122d4d}},	//   _hugn, बूर_, арах_, _taya_,
   {{0x63a3abac,0x6569ad4e,0x6d4d2d4f,0x6d430087}},	//   _hinn, nneh, ghaa, _înal,
   {{0x63a3ad50,0x443fad51,0x442dad52,0xe5770a18}},	// [1a40] _kinn, nyu_, nxe_, ізу_,
   {{0x6fe081fe,0x63a3ad53,0x261a81ce,0x7c2480f7}},	//   _निबं, _jinn, _मछली_, _áire,
   {{0x64a62d54,0x443f8397,0x63ab816d,0x2d8c2d55}},	//   _мана, hyu_, _lugn, ïdes_,
   {{0x63a3ad56,0x6d4d2d57,0x443fad58,0xdce4017f}},	//   _linn, chaa, kyu_, onič,
   {{0xee02ad59,0xd70a8162,0x63ab82d5,0xc8cc801b}},	//   लब्ध_, инде_, _nugn, ारबट,
   {{0x1754a4b6,0xfaa60703,0xd04e0085,0x501b04de}},	//   явля, _фаво, ükəs, יונו,
   {{0x79460063,0xd946879e,0x6146a865,0x6283835f}},	//   _równ, _деви, _дева, _nyno,
   {{0x6d4401e2,0x63abad5a,0x7d162d5b,0xdb040511}},	//   nkia, _bugn, ndys, mpiñ,
   {{0x63a3a539,0xdce40052,0x443fad5c,0xeb06ad5d}},	//   _binn, jnič, gyu_, очно,
   {{0x63a3861f,0x6d5f036a,0x63abad5e,0xba548251}},	//   _cinn, ziqa, _dugn, звој,
   {{0x442d84c3,0x39492d5f,0x62838114,0x6d440198}},	//   axe_, _plas_, _cyno, kkia,
   {{0x63a38125,0x62838114,0x80b5064a,0x2ca682c4}},	//   _einn, _dyno, ंडें, _ugod_,
   {{0x63a39808,0xfd4f0104,0xcb6a80a9,0x61e18118}},	//   _finn, _thiế, _каде_, arll,
   {{0x63a3ad60,0x628e0b80,0xdced0bcf,0xf48781f9}},	//   _ginn, _ozbo, vlađ, _بامی,
   {{0x26ccad61,0x6d5f2d62,0x6d4d044e,0x661e0369}},	//   _medo_, tiqa, thaa, _crpk,
   {{0xb4e52d63,0x39492d64,0x91b780d5,0x63a3ad65}},	//   नले_, _ulas_, _بطور_, _zinn,
   {{0xe8731125,0x6d4d2d66,0x6d5f0748,0x628e2d67}},	// [1a50] _زندگ, rhaa, riqa, _azbo,
   {{0x6d4d2d68,0x26cc8267,0xce950098,0x2bdd909b}},	//   shaa, _nedo_, _напъ, _मिसा,
   {{0x60cd059c,0x6cea9344,0xdced0289,0x2fc900e4}},	//   _keam, _टांग_, slađ, _hwag_,
   {{0xdd868065,0x6d5f00b9,0x26d12d69,0x60c2ad6a}},	//   _سو_, qiqa, lazo_, gbom,
   {{0xf48419bb,0x880780d5,0x6d5d2d6b,0x2be20075}},	//   _журн, تظام, _imsa, _पिया,
   {{0x26d12d6c,0x60cd0635,0x26ccad6d,0x61e88234}},	//   nazo_, _leam, _cedo_, kudl,
   {{0x63a3ad6e,0xc33203c8,0x6569ad6f,0x63ab8079}},	//   _rinn, _אום_, tneh, _sugn,
   {{0x60cd0af6,0x26d1016a,0x442d89cb,0x63abad70}},	//   _neam, hazo_, txe_, _pugn,
   {{0x6569ad71,0xb4bb901c,0x399b0029,0xb4ab9a42}},	//   rneh, _अभी_, _jūsu_, _खली_,
   {{0x399b0029,0xdce42d72,0x442d84c3,0x6d932d73}},	//   _mūsu_, vnič, rxe_, lçad,
   {{0x63a3ad74,0x6d442d75,0xd9100065,0x98b00668}},	//   _vinn, ykia, ہیں_, šača_,
   {{0xdce4003b,0x6d93055a,0x63abad76,0x60cd01a8}},	//   tnič, nçad, _tugn, _ceam,
   {{0x6d4bad77,0x60cd1581,0x661e0253,0xe81e92ee}},	//   _ilga, _deam, _srpk, पिया_,
   {{0x26cc1d16,0x7d099196,0x6d5d2d78,0x61e8ad79}},	//   údo_, lees, _amsa, budl,
   {{0x61462d7a,0x65c60098,0xd9462d7b,0x60dbad7c}},	//   _нека, ябва, _неки, _odum,
   {{0x60cd2d7d,0x7d09ad7e,0x2a3a8039,0xdce41607}},	//   _geam, nees, _לעצמ, pnič,
   {{0x26d12d7f,0x6d442d80,0x2900019d,0x2fc90428}},	// [1a60] bazo_, rkia, _ibia_, _gwag_,
   {{0xe8190540,0x7d098009,0x78a9847f,0x8afc809a}},	//   दिरा_, hees, _agev, mięc,
   {{0x6d4bad81,0x2366011f,0x7d09ad82,0x7ae32d83}},	//   _olga, đoj_, kees, ónta,
   {{0xdb042d84,0xfaf88ec3,0x39b797c9,0x26ccad85}},	//   rpiñ, lnīt_, _găse_, _sedo_,
   {{0x2d821f65,0x98a70a20,0x8afc809a,0x26cc97e9}},	//   _ikke_, šića_, nięc, _pedo_,
   {{0x6d93041c,0x60dbad86,0x6d4ba0ef,0xa2bb0c9a}},	//   açad, _edum, _alga, शुद्,
   {{0x78ad803a,0x26ccad87,0x6440a251,0x7d09ad88}},	//   žava, _vedo_, wymi, fees,
   {{0x7d09ad89,0x3f878289,0x6440ad8a,0x5bb882ff}},	//   gees, alnu_, tymi, олия_,
   {{0x6fb685ff,0x7bd62d8b,0x60cd2d8c,0x26d12cde}},	//   _رمضا, nsyu, _ream, yazo_,
   {{0x29002d8d,0x60cd2d8e,0xff24803d,0x656082a6}},	//   _abia_, _seam, _تبری, simh,
   {{0x628781cd,0xc3330039,0x60cd0074,0x7bd600dd}},	//   żjon, תות_, _peam, hsyu,
   {{0x39468110,0xf8cc850d,0x26d10010,0x7bd6076d}},	//   nkos_, ारिय, wazo_, ksyu,
   {{0x61e8ad8f,0x315783c8,0x60cd2d90,0x26d12d91}},	//   sudl, ליטן_, _veam, tazo_,
   {{0xd7f81b7a,0x973c8b80,0x2d8205ee,0xe8d904be}},	//   чую_, _mićo, _akke_, _imọ_,
   {{0x50ccad92,0x8afb8051,0x26d12d93,0xf8cc8a74}},	//   ाराष, _להגי, razo_, ाराय,
   {{0x2d582d94,0x6b40007b,0xe8d900ff,0x2fc902c4}},	//   пись_, _mögu, _thự_, _twag_,
   {{0x26d1062f,0x6728911b,0xb0c3097d,0x6b40007b}},	// [1a70] pazo_, _ondj, _व्यग, _lögu,
   {{0x29190267,0xe1ab83db,0x399203a8,0xe9ff8129}},	//   ldsa_, _घूँघ, ráse_, _hoại_,
   {{0x7f3c0039,0xdb0b8687,0x62868035,0x22470061}},	//   _לעזו, _utgå, ękow, ánk_,
   {{0x67288088,0xbcfb0693,0x3946861b,0x6d5d2d95}},	//   _andj, _ejér, gkos_, _umsa,
   {{0xdb1b85b4,0x2486ad96,0x29d88028,0x6d932d97}},	//   spué, _nyom_, hĩa_, rçad,
   {{0xe9ff8104,0x7d09ad98,0xdb0286a5,0x69d88081}},	//   _loại_, wees, _otoñ, _ovve,
   {{0x7d09ad99,0xed5981bb,0x290b2d9a,0x673a85f3}},	//   tees, жой_, keca_, _dotj,
   {{0x656d2d9b,0x63af007d,0x25de8697,0xe3b9ad9c}},	//   nnah, _kucn, _गिरी_, оби_,
   {{0x69d8ad9d,0x2bdd835a,0x394dad9e,0x290b2d9f}},	//   _avve, _मिळा, _iles_, deca_,
   {{0x990608fd,0xe9d98256,0x7d09ada0,0x4a459383}},	//   षज्ञ_, око_, sees, днов,
   {{0x7d09ada1,0x63a700f3,0x779082e3,0xdb0381d0}},	//   pees, _mijn, _حیوا, _jiné,
   {{0x69d803a7,0xe6c601a2,0x6b40016d,0x2ec60c2d}},	//   ávei, वर्ज, _högt, वर्त,
   {{0x7d5680be,0xdb038866,0x69d8ada2,0x656d0df6}},	//   _קינד_, _liné, _evve, dnah,
   {{0x394dada3,0x6265997d,0x7763ada4,0x63a72da5}},	//   _lles_, _овла, ninx, _nijn,
   {{0x8fa31814,0x8afc809a,0x394d808e,0x656d2385}},	//   таре, sięc, _oles_, fnah,
   {{0x19870098,0x63af0bcf,0xa1870081,0x8afc8035}},	//   _общи_, _bucn, _обща_, pięc,
   {{0x7984022e,0x63a70a0f,0x2486822c,0x63af00c3}},	// [1a80] _ikiw, _bijn, _xyom_, _cucn,
   {{0x394d802e,0x7bd60057,0xdb098876,0x395fada6}},	//   _ales_, rsyu, mpeó, _amus_,
   {{0xdb03ada7,0x69c1ada8,0x6b52013c,0x656d0079}},	//   _ciné, nple, _lægg, bnah,
   {{0x39468110,0x395f802a,0x2004ada9,0x656d01b4}},	//   ukos_, _cmus_, _ppmi_, cnah,
   {{0x3946adaa,0x63a700f3,0x6b40007b,0x77638118}},	//   rkos_, _fijn, _sögu, finx,
   {{0x394d8e67,0xd5ba83bc,0x3946adab,0xdb03adac}},	//   _eles_, оси_, skos_, _finé,
   {{0x44222dad,0x53a700d4,0x394dadae,0x09d800ab}},	//   _hrk_, _कूटश, _fles_, _সহকা,
   {{0xb4e883eb,0x69c19c2b,0x63a701ed,0x2d800037}},	//   बले_, dple, _zijn, noie_,
   {{0xd90d8bca,0xa2a203dd,0x64440365,0x25a69139}},	//   _دین_, _कृत्, nyii, _viol_,
   {{0x79842daf,0x5a349071,0x25f68035,0x628f8035}},	//   _akiw, енот, _एमपी_, ęcon,
   {{0x6b4000f2,0x290b2db0,0x656d02a3,0x212900dd}},	//   _högs, teca_, ynah, _pnah_,
   {{0x1c46adb1,0x78a4936f,0x79960286,0x2d4707b6}},	//   _онем, živu, _chyw, _põem_,
   {{0xb8d705fb,0x6d43002e,0x290b2db2,0x59ce016f}},	//   _जल_, _înai, reca_, हीतर,
   {{0x290b02a5,0x2bb501fe,0x63af011f,0x5ee080ab}},	//   seca_, _अंबा, _rucn, প্রে,
   {{0xd9f281b6,0x27e6adb3,0x290b2db4,0x3da701e2}},	//   _अमित_, hron_, peca_, драб,
   {{0xa3e58076,0x994402bb,0x63af10d3,0x656d2db5}},	//   बूक_, mış_, _pucn, unah,
   {{0x63a72db6,0xdb039ca3,0x994407c0,0x6f170144}},	// [1a90] _pijn, _siné, lış_, _taxc,
   {{0x656d2db7,0x442214fb,0xdb038144,0xa3e6adb8}},	//   snah, _drk_, _piné, _बटन_,
   {{0x27e685a4,0x39920019,0x21f888f9,0x994408c5}},	//   eron_, lása_, néh_, nış_,
   {{0x63a700f3,0x26de833e,0x7c22adb9,0x6b448176}},	//   _wijn, _adto_, _oror, _dògi,
   {{0x7d0d2dba,0x80278013,0x78ad82a5,0x5ed380ab}},	//   meas, برام, žavo, _সাবে,
   {{0xf77381bd,0xae03016f,0x7d02adbb,0x7d0d2dbc}},	//   خاص_, _लहान_, _abos, leas,
   {{0x753d228f,0x27e6adbd,0x7763adbe,0xc17788ca}},	//   _kosz, aron_, rinx, _قدرت,
   {{0x7643adbf,0x7d0d2dc0,0x92942dc1,0x7c22adc2}},	//   ryny, neas, _расц, _bror,
   {{0x7996031d,0x76438198,0x99858061,0xf8b28e82}},	//   _rhyw, syny, _élő_, _תשמ_,
   {{0x7d0d2dc3,0x6b4000f2,0x39920019,0x69c1adc4}},	//   heas, _högr, dása_, tple,
   {{0x26c78353,0x7d0d0009,0x7c22a838,0xe1f6802e}},	//   mbno_, keas, _eror, нгэ_,
   {{0x361a8039,0x69c1adc5,0xaca38135,0x7c22802a}},	//   _מועד, rple, _arụm, _fror,
   {{0x2d802dc6,0x69c1adc7,0x291e001b,0xdb060c83}},	//   voie_, sple, ěta_, _luká,
   {{0x6d4f11b9,0xcc3a893f,0x7d1b8006,0x6b40007b}},	//   _alca, _מענט, ldus, _lögr,
   {{0x236580f2,0xd0408201,0x7d0d1997,0xd5b21a05}},	//   milj_, _demə, feas, افر_,
   {{0x7d1b8665,0xdb0985e4,0x7984004f,0x7d198326}},	//   ndus, mpeñ, _ukiw, _jaws,
   {{0x03260d9e,0x6b52013c,0xec770012,0x490000c2}},	// [1aa0] ндан, _læge, епт_, ष्णो_,
   {{0xaca4019d,0xb4db0362,0x44220d55,0x27e6adc8}},	//   _nzụt, _blàs, _vrk_, vron_,
   {{0x00e694b8,0xb4db023e,0x2d73025b,0x7d0d2dc9}},	//   ежен, _clàs, mćen_, beas,
   {{0x27e6adca,0x61e30065,0xaca40133,0xe0d29459}},	//   tron_, ánla, _azụt, ازا_,
   {{0x14d70051,0x673e2dcb,0x7d1badcc,0x27e6adcd}},	//   _אוכל_, _kopj, ddus, uron_,
   {{0x7bc42dce,0xf0930158,0x7c24adcf,0x27e6add0}},	//   mpiu, אנד_, _širo, rron_,
   {{0x99440201,0x39920019,0x38728087,0x6b6680e7}},	//   xış_, zása_, _ţară_, _légè,
   {{0x78a90024,0xe9a38e63,0xdd9781e5,0x69dc2898}},	//   ževi, _басп, ншы_, _ivre,
   {{0x3076938f,0x7d19add1,0x6b818352,0x4420009f}},	//   _чувс, _daws, folg, nvi_,
   {{0x994403bf,0x44202dd2,0xf063add3,0x973c81a1}},	//   tış_, ivi_, _скуп, _mićk,
   {{0x44202dd4,0xdb072dd5,0x2fc01670,0x7d1982ed}},	//   hvi_, _dijè, _atig_, _faws,
   {{0x4420003a,0x39920065,0x99441014,0x613f00f1}},	//   kvi_, tása_, rış_, _pëlq,
   {{0x53b5016f,0xa49b06c0,0x656282c4,0x23658b80}},	//   _अंधश, _abòn, _imoh, bilj_,
   {{0x7d19809a,0x44200088,0x7c2d8904,0xadf489c1}},	//   _zaws, dvi_, _šarg, _इमान_,
   {{0x6f1aadd6,0x753d2dd7,0x3ea52dd8,0x7d0d2dd9}},	//   _matc, _posz, ält_, teas,
   {{0x69daadda,0xdb06026f,0x2bb51da7,0x3ceb00c2}},	//   mste, _ruká, _अंदा, टलें_,
   {{0x97a7028b,0x69dc2012,0xb4db0a2a,0x442001fa}},	// [1ab0] _прол, _avre, _blàr, gvi_,
   {{0x6f1aaddb,0x7d1b8b80,0x69daa71e,0x2009008e}},	//   _natc, zdus, oste, _ipai_,
   {{0x64410201,0x69daa86b,0x44202ddc,0x7d0d2ddd}},	//   _əliy, nste, avi_, peas,
   {{0x69daadde,0x3f832ddf,0xf99f06c0,0x6b818061}},	//   iste, loju_, nmè_, zolg,
   {{0xb90992c7,0x7d19ade0,0x69dc2de1,0x41748290}},	//   _मय_, _raws, _evre, دالس,
   {{0x65628122,0x2d8686cb,0xdcfb86d3,0xdce9826c}},	//   _amoh, _akoe_, rouč, rneč,
   {{0x6b81ade2,0xc8f58698,0xda0512ee,0x69daade3}},	//   volg, _извъ, _रहित_, jste,
   {{0x26d300f1,0xab640380,0x387e0035,0x7c2000c3}},	//   _lexo_, rmüş, ętrz_, _šmri,
   {{0x69daade4,0x81c300ab,0x6d49ade5,0x290fade6}},	//   este, _এটি_, rkea, mega_,
   {{0x26d30207,0x69daade7,0x290fade8,0x656295d7}},	//   _nexo_, fste, lega_, _emoh,
   {{0x2bd18740,0x2fc02445,0x28c3016f,0x291b19ea}},	//   _दौरा, _stig_, _व्हि, _baqa_,
   {{0x290f8db7,0x291dade9,0x81c300c8,0x186a24b6}},	//   nega_, ndwa_, _এটা_, дами_,
   {{0x3959020f,0x3de380ab,0x2d8d8748,0x61e8adea}},	//   ërsa_, _মহিল, mlee_, ardl,
   {{0x290fadeb,0xdf15035f,0x2d8dadec,0x3f8306ec}},	//   hega_, льсь, llee_, goju_,
   {{0x290f8db7,0x5ed400c8,0x26d30118,0x628a8428}},	//   kega_, _তাদে, _dexo_, _gyfo,
   {{0x290faded,0x44202dee,0xa2a21299,0x25ab0037}},	//   jega_, tvi_, _कृष्, _cicl_,
   {{0xd4671a1f,0xc4d28158,0x290f8006,0x6da30012}},	// [1ac0] вите_, יגן_, dega_, рита,
   {{0x212d81f1,0x7bdb8009,0x39400362,0x7bc40048}},	//   _aneh_, isuu, _hois_, rpiu,
   {{0x26d800b4,0xab5b02af,0x2d8dadef,0xe8fa81e2}},	//   maro_, _stüc, klee_, дле_,
   {{0x290fadf0,0x26d8009c,0x6f1a8aff,0xd7e6902a}},	//   gega_, laro_, _satc, віко,
   {{0xa41c80c8,0x394003d3,0x3166adf1,0x212d807a}},	//   _তথ্য_, _mois_, rioz_, _dneh_,
   {{0x6d932df2,0x69da92cf,0xbcfb000d,0x26d81ab6}},	//   nçan, yste, _jmén, naro_,
   {{0x67042441,0x6f0307d9,0x69dc0067,0x52750087}},	//   श्यक_, _önce, _uvre, _буту,
   {{0x290f82a5,0x6f1a8039,0xe297186e,0x38c889a7}},	//   cega_, _watc, _рас_, _ساری_,
   {{0xa8878071,0xd175876a,0x98a39d5c,0x69daadf3}},	//   _айта_, _сыры, _вите, wste,
   {{0x69da9f8f,0x39400068,0x5fdc0321,0x26d82df4}},	//   tste, _aois_, _बिजल, jaro_,
   {{0x394002be,0xe7378f2e,0x69daadf5,0x26d82df6}},	//   _bois_, _шеф_, uste, daro_,
   {{0x69da8faf,0x26d303aa,0x7c2d8668,0xbcfb00e7}},	//   rste, _sexo_, _šare, _amén,
   {{0x39402df7,0x69da8456,0xc0ab0875,0x50642df8}},	//   _dois_, sste, بادل_, атра,
   {{0x26d82df9,0x4426adfa,0x973c8669,0x628aadfb}},	//   garo_, _iro_, _bići, _tyfo,
   {{0x394003d3,0x3f832dfc,0xe8d90870,0x26d301df}},	//   _fois_, roju_, _akụ_, _vexo_,
   {{0x2d84adfd,0x4426adfe,0x63ad81e8,0x6e2505f3}},	//   nome_, _kro_, _èanc, _vrhb,
   {{0x290fadff,0x26d82e00,0x27e096f2,0x26d3002a}},	// [1ad0] vega_, baro_, šinj_, _texo_,
   {{0x9952003e,0x26d80314,0x61e30019,0x2d8d80b9}},	//   máš_, caro_, ánlo, zlee_,
   {{0x6d5c81e2,0x290fae01,0x02a719bb,0x2d84ae02}},	//   _įran, tega_, трам, kome_,
   {{0x4426ae03,0xe5350009,0x2d848084,0xa6cf8264}},	//   _oro_, _семь, jome_, _রাইট,
   {{0xb4c12e04,0x4426ae05,0x290fae06,0xdee58790}},	//   ुरी_, _nro_, rega_, голи,
   {{0x290f8665,0x6d4d02c1,0x20d18104,0x77848112}},	//   sega_, lkaa, ại_, аліз,
   {{0x7bc2ae07,0x2d84ae08,0x80d280ab,0xfd1181a8}},	//   _atou, fome_, _হার্, مجة_,
   {{0xdb0d160a,0x6d4d1e3b,0x7d1d2e09,0x2d84ae0a}},	//   mpañ, nkaa, _jass, gome_,
   {{0x7d1d29da,0x4426ae0b,0x39402e0c,0x98a008ae}},	//   _mass, _cro_, _rois_, _inić_,
   {{0x7d1d2e0d,0x7bdbae0e,0x96ca8540,0xdced0024}},	//   _lass, rsuu, _स्पॉ, dnač,
   {{0x4426ae0f,0x39402e10,0x6d4d2e11,0xd9461c64}},	//   _ero_, _pois_, kkaa, гени,
   {{0x7d1d2e12,0x44268428,0x2d848039,0x6d4d2e13}},	//   _nass, _fro_, come_, jkaa,
   {{0xeb8eae14,0x4426ae15,0x26d82e16,0x39402e17}},	//   _ги_, _gro_, taro_, _vois_,
   {{0x973c80fe,0x06e580ab,0x6569ae18,0x59d0801b}},	//   _pići, প্রি, lieh, थीहर,
   {{0x7d1d2e19,0xfce6215b,0x26d82e1a,0xa50a1f0d}},	//   _bass, лово, raro_, нева_,
   {{0x7d1d2e1b,0x291e0029,0x39990065,0x6d4d2e1c}},	//   _cass, ētas_, tése_, gkaa,
   {{0x2e178201,0x5f76003d,0x25a02e1d,0x69c380c3}},	// [1ae0] _dəfə_, _مادر, rmil_, _htne,
   {{0x6d5602a0,0x46f604fa,0xdcf49487,0x7c24ae1e}},	//   shya, _счит, _čačk, _širk,
   {{0x7d1d2e1f,0x29d18796,0x6d4d01b4,0xdb0a849c}},	//   _fass, nša_, bkaa, _difè,
   {{0x3940808b,0x631400ab,0x79862e20,0x6d932e21}},	//   ðis_, সাইট_, nokw, nçal,
   {{0x6f1e0117,0xe3b207d2,0x61fe2e22,0x799b8077}},	//   _kapc, _درج_, stpl, _dhuw,
   {{0x779180d5,0x7c240842,0x9c12819d,0x798981bc}},	//   قیقا, mvir, _dọlf, _ekew,
   {{0xe297028b,0x5fe0823c,0x29d1ac62,0xdced1ef1}},	//   _бар_, _निकल, jša_, znač,
   {{0x442693d9,0x69de2e23,0x74149a3e,0x68e40135}},	//   _pro_, mspe, لوبا, _ndid,
   {{0x7c242e24,0x69de2e25,0x136a9182,0x7f41ae26}},	//   nvir, lspe, ешни_, _folq,
   {{0xa3e5901c,0x93fb012a,0xbcfb02be,0xe3bf81df}},	//   _फिर_, עליי, _amél, íña_,
   {{0x19590a7f,0xe1350364,0xaa94ae27,0x69de2e28}},	//   ваны_, анны, ринч, nspe,
   {{0x25f38076,0x4426ae29,0x69de00f7,0x63ae02d6}},	//   ्झरी_, _tro_, ispe, _libn,
   {{0x44268353,0x68e40114,0x644682f1,0x27e00176}},	//   _uro_, _ddid, äkid, _cvin_,
   {{0x7d1d2e2a,0x2b8f02af,0x69de2e2b,0x7c290bda}},	//   _sass, rück_, kspe, _šero,
   {{0x7d042e2c,0xd9048065,0x6d4d2e2d,0xe5c40081}},	//   ffis, _ٹی_, tkaa, йсто,
   {{0x6298803b,0xb4c12e2e,0x69de0e23,0x7d1d022b}},	//   _izvo, ुरे_, dspe, _qass,
   {{0x6d4d02c1,0x81b680c8,0x7afd9f79,0x69c8a014}},	// [1af0] rkaa, _ছবি_, đstv, lpde,
   {{0x7d1d2e2f,0x6d4d2e30,0x656982af,0x6e288370}},	//   _wass, skaa, zieh, _ordb,
   {{0x7d1d2e31,0x5ed380ab,0x69de2e32,0x63ae01b4}},	//   _tass, _সালে, gspe, _dibn,
   {{0xf8bf02be,0xa3e585fc,0x973c8390,0x7ff59459}},	//   ncé_, _फिल_, _miću, لستا,
   {{0x6d932e33,0x6e289997,0x69de0162,0xdb0d0333}},	//   nçam, _ardb, aspe, spañ,
   {{0x6d5801e2,0xb8ec80d4,0x99d712c8,0x79860234}},	//   _įvai, _श्_, _مترا, zokw,
   {{0xb8db80c8,0x8d558a13,0x6569ae34,0xf8c980e7}},	//   _আজ_, итич, tieh, _créé_,
   {{0xf1a48554,0x754595ac,0x29d1811f,0xdce40289}},	//   _грун, рниз, vša_, rnić,
   {{0x1c4297ae,0xdb0f11b9,0x656984dc,0x6e288192}},	//   жным, _lucí, rieh, _erdb,
   {{0x7bdf0187,0xe787ae35,0x60d62e36,0x6569ae37}},	//   isqu, _субо, _seym, sieh,
   {{0x4a758048,0x29d1ae38,0x5efe809a,0x291f82f1}},	//   рыпт, uša_, _शॉट्_, _kaua_,
   {{0xb4e42776,0xdb0385e4,0xfe708591,0x60260a41}},	//   _नये_, _diná, _عدل_, адма,
   {{0xb4c3885d,0x291f804f,0x6d93061c,0x2f248061}},	//   ्री_, _maua_, rçal, ségű_,
   {{0xfaa5ae39,0x2d8b001b,0xdb038e93,0x2909019d}},	//   _кало, _akce_, _finá, _ebaa_,
   {{0x7d042e3a,0x597604d9,0xbea61229,0x6d930722}},	//   tfis, _выпу, равк, pçal,
   {{0x7c2401e2,0x2c09809a,0x27e08805,0x29092e3b}},	//   tvir, _वहां_, šini_, _gbaa_,
   {{0xdee626c5,0xab662ce0,0x7d04007b,0x5ee080c8}},	// [1b00] _копи, авал, rfis, প্টে,
   {{0x68fbae3c,0x69de2e3d,0x212000b9,0xb4c384c5}},	//   _acud, tspe, _haih_, ्रु_,
   {{0xbd8a003f,0x399c80f7,0xa3b60999,0xf8ba00d4}},	//   _لندن_, híse_, _चूर_, _इलाय,
   {{0xb4db0028,0x4fc6ac39,0x6d430087,0x628e016b}},	//   _hoàn, аска, _înap, _vybo,
   {{0x628e2e3e,0x63ae2e3f,0x779482e3,0x27e08834}},	//   _wybo, _tibn, میرا, éin_,
   {{0x7c2480f7,0x69de2e40,0x2d922e41,0x7bc6062c}},	//   _áiri, pspe, llye_, _itku,
   {{0x91e302a4,0x25af81a1,0xdb0e0168,0xcb67002e}},	//   _море, _bigl_, _libë, _таре_,
   {{0x27e98341,0x7c2d8052,0x399c81a8,0xa534acab}},	//   šana_, _šara, físe_, снич,
   {{0xef1a8abe,0x60cdae42,0x973c80d2,0xf8bf00e7}},	//   _има_, ñame, _siću, ndée_,
   {{0x3b5491b3,0x3944ae43,0xd00f80f7,0x316b0035}},	//   скор, _homs_, _تلك_, wicz_,
   {{0xe81e825e,0x44e880ab,0x7c2901b9,0x291f8c53}},	//   पिका_, ক্ষক_, _ġerm, _yaua_,
   {{0x7bc6003a,0x26dcae44,0x2b0606f0,0xbc6789a7}},	//   _otku, lavo_, स्तु_, امین_,
   {{0xb4d2ae45,0x7afc00d2,0xf8bf2e46,0x1b1d0264}},	//   वरी_, _ocrt, rcé_, নাতে_,
   {{0xe7872894,0x200501b9,0x26dcae47,0xdb0e13de}},	//   румо, ċli_, navo_, _dibë,
   {{0xd5b81e58,0x139b84de,0x539b8039,0x629880d2}},	//   ист_, _שבוע, _שיוו, _uzvo,
   {{0x3944ae48,0x3a2d2e49,0x48670081,0x00000000}},	//   _noms_, _čep_, _въоб, --,
   {{0x9fe180ab,0x798d2e4a,0xe7ee0105,0x3f87880a}},	// [1b10] _মঙ্গ, _ikaw, _जिया_, yonu_,
   {{0xf2c7096b,0x7bdf02be,0x26dcae4b,0x68fb847f}},	//   рсан, rsqu, javo_, _scud,
   {{0xd1b80065,0x26dc8110,0x6f150216,0x79a786fd}},	//   لانا_, davo_, mezc, арде,
   {{0x3944ae4c,0x8c48017b,0xc10580f7,0xdb0e06c0}},	//   _coms_, _bağı, صوتي, _libè,
   {{0xdc350159,0x656d010c,0x2cbf811c,0x80c68327}},	//   _האָט_, miah, vcud_, ाड़े,
   {{0x8c480182,0x656d2e4d,0x6f152e4e,0x6dbc007a}},	//   _dağı, liah, nezc, _očal,
   {{0xb87b17ad,0x6b52006a,0x291fae4f,0xb345841c}},	//   laíd, _mægl, _taua_, _loçã,
   {{0x798d01c5,0xb4c38f21,0xe3bf81df,0x656d2e50}},	//   _nkaw, ्रे_, íño_, niah,
   {{0x69c7120e,0x21200590,0x26dc807a,0x442b0197}},	//   _htje, _raih_, bavo_, _jrc_,
   {{0xda0e2af8,0x798d2e51,0x26dc81e8,0x442b2e52}},	//   _सहमत_, _akaw, cavo_, _mrc_,
   {{0xe69580f7,0x39920019,0x442b026c,0x6f150e1b}},	//   _الاد, lási_, _lrc_, dezc,
   {{0x6721ae53,0xf65282f6,0x8c48080a,0x7bc9ae54}},	//   _halj, _מצב_, _yağı, ppeu,
   {{0x656d2e55,0x4ca580ab,0x6721ae56,0xe81b03a4}},	//   diah, _গ্রু, _kalj, _पैदा_,
   {{0x20022e57,0x69c702ce,0x6721808e,0x6d5bae58}},	//   rtki_, _otje, _jalj, lhua,
   {{0xceb281db,0xed5a1628,0xa6e3007b,0x20022e59}},	//   לים_, гов_, íðar, stki_,
   {{0x6d5b80fc,0x26dc8517,0x7afc0267,0xc21281c6}},	//   nhua, zavo_, _scrt, _זהה_,
   {{0x64a30084,0x657603a6,0x7c3bae5a,0xdcfb8380}},	// [1b20] зата, rnyh, nxur, zluğ,
   {{0x39448b3c,0x7c2bae5b,0xb05b016d,0x6721ae5c}},	//   _soms_, _mrgr, rbät, _nalj,
   {{0x260184c3,0x442b009f,0x6d5b8748,0x26dc8084}},	//   jóo_, _erc_, khua, vavo_,
   {{0x00da803f,0x3f8a2e5d,0xd91080d5,0x6d5b8282}},	//   ابات_, lobu_, بیر_, jhua,
   {{0xdcfb82a5,0x7d160079,0xdb0e00e7,0x5ec980ab}},	//   jluđ, meys, _libé, _রয়ে,
   {{0xa09b0158,0x06d880c8,0x6d4606cb,0x7d162e5e}},	//   ניסט, _সাহি, _hoka, leys,
   {{0x6d462e5f,0x7c2b8114,0x60c415a0,0x3944ae60}},	//   _koka, _argr, _ofim, _toms_,
   {{0x2fda83f8,0x75242e61,0x6d462e62,0x6fb68077}},	//   _مورد_, ndiz, _joka, _همرا,
   {{0x7524004f,0x6d462e63,0x3eaa8388,0x67218168}},	//   idiz, _moka, _ºbto_, _falj,
   {{0x6d462e64,0x69c103d3,0xd00f8eca,0x8c1b0039}},	//   _loka, _élec, _سلم_, נויי,
   {{0xd9151006,0x60c904c3,0x61150fe6,0x60dd0102}},	//   одны, ñemo, одну, tasm,
   {{0x27e0805c,0xf53f016d,0x6d5bae65,0xd7fb0198}},	//   šinu_, _ihåg_, chua, луг_,
   {{0xbfb68104,0x588701e5,0x60dd2e66,0xc05803a9}},	//   _điểm_, сына, rasm, бір_,
   {{0x3f8a2e67,0x26da0144,0xac9784a3,0x3c778e82}},	//   gobu_, _cepo_, _انها_, _פתגם_,
   {{0x26da2e68,0x6f1505a4,0x656d00e1,0x39920019}},	//   _depo_, rezc, tiah, zási_,
   {{0x22ae8086,0x6d408247,0x7d160079,0x6a4a8085}},	//   mək_, njma, geys, rəfd,
   {{0x6d9303d3,0x69c71277,0xb4b9000f,0x656d2e69}},	// [1b30] nçai, _stje, _चली_, riah,
   {{0x656d01ac,0xb87b2602,0x6b4d8144,0x6d5bae6a}},	//   siah, raíd, _púgi, zhua,
   {{0xfbda88fd,0x644d0239,0x821500f7,0x7d1601b4}},	//   _मौसम, syai, تواص, beys,
   {{0x39920065,0x6d5bae6b,0x6dbc005c,0x752281ac}},	//   tási_, xhua, _očaj, _naoz,
   {{0x672198c5,0x261b8076,0x6d4080d2,0xf8078087}},	//   _palj, _मनही_, djma, счен,
   {{0x7c2d811f,0x44292e6c,0xf41f0198,0x2fc90122}},	//   _šaro, mva_, _isä_, _mtag_,
   {{0x6721803a,0x69c7120e,0xe81b175d,0x67238052}},	//   _valj, _utje, _पैसा_, rdnj,
   {{0x60c2ae6d,0xdd9180f7,0x44292e6e,0xd65804de}},	//   ccom, بوع_, ova_, מיות_,
   {{0xe3b693cd,0x7bcd2e6f,0x6721ae70,0x27e080f7}},	//   обы_, npau, _talj, áint_,
   {{0x44292e71,0x6d5bae72,0x98ad80e1,0x60dbae73}},	//   iva_, shua, _hneď_, _heum,
   {{0xe2999289,0x44278416,0x44290406,0x60db80dd}},	//   ран_, _گراف, hva_, _keum,
   {{0x4429003a,0xfd5681bc,0x6d5b81c0,0x7d1601b4}},	//   kva_, _mgbọ, qhua, xeys,
   {{0x6d462e74,0x2bb50d14,0xdce9ae75,0x26da0c53}},	//   _roka, _अंगा, nieč, _pepo_,
   {{0x6d462e76,0x7c29ae77,0xbf9b0073,0x83fd8019}},	//   _soka, mver, stên, rződ,
   {{0x22ae8086,0x3f8a026f,0x61462e78,0x7d162e79}},	//   cək_, robu_, _мека, teys,
   {{0xdce98110,0x7c29a86c,0x9f468118,0xb05b0338}},	//   kieč, over, iroá_, rbär,
   {{0x06d900c8,0x7d162e7a,0xfd56aaaa,0x7bcd13d2}},	// [1b40] _তারি, reys, _agbọ, gpau,
   {{0x68e9ae7b,0x75242e7c,0x1b1780ab,0x7c29ae7d}},	//   _aded, sdiz, তাকে_, iver,
   {{0x7c299103,0x44292e7e,0xe8220ebf,0x8afc809a}},	//   hver, ava_, मिका_, mięt,
   {{0x60c2a651,0x7c29ae7f,0x629c1fd8,0xf1a9803d}},	//   ucom, kver, _vzro, مانه_,
   {{0xb4d62e80,0x7c29ae81,0x88169a3e,0x68e9ae82}},	//   हरी_, jver, تباط, _dded,
   {{0x05ea9d59,0x60c2ae83,0xe3a78591,0x8afc809a}},	//   афии_, scom, _زر_, nięt,
   {{0xd6d98cde,0xda0e090a,0x629c003a,0xd5b78364}},	//   сті_, _सहित_, _uzro, осы_,
   {{0x7c290042,0x29002e84,0x7c29ae85,0x60db8706}},	//   _šeri, _ncia_, fver, _geum,
   {{0x7c29ae86,0x8d5b03de,0xb054819d,0x8b6681a8}},	//   gver, יכקי, ọọrụ_, قادم,
   {{0xb4d613d9,0x3f76809a,0xa3dc2263,0xeb4a9cd0}},	//   हरु_, dług_, णीय_, рчик_,
   {{0x2b4783d3,0x06d900ab,0x79952e87,0x2c0600ab}},	//   _donc_, _তালি, зинф, রিয়ে_,
   {{0x81bc8341,0xb4b9023c,0x22ae8201,0x212682f7}},	//   lvēk, _चले_, rək_, ndoh_,
   {{0x2006ae88,0x22ae829a,0x32058833,0x69c807b6}},	//   ntoi_, sək_, atly_, _édef,
   {{0x6d932e89,0xdefb0110,0x21248229,0x7c3b0580}},	//   nçav, шым_, _lamh_, _àuri,
   {{0xb4d60b6f,0xd25080f7,0xc4db04ae,0x3205ae8a}},	//   हरू_, _سنة_, иђа_, ctly_,
   {{0xb87b0187,0x395d81c0,0x6ecb170c,0x200683ed}},	//   raíb, xhws_, _त्रु, ktoi_,
   {{0x29192e8b,0x4c940198,0x0cab2e8c,0x94ab14c4}},	// [1b50] mesa_, дитс, ртви_, ртва_,
   {{0x29192e8d,0x60dbae8e,0x6f188904,0x7bcd00c6}},	//   lesa_, _seum, jevc, rpau,
   {{0x3915885f,0x44292e8f,0x7bcd0110,0x9268108d}},	//   змер, sva_, spau, орца_,
   {{0x68fd1887,0xdb0b8106,0xdb1bae90,0x28f88749}},	//   ngsd, _utgö, rqué, жець_,
   {{0x25a90ecb,0x67250074,0x39490118,0xdb1b85c9}},	//   mmal_, _kahj, _moas_, squé,
   {{0x7c29ae91,0x9a87143d,0x3949056c,0x25a92e92}},	//   vver, _дубл, _loas_, lmal_,
   {{0xd90f8065,0x2006ae93,0x7c29890d,0x316f8118}},	//   _لیا_, atoi_, wver, pigz_,
   {{0x25a902af,0x29192e94,0x67252e95,0xea0000ff}},	//   nmal_, jesa_, _lahj, _hiếp_,
   {{0x29192e96,0xc10480f7,0x7c2980e7,0x657e80e7}},	//   desa_, _توقي, uver, épha,
   {{0x63bd2e97,0x25a901ec,0x67252e98,0x7d09ae99}},	//   _musn, hmal_, _nahj, sfes,
   {{0x29192e9a,0x39490548,0x25a92e9b,0x29000144}},	//   fesa_, _boas_, kmal_, _pcia_,
   {{0x3949062f,0x29192e9c,0x7c29ae9d,0x9f42001b}},	//   _coas_, gesa_, pver, mské_,
   {{0xdb03ae9e,0x9f4203fb,0x63bb01df,0x44298548}},	//   _minú, lské_, _éunh, _éa_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4203cb,0x6da62e9f,0x2bb5000f,0x442f82f7}},	//   nské_, зива, _अंजा, _hrg_,
   {{0xf9920077,0x7ae1aea0,0x63bd031d,0xb4d617ba}},	//   _ثبت_, lalt, _busn, हरे_,
   {{0x29c18028,0x27e9aea1,0xaaba0a47,0xf48400d7}},	// [1b60] _hóa_, šanj_, مدار_, ذاری,
   {{0xdb0b8118,0x8b230d55,0x442f8362,0xed160035}},	//   _augú, ндуе, _mrg_, _łódź_,
   {{0x63b50da8,0x9f42016b,0xb6bb01c6,0xdb1989c4}},	//   _dizn, jské_, _לציי, _cuwé,
   {{0x7ae1aea2,0x2d8081ac,0xa6d880ab,0x63bd2ea3}},	//   halt, čiek_, _সাইট, _fusn,
   {{0x18188077,0x7ae1a32d,0x98a68162,0x29c1aea4}},	//   تراک_, kalt, чиде, _lóa_,
   {{0xbb4a0013,0x7bcb2e3c,0x291902ec,0x2006aea5}},	//   _الآن_, ígue, zesa_, rtoi_,
   {{0x7ae18fe0,0x442f848d,0x6f188da8,0x29192ea6}},	//   dalt, _arg_, revc, yesa_,
   {{0x6d4408de,0xd90d826a,0x7cf6880a,0x442f89ca}},	//   njia, _نیم_, dürü, _brg_,
   {{0x9f5900f2,0x29192ea7,0x06e200ab,0x63bd0df6}},	//   ltså_, vesa_, _বানি, _xusn,
   {{0x27e6aea8,0x442f8573,0x44222ea9,0x7ae1aeaa}},	//   mson_, _drg_, _msk_, galt,
   {{0x442f82d8,0xc333036b,0x29192eab,0x6d5604b9}},	//   _erg_, גות_, tesa_, kkya,
   {{0x463b80be,0x26de876d,0x7ae1aeac,0x68e28c53}},	//   _לעבע, _heto_, aalt, naod,
   {{0x7ae1aead,0x26de80f1,0x24aa80ab,0x63602eae}},	//   balt, _keto_, _গ্রহ, _göng,
   {{0x27e683d3,0x7c22aeaf,0xd3708077,0x7ae1aeb0}},	//   ison_, _isor, _جهت_, calt,
   {{0x29192eb1,0x39920019,0x63b50289,0x2cb9008e}},	//   pesa_, tást_, _rizn, _pgsd_,
   {{0x26deaeb2,0x9cfa8264,0x5d9901e2,0x3f8e9ffb}},	//   _leto_, _আসুন_, ікаў_, hofu_,
   {{0x68ed2eb3,0x68e2aeb4,0xa49b0032,0x27e68b80}},	// [1b70] _idad, daod, _abòr, json_,
   {{0x8aa705c2,0x02a70adb,0x25a901ec,0x6d562eb5}},	//   пред, прем, smal_, akya,
   {{0x2b0e8023,0x60cda56c,0x98bf8087,0xfe1b8424}},	//   त्यु_, ñamo, _nouă_, _भैंस_,
   {{0x1a6804c0,0x63bd2eb6,0x9f42026f,0x7c22aeb7}},	//   سیقی_, _tusn, vské_, _osor,
   {{0xea000104,0x26deaeb8,0xbcfb002a,0x7d0d2eb9}},	//   _tiếp_, _beto_, _alég, mfas,
   {{0x9f42003e,0x7c2d2eba,0xaae10cfd,0x26de8041}},	//   tské_, mvar, _फ़िक, _ceto_,
   {{0x7ae1aebb,0x26de80b9,0xa3dfaa90,0x68ed2ebc}},	//   valt, _deto_, धीन_, _odad,
   {{0x7d0d2ebd,0x98bf802e,0x27e90292,0x9f42027f}},	//   nfas, _două_, _ovan_, rské_,
   {{0xb4bd835a,0x7ae1aebe,0xbcfb2ebf,0xdc0b00ab}},	//   _आली_, talt, _elég, রিকস_,
   {{0x63600459,0x68ed2ec0,0x04ff80ab,0x7cf68059}},	//   _gönd, _adad, ্যের_, türü,
   {{0x27e906c0,0x7c22aec1,0x6d5d061c,0x987000e1}},	//   _avan_, _esor, _olsa, rúča_,
   {{0x7ae1ae89,0x442f8796,0x29e78c18,0xdb06002a}},	//   salt, _trg_, rđa_, _yukó,
   {{0x442f80b9,0x7ae1aec2,0xeb8e8087,0x7d1baec3}},	//   _urg_, palt, _аи_, meus,
   {{0xdfcf0013,0x6d4baec4,0x442daec5,0x61faaec6}},	//   شيف_, _hoga, mve_, butl,
   {{0xab28845b,0xdb1b97ad,0x7d0d2ec7,0x7c2d0084}},	//   _رسول_, nquí, ffas, evar,
   {{0x7529aec8,0x6d4baec9,0x78bb822e,0xe5a32c18}},	//   ndez, _joga, _nguv, виси,
   {{0x9f5fae3c,0x6360016d,0x7c2d2eca,0x2fcd822c}},	// [1b80] _aquí_, _löne, gvar, _nteg_,
   {{0x6d4baecb,0xdcdaa7fb,0xa3df83eb,0xeb9f00e8}},	//   _loga, _यज्ञ, धीय_, _spør_,
   {{0x26deab49,0x75262ecc,0xc87f02af,0x7d1baecd}},	//   _reto_, _takz, raße_, keus,
   {{0x442d803a,0x63602ece,0x26deaecf,0xaca38032}},	//   kve_, _sönd, _seto_, _afọj,
   {{0xd0108277,0x44222ed0,0xa3f880ab,0x442d80f1}},	//   الت_, _usk_, _অন্য_, jve_,
   {{0x27e68782,0x60c9aed1,0x44200010,0x7d02aed2}},	//   rson_, _efem, mwi_, _scos,
   {{0xe1e78117,0x442daed3,0x656f031d,0x27e6aed4}},	//   _جس_, eve_, _ymch, sson_,
   {{0x6f1c2ed5,0x636007d9,0x6d4b9a2f,0x7d1baed6}},	//   herc, _döne, _coga, geus,
   {{0xe3bf01df,0x26deaed7,0xea0000ff,0x44200114}},	//   _xuñ_, _teto_, _khắp_, nwi_,
   {{0x6d9307e0,0x291202d6,0x68e0aed8,0x61faaed9}},	//   nçar, _abya_, _hemd, tutl,
   {{0x6d4baeda,0x7d2780f2,0x442daedb,0x7d1b8118}},	//   _foga, örsä, ave_, beus,
   {{0x7d1b8373,0x7c2284b9,0x442daedc,0x68e0826c}},	//   ceus, _tsor, bve_, _jemd,
   {{0xab2a91b3,0xf7730829,0x7c22882e,0x442000b4}},	//   _мода_, ناس_, _usor, jwi_,
   {{0x636007d9,0x6f1c2edd,0x44202ede,0x61faaedf}},	//   _yöne, gerc, dwi_, putl,
   {{0x672880f1,0xb87b28d5,0x7d0d248a,0x7dc782d0}},	//   _madj, caín, tfas, _kısa,
   {{0xbcfb2ee0,0x6d4b862f,0x06e200ab,0x68ed2ee1}},	//   _amér, _xoga, _বাণি, _udad,
   {{0xdd940196,0x7d0d10f6,0x6f1c2ee2,0xb87b00f7}},	// [1b90] таты, rfas, berc, maío,
   {{0x6f1c2ee3,0x672889cf,0xb87b0013,0x3866aee4}},	//   cerc, _nadj, laío, dzor_,
   {{0x442daee5,0x2fcdaee6,0x3f912ee7,0x2bdf06f0}},	//   zve_, _steg_, mozu_, _पौरा,
   {{0xb4bd835a,0x63b8942f,0xb87b00f7,0x8aa4220b}},	//   _आले_, _livn, naío, труд,
   {{0xe739aee8,0xdd910065,0x442d0091,0x6d4baee9}},	//   зел_, _لوگ_, _ée_, _roga,
   {{0x25a68019,0x6d4baeea,0x442daeeb,0xb87b01a8}},	//   _ahol_, _soga, vve_, haío,
   {{0xf7708bbe,0x995c803e,0x7ae52eec,0xe8d911d3}},	//   جان_, síš_, maht, _alọ_,
   {{0x442daeed,0x6f1c003e,0x9425a017,0xdb1b85e4}},	//   tve_, zerc, емие, rquí,
   {{0x6d4baeee,0x442daeef,0x291da659,0x7d1baef0}},	//   _voga, uve_, mewa_, reus,
   {{0x291d822e,0x4a45867c,0x1b1d00c8,0x629881b0}},	//   lewa_, енов, নাকে_, _byvo,
   {{0x44202ef1,0x63b88503,0x442daef2,0x6d4b8014}},	//   zwi_, _divn, sve_, _toga,
   {{0x2fc00722,0x9952026f,0x291daef3,0x25b90f3e}},	//   _puig_, sáž_, newa_, _nisl_,
   {{0x25adaef4,0x394d879f,0xdbd70406,0xf1b9aa06}},	//   mmel_, _moes_, _jäät, _miš_,
   {{0x7ae5178f,0x442006c4,0x291daef5,0x63b8aef6}},	//   jaht, vwi_, hewa_, _givn,
   {{0x6996239f,0x59b98076,0x291daef7,0xba5280f7}},	//   _прих, _ईंटर, kewa_, _منوع,
   {{0xa0a60048,0xb87b0013,0xa2cd08fd,0xf1b98024}},	//   _пайд, caío, दुस्, _niš_,
   {{0x248604c3,0xac861663,0x291daef8,0x2bdb001b}},	// [1ba0] çom_, хгал, dewa_, मीला,
   {{0x395faef9,0xe6258028,0x44202efa,0x6b520366}},	//   _alus_, _đông_, rwi_, _nægt,
   {{0x26d82efb,0xa2a5053e,0x44202efc,0x6728aefd}},	//   mbro_, _करण्, swi_, _radj,
   {{0x29022efe,0x8c461e17,0x39990019,0x67288353}},	//   ngka_, _земе, tési_, _sadj,
   {{0x394daeff,0xea000129,0x2d802f00,0x6728832a}},	//   _does_, _thắp_, mnie_, _padj,
   {{0x2d800063,0x69dc041c,0x6720052a,0x395faf01}},	//   lnie_, _twre, मजिक_, _elus_,
   {{0xfaa32f02,0x5693af03,0x63830098,0x395f81b9}},	//   _баро, лашт, _сгра, _flus_,
   {{0x291daf04,0x248681df,0xa53480c4,0xd00a9052}},	//   cewa_, _pxom_, тнич, _небе_,
   {{0x9f868221,0x63b89a84,0xfbcf815b,0x2d802f05}},	//   _згад, _pivn, یتی_, inie_,
   {{0x5a348e17,0x7c3b12ca,0x2d802f06,0xdbdb846d}},	//   внот, _áure, hnie_, _dààt,
   {{0x7d0604b8,0x28f92f07,0xb87b00f7,0x3f912f08}},	//   _ocks, мень_, taío, vozu_,
   {{0x25d983f8,0xea000104,0x7c262f09,0xa3c0000d}},	//   _آهنگ_, _nhập_, _oskr, ँदा_,
   {{0x2d800063,0xdd8f8154,0xb87b00f7,0xd8382f0a}},	//   dnie_, _اون_, raío, нэр_,
   {{0x4426af0b,0x61fe003a,0x2d80009a,0xb87b00f7}},	//   _iso_, kupl, enie_, saío,
   {{0xbe882f0c,0x249f0088,0xdb03801b,0x59b0af0d}},	//   есте_, _šum_, _jiný, जगार,
   {{0x2d802f0e,0x6564009c,0xba9b8039,0x4426af0f}},	//   gnie_, ghih, _מסוי, _kso_,
   {{0x44268088,0x26d800e5,0x7ae518c2,0x3ebe80c3}},	// [1bb0] _jso_, bbro_, taht, _ogtt_,
   {{0x6d5a08cf,0xd6db0009,0x2d800035,0x63ad8037}},	//   ëtar, _эти_, anie_, _èant,
   {{0xf7718bca,0x395fa527,0xa4d924b6,0x2d9202a0}},	//   یات_, _plus_, _одну_, boye_,
   {{0xdbd70364,0x4426811e,0x60b59ec9,0x2d80009a}},	//   _päät, _oso_, نمائ, cnie_,
   {{0x4426af10,0xb8e98076,0xbcfb02ba,0x7ae50364}},	//   _nso_, _ईल_, _eléc, paht,
   {{0x394d81b0,0x6d4f0214,0x21298824,0xbcfb0866}},	//   _woes_, _hoca, žah_, _fléc,
   {{0x4426af11,0x291d8010,0x6d4f2f12,0x6b52006a}},	//   _aso_, pewa_, _koca, _vægt,
   {{0x752d2f13,0x69c78efc,0x7415845b,0x8477826b}},	//   ndaz, íjem, نوعا, _aáwẹ,
   {{0x51849fe3,0xdb1882d6,0x5f09866f,0xe4c895a9}},	//   _сура, _kivè, _साप्_, ربين_,
   {{0x2d8024a3,0x799d01ec,0x6b52008b,0xdd0201a1}},	//   znie_, elsw, _hægr, _čučk,
   {{0x4426af14,0x96ca8540,0x36d48009,0x68e62f15}},	//   _eso_, _स्टॉ, _сохр, takd,
   {{0x27e98341,0x2902816d,0x4ad18701,0x6dbc131b}},	//   šanu_, _ökat_, _द्रव, _očar,
   {{0xf1b28f60,0xd24e80d5,0x8b25af16,0x3ebe8326}},	//   יסט_, منی_, _адле, _ygtt_,
   {{0x06e200ab,0x7bc00187,0x3ebe004a,0x6d5b8bf0}},	//   _বাহি, _émui, øtt_, lkua,
   {{0x6d4f2f17,0x2d800063,0xfce60171,0x4426af18}},	//   _boca, tnie_, ково, _zso_,
   {{0x7ae38de1,0x2bc30fb8,0x6d5baf19,0x26d82f1a}},	//   _hent, _वंशा, nkua, sbro_,
   {{0xc9530051,0x78a40503,0x69c3af1b,0x2d802f1c}},	// [1bc0] _כמה_, _uziv, _hune, rnie_,
   {{0x7ae3af1d,0x69c3acf2,0x27e02f1e,0x65642f1f}},	//   _jent, _kune, _iwin_, shih,
   {{0x6d4f0013,0x6dbc0353,0xdb1886c0,0xea0000ff}},	//   _foca, _včas, _divè, _thập_,
   {{0x7ae3af20,0x69c3af21,0x61fe2f22,0x3f85826c}},	//   _lent, _mune, rupl, _ajlu_,
   {{0x69c3af23,0xf7468003,0xdb0baf24,0x7c26005c}},	//   _lune, кедо, _bugü, _uskr,
   {{0x7bd62f25,0x68e405d1,0x7d042f26,0x7ae3af27}},	//   mpyu, _leid, lgis, _nent,
   {{0x69c3af28,0x91e30e02,0x27ed8051,0x752b81a1}},	//   _nune, _восе, _even_, _bagz,
   {{0x7d042f29,0x68e40114,0x39992f2a,0x6d4f2f2b}},	//   ngis, _neid, nést_, _xoca,
   {{0x7ae38763,0x63bc2f2c,0x7c240192,0x27ed81f4}},	//   _bent, _kirn, nwir, _gven_,
   {{0x69c3af2d,0x3a27808e,0x4426807a,0xdb188061}},	//   _bune, _bsnp_, _vso_, _kivé,
   {{0x68e42f2e,0x69c3af2f,0x7ae39f21,0x6ed88f1b}},	//   _beid, _cune, _dent, _न्यु,
   {{0x442681e9,0x7c2400b4,0x7ae3af30,0x629c2176}},	//   _tso_, kwir, _eent, _myro,
   {{0x7ae3af31,0x5887014c,0x68e401e4,0x60cd8020}},	//   _fent, тына, _deid, ñami,
   {{0x7ae3af32,0x63bc01a1,0x629c02c4,0x52e10035}},	//   _gent, _nirn, _oyro, _फ़ेस,
   {{0xe5c42f33,0xd378811f,0x68e40013,0x31668019}},	//   исто, mić_, _feid, khoz_,
   {{0x7ae3af34,0x7982809a,0x7d042f35,0x9f59026f}},	//   _zent, jnow, ggis, musí_,
   {{0x63bc03c3,0x6c542f36,0x752d2f37,0x629c0420}},	// [1bd0] _birn, акту, rdaz, _ayro,
   {{0x7ae3862f,0x629c2f38,0x7d042f39,0x68e40bfd}},	//   _xent, _byro, agis, _zeid,
   {{0x3f83011f,0xdb050013,0x6562af3a,0x27edaf3b}},	//   mnju_, gmhá, _oloh, _sven_,
   {{0xd37885f5,0x6d4f026c,0x7c2402a0,0x9f4203c1}},	//   hić_, _uoca, bwir, mská_,
   {{0xd3788025,0x7ae8af3c,0x629c0bb1,0x9f4205b9}},	//   kić_, kadt, _eyro, lská_,
   {{0x65628091,0xd378803b,0x6360007b,0x490886a7}},	//   _aloh, jić_, _hönn, _हाथो_,
   {{0x63602f3d,0x9f42003e,0xd378803b,0x2d55013c}},	//   _könn, nská_, dić_, _fået_,
   {{0xdb1d0a56,0x2d55013c,0x661a8748,0x4424822c}},	//   _musí, _gået_, _dptk, fwm_,
   {{0x7ae38193,0x6d5baf3e,0x69c3af3f,0x3f831351}},	//   _pent, rkua, _sune, knju_,
   {{0xd37885f5,0xe9d99016,0x69c3af40,0x2902816d}},	//   gić_, нко_, _pune, _ökar_,
   {{0x3f83003b,0xc3320158,0xdb0385e4,0x68e42f41}},	//   dnju_, זוי_, _sinó, _peid,
   {{0x69c380fe,0x290911b9,0x7412803d,0x9f42016b}},	//   _vune, _ccaa_, جویا, dská_,
   {{0x68e42f42,0xd3788d78,0xe9e980e1,0xa3dfac07}},	//   _veid, bić_, dnúť_, धीश_,
   {{0x44322f43,0x68e40faf,0xd378809a,0x2d992f44}},	//   vvy_, _weid, cić_, _akse_,
   {{0x68e42f45,0x39990019,0x2bdfa776,0x31790035}},	//   _teid, tést_, पीरा, bisz_,
   {{0x96d411bc,0x63bc2f46,0x7c242f47,0x2d960a14}},	//   _ब्रॉ, _sirn, twir, ургс,
   {{0x6da30087,0x09cc016f,0x3f832cf6,0x629c0690}},	// [1be0] сита, ाऱ्य, bnju_, _syro,
   {{0x7c242f48,0x44322f49,0xfbcd00ab,0x87260009}},	//   rwir, rvy_, _লিখত, _смож,
   {{0xe8faaaa8,0x20022f4a,0x7c242f4b,0x644001a1}},	//   еле_, luki_, swir, _šmid,
   {{0x629c027f,0xd378af4c,0x786a8019,0x88e68198}},	//   _vyro, zić_, _növé, ужде,
   {{0x63bc2f4d,0x20022f4e,0xe3c880ff,0x629c0035}},	//   _tirn, nuki_, _mực_, _wyro,
   {{0xdb1c00f1,0xe3c88028,0x31668019,0x96a8001b}},	//   _mirë, _lực_, shoz_, _गराउ,
   {{0xd378803b,0x6b632f4f,0x7bc60300,0xd6d9804a}},	//   vić_, _укра, _huku, тті_,
   {{0x7bc62f50,0x3f83007d,0x1db4035a,0xd378809a}},	//   _kuku, znju_, ंगित, wić_,
   {{0xd378803a,0x12e68a4c,0x7bc62f51,0xe64483bf}},	//   tić_, лінг, _juku, ılığ,
   {{0x96d42f52,0x20022f53,0x7bc62122,0x39402f54}},	//   _ब्लॉ, duki_, _muku, _anis_,
   {{0xd378803a,0x7bc62f55,0xdb0380f7,0x3f832f56}},	//   rić_, _luku, _ghní, vnju_,
   {{0x2ee58613,0xe3c88028,0x9f42026f,0xf1ab0077}},	//   _zelf_, _cực_, vská_, عاده_,
   {{0x8d938013,0x3f830024,0x7bc62f57,0x69c100e7}},	//   _النش, tnju_, _nuku, _élev,
   {{0x9f42026f,0x3179009a,0x28e32db8,0x636001fa}},	//   tská_, sisz_, परहि, _sönn,
   {{0x58d50698,0x31790063,0xe8d90135,0x3f83012b}},	//   _койт, pisz_, _ajụ_, rnju_,
   {{0x7bc62f58,0x3f8302a5,0x9f42026f,0x20022f59}},	//   _buku, snju_, rská_, buki_,
   {{0x7bc60763,0x3f83173d,0x33752b05,0x80cd8264}},	// [1bf0] _cuku, pnju_, агар, ারম্,
   {{0x7bc62f5a,0x9f42128a,0x332e8372,0xa3e6885d}},	//   _duku, pská_, _jafx_, यीय_,
   {{0xfaa7174a,0x02a72e27,0xb4db0362,0xe9e981d6}},	//   ушан, урам, _cnàc, pnúť_,
   {{0xdc34026f,0x27ed012b,0x2ee58039,0x3835802e}},	//   _zúča, šenu_, _self_, инер,
   {{0x7bc62f5b,0x3b0a0580,0x5045847f,0x6360029a}},	//   _guku, _fcbq_, релб, _könl,
   {{0x6d4d2f5c,0xb0d580d4,0x29068102,0x2b140ebf}},	//   ljaa, _ड्रग, agoa_, न्दु_,
   {{0xf1a785c2,0x7bc601ec,0xd0560085,0xf1c980ff}},	//   _бран, _zuku, _deyə, _mạc_,
   {{0x442b2f5d,0x6d4d2f5e,0xf1c98028,0x528400f7}},	//   _ksc_, njaa, _lạc_, _الفك,
   {{0x7bc602a3,0xab6595ac,0x2ee5af5f,0x69ceaf60}},	//   _xuku, ивил, _telf_, íben,
   {{0xce6b9a1f,0x69c72f61,0xd7a4000f,0x68eb84dc}},	//   _пред_, _kuje, _खींच, lagd,
   {{0x216a2f62,0x6723895e,0xa96a013a,0xfaa5af63}},	//   вини_, menj, вина_, рано,
   {{0x69c704a1,0x67238353,0xdc3401ac,0x442b00ee}},	//   _muje, lenj, _súča, _osc_,
   {{0x6603af64,0xe3c88028,0x25e30540,0xf1c9801c}},	//   lunk, _vực_, टीसी_, _bạc_,
   {{0x7bc62f65,0x66e301e5,0x20022f66,0x6723af67}},	//   _ruku, жора, ruki_, nenj,
   {{0x13da80c8,0x7bc62f68,0x20020590,0x799b8c56}},	//   _দিয়, _suku, suki_, _okuw,
   {{0x7bc613b8,0x6723af69,0x6446816d,0x39402f6a}},	//   _puku, henj, åkig, _unis_,

   {{0x6723af6b,0x644984c3,0x69d5011e,0x68eb96fb}},	// [1c00] kenj, nxei, _atze, dagd,
   {{0x44392f6c,0xaaba026a,0x6603af6d,0x25a0141f}},	//   _drs_, ندار_, kunk, slil_,
   {{0x44392f6e,0x7ae72f6f,0x69c70052,0x67238805}},	//   _ers_, _dejt, _cuje, denj,
   {{0x7bc62f70,0xe3c8801c,0xdb0f0825,0x44392f71}},	//   _tuku, _lựa_, _bucó, _frs_,
   {{0x6a4a8201,0x2906af72,0x33d52f73,0x3860af74}},	//   rəfi, rgoa_, _гіст, áir_,
   {{0x752f009a,0x6723af75,0x25e30105,0x78a9826c}},	//   _zacz, genj, टीवी_, _dzev,
   {{0x69c18526,0x25fd8f85,0x7c2d8e9f,0x9f590036}},	//   _रंगी, रंगी_, _šarp, ursé_,
   {{0x3f98001b,0xdb1c2f76,0xa6e9801c,0x7ae72f77}},	//   horu_, _sirè, _ngươ, _zejt,
   {{0x69c0af78,0x442b0118,0x6723af79,0xdb072f7a}},	//   _iime, _xsc_, benj, _gijó,
   {{0x4aaa2f7b,0x6723803b,0x69c0af7c,0x7c398122}},	//   _कराव, cenj, _hime, _drwr,
   {{0x69c10065,0x195917ae,0x69c0af7d,0xe3c880ff}},	//   _élet, ганы_, _kime, _dựa_,
   {{0x50672f7e,0xf1c980ff,0x2c5e00eb,0x69c0af7f}},	//   атга, _sạc_, _kādā_, _jime,
   {{0xb8cf2f80,0x938a8098,0x8ca20d86,0x68f6031d}},	//   _कर_, _иска_, _खरगो, _ddyd,
   {{0x69c0af81,0x3f9802a5,0x09d700ab,0x65662f82}},	//   _lime, goru_, _হিসা, _alkh,
   {{0x7ae72f83,0x752f0035,0xdef801e2,0xa1872f84}},	//   _rejt, _pacz, шыя_, _выпл,
   {{0x81c40a49,0x69c0af85,0x672380d2,0x442b009f}},	//   _এবং_, _nime, zenj, _psc_,
   {{0x69c72f86,0x6d4d2f87,0x61fe110f,0xf2c701cf}},	// [1c10] _suje, rjaa, erpl, асен,
   {{0x34a7023c,0x69c0af88,0x44392f89,0xdb0a80f7}},	//   _खरीद, _aime, _vrs_, _bhfé,
   {{0x6723af8a,0x5f00800f,0x69c0af8b,0x6d428162}},	//   venj, _राज्_, _bime, _onoa,
   {{0xdd8683f8,0x98a9811f,0x44392f8c,0xdb0f0144}},	//   _رو_, žač_, _trs_, _pucó,
   {{0xe8f8af8d,0x7ae70038,0x44392f8e,0x6723a800}},	//   рлі_, _tejt, _urs_, tenj,
   {{0x442925d3,0x2fc901e9,0x6d4282c4,0x6603af8f}},	//   mwa_, _muag_, _anoa, tunk,
   {{0x672382a5,0x44292f90,0x2fc901e9,0xdb1881df}},	//   renj, lwa_, _luag_, _civí,
   {{0x6723825b,0x6603af91,0x99858013,0xf8bf2f92}},	//   senj, runk, _الرو, ndés_,
   {{0x44292f93,0x1c4297ae,0x681a80eb,0x6723af94}},	//   nwa_, зным, gādā, penj,
   {{0x69c08010,0x6569af95,0x44292f96,0xb4e68035}},	//   _zime, sheh, iwa_, _बड़ी_,
   {{0x44292f97,0xb6358277,0xed358162,0x68e9af98}},	//   hwa_, _دفاع, _гэлэ, _keed,
   {{0x44292f99,0x68e982a3,0xce689878,0x3f982f9a}},	//   kwa_, _jeed, _труд_, woru_,
   {{0x3438819f,0xa2e800c8,0x68e9af9b,0x2fc901c5}},	//   _پسند_, _পাসও, _meed, _cuag_,
   {{0x59cf8a16,0x4429029b,0x50d80eed,0x68e9af9c}},	//   _संपर, dwa_, _भ्रष, _leed,
   {{0x44292f9d,0x7c29844e,0xdb0380f7,0xc8798087}},	//   ewa_, lwer, _ghná, _deşi_,
   {{0xbf9b03a7,0x68e98039,0x44292f9e,0x3f982f9f}},	//   quên, _need, fwa_, soru_,
   {{0x44292fa0,0x7c29afa1,0x69c0afa2,0x75242fa3}},	// [1c20] gwa_, nwer, _rime, reiz,
   {{0x69c0afa4,0x06e200ab,0x290d8087,0x7d098192}},	//   _sime, _বাকি, _acea_, hges,
   {{0xcf57004c,0xe1fa2fa5,0xe80a8076,0x44292fa6}},	//   _הבית_, уге_, हूना_, awa_,
   {{0x44292fa7,0xb4e6923a,0x7c29afa8,0x2638026f}},	//   bwa_, _बजे_, kwer, _ičo_,
   {{0x7bcfa777,0x69c0afa9,0x7d09949d,0x6360016d}},	//   ícul, _vime, dges, _jönk,
   {{0x69da9766,0xaa462faa,0x7c29afab,0x2d9d8326}},	//   ypte, _легл, dwer, _akwe_,
   {{0x69c0afac,0xf38a877f,0x68e9afad,0x6b632f84}},	//   _time, nṣe_, _feed, _экра,
   {{0x68e98079,0x7c29afae,0xea00001c,0xdb1885e4}},	//   _geed, fwer, _chấp_, _viví,
   {{0x7866a8a7,0x80668f75,0x7c29afaf,0xa6c000ab}},	//   _указ, _уваж, gwer, ্রিয়,
   {{0x681a8029,0x6e3ca915,0x2619009a,0x7d09afb0}},	//   rādā, _árbo, _पहली_, ages,
   {{0x44292fb1,0x6b9b00be,0x68e981b4,0xcb9b1101}},	//   zwa_, רשיד, _yeed, רסיט,
   {{0xd90f15e4,0x44292fb2,0x7c29afb3,0x2fc901c5}},	//   ریخ_, ywa_, bwer, _puag_,
   {{0x34a7016f,0x2fc901c0,0xf8ba970c,0x91ca80bc}},	//   _खरेद, _quag_, ेशिय, _संवै,
   {{0x44290205,0x2fc90069,0xd7f80198,0x69daafb4}},	//   vwa_, _vuag_, щую_, ppte,
   {{0xf1c98028,0x7aea802e,0x442904b7,0x4b7b8e82}},	//   _hạn_, _ieft, wwa_, _תאוו,
   {{0x44292fb5,0x2fc92fb6,0x46d9064a,0x6b9a87f1}},	//   twa_, _tuag_, _ब्रह, lotg,
   {{0x68e9afb7,0xd05d0201,0xf8bf2fb8,0x44292fb9}},	// [1c30] _reed, yasə, rdés_, uwa_,
   {{0x44292fba,0x7aea803a,0x69caafbb,0xf1c980ff}},	//   rwa_, _jeft, _kufe, _mạn_,
   {{0x44292fbc,0x201f8087,0x7d09867f,0x9d190087}},	//   swa_, _spui_, yges, _конт_,
   {{0xe705026a,0x44292fbd,0x69ca8e72,0x3f9eafbe}},	//   _اسکی, pwa_, _mufe, _aktu_,
   {{0x44292fbf,0x260681ce,0xf1c9801c,0xbae800ab}},	//   qwa_, सूसी_, _nạn_, _পারছ,
   {{0x7c2f0698,0xe739afc0,0x7aea8085,0x45d58293}},	//   _iscr, рек_, _neft, оцит,
   {{0x7d098e61,0x636d8c52,0x7c299699,0x9c1381bc}},	//   tges, _húng, wwer, _tọkw,
   {{0xf1c98142,0xf77391fb,0x7c29afc1,0xed599d20}},	//   _bạn_, _کار_, twer, рои_,
   {{0x7d09afc2,0x69d8ab47,0x7c2981ed,0x25fd8fd5}},	//   rges, _atve, uwer, रूजी_,
   {{0x7c29910f,0x7d09afc3,0x6d932fc4,0x3205816b}},	//   rwer, sges, lħad, tuly_,
   {{0xdce2803a,0xea00001c,0x2d8910e4,0xdd9983f2}},	//   _zloč, _thấp_, knae_, poň_,
   {{0x26138073,0x24198009,0x7c29afc5,0xdb0180e7}},	//   mão_, _воды_, pwer, illé,
   {{0x26138073,0x656d2fc6,0xb87b0207,0x6b9aafc7}},	//   lão_, dhah, daís, botg,
   {{0x88ba8039,0x78ad0b80,0xdb0a87f1,0x7bd98db1}},	//   יזרי, _dzav, _difó, _itwu,
   {{0x3ebe2fc8,0x443dafc9,0x7bcbafca,0x26138187}},	//   ätt_, _hrw_, _hugu, não_,
   {{0x7bc39341,0x7bcb8f45,0x656d02b8,0x2d8902f7}},	//   _hinu, _kugu, ghah, gnae_,
   {{0x7bcbafcb,0x7bc3afcc,0xfd648135,0x64a32fcd}},	// [1c40] _jugu, _kinu, _anwụ, дата,
   {{0xaac986bf,0xdb188019,0x443d8333,0x636001ec}},	//   रशिक, _kivá, _mrw_, _köni,
   {{0x442f82f7,0x26138187,0x7bcbafce,0x2d9e0036}},	//   _lsg_, jão_, _lugu, îtes_,
   {{0xdce280ce,0x26138073,0x8c4609e0,0x02aa12c6}},	//   _ploč, dão_, _деме, _करीन,
   {{0x274a80ae,0x2eeeafcf,0x6d462fd0,0x443dafd1}},	//   ичко_, taff_, _inka, _nrw_,
   {{0x442209da,0x7bc3afd2,0x29d70372,0x2613841c}},	//   _ipk_, _ninu, _bħad_, fão_,
   {{0x7bcb9e78,0x2eeeafd3,0x261383a7,0xf1c9801c}},	//   _augu, raff_, gão_, _sạn_,
   {{0x54549bd8,0x7bc38006,0x7bcbafd4,0x44220b99}},	//   звит, _ainu, _bugu, _kpk_,
   {{0x68e2afd5,0xa067afd6,0xa2be063a,0x7bc3a703}},	//   mbod, _дата_, _वृत्, _binu,
   {{0x7bcb8102,0xb4db009f,0x2d680214,0x7bc3808e}},	//   _dugu, _anàl, rşey_, _cinu,
   {{0x6d462fd7,0x78ad0019,0x7bc3afd8,0x261383a7}},	//   _onka, _szav, _dinu, cão_,
   {{0x7bc3807b,0xdb1d02af,0xdb18826f,0x3f9c80fa}},	//   _einu, _zusä, _divá, lovu_,
   {{0x6440011f,0x6727022b,0x69caafd9,0x60c901a1}},	//   _šmin, tejj, _wufe, žemo,
   {{0x3f9c8025,0x6d460835,0x7c228136,0x7bc3afda}},	//   novu_, _anka, _ipor, _ginu,
   {{0x69d8afdb,0x44222fdc,0xdb1c0118,0x656d00d7}},	//   _utve, _apk_, _cirí, thah,
   {{0x3f9c8042,0x31690052,0x44222fdd,0x656d2fde}},	//   hovu_, _ulaz_, _bpk_, uhah,
   {{0xb87b2b49,0x261383a7,0x78ad03fb,0x636d802a}},	// [1c50] raís, zão_, _uzav, _fúnd,
   {{0x656d2fdf,0x27e92fe0,0xfaa72fe1,0x6d462fe2}},	//   shah, _iwan_, ошен, _enka,
   {{0x68ed0867,0xa2be0af3,0x26138073,0x27e90683}},	//   _kead, _वृद्, xão_, _hwan_,
   {{0x68e28091,0x27e92fe3,0xa2daa7fb,0x61e701c0}},	//   gbod, _kwan_, पुत्, _vwjl,
   {{0xd6bd00c8,0xf7458f13,0x442200b9,0xb8d3864a}},	//   _অভিয, зело, _gpk_, _ऑर_,
   {{0x26138003,0xdfce8013,0x7d0d2fe4,0x7c2d26da}},	//   tão_, ديو_, lgas, mwar,
   {{0x7c22afe5,0x59c69344,0x7bc3afe6,0xf9938277}},	//   _apor, _रंगर, _rinu, _قبر_,
   {{0x261380a9,0x7d0d2fe7,0x7bcb809f,0x442fafe8}},	//   rão_, ngas, _pugu, _psg_,
   {{0x261380a9,0xa3e68076,0x7bc3afe9,0x7c2d2fea}},	//   são_, यील_, _pinu, nwar,
   {{0x59cf8935,0x261383a7,0x31b6066b,0x6d9304b7}},	//   _संदर, pão_, ृद्ध, nħab,
   {{0xe299839d,0x7c2d2feb,0x27e92fec,0x7bc3afed}},	//   сан_, hwar, _awan_, _vinu,
   {{0x7c2d082e,0xbea8803d,0xfc3f077f,0x68ed0cb5}},	//   kwar, _بهمن_, _orí_, _cead,
   {{0x7bc3afee,0xf1c98104,0x8d748077,0xdb1c0118}},	//   _tinu, _tạo_, _تالا, _sirí,
   {{0x81e10a49,0x442d82f4,0x7c2d2fef,0x657d2ff0}},	//   _দিন_, mwe_, dwar, _amsh,
   {{0x6d5980a4,0x442daff1,0x68ed0ad0,0xdcfb807d}},	//   _kowa, lwe_, _fead, gnuć,
   {{0x60c9aff2,0x7d0d0fc3,0xdb1c2ff3,0x3f9caff4}},	//   _ngem, ggas, _virí, zovu_,
   {{0x442daff5,0x7c2d2ff6,0x2b581458,0x6d598c2e}},	// [1c60] nwe_, gwar, _porc_, _mowa,
   {{0x083b0051,0x291f81bc,0x7d0d2ff7,0x44222ff8}},	//   _פעיל, _abua_, agas, _vpk_,
   {{0xa9268991,0xb6a300e7,0x442daff9,0xa75b01c6}},	//   здел, éâtr, hwe_, _הדיר,
   {{0x442da129,0x6d59affa,0xfc3f01fa,0x68ed03a8}},	//   kwe_, _nowa, _frí_, _xead,
   {{0x07a69e16,0x442d8578,0x684681e5,0x68e2affb}},	//   падн, jwe_, янда, rbod,
   {{0xe3a78b76,0x501b0039,0x21200359,0x1b0300ab}},	//   _سر_, מונו, _lbih_, র্বে_,
   {{0x7d1baffc,0x2cc18201,0x442d81b0,0x6d59838a}},	//   ffus, ərdə_, ewe_, _bowa,
   {{0x3f9c825b,0x6b818013,0x69ce0087,0x7d7880f7}},	//   sovu_, eilg, _iube, تمبر_,
   {{0x442daffd,0x69ce2ffe,0x68ed0051,0x6d59afff}},	//   gwe_, _hube, _read, _dowa,
   {{0x69ce0f45,0x68ed3000,0xb4ac800d,0x27f7800d}},	//   _kube, _sead, _गरी_, ření_,
   {{0x52138071,0xcfc400ab,0x442db001,0x7c2d3002}},	//   ндэт, ্ঠান, awe_, zwar,
   {{0x442db003,0x7c22973d,0x7982809a,0x69ce1be3}},	//   bwe_, _tpor, niow, _mube,
   {{0x7c22b004,0x69ce3005,0x4346a20b,0x6b81b006}},	//   _upor, _lube, _недв, bilg,
   {{0xc7c40009,0x6d59b007,0xb90422bd,0x69dc3008}},	//   есси, _zowa, _प्_, _otre,
   {{0xd7888104,0x68ed0006,0x21200fda,0x69ce05e4}},	//   yển_, _tead, _fbih_, _nube,
   {{0xbcfb3009,0x7c2d300a,0x7aee0f3e,0x7d0d0789}},	//   _llév, twar, _aebt, ugas,
   {{0x94ab300b,0x7d0d300c,0x69dc20e6,0x2d5802c7}},	// [1c70] ства_, rgas, _atre, чить_,
   {{0x212b300d,0x69ce300e,0x3dc680b9,0x7c2d300f}},	//   lech_, _bube, _liow_, rwar,
   {{0x69ce3010,0x442db011,0x200b00d2,0x35b53012}},	//   _cube, zwe_, luci_, _обор,
   {{0xfc3f3013,0x6b81b014,0x212b3015,0x69ce3016}},	//   _trí_, zilg, nech_, _dube,
   {{0xf77084c0,0x6d59b017,0x20193018,0x200b0503}},	//   گان_, _rowa, ntsi_, nuci_,
   {{0x6d59b019,0x7bdd301a,0xf09400be,0x25a9301b}},	//   _sowa, _itsu, ענס_, llal_,
   {{0xf770806b,0xa3c29a22,0x69ce301c,0x442d867f}},	//   دان_, ्दन_, _gube, wwe_,
   {{0x442da122,0x61fa007b,0x7982809a,0x7bc70144}},	//   twe_, _ætla, ciow, _hiju,
   {{0x442d8586,0x6b81b01d,0x200b0042,0x212b001b}},	//   uwe_, tilg, juci_, dech_,
   {{0xe1f99bd8,0x442db01e,0xdb1c0019,0x7bcf301f}},	//   ого_, rwe_, _kirá, _mucu,
   {{0x7bcf3020,0x3f833021,0x442db022,0xf1c9801c}},	//   _lucu, diju_, swe_, _tạm_,
   {{0x290f9e92,0x7bdd0006,0xdb1c0333,0x37e20264}},	//   ngga_, _otsu, _mirá, _বিবর,
   {{0x02aa1344,0x59cf858c,0x7bdd01e9,0x200b00d2}},	//   _कर्न, _संवर, _ntsu, guci_,
   {{0x3f830025,0x6b8182a6,0xdb1c0144,0x1b030264}},	//   giju_, qilg, _oirá, র্তে_,
   {{0x7bcf03d3,0x6372006a,0xe5a63023,0xddd401d6}},	//   _aucu, _hæng, диви, ňažn,
   {{0x7bcf0012,0xdb188364,0x200b3024,0x2d8db025}},	//   _bucu, _eivä, buci_, nnee_,
   {{0xe73a15fe,0x3f831487,0x7bc73026,0x6721a847}},	// [1c80] _деп_, biju_, _biju, _oblj,
   {{0x39490025,0x09e61bd8,0x6372006a,0x316d86c4}},	//   _znas_, дожн, _mæng, _alez_,
   {{0x7bc701f1,0x63720022,0x39990e06,0x6b9e3027}},	//   _diju, _læng, vész_, ropg,
   {{0x6e3ca755,0x7aee3028,0xdb1c0333,0xfc4a9434}},	//   _árbi, _webt, _dirá, ntíð_,
   {{0xb4ac800d,0xdfcf8c3b,0x7bc7017f,0x629500b9}},	//   _गरे_, لين_, _fiju, _exzo,
   {{0x212b085d,0x26d83029,0x3dc680b9,0x6d5d8106}},	//   zech_, ncro_, _siow_, ösan,
   {{0x69dc23f5,0x63600019,0x200b302a,0xdb1c002a}},	//   _utre, _dönt, zuci_, _girá,
   {{0x2d8db02b,0xd8268a2e,0x63648580,0x6d56018f}},	//   gnee_, _одби, _iòni, njya,
   {{0xf8b28105,0xae0282f1,0x212b302c,0x657a1a25}},	//   _जरिय, रूजन_, vech_, éthy,
   {{0xd370845a,0x200b02a5,0x6eb6866e,0xdb0a8174}},	//   اهد_, vuci_, _قصائ, _bhfá,
   {{0xc3331a15,0x3f83005c,0x212b001b,0x25a0302d}},	//   דות_, viju_, tech_, koil_,
   {{0x80fb2441,0x6372006a,0x63600106,0xe7f58035}},	//   ्लेख_, _fæng, _köns, ुंचा_,
   {{0x3f83025b,0x212b302e,0x6360302f,0xd8380087}},	//   tiju_, rech_, _yönt, мэр_,
   {{0x4426b030,0x2d84b031,0x6360016d,0xa2948a8e}},	//   _ipo_, lime_, _möns, _палі,
   {{0x290fb032,0x212b1e51,0x200b09c4,0x63600106}},	//   ygga_, pech_, suci_, _löns,
   {{0x394905b4,0x26170073,0x2d84b033,0x7bcf3034}},	//   _unas_, rço_, nime_, _pucu,
   {{0x36d516df,0x60cd3022,0x9f4205b9,0xc3130032}},	// [1c90] _попр, _igam, lský_, _ajíṣ,
   {{0x25a91807,0x4426b035,0x316d81a1,0x2006b036}},	//   slal_, _mpo_, _slez_, droi_,
   {{0x9f42027f,0x2d84b037,0x7bc73038,0x636487f1}},	//   nský_, kime_, _viju, _còni,
   {{0x4adf0913,0x3949840e,0x4426b039,0xdb1c0019}},	//   _प्रव, ñas_, _opo_, _virá,
   {{0x44268282,0x752d002e,0x636d80f7,0x60cd303a}},	//   _npo_, meaz, _lúna, _mgam,
   {{0x752d002e,0xbcfb303b,0x2d848118,0x798083f7}},	//   leaz, _elét, eime_, _emmw,
   {{0x442688cf,0x69ca8128,0x6da5b03c,0x38698916}},	//   _apo_, _संगी, ника, šar_,
   {{0x636000f2,0x60cd303d,0x752d002e,0x2d84b03e}},	//   _föns, _ngam, neaz, gime_,
   {{0x6d5d303f,0x6442b040,0xa2d606bf,0x4426808e}},	//   _mosa, _croi, मुक्, _cpo_,
   {{0x644294e1,0x60cd2148,0x4426b041,0xf1c9801c}},	//   _droi, _agam, _dpo_, _hại_,
   {{0x442684be,0x80c200d4,0x636d81a8,0x2d84b042}},	//   _epo_, रेने, _cúna, bime_,
   {{0x6442b043,0x6d5d3044,0x5c758256,0x752d0087}},	//   _froi, _nosa, _плет, jeaz,
   {{0x6d4bb045,0xeb8e96cf,0xf1c98028,0xec6ea118}},	//   _inga, _би_, _mại_, _сп_,
   {{0xf1c98104,0x27ed8f23,0xa3c08540,0x443fb046}},	//   _lại_, _mwen_, ंगण_, mvu_,
   {{0x6d5d056f,0x69ce8e15,0x60cd002a,0x443fb047}},	//   _bosa, íbet, _fgam, lvu_,
   {{0x6d5d3048,0x753bb049,0xed5715d1,0xf65280be}},	//   _cosa, nduz, нос_, נצן_,
   {{0x6d5d304a,0x443f82ec,0x2fdf8069,0xf1ac1251}},	// [1ca0] _dosa, nvu_, _ntug_, _टीएन,
   {{0x60dbb04b,0x25a0304c,0x27e00110,0x7986304d}},	//   _afum, soil_, _itin_, likw,
   {{0x6d4bb04e,0x6d5d1db7,0x090695bf,0x443fb04f}},	//   _onga, _fosa, епен, hvu_,
   {{0x2d84b050,0x443f803a,0x7e6100f2,0x79863051}},	//   xime_, kvu_, älpe, nikw,
   {{0x40349071,0x69c9b052,0x63a1b053,0x2d84b054}},	//   телс, _diee, koln, vime_,
   {{0x6d4bb055,0xf1ca0129,0x4426b056,0x60dbb057}},	//   _anga, _dại_, _rpo_, _efum,
   {{0xe2973058,0xe5c68ada,0x443f9693,0x27ed8706}},	//   _зар_, нсио, evu_, _ewen_,
   {{0x9f42003e,0xd5b781bb,0xdb1c0214,0x29000135}},	//   vský_, нсы_, _birç, _ndia_,
   {{0x6d4b8359,0x6372006a,0x70af123a,0x79863059}},	//   _dnga, _tænd, _घरेल, dikw,
   {{0x8883a91d,0x2d84b05a,0x5c739663,0x752d002e}},	//   _служ, sime_, ульт, zeaz,
   {{0x27e0009c,0x7e9a8a47,0xa294902a,0x2a6a8061}},	//   _atin_, _عنصر_, тані, ább_,
   {{0x32029385,0x6442b05b,0x9f421c32,0x67d5272f}},	//   čky_, _troi, rský_, кому,
   {{0x38668722,0x752d0087,0x4426b05c,0x63a1b05d}},	//   nyor_, veaz, _upo_, boln,
   {{0x6d5d00a4,0x4432031d,0x66010019,0x69ce802a}},	//   _sosa, dwy_, álko, íbes,
   {{0xf1a726c5,0x79a718ff,0x752d305e,0x644780eb}},	//   _прин, _прие, teaz, ājie,
   {{0x60cd305f,0xbcfb2602,0x29d70372,0xe534076a}},	//   _ugam, _alér, _bħan_, лесь,
   {{0x752d0012,0x7bcab060,0xfbd3006b,0x6d5d3061}},	// [1cb0] reaz, _kifu, اتر_, _vosa,
   {{0x673aa4fb,0x752d002e,0x60dbb062,0x7bca804f}},	//   _natj, seaz, _sfum, _jifu,
   {{0x6d5d0013,0x752d0870,0x69c98029,0x61fab063}},	//   _tosa, peaz, _piee, nstl,
   {{0x7ff5819f,0xbcfb0065,0x27ed86c0,0xb4db0980}},	//   نستا, _elér, _pwen_, _anàv,
   {{0xa3c283bb,0xe7399878,0xa3c0b064,0x29d704b7}},	//   ्दा_, дел_, ंगा_, _għan_,
   {{0x25a6b065,0x6d4b80dd,0xdb0501a8,0x79863066}},	//   _akol_, _snga, rmhó, zikw,
   {{0x6d4b80dd,0xed59b067,0x63a183c1,0x61ee0428}},	//   _pnga, дой_, voln, _gwbl,
   {{0xf1ca0104,0x92e900c8,0x63a1809a,0xf1a4b068}},	//   _tại_, _যায়_, woln, _брун,
   {{0x02c98aed,0x210401e2,0xe3b9a159,0x656982af}},	//   रश्न, nčių_, мби_, rkeh,
   {{0x4a458e12,0x443fb069,0x200fb06a,0x6569b06b}},	//   внов, rvu_, mugi_, skeh,
   {{0x3f87b06c,0x200fb06d,0x6aaa831d,0x779087d2}},	//   minu_, lugi_, _cyff, _دیوا,
   {{0x3f87b06e,0x6d4ba941,0x212f826c,0x69dc8174}},	//   linu_, _unga, negh_, írea,
   {{0x63a18db7,0x8d74b06f,0x79863070,0xb0a51774}},	//   poln, _حالا, rikw, _गुदग,
   {{0x25adb071,0x79863072,0xa283803d,0x25bf8087}},	//   llel_, sikw, _میخو, lmul_,
   {{0xbea60056,0x7af70079,0x6aaa8114,0xe3c880ff}},	//   тавк, daxt, _gyff, _cựu_,
   {{0x395fb073,0x1614000f,0x7bcab074,0x44320035}},	//   _nous_, तंबर_, _zifu, twy_,
   {{0xccf2812a,0xf773003d,0x3f87b075,0x61fc0390}},	// [1cc0] יכן_, _چاپ_, kinu_, _svrl,
   {{0x443229e6,0x200f8074,0xc88701ec,0x31caabb2}},	//   rwy_, dugi_, ößer_, िद्ध,
   {{0x3f878289,0xc33284de,0xf506028b,0x7ae58074}},	//   dinu_, שוב_, _изно, _õhtu,
   {{0xcfe680c8,0xb816278a,0x4a5a8039,0x200fb076}},	//   _নিবন, _तमाम_, ודעו, fugi_,
   {{0x395fb077,0x394d8775,0x261486b7,0x2d923078}},	//   _dous_, _dnes_, नूनी_, mnye_,
   {{0x394db079,0x3f87807b,0xbf9b00e7,0x2d9200dd}},	//   _enes_, ginu_, quêt, lnye_,
   {{0x6e288713,0x7bca9360,0x6aa301ec,0x2bd8143e}},	//   _qpdb, _rifu, ünft, _भंडा,
   {{0x2d92307a,0x7bcab07b,0x3160011b,0xfbe78129}},	//   nnye_, _sifu, _noiz_, _thế_,
   {{0x3f878024,0x2d9200b9,0xd0e3307c,0x47c68110}},	//   binu_, inye_, _क्षण_, _абав,
   {{0x3f8780d2,0x64460088,0x2d9200ee,0x3d148075}},	//   cinu_, _mrki, hnye_, _धावे_,
   {{0x27e68cc0,0xcb130039,0xc224826a,0x2d92036e}},	//   lpon_, בלת_, اکتو, knye_,
   {{0xfce6b07d,0x6446307e,0x25a6820d,0x7984008e}},	//   _родо, _orki, _ukol_, _cmiw,
   {{0x7d02b07f,0x2d9200b9,0x27e6b080,0xf1bf2ba3}},	//   _idos, dnye_, npon_, rmá_,
   {{0x29d704b7,0x257503ba,0x27e680e4,0x798403f7}},	//   _bħal_, _måle_, ipon_, _emiw,
   {{0x64463081,0x636d81a8,0xfbb781c6,0xc333825f}},	//   _arki, _múnl, _שפות_, _כוס_,
   {{0x6446017f,0x39150391,0x81e100ab,0x69cb0107}},	//   _brki, _смир, _দিল_, _सूची,
   {{0x95c80bac,0x0dc83082,0x644488ae,0x5bb90fe6}},	// [1cd0] тура_, тури_, _šiij, елая_,
   {{0x395fb083,0xdb01b084,0x2571b085,0x64460140}},	//   _sous_, golè, _mála_, _drki,
   {{0x3f87803b,0x29d73086,0x64463087,0x7d0281ac}},	//   vinu_, _għal_, _erki, _odos,
   {{0x7d0280f1,0x6446026c,0x69c88037,0x200fb088}},	//   _ndos, _frki, _èdel, tugi_,
   {{0x395f9cb0,0x3f87b089,0x2575016d,0x6d4f0888}},	//   _vous_, tinu_, _våld_, _inca,
   {{0x753d0117,0xa2be00d4,0xa3b28105,0xf1ca001c}},	//   _hasz, _वृक्, _झील_, _hạt_,
   {{0x395f86e3,0x4439308a,0x753d2a87,0x200fb08b}},	//   _tous_, _hss_, _kasz, sugi_,
   {{0x2249803a,0x394d809f,0x3f87b06e,0xdb01b08c}},	//   _čak_, _unes_, sinu_, molé,
   {{0xc9849506,0x5184830d,0x69d5308d,0xcfab8065}},	//   _тури, _тура, _huze, _قائم_,
   {{0x25bf802e,0x25ad816b,0x4439308e,0x69d5308f}},	//   smul_, slel_, _mss_, _kuze,
   {{0x75158307,0x44393090,0x198a0ae7,0xa18a00c4}},	//   _مواض, _lss_, ебни_, ебна_,
   {{0x753d0d38,0x44390687,0x69d53091,0x78ad3092}},	//   _nasz, _oss_, _muze, _byav,
   {{0x69d53093,0xaac3000d,0x2d8909c4,0x63a509da}},	//   _luze, वेतक, diae_, kohn,
   {{0x6d4f3094,0x77ad8118,0xdce28140,0xe2998791}},	//   _anca, fúxi, _ploć, _пал_,
   {{0xa3c2800f,0x63a53095,0x656d0359,0x44393096}},	//   ्दर_, dohn, fkah, _ass_,
   {{0x6d5b8867,0x656d3097,0x2614816f,0x442b3098}},	//   njua, gkah, नंती_, _bpc_,
   {{0x44393099,0x03260162,0xe3ba309a,0xa4460071}},	// [1ce0] _css_, лдан, еба_, ынад,
   {{0x6d4f309b,0x68f60085,0x442b309c,0x63768087}},	//   _enca, _heyd, _dpc_, _gând,
   {{0x6146b09d,0xd946a012,0x471b00be,0x2d9200b9}},	//   лежа, лежи, _אויג, pnye_,
   {{0x4439309e,0x2d89002a,0x673e309f,0xdb01a218}},	//   _fss_, ciae_, _hapj, solè,
   {{0x68f630a0,0x776188f1,0x6d5bb0a1,0x644630a2}},	//   _meyd, _bolx, djua, _urki,
   {{0x27f2031d,0x8fa3b0a3,0xfaa630a4,0x753d066f}},	//   _mwyn_, баче, _баго, _zasz,
   {{0x27e6b0a5,0x09cf80a5,0xe1e78019,0x7c2b80eb}},	//   spon_, _संगठ, _دس_, _apgr,
   {{0x442030a6,0x7bce0587,0x44390683,0x6d5b8168}},	//   oti_, _hibu, _yss_, gjua,
   {{0x442030a7,0xa3c2835a,0x7bce30a8,0x69d500ad}},	//   nti_, ्दल_, _kibu, _zuze,
   {{0x442030a9,0x3f8a022e,0x673e0019,0x69d519d8}},	//   iti_, jibu_, _napj, _yuze,
   {{0x44200a92,0xdd8f8bca,0x6b7b098a,0x63768087}},	//   hti_, _کون_, גרינ, _rând,
   {{0x84468b76,0x7bce30aa,0x7d02809a,0xddb68019}},	//   _مختل, _libu, _udos, _صحاب,
   {{0x442030ab,0x68f630ac,0x69c2808e,0x20000362}},	//   jti_, _deyd, imoe, _cvii_,
   {{0x443930ad,0x447b893f,0x7bce0ab4,0x78ad018e}},	//   _rss_, _אנדע, _nibu, _vyav,
   {{0x442030ae,0x7afa8364,0xd5bb30af,0x2904805c}},	//   eti_, matt, еса_, _odma_,
   {{0x442030b0,0x7bce30b1,0x61fe1da3,0x63a501ec}},	//   fti_, _aibu, dspl, wohn,
   {{0x656d30b2,0x442b01df,0x44200dc3,0x7bce2c1d}},	// [1cf0] rkah, _qpc_, gti_, _bibu,
   {{0x443902a5,0x59d901b6,0x7bce30b3,0x34d195a7}},	//   _vss_, _बंदर, _cibu, _हल्द,
   {{0x5a3530b4,0x442030b5,0x7afa80e5,0x44390299}},	//   рнет, ati_, iatt, _wss_,
   {{0x7afab0b6,0x673e0654,0x442030b7,0xe9ab9e5c}},	//   hatt, _zapj, bti_, ردان_,
   {{0x68f98063,0x442030b8,0xda010076,0xb97c0158}},	//   rawd, cti_, _लटकत_, ענדי,
   {{0x6d478029,0xa0669c0b,0xf74584db,0x7bce04a7}},	//   ējam, раша_, реко, _gibu,
   {{0x7afab0b9,0x7f3c00be,0xff048ea6,0xb87b0118}},	//   datt, געוו, сячн, ncíb,
   {{0xdb150118,0x656280c3,0x3f8a02ec,0x7bce06a0}},	//   _tizó, _cooh, zibu_, _zibu,
   {{0x6d5b94ec,0x236301c0,0x7bce0cb7,0x28c701a2}},	//   rjua, _kojj_, _yibu, रेमि,
   {{0x7afab0ba,0x25a08ee1,0x21290239,0x4225b0bb}},	//   gatt, čila_, _abah_, адов,
   {{0xe299b0bc,0x442030bd,0x491a02f1,0x45d5b0be}},	//   тан_, zti_, _भादो_, _тоес,
   {{0x442030bf,0x213f8867,0x68f60086,0x69d80073}},	//   yti_, _jauh_, _qeyd, ívei,
   {{0x7afa9da3,0x3f8a022e,0x671c80a5,0x290c07c0}},	//   batt, tibu_, _नामक_, ğda_,
   {{0xcb6684dd,0xb4c19094,0x68f602a3,0x7afa8081}},	//   _ваше_, ंधी_, _weyd, catt,
   {{0x3f8a022e,0x7bce178f,0x0fc300e8,0x24f616cf}},	//   ribu_, _ribu, ійсн, ичар,
   {{0x442030c0,0x7bce30c1,0x3f8a30c2,0x257185b9}},	//   tti_, _sibu, sibu_, _málo_,
   {{0x3b860110,0x44201af6,0x6386041c,0x31bc801b}},	// [1d00] алаг, uti_, агаа, níze_,
   {{0x44200743,0xfbdf0142,0x394010af,0x61fe1d5b}},	//   rti_, _trên_, _hais_, tspl,
   {{0x201fb0c3,0x4aab8076,0x394030c4,0x69c280c9}},	//   _aqui_, _घुमव, _kais_, tmoe,
   {{0xc8ca8154,0x61fe30c5,0x636d816a,0x394030c6}},	//   نوان_, rspl, _búnk, _jais_,
   {{0x394019c6,0x7bce04a7,0x69c2b0c7,0x61fe30c8}},	//   _mais_, _tibu, rmoe, sspl,
   {{0x394030c9,0x63768087,0x69c2b0ca,0x9e069bc6}},	//   _lais_, _mânc, smoe, ачил,
   {{0x9c87026f,0xbcfb010c,0x798bb0cb,0xd6d98163}},	//   počí, _moén, bigw, уті_,
   {{0x5d5498a0,0x394030cc,0x6443009a,0xe29701a1}},	//   скит, _nais_, łnie, _тас_,
   {{0x7afab0cd,0x6d40ae2b,0x68ed83a8,0xf1d00a27}},	//   tatt, rdma, ñade, _संजन,
   {{0x39520813,0xf36695b5,0x6562808e,0x7b668f13}},	//   _anys_, ртин, _wooh, ртие,
   {{0x7afab0ce,0x1b0300c8,0x0bb70039,0x394030cf}},	//   ratt, র্কে_, שלים_, _bais_,
   {{0x644901e2,0x7afa920b,0x394030d0,0x672d80ce}},	//   _šeim, satt, _cais_, đaje,
   {{0x394030d1,0x7afab0d2,0xc86430d3,0x63768187}},	//   _dais_, patt, отри, _cânc,
   {{0x93fb8051,0x7afa8372,0x3ea98162,0xd7f80d15}},	//   _ילדי, qatt, şate_, шую_,
   {{0x394002be,0xe8d90135,0x63a8b0d4,0xf1bf81d6}},	//   _fais_, _amụ_, modn, žšia_,
   {{0xda5b8051,0x69d8b0d5,0x2129010b,0x2baf0d86}},	//   _יכול, _iuve, _ubah_, _जीजा,
   {{0x54b901bb,0x68fd30d6,0x7af881c0,0x69d888dc}},	// [1d10] угая_, masd, _kevt, _huve,
   {{0x8ae7035f,0x3b541242,0x69d8b0d7,0x28c7009a}},	//   ріал, окур, _kuve, रेणि,
   {{0xcfe200c8,0x213f8748,0x69da0019,0x39520114}},	//   _বিএন, _pauh_, _étel, _ynys_,
   {{0x29190397,0x63a8b0d8,0x69d8997c,0x68fd30d9}},	//   ngsa_, hodn, _muve, nasd,
   {{0x8d5a0051,0xdee581cf,0x69d8b0da,0x504583a7}},	//   _עכשי, боли, _luve, селб,
   {{0x69d882be,0xcc3a0158,0xdc3a0158,0x543a00be}},	//   _ouve, _געשט, _געשר, _געשא,
   {{0x798b8010,0x69d8b0db,0x81e10264,0x92580436}},	//   pigw, _nuve, _দিক_, _карт_,
   {{0x7bc530dc,0xf1ca00ff,0x069801c6,0xddd50e06}},	//   lmhu, _nạp_, ידום_, nyző,
   {{0x394000f6,0x7989804f,0x69d88036,0x201f8118}},	//   _rais_, _imew, _auve, _uqui_,
   {{0xf77395e4,0x63a8b0dd,0x4ea792bc,0x394030de}},	//   _بار_, godn, _креа, _sais_,
   {{0x394030df,0x636d8019,0xa96a1c9b,0xd946116b}},	//   _pais_, _júni, гина_, бени,
   {{0x394000dd,0xdb050106,0x249d81c5,0x636d957a}},	//   _qais_, llhä, _txwm_, _múni,
   {{0x63a8883d,0x394030e0,0xab298bda,0xb900109b}},	//   bodn, _vais_, _бола_, _तल_,
   {{0x2bdb023c,0x53348ada,0x442f80ee,0x7777002a}},	//   _बढ़ा, _мечт, _ipg_, _clxx,
   {{0x394001e9,0x69d8b0e1,0xa50a07a1,0x26182776}},	//   _tais_, _guve, лева_, बंधी_,
   {{0xf1d01299,0x1c030006,0x442f80ee,0xa19309a5}},	//   _सूचन, _लिखल_, _kpg_, _најч,
   {{0xb87b30e2,0x69d881ec,0x7bd98326,0xdb018144}},	// [1d20] rcíc, _zuve, _juwu, holí,
   {{0xf3f98a49,0x26180540,0x46f6159f,0x7989804f}},	//   _আমার_, बंदी_, _учит, _amew,
   {{0x6e4603f8,0x2002127a,0x69d8862f,0x2571808b}},	//   _انجم, lski_, _xuve, _páll_,
   {{0x9f4907ca,0x442f8115,0xdb01a119,0xf8fa81a8}},	//   _hvað_, _opg_, dolí, اءات_,
   {{0x7f41b0e3,0x7bd9803d,0x68e40c53,0xbf9b0866}},	//   _balq, _nuwu, _mfid, prêt,
   {{0x7f41862f,0x6d44011e,0xb87b0511,0x798991d3}},	//   _calq, ldia, ncía, _emew,
   {{0x644bb0e4,0x41b6803d,0x65be8168,0x8afb04de}},	//   _argi, _همسر, hëhe, _תהלי,
   {{0x25a0a588,0x63a8809a,0xb99680f7,0x657bb0e5}},	//   čilo_, wodn, _الرب, ghuh,
   {{0x7c2430e6,0x69d8b0e7,0x69c08009,0x656600ee}},	//   ntir, _suve, _ihme, _mokh,
   {{0x20020289,0x4f658013,0x6566029b,0x68e430e8}},	//   dski_, _والف, _lokh, _afid,
   {{0x9f5d0324,0x442f8695,0xe1352252,0x68e92d84}},	//   _ìwé_, _epg_, онны, ñedo,
   {{0x3f8e8010,0x5a9b00be,0x442f8118,0x7afe1abb}},	//   lifu_, רשטא, _fpg_, hapt,
   {{0x6d440355,0x63a8803b,0x7afe30e9,0x68fd30ea}},	//   ddia, podn, kapt, rasd,
   {{0x7f418201,0x60d60019,0x3f8e8010,0x6d4430eb}},	//   _xalq, _egym, nifu_, edia,
   {{0x41e68bbe,0xf1ca001c,0x656630ec,0xdb1c01a8}},	//   _استف, _tạp_, _bokh, _ghré,
   {{0x1619835a,0x6615011e,0xd0110b8c,0x569430ed}},	//   नंतर_, ruzk, _قلب_, част,
   {{0xdd1c816b,0x7c2400e4,0x9817136d,0xe520b0ee}},	// [1d30] kážk, gtir, _ابعا, _यानि_,
   {{0x63600065,0x6615011e,0x27e910ab,0x25a90748}},	//   _köny, puzk, _itan_, soal_,
   {{0x6d440b50,0x7c2430ef,0xd25101a8,0x7a3501a8}},	//   bdia, atir, بنا_, تفاص,
   {{0xac1930f0,0x68e2b0f1,0x7c2430f2,0x798f0db1}},	//   _кому_, gcod, btir, nicw,
   {{0x7afe30f3,0x27e90101,0x442480b9,0xe8f89138}},	//   bapt, _jtan_, jtm_, слі_,
   {{0x7afe30f4,0x2d9a8019,0xdb01b0f5,0xd7c8b0f6}},	//   capt, épen_, tolí, مونه_,
   {{0xdb18826f,0x442f82f7,0x7bd980d7,0x6d42b0f7}},	//   _chví, _spg_, _suwu, _baoa,
   {{0x2409a672,0xdb01b0f8,0x68e2b0f9,0x442f9670}},	//   ании_, rolí, ccod, _ppg_,
   {{0x75ca809a,0x1c4297ae,0x7f4180ee,0x0b59876a}},	//   _języ, дным, _talq, арны_,
   {{0x68e430fa,0x657b8010,0x645b8118,0x644b80c3}},	//   _sfid, shuh, rxui, _vrgi,
   {{0xcb120bea,0x2002009a,0xeab180f7,0x68fb80dd}},	//   ולי_, wski_, بعة_, _keud,
   {{0x2002003a,0x68fb82be,0x443d8069,0xa4f780d5}},	//   tski_, _jeud, _tsw_, _اکثر_,
   {{0x442f802a,0x443d81ec,0xbee5016f,0x68fb851e}},	//   _upg_, _usw_, कडून_, _meud,
   {{0x7d1b8074,0x94748875,0x68fb81e4,0x257c01a8}},	//   lgus, _عدنا, _leud, _míle_,
   {{0xfc3f160a,0xdce40279,0x27e930fb,0x212db0fc}},	//   _así_, nkić, _etan_, _obeh_,
   {{0x20021487,0x7c2430fd,0x75298081,0x291f8069}},	//   pski_, ttir, nfez, _ncua_,
   {{0xf74630fe,0xab6630ff,0x61e902d4,0x33662f8d}},	// [1d40] _депо, овал, _čela, оваг,
   {{0x6d44002a,0x2575016d,0xb7d7004e,0x3cff8282}},	//   sdia, _håll_, _گویا_, hauv_,
   {{0xe0dab100,0xdce40754,0x68e28bfd,0xfc3f0091}},	//   аве_, jkić, tcod, _esí_,
   {{0x64430035,0x671c82f1,0x27e90106,0x68fb851e}},	//   łnia, _नाहक_, _ytan_, _ceud,
   {{0x68fbb101,0x68ed85e4,0x3f8eb102,0x183680a0}},	//   _deud, ñada, tifu_, تراح,
   {{0x68e28f67,0x7d1bb103,0x69d83104,0x7c3b8123}},	//   scod, egus, íves, dwur,
   {{0xe2973105,0xdd1c816b,0x3f8eb106,0x7afc0162}},	//   _дар_, rážk, rifu_, _iert,
   {{0x3f8eb107,0x7d1bb108,0x7ae901a1,0x717680d7}},	//   sifu_, ggus, _đeti, _بهرا,
   {{0x7afc3109,0x660381c0,0xe81603b7,0x7c3b8133}},	//   _kert, asnk, _तमगा_, gwur,
   {{0x69dc310a,0xe4570158,0x442480ee,0x3946b10b}},	//   _kure, קייט_, rtm_, ldos_,
   {{0xc4e6b10c,0x798f310d,0xbcfb04be,0x3946b10e}},	//   _джей, ticw, _eléy, odos_,
   {{0x69dc310f,0x3946b110,0x7afc3111,0x21200176}},	//   _mure, ndos_, _lert, _ccih_,
   {{0x81ba00ab,0x3946b112,0x7dd58110,0x84968019}},	//   _অংশ_, idos_, _išsa, _بجائ,
   {{0x69dc062f,0x25a996f2,0x6738911b,0x7d00b113}},	//   _oure, čale_, nevj, lams,
   {{0xb7bb041c,0xccfb0eef,0x5559047f,0x645d862c}},	//   stão, ића_, бавя_, äsiv,
   {{0xdb1c0118,0x394481a9,0x7d00b114,0x7afc3115}},	//   _oiró, _nams_, nams, _aert,
   {{0x7afc100d,0x69dc3116,0x27e93117,0x0bd500f7}},	// [1d50] _bert, _aure, _utan_, سياح,
   {{0x69dc3118,0x7afc10b6,0x20193119,0x6738b11a}},	//   _bure, _cert, musi_, jevj,
   {{0x20191ade,0x7afc311b,0xea00001c,0x28c71516}},	//   lusi_, _dert, _đảo_, रेरि,
   {{0x69dc311c,0x3f910052,0xf55900f7,0x7d008bcf}},	//   _dure, lizu_, _الحب_, jams,
   {{0x69dc311d,0x66e591b1,0x2019311e,0xa3ca816f}},	//   _eure, пола, nusi_, लगा_,
   {{0x7afc311f,0x39468510,0x213900f1,0x69dc3120}},	//   _gert, ados_, hesh_, _fure,
   {{0x7c390214,0x7bdd3121,0xf77092c8,0x69dc3122}},	//   şarı, _husu, خان_, _gure,
   {{0x7bdd3123,0x20193124,0x7afc3125,0x7c3bb126}},	//   _kusu, kusi_, _zert, twur,
   {{0x20193127,0x7bdd3128,0x7d1bb129,0x69dc3125}},	//   jusi_, _jusu, rgus, _zure,
   {{0x7bdd312a,0x6449b12b,0x2019312c,0x2571807b}},	//   _musu, rvei, dusi_, _máli_,
   {{0xcb12093f,0x2b1c85b3,0x6449b12d,0x7ae50014}},	//   עלט_, _मारु_, svei, icht,
   {{0x291db12e,0xac198b71,0xaca38133,0xdb0a80f7}},	//   ngwa_, _году_, _ahụk, _bhfó,
   {{0x2019312f,0x7bdd3130,0xdce28088,0x5ed080ab}},	//   gusi_, _nusu, _glođ, _স্পে,
   {{0xdb1c0706,0xc3110264,0x636d8174,0x7bd53131}},	//   _chrì, স্তি_, _cúnt, _nizu,
   {{0xe29690fc,0xed5a0847,0xdb01b132,0x272f83bf}},	//   _наш_, бов_, colá, mını_,
   {{0x7afc14ff,0x20193133,0x6372013c,0x7bdd3134}},	//   _sert, busi_, _tænk, _busu,
   {{0x7afc3135,0x29023136,0x69dc3137,0x7bdd02a3}},	// [1d60] _pert, maka_, _sure, _cusu,
   {{0x29023138,0xef860c5c,0x272f861c,0x04fc00ab}},	//   laka_, _хлоп, nını_, ইলের_,
   {{0x7afc3139,0x7dc58511,0x7bdd002a,0x19ba82c7}},	//   _vert, mósf, _eusu, будь_,
   {{0x7ae50307,0x7afc313a,0xe5a60ada,0x69d60708}},	//   acht, _wert, _хими, _jiye,
   {{0x7afc0393,0x2d92313b,0x672d80d2,0x25ad837a}},	//   _tert, miye_, đajn, doel_,
   {{0x69dc313c,0x6d46313d,0x2902313e,0x2d92313f}},	//   _ture, _haka, haka_, liye_,
   {{0x6d463140,0x29023141,0x272f8059,0xfaa33142}},	//   _kaka, kaka_, dını_, _заро,
   {{0x6d463143,0x290209a6,0x2d923144,0x7ec70019}},	//   _jaka, jaka_, niye_, lépé,
   {{0x6d460846,0x7bdd3145,0x6618816b,0xb4c880d4}},	//   _maka, _xusu, suvk, ोखे_,
   {{0x6d4625e3,0x6843b146,0xfc2f9a43,0x20193147}},	//   _laka, _януа, احي_, vusi_,
   {{0x29023148,0x2d923149,0x213900f1,0x69d6314a}},	//   faka_, kiye_, tesh_, _biye,
   {{0x6d46314b,0x2019314c,0x644a00eb,0x69c41ea0}},	//   _naka, tusi_, āfij, _chie,
   {{0x69d6314d,0x2d92314e,0x69c4008e,0x21390168}},	//   _diye, diye_, _dhie, resh_,
   {{0x2019314f,0x6d46076d,0x321a1d4b,0x1be306a7}},	//   rusi_, _aaka, kupy_, _कंबल_,
   {{0x29023150,0xc6a41109,0x7bdd3151,0x644f017f}},	//   baka_, ерти, _susu, _srci,
   {{0x2d803152,0x6d461083,0x20193153,0x2d9202a0}},	//   ghie_, _caka, pusi_, giye_,
   {{0x071c9d2a,0x6d463154,0xea000028,0x5c99027e}},	// [1d70] _नांव_, _daka, _đạo_, цкая_,
   {{0xe3b8884a,0xa87c0039,0x7ae501ec,0xad2723e0}},	//   nlı_, _לאחר, ucht, _کردو,
   {{0x7bd53155,0x32070065,0x6d463156,0x68ed82ba}},	//   _vizu, ény_, _faka, ñado,
   {{0x2d803157,0x4426802a,0x637307d9,0x7ae501ec}},	//   chie_, _oqo_, _sını, scht,
   {{0x25ad80c9,0xb4d909c8,0xe3b88214,0x4426b158}},	//   voel_, ाशी_, klı_, _nqo_,
   {{0x44293159,0xaca3019d,0xe80e83b7,0x644d315a}},	//   mta_, _laịb, _सिरा_, mvai,
   {{0x6d46315b,0x2902266d,0xc33200be,0xee3980e8}},	//   _yaka, yaka_, _שול_, іни_,
   {{0x4429315c,0xd6580039,0x5ebf00ab,0xc1740326}},	//   ota_, ליות_, _আলাই, _kiɗe_,
   {{0xe3b888c5,0x2d838110,0x272f817b,0x644d230d}},	//   flı_, ėje_, tını_, nvai,
   {{0x4429171c,0x29022b5c,0x69d6315d,0x29d781b9}},	//   ita_, waka_, _siye, _għar_,
   {{0x2902315e,0x4429315f,0x272f8afe,0x62853160}},	//   taka_, hta_, rını_, nzho,
   {{0x4429088b,0x272f8459,0x72078019,0x2cae819d}},	//   kta_, sını_, _ہفتہ_, ịmị_,
   {{0x29023161,0x6d463162,0xa01b0065,0x3b099232}},	//   raka_, _raka, szön, _дело_,
   {{0x6d463163,0x44293164,0x6f03b165,0x6d49811e}},	//   _saka, dta_, nanc, ldea,
   {{0x6d463166,0x29023167,0x2d923168,0xa2c9820e}},	//   _paka, paka_, tiye_, हेश्,
   {{0x6d49b169,0x60db8d48,0x44290b0b,0xed57316a}},	//   ndea, _ngum, fta_, мос_,
   {{0x6d46316b,0x4429316c,0x2d92316d,0x6d49803c}},	// [1d80] _vaka, gta_, riye_, idea,
   {{0x6d46316e,0x2d92316f,0x7c298b2b,0x6d498f31}},	//   _waka, siye_, iter, hdea,
   {{0x6d463170,0x44293171,0x7c29b172,0x673c1eb9}},	//   _taka, ata_, hter, merj,
   {{0x27e0025d,0x3d1805b3,0x44293173,0x443f882e}},	//   _kuin_, _फाटे_, bta_, kwu_,
   {{0x44291883,0x27e003d3,0x7d043174,0xe3b88182}},	//   cta_, _juin_, mais, ylı_,
   {{0x7d043175,0x6d59b176,0x6f03b177,0x673c3178}},	//   lais, _anwa, ganc, nerj,
   {{0x7c29b179,0x27edb17a,0xa3c38beb,0x656bb17b}},	//   eter, _eten_, ्षन_, _bogh,
   {{0x7d04317c,0x7c29b17d,0x257880e7,0x753b804f}},	//   nais, fter, _vélo_, geuz,
   {{0x673c1a6e,0x7c29b17e,0x656bb17f,0x2b47b180}},	//   kerj, gter, _dogh, _banc_,
   {{0x6f03b181,0x7d043182,0x2d988019,0x2b47b183}},	//   canc, hais, őre_, _canc_,
   {{0x7d043184,0x656b8c64,0x81bd0029,0xa3dea774}},	//   kais, _fogh, stēm, _दूर_,
   {{0xaca48135,0x6d60816b,0x661c3185,0x7d043186}},	//   _akụz, ávač, durk, jais,
   {{0x44293187,0xdb088511,0x29003188,0x27e00229}},	//   xta_, lodí, _deia_, _cuin_,
   {{0xe3b88201,0x27e03189,0x81bd00eb,0x673c318a}},	//   qlı_, _duin_, otēk, gerj,
   {{0xdfd41641,0xd90499f7,0x67d40ca4,0x79a71e58}},	//   торы, _پی_, тору, _орие,
   {{0x7d04318b,0x656bb18c,0x29ee8326,0x62850824}},	//   gais, _xogh, mƙa_, vzho,
   {{0x673c318d,0x4429318e,0x6f03b18f,0x7bd8b190}},	// [1d90] berj, uta_, yanc, _kivu,
   {{0x661c2e55,0x752d3191,0x31a403bf,0xa3c3b192}},	//   burk, sfaz, mıza_, ्षय_,
   {{0x7c29b193,0x7d043194,0x644d3195,0x27edb196}},	//   zter, bais, svai, _sten_,
   {{0x44293197,0x6f03b198,0xaca30133,0x764502a0}},	//   pta_, wanc, _abụb, _ishy,
   {{0x39493199,0x656b861f,0x06f30a74,0x4429319a}},	//   _maas_, _rogh, _अभाव_, qta_,
   {{0xf1ca001c,0x656b80f7,0xa3e400d4,0x705292dc}},	//   _dạy_, _sogh, _पंत_, انوا,
   {{0x81bd0029,0xd90f80d5,0x6d49b19b,0x45d580b3}},	//   rtēj, _نیا_, tdea, нцит,
   {{0x6f03b19c,0x79828063,0x7c299140,0x1c45b19d}},	//   sanc, chow, tter, еним,
   {{0x7c29b19e,0x27ed835f,0xfc48801c,0x3dc68079}},	//   uter, _uten_, _cử_, _dhow_,
   {{0x6d49851e,0x61e90796,0xc48286d2,0x2d8c0866}},	//   sdea, _čelj, ульк, édez_,
   {{0x673c319f,0x7bd8b1a0,0x68e48024,0x394910b0}},	//   verj, _divu, žide, _baas_,
   {{0x6d598114,0x92df80ab,0xf99f31a1,0x27e009ff}},	//   _unwa, তরে_, gnè_, _puin_,
   {{0x673c31a2,0xa3db000f,0x6007035f,0x27e0009f}},	//   terj, _ढंग_, нням_, _quin_,
   {{0xfaa584f6,0x201d82c4,0x29ee8326,0x7bd89a1a}},	//   _пало, iuwi_, bƙa_, _givu,
   {{0xf772810f,0x7d0431a3,0x6f01b1a4,0xed5a16ba}},	//   נקל_, tais, _melc, пов_,
   {{0x27e0038e,0x61ee86a5,0x673c02d4,0x2d9f80e7}},	//   _tuin_, íble, serj, nnue_,
   {{0x7d0431a5,0x673c01b9,0xfc488028,0xdee61f7d}},	// [1da0] rais, perj, _xử_, _попи,
   {{0x7d0431a6,0x60c4005d,0x8fa631a7,0xdb1c01a8}},	//   sais, _izim, _سمجه, _bhrá,
   {{0xdb1c003e,0xe9da2ae3,0xc33282f6,0x4efb0039}},	//   _chrá, чке_, רוב_, _מהיו,
   {{0xfbdf00e7,0x4aaf0072,0x307a03de,0xdb0884e8}},	//   _prêt_, _जुळव, ּאַנ, vodí,
   {{0x6f018358,0xb8e88fd5,0x26180035,0x201d82d5}},	//   _belc, _उर_, बंकी_, guwi_,
   {{0x38cb8bca,0x3dc6b1a8,0xdfcf880b,0x60c400b8}},	//   سانی_, _show_, مين_, _mzim,
   {{0xfc488104,0x03a30b9c,0x53a331a9,0x6f01b1aa}},	//   _sử_, _сиро, _сарб, _delc,
   {{0x7bd8b1ab,0x60c431ac,0x8c66ac60,0x5d54b1ad}},	//   _sivu, _ozim, етод, ткит,
   {{0x60c43074,0x10a38a2e,0x394931ae,0x81e78264}},	//   _nzim, _битн, _raas_, মীম_,
   {{0x6446008e,0xf8bf0036,0x25a00824,0x53b001a2}},	//   _mski, ngée_, hnil_, जकिश,
   {{0xc3331a15,0x60c41fa4,0x7bd8b1af,0x25a002d4}},	//   אות_, _azim, _vivu, knil_,
   {{0xfc488104,0x4c868098,0x4a9b00be,0x546a8081}},	//   _tử_, _плев, לייג, _наем_,
   {{0xb90905e8,0xdb0883a7,0xc95384de,0x25718061}},	//   _बल_, godã, אמר_, _vált_,
   {{0xa3c38e70,0x60c400eb,0x25a08353,0x394931b0}},	//   ्षण_, _dzim, čilu_, _waas_,
   {{0x394931b1,0x60c40316,0x644631b2,0x6a869a25}},	//   _taas_, _ezim, _aski, _défé,
   {{0xd5b831b3,0x25a002d4,0x257c128a,0x3eba0163}},	//   есу_, gnil_, _dílo_, _dypt_,
   {{0x2ef50698,0x68ed017b,0xe802801b,0xafdb1277}},	// [1db0] _изпр, _ifad, रीमा_, rvøs,
   {{0xc5f680ab,0x200b31b4,0x8aa7031f,0x889c0039}},	//   _ঘটনা_, msci_, нред, _מבחי,
   {{0x644631b5,0xd5df800f,0x321eb1b6,0xdd9100d7}},	//   _eski, _पूंज, nuty_, _نود_,
   {{0xc17400fc,0x7ec70032,0x1a6801f9,0x27e68299}},	//   _kiɗa_, _eépí, ریقی_, fqon_,
   {{0x2d84b1b7,0x6f01b1b8,0x6d5d0b03,0x64460326}},	//   dhme_, _pelc, _insa, _gski,
   {{0x7bdf83d3,0x7c2d020f,0x656f0352,0x39498df1}},	//   _équi, mtar, _hoch, žas_,
   {{0xfbdf0073,0xe7088154,0x6372008b,0x61dc00d4}},	//   _três_, رتون_, _vænt, यदृष,
   {{0x6d4d31b9,0x7dd58110,0x6f0184e7,0x49049a3e}},	//   ndaa, _išsk, _welc, _موفق,
   {{0x656f31ba,0x200b00d2,0x7d02802e,0x6f01b1bb}},	//   _moch, jsci_, _deos, _telc,
   {{0x656f0083,0x7c2d31bc,0x24890042,0x67200035}},	//   _loch, itar, izam_, _बाइक_,
   {{0xfaa59982,0x6a8682be,0x7c2d31bd,0x69c981e9}},	//   тано, _réfé, htar, _khee,
   {{0x656f31be,0x7d02b1bf,0x853000fc,0x2d9f8037}},	//   _noch, _geos, kiɗa, qnue_,
   {{0x6d4d31c0,0x7c2d0168,0x8ccd8035,0x1b0c0264}},	//   ddaa, jtar, देशो, স্টে_,
   {{0x6d4bb1c1,0x24891a23,0x6d5d31c2,0x6569b1c3}},	//   _haga, dzam_, _ansa, ljeh,
   {{0x6d4bb1c4,0x656f31c5,0x7c2d31c6,0x201931c7}},	//   _kaga, _boch, etar, arsi_,
   {{0x656f31c8,0x6d4bb1c9,0xe8029834,0x443931ca}},	//   _coch, _jaga, रीडा_, _bps_,
   {{0x60c402a5,0x6d4b8fa9,0x25a031cb,0x7c2d31cc}},	// [1dc0] _uzim, _maga, rnil_, gtar,
   {{0x6d5d31cd,0x61e3930c,0xa3c1823c,0x6f07003b}},	//   _ensa, _kunl, ंति_, cajc,
   {{0x442db1ce,0xbcfb31cf,0x3f98005c,0x6d4d15e8}},	//   hte_, _poét, miru_, bdaa,
   {{0x6d4bb1d0,0x3f98010b,0x656f31d1,0x6d4d0079}},	//   _naga, liru_, _goch, cdaa,
   {{0x69c982a3,0x7c2d31d2,0xa3c1a967,0x69db8722}},	//   _dhee, ctar, ंता_, _diue,
   {{0x442031d3,0x442d8ed8,0x7d02b1d4,0x6d4b9bf4}},	//   mui_, dte_, _seos, _aaga,
   {{0x442031d5,0x6d4bb1d6,0x442db1d7,0x26dc026f}},	//   lui_, _baga, ete_, _úvod_,
   {{0x752431d8,0x7bdc31d9,0x6d4bb1da,0x657bb097}},	//   ngiz, _hiru, _caga, gkuh,
   {{0x6d4bb1db,0x442db1dc,0x61e900d2,0x442031dd}},	//   _daga, gte_, _čeli, nui_,
   {{0x2d8488cf,0x671c81ab,0x61e382bb,0x201902a5}},	//   shme_, _नाटक_, _bunl, vrsi_,
   {{0x44200867,0xdee387b6,0x442db1de,0xf3638190}},	//   hui_, _тохи, ate_, ртын,
   {{0x442db1df,0x6d4bb1e0,0x7c2d31e1,0xfd5501bc}},	//   bte_, _gaga, ytar, _draị,
   {{0x442d8bf6,0x656f31e2,0x442031e3,0x2904804f}},	//   cte_, _roch, jui_, _mema_,
   {{0x6d40b1e4,0x6d4bb1e5,0x442031e6,0x656f03b3}},	//   lema, _zaga, dui_, _soch,
   {{0x443902ee,0x35e4035f,0xda6f8698,0x6d4b81d3}},	//   _sps_, ицтв, _тя_, _yaga,
   {{0x7c2d31e7,0x672d812b,0x6d40938e,0xdd11011c}},	//   ttar, đaji, nema, _düşd,
   {{0x442031e8,0x54550b71,0x6d4d31e9,0x7bdc31ea}},	// [1dd0] gui_, ыват, rdaa, _biru,
   {{0x09cb8eed,0x2d8210f4,0x6d408006,0x656f0352}},	//   िष्य, _elke_, hema, _woch,
   {{0x442db1eb,0x7bdc31ec,0x69c981c5,0x6d40b1ed}},	//   zte_, _diru, _phee, kema,
   {{0x7c2d08cf,0x6d5d1341,0x6d40b1ee,0x442031ef}},	//   ptar, _unsa, jema, bui_,
   {{0x6d4bb1f0,0x442db1f1,0x7bdc31f2,0x69db823e}},	//   _raga, xte_, _firu, _viue,
   {{0x7dd581e2,0x442d826f,0x7bdc31f3,0xe8d9019d}},	//   _išsi, vte_, _giru, _nnọ_,
   {{0x6d4bb1f4,0x69c9b1f5,0xc794803d,0x6abc0114}},	//   _paga, _thee, جشنب, _gyrf,
   {{0xe8d90870,0x26dc007c,0x7bdc31f6,0x6f0501d0}},	//   _anọ_, וקומ, _ziru, _lehc,
   {{0x7bca9301,0x442db1f7,0xf1bf0038,0xc6bf00c8}},	//   _bhfu, ute_, dlá_, _আলোচ,
   {{0x9ee980f7,0x6d4bb1f8,0x200980eb,0x212900b9}},	//   _أفضل_, _waga, šais_, _acah_,
   {{0x6d4bb1f9,0x35f59bbf,0x65698499,0x6d40b1fa}},	//   _taga, _спер, pjeh, bema,
   {{0xdb089bff,0x290431fb,0x8ed58264,0x06d58264}},	//   rodá, úma_, _স্থগ, _স্থি,
   {{0x394d831d,0xd9100019,0x442d8168,0x7c648019}},	//   _maes_, میں_, qte_, _ناول,
   {{0x749aa94d,0x649a8158,0x3ced8353,0x61e3826b}},	//   _אינפ, _אינה, lcev_, _tunl,
   {{0xe1f18288,0x200031fc,0x3f9831fd,0x98a403bf}},	//   _است_, _wwii_, riru_, ımı_,
   {{0x7d098025,0x44200f52,0x0ce200ab,0x3ced8353}},	//   naes, tui_, বর্ত, ncev_,
   {{0x752404b9,0x3f98012b,0x26180074,0x644488ae}},	// [1de0] rgiz, piru_, बूजी_, _šiiz,
   {{0xdd041010,0x394231fe,0x2904b1ff,0x44203200}},	//   ısın, leks_, _sema_, rui_,
   {{0xeb96893f,0x6d408870,0x44203201,0x75e78085}},	//   נדער_, yema, sui_, _qızl,
   {{0x673b005c,0x394218c2,0x44203202,0x6d408f3e}},	//   đuje, neks_, pui_, xema,
   {{0x44203203,0x6d40ae2b,0xe3b10019,0x2904804f}},	//   qui_, vema, صرے_, _vema_,
   {{0x6fb4000f,0xa2e30256,0x7d063204,0x39420074}},	//   ंकिं, _горд, _heks, heks_,
   {{0x6d40b205,0x7d063206,0xfbde0118,0x63768162}},	//   tema, _keks, _iiª_, _mânt,
   {{0x782680f7,0x746a8009,0xf65703c8,0xdd9080f7}},	//   _معطل, еров_, רסקי_, توب_,
   {{0x6d40b207,0x39423208,0xd1b38077,0x644d81a1}},	//   rema, deks_, _اینک, _šair,
   {{0x6d40b209,0x6d8784a1,0x7984320a,0xff248065}},	//   sema, _añad, _aliw, _خبری,
   {{0x4ebf00c8,0xa49b0362,0xaace8074,0xfca980d7}},	//   _আল্ল, _aeòl, हेंक, _یاهو_,
   {{0x6fc005ec,0x25bf8162,0xfce6b20b,0x394206ae}},	//   böck, clul_, _содо, geks_,
   {{0xa3e40540,0xe81c0006,0xa49b051e,0x8cb00c28}},	//   _पूल_, भंगा_, _ceòl, _अँगो,
   {{0xead48e02,0x63768087,0xf1bf03f2,0x1b1a0264}},	//   _коль, _cânt, slá_, ন্তে_,
   {{0xa3c3815c,0xa3c1b20c,0x7d06320d,0x5b7b80be}},	//   ्षर_, ंतर_, _beks, _ארגא,
   {{0x9e43016b,0xa49b0a2a,0x7984066f,0x6b9a8580}},	//   žďov, _feòl, _gliw, litg,
   {{0x7d06320e,0x33f400f7,0xbcfb0511,0x24180fe6}},	// [1df0] _deks, مسلس, _anéc, лоты_,
   {{0x290b320f,0x7d0602d5,0x69df0168,0x395fb210}},	//   laca_, _eeks, _hiqe, _snus_,
   {{0x3ebe9816,0xdb08807b,0x394db211,0xd6db004a}},	//   _nytt_, lldó, _paes_, _яти_,
   {{0x290b3212,0x4dfa0158,0x3547102a,0x3135804a}},	//   naca_, _שפרא, _схов, редр,
   {{0x3ced807a,0xd7058dae,0xada581d6,0x69df03ed}},	//   vcev_, азли, nkúš, _miqe,
   {{0x88c700c8,0x3ebe919b,0x69df3213,0x290b3214}},	//   _এলাক, _bytt_, _liqe, haca_,
   {{0x6d4f3215,0xd5ae0117,0x27780039,0x25bf8087}},	//   _kaca, _رہے_, רגון_, tlul_,
   {{0x290b0503,0x395fb216,0x2d893217,0x6d4f3218}},	//   jaca_, _unus_, nhae_, _jaca,
   {{0xb81ca441,0xe7e1023c,0x0d828112,0x87278c2a}},	//   _नियम_, _गंगा_, ільн, _معام,
   {{0x6d4f02a3,0x308481a8,0x60c9b219,0x00000000}},	//   _laca, _الكف, _izem, --,
   {{0x39420006,0x69cd0362,0x49ca321a,0xb1130135}},	//   teks_, _bhae, клон_, _tụle,
   {{0x24968077,0x69cd0114,0x672d812b,0x290b321b}},	//   انید_, _chae, đaju, gaca_,
   {{0x7dc58207,0x764e807b,0x6b65a4b6,0x7d06007b}},	//   lóso, _ábyr, _вкла, _reks,
   {{0x87b90676,0x39420665,0x64598609,0x248d822c}},	//   густ_, seks_, _irwi, mzem_,
   {{0x290b321c,0x2d960196,0xe81c8105,0x7d06321d}},	//   baca_, арас, _निभा_, _peks,
   {{0x6d4f321e,0x290b321f,0x69cd0013,0xdb188176}},	//   _caca, caca_, _ghae, _akvè,
   {{0x7d06021e,0x6d4f01b4,0x81bd01a9,0x3f85b220}},	// [1e00] _veks, _daca, rtēt, _ollu_,
   {{0x7bc18355,0x644b8077,0x6d4f0229,0x42560992}},	//   nllu, _msgi, _eaca, итет,
   {{0x7d060558,0x00e695f7,0x6d4f0014,0x7c3d3221}},	//   _teks, ажен, _faca, _epsr,
   {{0x6d4f3222,0x6e3e00b9,0x31608333,0x323680be}},	//   _gaca, _ippb, ñiz_, יטען_,
   {{0x60c98035,0x6d443223,0x69da8037,0x2f18b224}},	//   _czem, meia, _ètem, голь_,
   {{0x248db02a,0x2d80009a,0x60c9b225,0x6d4f3226}},	//   dzem_, lkie_, _dzem, _zaca,
   {{0xfaa33227,0xeb972678,0x1c188074,0xe8e000ff}},	//   _даро, _тир_, _दिहल_, _muối_,
   {{0x2d80079f,0xe817016f,0x290b0e1b,0xad6680f7}},	//   nkie_, _तिला_, xaca_, شابه,
   {{0x290b003a,0x44323228,0xb716803d,0x7b66b229}},	//   vaca_, nty_, _نباش, атне,
   {{0x4432322a,0x61e0908c,0x443d808e,0x68e4322b}},	//   ity_, _himl, _dpw_, _agid,
   {{0x2d80079f,0x0cc3123a,0x3f9cb22c,0x4432322d}},	//   kkie_, _शर्म, mivu_, hty_,
   {{0x443209a4,0x60c08009,0x3f9cb22e,0x7bc1b22f}},	//   kty_, _kymm, livu_, allu,
   {{0x7bce00b9,0x6d443230,0xdbdc81d0,0xdb050118}},	//   _ohbu, deia, lšíh, rohú,
   {{0x6d4f3231,0xe8e00028,0x61e0b232,0x7c243233}},	//   _saca, _cuối_, _liml, duir,
   {{0x290b0024,0x6d4f3234,0xada580e1,0x8de827ee}},	//   paca_, _paca, skúš, ифта_,
   {{0x69c88029,0xdb1c01a8,0x261803ca,0x44323235}},	//   _ūden, _ghrú, _फिरी_, fty_,
   {{0x4424b236,0x6562803e,0x7bce0267,0x69c38036}},	// [1e10] num_, _mnoh, _bhbu, înem,
   {{0x799d005d,0x25a9a356,0x6d4f3237,0x8c1b8039}},	//   lisw, čali_, _waca, כומי,
   {{0x60c98117,0x6d4f04f9,0x442484a7,0x27e93238}},	//   _szem, _taca, hum_, _huan_,
   {{0x4424b239,0x2d80323a,0x799d005d,0x79a4ac60}},	//   kum_, ckie_, nisw, орче,
   {{0x765a8063,0x4424b23b,0x27e902f9,0x7bc1b23c}},	//   _arty, jum_, _juan_, yllu,
   {{0xbb850307,0x4424b23d,0x2d86b23e,0x7d0d323f}},	//   _السي, dum_, _aloe_, laas,
   {{0x6fcd81ac,0x636db240,0x27e93241,0x799d0234}},	//   júce, _gúny, _luan_, kisw,
   {{0x6fcdb242,0x7d0d3243,0x44248125,0x248d8722}},	//   dúce, naas, fum_, tzem_,
   {{0x4424b244,0x60c0b245,0xe3b99a1f,0x60c9b246}},	//   gum_, _gymm, лби_, _uzem,
   {{0xd7748013,0x5f748013,0x7d0d29cd,0x61e0b247}},	//   _والع, _والر, haas, _ziml,
   {{0x7d0d3248,0xe9da0021,0x248da47d,0x26c101c0}},	//   kaas, лко_, szem_, _nyho_,
   {{0x27e93249,0x186a324a,0x4432324b,0x7d0d324c}},	//   _buan_, гами_, yty_, jaas,
   {{0x4424b24d,0x7d0d02a3,0x4432324e,0x55528065}},	//   cum_, daas, xty_, _رپور,
   {{0xa0270125,0x27e9324f,0x291e02d0,0x7529b250}},	//   _stöð, _duan_, şta_, lgez,
   {{0xc9f5845b,0x51f59e44,0xfaa2b251,0x644981ec}},	//   _استع, _استر, _нашо, lwei,
   {{0x7d0d3252,0x7529b253,0x7c243254,0x63bc3255}},	//   gaas, ngez, tuir, _skrn,
   {{0x1ddf800f,0x69c280c9,0xd4671300,0x644982af}},	// [1e20] _पूछत, vloe, бите_, nwei,
   {{0x443214e3,0x2d803256,0x212d81f1,0x4f260991}},	//   rty_, skie_, _aceh_, _удоб,
   {{0x44323228,0x6449b257,0x7c2402a5,0x7d0d3258}},	//   sty_, hwei, suir, baas,
   {{0x4424b259,0x7529890d,0x4432325a,0x6f0e0326}},	//   yum_, jgez, pty_, labc,
   {{0x7c24325b,0xdb01b25c,0xe80b800f,0x3a258fb0}},	//   quir, noló, _सौदा_, hulp_,
   {{0xe82000a5,0x4420325d,0x64498114,0x799d0234}},	//   _बिना_, mri_, dwei, zisw,
   {{0x528600f7,0xa248325e,0x4424b25f,0x44203260}},	//   _الأك, _خیال_, wum_, lri_,
   {{0x44203261,0x3f9cb262,0x7529b263,0xdb018298}},	//   ori_, sivu_, ggez, koló,
   {{0x44203264,0x644997fb,0x3946b265,0x81ae0264}},	//   nri_, gwei, meos_, কতা_,
   {{0x4424b266,0xf366b267,0x44203268,0xdb018ce0}},	//   rum_, стин, iri_, doló,
   {{0x7d0d02c1,0x44203269,0xed06803d,0x7dea8035}},	//   yaas, hri_, _هواپ, _męsk,
   {{0x27e9326a,0x7982809a,0x3946a62c,0x4424808b}},	//   _puan_, nkow, neos_, pum_,
   {{0x27e9326b,0x543387d2,0x39520039,0x8c43b26c}},	//   _quan_, _فرور, _days_, _неце,
   {{0x799d1c1a,0x7d0d326d,0x3e580242,0x6f0e0326}},	//   sisw, waas, _bčt_, gabc,
   {{0x4420326e,0x7d0d326f,0x63ba9122,0x7a1c0087}},	//   eri_, taas, motn, nătă,
   {{0x27e93270,0x63ba8353,0xe8d90133,0xdd940084}},	//   _tuan_, lotn, _alụ_, пасы,
   {{0x44203271,0xe8200006,0xdb01b272,0x539901bb}},	// [1e30] gri_, _बिया_, coló, авая_,
   {{0x7d0d3273,0xdce982ce,0x3e5806c0,0x5b153274}},	//   saas, vječ, _fčt_, імет,
   {{0x26c701ac,0xd1758196,0x39468511,0x27f8807a}},	//   _áno_, жылы, feos_, _črna_,
   {{0x41c91869,0xdce9b275,0x59c908fd,0xf1c90ebf}},	//   रतिस, tječ, रतिर, रतिन,
   {{0x1869a4b2,0xa069828b,0x63bab276,0xa3d51354}},	//   рали_, рала_, kotn, _момч,
   {{0xaded9344,0x36198009,0x66fb06bf,0xdce982ce}},	//   _चंदन_, ацию_, ्रिक_, rječ,
   {{0x3cdb8076,0xdce9920e,0x25a93277,0x752981ed}},	//   खेने_, sječ, onal_, tgez,
   {{0x25a93278,0x4c85835f,0x6449b279,0x3946a790}},	//   nnal_, жлив, twei, ceos_,
   {{0x290fb27a,0xe10100c8,0x7989826b,0x7529b27b}},	//   maga_, ্লাহ_, _ilew, rgez,
   {{0x290fb27c,0x6449b27d,0x645d2cf6,0x3952327e}},	//   laga_, rwei, _mrsi, _says_,
   {{0x395203d3,0x89aa0364,0x6449b27f,0x60cd3280}},	//   _pays_, иков_, swei, _azam,
   {{0x290fb281,0x44203282,0xc1740326,0xdb01b283}},	//   naga_, yri_, _kiɗi_, toló,
   {{0x77770197,0xcb699073,0xe8e00129,0x25a904e8}},	//   _boxx, _вале_, _ruồi_, dnal_,
   {{0x44203284,0x60cd0754,0x661a03f2,0x5ed080ab}},	//   vri_, _dzam, átko, _স্টে,
   {{0xb87b2602,0x645d3285,0xdb01b286,0x290fb287}},	//   scíp, _arsi, soló, kaga_,
   {{0x44203288,0xa3c38a74,0x2d8db289,0xa0a6004a}},	//   tri_, ्षक_, nhee_, _майд,
   {{0x4420328a,0x7d0b8065,0x290fb28b,0x9f840198}},	// [1e40] uri_, _megs, daga_, töä_,
   {{0x4420328c,0x76418022,0x2bcf800c,0xa2d080d4}},	//   rri_, _oply, _सीमा, डेक्,
   {{0x79828063,0x644f328d,0x4420328e,0x98b90084}},	//   tkow, _esci, sri_, resą_,
   {{0x4420328f,0x5f460416,0xed5a3290,0x08c69cf4}},	//   pri_, _انگل, _том_, обен,
   {{0x3946a8d5,0x7982b291,0x61e43292,0x798988f9}},	//   reos_, rkow, _miil, _dlew,
   {{0x7989b293,0xdfcf8013,0x394682ba,0x7982809a}},	//   _elew, نين_, seos_, skow,
   {{0x63baa6ef,0x394685e4,0x290fb294,0xa3d70701}},	//   votn, peos_, baga_, ागर_,
   {{0x61e40a2c,0x6d563295,0x25a03296,0x290fb297}},	//   _niil, ndya, niil_, caga_,
   {{0x98a38a29,0x61ea802e,0x60c43298,0x7c3604fe}},	//   _жите, _sufl, _nyim, ntyr,
   {{0x25a91b49,0x61e40362,0x63a8808e,0xdb17002a}},	//   znal_, _aiil, undn, toxé,
   {{0xa2a001fe,0x63bab299,0x19590a41,0x326680e8}},	//   _गेम्, rotn, баны_, ітов,
   {{0x63bab29a,0xdb17002a,0x60c40a03,0x6fc48580}},	//   sotn, roxé, _byim, dòci,
   {{0xb8f3035a,0x63ba807a,0x9f490187,0xdb01823e}},	//   _वर_, potn, _itaú_, rolò,
   {{0x290fb29b,0x60cd007a,0xa294902a,0xdb170118}},	//   zaga_, _vzam, _налі, poxé,
   {{0x290fb29c,0xdd9b2466,0x6933001b,0xdb23807b}},	//   yaga_, аша_, _přeč, _þrát,
   {{0xf1a40087,0x48151285,0x3f83329d,0x1b0400ab}},	//   _орын, _емис, skju_, _লাগে_,
   {{0x6ebb05e8,0x25a9329e,0x60cd329f,0xe8e0001c}},	// [1e50] _शुरु, rnal_, _uzam, _buổi_,
   {{0xd25b2ae3,0x645d0042,0x69c0ab47,0xed5985f3}},	//   ице_, _vrsi, _akme, može_,
   {{0xdced0a20,0x290fb2a0,0xdb07008b,0x25a032a1}},	//   ljač, taga_, _skjó, biil_,
   {{0x20090300,0x2b8086c0,0x25a00079,0x604081bc}},	//   _kwai_, _wòch_, ciil_, _ịmag,
   {{0x290fb2a2,0x644f32a3,0x7d0b81b0,0x64468085}},	//   raga_, _usci, _regs, çkil,
   {{0x442932a4,0x290fb2a5,0xd34300d5,0x637f83a7}},	//   mua_, saga_, _تفسی, _têni,
   {{0x442932a6,0x64428e67,0xf96bb2a7,0x2d8d89ff}},	//   lua_, _apoi, _край_, thee_,
   {{0x752d32a8,0xe79580d5,0x3cf7809a,0x764180e1}},	//   ngaz, _کارک, ीरें_, _vply,
   {{0xdced0067,0xd7f89e0b,0x1c428190,0x68e98609}},	//   jjač, _дух_, еным, _iged,
   {{0x61e429cd,0x2d8d8079,0xdced0503,0x7d0bb2a9}},	//   _siil, shee_, djač, _wegs,
   {{0x442910af,0x4b7c0158,0x7641816b,0x61e4156e}},	//   hua_, יאזו, _uply, _piil,
   {{0x442932aa,0xe8028c1c,0x248001a5,0x644f806a}},	//   kua_, रीका_, yyim_, æcis,
   {{0x442932ab,0x2d9d80b4,0x27e5a8bd,0xeb8e96c7}},	//   jua_, _imwe_, _kiln_, _зи_,
   {{0x44290ee2,0x7c298216,0x61e40079,0x752d047f}},	//   dua_, muer, _wiil, egaz,
   {{0x9663229c,0x7c2981eb,0x63a1b2ac,0x68e9b2ad}},	//   нкре, luer, miln, _oged,
   {{0x752d32ae,0x68e9b2af,0xdce404a8,0x4429004f}},	//   ggaz, _nged, njić, fua_,
   {{0x442932b0,0x27ed8102,0x7c29b2b1,0xd467013a}},	// [1e60] gua_, _nuen_, nuer, пите_,
   {{0xe7ef8105,0x63a1b2b2,0x213f88f9,0x68e9b2b3}},	//   _चढ़ा_, niln, _abuh_, _aged,
   {{0x7c361da3,0x24920063,0x44290087,0x248615d8}},	//   styr, szym_, aua_, šom_,
   {{0xb4ea8076,0x442932b4,0x27ed80ab,0x290d802e}},	//   _मले_, bua_, _buen_, _ceea_,
   {{0xa3cb9521,0x7d0424b9,0xe8e00028,0x63a1b2b5}},	//   लता_, mbis, _tuổi_, kiln,
   {{0x26c5800d,0x27ed811e,0xfbc78bbe,0x7c29b2b6}},	//   _bylo_, _duen_, _ست_, duer,
   {{0x63a1b2b7,0x68edb2b8,0x6b6305a8,0xa3c18074}},	//   diln, žada, _якра, ूतन_,
   {{0x7c298693,0xb608801b,0x7f8b0085,0x7d0432b9}},	//   fuer, jišť, _müqa, nbis,
   {{0x7c29adb0,0xdb050511,0x7d0432ba,0xbcfb01d6}},	//   guer, cohó, ibis, _poéz,
   {{0x5ede80c8,0x394032bb,0xfbbe1664,0x63a1a11b}},	//   নুষে, _abis_, ्तिम, giln,
   {{0x27ed80ad,0x442932bc,0xa3e401ce,0x61ee04fe}},	//   _zuen_, zua_, _पूछ_, _jubl,
   {{0xed59803e,0x7c2984dc,0x63be027f,0xa3e79344}},	//   tože_, buer, hopn, _मूक_,
   {{0x63a1a8ee,0x7c2985b4,0xc8640adb,0x53348198}},	//   biln, cuer, нтри, _желт,
   {{0x61ee03d3,0x7c242a06,0x442932bd,0x38660bcf}},	//   _oubl, drir, vua_, _šorc_,
   {{0xdced0042,0x7bda807b,0x433b8039,0x777ab2be}},	//   sjač, mmtu, _העוב, _motx,
   {{0x442932bf,0x7c2432c0,0x7d042277,0x557432c1}},	//   tua_, frir, gbis, нгст,
   {{0x09c909a3,0x3f8c8459,0x7c2432c2,0x752d32c3}},	// [1e70] रतीय, _oldu_, grir, rgaz,
   {{0x3b540a4c,0x442932c4,0x798d0282,0x44248c5e}},	//   нкур, rua_, _hlaw, irm_,
   {{0x442932c5,0xb6068024,0x213f80ee,0x7c2432c6}},	//   sua_, nošć, _pbuh_, arir,
   {{0x15f205b3,0xdd86803f,0x442932c7,0x7dc58510}},	//   _आंतर_, _شو_, pua_, pósi,
   {{0x27edb2c8,0xdb1707f4,0x44290098,0xdb1c32c9}},	//   _quen_, loxí, qua_, _chró,
   {{0x798d031d,0x777a809f,0x3f9e80b9,0x3dc90080}},	//   _llaw, _cotx, _cmtu_, llaw_,
   {{0x63a1adee,0x61ee02a5,0x7c299770,0x798d32ca}},	//   viln, _gubl, wuer, _olaw,
   {{0x7c29b2cb,0xb60680ce,0x63a18035,0x3dc91217}},	//   tuer, došć, wiln, nlaw_,
   {{0x63a1b2cc,0x320102d5,0x3940002a,0x69c38036}},	//   tiln, lphy_, _rbis_, îneu,
   {{0x798d32cd,0x7c29b2ce,0x798611ee,0xaca3819d}},	//   _alaw, ruer, wkkw, _nkụk,
   {{0x7c299b7d,0x63a18353,0xb606b2cf,0xa91d8bcf}},	//   suer, riln, gošć, _alži,
   {{0x7c298388,0x7e7e816d,0xaca3882e,0x2d9d82a0}},	//   puer, äppe, _akụk, _umwe_,
   {{0x798d32d0,0x63a1b2d1,0x3dc9033e,0xbcfb00e1}},	//   _dlaw, piln, dlaw_, _inéh,
   {{0x8c429e4e,0x61fb0b67,0x7c2432d2,0xa49b0706}},	//   _реше, _čuln, vrir, _leòs,
   {{0xafe30037,0xdb1703a8,0x7d0f0061,0x4ad191be}},	//   торл, goxí, _becs, _हरिव,
   {{0x61ee32d3,0x99520110,0x25adb2d4,0xe817016f}},	//   _rubl, ršų_, nnel_, _तिचा_,
   {{0x7d0432d5,0xdca32358,0x63be007a,0x6fcd80e1}},	// [1e80] rbis, вати, topn, júco,
   {{0x25bf82d6,0x7c24011e,0x387f0192,0x7dea8196}},	//   houl_, rrir, äure_, _kęst,
   {{0xa49b0706,0xdb1c0229,0x68ed81d6,0x3dc90428}},	//   _beòs, _bhrò, ľadn, blaw_,
   {{0x7c240081,0x3dc932d6,0xdb1c1a2c,0x2f0a8035}},	//   prir, claw_, _phró, _mógł_,
   {{0xb8f6901b,0x7bc38b99,0x7bc8807b,0xaca4019d}},	//   _हर_, _oknu, yldu, _maịs,
   {{0xdb1a826f,0x61ee02f1,0x9f458176,0xe29a32d7}},	//   poté, _tubl, _jilè_, _даг_,
   {{0x2b580088,0x69c432d8,0x61fc0503,0x9f8d008b}},	//   _iarc_, _okie, _utrl, nþá_,
   {{0xa5349612,0xb606811f,0x2d9202f7,0x29c40118}},	//   хнич, vošć, nhye_, iñas_,
   {{0x29069f72,0x20c381e5,0x7e878110,0xdb18b2d9}},	//   mboa_, _айтм, _įspū, _akvá,
   {{0x798d32da,0x69c432db,0xb606811f,0x2b5832dc}},	//   _slaw, _akie, tošć, _jarc_,
   {{0xa2c19513,0xd01380c8,0x798d01e9,0x3218826f}},	//   _रुद्, _সময়_, _plaw, éry_,
   {{0xe4a6954f,0xc486b2dd,0x68e4826c,0xb6068bcf}},	//   _орло, _олек, židu, rošć,
   {{0xa3e7823c,0xc058102a,0xbf0a016f,0x107432de}},	//   _मंच_, мір_, वरून_, вляю,
   {{0x0efb32df,0x2b5832e0,0x47cc80ab,0x3dc902c4}},	//   ्रेस_, _narc_, াদকী, wlaw_,
   {{0x52bf0beb,0x9f45b2e1,0x69c40609,0x3ceb32e2}},	//   _्रेस, _dilè_, _fkie, _pgcv_,
   {{0x3dc90122,0x7f5701b4,0x58d5062c,0x637f8901}},	//   ulaw_, _waxq, _пойт, _fêns,
   {{0x7d020333,0x3dc932e3,0xb7d50032,0x9f4586c4}},	// [1e90] ñosa, rlaw_, _aṣen, _filè_,
   {{0x6d978087,0x69dd32e4,0xdb018366,0xdb1c0a2a}},	//   nţar, lmse, anlæ, _shrò,
   {{0xb50e86a7,0x7d0f32e5,0xe1f00481,0xdb1c01e4}},	//   सराय_, _tecs, لسن_, _phrò,
   {{0x320132e6,0x7dc5b2e7,0x645c80eb,0x68ed80e1}},	//   rphy_, nóst, ārij, ľado,
   {{0x68ed826f,0x2b5832e8,0x20190198,0x6008af8d}},	//   žado, _farc_, nssi_, днім_,
   {{0x657d32e9,0x7c2d32ea,0xa49b0229,0x443907f1}},	//   _hosh, muar, _feòr, _iqs_,
   {{0x7c2d32eb,0xee398cde,0x2bbe090f,0x657d32ec}},	//   luar, їни_, ्तरा, _kosh,
   {{0x68ed32ed,0x63a5178f,0x657d32ee,0x6d87811b}},	//   _ngad, lihn, _josh, _iñak,
   {{0x657d32ef,0x3834b2f0,0x7c2d32f1,0xed598904}},	//   _mosh, _интр, nuar, rdž_,
   {{0x69c432f2,0xa3bf0592,0x61e9b2f3,0x63a500dd}},	//   _skie, ँकि_, _hiel, nihn,
   {{0x61e9b2f4,0xa2d3016f,0x60c982f7,0x25ad8706}},	//   _kiel, भेच्, _hyem, pnel_,
   {{0x657d32f5,0x7c2d32f6,0xa3cf81a2,0x60c983f7}},	//   _nosh, kuar, _वीर_, _kyem,
   {{0x61e9b2f7,0xdb088511,0x656bb2f8,0xbcfb00f7}},	//   _miel, godó, _ingh, _gnéi,
   {{0x61e98341,0x7c2d32f9,0x7c3bb2fa,0xdb1e0168}},	//   _liel, duar, mtur, ropë,
   {{0x6d59b2fb,0x657d32fc,0x442db2fd,0x63a514e4}},	//   _kawa, _bosh, lue_, dihn,
   {{0x6d5bb2fe,0x61e9b2ff,0x7bc1b300,0xaca381bc}},	//   ndua, _niel, lolu, _nhịk,
   {{0x2b583301,0x6d59b20a,0x7c2d3302,0x6aa806ce}},	// [1ea0] _parc_, _mawa, guar, कप्र,
   {{0x6d59b303,0x291fb304,0xaca3819d,0x2d9202a0}},	//   _lawa, _adua_, _ahịk, shye_,
   {{0x61e9b305,0x27ffa2c2,0x3ea63306,0xa9269da4}},	//   _biel, _atun_, _чинг, едел,
   {{0x61e9b307,0x6d59b308,0x657d3309,0xb17b016d}},	//   _ciel, _nawa, _gosh, rmåg,
   {{0xc7c69821,0x4fc6aa13,0x61e988dd,0x7d1602a3}},	//   нски, нска, _diel, mays,
   {{0x7d16330a,0x656bb30b,0xfaa60d0e,0x442db30c}},	//   lays, _angh, _заго, due_,
   {{0x6d59b30d,0x657d330e,0x1dcb99a1,0x61e98039}},	//   _bawa, _yosh, ातंत, _fiel,
   {{0x7d16330f,0x6d59b310,0x61e98609,0xdd97ad94}},	//   nays, _cawa, _giel, ешь_,
   {{0x442dab56,0x7c3bb0e5,0x3cdb82f1,0x60c9b311}},	//   gue_, gtur, खेले_, _gyem,
   {{0x09c90b6f,0xa0a3b312,0x61e9b313,0x1e969285}},	//   रत्य, _сауд, _ziel, _прер,
   {{0x200d8352,0x0c73819f,0x7d163314,0x7c2d3315}},	//   _zwei_, ندید, kays, zuar,
   {{0x6d59b316,0xdce606c4,0x67eb0372,0x0efb01a2}},	//   _gawa, _ankč, _ażja, ्र्स_,
   {{0x7c3b9bb4,0x69dd3317,0x7bc1b318,0x7d160079}},	//   ctur, rmse, bolu, days,
   {{0x7bc1802e,0x657d3319,0x6d59b31a,0x2019331b}},	//   colu, _sosh, _zawa, rssi_,
   {{0xdb1a87e2,0x6d59b31c,0xa2a0016f,0x657d331d}},	//   notí, _yawa, _गेल्, _posh,
   {{0x7d160079,0x7c2201b9,0xdb01b31e,0x6285016b}},	//   gays, ġorn, vilé, vyho,
   {{0x63a509da,0x61e9b31f,0xb81ca0c0,0x6d4d3320}},	// [1eb0] tihn, _riel, _निगम_, reaa,
   {{0x7c2d27ed,0x61e9b321,0x6e2e3322,0xb17b0366}},	//   ruar, _siel, bubb, småd,
   {{0x61e9b323,0x7d160079,0x442d8102,0xdb188106}},	//   _piel, bays, zue_, _ikvä,
   {{0x63a5010b,0x1c218665,0x61e98168,0x27ff808e}},	//   sihn, _मिलल_, _qiel, _ptun_,
   {{0x61e9b324,0x6d59b325,0x7c2d3326,0x29d900f7}},	//   _viel, _rawa, quar, méad_,
   {{0x61e9b327,0x6d598886,0xdce9920e,0x442db328}},	//   _wiel, _sawa, ljeć, vue_,
   {{0x44293329,0x61e9b32a,0x6d59b32b,0x6d40b32c}},	//   lra_, _tiel, _pawa, ffma,
   {{0x7c3b81dc,0x4429332d,0x8d658ada,0xf8bf332e}},	//   ttur, ora_, твие, ngés_,
   {{0x4429332f,0xe43280f7,0x7bc1b330,0x6d5bb331}},	//   nra_, لفيد, tolu, rdua,
   {{0x4429186b,0x6d59b332,0x442db333,0x394fb334}},	//   ira_, _wawa, rue_, legs_,
   {{0x09d60a49,0x6d59b335,0x7bc1b336,0x316d8390}},	//   _সংবা, _tawa, rolu, _knez_,
   {{0x44293337,0x7bc1b338,0xdb1e02be,0x656bb339}},	//   kra_, solu, ropé, _ungh,
   {{0x442db33a,0x29120179,0x8edf00c8,0x4429333b}},	//   que_, _veya_, _ব্লগ, jra_,
   {{0x4429333c,0x701380ab,0x7d16057b,0x7c299da3}},	//   dra_, _সমাজ_, ways, mrer,
   {{0x4429333d,0x65b301cd,0x6da61577,0x7d020333}},	//   era_, għho, вива, ñoso,
   {{0x7d09ab82,0x893612c8,0x6e2e333e,0x12e880be}},	//   nbes, _شعبا, rubb, _אַפּ,
   {{0x4429333f,0xa91d803a,0x7d1602a3,0x28de0540}},	// [1ec0] gra_, _možd, rays, नेशि,
   {{0x6e2e2d9d,0x7d163340,0x06863341,0x8cd6864a}},	//   pubb, says, _агон, मेटो,
   {{0x44293342,0x7c2982af,0xdce982ce,0x7d09874c}},	//   ara_, hrer, bjeć, kbes,
   {{0x29d900f7,0x7d1601b4,0x637e928a,0x6fcd8174}},	//   céad_, qays, _záně, lúch,
   {{0x7d09b343,0x317f83ec,0x6d46026b,0xe9478061}},	//   dbes, _douz_, _ibka, ئرمی,
   {{0x5ead80c8,0x7c29b344,0xaca38135,0x7d09a0ff}},	//   য়েছে, drer, _chọk, ebes,
   {{0x6ae000c8,0x7c29b345,0xf3f400ab,0x7d09b346}},	//   _প্রো, erer, _ছবির_, fbes,
   {{0x7d09b347,0x6ce68d13,0x7c2982df,0x6fcd8174}},	//   gbes, кіпе, frer, húch,
   {{0xc0458277,0x7c29b348,0xdb1c01d0,0x00000000}},	//   _مخلو, grer, _zkrá, --,
   {{0xf4130051,0x2006b349,0xf3669677,0xa91d9502}},	//   ספת_, mpoi_, ттин, _požg,
   {{0xc3331a15,0x4429334a,0x79809088,0x7d09b34b}},	//   בות_, zra_, _komw, bbes,
   {{0x7c29b34c,0x316d334d,0x6f188353,0x44290e20}},	//   brer, ñez_, lavc, yra_,
   {{0x75228133,0xb7d50032,0x6d958091,0xe9df002a}},	//   _idoz, _aṣan, _dáad, rmú_,
   {{0x4429334e,0x547b8039,0x9e35334f,0x6d463350}},	//   vra_, _קטגו, легч, _abka,
   {{0xb8ca058c,0x442919ea,0x2bb1816f,0x2bec064a}},	//   _गे_, wra_, ीकरा, _अंजू_,
   {{0xa91d826f,0x7bc7104a,0x7e653351,0xdcfb811f}},	//   _kože, _skju, _vrhp, rkuć,
   {{0xdb1c3352,0x29193353,0x6f18807d,0xdcfb8289}},	// [1ed0] _skrá, masa_, kavc, skuć,
   {{0xa91d803a,0x4ea720e1,0x8f55035f,0xdce9920e}},	//   _može, _арма, _свої, sjeć,
   {{0x44293354,0x6f188503,0x7522b355,0x61ed3356}},	//   sra_, davc, _odoz, _kial,
   {{0x44293357,0x29193358,0x673b012b,0x60cd3359}},	//   pra_, nasa_, đuju, _kyam,
   {{0xa3c2853e,0xa91d8503,0x6d5d0cb5,0x6fcdb35a}},	//   ंवा_, _nože, _iasa, lúci,
   {{0x291915bd,0x7522b35b,0x24890282,0x2d82b35c}},	//   hasa_, _adoz, myam_, öken_,
   {{0x6d5d335d,0x6da59860,0x2919335e,0xe5a5a358}},	//   _kasa, лика, kasa_, лики,
   {{0x61ed335f,0x7bc50091,0x7c29b360,0xe4599c60}},	//   _nial, lohu, trer, ежи_,
   {{0x6d5d3335,0x60cd3361,0x6f1880d2,0xa91d8279}},	//   _masa, _nyam, bavc, _vožd,
   {{0x7c29ad11,0x6d5d3362,0x2bd90321,0x490b800d}},	//   rrer, _lasa, _बीमा, ारको_,
   {{0x61ed3363,0x6fcd81ac,0x60cd3364,0x25a91e51}},	//   _bial, júci, _ayam, kial_,
   {{0x6d5d3365,0x29193366,0xb4db046d,0x60cd2c1d}},	//   _nasa, gasa_, _abàm, _byam,
   {{0x61ed2786,0x4429b367,0x9b458591,0x343980be}},	//   _dial, _ía_, _منشو, _נײַע,
   {{0x9474806b,0x656f1140,0x63a88699,0x443fb368}},	//   _خدما, _anch, cidn, mtu_,
   {{0x6d5d3369,0xa2ca89a3,0x291911c2,0x61ed336a}},	//   _basa, _सुप्, basa_, _fial,
   {{0x5bbe0f21,0x61ed336b,0x69c98069,0xed5715fc}},	//   ्त्व, _gial, _nkee, лос_,
   {{0x443f88a7,0x6d5d1e92,0x2bf680be,0x69c6336c}},	// [1ee0] ntu_, _dasa, ָמען_, moke,
   {{0x443fb36d,0x69c6336e,0xa09b03de,0x69c9b36f}},	//   itu_, loke, _נייט, _akee,
   {{0x6d5d3370,0x443fb371,0x201f87e2,0x35a61988}},	//   _fasa, htu_, _avui_, _банг,
   {{0x25a9325b,0x6d5d3372,0x05560d0e,0x644b8366}},	//   cial_, _gasa, _стоя, _opgi,
   {{0xdefa825d,0x443fb373,0xa2ca9516,0xbcfb0333}},	//   ный_, jtu_, _सुन्, _enés,
   {{0x6d5d0491,0xdb1c006a,0x69c63374,0x7c2b1434}},	//   _zasa, _skræ, hoke, ágre,
   {{0x6d5d3375,0x29193376,0xb8eb800c,0xbb3b00be}},	//   _yasa, yasa_, _रु_, _רעלי,
   {{0xa91d80ce,0x6d5d02a3,0x69c62419,0x6f18b377}},	//   _pože, _xasa, joke, savc,
   {{0x61ed0307,0x20e303dd,0x63a8816d,0x6f18b378}},	//   _rial, _गणेश_, tidn, pavc,
   {{0x40938013,0x2d823379,0x25a9337a,0x61ed337b}},	//   _الكر, _loke_, zial_, _sial,
   {{0x61ed0397,0x2919337c,0x60cd0590,0x443fb37d}},	//   _pial, tasa_, _syam, atu_,
   {{0x6288b37e,0xa91d807a,0x7bc5004f,0xe80b801b}},	//   rydo, _tože, zohu, सीका_,
   {{0x2919337f,0x629ab380,0x61ed3381,0x44321126}},	//   rasa_, szto, _vial, juy_,
   {{0x6d5d3151,0x29193148,0x60cd0010,0x6fcd80e1}},	//   _sasa, sasa_, _vyam, túci,
   {{0x6d5d3382,0xcddb0fbb,0x6d443383,0x69c62176}},	//   _pasa, ења_, ffia, boke,
   {{0x55580160,0x6d5d3384,0x2d580987,0x248905b0}},	//   лася_, _qasa, лись_, tyam_,
   {{0x5b153385,0x6d5d3386,0x7bc53387,0x7bdc0083}},	// [1ef0] имат, _vasa, tohu, _bhru,
   {{0x6d5d3388,0x25a93389,0x7bdc0c64,0x2489338a}},	//   _wasa, sial_, _chru, ryam_,
   {{0x6d5d338b,0x443f811e,0x7ceb8019,0xd2510c3b}},	//   _tasa, ztu_, _körü, تنا_,
   {{0x6d5d0c41,0x3d0e809a,0xbcfb338c,0xdb018216}},	//   _uasa, सरों_, _enér, vilí,
   {{0x65360158,0xe739a351,0x443fb38d,0xf3ff0187}},	//   _דארף_, вел_, xtu_, _irão_,
   {{0x61f5338e,0x8ae70d13,0xdb01b38f,0xdb0883a7}},	//   _tuzl, _бібл, tilí, sidê,
   {{0xed59b067,0x69dbb390,0x61fc8118,0x01d60264}},	//   вой_, _thue, írll, _সংসদ,
   {{0x443f9184,0x14258284,0x0d85a14a,0x7c2d336b}},	//   ttu_, адим, рлин, orar,
   {{0x443fb391,0x998480f7,0x7c2d04be,0x69c63392}},	//   utu_, _القو, nrar, voke,
   {{0x395fb393,0x4a45adf8,0x443fb394,0x25a6a268}},	//   _haus_, анов, rtu_, _emol_,
   {{0xa2cb2f52,0x69c6022e,0x395fb395,0x2fc7b396}},	//   _तुम्, toke, _kaus_, mong_,
   {{0x9f49007b,0x7c2d3397,0x39490362,0x2fc7b398}},	//   _stað_, krar, _cbas_, long_,
   {{0x69c63399,0xa2a71055,0x2d82007a,0xeb8eb39a}},	//   roke, _टेस्, _roke_, _ди_,
   {{0x7d1bb39b,0x395f81c5,0x2fc784d2,0x442d906f}},	//   laus, _laus_, nong_, mre_,
   {{0x66e61198,0xeab00a49,0xdee60b9c,0x69c60010}},	//   рова, _কর্ম, рови, poke,
   {{0x7ceb8b06,0x2fc7840a,0x7d0d339c,0x442db39d}},	//   _görü, hong_, gbas, ore_,
   {{0x2fc7b39e,0x7c2d0baf,0x6db7012b,0x6d44339f}},	// [1f00] kong_, grar, pćan, rfia,
   {{0x442db3a0,0x6b83b3a1,0x2fc7b3a2,0xb6a61dba}},	//   ire_, _jong, jong_, _виол,
   {{0x6f1c2db0,0x6b83b3a3,0x442db3a4,0x2fc782b8}},	//   marc, _mong, hre_, dong_,
   {{0xd94693b4,0x442db3a5,0x7d1b87ac,0x6f1c33a6}},	//   реди, kre_, jaus, larc,
   {{0x61e281b9,0x395f8282,0x7c2d002e,0x442db3a7}},	//   rmol, _daus_, crar, jre_,
   {{0x442d8e1c,0x2fc7b3a8,0x442033a9,0x7996031d}},	//   dre_, gong_, msi_, _llyw,
   {{0xd5ba9e72,0x395f8282,0xf8d327fb,0x6d4781a1}},	//   кси_, _faus_, _सर्प, đjan,
   {{0x442db3aa,0x44200190,0x6f1c33ab,0x6b839e73}},	//   fre_, osi_, harc, _aong,
   {{0x57eaa351,0x442d888b,0x6b83b3ac,0x2fc78bf2}},	//   _адам_, gre_, _bong, bong_,
   {{0x442033ad,0x46a68098,0xbea68221,0x2fc7b3ae}},	//   isi_, _казв, _казк, cong_,
   {{0x6b83b3af,0x442db3b0,0x6440b3b1,0x6f1c33b2}},	//   _dong, are_, stmi, darc,
   {{0x442db3b3,0x442033b4,0x8c46875a,0x7d1b8051}},	//   bre_, ksi_, _веде, caus,
   {{0x6f1c2bf7,0xfce68abe,0x442033b5,0x6b83907c}},	//   farc, _тодо, jsi_, _fong,
   {{0x6f1c33b6,0x7c2d0012,0x8c1b83c8,0x6b83821e}},	//   garc, vrar, _יודי, _gong,
   {{0x7c22b3b7,0x7bc8b3b8,0x61418019,0x316033b9}},	//   _hvor, modu, náló, _faiz_,
   {{0x4420022e,0x44f533ba,0x39151bf5,0x527b84de}},	//   fsi_, спас, _умир, _ינוא,
   {{0x2fc784d2,0x7d0d33bb,0xe4e7035f,0x6b83b3bc}},	// [1f10] yong_, rbas, рівн, _yong,
   {{0x7c2d33bd,0x6f1c33be,0x395fb3bf,0xd9bf83eb}},	//   rrar, carc, _saus_, एक्ट,
   {{0x395fb3c0,0x442033c1,0x2bbe0424,0x442d8061}},	//   _paus_, asi_, ्तजा, zre_,
   {{0x442db3c2,0x2fc7833e,0x442033c3,0xdb088722}},	//   yre_, wong_, bsi_, sidè,
   {{0x442033c4,0x2fc7843c,0x557600be,0x395f81c0}},	//   csi_, tong_, _הערן_, _vaus_,
   {{0x442db3c5,0x645d33c6,0x7d02b3c7,0x06b280ab}},	//   vre_, _issi, _afos, য়েছি,
   {{0x2fc782e8,0x22950013,0xa6c996fe,0x7c22b3c8}},	//   rong_, _الأس, ылка_, _avor,
   {{0x6b83b3c9,0x56b80039,0x2fc7b3ca,0x6f1c33cb}},	//   _song, יפון_, song_, zarc,
   {{0x442daa26,0x6b83b3cc,0x7f8b0201,0x2fc7b3cd}},	//   ure_, _pong, _hüqu, pong_,
   {{0x442d8625,0x291db3ce,0x31600ad4,0x7c22a9b4}},	//   rre_, lawa_, _saiz_, _dvor,
   {{0xa2ca816f,0x442d8019,0x6f1c33cf,0xb17b0502}},	//   _सुद्, sre_, varc, rmån,
   {{0x442da6ce,0x291db3d0,0x442033d1,0xd00a1d5c}},	//   pre_, nawa_, ysi_, леме_,
   {{0x6f1c33d2,0x8d5a8039,0x44200085,0x31601e03}},	//   tarc, _תכני, xsi_, _vaiz_,
   {{0x291d9cdf,0x6b838010,0x6b9a8a11,0x7643808e}},	//   hawa_, _uong, chtg, otny,
   {{0x291db3d3,0x645d213b,0x7c228253,0x2d9628e6}},	//   kawa_, _assi, _zvor, брас,
   {{0x44202557,0x6da31e81,0x6f1c33d4,0x2b4a008e}},	//   tsi_, писа, sarc, _sbbc_,
   {{0x7b068065,0x442033d5,0x291db3d6,0x249f82ce}},	// [1f20] _érté, usi_, dawa_, nzum_,
   {{0x442030a7,0xa91db3d7,0xa3dd80d4,0x61e60b81}},	//   rsi_, _roža, _थीम_, lmkl,
   {{0x645d33d8,0x25adb3d9,0xdb070019,0x60dbb3da}},	//   _essi, kiel_, ámár, _azum,
   {{0x291db3db,0x38668067,0xa91d90d1,0xf1a5835f}},	//   gawa_, tvor_, _poža, орін,
   {{0x53c787e6,0x442033dc,0x25ad81ac,0x6d5633dd}},	//   रकाश, qsi_, diel_, meya,
   {{0x60db8267,0x38cb803d,0xd8d700be,0x3f858140}},	//   _dzum, دامی_, זונט_, _colu_,
   {{0x25ad82d8,0x291d985b,0x3f8585aa,0x7c22b3de}},	//   fiel_, bawa_, _dolu_, _svor,
   {{0x656433df,0x2d8033e0,0xd94397c8,0xdd978084}},	//   ndih, njie_, _неси, йшы_,
   {{0x91e38758,0x644433e1,0x7643b2bb,0x61f89123}},	//   _хоте, ntii, atny, _suvl,
   {{0x5c5b00be,0x69df00f1,0x3f858390,0x2902009a}},	//   נדיק, _shqe, _golu_, ecka_,
   {{0xa91d9234,0x64d506a7,0x25ad9695,0x6d56010c}},	//   _možn, _दर्श, biel_, keya,
   {{0x7c2284e8,0x25adb3e2,0x64440406,0x7bc8b3e3}},	//   _tvor, ciel_, ktii, sodu,
   {{0x399b020f,0xa3d805fb,0x3f858059,0x2d8001b0}},	//   _nëse_, ाता_, _yolu_, djie_,
   {{0x0a948d13,0x291db3e4,0xdbf1001b,0x2ca0026c}},	//   _малю, zawa_, _příl, dzid_,
   {{0x569433e5,0xa14380eb,0x291d801d,0xfdc406a7}},	//   парт, šķir, yawa_, वकूफ,
   {{0x6d5633e6,0x644401b4,0x69cd33e7,0x6d9c8174}},	//   geya, ftii, _ukae, _déag,
   {{0x5fba941b,0x2129036e,0x4dd401a8,0x765e06c4}},	// [1f30] ेवाल, _idah_, ستفس, _espy,
   {{0xdea404c0,0x291db3e8,0x6f1ab3e9,0x25adb3ea}},	//   _کیفی, wawa_, _netc, ziel_,
   {{0x291db365,0x6d5633eb,0xd6d9003d,0x72b901a8}},	//   tawa_, beya, _خودش_, جهاز_,
   {{0x6ab90beb,0x291d804f,0x8f5500d7,0x644433ec}},	//   _आशीर, uawa_, _انگش, btii,
   {{0x291db3ed,0xf7708416,0x6d9c80f7,0x25adb3ee}},	//   rawa_, کان_, _méad, viel_,
   {{0x291db3ef,0x6d4b8359,0x25ad9699,0x8afe8326}},	//   sawa_, _sbga, wiel_, _yaƙe,
   {{0x2902016d,0xfebb815b,0x62341138,0x66e28048}},	//   ycka_, داشت_, _неру, моша,
   {{0x200903ac,0x7dc58019,0x236333f0,0x7643b3f1}},	//   _otai_, lósz, _hajj_, rtny,
   {{0xa2b901b6,0x25adb3f2,0x60dbb3f3,0x92e680ab}},	//   ्थव्, riel_, _uzum, যুৎ_,
   {{0x42259895,0x212900dd,0xb17b0f91,0x25adb3f4}},	//   одов, _adah_, smål, siel_,
   {{0x80d100c8,0x25adb3f5,0x09b580be,0x6d5633f6}},	//   সেম্, piel_, ַפֿט_, yeya,
   {{0x6d9cb3f7,0x64440198,0xbc758a19,0xdb038f35}},	//   _réag, ytii, _وهاب, _imní,
   {{0xe45f025d,0x6d5633f8,0x10a30162,0x65642ded}},	//   _myös_, veya, диян, vdih,
   {{0x69cbb3f9,0x212900ee,0x1af38264,0x6d498174}},	//   hoge, _edah_, _আজকে_, lfea,
   {{0x59c9885d,0xba778077,0x2d80079f,0xb8d108af}},	//   िकार, _داشت, tjie_, _टे_,
   {{0x64440364,0x753ba4d4,0xf50a33fa,0x29d901a8}},	//   ttii, nguz, рнал_, néal_,
   {{0x92d600c8,0x6d5633fb,0xd46718a0,0x3b8624dd}},	// [1f40] _হলে_, reya, оите_, олаг,
   {{0x32d6324a,0xa91db3fc,0x644433ec,0x213f80dd}},	//   оцес, _božo, rtii, _acuh_,
   {{0xe8fa9777,0x644433fd,0x8b0780fc,0x69cb9a1c}},	//   але_, stii, _taƙƙ, foge,
   {{0x6f1a82e6,0x69cbb3fe,0x644433ff,0x7d1f011c}},	//   _setc, goge, ptii, caqs,
   {{0xe0568277,0xa91d807a,0x29d901a8,0x386001b9}},	//   تخاب, _tožn, déal_, _jsir_,
   {{0x44320114,0x7c240834,0x7d043400,0x9e06818b}},	//   mry_, msir, lcis, очил,
   {{0xdd9a9617,0x41ca1299,0x69cbb401,0xbf9b0036}},	//   иши_, रवास, boge, mpêt,
   {{0x69cbb402,0xed59939c,0x7d043403,0x44323404}},	//   coge, kožu_, ncis, ory_,
   {{0x7c243405,0xdb1e006a,0xc31e80ab,0x6d9c81a8}},	//   nsir, ropæ, _দাবি_, _réad,
   {{0x77928077,0x7c243406,0x44320748,0x926aa8c4}},	//   _زیبا, isir, iry_, арма_,
   {{0x9d46817a,0x20093407,0x4432016b,0xe3b8b408}},	//   _межд, _stai_, hry_, rnı_,
   {{0x443201b0,0x7c240304,0x963385e9,0xa194102a}},	//   kry_, ksir, _ініц, даюч,
   {{0x92d600c8,0xa2ca800c,0x9f4c801b,0x7c240503}},	//   _হলো_, _सुर्, _lidí_, jsir,
   {{0x442680ce,0x69cb82af,0xc05800e8,0x09b79053}},	//   _ivo_, zoge, цію_, _अद्य,
   {{0x69cb82ec,0x4426b409,0xddab0087,0x61fc0965}},	//   yoge, _hvo_, атал_, _nurl,
   {{0x2129035a,0x7c24340a,0x4432015c,0x2bbf28e1}},	//   _udah_, fsir, fry_, ्वभा,
   {{0xb9c40013,0x6fca8540,0x78a288ae,0x3959340b}},	// [1f50] _تقيي, ाकां, jzov, mess_,
   {{0x09b3853e,0x69cb8365,0x63ba81ec,0x3959340c}},	//   ंच्य, woge, nntn, less_,
   {{0xe7f9016f,0x4432340d,0x46d20cfd,0x69cbb40e}},	//   ंदवा_, ary_, _दुपह, toge,
   {{0x44268025,0xe1f80110,0x3959340f,0x7d0423a5}},	//   _ovo_, ігі_, ness_, ccis,
   {{0x18698258,0xa2cb3410,0xf994025f,0x8caa81a2}},	//   сали_, _तुर्, ורף_, _जेलो,
   {{0x7d1d1831,0x23fa0039,0x69cbb411,0xbdf81190}},	//   _hess, _להשא, soge, _دریا_,
   {{0x61fc1486,0xc7b40039,0xa3d800d4,0xa2ca850a}},	//   _gurl, ובס_, ातर_, _सुल्,
   {{0xc4858785,0x4c8586e6,0xf1c004e8,0x673c0140}},	//   злик, злив, čák_, zgrj,
   {{0x7d1d114e,0xe3b1803f,0x937980f7,0x29d900e7}},	//   _mess, فرد_, مصدر_, réal_,
   {{0xf8ae80d5,0x29dc85a4,0x798980c9,0x7d1d0a85}},	//   _حکم_, nían_, _hoew, _less,
   {{0x4426803a,0x799bb412,0xdb0888f1,0x8a058110}},	//   _evo_, _kluw, cidí, язне,
   {{0x7d1d1927,0x76470366,0xe61080d7,0xc7a901c6}},	//   _ness, dtjy, _ششم_, _גב_,
   {{0xb4fa8039,0x764b8110,0x92b58fd3,0xdb01862c}},	//   _הפני, žnyč, تحکا, tilä,
   {{0xfaa5a302,0x44323413,0xed5981c8,0x6dac02d0}},	//   _нало, vry_, lež_, rşam,
   {{0x70b89513,0x7d1d02af,0x29dc85e4,0xa2cb01d0}},	//   _अश्ल, _bess, dían_, _तुल्,
   {{0xf99f3414,0x39593415,0x7c243416,0x7d1d3417}},	//   chè_, cess_, tsir, _cess,
   {{0x7d1d3418,0x38603419,0x8afe89ab,0x7d04341a}},	// [1f60] _dess, _usir_, _haƙa, rcis,
   {{0x4432341b,0xa01b0009,0x8afe8326,0xe7f9341c}},	//   rry_, pyör, _kaƙa, ंदरा_,
   {{0x4efb0051,0xe7170051,0x7c24341d,0x61e4341e}},	//   _להיו, _מחיר_, ssir, _khil,
   {{0xc693093f,0xd7fa8676,0x7d1d341f,0xdb08a99b}},	//   _נאר_, бук_, _gess, vidí,
   {{0x29dc82ba,0x61e40c41,0xed59915c,0x8afe89ab}},	//   bían_, _mhil, dež_, _laƙa,
   {{0xc7a38226,0xa2a73420,0x29dc85e4,0x8fa3a5d9}},	//   ничк, _टेक्, cían_, наче,
   {{0x442687ca,0x6566029b,0x7d1d3421,0xdb1e01ec}},	//   _svo_, _kakh, _yess, ropä,
   {{0x2abb0039,0x2d9fb422,0x4426929b,0x25a0008e}},	//   _המלא, ghue_, _pvo_, nhil_,
   {{0x3a3a04b7,0x212209c4,0xdb08ad84,0xf0448fd3}},	//   lupp_, dakh_, sidí, _تعزی,
   {{0xe44f8013,0x6566005d,0x6f1e011f,0x8afe89ab}},	//   اضي_, _lakh, _nepc, _baƙa,
   {{0x395904b7,0x25a00d8b,0x61e40c41,0xfbab8035}},	//   tess_, khil_, _bhil, टोधम,
   {{0x61e43423,0x65663424,0x4426808b,0x867b81c6}},	//   _chil, _nakh, _tvo_, _לרבו,
   {{0x7d1d3425,0xa91da847,0x4426b426,0x39593427}},	//   _ress, _božj, _uvo_, ress_,
   {{0x6d9c8013,0x7d1d3428,0x39593429,0x656601b4}},	//   _féac, _sess, sess_, _aakh,
   {{0x7d1d00a9,0x6566005d,0xd3e582e3,0x29dc8511}},	//   _pess, _bakh, _تقوی, vían_,
   {{0x61e4342a,0xbcfb03a8,0xdb08823e,0x98b901a9}},	//   _ghil, _gaél, lidà, nesī_,
   {{0x6ecd0f12,0x6c54096f,0x29dc8511,0x69cf016b}},	// [1f70] _दुरु, нкту, tían_, moce,
   {{0x7d1d0123,0x69c08115,0x8afe89ab,0x889c01c6}},	//   _wess, _ajme, _yaƙa, _לבחי,
   {{0x29dc840e,0x7d1d342b,0xecf905e9,0xbb8400f7}},	//   rían_, _tess, _менш_, علمي,
   {{0x6f1e342c,0x25a000f3,0x69cf2d12,0xc2c40174}},	//   _zepc, chil_, noce, ريني,
   {{0xa3ccb42d,0x1b2280ab,0x6d4d008e,0x237800fe}},	//   लवा_, _মানে_, mfaa, _fnrj_,
   {{0x2d8b05f5,0x6566005d,0x6d4d342e,0xceba80fc}},	//   _hoce_, _zakh, lfaa, waƙa_,
   {{0x6566029b,0xb8f4ac17,0x6b83007b,0x443b342f}},	//   _yakh, _सु_, öngu, luq_,
   {{0x6d4d0763,0x6d9c80e7,0x799b80dd,0x2d8b3430}},	//   nfaa, _réac, _uluw, _joce_,
   {{0xcc8980d7,0x8afe8326,0x3f818338,0xafdb0646}},	//   زنده_, _saƙa, öhus_, rtøj,
   {{0x61e43431,0x2d8b002a,0x69d981ec,0x7d038061}},	//   _shil, _loce_, llwe, _bíró,
   {{0x52db3432,0x61e43433,0x7e7e816d,0xed598259}},	//   _भरोस, _phil, äppt, pež_,
   {{0x6723b434,0x2d8b3435,0x69cf3436,0xdb08841c}},	//   lanj, _noce_, goce, tidã,
   {{0x65663437,0xa3bf27cf,0x81c200ab,0x8afe89ab}},	//   _rakh, ुका_, ্গল_, _waƙa,
   {{0x82358bca,0x6723b438,0xe299b439,0x61e40051}},	//   _قربا, nanj, _мал_, _whil,
   {{0x61e4343a,0x2d8b012b,0x6d4d343b,0x25a00642}},	//   _thil, _boce_, ffaa, thil_,
   {{0x6723b43c,0x291f822c,0x6569b43d,0x68fbb43e}},	//   hanj, _neua_, ndeh, _ngud,
   {{0x6449b43f,0x6723b440,0x2d8b3441,0xbfc623a4}},	// [1f80] ntei, kanj, _doce_, _обик,
   {{0x61b899eb,0x65663442,0xd9b886ce,0x212d80b9}},	//   ेक्ष, _wakh, ेक्ट, _adeh_,
   {{0x23678353,0x64499bf3,0x35a60071,0x65663443}},	//   _manj_, htei, _жанг, _takh,
   {{0xe0dab444,0x2d8b31b8,0x3a3a3445,0x6449b446}},	//   ове_, _goce_, rupp_, ktei,
   {{0x26039220,0xdcb90364,0x4fc69597,0xc7c697c8}},	//   _año_, _ещё_, мска, мски,
   {{0x09bb0519,0x31bb2296,0x6d42802e,0x65698fb0}},	//   _उद्य, _उद्ध, _scoa, edeh,
   {{0x9f4c8118,0x6e3c0144,0xc34e80ff,0x45d49860}},	//   _cidá_, nurb, _bổng_, нокс,
   {{0x717683f8,0xc34e801c,0x6449b447,0x68fb85ee}},	//   _تهرا, _cổng_, ftei, _ggud,
   {{0xe043b448,0x29e88085,0x69cf3449,0x3944841c}},	//   _инти, _uşaq_, voce, _icms_,
   {{0x6723803a,0x96968098,0x547b03de,0x7524344a}},	//   canj, _ореш, קטיו, haiz,
   {{0x69cf344b,0xa3e606b7,0xd3370039,0xa2948d8e}},	//   toce, _पठन_, וריה_, хані,
   {{0x3872119b,0x7c3bb44c,0x7524026c,0x443b011c}},	//   _bryr_, buur, jaiz, yuq_,
   {{0x14e2a594,0x3f8cad05,0x2d8b001b,0xdb1c07d3}},	//   _परिण, _kodu_, _roce_, _skrý,
   {{0xeaaf8416,0x61ee01ac,0xac978077,0xd90f015b}},	//   اعی_, _ďale, _تنها_, دیک_,
   {{0x2bbf14d5,0x3f8cb44d,0xdce28754,0x9f458118}},	//   ्वसा, _modu_, _maoč, _pilú_,
   {{0x23678838,0xa2ad800d,0x7bdab44e,0x693601d0}},	//   _zanj_, ुपर्, lltu, _přež,
   {{0x2d8b163e,0xf1bf026f,0x3375344f,0x6723b450}},	// [1f90] _voce_, mná_, нгар, yanj,
   {{0xdce285f5,0xf1bf027f,0xa3e48054,0x291f8722}},	//   _naoč, lná_, _भीम_, _seua_,
   {{0x6e3c2dd5,0xaad486a7,0xe3c300ab,0x2d8b0037}},	//   curb, _ठुमक, ্গলব, _toce_,
   {{0x59f9893f,0xf1bf3451,0xa91d96f2,0x6723aa5a}},	//   פּעד, nná_, _koži, wanj,
   {{0x67238025,0x443b0085,0x3f8c816b,0x64499500}},	//   tanj, quq_, _bodu_, xtei,
   {{0xf77180f7,0xa3dd809a,0x66e58071,0x28b201a2}},	//   طات_, _थीं_, нола, ीपति,
   {{0x6723b452,0x92c280ab,0xe91980e8,0xa91da1d1}},	//   ranj, ্ধু_, _нові_, _loži,
   {{0x6449b453,0xf1bf05b9,0x6d40b454,0x212d82f7}},	//   ttei, jná_, ggma, _udeh_,
   {{0x44290788,0xf1bf0775,0x236799ba,0xa91d8450}},	//   nsa_, dná_, _panj_, _noži,
   {{0x44293455,0x6449b456,0x2d8280f2,0x7c3b8079}},	//   isa_, rtei, öker_, ruur,
   {{0xd9460d0e,0xc34e8028,0xfbd20039,0x44293457}},	//   нени, _tổng_, רתי_, hsa_,
   {{0x3f878024,0xaca381bc,0x569486c8,0x6449b458}},	//   ljnu_, _ajụk, _шахт, ptei,
   {{0xaacf885d,0x44291554,0xb9081404,0x25bf802e}},	//   _सुरक, jsa_, _भर_, mnul_,
   {{0x6601b459,0xe8df8135,0x7d09b45a,0x4429345b}},	//   _kulk, _arịa_, lces, dsa_,
   {{0x44292e31,0x66018364,0x7c29b45c,0xf1bf026f}},	//   esa_, _julk, lser, bná_,
   {{0x660180a4,0xf1bf016b,0xe7e002f1,0x6d9c9e6a}},	//   _mulk, cná_, _खीरा_, _léan,
   {{0x7c29b45d,0x4429345e,0x64a31597,0xdca31b8b}},	// [1fa0] nser, gsa_, гата, гати,
   {{0xa3c1800f,0x6721843d,0xf40180c8,0x68e4345f}},	//   ्कि_, _nelj, _এবার_, _izid,
   {{0x44293460,0x1b1f00ab,0xdb1c0035,0x7d098035}},	//   asa_, _পাশে_, _skró, kces,
   {{0x7d0980d2,0x44293461,0xf1a99f33,0x3f8cb462}},	//   jces, bsa_, وانه_, _sodu_,
   {{0x1b1f00c8,0x44293463,0xe814016f,0x6721b2b2}},	//   _পারে_, csa_, तीचा_, _belj,
   {{0x6d9c80f7,0x7c29b464,0x67218353,0x7dde80f1}},	//   _céan, dser, _celj, tëso,
   {{0x6d9c8307,0xa3b501d2,0xa3bf0a61,0x6721b465}},	//   _déan, _जगत_, ुकर_, _delj,
   {{0xa2ca8a75,0x7dde80f1,0x7bc3b466,0x66018084}},	//   _सुग्, rëso, _ajnu, _dulk,
   {{0x6d460358,0x7c29b467,0xf1bf0a21,0xb7da9f54}},	//   _mcka, gser, vná_, _فورا_,
   {{0xc45380f7,0x6d9c8b6a,0x1fb58195,0x69d63468}},	//   اضيع, _géan, _исхр, _akye,
   {{0xf1bf003e,0x7c2985ee,0x7dde8168,0x533700be}},	//   tná_, aser, qëso, ענטן_,
   {{0x44293469,0x672180d2,0xa91db46a,0x7d09a43c}},	//   ysa_, _zelj, _poži, cces,
   {{0x55778158,0xf1bf003e,0xa3d019a1,0x6601b46b}},	//   _רעדן_, rná_, शवा_, _zulk,
   {{0xe47b812a,0xf1bf026f,0x4429006a,0x5c978a8e}},	//   _מרדכ, sná_, vsa_, _якія_,
   {{0xf1bf026f,0x67e00106,0x68e401f6,0x6be381a8}},	//   pná_, möjl, _ezid, _حكوم,
   {{0x4429346c,0x13d580ab,0xa3e48beb,0xa91d82d4}},	//   tsa_, _হওয়, _भीत_, _toži,
   {{0x24580009,0x41c40c3b,0x442b346d,0x98b90084}},	// [1fb0] нать_, _حقيق, _qvc_, mesį_,
   {{0x69dd0014,0x23a4016d,0x236a0144,0xf11980c2}},	//   llse, _nöjd_, _cabj_, दर्द_,
   {{0x4429346e,0xa2d40ebf,0x3a3e82f7,0x290b0037}},	//   ssa_, _बुद्, nutp_, occa_,
   {{0x4429346f,0xc984ac60,0x5184b470,0x7c29b471}},	//   psa_, лучи, луча, yser,
   {{0x34940196,0x657d3472,0x6601b473,0x44293474}},	//   _баяр, _insh, _sulk, qsa_,
   {{0x66019e52,0x6d5f13de,0x7c29b475,0xb17b0338}},	//   _pulk, leqa, vser, llåd,
   {{0x644d3476,0x6721b477,0xbbbf1305,0x7c29b478}},	//   ltai, _velj, ्वीक, wser,
   {{0x6d5f20d8,0x7c29b479,0x6727347a,0x644d347b}},	//   neqa, tser, hajj, otai,
   {{0x6721b47c,0x644d347d,0x9f5307e2,0xa3b5064d}},	//   _telj, ntai, _així_, _जगा_,
   {{0x660190c0,0x25bfb47e,0x7d0981e8,0x6727298d}},	//   _tulk, snul_, sces, jajj,
   {{0x644d347f,0x7c29b480,0x2d890681,0x34de0ebf}},	//   htai, sser, kjae_, _मर्द,
   {{0xe2968554,0x644d3481,0x60dbb482,0x61fbb483}},	//   таю_, ktai, _kyum, _jiul,
   {{0x6d5f0748,0x2ca9076c,0x656d01b4,0x8c45951b}},	//   deqa, jzad_, ddah, _реле,
   {{0x656b8013,0x644d3484,0x2d8f8a0f,0x69dd0074}},	//   _hagh, dtai, _hoge_, alse,
   {{0x443fb485,0x644d0084,0x6d460122,0x9f4581a8}},	//   luu_, etai, _pcka, _chlé_,
   {{0xdde9003d,0x2d8fb486,0xfce615a6,0x656d3487}},	//   فرقه_, _joge_, вобо, gdah,
   {{0x60dbb488,0x656bb489,0x443fb48a,0xdb1a816a}},	// [1fc0] _nyum, _magh, nuu_, cotó,
   {{0x4e0608cc,0x656bb48b,0x657d0c2e,0x22ba1f31}},	//   _изоб, _lagh, _ensh, وداع_,
   {{0x23a400f2,0x644d032f,0x6a860098,0x3ea6217b}},	//   _nöje_, atai, ължа, _ринг,
   {{0x443fb48c,0x61e9b48d,0x656bb48e,0xc05a90ac}},	//   kuu_, _chel, _nagh, дік_,
   {{0xd0078698,0x92bd80c8,0xd94395ac,0x61fb8b20}},	//   вече_, _আরো_, речи, _diul,
   {{0xdefa81a0,0x6d44348f,0x244b806a,0x443f8079}},	//   мый_, lgia, døm_, duu_,
   {{0x764e3490,0x64598176,0x61fb8162,0xacbb0866}},	//   ntby, _apwi, _fiul, _jeûn,
   {{0x6d443491,0x61fbb492,0x2d8fb493,0x61e9b494}},	//   ngia, _giul, _coge_, _ghel,
   {{0x80e101fe,0x656bb495,0x443fb496,0x9f4c8198}},	//   _नरें, _dagh, guu_, _pidä_,
   {{0x6d44237d,0xb4e28127,0x5fb68074,0xa91d8115}},	//   hgia, _धरी_, _अगिल, _dožu,
   {{0x75228267,0x46d23497,0x656bb498,0x19950a4c}},	//   _teoz, _दुलह, _fagh, ганя,
   {{0x2004a4d4,0x80d100ab,0x61e980f1,0x656b8870}},	//   _kumi_, _সৃষ্, _xhel, _gagh,
   {{0x8c4380e9,0x1d079634,0x656d3499,0xb17b0106}},	//   _вече, _речи_, vdah, vlåd,
   {{0xa2cb016f,0x656bb49a,0x6440b49b,0x2004b49c}},	//   _तुझ्, _zagh, mumi, _mumi_,
   {{0x6440b49d,0xa3c18128,0x6d9c80f7,0x2004b49e}},	//   lumi, ्कर_, _léam, _lumi_,
   {{0x6d440698,0xa2b804c5,0x644d0364,0xa3b50740}},	//   ggia, ्पन्, ttai, _जगह_,
   {{0x6d9c94e1,0x6440b49f,0x656d34a0,0x644d051e}},	// [1fd0] _réal, numi, rdah, utai,
   {{0x644d34a1,0x6d5f05e7,0x61fbb4a2,0xbbbf000c}},	//   rtai, seqa, _siul, ्वेक,
   {{0x6440822e,0x61e9b4a3,0x644d34a4,0x60db80ee}},	//   humi, _phel, stai, _syum,
   {{0x656d02ed,0x6440b4a5,0x20049e92,0x99d180ab}},	//   qdah, kumi, _bumi_, িষ্ক,
   {{0x443f82c1,0x64408029,0x7c841bbf,0x656bb4a6}},	//   xuu_, jumi, _куре, _ragh,
   {{0x6440b4a7,0xb60583cb,0x7d0d34a8,0x2004b4a9}},	//   dumi, hláš, lcas, _dumi_,
   {{0x656b97ef,0x99678d69,0x61e9b4aa,0x28da10be}},	//   _pagh, _итал, _thel, _युनि,
   {{0x4efc0051,0x443fae79,0x3949022c,0xa91d812b}},	//   ולוג, tuu_, _ncas_, _požu,
   {{0x6440b4ab,0xa3d8016f,0xa3c18aed,0x60db8bdf}},	//   gumi, ातच_, ्कल_, _uyum,
   {{0x443fb4ac,0x244b8aa2,0xceeb92c8,0x7d0d0362}},	//   ruu_, røm_, _قران_, hcas,
   {{0xe299b4ad,0x38693335,0x656bb4ae,0x2d8f933b}},	//   хан_, _asar_, _tagh, _toge_,
   {{0x98b20201,0xe5708c2a,0x6440b4af,0x443fb4b0}},	//   _sayı_, _وطن_, bumi, puu_,
   {{0x7d1bb4b1,0xad9b1d64,0x6440925c,0x7c2d0338}},	//   mbus, _miúd, cumi, jsar,
   {{0x442db4b2,0x7c2d0bbd,0x6a7781bc,0x39490580}},	//   mse_, dsar, _ụfo, _ecas_,
   {{0x442db4b3,0xed5a1928,0xd5ac8065,0x386902c4}},	//   lse_, нов_, _رہی_, _esar_,
   {{0xceb283c8,0x442db4b4,0x29000118,0x69c38061}},	//   צין_, ose_, _ugia_, énel,
   {{0x442db4b5,0x69db0158,0x707700f7,0x7c3b802a}},	// [1fe0] nse_, _אַזו, _مميز_, nrur,
   {{0x442db4b6,0x6d9c80f7,0x1c1ba967,0x442fb4b7}},	//   ise_, _réam, पीएल_, _mvg_,
   {{0x6440b4b8,0x442db4b9,0x77f70039,0x2004b4ba}},	//   zumi, hse_, _תמיד_, _sumi_,
   {{0x442db4bb,0x9f5a06c0,0x7d0d00e5,0xaca384be}},	//   kse_, _sipè_, ccas, _akọk,
   {{0x64e2823c,0x442db4bc,0x25d70039,0x69c2b4bd}},	//   _परेश, jse_, _תוכן_, rnoe,
   {{0x38cb91fb,0x442db4be,0xb7d280ab,0x6440b4bf}},	//   رانی_, dse_, াষ্ট, vumi,
   {{0xfaa62e78,0x7bcb31cf,0x499482e3,0x316d80b9}},	//   _саво, égue, _پیشر, _faez_,
   {{0x6440b4c0,0x6d9c80f7,0x62810088,0x7d1bb4c1}},	//   tumi, _téam, _šlog, gbus,
   {{0x5b26abef,0xd326976a,0x442db4c2,0xb99380f7}},	//   льна, льни, gse_, _القب,
   {{0x6440b4c3,0xf366a43b,0x3946b4c4,0xaca401bc}},	//   rumi, утин, lgos_, _nsọt,
   {{0x442db4c5,0x7c2d0029,0xafdb0aa2,0x7dde8168}},	//   ase_, zsar, ktør, hësi,
   {{0x3946b4c6,0xdb01b4c7,0x7dde8168,0xaca4046d}},	//   ngos_, filó, kësi, _asọt,
   {{0x7c3b802e,0x7d028135,0xc5f38039,0x442db4c8}},	//   crur, _igos, _הדף_, cse_,
   {{0x6ed61d41,0x66051ea9,0xb8fd3497,0xb8dd03b7}},	//   _मुहु, _puhk, _तँ_, _आध_,
   {{0x442234c9,0x7c2d01e0,0x394900b9,0x7dde8168}},	//   _awk_, wsar, _tcas_, tësh,
   {{0x63ba83cb,0x7c2d34ca,0x4422036e,0x27ec80ee}},	//   litn, tsar, _bwk_, _lhdn_,
   {{0x386903aa,0x7d0d17d6,0x69c382be,0x26de808e}},	// [1ff0] _usar_, rcas, énem, _lyto_,
   {{0x212b34cb,0x3946b4cc,0x63baa1f8,0x798083ec}},	//   lach_, egos_, nitn, _anmw,
   {{0x7c2d34cd,0x61ed1b5e,0x8afe8300,0x316d8144}},	//   ssar, _khal, _baƙi, _paez_,
   {{0x212b34ce,0x7d02b4cf,0x7c2d34d0,0x442db4d1}},	//   nach_, _ngos, psar, yse_,
   {{0x39498029,0x1869817c,0xa069b4d2,0x61ed125b}},	//   ļas_, тали_, тала_, _mhal,
   {{0x212b0083,0x656f34d3,0x25a934d4,0xe736b4d5}},	//   hach_, _hach, lhal_, аеш_,
   {{0x656f34d6,0x212b198a,0x244f0457,0x7c2284be}},	//   _kach, kach_, lüm_, _awor,
   {{0x442db4d7,0x629a8d42,0x212b0035,0x2bbf0b84}},	//   tse_, dyto, jach_, ्वका,
   {{0x212b34cb,0x291db4d8,0x656f34d9,0x442db4da}},	//   dach_, mbwa_, _mach, use_,
   {{0x656f34db,0xe7a983bb,0x7d028870,0x61ed011e}},	//   _lach, _कतिप, _egos, _ahal,
   {{0x61ed34dc,0x26e4000d,0x4acf99a1,0xf98617c7}},	//   _bhal, _गरेर_, _सुखव, агно,
   {{0x656f34dd,0x442db4de,0x212b34df,0x3f81311a}},	//   _nach, pse_, gach_, _anhu_,
   {{0x7643b4e0,0x61ed02c1,0x15f484e3,0x25a905a1}},	//   luny, _dhal, _اسلح, dhal_,
   {{0x629ab4e1,0x656f34e2,0xdca28fc8,0x63ba9b4e}},	//   byto, _aach, _фаши, citn,
   {{0xb8fd0935,0x645d0110,0x212b34e3,0x39468110}},	//   _तु_, _apsi, bach_, ygos_,
   {{0x7dde820f,0x61ed34e4,0x3d20009a,0x25a901e4}},	//   tësi, _ghal, बरें_, ghal_,

   {{0x656f34e5,0x7643b4e6,0x8c46143b,0x044600e8}},	// [2000] _dach, huny, резе, резн,
   {{0x7dde820f,0x656f0ad0,0x7643b4e7,0xd76402e3}},	//   rësi, _each, kuny, _اندی,
   {{0x320787e2,0x656f34e8,0x34e28b04,0x764389ca}},	//   _juny_, _fach, _पर्द, juny,
   {{0x656f34e9,0x25a91054,0x39468110,0xd2e603a4}},	//   _gach, chal_, ugos_, _करीब_,
   {{0x39469e31,0x7dde80f1,0x8eb3003d,0x2d820326}},	//   rgos_, qësi, _همیش, _inke_,
   {{0x656f0f66,0x81bd0029,0x394685a4,0x6d59b4ea}},	//   _zach, lsēt, sgos_, _abwa,
   {{0x76438dc4,0x8afe8326,0x56948705,0x798085ee}},	//   guny, _taƙi, сайт, _tnmw,
   {{0x6d5606c0,0x645d00e5,0x25a034eb,0x63bab4ec}},	//   nfya, _ypsi, nkil_, witn,
   {{0x88bd8063,0x2fd8016d,0x7763ada4,0xdb1aa631}},	//   _jeśl, korg_, benx, entá,
   {{0x61ed34ed,0x29120010,0x386980f1,0x26de801b}},	//   _shal, _afya_, çare_, _tyto_,
   {{0x212b34ee,0xc333078d,0x76439481,0x7ac69509}},	//   tach_, חות_, cuny, рспе,
   {{0x7d028025,0x7c22809a,0x29dc8511,0x96958bda}},	//   _ugos, _twor, mías_, _уруш,
   {{0x212b34ef,0x29dc8511,0x6728b4f0,0xa49b0580}},	//   rach_, lías_, _kedj, _agòn,
   {{0x212b34ce,0x656f34f1,0x2d822e7c,0x644f809f}},	//   sach_, _sach, _anke_, àcie,
   {{0x61ed3249,0x6728b4f2,0x656f0e44,0x29dc8511}},	//   _thal, _medj, _pach, nías_,
   {{0x6728807d,0x61ed004f,0x656f2828,0x8afe8326}},	//   _ledj, _uhal, _qach, _saƙw,
   {{0x2fd834f3,0x656f34f4,0x25a934f5,0x61e28122}},	// [2010] borg_, _vach, rhal_, dlol,
   {{0x656f34f6,0x672882fd,0x9f5e820f,0x25a91b77}},	//   _wach, _nedj, _ditë_, shal_,
   {{0x656f34f7,0x68e98019,0x200102c4,0x20090326}},	//   _tach, _szed, _iihi_, _huai_,
   {{0x656f1a2f,0x76438aef,0x29dc85e4,0x2cad808e}},	//   _uach, vuny, días_, yzed_,
   {{0xa3e680c2,0xa2d88540,0xe7398256,0x68e0831d}},	//   पता_, _नुस्, гел_, _cymd,
   {{0x785a8029,0x7643b4f8,0x29dc82ba,0x8a170077}},	//   dāvā, tuny, fías_, _نظرا,
   {{0xf7709dd2,0x29dc85a4,0xed598d55,0x7763802a}},	//   بان_, gías_, гой_, renx,
   {{0xa3b305e8,0x764389ca,0x752d34f9,0x2fd800f3}},	//   जोर_, runy, naaz, zorg_,
   {{0xbee403bb,0x76438d6d,0x68e08114,0x8afe80fc}},	//   _गर्न_, suny, _gymd, _maƙu,
   {{0x76438886,0xed59812b,0x29dc8020,0x4a4592ea}},	//   puny, diže_, bías_, бнов,
   {{0xe1fa0396,0x29dc85e4,0x6b9534fa,0xd5758110}},	//   лго_, cías_, _mozg, _гуль,
   {{0x6d5982a0,0x200900ee,0x6728826c,0x35f5ace0}},	//   _ubwa, _buai_, _zedj, _упер,
   {{0xd24e8416,0x200900ee,0x2fd8008b,0xf1b283de}},	//   ونی_, _cuai_, torg_, לסט_,
   {{0x443fb4fb,0x200900b9,0x6d49b4fc,0xf4128039}},	//   mru_, _duai_, lgea, _צפו_,
   {{0x78c10086,0x66e634fd,0xdb1ab4fe,0x6b83b4ff}},	//   _əvvə, сова, zitë, _inng,
   {{0x6d49947d,0x29008110,0x394d81c0,0xdce4012b}},	//   ngea, žiai_, _nces_, ndić,
   {{0x6d49832f,0x69d9809a,0x7984020d,0x20093500}},	// [2020] igea, dowe, _iniw, _guai_,
   {{0x25a03501,0x443fb502,0x68e08106,0x65641f9f}},	//   skil_, iru_, _rymd, seih,
   {{0x29dc84c3,0x443fb503,0x490680f7,0x67288b80}},	//   xías_, hru_, مواق, _redj,
   {{0x5d860013,0x614691b3,0x705309d7,0xd764015b}},	//   _الحل, седа, _بنیا, _انگی,
   {{0x2056b504,0x6b95026c,0xe3b10065,0x67288088}},	//   стер, _fozg, سرے_, _pedj,
   {{0x443fb505,0x29dc91b9,0x23658267,0xfbc78481}},	//   dru_, tías_, jelj_, _رت_,
   {{0x44321486,0x443fb506,0x9f520144,0xe2970088}},	//   lsy_, eru_, _huyó_, _лар_,
   {{0x29dc960a,0x443fb507,0x98a68012,0x15fa0bb8}},	//   rías_, fru_, _либе, ्दिर_,
   {{0xdb1ab508,0x44323509,0x443fb50a,0x29dc8511}},	//   lité, nsy_, gru_, sías_,
   {{0x320a350b,0x6d498706,0x29dc8333,0x7984113b}},	//   _kuby_, agea, pías_, _aniw,
   {{0xa3d90ee6,0xdd8f8162,0x15f811bc,0x200903ac}},	//   ावत_, _еш_, ंगार_, _suai_,
   {{0x443fb50c,0x394d350d,0x7dde8168,0x25a682d5}},	//   bru_, ües_, tësu, _ulol_,
   {{0x443f8012,0x2009350e,0x8afe89ab,0x6ac4066b}},	//   cru_, _quai_, _raƙu, वपुर,
   {{0x7dde80f1,0x442684be,0x443201b0,0x33f68226}},	//   rësu, _iwo_, dsy_, _учес,
   {{0x9f5e80e7,0x3da709a8,0xdced0699,0x69d9804f}},	//   _cité_, браб, rdač, yowe,
   {{0x7bda8bd2,0xd131003d,0x200900ee,0xb88601d0}},	//   lotu, _کمک_, _tuai_, _spíš,
   {{0x6eda8076,0x7dde80f1,0xdcfd026c,0xb60689d1}},	// [2030] _पुसु, qësu, _posđ, lišć,
   {{0x6ac401c4,0x68ed350f,0x4426b510,0xa3b3009a}},	//   वपूर, _izad, _mwo_, जों_,
   {{0x69d9b511,0x3cde016f,0x7bc8b512,0xdd950196}},	//   towe, _कुठे_, indu, _даны,
   {{0x19598084,0x4426877f,0xa159b513,0x127b80be}},	//   рады_, _owo_, раду_, טאבע,
   {{0x44268091,0xf09f3514,0x69d9b515,0x7bda9619}},	//   _nwo_, nyà_, rowe, kotu,
   {{0x8cdc800f,0x645c802e,0xbcfb3516,0x01cf00ab}},	//   _पड़ो, ăril, _abég, রতিদ,
   {{0x35f803f8,0x4426b517,0xdb1a80e7,0x7bdaaf84}},	//   _خرید_, _awo_, cité, dotu,
   {{0xa2b81d6a,0x44268e4d,0xd0d58098,0x394db518}},	//   ्पर्, _bwo_, _добъ, _uces_,
   {{0x6d498068,0x443fb519,0x386d8051,0x442682f7}},	//   rgea, uru_, _user_, _cwo_,
   {{0x443f8aee,0x6d49b51a,0x212f8229,0xdb0e008b}},	//   rru_, sgea, lagh_, _embæ,
   {{0x6d5d0a56,0x68ed0201,0x6602b51b,0x198a0098}},	//   _obsa, _azad, _fiok, абни_,
   {{0x443fb51c,0x66028037,0x23659502,0xbcfb046d}},	//   pru_, _giok, selj_, _gbég,
   {{0xa3d90576,0x4426b51d,0x2365817f,0x629e009a}},	//   ावा_, _gwo_, pelj_, zypo,
   {{0x6d5d351e,0x6d4f0098,0x25bf8087,0x6b8380e8}},	//   _absa, _acca, liul_, _unng,
   {{0x9f52046d,0xa50a351f,0x68ed0c2e,0xd62a3227}},	//   _buyò_, иева_, _ezad, робе_,
   {{0x44323520,0xdb1a82be,0x25bf802e,0x386000b4}},	//   tsy_, vité, niul_, _tpir_,
   {{0x249f9cc9,0x212f8706,0x290501d0,0x752bb521}},	// [2040] nyum_, dagh_, ělat_, _megz,
   {{0x44323522,0x212280bc,0x25bf8162,0x61e60fb6}},	//   rsy_, मर्श_, hiul_, llkl,
   {{0xed5a00a9,0x3dc902d5,0x7a08928a,0x826601a8}},	//   _кон_, bnaw_, _pěti, تهان,
   {{0x00e6a66e,0xe9da8604,0xdb1ab523,0xd3788503}},	//   ожен, шке_, rité, moće_,
   {{0x25bf802e,0x7bda804f,0x7bc8808b,0x25ad9abb}},	//   diul_, yotu, yndu, dhel_,
   {{0x442682a0,0x2d99b524,0xc7a39a1f,0x8fa39ae2}},	//   _rwo_, ösen_, мичк, маче,
   {{0x59ca09c2,0x2454039c,0xf8bf0866,0xd37880fe}},	//   ाचार, läm_, mbée_, noće_,
   {{0x2cbf00fe,0x25adb525,0x2d9202a0,0xdc1e80ab}},	//   _žudi_, ghel_, njye_, _দিবস_,
   {{0xc5f3078d,0x938aaf02,0x7bdab526,0x2717001b}},	//   ודה_, асна_, totu, nění_,
   {{0xa3e48105,0xa3ea00bc,0x442681ed,0x68ed0035}},	//   _भीख_, मति_, _vwo_, _rzad,
   {{0x7ae3831d,0x86c680f7,0xf1bf01df,0xddc8826c}},	//   _cynt, _بيان, tiá_, _irdž,
   {{0xb606b527,0x44268051,0x25bf802e,0x29008110}},	//   rišć, _two_, ciul_, žiau_,
   {{0x44268578,0x7bdab528,0x25d9803d,0xcf00011c}},	//   _uwo_, potu, _اهنگ_, əşən_,
   {{0x4374803d,0x271701d0,0x68ed016b,0xc6a71da6}},	//   _رهبر, dění_, _vzad, орби,
   {{0x3ea50019,0x7ae38114,0xa3d906ae,0xed59811f}},	//   ált_, _gynt, ावस_, liža_,
   {{0x321e89c4,0xdb1703a8,0x51870b26,0x7647018e}},	//   mpty_, rixí, _фука, rujy,
   {{0x5fbc801b,0x030e8816,0x68ed3529,0x6d9c81a8}},	// [2050] ्चाल, _सलाह_, _uzad, _héas,
   {{0x69dd352a,0x09d38bbc,0xd37101a8,0x7a35819d}},	//   lose, तव्य, عها_, _ẹtit,
   {{0xe8d90870,0xdb01b31b,0x211881bc,0xc3240264}},	//   _mbọ_, silö, _ịtụl, _পাখি_,
   {{0xe0d383f8,0x6b988edd,0x249f9cbc,0x67ed95a0}},	//   وزش_, _lovg, yyum_, dúja,
   {{0x29090122,0x95160039,0xdb1e0580,0x6d4d14ba}},	//   _mgaa_, _מקרא_, kipè, mgaa,
   {{0x81c30a49,0x2d9900b4,0x6cfa0039,0x1b2280ab}},	//   ্তি_, _hose_, _לפרס, _মাঝে_,
   {{0x2d9926a3,0x69dd352b,0x25adb52c,0x67ed8019}},	//   _kose_, kose, thel_, gúja,
   {{0x6d4d12eb,0xdceb84b7,0xe8d9046d,0x2909352d}},	//   ngaa, _jogħ, _abọ_, _ngaa_,
   {{0x65a30006,0x81c300c8,0x25bf802e,0xdceb9693}},	//   _põhj, ্তা_, riul_, _bagā,
   {{0x5ba98319,0x290901bc,0xdceb84b7,0x26d30216}},	//   ском_, _agaa_, _logħ, _oxxo_,
   {{0x69cbb52e,0x249fb52f,0x25bf8087,0x95cba903}},	//   onge, syum_, piul_, _куда_,
   {{0x2005822e,0x2ca03530,0x69dd0168,0x186a2361}},	//   _hili_, yyid_, gose, бами_,
   {{0x69cbb531,0xda0b8035,0x6d5b8c53,0x6d4d3532}},	//   inge, _सूरत_, mfua, dgaa,
   {{0xd9b8800c,0xa4fa81c6,0xaabd09c1,0x2d99010c}},	//   _अष्ट, _פלסט, ्पाक, _aose_,
   {{0x2d9902a0,0x2005b533,0x59db86bf,0x76438359}},	//   _bose_, _mili_, यकार, nrny,
   {{0xf992003f,0x2005b534,0x6d4d3535,0x2d990098}},	//   _سبب_, _lili_, ggaa, _cose_,
   {{0xdb1e020f,0x02c4016f,0x6ac4036d,0x7643808e}},	// [2060] qipë, वप्न, वप्र, hrny,
   {{0x6d4d1cdf,0x6569b536,0x395f89cd,0xa3cb8072}},	//   agaa, heeh, _abus_, रचि_,
   {{0x2d993537,0x479b0158,0x98b0805c,0x179b00be}},	//   _fose_, _הייס, đači_, _הייב,
   {{0x7bc1b538,0x6d9c80f7,0xddc88754,0x80da80ab}},	//   hilu, _léar, _srdž, _বৃষ্,
   {{0xd12f8d4a,0xa3bd835a,0x75243539,0x7bc1b53a}},	//   امه_, ीचा_, mbiz, kilu,
   {{0x26118104,0x2005b53b,0xdb1e09c4,0x6449809f}},	//   _báo_, _cili_, kipé, duei,
   {{0xa3d91cfa,0x2005b495,0x26118028,0x4420353c}},	//   ावर_, _dili_, _cáo_, lpi_,
   {{0x7bde2419,0xdcebb53d,0x66061be5,0x77ab0085}},	//   lopu, _xogħ, _jikk, _müxa,
   {{0x6449acec,0x2005b53e,0x6d9c81a8,0x4420353f}},	//   guei, _fili_, _béar, npi_,
   {{0x0b8a8364,0x3160008e,0x6d9c81a8,0x66063540}},	//   ссии_, _abiz_, _céar, _likk,
   {{0xe4d699f7,0x46db0105,0x6d9c81a8,0x644401b4}},	//   _کتاب, _मुंह, _déar, hrii,
   {{0xdb1ab541,0x7bde0133,0x6d9c8388,0xfbc400ab}},	//   mití, hopu, _véas, ্তিত,
   {{0x644983d3,0x7bc1b542,0xdb1ab543,0x7bde0198}},	//   cuei, bilu, lití, kopu,
   {{0x2259809a,0xe8d9019d,0x200581b4,0x6d9c8174}},	//   ńska_, _nnụ_, _xili_, _géar,
   {{0x6d4d271e,0x6a1380f7,0xe3c400ab,0xdb1e00f7}},	//   tgaa, _كبير, ্তাব, cipé,
   {{0x66060065,0xe8d90870,0x91e40eef,0x1c11864a}},	//   _cikk, _anụ_, _поје, _डूडल_,
   {{0x66063544,0xa3d90006,0x53992252,0x442000e4}},	// [2070] _dikk, ावल_, овая_, gpi_,
   {{0x25ef05b3,0x3374002e,0x2a6302f7,0x7bde008e}},	//   _आठवी_, нгур, _ppjb_, gopu,
   {{0x35f5018b,0xdb0181ec,0x44203545,0xa3b30a43}},	//   _опор, chlä, api_, जोग_,
   {{0x69cb8081,0x644410b5,0xdb1e0198,0x7bc1b546}},	//   unge, brii, enpä, zilu,
   {{0x2005822e,0x200d8081,0x3ce681c0,0x7777022b}},	//   _pili_, _quei_, _nyov_, _kaxx,
   {{0x69dab547,0xdb23003d,0x66e5b548,0xdee5a041}},	//   _íten, _سوری, мола, моли,
   {{0x7bc184b7,0xe7308fc5,0x44393549,0x6d5b80b9}},	//   vilu, اصه_, _hvs_, tfua,
   {{0x69c288f1,0x2005b54a,0x395f833e,0x6449b54b}},	//   cioe, _wili_, _ubus_, tuei,
   {{0x7bc1b54c,0x387f81b4,0x752f0035,0x290080e1}},	//   tilu, _urur_, _mecz, žiar_,
   {{0x752f009a,0x261180ff,0x799b8bfd,0xad9b0174}},	//   _lecz, _táo_, _houw, _siúl,
   {{0xd946243b,0x7bc1b54d,0x61460d45,0x44200102}},	//   мени, rilu, мена, zpi_,
   {{0x5ec100ab,0x799bb54e,0x7bc1b54f,0x44203550}},	//   _শুভে, _jouw, silu, ypi_,
   {{0x66063551,0x7bc1802e,0x6d9c80f7,0x64499a85}},	//   _rikk, pilu, _téar, quei,
   {{0x660606be,0x69c28102,0x777700e5,0x799bb552}},	//   _sikk, zioe, _caxx, _louw,
   {{0x66e33553,0x6606037b,0x7a08800d,0x1db183eb}},	//   вора, _pikk, _děts, _जतात,
   {{0x69bf89a3,0x3dcd822b,0x64442eac,0xdb1c3554}},	//   लोमी, nnew_, trii, _imré,
   {{0x7bde3555,0x5f76045b,0xdb1a8524,0xa3d9016f}},	// [2080] topu, _قادر, zití, ावं_,
   {{0x44393556,0x64441ee7,0x66062633,0xf77201f9}},	//   _dvs_, rrii, _wikk, _شاخ_,
   {{0x81c300c8,0x66063557,0x7c360338,0x799b8a0f}},	//   ্তর_, _tikk, ssyr, _bouw,
   {{0x64a60071,0x64443558,0x2904026c,0x6d9c810c}},	//   _жама, prii, žmau_, _néap,
   {{0x69c2811b,0x799bb559,0x2a6d01a1,0xdb1a82df}},	//   rioe, _douw, _ćebe_, nitã,
   {{0x4375355a,0x7a0c0087,0xd378acf6,0x7989b55b}},	//   _пуст, _aşte, koća_, _enew,
   {{0x7c2b8114,0xa3db06af,0x799b8176,0x6b9c31d2}},	//   _awgr, डकर_, _fouw, _iorg,
   {{0x5c749508,0x65a30006,0x6b9c355c,0x61e4355d}},	//   елит, _põhi, _horg, _nkil,
   {{0x69c0b55e,0x6b9c355f,0xbeeb064a,0x21268d8b}},	//   _imme, _korg, _टर्न_, mboh_,
   {{0x61e40010,0xf3668d9e,0x7d0b8558,0x7ac6818b}},	//   _akil, фтин, _eggs, дсме,
   {{0xa3b60e18,0x3ddf8a0f,0xbcfb01a8,0x6b9c3560}},	//   _जतन_, bouw_, _mbéa, _morg,
   {{0x6b9c0c41,0x9e658065,0x61f610ae,0x237802d6}},	//   _lorg, _سامن, _chyl, _larj_,
   {{0x6b9c01b0,0x0cc900ab,0x6562818e,0x00000000}},	//   _oorg, _শর্ত, _iboh, --,
   {{0xead49edc,0x6b9c0cde,0x2cb0861c,0x61e43561}},	//   _поль, _norg, ıldı_, _ekil,
   {{0xbd0580e7,0x69c0b562,0xf8ae004e,0xdd9b1617}},	//   _théâ, _omme, لکی_, оша_,
   {{0xfaa7803d,0xdb1aab8f,0xc5f881a9,0x96f80993}},	//   _تجهی, lità, _spēj_, фест_,
   {{0x3cfc011b,0x6b9c3563,0xdce980d2,0x94ab06b5}},	// [2090] рvv_, _borg, rdeć, цтва_,
   {{0x799b82d6,0x69c0b564,0x44390370,0xdb1ab565}},	//   _souw, _amme, _vvs_, nità,
   {{0x6562816b,0xafdb004a,0x69cf0037,0xfd100061}},	//   _oboh, nrøm, once, اجہ_,
   {{0x77b000f2,0x442b041c,0x673507d8,0x3495164f}},	//   _växe, _twc_, lazj, _замр,
   {{0x6b9c1cb6,0x2d8b02d0,0x7e620b80,0x799b890d}},	//   _forg, _ince_, _ćopi, _vouw,
   {{0x69c0b566,0xdce407d9,0x644d000e,0x673523b3}},	//   _emme, ldiğ, muai, nazj,
   {{0x644d3476,0x4ae401e2,0x4ad903b7,0x16a9b10c}},	//   luai, _аўта, _बँटव, явки_,
   {{0x6b9c3567,0xc8c0835a,0x7bc53568,0xdce40214}},	//   _zorg, _शेवट, lihu, ndiğ,
   {{0x4439b569,0x644d356a,0x3ddf81ed,0x290d80e5}},	//   és_, nuai, rouw_, _igea_,
   {{0x61e42c02,0x3dcd89c4,0x69cf2527,0x7bc5356b}},	//   _skil, snew_, ence, nihu,
   {{0x25a90065,0xfaa58470,0x2d8b1b90,0x644d01a8}},	//   kkal_, хано, _once_, huai,
   {{0x9f47816b,0x22598035,0x6dc792c8,0x7d0b80c3}},	//   dlné_, ńsko_, _غزال, _uggs,
   {{0x320902d5,0xa5c6807b,0x6abd1107,0x7bc5356c}},	//   _diay_, sjóð, ्पुर, kihu,
   {{0x2d8b356d,0x644d356e,0xdb1a8980,0x2d9db56f}},	//   _ance_, duai, cità, _howe_,
   {{0x645bb570,0x24598385,0x2d9da11d,0x7a0901d0}},	//   ltui, lèm_, _kowe_, _větr,
   {{0x65aa003e,0x657bb571,0x3209001c,0x06072f16}},	//   _výho, nduh, _giay_, енск_,
   {{0xd46715fd,0x04430e6b,0xb4db026b,0x68e980d7}},	// [20a0] ните_, летн, _adàb, _nyed,
   {{0x69c63572,0x2d8b03a8,0x213f885c,0x6abd0b04}},	//   like, _ence_, _aduh_, ्पूर,
   {{0x6b9c02af,0xdb1ab573,0x814680f7,0x68e9adbb}},	//   _vorg, nitá, فنان, _ayed,
   {{0x69c63574,0x2d9d809a,0x68e985ee,0x645b9407}},	//   nike, _nowe_, _byed, ktui,
   {{0x644d0748,0x764e0c8b,0x6b9c3575,0x201209ab}},	//   cuai, luby, _torg, _juyi_,
   {{0x290d802a,0x69c63576,0x201209ab,0x6283b577}},	//   _egea_, hike, _muyi_, _orno,
   {{0x201fb578,0xfa670d8f,0xda0b8327,0x56949383}},	//   _etui_, _парк_, _संगत_, тайт,
   {{0xd5b7acd1,0xf3908028,0xc693036b,0x69c0b579}},	//   есь_, _cảnh_, ראה_, _umme,
   {{0x6283b57a,0x7c24357b,0x2d9db57c,0x61e2a76a}},	//   _arno, npir, _dowe_, mool,
   {{0x61e2b57d,0x765c009a,0xafdb03ba,0x3940357e}},	//   lool, ktry, trøm, _adis_,
   {{0x6283803b,0x69c6357f,0xf8bf8125,0xdb1ab580}},	//   _crno, fike, _þér_, gitá,
   {{0x248000ce,0x765c01a3,0x69c63581,0x20123582}},	//   kvim_, dtry, gike, _buyi_,
   {{0x3f9e84b9,0xfbcf82e3,0x644d0ba3,0xdce402d0}},	//   _kotu_, شتی_, xuai, vdiğ,
   {{0x8c1b893f,0x39403583,0x229480f7,0x7c24007a}},	//   _צווי, _edis_, _للتس, dpir,
   {{0x61e2b584,0x69c63585,0x61eb951e,0xfe700065}},	//   kool, bike, ylgl, یدہ_,
   {{0x644d3586,0x3f9eb587,0xf0a680ff,0xdced01a1}},	//   tuai, _lotu_, _đành_, ndać,
   {{0x3cfc2f7b,0xdce407d9,0x798d3588,0x32113589}},	// [20b0] लेले_, rdiğ, _inaw, _suzy_,
   {{0x25a9358a,0x657b9408,0x644d032f,0x3869358b}},	//   skal_, zduh, ruai, _ipar_,
   {{0x644d2645,0x325511d2,0xc3338039,0xdcef0162}},	//   suai, твер, רוע_, _bacă,
   {{0x7aea83ed,0x27e3358c,0x247202d6,0x7bc5358d}},	//   _myft, lojn_, _fņm_, sihu,
   {{0x7aeab58e,0x777aad08,0x6579b58f,0xf3908129}},	//   _lyft, _batx, _rawh, _rảnh_,
   {{0xf7718250,0x69c63590,0x10a282ee,0xdb1a85be}},	//   شات_, zike, ришн, litæ,
   {{0x69c63591,0x0675b592,0x61e2b593,0xd91581e2}},	//   yike, туля, bool, _адбы,
   {{0xd6ce8013,0xfc3f826f,0x61e2b594,0x68fb0084}},	//   تقى_, ším_, cool, žudy,
   {{0x69c63595,0x2a6780ee,0x777ab596,0x657bb597}},	//   vike, _spnb_, _fatx, rduh,
   {{0x09ca053e,0x645b8b3c,0x798d3598,0x5ed700ab}},	//   ाच्य, rtui, _anaw, _ধরনে,
   {{0x69c63599,0x6579b59a,0x645bb59b,0x2fc7b59c}},	//   tike, _tawh, stui, ming_,
   {{0xaca3819d,0x62838267,0xf8bf002a,0x765c359d}},	//   _amụk, _vrno, rbén_, vtry,
   {{0x7529b59e,0x98a48084,0x7c24010c,0x69c6359f}},	//   mbez, _temą_, xpir, rike,
   {{0x69c635a0,0x7c3b80dd,0x6449b5a1,0x644680fe}},	//   sike, msur, mrei, škic,
   {{0x66e6239f,0x2c1980c8,0xdee6215b,0xd007023a}},	//   това, _দিয়ে_, тови, тере_,
   {{0x2fc7b5a2,0x7d1b8289,0x661c8019,0xceb284de}},	//   hing_, ncus, _érke, ביל_,
   {{0x2fc7860c,0xff26087e,0xe8fa0698,0x973c8a20}},	// [20c0] king_, _импо, _юли_, _hoće,
   {{0x2fc7b5a3,0x6449b5a4,0x7c3bb5a5,0xd00f004e}},	//   jing_, irei, isur, _گلی_,
   {{0x2fc7b5a6,0x24800025,0x6449b5a7,0x61e2b5a8}},	//   ding_, svim_, hrei, tool,
   {{0x6449b5a9,0x3ea7831d,0x442f80b9,0x6cc6053b}},	//   krei, dynt_, _owg_, _айма,
   {{0xb82280c8,0x61e290b5,0x442f8282,0x2056b5aa}},	//   _নিহত_, rool, _nwg_, ттер,
   {{0x6449b5ab,0xb17b016d,0x2fc7b5ac,0x61e2b5ad}},	//   drei, llåt, ging_, sool,
   {{0x973cb5ae,0x163780f7,0x61e2b5af,0x660bb5b0}},	//   _noće, نسية_, pool, _bigk,
   {{0x6449b5b1,0xd01a00c8,0x557481f3,0x442f80b9}},	//   frei, তীয়_, угит, _bwg_,
   {{0x2fc797ef,0x6449a300,0xe817000f,0x7aea816d}},	//   bing_, grei, _धंधा_, _syft,
   {{0x442f8358,0x2fc7b5b2,0x69c42f8c,0x6e3e01a1}},	//   _dwg_, cing_, _amie, _ovpb,
   {{0x38691610,0x19590a14,0xf1f60035,0x23a40338}},	//   _spar_, наны_, ीगढ़_, _höjs_,
   {{0x6449b5b3,0xf1a71982,0x973c8267,0x200c804f}},	//   brei, трон, _doće, _hidi_,
   {{0xe1ff05a4,0xc05810ac,0x6e22192c,0xa3e203db}},	//   rmó_, кір_, _čoba, दवा_,
   {{0x9f5307e2,0x2618801c,0x38698168,0x7c22b5b4}},	//   _això_, _kéo_, çari_, _itor,
   {{0xf8bf0003,0x4ea4326c,0xc6a41317,0x200cb5b5}},	//   mbém_, арта, арти, _midi_,
   {{0x7c22b5b6,0x798d35b7,0x200c81d0,0x2fc78e9e}},	//   _ktor, _unaw, _lidi_, zing_,
   {{0x2fc78051,0x6abd01a2,0x69c380e7,0x9f430168}},	// [20d0] ying_, ्प्र, ènem, nojë_,
   {{0x69c421f3,0x68ed02c1,0x8aa7023a,0x02a700e8}},	//   _zmie, _iyad, кред, крем,
   {{0x9f5e8364,0x2fc7b5b8,0x26188866,0x75d50c3b}},	//   _mitä_, ving_, _néo_, _ميدا,
   {{0xc6920159,0x7bc88867,0x7c22b5b9,0xdd9513cd}},	//   _האט_, hidu, _otor, _самы,
   {{0x2fc7b5ba,0x200c9a7b,0x7bc8b5bb,0x248681c0}},	//   ting_, _bidi_, kidu, _nrom_,
   {{0x657d35bc,0xfc3f803e,0x261880ff,0x442f822c}},	//   _hash, šík_, _béo_, _rwg_,
   {{0x657d35bd,0x7c22b5be,0xcf94098a,0x7bc8a0aa}},	//   _kash, _ator, יטס_, didu,
   {{0x657d020f,0x7c3bb5bf,0x442f822c,0x24869c2b}},	//   _jash, tsur, _pwg_, _brom_,
   {{0x2fc7b5c0,0x657d35c1,0x61e9b5c2,0x75299083}},	//   ping_, _mash, _ikel, rbez,
   {{0x6449b5c3,0x657d35c4,0x7c3bb5c5,0x69c435c6}},	//   rrei, _lash, rsur, _smie,
   {{0x7c22811e,0x6449b5c7,0xdb1ab5c8,0x68ed01b4}},	//   _etor, srei, entó, _ayad,
   {{0x2486804c,0x442f81e9,0x64498b2b,0x64468110}},	//   _from_, _twg_, prei, škia,
   {{0x3fc80077,0x7bc8b5c9,0x8c458b5b,0x2d8fae28}},	//   ندسی_, bidu, _селе, _inge_,
   {{0xf53980e1,0x657d01b4,0x7bc38234,0x25adb5ca}},	//   lať_, _aash, _umnu, lkel_,
   {{0x657d35cb,0x44220ac6,0x69c401b9,0x61e9b5cc}},	//   _bash, _stk_, _tmie, _okel,
   {{0x25adb5cd,0x657d35ce,0x69c4198a,0xf53980e1}},	//   nkel_, _cash, _umie, nať_,
   {{0x657d35cf,0xb17b0106,0x68ed09ab,0x81cc8264}},	// [20e0] _dash, rlåt, _gyad, রকম_,
   {{0x5503176e,0xb3468073,0x9f5e0009,0x61e9b5d0}},	//   спуб, moçõ, ötä_, _akel,
   {{0x657d35d1,0x25adb5d2,0xbea60912,0x3ea6283f}},	//   _fash, kkel_, _санк, _синг,
   {{0x61fbb5d3,0x657d35d4,0x3ea508aa,0x2247016b}},	//   _chul, _gash, älte_, ánka_,
   {{0xe8948554,0xf539b5d5,0x44220867,0x261a000f}},	//   раль, dať_, _utk_, _मंडी_,
   {{0xafdb0022,0x2d8fb5d6,0x61e98135,0x9f430168}},	//   rsøg, _ange_, _ekel, vojë_,
   {{0x200c803a,0x657d35d7,0x67388db7,0x61e6026c}},	//   _vidi_, _yash, ravj, kokl,
   {{0x9f5e8364,0x6d5635d8,0x7bc8809a,0xd49ab5d9}},	//   _sitä_, ngya, widu, еро_,
   {{0xa84a88ca,0x61e600eb,0x161602f1,0x2d8035da}},	//   _سلام_, dokl, _दूसर_, idie_,
   {{0x9f4300f1,0x291235db,0x99860084,0x2d8fb5dc}},	//   rojë_, _agya_, kslų_, _enge_,
   {{0x7bc8b5dd,0xdb1a8a48,0x68ed0359,0x9f430168}},	//   ridu, vitä, _syad, sojë_,
   {{0x2eb08bb8,0x2486b5de,0x2d800493,0x25adb5df}},	//   जनीत, _trom_, jdie_, ckel_,
   {{0x657d00a4,0x7bc8b5e0,0x213935e1,0x73c4a1d7}},	//   _rash, pidu, rash_, _پيغم,
   {{0x657d00a4,0x2a660035,0x14d781c6,0x29120c2e}},	//   _sash, łoby_, _גודל_, _egya_,
   {{0x657d35e2,0x39448144,0xdb1ab5e3,0x8b6580d7}},	//   _pash, _odms_, ritä, _خانم,
   {{0x6d562bc0,0x61e635e4,0x657d35e5,0xca4781a8}},	//   ggya, cokl, _qash, _إليه_,
   {{0x657d35e6,0xdb1ab5e7,0xf53f35e8,0xdce284e8}},	// [20f0] _vash, pitä, _slås_, _oboč,
   {{0x91fd0029,0x61fb822e,0xf53981ac,0x657d35e9}},	//   stād, _shul, zať_, _wash,
   {{0x657d2c23,0x3a7501e5,0x20d40bca,0x92590009}},	//   _tash, рлер, _نتیج, тает_,
   {{0x657d35ea,0x6e250362,0x57dd8072,0x3e410048}},	//   _uash, _ithb, यव्ह, mėt_,
   {{0xf539b5d5,0x752d35eb,0xd5b1827d,0xa3d48b99}},	//   vať_, mbaz, _lúc_, सचा_,
   {{0x442935ec,0x2259809a,0x61fb82f7,0x3f69b5ed}},	//   mpa_, ński_, _whul, тико_,
   {{0xf53981ac,0x25ad8074,0xfd1180f7,0xf77403de}},	//   tať_, tkel_, يجة_, מקס_,
   {{0x1c4593b4,0x644d0090,0x442935ee,0xada58198}},	//   аним, orai, opa_, раил,
   {{0x4429028a,0x69cbb5ef,0x644d061f,0xf53981ac}},	//   npa_, mige, nrai, rať_,
   {{0x69cb84e1,0xf53981ac,0x5ba9968a,0x442935f0}},	//   lige, sať_, тком_, ipa_,
   {{0x644d0a1c,0x27e7b5f1,0xd6d18a47,0x25b08061}},	//   hrai, monn_, _بقا_, álló_,
   {{0x2d8f8bc5,0x69cbb5f2,0x44290133,0x660f35f3}},	//   _unge_, nige, kpa_, _nick,
   {{0x6e2500f7,0x80c001d0,0xac278162,0x00000000}},	//   _athb, _लेखे, _сфек, --,
   {{0x644d1dd9,0x7c2999b0,0xdcfb9487,0x443fb5f4}},	//   drai, mper, nduč, msu_,
   {{0xa91d8a56,0xe7370a94,0x09b5816f,0x63a38046}},	//   _každ, рес_, ंसाठ, _ionn,
   {{0x63a3b5f5,0x644d35f6,0xf53f0082,0x248d35f7}},	//   _honn, frai, _slår_, _šema_,
   {{0x63a3b5f8,0x443f8a73,0x2d8004df,0x644d35f9}},	// [2100] _konn, nsu_, rdie_, grai,
   {{0x443f9572,0xdcfb8d2f,0xdb0183ba,0x63a3a232}},	//   isu_, jduč, rklæ, _jonn,
   {{0x69cbb5fa,0x673c16c4,0x973c8289,0x3dd7077f}},	//   fige, marj, _noća, úewé_,
   {{0x7c29b5fb,0x673c35fc,0x63a381a8,0x88868db6}},	//   kper, larj, _lonn, илеж,
   {{0x6604043d,0x644d0cb5,0x261c002a,0x91fd00eb}},	//   mmik, crai, _hío_, ltāc,
   {{0x673c35fd,0x7c29b5fe,0x63a3b5ff,0x66043600}},	//   narj, dper, _nonn, lmik,
   {{0x69cbb601,0x29568098,0x2eb080c2,0xafdb0aa2}},	//   bige, _възр, जनेत, prøv,
   {{0xd378803a,0x443fb602,0x91e39a1f,0x261c06a5}},	//   moći_, fsu_, _досе, _mío_,
   {{0x26168063,0x673c3603,0x63a3b604,0x261c0661}},	//   _पूरी_, karj, _bonn, _lío_,
   {{0x673c3605,0xeb06b606,0x63a38213,0x798082a0}},	//   jarj, ично, _conn, _hamw,
   {{0x6d460a56,0x7980b607,0x673c3608,0x63a3b609}},	//   _odka, _kamw, darj, _donn,
   {{0x7c26003b,0x4429360a,0x63a38b99,0x7982b60b}},	//   _otkr, ypa_, _eonn, ndow,
   {{0x660f360c,0x63a3b60d,0x84638081,0x98b20176}},	//   _rick, _fonn, _дъще, _feyč_,
   {{0x4426b60e,0x63a3b60f,0x644d03d3,0x6d460079}},	//   _ito_, _gonn, vrai, _adka,
   {{0x7c262dab,0xc3fb8039,0x644083ba,0x7a138162}},	//   _atkr, _שלוש, lsmi, _bătu,
   {{0xa91d82a5,0x4426b610,0x63a3b611,0x644d3612}},	//   _kaže, _kto_, _zonn, trai,
   {{0x63a382ec,0x61ed17ea,0x69cbb613,0x644d3614}},	// [2110] _yonn, _ikal, vige, urai,
   {{0x644d3615,0x44293616,0x4426b617,0x69d880e7}},	//   rrai, rpa_, _mto_, éven,
   {{0x44293618,0x69cbb619,0x79809b25,0x386d8087}},	//   spa_, tige, _bamw, _sper_,
   {{0x4426b61a,0x443fb61b,0xf5950f99,0x6440b61c}},	//   _oto_, ysu_, _الحج, ksmi,
   {{0x4426b61d,0x702280c8,0xfd960039,0x61ed004f}},	//   _nto_, _নিউজ_, _הדרך_, _mkal,
   {{0x9f4780f1,0x6440b61e,0x628ab61f,0xdb1e02f1}},	//   monë_, dsmi, _orfo, gipä,
   {{0x4426b620,0x3f811083,0x6442b621,0x28a7864a}},	//   _ato_, _mahu_, _avoi, _कॅरि,
   {{0x81bd0341,0x63a3b622,0x7c2983ab,0x973c83b1}},	//   spēj, _sonn, tper, _voća,
   {{0x69c9b623,0xb4f532df,0x27e78247,0x63a3b624}},	//   _imee, _आरोप_, ponn_, _ponn,
   {{0x443fb625,0x7c29b626,0xd7fb8364,0x61ed3627}},	//   rsu_, rper, _руб_, _akal,
   {{0x4426b628,0x443fb629,0x673c362a,0x63a3b62b}},	//   _eto_, ssu_, varj, _vonn,
   {{0x261c02ba,0x443fb62c,0x63a38c2e,0x3e619e18}},	//   _río_, psu_, _wonn, mót_,
   {{0x673c362d,0x628a8352,0x973c805c,0x3f810458}},	//   tarj, _erfo, _moćn, _bahu_,
   {{0x261c157a,0x63bab62e,0x23268dcd,0xab26964f}},	//   _pío_, chtn, _лоши_, _лоша_,
   {{0x6604362f,0xdfcf00f7,0x673c054b,0x65b5816b}},	//   tmik, ريف_, rarj, _záha,
   {{0x973c803b,0x673c3630,0xd01f80ab,0xdb019b57}},	//   _noćn, sarj, নীয়_, rklä,
   {{0x6da33631,0x66043632,0x3f810115,0x44268144}},	// [2120] чита, rmik, _fahu_, _xto_,
   {{0xa3ca8aec,0x261c28f4,0x69c9b633,0x2a6e8144}},	//   रोप_, _tío_, _amee, _ypfb_,
   {{0xdb1a84c3,0x9f4c801c,0x8e8600f7,0x798082d6}},	//   titú, _đoàn_, _الجه, _pamw,
   {{0xe93a9e09,0x8d560d0e,0xe9da8a26,0x6d460366}},	//   اسات_, _уточ, ыке_, _udka,
   {{0xa3e79130,0x7982b634,0x60003635,0x515b01c6}},	//   पवा_, rdow, römf, רכנו,
   {{0xc059835f,0xd9a5016f,0xdefa8009,0xbcfb0032}},	//   рії_, _ऑक्ट, лый_, _abéw,
   {{0x44268025,0x2d8200a4,0xa91db636,0x65b59727}},	//   _sto_, _kake_, _saže, _sáha,
   {{0x6440a0e5,0xa91d8110,0x25a03637,0xa3ca81a2}},	//   tsmi, _paže, njil_, रोन_,
   {{0x2d820051,0x77b0016d,0x5bb895a6,0x4426841c}},	//   _make_, _växj, илия_, _qto_,
   {{0xa91d805c,0x61ed3638,0xd37a8ae7,0xf8bf00e7}},	//   _važe, _skal, учи_, ncée_,
   {{0x77ab0085,0x9f8d01d0,0x25a0008e,0xc7b381c6}},	//   _müxt, uží_, kjil_, _צבע_,
   {{0xdb1c0125,0x2d820041,0xdb03b4fe,0x64563639}},	//   _umræ, _nake_, _zonë, kuyi,
   {{0x4426b63a,0xafdb0aa2,0x673a8009,0x5c068a4c}},	//   _uto_, drør, _ketj, _ляка,
   {{0x7bcf80e7,0x62348e8e,0x2d82026b,0x43948254}},	//   écut, _деку, _aake_, _факс,
   {{0x25a6b63b,0x673a81a1,0x61ed363c,0x7bca9ba4}},	//   _kool_, _metj, _tkal, _imfu,
   {{0x673a82ce,0xa2b101bc,0x7bdc022b,0x61ed363d}},	//   _letj, _dọ́l, _ajru, _ukal,
   {{0x3f811a6e,0x21f9003e,0x64a40003,0x2d8203c3}},	// [2130] _tahu_, lého_, паѓа, _dake_,
   {{0x261a009a,0x673a8fb0,0x69c98cfa,0x661a8326}},	//   _मूवी_, _netj, _smee, _outk,
   {{0x21f90775,0xdb03809f,0x02d90eca,0x1df90190}},	//   ného_, _conè, جواب_, _вены_,
   {{0xd378803b,0x25a68079,0x9f4c801c,0x64560c6a}},	//   moću_, _nool_, _đoán_, buyi,
   {{0x3dcdb63e,0x973ca8d2,0x673a8aa2,0x21f9016b}},	//   view_, _voćn, _betj, hého_,
   {{0x21f90a56,0x7c2d2b56,0x2d82022e,0xb4b5047d}},	//   kého_, mpar, _zake_, जनी_,
   {{0x2d82363f,0x201302a6,0x69cf3640,0x9989009a}},	//   _yake_, _mixi_, kice, _miał_,
   {{0x0c258790,0x69c9b641,0x94258049,0x25a681c6}},	//   омин, _umee, омие, _cool_,
   {{0x6f001931,0x7c2d3642,0x9f47b643,0x57d58073}},	//   _kábí, npar, yonè_, _доаѓ,
   {{0x4a4599a7,0x39493644,0x61ebb645,0xd378842b}},	//   онов, _adas_, logl, koću_,
   {{0x395f88ae,0xe9da27d4,0x63a73646,0x69cf3647}},	//   _kcus_, ико_, _mojn, fice,
   {{0x61ebb648,0x69cf2fa4,0x39490144,0x7a138162}},	//   nogl, gice, _cdas_, _bătr,
   {{0x09a78076,0x7a13802e,0x201301b4,0x64a58152}},	//   _खवैय, _cătr, _bixi_, _фала,
   {{0x2d823649,0x44079cf4,0x63a701c0,0xe7371cae}},	//   _sake_, _учеб, _nojn, жер_,
   {{0x2d82364a,0x442db64b,0x7643b64c,0x320682c4}},	//   _pake_, lpe_, nsny, ymoy_,
   {{0x28c50df4,0x6d5bb64d,0x6000016d,0x6569b64e}},	//   _लेकि, ngua, döme, nfeh,
   {{0x6b83b64f,0x90c30364,0xfaf80029,0x442d8247}},	// [2140] _kang, _объе, _šī_, npe_,
   {{0x6b83828a,0xdb1c0082,0x442db650,0x7a0c8201}},	//   _jang, _områ, ipe_, _işti,
   {{0x6b83b651,0x6da6069b,0x79840041,0x2d820051}},	//   _mang, _дина, _kaiw, _take_,
   {{0xa96a81a1,0x442db652,0xdb03b653,0x61ebb654}},	//   рида_, kpe_, _coné, gogl,
   {{0x63a70042,0x7984020d,0x00da9a16,0xa3ca847d}},	//   _fojn, _maiw, جبات_, रोड_,
   {{0x6b83b655,0x69cf3656,0x661a8198,0x25a681c7}},	//   _nang, zice, _putk, _sool_,
   {{0xd5ba95fe,0x179b0051,0xdb1a80f1,0x8f9b010f}},	//   иси_, ייסב, shtë, ייסי,
   {{0x6b8381d8,0x21f90ed7,0x79843657,0x61eb8081}},	//   _aang, vého_, _naiw, cogl,
   {{0x64441ec1,0x764380dd,0x442d82d5,0x69cf3658}},	//   nsii, asny, gpe_, vice,
   {{0x6b838886,0x70538077,0x661ab659,0x6444365a}},	//   _cang, _آنلا, _tutk, isii,
   {{0x25a6b65b,0x7414803d,0x442db65c,0x798404b9}},	//   _tool_, _کوتا, ape_, _baiw,
   {{0x21f9003e,0x64441bf3,0xd46a9ca4,0x6b83b65d}},	//   rého_, ksii, _виде_, _eang,
   {{0x6d40b65e,0x3866b65f,0xdd8f8c2a,0x6b83b660}},	//   mama, ntor_, _جون_, _fang,
   {{0x6d40b661,0x69cf3662,0xa91d8110,0xb4c892e0}},	//   lama, sice, _maža, ोपी_,
   {{0xa91d8390,0x69cf3663,0x20133664,0xb5a70956}},	//   _laža, pice, _vixi_, орай,
   {{0x6d40b665,0x6b83b666,0x9f4780d7,0x63a701c0}},	//   nama, _zang, roné_, _sojn,
   {{0x6b83b667,0xa91d803a,0xb4b50361,0x63a70069}},	// [2150] _yang, _naža, जने_, _pojn,
   {{0x7c2d3668,0x6d40b669,0x6b83b66a,0xc2e900ab}},	//   rpar, hama, _xang, _কৃষি_,
   {{0x6d40b66b,0x7a400013,0x250909a7,0x65aa05b9}},	//   kama, _rátá, _گردی_, _výhr,
   {{0xa3ca9a4d,0xf67a0158,0x19598e11,0x1a9b80be}},	//   रोत_, _פארמ, сады_, ייבע,
   {{0x6d40b66c,0x859a0039,0x61ebb66d,0xf1b40039}},	//   dama, _השרו, rogl, וסף_,
   {{0xa91d96b5,0x3e4581a9,0xec3601c6,0xf8bf002a}},	//   _daža, tēt_, _מאשר_, lbés_,
   {{0x4439366e,0x31359c9b,0x628e025b,0x69cd2eac}},	//   _hws_, _невр, _grbo, _omae,
   {{0x6d40b66f,0x753d0063,0x31790063,0x6602b670}},	//   gama, _jesz, jesz_, _chok,
   {{0x6b839a9a,0x442db671,0x3866b672,0x6d5bb2f6}},	//   _pang, upe_, ctor_, rgua,
   {{0x69dd03d3,0x753d100b,0x6d5bb673,0x75d38087}},	//   éren, _lesz, sgua, văzu,
   {{0x656f1385,0x656982af,0x44393674,0xddc880eb}},	//   _obch, pfeh, _lws_, žoša,
   {{0x6d408faa,0x442d8dfc,0x6b83b675,0x7bda8009}},	//   cama, ppe_, _wang, antu,
   {{0x6b83859e,0x4439146a,0x3f85b676,0x442b3677}},	//   _tang, _nws_, _kalu_, _ntc_,
   {{0x6609b678,0x61a88670,0x3f85b679,0x79840300}},	//   lmek, _कक्ष, _jalu_, _waiw,
   {{0x753d0065,0x7984367a,0x4439367b,0xcf9280be}},	//   _besz, _taiw, _aws_, עטל_,
   {{0x3f85848f,0x3179009a,0xf1bf026f,0x741600f7}},	//   _lalu_, cesz_, chá_, كورا,
   {{0x39420006,0x75241e75,0xa5070c5c,0x25bf80ee}},	// [2160] maks_, rciz, зета_, ihul_,
   {{0x6d40b67c,0x64440079,0xb903367d,0x4420367e}},	//   zama, rsii, _язык, rqi_,
   {{0x442b367f,0x753d0019,0xa91d80d2,0xdb1ab680}},	//   _etc_, _fesz, _saža, uhté,
   {{0x3866b681,0x628e042b,0x25bfb11a,0x5886a252}},	//   ttor_, _vrbo, jhul_, зыка,
   {{0x6d40b682,0xd90d826a,0x3f85b683,0x44203684}},	//   vama, لیف_, _balu_, qqi_,
   {{0x6d4bb685,0x3866b686,0x6602b687,0xa91d805c}},	//   _adga, rtor_, _shok, _važa,
   {{0x6d40b1ed,0x7bce3688,0x7c2b80eb,0x59dc020e}},	//   tama, _imbu, _atgr, मचार,
   {{0x80cd81ab,0xbcfb3689,0x9adb0039,0x661e026c}},	//   _देवे, _ibér, _החלט, _mupk,
   {{0x6d40b68a,0xa91d8024,0x661e00d2,0x6d4b01a8}},	//   rama, _kažn, _lupk, ógai,
   {{0x6d40b68b,0xad9b001c,0x644fb68c,0x3f85a046}},	//   sama, _nhún, ácia, _galu_,
   {{0x21fc801b,0x7bce0359,0x21790190,0xdcfd01a9}},	//   ního_, _mmbu, ойны_, _masā,
   {{0xa91d8503,0x25bfb68d,0x6d40b68e,0x80ab00ab}},	//   _lažn, chul_, qama, _চেষ্,
   {{0x2ac282be,0x4420802e,0x26099094,0x3a20a384}},	//   _bébé_, _îi_, ागरी_, _čipu_,
   {{0xad9b0104,0xefc815da,0x03a3a4f5,0xf09f07f1}},	//   _chún, пуск_, _пичо, rxà_,
   {{0x248200ee,0x3942368f,0xdb07010c,0x21fc928a}},	//   _askm_, baks_, _gojè, jího_,
   {{0x40ee082e,0x22f78039,0x44391670,0x9df90a4c}},	//   ọrọ_, _מזון_, _pws_, інат_,
   {{0x753d0065,0xf8bf0b2c,0xa91d8110,0xbcfb026b}},	// [2170] _vesz, rbés_, _bažn, _abér,
   {{0x6ad080ab,0x442b00ff,0x051d0264,0x44390bfd}},	//   _সুযো, _vtc_, তরের_, _vws_,
   {{0x753d0065,0xa91d81e2,0x22470061,0x69dd3690}},	//   _tesz, _dažn, énk_, onse,
   {{0x7bce3691,0x6aaa00f2,0x3f85b692,0x69dd3693}},	//   _embu, äffa, _salu_, nnse,
   {{0xc5fb0670,0x3f85b694,0x2d993695,0x656d34e2}},	//   ्षीय_, _palu_, _inse_, mfah,
   {{0x1408016f,0xab843696,0xbcfb00f7,0xdfd181a8}},	//   वगृह_, _пуск, _gcéa, ضيع_,
   {{0x21fc801b,0x6609b697,0x63a3007b,0x3f85b698}},	//   cího_, tmek, önnu, _valu_,
   {{0x2d893699,0x75fe8168,0x629a2cf6,0x69dd01ed}},	//   ndae_, tëza, _štog, jnse,
   {{0x91fd0029,0x394d80d2,0x6609b69a,0xfc058652}},	//   rtāl, _ides_, rmek, мпио,
   {{0x63aa8114,0x7655009a,0xe3b181a8,0xdb1ab69b}},	//   _cofn, krzy, ئرة_, ditó,
   {{0x91e6369c,0xf1c4801b,0x3942103d,0x29000019}},	//   доне, लोकन, taks_, _szia_,
   {{0x6d4b813c,0x44b5ad0a,0xbcb58ada,0x7f4381b4}},	//   _udga, _обес, _обещ, lanq,
   {{0xe87c0459,0xa91d80d2,0xa3ca83dd,0x21fc81d0}},	//   _düşü, _lažo, रोह_, zího_,
   {{0x2d99369d,0x39420006,0x3fcc00ab,0x63aa8428}},	//   _anse_, saks_, লক্ষ, _gofn,
   {{0x394d82a5,0xa91d8da8,0xdb03826f,0x248db69e}},	//   _odes_, _ražn, _koní, lvem_,
   {{0xbcfb00f7,0x394d89c4,0x68f6062c,0x70ef0133}},	//   _scéa, _ndes_, _tyyd, ụrụi,
   {{0xd4670f13,0xa91d8025,0xdcfd0029,0x64468289}},	// [2180] мите_, _pažn, _pasā, škiv,
   {{0x973cb69f,0x6b8701a1,0x2d9936a0,0x394d8580}},	//   _voćk, _cajg, _ense_, _ades_,
   {{0xa91d803a,0x38cb0077,0xa3af0665,0x213fa19b}},	//   _važn, _هایی_, _ओकर_, _beuh_,
   {{0x2005b6a1,0xbbaa946d,0xe8fab6a2,0x765c00b4}},	//   _ahli_, _चक्क, оле_, mury,
   {{0x394036a3,0x7bc19e92,0x6b8736a4,0x394d9670}},	//   _meis_, khlu, _fajg, _ddes_,
   {{0x39401e90,0x6d4436a5,0x394d8009,0xc5f8b6a6}},	//   _leis_, laia, _edes_, ुष्य_,
   {{0xd90d8065,0x5a550098,0x9e06a206,0xdb038980}},	//   لیہ_, _пъту, мчил, _boní,
   {{0x77b4809f,0xdb038473,0x6d4436a7,0x973c8bcf}},	//   _màxi, _coní, naia, _moći,
   {{0x628382c4,0xa06ab69c,0xf1bd8035,0xdb03846d}},	//   _asno, _фаза_, ्फरन, _doní,
   {{0x765c36a8,0x0a6a9a07,0x7bc1b6a9,0x6d44011b}},	//   kury, орми_, ghlu, haia,
   {{0x6d440867,0x973c80d2,0x6fb380d7,0x452a8162}},	//   kaia, _noći, _جملا, _джен_,
   {{0x85068872,0x225185b9,0x24800748,0x69c2b6aa}},	//   _قوان, ázka_, kwim_, nhoe,
   {{0x69dd36ab,0x394000f7,0xc86436ac,0x6d4436ad}},	//   rnse, _deis_, ктри, daia,
   {{0x7655009a,0x7bc1b6ae,0x6004823e,0xdb1ab6af}},	//   trzy, chlu, lòmb, ritó,
   {{0xc1ee80d4,0x05b280d4,0x6d4403cd,0x3940217a}},	//   जवाब_, _जवाब, faia, _feis_,
   {{0xa91d8029,0x6d4436b0,0x973c81a1,0x69d60061}},	//   _ražo, gaia, _doći, ézet,
   {{0x656d36b1,0xe9df00e1,0x261683db,0xa4c0099b}},	// [2190] rfah, mnú_, _पूछी_, rüşü_,
   {{0x2d89067f,0x765c00b4,0xe9df00e1,0x09d78072}},	//   sdae_, bury, lnú_, ढच्य,
   {{0x77b0016d,0x33f40106,0x6d4436b2,0x248d81d0}},	//   _växt, växt_, baia, zvem_,
   {{0xd5a68591,0xe9df36b3,0x9f47823e,0x397c03de}},	//   _صف_, nnú_, roní_, ַטונ,
   {{0xe7eb8076,0xe3b88214,0x394d8168,0x660d2232}},	//   टवला_, kkı_, _vdes_, mmak,
   {{0x660d36b4,0xe9df00f7,0x01c98019,0x65bcb6b5}},	//   lmak, hnú_, _کورٹ_, _réha,
   {{0xfe7189d7,0x7f43818a,0x7bc18282,0xd34600d7}},	//   ادت_, ranq, vhlu, _سینه_,
   {{0x660d36b6,0x2247027f,0x394db6b7,0x91fd00eb}},	//   nmak, ánku_, _udes_, stāj,
   {{0xe9df01ac,0xa924826f,0x6000016d,0x799b8300}},	//   dnú_, _úžas, dömn, _inuw,
   {{0xf77095e4,0x39401313,0xb605816b,0xa3caa135}},	//   _نام_, _seis_, dnáš, रोल_,
   {{0xeb920158,0xa3b70665,0xe299b6b8,0xd5bc046d}},	//   אָר_, _जवन_, чан_, _bọ́_,
   {{0x3ce08025,0xdb070125,0x29d200d2,0x1df9064a}},	//   _žive_, _hljó, ršao_, ंतोष_,
   {{0xbcfb1de2,0x777c002a,0x6e2180b9,0x6d4402df}},	//   _scén, terx, _hulb, vaia,
   {{0x6d44010b,0x7529b6b9,0x29d2026c,0xb4cb83b7}},	//   waia, lcez, pšao_, रछी_,
   {{0x670f800c,0xa91d8024,0x6449b6ba,0x394036bb}},	//   ाधिक_, _pažl, lsei, _teis_,
   {{0x660d36bc,0x973c80c3,0x6e21a86c,0x386902a6}},	//   gmak, _voći, _mulb, _fqar_,
   {{0x6449b6bd,0x6d4436be,0x6b5600f7,0x765c36bf}},	// [21a0] nsei, raia, فضائ, sury,
   {{0x7c2b36c0,0x6d441cb4,0x26cc0548,0x64498a2a}},	//   ígra, saia, údos_, isei,
   {{0xc0a90077,0x6d4420d5,0x69c2b6c1,0x443db5f1}},	//   _فایل_, paia, thoe, _lww_,
   {{0x64a61652,0x5066a1d2,0xdca6067c,0xe046867c}},	//   _зама, етка, _зами, енди,
   {{0x69c286a8,0x248000ee,0x2ac60032,0x201a2b8c}},	//   rhoe, qwim_, _bíbé_, _kipi_,
   {{0x61e410d3,0x6449b6c2,0xc7a382d3,0x69c29e12}},	//   _ljil, dsei, личк, shoe,
   {{0x539b0051,0x442236c3,0xa3dd02f1,0x644b868f}},	//   _צילו, _huk_, तचर_, _avgi,
   {{0x38cb80d5,0x9f4a03fb,0x75fe80f1,0xa91d807a}},	//   _کافی_, dobí_, rëzo, _lažj,
   {{0x69c0b6c4,0x44220110,0x91fd00eb,0x63ae012b}},	//   _ilme, _juk_, stāk, _kobn,
   {{0xa3ca8d38,0x61e4022e,0x442f89ca,0x7ac6a1a7}},	//   रों_, _ajil, _dtg_, есме,
   {{0x19590a14,0xe3b883bf,0x2ec69c2c,0xe9df00e1}},	//   маны_, rkı_, _ثقاف, tnú_,
   {{0x644982af,0x394695d7,0xcc88801c,0x3ce6822c}},	//   bsei, naos_, _tớ_, _txov_,
   {{0x44220b18,0x61e436c5,0xe9df00e1,0x201a00c3}},	//   _nuk_, _djil, rnú_, _bipi_,
   {{0xc5fb05e8,0x6d4f0683,0x6446807a,0x8c1b81c6}},	//   ्ष्य_, _sdca, škis, _זוגי,
   {{0x69c0b6c6,0x442236c7,0x660d36c8,0xd5bb2373}},	//   _olme, _auk_, tmak, пса_,
   {{0x7c228009,0x61e40168,0x3946b6c9,0x6b8ab6ca}},	//   _kuor, _gjil, jaos_, _hafg,
   {{0x660d36cb,0x442219d8,0x6ad900c2,0x3946b6cc}},	// [21b0] rmak, _cuk_, भप्र, daos_,
   {{0x69c0b6cd,0x442203c3,0x7c228081,0xdb150118}},	//   _alme, _duk_, _muor, _alzá,
   {{0xdb03816b,0xdb188216,0x660d36ce,0x29048c53}},	//   _koná, _olví, pmak, _azma_,
   {{0xa2d5053e,0x3e4c800d,0x28d2908a,0x2486826c}},	//   _येण्, dět_, _देहि, _osom_,
   {{0x7c2293cd,0xf8b336cf,0xdb03802a,0x7f4180f1}},	//   _nuor, ुनिय, _moná, _pelq,
   {{0x2d8b0a49,0x9a8736d0,0x69c08a09,0xa91d8110}},	//   _hace_, _публ, _elme, _kažk,
   {{0x973c817f,0x44220102,0x2d8b36d1,0x60000338}},	//   _noću, _zuk_, _kace_, döml,
   {{0x25a936d2,0x2d8b02a5,0x442f9083,0x6449b6d3}},	//   njal_, _jace_, _ptg_, tsei,
   {{0x7c228098,0x1c428084,0x2d8b04b9,0x6d42802e}},	//   _cuor, аным, _mace_, _deoa,
   {{0x61f636d4,0x6449b6d5,0x8b958878,0x6295026c}},	//   _skyl, rsei, трич, _krzo,
   {{0x13098009,0xa2e581e5,0x320902c4,0x920d0035}},	//   ьной_, тонд, _bhay_, सगंज_,
   {{0x7c228098,0x442fb6d6,0x62950b80,0x201a076d}},	//   _fuor, _ttg_, _mrzo, _sipi_,
   {{0x9f4a026f,0x64469f0a,0xef1880eb,0x2d9d8870}},	//   sobí_, škir, _daļu_, _inwe_,
   {{0x4422067f,0x2b4302d4,0x61fd0299,0x00000000}},	//   _ruk_, _nejc_, alsl, --,
   {{0xf74314d6,0x442236d7,0x201a36d8,0x2d8b0041}},	//   ресо, _suk_, _vipi_, _bace_,
   {{0xc692810f,0x2d8b026c,0x63ae36d9,0xdb070216}},	//   סאן_, _cace_, _sobn, _cojí,
   {{0x201a36da,0x2d8b00a4,0xab661505,0x62950333}},	// [21c0] _tipi_, _dace_, квал, _arzo,
   {{0x291fa018,0x44220024,0x2d8b008e,0x35c60035}},	//   _agua_, _vuk_, _eace_, रोज़,
   {{0x68fb9220,0xcf570051,0x0f570158,0x2d8b36db}},	//   _ayud, _בבית_, _ביים_, _face_,
   {{0xa7fb01df,0x25a907d8,0x2d8b0314,0x2c6b8366}},	//   ruñe, cjal_, _gace_, kød_,
   {{0xf993010f,0x64430a20,0x2d80002e,0x3946b6dc}},	//   ירא_, ćnic, meie_, raos_,
   {{0x60048247,0x6d4283a8,0x2d8b36dd,0x2d80004a}},	//   fòma, _seoa, _zace_, leie_,
   {{0x7c228364,0xfaa336de,0x2d8b00a4,0xc7b888ae}},	//   _suor, _каро, _yace_, _niđe_,
   {{0xa2c590a1,0x656436df,0x5e5700be,0x2d8b0118}},	//   ानन्, ngih, דיקע_, _xace_,
   {{0x68fbb303,0x2904b6e0,0x6d4286ae,0x7dde8ec3}},	//   _gyud, _uzma_, _veoa, nīsi,
   {{0x7c228009,0x212000b9,0x2d9d8870,0x32090df6}},	//   _vuor, _agih_, _enwe_, _shay_,
   {{0x2d8001b0,0xdea3804e,0xd7ef80f7,0xa5b300c2}},	//   keie_, _نیوی, _بكل_, _इकलौ,
   {{0x61e2b6e1,0x7c228009,0xb6d980be,0x24868069}},	//   nnol, _tuor, _אַנט, _tsom_,
   {{0x7c2d8457,0x2d8b36e2,0x3f8cb6e3,0x61fd2a92}},	//   _çarp, _race_, _kadu_, rlsl,
   {{0xb8cb249a,0x2d8b0041,0x7dde81a9,0x6b8a8366}},	//   _गप_, _sace_, dīsi, _uafg,
   {{0x8c1b810f,0x32090028,0x3f8c8b20,0x2d8b36e4}},	//   _קווי, _thay_, _madu_, _pace_,
   {{0x69c60352,0xdb1ab6e5,0xf1b98668,0x320902d5}},	//   chke, chtá, _kiše_, _uhay_,
   {{0x33750021,0x25a936e6,0xa5f824c1,0x61e2b6e7}},	// [21d0] лгар, rjal_, тету_, dnol,
   {{0x1ae700ab,0xe1ff36e8,0x248d026c,0x2d8b0041}},	//   _করবে_, lló_, _šems_, _wace_,
   {{0x2d8b04b9,0x798d36e9,0x68fb9400,0x2d8db6ea}},	//   _tace_, _kaaw, _syud, ydee_,
   {{0x61e2b6eb,0xe1ff0019,0x3f9e8041,0xfb1580be}},	//   gnol, nló_, _antu_, אַנט_,
   {{0x80cd8063,0x040d801c,0x518481e5,0x3f8c8102}},	//   _देखे, _cườn, руха, _badu_,
   {{0xa91d8110,0x69d885db,0xa5bb0825,0x040d80ff}},	//   _maži, éver, _bióg, _dườn,
   {{0xf770a779,0xf1b98267,0x44293461,0x661d36ec}},	//   تان_, _aiše_, lqa_, _kisk,
   {{0x661d36ed,0x644d36ee,0x752d36ef,0x3ea98d26}},	//   _jisk, osai, ncaz, ćat_,
   {{0xa3b70076,0x7afc00f1,0xad9b00f7,0x644d36f0}},	//   _जवा_, _zyrt, _chúi, nsai,
   {{0x3f8cb6f1,0x09dc035a,0x69d9b6f2,0x2c6b8edd}},	//   _gadu_, मच्य, liwe, rød_,
   {{0xd9460dd3,0xd57589c7,0x61461597,0xa96a1677}},	//   лени, _буль, лена, нина_,
   {{0x7c958591,0x798d0079,0x644d36f3,0xaca38133}},	//   _مشتا, _caaw, ksai, _alụk,
   {{0xeb8eb6f4,0x753ba7ce,0x798d36f5,0x3f8cb6f6}},	//   _ли_, mbuz, _daaw, _yadu_,
   {{0x69c600f1,0xe80403b7,0xe1ff0216,0x661d30c6}},	//   shke, _शीशा_, aló_, _aisk,
   {{0x6b8184cc,0xe1ff36f7,0x661d36f8,0x3ebe007b}},	//   melg, bló_, _bisk, átt_,
   {{0x61e28085,0x8886148d,0x69d9804f,0x3f8c25ea}},	//   xnol, _ближ, jiwe, ždu_,
   {{0xb0d2809a,0x645bb6f9,0x69c436fa,0x7c29b6fb}},	// [21e0] _देंग, nrui, _ilie, nqer,
   {{0xb6a6223c,0x3ea6045e,0xdb0380e7,0x69c436fc}},	//   _биол, _биог, _conç, _hlie,
   {{0x661d155f,0x644d10eb,0x50d6803d,0x7c3636fd}},	//   _fisk, asai, گزار, spyr,
   {{0x3f8ca236,0x91fd0029,0x249f0024,0xa91da1f8}},	//   _sadu_, stāv, _šume_, _zaži,
   {{0x7bc38006,0x644d36fe,0x69c401ac,0x6d4601a9}},	//   _olnu, csai, _mlie, _ieka,
   {{0x91fd0029,0x61e2a1fa,0x6d4636ff,0x661d016b}},	//   ltāt, snol, _heka, _zisk,
   {{0x6d4636a1,0x26058076,0x69c43700,0xf1c1026f}},	//   _keka, _हीही_, _olie, ášky_,
   {{0x5454ac60,0x645bb701,0x2627826c,0x040d801c}},	//   авит, frui, _gđom_, _tườn,
   {{0xa2d9a3e7,0x973c8088,0x7bc6adab,0x6b81b702}},	//   _फेब्, _anće, ūkum, felg,
   {{0xf1b9803a,0x1ae70a49,0x6d463703,0xef918077}},	//   _više_, _করতে_, _leka, _ویند,
   {{0x69c43704,0xb3458187,0x798d02d5,0xd3778048}},	//   _blie, _seçã, _paaw, учы_,
   {{0x6d463705,0x645b933a,0x8c46954f,0x0446b0be}},	//   _neka, brui, _беде, _бедн,
   {{0x645bb706,0x201eb707,0xa91d8110,0x107403c7}},	//   crui, _kiti_, _paži, бляю,
   {{0xa3e8a885,0x69c43708,0x92948ff7,0x69d9b709}},	//   _यदि_, _elie, _вакц, ziwe,
   {{0x6d46370a,0x4426822e,0xdd9b370b,0x7bda8364}},	//   _beka, _huo_, нша_, mitu,
   {{0x6d46370c,0x44268110,0x7c26370d,0x69c4370e}},	//   _ceka, _kuo_, _bukr, _glie,
   {{0x661d2985,0x2455003d,0x6298b70f,0x24580009}},	// [21f0] _visk, شناس, _hrvo, лать_,
   {{0x644d3710,0x442901b9,0x661d3711,0xf1bf01d0}},	//   rsai, rqa_, _wisk, lká_,
   {{0x644d3712,0x661d3713,0x6d463714,0x44293715}},	//   ssai, _tisk, _feka, sqa_,
   {{0x19598196,0x7bdab716,0xf1bf3717,0x3ebe0bc5}},	//   тады_, hitu, nká_, øtte_,
   {{0x201e8052,0x44268a8e,0xa0a58adb,0x7bdab718}},	//   _biti_, _nuo_, ралд, kitu,
   {{0x6d463719,0x65b5803e,0x201eb71a,0x62988019}},	//   _zeka, _náhr, _citi_, _orvo,
   {{0x74d904c5,0xda05016f,0x8c0a80ab,0x6d46371b}},	//   _नेतृ, रतात_, রদান_, _yeka,
   {{0x4426b71c,0xf2d204de,0x201e8084,0x225c01d6}},	//   _buo_, _ועל_, _eiti_, ávke_,
   {{0x62988364,0x44268052,0xe1348012,0x05a68009}},	//   _arvo, _cuo_, _ынты, рвый_,
   {{0xf77388ca,0x69c4371d,0x7bdab581,0x6721805c}},	//   _دار_, _slie, gitu, _uglj,
   {{0x69c4371e,0x62988699,0x61e9835f,0x2909019d}},	//   _plie, _crvo, _kjel, _azaa_,
   {{0x629882a5,0x645bb71f,0x6b81b720,0x2258b721}},	//   _drvo, prui, selg, árka_,
   {{0x6d460025,0x69c40b3c,0x628aacec,0x629880f3}},	//   _reka, _vlie, _esfo, _ervo,
   {{0x6d460812,0x7bdab722,0x91fd00eb,0x7bc8b723}},	//   _seka, citu, tuāc, chdu,
   {{0x61fbb724,0x69c401b9,0x7c263725,0x2d8fb726}},	//   _okul, _tlie, _sukr, _kage_,
   {{0xf1bf0a56,0x65b581ac,0xceb28039,0x61e9b727}},	//   cká_, _záhr, חיל_, _njel,
   {{0x9f5e8009,0x6fc5816f,0xd7c58072,0xa91d80c3}},	// [2200] _yhtä_, वसां, वसाच, _kažu,
   {{0x2d8fb728,0x61fbb729,0x75fe80f1,0x91fd01a9}},	//   _lage_, _akul, rëzi, grāf,
   {{0x6d460886,0x61e98654,0xbea614bc,0xa9268db4}},	//   _teka, _bjel, _танк, адел,
   {{0x201eb72a,0x61e9920e,0x25adb72b,0xc05a8d13}},	//   _siti_, _cjel, jjel_, вік_,
   {{0x61e9830b,0x201eb72c,0x25a20456,0xd378807d}},	//   _djel, _piti_, _inkl_, liće_,
   {{0x91fd0341,0xd90d80d5,0x7c2480f7,0x44268870}},	//   ntār, ریل_, _éiri, _ruo_,
   {{0x44268698,0x4b7b0bea,0x7bdab72d,0x64428063}},	//   _suo_, _שאלו, vitu, _swoi,
   {{0x2d920205,0x61e9945c,0xbcfb00f7,0x4426b72e}},	//   ndye_, _gjel, _scéi, _puo_,
   {{0x2d8fb72f,0x201eb730,0xbc6780f7,0x7bdaa52a}},	//   _dage_, _titi_, لمين_, titu,
   {{0x62988b5d,0x90e5803d,0xc5e33731,0x201e8162}},	//   _prvo, _اسفن, _गद्य_, _uiti_,
   {{0xe7e38076,0xbeaa8077,0xf1b98353,0x2d8f8041}},	//   कचरा_, _جهان_, _hiša_, _fage_,
   {{0x4426b696,0x7bdab732,0x28db946d,0x6da39541}},	//   _tuo_, situ, _मेडि, _миха,
   {{0x6e28827f,0xe3af819f,0xdb0e0214,0x75d381a8}},	//   _hudb, سری_, _albü, _بينا,
   {{0xf1bf003e,0x2d84b733,0xf1b98390,0x248b008e}},	//   ská_, leme_, _miša_, _rscm_,
   {{0x394b3734,0x69dd3735,0x7bd89d8b,0xadc38091}},	//   pacs_, éres, _imvu, _atẹl,
   {{0xdcfb83bf,0xf99f1b0d,0x2d84b736,0xfa3395a9}},	//   nduğ, rmès_, neme_, _برود,
   {{0x69dd3737,0xf1b9b738,0x6e2889d1,0x600d8020}},	// [2210] mise, _niša_, _ludb, lúme,
   {{0x61fbb739,0x3dc90069,0x60c00bc5,0x69dd138e}},	//   _skul, shaw_, ømme, lise,
   {{0x2003003b,0xe6950013,0x6e950013,0xf1b988ae}},	//   mlji_, _الجد, _الجا, _aiša_,
   {{0x69dd373a,0x6286809a,0xa5bb0333,0xdb0e0216}},	//   nise, łkow, _dióc, _albó,
   {{0x2d8f84b9,0x2d84803e,0x9f51001b,0x260a9995}},	//   _rage_, deme_, hozí_, ातनी_,
   {{0x69dd373b,0x39490c5e,0x7dde80eb,0x490a0fb2}},	//   hise, _leas_, zīst, _सरसो_,
   {{0x2d8fb73c,0x320d804c,0x69dd373d,0x7c2d373e}},	//   _page_, _they_, kise, lqar,
   {{0x59f98009,0x61fb805d,0x3940807b,0xc7b8811f}},	//   _себя_, _ukul, ðist_, _viđa_,
   {{0x7bc704c4,0x69dd0006,0x26c181ac,0x63b50bcf}},	//   _klju, dise, šho_, _kozn,
   {{0x6e28835d,0x39490118,0x25bfb68b,0x3a2002f7}},	//   _fudb, _aeas_, skul_, _siip_,
   {{0x2d8fb73f,0x69dd3740,0x7dde8029,0x63b53741}},	//   _tage_, fise, tīst, _mozn,
   {{0x63b50904,0xd3788253,0x69dd3742,0x2d849e4f}},	//   _lozn, viće_, gise, ceme_,
   {{0x27f83743,0x39490083,0x7bc73744,0xec3580be}},	//   torn_, _deas_, _olju, _פאַר_,
   {{0x7c3bb745,0xd3788289,0x69dd3746,0xdc3680be}},	//   mpur, tiće_, aise, _האסט_,
   {{0xed5a0758,0xada61b1c,0x6da61630,0x75fe8168}},	//   лов_, бавл, бива, rëzv,
   {{0x249f01dd,0x6569b747,0xd3788289,0xe3bf03a8}},	//   _šuma_, ngeh, riće_, _buño_,
   {{0x61f9809a,0xdca31ad3,0xd3788904,0x7bc700ce}},	// [2220] dowl, пати, siće_, _blju,
   {{0x7bc1b748,0x65bc82be,0xd3788289,0x7f8600f7}},	//   nklu, _véhi, piće_, _الدن,
   {{0x63b53749,0xdceb80eb,0xdb0e06c4,0xce9581a9}},	//   _dozn, _angļ, _albò, šējā_,
   {{0x629a2b1f,0x27e981a8,0xdb1c0106,0x9f580168}},	//   _átom, éann_, _omrö, korë_,
   {{0x6e288025,0x28d2824c,0xdb0a8118,0x6604374a}},	//   _sudb, _देखि, _mofá, mlik,
   {{0x824a306f,0x6604374b,0xdfd080f7,0x798634cf}},	//   _مشرف_, llik, بيت_, hekw,
   {{0x7bde374c,0x69dd2acc,0x8f9b0039,0xddcb826c}},	//   mipu, yise, טיסי, _šiši,
   {{0x7bde0886,0x63b50038,0x6604374d,0x69cba89c}},	//   lipu, _zozn, nlik, chge,
   {{0xe3bf07f4,0xdcfb83bf,0x6604067f,0x69dd374e}},	//   _xuño_, rduğ, ilik, vise,
   {{0x7bde03f8,0x325485c2,0xdee68992,0x7bc1b74f}},	//   nipu, овор, _лози, gklu,
   {{0x69dd3750,0x66043751,0xd5af9b5a,0x93fb00be}},	//   tise, klik, _ес_, רליי,
   {{0x645d82ba,0x7bde003d,0xba9b03c8,0x69c2b752}},	//   ásic, hipu, אסטי, nkoe,
   {{0x7bde3753,0x66043754,0x39490511,0x600d8020}},	//   kipu, dlik, _veas_, súme,
   {{0x69dd3755,0x7bc182af,0xcc57810f,0x629c3756}},	//   sise, cklu, _פסוק_, _orro,
   {{0x98a51010,0x7bde3757,0x91fd00eb,0x7bdb8039}},	//   ğlı_, dipu, trād, _תקוו,
   {{0x98a50182,0x66043758,0x1ae700ab,0x7d02838a}},	//   şlı_, glik, _করলে_, _kyos,
   {{0x2003005c,0x545500e8,0xe9df01a8,0x93270061}},	// [2230] plji_, юват, miú_, مران,
   {{0x7bde1b7c,0x61ed2445,0xad9b00f7,0xe9df01a8}},	//   gipu, _hjal, _chúr, liú_,
   {{0x63b5135a,0x387fb759,0xc33381c6,0x7bc702d4}},	//   _vozn, _spur_, פוף_, _vlju,
   {{0xdb038038,0xe9df00f7,0x3949b75a,0x6e22b75b}},	//   _ponú, niú_, úas_, _niob,
   {{0x628e375c,0x7c2d0609,0x629c375d,0x27e985e4}},	//   _esbo, qqar, _erro, éano_,
   {{0x4439375e,0x7bc70042,0x9848a252,0xad9b0f35}},	//   _its_, _ulju, сяца_, _thús,
   {{0x7986375f,0x61ed3760,0x6569b761,0x3ffc03de}},	//   yekw, _ojal, tgeh, אפגע,
   {{0x44230586,0xe4598af2,0xf8bf31c8,0x7d0282a0}},	//   _hij_, ажи_, ncés_, _byos,
   {{0xdb1a80f7,0xa3b00540,0x6e22b762,0x6569b763}},	//   chtú, टॉक_, _diob, rgeh,
   {{0x79863764,0xa3d3800f,0x61ed3765,0x44233766}},	//   wekw, सों_, _ajal, _jij_,
   {{0xf77095e4,0x44230613,0x79863767,0x656f0098}},	//   _سال_, _mij_, tekw, _occh,
   {{0x7c3bb768,0x44230069,0x6e22b769,0x644301dd}},	//   ppur, _lij_, _giob, ćnij,
   {{0x61ed376a,0x79863070,0x4439376b,0x69c9826c}},	//   _djal, rekw, _nts_, _mlee,
   {{0x4423022c,0xee3a266e,0xd9b697a3,0xaa45a2e9}},	//   _nij_, инг_, _अक्ट, _декл,
   {{0x61ed376c,0x69c9b76d,0x6d4b8590,0x6604376e}},	//   _fjal, _olee, _kega, tlik,
   {{0x61ed376f,0x806611c7,0x2251803e,0xe5a30fe7}},	//   _gjal, _движ, ázku_, миси,
   {{0x44231dea,0x66043770,0x7bde1d53,0xd3788024}},	// [2240] _bij_, rlik, tipu, lića_,
   {{0x66043771,0x3f879351,0x6d4bb772,0x69c9b773}},	//   slik, jenu_, _lega, _alee,
   {{0x66043774,0x7bde3775,0x3f87b776,0x44390722}},	//   plik, ripu, denu_, _ets_,
   {{0x7bde3777,0x64a628c4,0x0906802e,0xf6530039}},	//   sipu, _дама, опен, _קצר_,
   {{0x44233778,0x6e22b779,0xd378b77a,0x69c2b77b}},	//   _fij_, _riob, hića_, rkoe,
   {{0x69c995ba,0xd3788289,0xc05980e8,0xa09b03c8}},	//   _elee, kića_, сії_, יינט,
   {{0x600487e2,0xeb910158,0xd37881dd,0x628e020d}},	//   nòmi, _אָן_, jića_, _usbo,
   {{0x44230613,0xd378803b,0x6d4b90e1,0x5d5480b3}},	//   _zij_, dića_, _cega, чкит,
   {{0x6d4bb77c,0x4423022c,0x7c238091,0x6d598365}},	//   _dega, _yij_, _binr, _ddwa,
   {{0x6d59b77d,0x3f87825b,0xd378812b,0x61ed070b}},	//   _edwa, cenu_, fića_, _sjal,
   {{0x6d4bb77e,0xc33302f6,0xd3788042,0x69c98009}},	//   _fega, וות_, gića_, _ylee,
   {{0x7c23ab86,0x6e22826c,0x78a201a9,0xfec20264}},	//   _einr, _uiob, _šova, োপাধ,
   {{0xa5078ae7,0xe9df0013,0x6443005c,0xc95384de}},	//   _деца_, riú_, ćnik, ומר_,
   {{0xd7fb138c,0x29050029,0xd378812b,0xe9df00f7}},	//   рум_, āla_, bića_, siú_,
   {{0xcddb19e6,0x442300f3,0x7c2b8398,0xa3ae1199}},	//   ања_, _rij_, _zugr, कान_,
   {{0x442301c5,0x442b0722,0x7bdc2fe3,0x7dce8229}},	//   _sij_, _puc_, _amru, _dùsg,
   {{0x44230282,0x61fd0a96,0x92e700c8,0x7e6701c0}},	// [2250] _pij_, mosl, _পরে_, sujp,
   {{0x4423377f,0x69c9b780,0x7a330609,0x9f430216}},	//   _qij_, _slee, _aħta, rojó_,
   {{0x69c9b781,0x442329c8,0x8ae7035f,0x443902f7}},	//   _plee, _vij_, ціал, _wts_,
   {{0x44230613,0x61fd3782,0xbcfb00e1,0x442b00ff}},	//   _wij_, nosl, _dcér, _tuc_,
   {{0x44233783,0x8fa58d13,0x4439008e,0x69c983b2}},	//   _tij_, зале, _uts_, _vlee,
   {{0x6d4b885c,0x2904831d,0x94ba0039,0x9f4780e7}},	//   _sega, _dyma_, _המשת, onné_,
   {{0x3f878289,0x9258038d,0x6d4ba62a,0xed59b784}},	//   renu_, _март_, _pega, бой_,
   {{0xd378803b,0x656d3785,0xd90e8065,0x21290748}},	//   vića_, ngah, ئیے_, _ngah_,
   {{0x6d4bb786,0x2054ad94,0x478b8009,0x3f879f0a}},	//   _vega, _октя, _всем_, penu_,
   {{0xd3788067,0x63b881c0,0x6d4bb787,0xf1b9826c}},	//   tića_, _covn, _wega, _hoš_,
   {{0x88bd80ab,0x7bc53788,0x9f4e03c1,0x6b950612}},	//   _অধিক, ikhu, áním_, _mazg,
   {{0xf1b9803a,0x22470ed7,0xd3788024,0x20010359}},	//   _još_, ánky_, rića_, _akhi_,
   {{0xa3dc05b3,0x64a599b8,0x394dab1d,0xd378812b}},	//   तोड_, _хала, _mees_, sića_,
   {{0x394db789,0x443f8812,0x4375893f,0xf1b9805c}},	//   _lees_, mpu_, _זײַן_, _loš_,
   {{0x443fb78a,0x6012007b,0x61fd378b,0xc33283de}},	//   lpu_, væmd, bosl, _אוו_,
   {{0xc8bd89a3,0x25a6040e,0x394d8282,0x69cf026f}},	//   ्नाट, ñol_, _nees_, chce,
   {{0x6b950115,0x2ea883e8,0x443f8176,0xdd8f0b8c}},	// [2260] _bazg, _कप्त, npu_, دوق_,
   {{0xdb0383d3,0x389b010f,0x60001cce,0x3a24b78c}},	//   _anné, _פיינ, röms, _simp_,
   {{0xf1b98353,0xd36f0154,0x394d9b00,0xc7b8811f}},	//   _boš_, اهم_, _bees_, _rođ_,
   {{0x2d89378d,0xa96a8f27,0x69c615c8,0x3f8a378e}},	//   ceae_, сида_, nkke, lebu_,
   {{0x6d441d03,0x394db78f,0x68438329,0xbcfb026b}},	//   mbia, _dees_, енча, _adéf,
   {{0x6d440110,0x3f983790,0x6e2602d5,0x64560034}},	//   lbia, ndru_, _hikb, msyi,
   {{0x3a248012,0x63b8803e,0x09cc035a,0xd946a0e4}},	//   _timp_, _rovn, ासाठ, _неви,
   {{0x394db791,0x6fcb01cc,0x3a24816a,0x3f8a3792}},	//   _gees_, _müca, _uimp_, hebu_,
   {{0x69dd02be,0x64563793,0x443f82d5,0x48ce0264}},	//   èrem, nsyi, gpu_, রপুর,
   {{0x5a348572,0x6f668073,0x799605ee,0x61e2b794}},	//   мнот, _ѕвез, _aayw, liol,
   {{0xa5bb0207,0x7f3b8039,0x799602d5,0x60c2a015}},	//   _biól, _העבו, _bayw, lyom,
   {{0x394d822c,0x61e2b795,0x25a68114,0xdceb02d4}},	//   _xees_, niol, _unol_, _žičn,
   {{0x60c2b796,0xdca39c9b,0x61fd1b5f,0x2bd9809a}},	//   nyom, _паци, rosl, योहा,
   {{0xb7bd802e,0x6fbe80d4,0x3f8a3797,0x61e2b798}},	//   _puţi, ्सिं, gebu_, hiol,
   {{0x644086a8,0xbcfb0118,0xddd03799,0x61e2b79a}},	//   lpmi, _acép, _šeši, kiol,
   {{0xb8e30a49,0x6d44379b,0x76550035,0x69c60192}},	//   _এই_, gbia, rszy, ckke,
   {{0x57f5120c,0x394db79c,0x69df0609,0xb0db8a27}},	// [2270] _опит, _rees_, _imqe, _मेंग,
   {{0xfe6e19f7,0xa3d7000f,0x60cf080a,0x76550035}},	//   دگی_, ़ों_, ınmı, pszy,
   {{0x6d44379d,0x6602b79e,0x394db79f,0x6b9502d0}},	//   bbia, _okok, _pees_, _vazg,
   {{0xe8d937a0,0x61e2847f,0x394d8282,0x27e301ed}},	//   _ndị_, giol, _qees_, lijn_,
   {{0x394db7a1,0x315800be,0x60c28019,0xf1b98af8}},	//   _vees_, ליאן_, gyom, _hišk_,
   {{0x394d84df,0x660290ab,0xe8d90870,0xbcfb046d}},	//   _wees_, _akok, _adị_, _adég,
   {{0x6d4f0397,0xdd918117,0x69c60b40,0x629a37a2}},	//   _keca, ہوں_, ykke, _štov,
   {{0xf1948153,0x7c2737a3,0x8459b7a4,0x38608503}},	//   _пись, _hijr, орот_, šira_,
   {{0x8554803d,0x225800cd,0x799600fc,0x6f0901d0}},	//   ریور_, _zvrk_, _rayw, řech,
   {{0x6d4f37a5,0x69cd0d62,0x443fb7a6,0x3e578162}},	//   _leca, _alae, rpu_, păt_,
   {{0x7c2f0c6e,0xa18a2c39,0xa3ae36cf,0x69cd031d}},	//   _lucr, обна_, कात_, _blae,
   {{0x443f8fc0,0x69cd37a7,0x6d4f37a8,0x88e60ca0}},	//   ppu_, _clae, _neca, джме,
   {{0x661bb7a9,0xc4fb803d,0x69c60198,0x6609b7aa}},	//   mmuk, _اعضا_, rkke, mlek,
   {{0x69cd02c4,0x661bb7ab,0x8b0381d0,0x7d061c99}},	//   _elae, lmuk, ářsk, _ryks,
   {{0xf77209d7,0x6d4f3672,0x2bda8077,0x442fb7ac}},	//   _یاد_, _beca, _بانک_, _hug_,
   {{0x4427b7ad,0x6d4f37ae,0x7e61007b,0x6609b7af}},	//   _hin_, _ceca, álpa, nlek,
   {{0x6d442cbe,0xe3ba0cf3,0xfce30195,0x442fb7b0}},	// [2280] rbia, оба_, вото, _jug_,
   {{0x44278b1b,0x8bf100c8,0x64561600,0x7d060110}},	//   _jin_, _জীবন_, rsyi, _vyks,
   {{0x442fb7b1,0x9f5c80f1,0x7c2f0118,0xbcfb2730}},	//   _lug_, sovë_, _eucr, _adéd,
   {{0x4427b7b2,0x6609b7b3,0x9f5c83c1,0x661b80b9}},	//   _lin_, jlek, mové_, jmuk,
   {{0x9f5c803e,0xa3bf897d,0x645d816b,0x443d81c0}},	//   lové_, ीसा_, ásil, _ntw_,
   {{0x4427b7b4,0x6609b7b5,0x8fa38878,0xd8d737b6}},	//   _nin_, elek, каче, וונט_,
   {{0xdb03a755,0x9f5c827f,0x34b88bb8,0xd6d080f7}},	//   _monó, nové_, ेन्द, طقة_,
   {{0xd5b08307,0x4427b7b7,0x27e301ed,0x661b977c}},	//   افة_, _ain_, zijn_, gmuk,
   {{0x4427b7b8,0x442f8640,0x9f5c826f,0xf41f0338}},	//   _bin_, _cug_, hové_, _isär_,
   {{0x63bc0a3e,0x9f5c83cb,0x39468110,0xa3d8809a}},	//   _jorn, kové_, lbos_, ठों_,
   {{0xbcfb37b9,0x9f5c826f,0x2fd7803d,0x69cd37ba}},	//   _idée, jové_, _تولد_, _plae,
   {{0x4427b7bb,0x9f5c83fb,0x3ce08289,0x8c4687b6}},	//   _ein_, dové_, _živu_, _жеде,
   {{0x6d4f1520,0x29f8b7bc,0x443d808e,0xdb18802a}},	//   _reca, mčad_, _gtw_, _mové,
   {{0x6d4f1a6e,0x4427b7bd,0x9f4300f1,0xdb038388}},	//   _seca, _gin_, mijë_, _conó,
   {{0xd5bb37be,0x7c2f3181,0xdb038118,0x9f5c85b9}},	//   оса_, _sucr, _donó, gové_,
   {{0x4427b7bf,0xdb18827f,0xca2980be,0x29f8811f}},	//   _zin_, _nové, _צופֿ, nčad_,
   {{0x63bc37c0,0x4427a80a,0x6d4f37c1,0x62978118}},	// [2290] _born, _yin_, _veca, _áxor,
   {{0x2fc70104,0x44278028,0x60c000f2,0x9f5c826f}},	//   _ông_, _xin_, ämme, bové_,
   {{0x3d0583bb,0x386680ee,0x63bc37c2,0xddc38087}},	//   _हुने_, eror_, _dorn, nunţ,
   {{0x6d5d006a,0x6eae001b,0x2909008e,0xf1b980ce}},	//   _udsa, ीहरु, _kyaa_, _kiši_,
   {{0xdd3a0051,0x63bc080e,0x798bb7c3,0x6609941f}},	//   _מערכ, _forn, regw, vlek,
   {{0x2d990079,0xe7398b9b,0xe8d9019d,0xe61180d7}},	//   _hase_, чек_, _ndọ_, گشت_,
   {{0x4427b7c4,0x2d9937c5,0x27e981dd,0x442fb7c6}},	//   _rin_, _kase_, đan_, _sug_,
   {{0x4427b7c7,0xdcf380fe,0xdceb81cd,0xe8d901bc}},	//   _sin_, šače, _jagħ, _adọ_,
   {{0x6609b7c8,0x661b9e92,0xdceb81cd,0x9f5c826f}},	//   rlek, rmuk, _magħ, zové_,
   {{0xe3b18307,0x63bc37c9,0x2d9937ca,0xe8bd8540}},	//   ارة_, _xorn, _lase_, ्नीच,
   {{0x29090962,0x4427b7cb,0x2bb1809a,0x6609b7cc}},	//   _ayaa_, _vin_, जाबा, plek,
   {{0x442f81e9,0x9f5c826f,0xf99f0247,0x9f4781a8}},	//   _tug_, vové_, blèm_, inní_,
   {{0x4427b7cd,0x30750d91,0x2ec81d6a,0x1c4485a8}},	//   _tin_, курс, रन्त, _анім,
   {{0x9f5c803e,0x4427b7ce,0x6aae81a8,0x25bd81b4}},	//   tové_, _uin_, óifí, _howl_,
   {{0xa3ae2b38,0xb90722bd,0xf8bd800d,0x39468110}},	//   कास_, _ये_, ्नुप, ybos_,
   {{0x9f5c803e,0x2d9937cf,0x212d90e1,0xdb1c00e7}},	//   rové_, _case_, _ngeh_, _forê,
   {{0xa3c3835a,0x3dd20355,0x9f5c803e,0x7de8801b}},	// [22a0] _एका_, rhyw_, sové_, měst,
   {{0xdcea812b,0x61e637d0,0xfc3f0013,0x395f90f0}},	//   šiće, likl, _dtí_, _adus_,
   {{0xa3dc058c,0x63bc01ec,0x160fa120,0x6600a12e}},	//   तोष_, _vorn, ातार_, yomk,
   {{0x3f9a37d1,0x61e60255,0x629a00c3,0xfb1683de}},	//   _hapu_, nikl, _štos, ײַבט_,
   {{0x63bc37d2,0xe8948ca0,0x6d5637d3,0xa927835f}},	//   _torn, таль, maya, ніше_,
   {{0x2d9921f8,0x2d8037d4,0xdb03823e,0x644437d5}},	//   _zase_, lfie_, _anní, mpii,
   {{0xaade8105,0x3f9a21d1,0xdb1c0168,0x61e637d6}},	//   _फेंक, _mapu_, _morë, kikl,
   {{0xceb30051,0x6d5637d7,0x442a0133,0xa3ae11bc}},	//   ריה_, naya, _hib_, काव_,
   {{0x442a37d8,0x61e637d9,0x18678073,0xd1758084}},	//   _kib_, dikl, _пати_, _шыры,
   {{0x6d5637da,0x3a29059c,0x442a056c,0xb3469243}},	//   haya, _siap_, _jib_, diçõ,
   {{0x6d5602e8,0x78a437db,0xd257804a,0x2ca002f1}},	//   kaya, _ariv, нця_, hvid_,
   {{0x442a37dc,0x6d5636a1,0x78a437dd,0x3e7a8168}},	//   _lib_, jaya, _briv, mët_,
   {{0x7dca003e,0x6d5637de,0x3e7a820f,0x1ae700c8}},	//   _výsl, daya, lët_, _করছে_,
   {{0x442a37df,0xf1b98024,0xb4be864a,0x78a437e0}},	//   _nib_, _viši_, ीनी_, _driv,
   {{0x2d990205,0x3a290057,0x2d802de2,0x3e7a80f1}},	//   _pase_, _tiap_, ffie_, nët_,
   {{0x6d561f36,0x32538698,0xb3468073,0x78a40370}},	//   gaya, _свър, biçõ, _friv,
   {{0xf3670758,0x442a03ec,0x3e7a80f1,0xdb15026f}},	// [22b0] етен, _bib_, hët_, _vozí,
   {{0x442a37e1,0x3e7a820f,0x667200d7,0x7c2a8372}},	//   _cib_, kët_, دگیر, _jifr,
   {{0x442a02a3,0xdcebb086,0x6d5637e2,0x3e7a80f1}},	//   _dib_, _tagħ, baya, jët_,
   {{0x200337e3,0x799d37e4,0x6d5637e5,0x7de7810c}},	//   loji_, ndsw, caya, _mèsè,
   {{0x660d37e6,0x249f03a7,0x799d198b,0x7dda128a}},	//   mlak, _éum_, idsw, růst,
   {{0x660d37e7,0x61e637e8,0xdee584ae,0x442a37e9}},	//   llak, zikl, коли, _gib_,
   {{0xa3ae0d86,0x34c98bb8,0x3e7a8168,0xddd48088}},	//   कार_, िन्द, gët_, _šaši,
   {{0x442a0282,0x4ce280ab,0x660d37ea,0x4c85b7eb}},	//   _zib_, _পড়ু, nlak, влив,
   {{0x61e606be,0x442a022c,0xc8e00540,0x7c2a808b}},	//   vikl, _yib_, _पेंट, _bifr,
   {{0xad9b01fa,0xd7598b76,0x660d005d,0x20030803}},	//   _skúl, _آلات_, hlak, joji_,
   {{0x6d5637ec,0x7c2aacc4,0x27e7807b,0xa96a0e0b}},	//   yaya, _difr, minn_, мина_,
   {{0xe3b18bca,0x660d0024,0x27e7b7ed,0x3f9a3745}},	//   ارک_, jlak, linn_, _sapu_,
   {{0xeb8e9e0b,0x660d37ee,0x1a65819f,0x61e637ef}},	//   _ки_, dlak, ریکی_, rikl,
   {{0x20030db7,0x6d562c30,0xb34683a7,0x777703a8}},	//   goji_, waya, riçõ, _ccxx,
   {{0x6d5637f0,0xb34683a7,0xa3d686af,0x645d0711}},	//   taya, siçõ, _सतत_, _avsi,
   {{0x442a10af,0x660d2277,0x27e78046,0x799bb7f1}},	//   _sib_, glak, hinn_, _nauw,
   {{0xa3ae09a3,0x442a01c5,0x6d5637f2,0x27e7807b}},	// [22c0] काल_, _pib_, raya, kinn_,
   {{0x6d5637f3,0x442a0069,0xa3dc0063,0x80db37f4}},	//   saya, _qib_, तों_, _যুক্,
   {{0x6d5637f5,0x442a0282,0x799bb7f6,0x81f7004e}},	//   paya, _vib_, _bauw, _سفیر_,
   {{0x442a0e60,0x5e570158,0x6e2b877f,0x6d5601b4}},	//   _wib_, _ביטע_, _nigb, qaya,
   {{0x442a01e9,0xf1b9a3b8,0xf772803f,0x6d49b7f7}},	//   _tib_, _nišu_, لاغ_, dbea,
   {{0x27e7b7f8,0x3e7a80f1,0x6e2b8091,0xf09303c8}},	//   ginn_, tët_, _aigb, ינד_,
   {{0x61e400ce,0xf1b9826c,0xbcfb37f9,0xd6cf80a0}},	//   _omil, _aišu_, _idéa, يقه_,
   {{0x3e7a88cf,0x6b9c37fa,0x7c2ab7fb,0x2bca99eb}},	//   rët_, _harg, _sifr, िस्थ,
   {{0xb4be913d,0xb4cc81fe,0x6b9c37fc,0xd3788289}},	//   ीने_, रने_, _karg, lići_,
   {{0x61e437fd,0x69c0b7fe,0xf1b98699,0x27e781e4}},	//   _amil, _home, _dišu_, cinn_,
   {{0x6d49b7ff,0xd6c48bca,0xa3e3923a,0xa3c38006}},	//   bbea, _حمای, _नगर_, _एकर_,
   {{0x6b9c35cf,0xdb1c3800,0x3869b801,0x6e2b8915}},	//   _larg, _coré, šare_, _gigb,
   {{0xdb151727,0xdb1c12b6,0x2d86810c,0xd3788140}},	//   _mozá, _doré, _iboe_, hići_,
   {{0x61e43802,0x5ba38698,0xbcfb00f7,0xa3e1824c}},	//   _emil, _връз, _ndéa, नोद_,
   {{0x27ed003b,0xdd9b0791,0x660d3803,0x9e07035f}},	//   đen_, мша_, tlak, вчал,
   {{0xd378805c,0x2ba68beb,0x973c8115,0x59670081}},	//   dići_, _कोता, _inću, _ръка,
   {{0x660d2853,0xa3ae00d4,0x629a3804,0x24580009}},	// [22d0] rlak, कां_, _štop, кать_,
   {{0x6b9c10dd,0xd3789487,0x39593805,0xfc3f0511}},	//   _carg, fići_, lass_, _cría_,
   {{0x6b9c3806,0x799bb807,0x69c0a1c2,0x656281d6}},	//   _darg, _pauw, _bome, _odoh,
   {{0x249f00fe,0xf99f06c0,0xf1b989d1,0xa11581a8}},	//   _šumu_, ndè_, _ništ_, هوات,
   {{0x27e7b808,0x69cb83b2,0xfc3f2b74,0xa0698254}},	//   tinn_, rkge, _fría_, хала_,
   {{0x6b9c3809,0xd37882a5,0x628a806a,0xa3ae380a}},	//   _garg, bići_, _opfo, काः_,
   {{0x27e7b80b,0x69c0b80c,0x2bb18076,0x7dd5b80d}},	//   rinn_, _fome, जासा, _láse,
   {{0x27e7b80e,0x2ca6811f,0xf1b98024,0x69c0b80f}},	//   sinn_, _brod_, _pišu_, _gome,
   {{0x6d49b810,0x9f478168,0x3f910102,0x6b9c02d0}},	//   rbea, ninë_, kezu_, _yarg,
   {{0x69c08a0f,0x6d4981e4,0xf1b980ce,0x249900ee}},	//   _zome, sbea, _višu_, _mssm_,
   {{0x39ea0ae7,0xdb1c0548,0x44211a2f,0x42260193}},	//   едно_, _poré, imh_, лдов,
   {{0x9f4e003e,0x186a11d2,0x7dca03f2,0xceb280be}},	//   čník_, нами_, _výsk, _ליב_,
   {{0xc60f86b7,0xa91d8110,0x6fcb01ec,0xd37880d2}},	//   ातीय_, _pažy, _küch, zići_,
   {{0xaae4803d,0x3a2d81ed,0x66e63811,0x2d9d867f}},	//   اسیو, _liep_, гога, _hawe_,
   {{0x2d9db812,0xf7430098,0x660430a2,0xcb5681c6}},	//   _kawe_, сесо, toik, _עסקה_,
   {{0xd3788052,0x2d9fb813,0xa01b0019,0xed598088}},	//   vići_, ndue_, gtöb, naž_,
   {{0xd4671289,0x5baa03c7,0xb38607b6,0x6b9c3814}},	// [22e0] лите_, нкам_, ллал, _parg,
   {{0x69c0b815,0xd378812b,0x3ce68006,0x5eff00c2}},	//   _some, tići_, _जइसे_, _शुक्_,
   {{0x68fb87f4,0x69c0a3fa,0x6b9c3816,0x63bc9252}},	//   _axud, _pome, _varg, örni,
   {{0xc693093f,0x6b9c3817,0x4421061f,0x2d9db818}},	//   _פאר_, _warg, amh_, _nawe_,
   {{0x2d923149,0x17548c40,0x3a2d837a,0xd7e68d8e}},	//   meye_, авля, _diep_, ліко,
   {{0x6fcb02af,0x78a2816b,0x2d9d8032,0x69c0b819}},	//   _rück, rvov, _aawe_, _wome,
   {{0x6442b81a,0x2480381b,0xb4cc8a27,0xe8d901bc}},	//   _stoi, ltim_, रन्_, _ibụ_,
   {{0x2d923149,0x225c026f,0xa3d686b7,0x25a0381c}},	//   neye_, ávku_, _सतह_, ndil_,
   {{0x98a39e58,0x2480381d,0xf74692b2,0x7c2e381e}},	//   _лите, ntim_, _безо, _kibr,
   {{0x7c2e381f,0x320698b3,0x248002d5,0xdcef0669}},	//   _jibr, looy_, itim_, šeće,
   {{0x3f910052,0x8646a8c4,0x2d923820,0x3f9e80b9}},	//   vezu_, _снеж, keye_, _iatu_,
   {{0x24803821,0x7c2e360b,0xf6518117,0x2d9db822}},	//   ktim_, _libr, _گئے_, _gawe_,
   {{0x7c2e0013,0x3f91007d,0x3f9e8a36,0x24803823}},	//   _oibr, tezu_, _katu_, jtim_,
   {{0x3940026c,0x3f9eb824,0x7d0686ae,0x39593825}},	//   _efis_, _jatu_, üksu, sass_,
   {{0x6298803b,0xa3ae0697,0x2d9db13e,0x39590687}},	//   _usvo, काई_, _yawe_, pass_,
   {{0xf9931e7b,0x7c2e00f7,0x3f9e80eb,0xe8d90870}},	//   _طبع_, _aibr, _latu_, _abụ_,
   {{0x442e81cd,0x3b5536ac,0x4421008e,0x7c2e0f3e}},	// [22f0] _kif_, икар, tmh_, _bibr,
   {{0x9f47820f,0x3f9eb826,0x7c2e3827,0x3a2d8299}},	//   rinë_, _natu_, _cibr, _siep_,
   {{0x06bf00c8,0x9f4780f1,0xa5bb0825,0x93880084}},	//   _উইকি, sinë_, _biót, ыста_,
   {{0xaca3019d,0x7dd5a769,0x9f47b828,0xd37880ce}},	//   _agụb, _másc, pinë_, miću_,
   {{0x3f9e9067,0x6d4d2394,0xd37881dd,0x9f47b727}},	//   _batu_, mbaa, liću_, liné_,
   {{0xdcfd0029,0x7c2e3829,0xf77191cc,0x764500f1}},	//   _lasī, _gibr, زات_, _kthy,
   {{0x45d598a0,0x3f9eafa3,0xd378812b,0x3a2d8129}},	//   ицит, _datu_, niću_, _tiep_,
   {{0x6d4d02b5,0xb88681d0,0x442eb82a,0x4465a39c}},	//   nbaa, _sníž, _aif_, авив,
   {{0x851fb82b,0x61eb8098,0xed598916,0x3f9eb82c}},	//   मेंट_, migl, raž_, _fatu_,
   {{0x2d9db13e,0x442e80fc,0xa5bb00f7,0x2d92382d}},	//   _wawe_, _cif_, _fhóg, zeye_,
   {{0x629ea007,0x6d4d05f8,0xd378811f,0x6b600061}},	//   _špor, kbaa, jiću_, lágí,
   {{0xd3788024,0x9f47b82e,0x78a9b82f,0x61ebb830}},	//   diću_, diné_, _krev, nigl,
   {{0x9f5c803e,0x20078006,0x6d5b8b99,0x6d4d344c}},	//   lová_, ooni_, maua, dbaa,
   {{0x2007b831,0xd378812b,0x6d5bb832,0xbcfb046d}},	//   noni_, fiću_, laua, _adéo,
   {{0xed5a00af,0x9f5c803e,0x2d923820,0x9f47b833}},	//   ков_, nová_, teye_, giné_,
   {{0x7bc38125,0x2007a869,0x38608289,0x78a9ae08}},	//   _honu, honi_, širi_, _orev,
   {{0x7bc3b834,0x2007b835,0x69d60065,0x2d923149}},	// [2300] _konu, koni_, _ilye, reye_,
   {{0x2007b836,0x69aa05b3,0x9f5c827f,0x2d923837}},	//   joni_, _जोती, ková_, seye_,
   {{0x7f5c0e99,0xeb9722e9,0x3f9eb70c,0x24803838}},	//   marq, рих_, _ratu_, stim_,
   {{0x3f9e848f,0x22518efc,0xa96a8b26,0x6d5b8590}},	//   _satu_, ázky_, тида_, jaua,
   {{0x78a9b839,0x7c2e383a,0x386080f7,0xad9b026b}},	//   _crev, _tibr, éir_, _akúw,
   {{0x78a9a3fa,0x7f5c1883,0x60000198,0x26170036}},	//   _drev, narq, tömy, nçon_,
   {{0x61ebb83b,0x442eb83c,0xd9109e5c,0xd1768198}},	//   bigl, _rif_, _کیش_, _вызы,
   {{0x3f9e80f6,0x69d9b83d,0xa3ae0076,0x69c413df}},	//   _watu_, chwe, काक_, _noie,
   {{0x3f9e8d4c,0x030b809a,0x20078dc4,0x2e3c007b}},	//   _tatu_, _सुबह_, boni_, _líf_,
   {{0x9f5c826f,0xa5bb00f7,0x2007b83e,0x7dd58187}},	//   bová_, _thóg, coni_, _pásc,
   {{0x1fb5ac18,0xbcfb383f,0x7bc3b840,0x98a20085}},	//   _устр, _adél, _donu, dakı_,
   {{0xd378803b,0x644601dd,0x6d5bb349,0x973c8b80}},	//   viću_, _otki, caua, _daće,
   {{0xa3e7000f,0x90980656,0x2b06b841,0x7dd13842}},	//   _बगल_, авят_, _सुरु_, _såso,
   {{0xd378a8d2,0x9f4780d7,0x9217141b,0x628e0fb0}},	//   tiću_, tiné_, _धीरज_, _opbo,
   {{0xc6a41ff3,0x69d623a2,0x799f3843,0x6d4d3844}},	//   орти, _flye, _taqw, tbaa,
   {{0xd3788289,0x69c40102,0xcdd804ae,0x9f479abb}},	//   riću_, _goie, ању_, riné_,
   {{0xdce6084a,0x6d4d0c11,0xf94a0158,0x2007b845}},	// [2310] _bakı, rbaa, _געפֿ, yoni_,
   {{0x6d4d206b,0xd79500f7,0x69c400f3,0x3ceb016f}},	//   sbaa, _الدخ, _zoie, _घेणे_,
   {{0x644607d9,0x69d98234,0x6d4d0cfa,0xfc3f0511}},	//   _etki, thwe, pbaa, _trío_,
   {{0xf993803d,0x7dd8001b,0x9f5c816b,0x69c4002a}},	//   تبط_, _píse, vová_, _xoie,
   {{0xf99f009f,0x2d8b01c0,0x61ebb846,0x98a5b847}},	//   llès_, _ibce_, rigl, силе,
   {{0x61ebb848,0x9f5c9c32,0x78a98390,0x6aaa8428}},	//   sigl, tová_, _vrev, _orff,
   {{0x44390bfa,0x2007b849,0x6d5bb84a,0xe61f001c}},	//   _hus_, roni_, taua, _khô_,
   {{0x7bc3b84b,0x78a9b84c,0x4439384d,0x2007b84e}},	//   _sonu, _trev, _kus_, soni_,
   {{0x7bc3b84f,0x61e9b850,0xdce607d9,0x44393851}},	//   _ponu, _imel, _yakı, _jus_,
   {{0x4439146a,0xa3e18df4,0x7bc3b852,0x395d9393}},	//   _mus_, नों_, _qonu, laws_,
   {{0x443910af,0x6449b853,0x44313854,0x2d8b222f}},	//   _lus_, spei, _miz_, _obce_,
   {{0x4439023e,0xbcfb0032,0x3cfd81c5,0x6449b855}},	//   _ous_, _adém, _txwv_, ppei,
   {{0x44390069,0x61e98133,0xc884817b,0x53a5802e}},	//   _nus_, _mmel, cağı_, _галб,
   {{0x7bdab5a7,0x6d598072,0x61fb8289,0x248f80b9}},	//   chtu, _hewa, _ljul, _ipgm_,
   {{0x44393856,0xdb188117,0x6d59b857,0x7dd5803e}},	//   _aus_, _tová, _kewa, _zása,
   {{0x25bf9abb,0x443100eb,0xdce602d0,0x44393858}},	//   njul_, _aiz_, _sakı, _bus_,
   {{0x4431173c,0x6d59b859,0x4439385a,0x2b580019}},	// [2320] _biz_, _mewa, _cus_, _perc_,
   {{0x4439385b,0x61e9b85c,0x6d598890,0xf1a9803d}},	//   _dus_, _amel, _lewa, یانه_,
   {{0x4439385d,0x44310073,0x6fd0016d,0x479b03c8}},	//   _eus_, _diz_, _läck, _גייס,
   {{0x2617385e,0x200a385f,0x29f88bcf,0xa3a80f12}},	//   nçol_, lobi_, rčao_, _खोर_,
   {{0x1cba030f,0x4fc68c07,0xc7c688cc,0x06e580c8}},	//   _صاحب_, йска, йски, _পুলি,
   {{0x161c023c,0x61e9b860,0x43751bf5,0x29f8826c}},	//   _भीतर_, _emel, _муст, pčao_,
   {{0x44393861,0x6d59b5cd,0xe0df01e8,0x2fc582d4}},	//   _zus_, _bewa, zzò_, _dolg_,
   {{0x443901e9,0x6d5980a4,0x6fd012d2,0x7dd58333}},	//   _yus_, _cewa, _bäck, _pása,
   {{0x6d598812,0x443901e9,0xbcfb026b,0xea010129}},	//   _dewa, _xus_, _adéj, _quậy_,
   {{0x6fd00106,0x9b588073,0x44313862,0x249d8176}},	//   _däck, шиот_, _xiz_, _dswm_,
   {{0x66098fb0,0x51f900e8,0x200a3863,0x91fd01a9}},	//   boek, иною_, dobi_, krāt,
   {{0x6d59b864,0x7bdab31d,0xf2d300be,0x386081a1}},	//   _gewa, shtu, פער_, širu_,
   {{0x6e3ab865,0xb4db046d,0xb87b01d6,0x63bca578}},	//   _hutb, _afàn, dzíc, örns,
   {{0xa3a809a3,0x63ad80fc,0x3fe70264,0x03a38162}},	//   _खोल_, _ɗank, পক্ষ, _ничо,
   {{0x44393866,0xd35b8bea,0x48e90074,0xe2468250}},	//   _sus_, _גדול, _चेरो_, _اختي,
   {{0x44310182,0x44393867,0xdb0a823e,0x395d8282}},	//   _siz_, _pus_, _infà, xaws_,
   {{0xf1f800d5,0x71f80829,0x320b009a,0x44390069}},	// [2330] _دعوت_, _دروس_, mocy_, _qus_,
   {{0x66098a0f,0x6fd002af,0x200a010c,0x44393868}},	//   zoek, _näch, cobi_, _vus_,
   {{0x6fb5003d,0x443101d0,0xe5350150,0x4439003d}},	//   _همکا, _viz_, _мень, _wus_,
   {{0x4439146a,0x7dd10022,0x6fcb0214,0x3f8c985b}},	//   _tus_, _måsk, _vücu, _abdu_,
   {{0x7dca027f,0x44390006,0x6d5f3869,0x9ccb01bb}},	//   _výst, _uus_, maqa, _сына_,
   {{0x644d0d17,0x6d59b86a,0x6fd000f2,0x6e3a8122}},	//   mpai, _sewa, _räck, _butb,
   {{0x2fc58b3c,0x7ac40056,0x6d599295,0x644d386b}},	//   _volg_, _есте, _pewa, lpai,
   {{0xa2d786ab,0x61e9b86c,0x1c459017,0x59f98009}},	//   मनस्, _umel, оним, _тебя_,
   {{0x644d386d,0x22478b99,0x6609b86e,0x386081a8}},	//   npai, _stnk_, roek, áirt_,
   {{0x7ff78277,0xdb1c12da,0xd2658ada,0x660981b0}},	//   _اسرا, _horá, окой, soek,
   {{0x6285386f,0x6d598562,0xdb1c2825,0x78ad3870}},	//   ntho, _tewa, _korá, _arav,
   {{0x6fd0016d,0x7bc73871,0x249d8282,0x62850428}},	//   _täck, _loju, _tswm_, itho,
   {{0x200a046d,0x394d0e15,0x62850362,0xb915826b}},	//   tobi_, ñesa_, htho, _agbẹ_,
   {{0x34b283f8,0x2329b872,0x78ad011a,0xdbf18085}},	//   _آموز, _коли_, _drav, dəçi,
   {{0x200a3873,0x62853874,0x443fb875,0x61ef2651}},	//   robi_, jtho, lqu_, bicl,
   {{0x63a3b876,0x69dd0352,0x7dd58065,0xdd920b76}},	//   _hann, chse, _máso, بور_,
   {{0x63a3b877,0x6285031d,0x13ea0048,0x7bc73878}},	// [2340] _kann, etho, амай_, _boju,
   {{0x63a3b879,0xad9b387a,0xa3e5103e,0x63bb0326}},	//   _jann, _skút, बोल_, _ɗung,
   {{0x63a3b87b,0x3f9804b6,0xe29a204d,0x6d5f3869}},	//   _mann, meru_, рае_, baqa,
   {{0x63a3b87c,0x63a50014,0xdb1c15a0,0x29f880c3}},	//   _lann, adhn, _corá, pčam_,
   {{0x92bc0a49,0xaca3819d,0x91a00129,0x7bc70032}},	//   েছে_, _blọk, _chỉ_, _foju,
   {{0x63a3b87d,0x6d441f91,0x6616387e,0x3f98387f}},	//   _nann, lcia, llyk, neru_,
   {{0xdb1c01a8,0x62853880,0xd90d8019,0x9f9d026b}},	//   _forá, ctho, نیہ_, _dìè_,
   {{0x6d442e58,0x26c08052,0x39428006,0x63a38c11}},	//   ncia, ćio_, _üks_, _aann,
   {{0x63a3b881,0x2249b882,0x6d443883,0x3f983884}},	//   _bann, _čaka_, icia, keru_,
   {{0x69c28b3c,0x3f9800ce,0x63a39ea0,0x7dd112c3}},	//   ljoe, jeru_, _cann, _påsk,
   {{0x61ef3885,0x1fb5b886,0x69dd0168,0x2905080a}},	//   ticl, _эстр, thse, ğlam_,
   {{0x78ad3887,0x51f80190,0x63a3998f,0x6d443888}},	//   _prav, жнюю_, _eann, jcia,
   {{0x63a3b889,0x7dd59c32,0x3f983505,0xa3c3816f}},	//   _fann, _záso, feru_, _एकच_,
   {{0xa3ce81b6,0x3f98388a,0x6560b88b,0x7ddc80e7}},	//   _रवि_, geru_, lamh, _dése,
   {{0x9f340163,0xbcfb03a7,0x6616388c,0x6d5f10ba}},	//   дері, _idéi, flyk, taqa,
   {{0x7dd5803e,0x78ad388d,0x63a390ed,0x24408247}},	//   _násl, _trav, _zann, _kòm_,
   {{0x63a3b88e,0xad9b01ac,0x78ad388f,0x3f983890}},	// [2350] _yann, _skús, _urav, beru_,
   {{0x6d5f3891,0x644d0f31,0xdb1c0019,0x57f40198}},	//   saqa, rpai, _sorá, _опыт,
   {{0x644d3892,0xdd910013,0x61ed007a,0x5a35046e}},	//   spai, _كود_, _kmal, чнет,
   {{0x62850347,0x6d440098,0xfe9a00be,0xf1bf3893}},	//   rtho, ccia, _פירמ, zmán_,
   {{0x6d5d00eb,0x61ed0135,0x62853894,0x660d09c4}},	//   _iesa, _mmal, stho, moak,
   {{0x6d5d3895,0x1da39513,0x940500d7,0x7dd5816b}},	//   _hesa, _खोजत, _روزه, _páso,
   {{0x63a3b896,0x6d5d3897,0x7c3d383a,0xdb1c0207}},	//   _rann, _kesa, _husr, _torá,
   {{0x63a3b898,0x3f983899,0x6d5d2b68,0xbca580f7}},	//   _sann, zeru_, _jesa, كمبي,
   {{0x6d5d389a,0x63a3b89b,0xb4d58816,0x6e22b89c}},	//   _mesa, _pann, सने_, _dhob,
   {{0x7ddc83d3,0x61ed389d,0x443fb89e,0x6d5d389f}},	//   _rése, _amal, rqu_, _lesa,
   {{0x63a3b8a0,0x443f82be,0xe8e10028,0x3f9810e8}},	//   _vann, squ_, _đều_, veru_,
   {{0x63a3b8a1,0x6d5d38a2,0xdb1c013c,0x3f9838a3}},	//   _wann, _nesa, _foræ, weru_,
   {{0x7c3d38a4,0x660d0359,0x63a3b8a5,0x6e298aa2}},	//   _nusr, doak, _tann, mmeb,
   {{0xf8a583f8,0x2bbb8307,0x69dba01d,0x63a390ac}},	//   _یک_, _خاصة_, _llue, _uann,
   {{0x6d5d1a6e,0x7c3d02af,0xa3b5239d,0xaca40133}},	//   _besa, _ausr, झाई_, _mpụt,
   {{0xf06638a6,0x1c462702,0x7c3501a9,0x29f88140}},	//   _екип, знам, _aizr, rčak_,
   {{0x6d5d38a7,0xdb1c00f1,0x3f9838a8,0x7c3d008e}},	// [2360] _desa, _korç, peru_, _cusr,
   {{0x6d4438a9,0x69db8364,0xe81b86a7,0x66160a64}},	//   scia, _alue, _पीला_, slyk,
   {{0x69c28901,0x8c1a8039,0xe2972432,0x160b8beb}},	//   tjoe, צועי, зах_, हकार_,
   {{0x6d5d38aa,0xf3f1abd6,0xaca40135,0x236a0122}},	//   _gesa, hị_, _apụt, _wdbj_,
   {{0xf5370051,0x2d82016d,0x6e2982f1,0xb4d586ae}},	//   _מרכז_, _icke_, dmeb, सनो_,
   {{0x56949269,0x6e949cae,0xbcfb0091,0x2440b8ab}},	//   дакт, дику, _adéw, _ròm_,
   {{0xcf268013,0x6e22b8ac,0x69dba3a2,0x60168187}},	//   أرشي, _phob, _flue, nâmi,
   {{0xe9a39273,0x21a390ca,0x7c3d0359,0xade380e8}},	//   _пасп, _писм, _yusr, ецьк,
   {{0xdb1c007e,0x28168061,0xdcebb8ad,0x6560b8ae}},	//   _borç, _فورس, _bagı, ramh,
   {{0x46a68554,0x6560b8af,0x61ed0039,0xa01b0009}},	//   _назв, samh, _smal, ttöm,
   {{0xe9df0013,0x6e2289ef,0x9f5c81d6,0xbeaa80d7}},	//   thú_, _thob, kovú_, _دهان_,
   {{0x39469313,0xdb03803d,0x26170214,0x7d028102}},	//   ncos_, _manè, rçok_, _txos,
   {{0xdb1c26e2,0x39468c52,0x7dd801d0,0x9ac481b9}},	//   _forç, icos_, _písn, _suċċ,
   {{0x6d5d3745,0x92578077,0xdc378158,0xa5bb38b0}},	//   _sesa, _کشور_, _זאגט_, _chón,
   {{0x6d5d38b1,0x7c3d003a,0x9f4a0388,0x660d38b2}},	//   _pesa, _susr, cibí_, toak,
   {{0x61ed38b3,0x442303ac,0x42fb8039,0xe1ab8beb}},	//   _umal, _shj_, _להוס, _घोंघ,
   {{0x394938b4,0x660d38b5,0x7bcab8b6,0x7bdc05ee}},	// [2370] _ifas_, roak, _kofu, _blru,
   {{0x3f8104cd,0x6e992f02,0x3946b8b7,0xdd9985b9}},	//   _uchu_, _двор_, ecos_, zeň_,
   {{0xaadc85b3,0x386938b8,0xdb580198,0xdd0c0035}},	//   मनिक, _hvar_, яют_, góło,
   {{0xd13191cc,0x61fd38b9,0x38690687,0x23c8801b}},	//   نما_, nnsl, _kvar_, ाउँद,
   {{0xdd99803e,0x8fa587ff,0x92bd00ab,0x07a5b8a6}},	//   veň_, дале, ইনে_, далн,
   {{0x25a92c1c,0xb4d903db,0x7bcab2f5,0x443d8bfd}},	//   ldal_, ़नी_, _nofu, _ruw_,
   {{0x24890065,0x9f478216,0x6446808b,0x5692acab}},	//   ltam_, giná_, íkin, вајт,
   {{0x96270341,0x53341c60,0x25a938ba,0x25a68c41}},	//   _uzņē, _чест, ndal_, _caol_,
   {{0x248938bb,0xf1bf1bf2,0x7dd5807b,0xea0000ff}},	//   ntam_, rmál_, _hásk, _ngại_,
   {{0x63a72e0b,0x320f8051,0xdd99826f,0x394938bc}},	//   _jajn, logy_, seň_, _afas_,
   {{0x25a938bd,0xdd99816b,0x3ed58f99,0x395f81ed}},	//   kdal_, peň_, _تقار, _keus_,
   {{0x77638a2b,0x25a68c41,0x67219351,0xaca3026b}},	//   lanx, _gaol_, _izlj, _afọb,
   {{0x7dd5803e,0x395fb8be,0xb87b0019,0xa5bb001c}},	//   _lásk, _meus_, szín, _phón,
   {{0x63a738bf,0x0c24835f,0x7dd800e1,0x24890019}},	//   _najn, _змін, _píso, dtam_,
   {{0x16a70381,0xe73715fe,0x386906ab,0xe7e58074}},	//   мври_, дер_, _evar_, _कतना_,
   {{0x200eb8c0,0xcb128039,0x601683a7,0x26138187}},	//   zofi_, _שלה_, râmi, mãos_,
   {{0x224d003b,0x39a681e2,0x63a70019,0xdb038077}},	// [2380] _čeka_, _jūsų_, _bajn, _sanè,
   {{0x39a681e2,0x6721b8c1,0xafdb0aa2,0x78a438c2}},	//   _mūsų_, _ozlj, spør, _isiv,
   {{0xe72a198e,0x395f8580,0xea010129,0x7ddc810c}},	//   _фонд_, _beus_, _quầy_, _lésa,
   {{0xfc3f0216,0x395f8362,0xbcfb0580,0xa01b062c}},	//   _fuí_, _ceus_, _adéu, ytök,
   {{0x395fb8c3,0x5fd20063,0x63a7009a,0x18679ae7}},	//   _deus_, _हवाल, _fajn, дачи_,
   {{0x25a680f7,0x63a738c4,0xb03380e8,0x2cadb8c5}},	//   _saol_, _gajn, вніш, dved_,
   {{0xc7b88028,0xdb1c016d,0x69d880f1,0x61fd24f1}},	//   _vnđ_, _borå, ëves, ynsl,
   {{0x746a8153,0x443838c6,0x395fb8c7,0x200eb8c8}},	//   оров_, _hir_, _geus_, sofi_,
   {{0x61e2b8c9,0x6f0d8380,0xd49a804a,0x6fd487f1}},	//   mhol, ğaca, іри_, _làci,
   {{0x5f76845b,0x1b2100ab,0x61e28a33,0x7ddc80e7}},	//   _زائر, _বলতে_, lhol, _désa,
   {{0x38690082,0x443838ca,0x33770039,0xc7b384de}},	//   _svar_, _mir_, ועים_, _שבע_,
   {{0xc333078d,0x61e2835f,0x443838cb,0xdd8f80f7}},	//   כות_, nhol, _lir_, _نوم_,
   {{0x7dd104b8,0xdd8f8bca,0x2ca00239,0x443801e4}},	//   _måst, _خون_, jwid_, _oir_,
   {{0x44380609,0x7dd103a6,0x61e2b8cc,0x7522b8cd}},	//   _nir_, _låst, hhol, _izoz,
   {{0x38c5020f,0x61e2805d,0xe61300f7,0x63a738ce}},	//   _bërë_, khol, نشر_, _rajn,
   {{0xe81f058c,0x2d8038cf,0x443838d0,0x24890019}},	//   _मीरा_, ggie_, _air_, ttam_,
   {{0x443838d1,0x61e2813c,0x395f809f,0xb4d9009a}},	// [2390] _bir_, dhol, _reus_, ़ने_,
   {{0x395f907f,0x3f9c8fda,0x7dd5b8d2,0xd838886f}},	//   _seus_, jevu_, _pásk, _nič_,
   {{0x443838d3,0x248938d4,0xe1ff1726,0x395f823e}},	//   _dir_, stam_, onó_, _peus_,
   {{0x7c38b8d5,0x201138d6,0x443838d7,0x6602b8d8}},	//   _livr, lozi_, _eir_, _njok,
   {{0x7b67025d,0x63a7003a,0x386980f7,0x395f8722}},	//   _отве, _tajn, éar_, _veus_,
   {{0x187c0039,0x4438035f,0x7c38826c,0x48e080ab}},	//   קטוב, _gir_, _nivr, বপূর,
   {{0x776384c3,0x395fb8d9,0x260b86bf,0xa3a80075}},	//   ranx, _teus_, ावली_, _खोट_,
   {{0x61e2b8da,0x442c8fb0,0xd5b18872,0xdcef08c5}},	//   chol, emd_, افظ_, _hacı,
   {{0x20112122,0xd83881a1,0x6012006a,0x316038db}},	//   kozi_, _fič_, kæmp, _reiz_,
   {{0x7dd58019,0x2cad8039,0x3f9c8699,0x9f9d026b}},	//   _mási, rved_, cevu_, _bìí_,
   {{0x656f21aa,0xd24e8416,0x7dd820e6,0xb81b8035}},	//   _odch, ینی_, _sísm, _पीएम_,
   {{0x7dd8026f,0x66028168,0x644f05f3,0x69c6022c}},	//   _písm, _gjok, _otci, ujke,
   {{0x764197ea,0x7dd5816b,0x65640009,0x26170187}},	//   _huly, _nási, vaih, nçou_,
   {{0x201138dc,0x661ba8be,0x6d49b8dd,0x60c4b31b}},	//   gozi_, lluk, lcea, äimi,
   {{0x442782af,0x66e61bd8,0xdee60b9c,0x443838de}},	//   _ihn_, хова, хови, _rir_,
   {{0x7dd59313,0xa3a80fea,0x7641b8df,0xd24e80f7}},	//   _bási, _खोज_, _muly, _اني_,
   {{0x20110578,0x656438e0,0xfce3023f,0x91fd00eb}},	// [23a0] bozi_, raih, гото, ksāj,
   {{0x9f9d0324,0xfc3f00f7,0x661b829b,0x085704de}},	//   _yìí_, _arís_, hluk, _רבים_,
   {{0x443826e6,0x7dd10bfa,0xdb1c01ac,0x442782f7}},	//   _vir_, _påst, _horú, _mhn_,
   {{0x443838e1,0x3f85b8e2,0xceb302f6,0x2a6a8019}},	//   _wir_, _aclu_, _עיר_, ábbi_,
   {{0x443806f6,0x61e2805f,0xdb1886c4,0x3f9cb8e3}},	//   _tir_, rhol, _envè, tevu_,
   {{0x6602b8e4,0x7641b8e5,0x442c06c0,0x998d81d6}},	//   _sjok, _buly, _òd_, _vieš_,
   {{0xfc031f64,0x7dd5826f,0x6996b8e6,0x3f9cb8e7}},	//   _спро, _zási, _прах, revu_,
   {{0x661bb06d,0x291e009a,0x3f9c8267,0x69d98252}},	//   gluk, ętaj_, sevu_, ckwe,
   {{0x09e3a187,0xb4da8105,0x7bce38e8,0xdb188187}},	//   _сотн, ठने_, _kobu, _invé,
   {{0x7bce0087,0x8afe89ab,0x236580c3,0x3ea9866f}},	//   _jobu, _leƙe, galj_, łata_,
   {{0x7c3880e7,0x7641a015,0x7bce38e9,0x442c80f3}},	//   _vivr, _guly, _mobu, rmd_,
   {{0x7982b8ea,0x225c003e,0x6136880a,0x7bce0234}},	//   ngow, ávky_, _gülü, _lobu,
   {{0x20110423,0x23658904,0xe3b2803d,0x799d1e59}},	//   tozi_, balj_, _مرغ_, resw,
   {{0xb8c90d38,0x644fa761,0x2ca68114,0x799d38eb}},	//   _गई_, ície, _isod_, sesw,
   {{0x201100b4,0x7a3e8084,0xe28f81a8,0x6e942672}},	//   rozi_, _būte, _هذي_, лиру,
   {{0x63aaa96c,0x20112c1d,0x34953067,0x2365026c}},	//   _hafn, sozi_, кабр, _žlj_,
   {{0x7dd838ec,0x7bce38ed,0xbcfb046d,0x3a29033e}},	// [23b0] _získ, _bobu, _adér, _ihap_,
   {{0x63aa8125,0xdce0b8ee,0x6442b8ef,0x7bce0c4d}},	//   _jafn, jamč, _muoi, _cobu,
   {{0xa0360039,0xbb8401a8,0x29d782d0,0x9f8f02f1}},	//   _שאתה_, المي, _uçak_, _müü_,
   {{0x6562b8f0,0xcb1380be,0x9f58007b,0x7ae582f1}},	//   _neoh, אלע_, lorð_, _ühte,
   {{0xf9940039,0x7641b8f1,0x69d9b8f2,0x661b817f}},	//   טרף_, _suly, rkwe, vluk,
   {{0x69d9b8f3,0x6298837a,0x63aa807b,0x3f83008b}},	//   skwe, _opvo, _nafn, ngju_,
   {{0x23658390,0x628b0493,0x5f05847f,0x9f47862c}},	//   valj_, ăgos, ъзка, vinä_,
   {{0xceb40158,0x7ddc82be,0x7bce38f4,0x9f5c816b}},	//   ריק_, _déso, _zobu, mový_,
   {{0x661b8867,0x2365b744,0xa5bb0c52,0x9f5c826f}},	//   rluk, talj_, _dióx, lový_,
   {{0x6d4980f7,0x1a65815b,0xe50203eb,0x9aa40019}},	//   scea, نیتی_, लपति_, _جمہو,
   {{0x386db3b7,0x9f5c826f,0xb17b0aa2,0x26172761}},	//   _hver_, nový_, rhån, nços_,
   {{0x999880eb,0x3a2938f5,0x186a0a7c,0x2365817f}},	//   _kurš_, _chap_, мами_, salj_,
   {{0x4427810b,0x9f5c816b,0x2365817f,0x9f9d026b}},	//   _thn_, hový_, palj_, _bìà_,
   {{0xb4bf835a,0x9f5c83fb,0x29f896f2,0xb4cd816f}},	//   ीही_, kový_, nčar_, रही_,
   {{0xfaa5b8f6,0x9f5c816b,0x248db8f7,0x91a000ff}},	//   _райо, jový_, ltem_, _thì_,
   {{0x386d8051,0x9f5c826f,0x98be0214,0x63bc38f8}},	//   _over_, dový_, ştı_, _snrn,
   {{0xd4670381,0x248db8f9,0x9f58008b,0xb386232b}},	// [23c0] ките_, ntem_, borð_, клал,
   {{0x7dd838fa,0xeafa0250,0x248db8fb,0x2d9f8a53}},	//   _mísi, ورات_, item_, heue_,
   {{0x386d8098,0xdb1c077f,0x66e638fc,0xb4cd8074}},	//   _aver_, _yorù, _рона, रहु_,
   {{0x7ddcb8fd,0xdb18803e,0xe9da80e8,0x248db8fe}},	//   _réso, _nový, ьке_, ktem_,
   {{0x80be8540,0xe8949663,0xe0e080ab,0x7bce38ff}},	//   ्हें, уаль, বপ্ন, _tobu,
   {{0xdfcf8624,0x248db900,0x6562a72a,0x9f5c8a21}},	//   يين_, dtem_, _seoh, bový_,
   {{0x6fdd809f,0x386d8039,0x2480051e,0x973c8b80}},	//   _tècn, _ever_, luim_, _jaći,
   {{0x5f168076,0x752601c0,0x25a0051e,0x442a008e}},	//   _पुण्_, _kzkz, neil_, _hhb_,
   {{0xc5f30051,0x6442b901,0xdb01865d,0x3a2902c4}},	//   ידה_, _quoi, ndlæ, _rhap_,
   {{0x32020038,0x7c3c04b7,0x660db902,0x25a03903}},	//   enky_, _jirr, čaka, heil_,
   {{0xe9f9222c,0x0d8682a9,0x5a351508,0x37ba00ab}},	//   енні_, _ален, лнот, ুসার,
   {{0xcb1304de,0x973c80fe,0x39400db1,0x91a0027d}},	//   ילת_, _naći, _cgis_, _phí_,
   {{0x386d3904,0x6abf016f,0x248d87f1,0x9f5c816b}},	//   éer_, _एप्र, ctem_, zový_,
   {{0x24803905,0x7c3c3906,0xdb1c03ba,0xd7c900d7}},	//   duim_, _nirr, _forø, روزه_,
   {{0x88cb00ab,0xbcfb046d,0x973c8140,0x1af080ab}},	//   _লেখক, _adép, _baći, _ঘুরে_,
   {{0x32538098,0x9f5c826f,0x25a001e4,0x7c3c0362}},	//   _твър, vový_, geil_, _airr,
   {{0x80be8063,0x443cb907,0x7c3c3908,0x38600428}},	// [23d0] ्हों, _kiv_, _birr, _gwir_,
   {{0x9f5c803e,0x7c3c3909,0x6fdd8722,0x442a01a1}},	//   tový_, _cirr, _rèco, _chb_,
   {{0x443cb90a,0x20031487,0x7dd5816b,0x248d8019}},	//   _miv_, mnji_, _zásu, ztem_,
   {{0xe7e581fe,0x443ca2af,0x261707e0,0x973c81dd}},	//   कसभा_, _liv_, rços_, _gaći,
   {{0x7dd5b90b,0x9f5c826f,0xdfd58d55,0x851e8054}},	//   _mást, sový_, лоды, _परगट_,
   {{0x443cb90c,0x7dd581ca,0x6e3d00fc,0x9f5c84e8}},	//   _niv_, _lást, _hisb, pový_,
   {{0x6e3d390d,0x4e9580f7,0xf1a7828b,0x7645008e}},	//   _kisb, اشتر, _иран, _juhy,
   {{0x7dd5803e,0x248d8065,0x26c9805c,0x069680f7}},	//   _nást, ttem_, ćao_, انية_,
   {{0x6e3d390e,0x31348596,0xb17b00f2,0xa5bb0013}},	//   _misb, _ветр, rhål, _chói,
   {{0x7dd80125,0x200302a5,0x248db90f,0xb17b016d}},	//   _vísi, jnji_, rtem_, shål,
   {{0x7d1d00f2,0x1603015c,0x17f880f7,0xdb03b910}},	//   _lyss, रचार_, _شركة_, _taní,
   {{0x64b592dc,0x6e3d3911,0x2b4e8326,0x61f982c4}},	//   _محتر, _nisb, _effc_, niwl,
   {{0x6d5b9a6e,0x443cb912,0x25a01ab3,0x6fd4823e}},	//   mbua, _fiv_, veil_, _tàct,
   {{0x443c813c,0x291e00eb,0x2a6c8101,0x75fe80eb}},	//   _giv_, āta_, bsdb_, vīzi,
   {{0x66e31adc,0x25a03913,0x6e3d3914,0xdee33915}},	//   бора, teil_, _bisb, бори,
   {{0x64a60972,0x443c82a5,0x7dd58207,0x7c3c3916}},	//   лаба, _ziv_, _gást, _sirr,
   {{0x29050459,0xa3d78768,0x25a03917,0xb4de3918}},	// [23e0] şlar_, _सवा_, reil_, तने_,
   {{0x7dd585b9,0xfc3f00f7,0x25a001e4,0x24803919}},	//   _zást, _tsín_, seil_, ruim_,
   {{0xdb0a8980,0x764509c4,0x7c3c391a,0x1bf683de}},	//   _cafè, _guhy, _virr, נצער_,
   {{0x00e69508,0x7cda01a9,0xaa570290,0x067b03de}},	//   лжен, _pārā, النا_, _אנטל,
   {{0xb4cd8076,0x6604391b,0xd9178160,0x7c3c01b9}},	//   रहो_, mnik, льш_, _tirr,
   {{0x6604391c,0x6281b91d,0x63a182a5,0xeeaa8e8e}},	//   lnik, kulo, jeln, етик_,
   {{0x63a1b91e,0x69dd0009,0xdb01816d,0x656615bd}},	//   deln, ykse, ndlä, _kekh,
   {{0x443c90af,0x5c749537,0x6604391f,0x6e3d02a3}},	//   _siv_, алит, nnik, _xisb,
   {{0x69c0b920,0x443c81c5,0xa3e8023c,0x600a8ae7}},	//   _inme, _piv_, _बता_, _знам_,
   {{0xda7ab921,0x644601d3,0x644fa3be,0x61e43922}},	//   ням_, _muki, ícia, _alil,
   {{0xd00f803f,0x66043923,0x443cb924,0x64463925}},	//   _علم_, knik, _viv_, _luki,
   {{0x69dd0364,0x15469445,0xa01b0009,0xe1350198}},	//   ukse, _седм, ytös, инны,
   {{0x20030024,0x443c81c5,0x644604b9,0x5c568139}},	//   tnji_, _tiv_, _nuki, _стеф,
   {{0x6281b926,0x53348adb,0x7d1d3927,0x3cff0110}},	//   bulo, _келт, _ryss, _žuvo_,
   {{0x6281b928,0xd5bb3929,0x6446392a,0x9f3500e8}},	//   culo, нса_, _auki, реві,
   {{0x20030052,0x5d551182,0x7d1d1a57,0x660407f6}},	//   snji_, ркат, _pyss, gnik,
   {{0xd37b1860,0x6e3d392b,0xf99000f7,0x8f55003d}},	// [23f0] ече_, _visb, _ربي_, _پنجش,
   {{0x69c0b92c,0x644604b9,0x6d4d392d,0x926b2183}},	//   _anme, _duki, scaa, ерда_,
   {{0x66040db7,0xdb038e93,0x63ae0282,0x973c990f}},	//   bnik, _kaná, _dabn, _kaću,
   {{0xdb0ab92e,0x6d42801c,0x5fc32cfc,0x629c392f}},	//   _café, _ngoa, शावल, _dpro,
   {{0x79c989a7,0x60168087,0x601f8187,0x644600b4}},	//   _یوسف_, tâmp, lêmi, _guki,
   {{0x629c002a,0x3d18800f,0x69c0b930,0x244981fa}},	//   _fpro, _पड़े_, _enme, _rúm_,
   {{0x6d5b8201,0x64460267,0xd3440019,0x0f5801c6}},	//   tbua, _zuki, _اہمی, ניהם_,
   {{0x660d8353,0x9f580168,0x78a9822c,0x9f4100e1}},	//   čako, tirë_, _tsev, _dlhé_,
   {{0x63a1b931,0x6d5bb932,0xa787815b,0x78a9b933}},	//   teln, rbua, _مشاو, _usev,
   {{0x6281b934,0xdb18840e,0x66043935,0x6619861b}},	//   tulo, _enví, znik, _wkwk,
   {{0x4fc4a39f,0xdb038c83,0x212900b9,0x3b098ae7}},	//   _уста, _baná, _azah_, тено_,
   {{0x63a1b936,0x66040085,0xd9f780d4,0x601f8187}},	//   seln, xnik, ूचित_, dêmi,
   {{0x7dd8000d,0x63a1b937,0x6281b938,0x3d04009a}},	//   _míst, peln, sulo, _रखें_,
   {{0x66040063,0x6446313e,0x7dd8026f,0xdb0380f7}},	//   wnik, _ruki, _líst, _eaná,
   {{0x316b0063,0x09e62fd6,0x656600b9,0xdb070144}},	//   bacz_, _войн, _pekh, _bají,
   {{0xe9df01ac,0x260b897d,0x290d8118,0xdb038216}},	//   ckú_, ावटी_, _oxea_, _ganá,

   {{0xab66045d,0xf1bf0c83,0xa01b1e5e,0xddd880d2}},	// [2400] ивал, rmát_, rtör, nuvš,
   {{0x66040668,0x64463939,0x629c01b9,0x68200019}},	//   snik, _vuki, _ppro, ködi,
   {{0x6604393a,0x65660101,0xb1468dc0,0x877b025f}},	//   pnik, _tekh, анел, _באיי,
   {{0x2018393b,0x6446393c,0xfc48801c,0x2d9606f1}},	//   lori_, _tuki, _lửa_, _трос,
   {{0x4fc691b3,0x629c009a,0x67450177,0x9f51393d}},	//   иска, _wpro, _átjá, lizá_,
   {{0xdb07000d,0x2018393e,0xfc48801c,0x63bb00fc}},	//   _zají, nori_, _nửa_, _ɗunk,
   {{0x46678fe6,0x7ddc80e7,0xb76580e8,0xa5f888ed}},	//   арым_, _hési, стій, леку_,
   {{0xd5b7a00e,0x20180114,0x9fa3808b,0x7dd58333}},	//   ась_, hori_, síðu_, _básq,
   {{0xad9b007b,0x644000e7,0x22478144,0x5f16ac17}},	//   _sjúk, _émis, _aunk_, _पुर्_,
   {{0xfc488028,0x2018393f,0x6609005c,0x60e8880a}},	//   _cửa_, jori_, čeki, ırmı,
   {{0xb4db0028,0x20183940,0x91fd00eb,0xa6ca80f7}},	//   _ngàn, dori_, ksāt, _جوال_,
   {{0x7dd807d0,0xd49ab941,0xdb1c0fba,0x05838d9e}},	//   _míss, _арк_, _horó, _душм,
   {{0xfbcf87d2,0x7648b942,0x245481ad,0x291f81c0}},	//   ستی_, _hudy, _انتس, _xyua_,
   {{0xb7f88aed,0xd7fb0a3d,0x7a2382f1,0xe9df01d6}},	//   ्चिम_, тум_, võtm, skú_,
   {{0xdb038019,0x62351182,0xdb1c3673,0x5f1a0fb2}},	//   _taná, _леку, _moró, _मुद्_,
   {{0x3c2b83ba,0xdb188580,0x5d78062c,0x2367b943}},	//   røve_, _invà, ийся_, _zenj_,
   {{0x20180503,0x22a80214,0x44210f3e,0x409500f7}},	// [2410] bori_, _aşk_, tlh_, _الخر,
   {{0x7ddc82be,0x3a3f808e,0x20183944,0xdb0e003d}},	//   _dési, _siup_, cori_, _kabè,
   {{0x24848122,0xa5bb01a8,0x442989ab,0x3a2d8129}},	//   humm_, _bhót, _ɗa_, _phep_,
   {{0x29d78380,0x32191122,0xf54f019d,0xe1f0b945}},	//   _açar_, nosy_, _rụwa_, وسن_,
   {{0x7dd812ca,0xdce28088,0xe80e03b7,0x245d026b}},	//   _víst, _beoč, _सदमा_, _dámò_,
   {{0xf77185ff,0x656d3946,0xab8411b3,0x7648809a}},	//   سات_, laah, _муск, _budy,
   {{0x3a3f8359,0x212981ac,0xfc4880ff,0x61fd3947}},	//   _tiup_, ťah_, _rửa_, kisl,
   {{0xfc488028,0x61fd3948,0x798d0069,0x644fb949}},	//   _sửa_, jisl, _ncaw, ício,
   {{0x442e8267,0x6285394a,0x2018394b,0x22400074}},	//   _bhf_, luho, yori_, _riik_,
   {{0x53c982de,0x63a502d4,0x656d394c,0x7dd58216}},	//   угом_, nehn, haah, _vásq,
   {{0xa96a013a,0x216a17c8,0xae7880e8,0x656d394d}},	//   лина_, лини_, _всіх_, kaah,
   {{0xdb038073,0x656d0079,0x442e807b,0x6fdd8036}},	//   _lanç, jaah, _ehf_, _sèch,
   {{0xeb9998a0,0x63c281d0,0x799bb94e,0x91ba81c6}},	//   _бил_, ávní, _mbuw, אמרי,
   {{0x7ddc82be,0xd91a8039,0xb4e39344,0x7648808e}},	//   _rési, רושל, ननी_, _yudy,
   {{0x799bb94f,0x20183950,0x6729000d,0xe2998162}},	//   _obuw, rori_, řejn, _сай_,
   {{0xfbdf001c,0xbb3a80be,0x7ddca8f4,0xa2c4852a}},	//   _quên_, _געצי, _pési, िमर्,
   {{0xbddb00e7,0xfd6481bc,0x7bd50214,0xdb18b951}},	// [2420] _sièc, _agwụ, _bozu, _invá,
   {{0xbddb03d3,0xdb0391dd,0xdb0e3952,0x9f860cf9}},	//   _pièc, _canç, _habé, _угод,
   {{0xfe721168,0xb87b0065,0xe5a6134e,0x69c41254}},	//   _عدد_, szít, _лини, _knie,
   {{0x69d63953,0xed360162,0xc8b50065,0x3eb809d1}},	//   _joye, _гэгэ, _الیک, mvrt_,
   {{0x69d602be,0x7bc3838a,0xdb1c3954,0x69c4009a}},	//   _moye, _onnu, _poró, _mnie,
   {{0x6e243955,0xa09b010f,0x62853956,0x2bc93957}},	//   llib, ריסט, buho, राणा,
   {{0x2291b958,0x3eb8007a,0x78bb8144,0x7ddc87f1}},	//   ják_, nvrt_, _eruv, _mésv,
   {{0x7bc3b959,0x5454b95a,0x61fd04c3,0xfbc90ebf}},	//   _annu, овит, xisl, राथम,
   {{0x61fd003e,0xdce28267,0xf1c3801b,0x61e28e3a}},	//   visl, _teoč, šší_, mkol,
   {{0xb274b95b,0x248001a8,0xf54f01bc,0xd4978a14}},	//   олош, irim_, _hụta_, ёры_,
   {{0x61fd0038,0x2480395c,0x441b00be,0x69d6395d}},	//   tisl, hrim_, רויס, _boye,
   {{0x14c8395e,0x7bc3b95f,0x61e2b960,0xd46a80a9}},	//   रमाण, _ennu, nkol, _биде_,
   {{0xdca3b915,0xf54f0135,0xdce60609,0x682d81d6}},	//   _наци, _mụta_, _dekċ, súde,
   {{0xdb018019,0x656d0870,0xd7f810bc,0xb8d12c17}},	//   zelé, waah, бус_, _ऐन_,
   {{0x61e2b961,0x7bd5185c,0xdb0a8247,0xf40000ab}},	//   kkol, _rozu, _enfò, ্তার_,
   {{0x6e243962,0xbcfb0019,0x9f47816b,0x78ad3963}},	//   glib, _idéz, diný_, _tsav,
   {{0x63a53964,0x656d02a3,0x7bd50085,0xdb018019}},	// [2430] tehn, raah, _pozu, velé,
   {{0xe1ff1362,0xa5bb01a8,0x62853965,0xdb1c2d84}},	//   lió_, _chór, tuho, _enrí,
   {{0xa6ab0b76,0xe7c7809a,0xdb018019,0x7bd50267}},	//   _صادق_, लासप, telé, _vozu,
   {{0xe1ff07e2,0x201eb966,0x78bbb967,0x61e2b968}},	//   nió_, _akti_, _pruv, gkol,
   {{0x7bd51cf0,0xdb018019,0x3ea1008e,0xb97c03c8}},	//   _tozu, relé, _hpht_, רנדי,
   {{0xf2e7119d,0x66090289,0x7e55988f,0x22918061}},	//   _любо, čeku, отиц, yák_,
   {{0xb7dc00be,0xdb0187bc,0xdddc0b80,0x7ddc810c}},	//   רקוי, pelé, lurš, _lésu,
   {{0x649982a4,0x2291a99b,0xec79b5d9,0x91a90129}},	//   атор_, vák_, апи_, _nhà_,
   {{0xe1ff3969,0xb4e3809a,0x61fbb96a,0x13e9b96b}},	//   dió_, नने_, _imul, имий_,
   {{0x69c4396c,0x69d600e7,0x2291a825,0xdb0e396d}},	//   _snie, _soye, ták_, _sabé,
   {{0xd5ae8077,0xab298470,0xe299911c,0x645bb96e}},	//   رفی_, рона_, шан_, spui,
   {{0x5ed280c8,0xe1ff396f,0xbba60540,0x27fa0101}},	//   _থেকে, gió_, _ऑस्क, _smpn_,
   {{0x69d63970,0x9f45b971,0x776e011c,0x2291a825}},	//   _voye, _allé_, tabx, sák_,
   {{0xa2e58193,0x3eb8025b,0x61e9802a,0x61e2b972}},	//   _молд, tvrt_, _llel, zkol,
   {{0x61fb8c56,0xe1ff00ab,0xdb1c0125,0x7f430e86}},	//   _omul, bió_, _norð, держ,
   {{0xe1ff3973,0x6609b974,0x644b8578,0x69c40905}},	//   ció_, nnek, _kugi, _unie,
   {{0x656bb975,0xb87b0065,0x6e240057,0x644b81a1}},	// [2440] _megh, szír, rlib, _jugi,
   {{0x9f580013,0xdb070065,0x644bb976,0x61fbb977}},	//   oirí_, _sajá, _mugi, _amul,
   {{0x44258224,0x9d460256,0x661ba43f,0xf54f0135}},	//   ill_, _менд, kouk, _pụta_,
   {{0xa9268381,0x661b8198,0x24803978,0x660981a1}},	//   одел, jouk, prim_, jnek,
   {{0x61e2b979,0x7642810c,0x9f5c936f,0xdce60af8}},	//   rkol, _rioy, livé_, _kekč,
   {{0x61e98135,0x6609811b,0x2d9d838a,0x6443b97a}},	//   _elel, enek, _abwe_, _nini,
   {{0x644b8110,0x98a38084,0xfe6fa239,0x656b80e5}},	//   _augi, _ąją_, ندي_, _begh,
   {{0x9343035f,0x644bb97b,0x6443b97c,0x4425b97d}},	//   _інте, _bugi, _aini, ell_,
   {{0x6443b97e,0x656bb97f,0xe1ff06a5,0x644bb45a}},	//   _bini, _degh, vió_, _cugi,
   {{0x7ddc83d3,0x644b811f,0x6443b980,0xa2f480e8}},	//   _résu, _dugi, _cini, зпоч,
   {{0xe1ff05a4,0x661bb981,0xe3b88214,0x3eb88061}},	//   tió_, bouk, llık_, _ért_,
   {{0x201c89cf,0x644bb982,0x644391e6,0x81e30264}},	//   lovi_, _fugi, _eini, ফোন_,
   {{0xe1ff05a4,0xa92b10ac,0xe3b88214,0x64439ea0}},	//   rió_, ріне_, nlık_, _fini,
   {{0xbebc8341,0xe1ff07e2,0x6443b983,0x3a203984}},	//   _dzīv, sió_, _gini, _ekip_,
   {{0x3dc68051,0x23c9064a,0x3a26b985,0x356b0abe}},	//   _know_, रासद, klop_, иран_,
   {{0x63a8b986,0x7a120029,0x644b8358,0x6443b987}},	//   ledn, tāte, _yugi, _zini,
   {{0x628880ab,0x34940009,0x7dd80661,0x25d78e82}},	// [2450] ludo, матр, _vísp, קומן_,
   {{0xa2be86bf,0x61fbb988,0x60c00366,0x9f3501b5}},	//   षिप्, _smul, æmme, _непі,
   {{0x201c803a,0x62888301,0x7afc80f7,0x7ddc82df}},	//   dovi_, nudo, úrth, _jéss,
   {{0x7bd8b989,0xdb188106,0x386900fc,0x6600928a}},	//   _lovu, _invä, _kwar_, jimk,
   {{0x4425b98a,0x998d81ac,0x201c8390,0xf7f4003d}},	//   yll_, _tiež_, fovi_, _رسید,
   {{0x63a8807d,0x201c812b,0xa2a6000f,0x644bb98b}},	//   jedn, govi_, _टैक्, _rugi,
   {{0xfbd20051,0x644bb98c,0x661bb98d,0x656b80b9}},	//   _אתם_, _sugi, touk, _pegh,
   {{0x2bc91344,0x25a90014,0x63b529f3,0x644bb98e}},	//   रावा, neal_, _hazn, _pugi,
   {{0x6443b98f,0x201c8024,0x24893990,0x321d8035}},	//   _pini, bovi_, nuam_, mowy_,
   {{0x656bb991,0x644381f6,0x25a910eb,0x321d8035}},	//   _wegh, _qini, heal_, lowy_,
   {{0x316db992,0x7bd8b993,0x63b53994,0x386904b9}},	//   _keez_, _dovu, _mazn, _awar_,
   {{0x63b500d2,0x644bb995,0x3d959445,0x321d8035}},	//   _lazn, _tugi, _хидр, nowy_,
   {{0xdb189918,0x64439eba,0x63a882ee,0x25a93996}},	//   _anvä, _tini, bedn, deal_,
   {{0x386901cd,0x628889a4,0x9f5cb997,0x2a67841c}},	//   _dwar_, budo, tivé_, _twnb_,
   {{0xf1bf0013,0xfaa28698,0x62888c52,0xe7f38006}},	//   mlán_, _защо, cudo, _अतना_,
   {{0x201c8024,0x7bc7237e,0x25a93998,0xceb282f6}},	//   zovi_, _anju, geal_, עין_,
   {{0xdca30993,0x321d809a,0x248903ac,0x64a33999}},	// [2460] нати, dowy_, guam_, ната,
   {{0xa097010f,0x66008850,0xdb1c0338,0x32021e51}},	//   _צדיק_, zimk, _morö, liky_,
   {{0x201c8052,0x386902af,0xdce08289,0x3ce60a21}},	//   vovi_, _zwar_, pamć, šov_,
   {{0x3202026f,0x63a8809a,0x8c460198,0xaca40133}},	//   niky_, zedn, _неме, _ahụr,
   {{0xd7c78e1a,0x25d7093f,0xe89497d4,0x63b5399a}},	//   लांच, _זוכן_, фаль, _fazn,
   {{0xdb0e040e,0xdb0a80f2,0x63b521fa,0x7416015b}},	//   _habí, _infö, _gazn, _روزا,
   {{0xcfb600ab,0x3a26aacb,0xfbc90c1c,0x76460c2e}},	//   ঞাপন, plop_, रारम, _kiky,
   {{0xf64f803d,0xdb0380e1,0x7646008e,0xceb301c6}},	//   دئو_, _fanú, _jiky, תיה_,
   {{0x7bd8803b,0x201c803b,0x66008877,0xdb088187}},	//   _povu, povi_, rimk, cedê,
   {{0x6288b99b,0x9f4781e8,0x7ddc8187,0xb05b0106}},	//   tudo, sinò_, _péss, lväg,
   {{0x63a8b99c,0xa75b8039,0x61358019,0x3202016b}},	//   redn, _הדבר, pülé, fiky_,
   {{0xdb0e03bb,0x6288806a,0xddcb026c,0x80b38035}},	//   _nabí, rudo, _žiža, _इनमे,
   {{0x68e2b6a0,0x7bd8b99d,0x2fda0473,0x7a2382f1}},	//   nyod, _tovu, _bopg_, mõtt,
   {{0x3f8eb99e,0xf1bf399f,0xa01b0061,0xd7f80087}},	//   ngfu_, clán_, ltöz, пус_,
   {{0x752f0d38,0xa3b58592,0x25a90c41,0x245280ff}},	//   _szcz, _चोट_, teal_, _hâm_,
   {{0x63b5003b,0xe3b882bb,0x6564177c,0x6a1501b5}},	//   _sazn, ldı_, gbih, _імпу,
   {{0x61ed39a0,0xb4e739a1,0x67ef813c,0x9f583076}},	// [2470] _ilal, बने_, _høje, birà_,
   {{0xe3b882bb,0x25a939a2,0x67250009,0x68e2b9a3}},	//   ndı_, seal_, _tyhj, dyod,
   {{0x98b90459,0x63b500d2,0x25a939a4,0x24890069}},	//   ması_, _vazn, peal_, suam_,
   {{0x7a3f1482,0x9f580207,0x62970102,0x22950687}},	//   _būti, mirá_, rtxo, råk_,
   {{0x656f031d,0x248907b6,0x321db9a5,0x7a1200eb}},	//   _iech, quam_, rowy_, nāta,
   {{0xb8d585e8,0x656f39a6,0x7bc70573,0x98b9080a}},	//   _जन_, _hech, _unju, nası_,
   {{0x656f39a7,0xdce600eb,0x9f581e31,0x60c0b9a8}},	//   _kech, _iekā, nirá_, _ermm,
   {{0x644f0587,0x660d39a9,0x20031efb,0x644739aa}},	//   _kuci, nnak, hiji_, _hiji,
   {{0x98b90182,0x644739ab,0xf1bf0e1b,0xdcfd0457}},	//   kası_, _kiji, tlán_, _kası,
   {{0x656f39ac,0x61ed2c38,0x200339ad,0x644739ae}},	//   _lech, _alal, jiji_, _jiji,
   {{0x3202026f,0x6447071d,0xdb088722,0x26c101c5}},	//   tiky_, _miji, nedè, _nrho_,
   {{0x656f0775,0x471a893f,0x645d01c2,0x69db83d3}},	//   _nech, _וועג, _otsi, _joue,
   {{0x25098288,0x660d00ce,0x645d10af,0x69db9ed6}},	//   _برای_, dnak, _ntsi, _moue,
   {{0xdcfd07d9,0xdb0e0d76,0x69dbae17,0xdce600eb}},	//   _nası, _sabí, _loue, _nekā,
   {{0x645d0a8e,0x656f39af,0x9f5839b0,0x69c9b9b1}},	//   _atsi, _bech, rirà_, _onee,
   {{0x660d39b2,0x644739b3,0x656f1f5b,0xdb0a81a8}},	//   gnak, _aiji, _cech, _uafá,
   {{0x20030d11,0x644f0698,0x656f39b4,0x644739b5}},	// [2480] biji_, _cuci, _dech, _biji,
   {{0x644f39b6,0x9f459efe,0x9f5805e4,0x656439b7}},	//   _duci, _allí_, birá_, sbih,
   {{0x6d598c0b,0xe2971a97,0x656f03aa,0x644739b8}},	//   _ofwa, дах_, _fech, _diji,
   {{0x6d4b8854,0xa96789a0,0x644f047f,0x79a38992}},	//   _ngga, дица_, _fuci, врше,
   {{0x660439b9,0x7a238074,0xd6cf803d,0x644739ba}},	//   miik, võtt, یقه_, _fiji,
   {{0x66040ef6,0x6d4bb9bb,0xb05b016d,0x68e2b9bc}},	//   liik, _agga, sväg, ryod,
   {{0x644f04b9,0x656f39bd,0x2452b9be,0x7a2382f1}},	//   _zuci, _yech, _sâm_, tõtt,
   {{0x98b90059,0x7bdc0079,0xc8838214,0x1dc58b84}},	//   zası_, _horu, üğü_, वागत,
   {{0x7bdc39bf,0x98b90201,0xe3b8811c,0x9f5802df}},	//   _koru, yası_, tdı_, zirá_,
   {{0x61ed0bda,0x88bd809a,0x6d4bb9c0,0xc0a98481}},	//   _slal, _myśl, _egga, _عاقل_,
   {{0x200302a5,0xddcb803a,0xe3b882bb,0xdd8f81a1}},	//   viji_, žišt, rdı_, _иш_,
   {{0x24528104,0x7bdc046d,0x7c669459,0x9f58018a}},	//   _tâm_, _loru, _قاتل, virá_,
   {{0x656f39c1,0x60f801bb,0x64c8000f,0x660d01ac}},	//   _rech, дняя_, रमोश, vnak,
   {{0x9f582790,0x656f39c2,0x67ef8366,0xdce0928a}},	//   tirá_, _sech, _tøje, zamě,
   {{0x656f39c3,0xa3d205fb,0x75ea003e,0x98b9017b}},	//   _pech, वान_, _význ, rası_,
   {{0x200302a5,0x6e20b9c4,0x644739c5,0x9f5839c6}},	//   siji_, nomb, _siji, rirá_,
   {{0x656f39c7,0x660d2795,0x25a20748,0x69db80e7}},	// [2490] _vech, rnak, _dbkl_, _roue,
   {{0x7bdc39c8,0xfe710065,0x656f02af,0x644f0bcf}},	//   _coru, _مگر_, _wech, _vuci,
   {{0x7bdc21d1,0x6e20b9c9,0x644739ca,0x69dbb9cb}},	//   _doru, komb, _viji, _poue,
   {{0x7bdc0176,0x3e7a8029,0xdb088019,0xdb0e0187}},	//   _eoru, dīt_, gedé, _sabã,
   {{0xa0699a97,0x18699ff3,0x645d39cc,0x6e29b9cd}},	//   чала_, чали_, _utsi, vleb,
   {{0x63b88b40,0x7bdc1035,0xdb070722,0x76b3811c}},	//   _navn, _goru, _majú, _həyə,
   {{0xfc488104,0x26c183bb,0xd6d19ecd,0x442139ce}},	//   _gửi_, ího_, اقع_, moh_,
   {{0x6e20a5d3,0x442102d4,0x22988019,0x7bdc0214}},	//   gomb, loh_, dék_, _zoru,
   {{0x7bdc39cf,0x6e29b70a,0xdb018a21,0x212900b9}},	//   _yoru, rleb, delá, _nyah_,
   {{0xf6e7b9d0,0xa3d20576,0x35d106a7,0x2bd20072}},	//   _оцен, वाय_, हाड़, साया,
   {{0x63b88025,0x21290057,0xdb15026f,0x6e20b9d1}},	//   _davn, _ayah_, _bazé, bomb,
   {{0x61f9a92c,0x7bca8365,0x6d4ba4d0,0x70cb0a43}},	//   _çalı, _enfu, _ugga, ामूल,
   {{0x44211ade,0x629a8009,0x1c398a14,0x66040198}},	//   koh_, atto, _езды_, viik,
   {{0xcc76810f,0xf1b981a1,0x212939d2,0xdb0e0338}},	//   _טענה_, _laš_, _dyah_, _inbö,
   {{0x44210057,0x5f1a0105,0x660439d3,0x6da61634}},	//   doh_, _मुख्_, tiik, нива,
   {{0x7bdc292c,0x25ad85f8,0xc1ba00a0,0x22490122}},	//   _soru, neel_, _رابط_, _giak_,
   {{0x7bdc39d4,0x66043252,0x1de10074,0x76b38085}},	// [24a0] _poru, riik, _नवरत, _dəyə,
   {{0xa09b0158,0x25ad8fb0,0x7bdc0201,0x660439d5}},	//   _צייט, heel_, _qoru, siik,
   {{0xf1b9803a,0x386d810c,0x2bb78076,0x88bd809a}},	//   _baš_, _awer_, _असना, _wyśl,
   {{0x60c406a4,0xd910804e,0x9f5c8118,0x62530372}},	//   _krim, لیز_, riví_, _għom,
   {{0xf1238b88,0x44210458,0x25ad837a,0x9f458722}},	//   льшо, boh_, deel_, _allà_,
   {{0x3e7a8029,0x442139d6,0x65760df6,0xe7c78327}},	//   tīt_, coh_, layh, लागप,
   {{0x44380352,0x63b88805,0x6e20b9d7,0x629a8706}},	//   _ihr_, _ravn, tomb, xtto,
   {{0x3e7a80eb,0x63b88e66,0x32078061,0x2d9239d8}},	//   rīt_, _savn, ényt_, ngye_,
   {{0x3e7a8029,0x248d855a,0x22491bea,0x2cb2031d}},	//   sīt_, guem_, _riak_, nwyd_,
   {{0x22988065,0xa87b8051,0xa01b089c,0xa5bb0032}},	//   ték_, _מאמר, tröm, _akól,
   {{0x60c439d9,0x056682ff,0x44380706,0xda77b9da}},	//   _arim, _звен, _mhr_, няя_,
   {{0xddea803d,0x60c439db,0xf8bf016b,0x20010106}},	//   _عرضه_, _brim, tvé_, _smhi_,
   {{0xebe6b470,0xf8bf02be,0x442109c4,0x60c4079a}},	//   _подп, uvé_, yoh_, _crim,
   {{0xf8bf00e7,0xdb188168,0x2cb20114,0x44380133}},	//   rvé_, _javë, dwyd_, _nhr_,
   {{0x443e8352,0x60c439dc,0x6e26008e,0x25a00428}},	//   mmt_, _erim, _bkkb, ffil_,
   {{0x7c3e12ca,0x442ca578,0x60c404dc,0xbcfb0061}},	//   empr, lld_, _frim, _beép,
   {{0x644ab9dd,0x60c40d1a,0x69cd004f,0xe4531f31}},	// [24b0] _kifi, _grim, _inae, اضر_,
   {{0x7a3639de,0x1602016f,0x68470032,0x62888037}},	//   ráte, रोबर_, _dédì, ordo,
   {{0xa5f939df,0x442c808b,0x443839e0,0x8c1b81c6}},	//   _жену_, ild_, _dhr_, לומי,
   {{0x442139e1,0x443e8192,0x644ab9e2,0x225c1517}},	//   soh_, hmt_, _lifi, ívka_,
   {{0x25ad90f4,0x644a803c,0x442110e1,0xed59812b}},	//   veel_, _oifi, poh_, ndže_,
   {{0x9f4585a4,0x442139e3,0x644ab9e4,0x66028314}},	//   _allá_, qoh_, _nifi, _amok,
   {{0xf1a7a4ac,0x6e2d1793,0x25adb9e5,0xf1b981f4}},	//   _пран, olab, teel_, _taš_,
   {{0x6e2d39e6,0xa91d808d,0x2bc9001b,0x02a28133}},	//   nlab, _adže, राका, _chọọ,
   {{0x8cc4009a,0x6e2d0051,0x628881ca,0x644a80b4}},	//   रियो, ilab, erdo, _bifi,
   {{0xa5bb0125,0x69cd39e7,0x6e2d005d,0x24890187}},	//   _skól, _anae, hlab, iram_,
   {{0xa3d2035a,0x2489395c,0x05e10035,0x60c439e8}},	//   वात_, hram_, _नवंब, _srim,
   {{0xd70d83eb,0x442c81ed,0x24890f7c,0xdd1d8162}},	//   िपीठ_, ald_, kram_, _câţi,
   {{0x248939e9,0x644ab304,0x248db9ea,0x7c218b99}},	//   jram_, _fifi, quem_, polr,
   {{0x2007b845,0x65698aa2,0x7a38b9eb,0x644a8314}},	//   nini_, lbeh, míte, _gifi,
   {{0xd62a39ec,0xa5961bd8,0x91fd00eb,0x6e2d3673}},	//   дове_, кращ, mpān, flab,
   {{0x200780f6,0x6e2d39ed,0xa6e9801c,0x6569b9ee}},	//   hini_, glab, _trươ, nbeh,
   {{0x200780f6,0xb9070a49,0x25a039ef,0xa5071628}},	// [24c0] kini_, _যে_, rfil_, вета_,
   {{0xdca3246b,0x2007b9f0,0x64a30fbf,0x2bd210be}},	//   рафи, jini_, рафа, साधा,
   {{0xee3a0604,0x44278239,0xd259102a,0xeb9739f1}},	//   _оно_, _mkn_, еці_, тих_,
   {{0x248902df,0x6d5b81c0,0x656981ed,0x58868a14}},	//   bram_, jcua, jbeh, выка,
   {{0xa3d22af8,0x2007b9f2,0x443ea578,0xdce4012b}},	//   वाद_, fini_, ymt_, obič,
   {{0x2007b9f3,0x44380352,0x656980e1,0x02a281bc}},	//   gini_, _uhr_, ebeh, _shọọ,
   {{0x60090503,0x644ab9f4,0xa3d58aad,0x63bc2ab0}},	//   nžma, _rifi, हान_, _iarn,
   {{0x44279600,0x644ab9f5,0x6adb00ab,0x531b01c6}},	//   _akn_, _sifi, _যেকো, _חולצ,
   {{0x61e08068,0x41d6000c,0x442789ca,0x229c026f}},	//   _ioml, धानस, _bkn_, lík_,
   {{0x3866b9f6,0x442c8051,0x2bb7816f,0x63bc39f7}},	//   mpor_, uld_, _असणा, _jarn,
   {{0x63bc39f8,0x443ea0e5,0x229c03cb,0x764b8065}},	//   _marn, rmt_, ník_, _figy,
   {{0x2489061c,0x61e080b9,0x8b0781d0,0xad9b0032}},	//   yram_, _joml, _skří, _amún,
   {{0x63bc00b9,0x6ba78106,0x442c80b9,0xcdf781c6}},	//   _oarn, ärgå, pld_, _במאי_,
   {{0xdb03b9f9,0x44278118,0x69cd0114,0x61e0b9fa}},	//   _canó, _gkn_, _wnae, _loml,
   {{0x2bb7835a,0xdceb80eb,0x5c37807c,0xdb019647}},	//   _असता, _iegā, _שטוב_, gelä,
   {{0x24893021,0x518715da,0x61e0836a,0x229c016b}},	//   tram_, _рука, _noml, dík_,
   {{0x6e2d39fb,0x2007b9fc,0x63bc39fd,0x7bda822c}},	// [24d0] rlab, yini_, _barn, ojtu,
   {{0x31790117,0x248939fe,0xd378809a,0x6e2d39ff}},	//   lasz_, rram_, nać_, slab,
   {{0xf09f01c1,0x16229c6f,0x6e243a00,0x78a980e1}},	//   ltà_, मवार_, boib, _spev,
   {{0xd378ba01,0xf6500117,0xf1bf0032,0xa5f902de}},	//   hać_, _گئی_, ndá_, _чему_,
   {{0xd378809a,0xf09f3a02,0x3c398036,0x61e081d0}},	//   kać_, ntà_, lève_, _doml,
   {{0xe73989e0,0xb4df016f,0xf09f3500,0x1e95ba03}},	//   нел_, तही_, ità_, грир,
   {{0x2007ba04,0xed599641,0xd3788063,0x9f5105a4}},	//   rini_, ной_, dać_, lizó_,
   {{0x2007ba05,0x26c5803a,0xe8d9082e,0xe3b88085}},	//   sini_, _vrlo_, _afọ_, dlıq_,
   {{0xdd118182,0x2007b440,0xdd918065,0x9f5101ca}},	//   _düşm, pini_, لوں_, nizó_,
   {{0x7a3896a5,0x3a292da9,0x7c25016b,0x2007ba06}},	//   ríte, _akap_, nohr, qini_,
   {{0x81b68a49,0x420a1056,0x224d81e2,0xf09f0098}},	//   জার_, енно_, _kiek_, età_,
   {{0x3a2900b9,0xdb088333,0x6ec08651,0x75ea01d0}},	//   _ckap_, cedí, विरु, _výzk,
   {{0x22478400,0x4427ba07,0x229c016b,0x66099c2b}},	//   ínky_, _tkn_, zík_, miek,
   {{0x660985d7,0x25bdba08,0x224dba09,0xdb01ba0a}},	//   liek, _hawl_, _liek_, telä,
   {{0x4425ba0b,0x98a50029,0x249fba0c,0xd757004e}},	//   mol_, ālā_, ltum_, الفت_,
   {{0x66098341,0x229c0125,0xe1f20077,0x25bfba0d}},	//   niek, vík_, _دست_, ndul_,
   {{0xfbb788af,0x61e0b437,0x63bc1b4e,0xd57505a8}},	// [24e0] _असाम, _roml, _parn, русь,
   {{0x44258355,0x229c3a0e,0x61e0ba0f,0x69a0224b}},	//   nol_, tík_, _soml, ग्री,
   {{0xdee60187,0x63bc3a10,0x7f9b0039,0x51869860}},	//   _сони, _varn, _אביז, гула,
   {{0x4425ba11,0xa3d20ebf,0x200a3a12,0xd3788035}},	//   hol_, वाह_, libi_, zać_,
   {{0x4425ba13,0x63bc3a14,0x7a1c81d0,0x25bf8326}},	//   kol_, _tarn, jčte, ddul_,
   {{0xb4c20aed,0x2ca00e23,0x4425ba15,0x3866ba16}},	//   ्मी_, mtid_, jol_, rpor_,
   {{0x2ca02fdb,0x4425ba11,0x3866ba17,0x09a980c8}},	//   ltid_, dol_, spor_, ওয়া,
   {{0xd3788d38,0x200a03bf,0xb05b016d,0xa3d2056b}},	//   wać_, hibi_, dvän, वाव_,
   {{0x7ddc8117,0x644e3a18,0x200a3a19,0x4425831d}},	//   _kész, _kibi, kibi_, fol_,
   {{0x3a2680c9,0x4425ba1a,0x200a04b9,0x644e2221}},	//   loop_, gol_, jibi_, _jibi,
   {{0x9e669db0,0x53348764,0xa91d8267,0x6609af05}},	//   _свед, рент, _idža, biek,
   {{0xf09f0698,0xf2d30158,0xe3b88085,0xd378809a}},	//   ttà_, צער_, rlıq_, sać_,
   {{0x4425ba1b,0x7984031d,0x3dc00114,0x7d7b83de}},	//   bol_, _ddiw, ddiw_, _טראג,
   {{0x4425ba1c,0xf09f01c1,0x644e3a1d,0xc3568698}},	//   col_, rtà_, _nibi, _съдъ,
   {{0x3a268cfa,0xa36f80e1,0xd90f003d,0xf09f3a1e}},	//   koop_, äčši, تیک_, stà_,
   {{0x2bd290be,0x270e8201,0xb4c20361,0x442a3a1f}},	//   तावा, _mən_, ्मू_, _akb_,
   {{0x9f4100f1,0xa91d8390,0x200a3a20,0x1ae200ab}},	// [24f0] _kohë_, _odža, bibi_, _গেলে_,
   {{0x644e3a21,0x320b3a22,0x6609ba23,0xbcfb0118}},	//   _cibi, licy_, ziek, _aféc,
   {{0x644e3a24,0xddd00214,0xe45f0106,0x9e350391}},	//   _dibi, _çeşi, _grön_, _венч,
   {{0x320b0035,0x4425ba25,0xac951fd9,0x69d80f12}},	//   nicy_, zol_, _камш, यायी,
   {{0x656d1ade,0x4425ba26,0xa3e5950e,0x2ca00428}},	//   mbah, yol_, _नवल_, ctid_,
   {{0xdceb8087,0xba7712c8,0x656d3a27,0x9f518085}},	//   _legă, _مارت, lbah, _özü_,
   {{0x224da393,0x6609ba28,0xb3d2035a,0xec360039}},	//   _tiek_, tiek, सारख, _כאשר_,
   {{0x656d3a29,0xfbb78063,0x249fba2a,0x4425ba2b}},	//   nbah, _असहम, ttum_, wol_,
   {{0x4425ba2c,0x25bfba2d,0xec768a14,0x20ce808b}},	//   tol_, rdul_, апы_, rðið_,
   {{0xa3ab01b6,0x6609ba2e,0x249fba2f,0x60c9ba30}},	//   _कॉम_, siek, rtum_, _irem,
   {{0x249fba31,0xddc701e2,0xc5d5a22c,0x216a1d5e}},	//   stum_, gpjū, _віль, кини_,
   {{0x4425831d,0xb05b00f2,0x249f808b,0xcfaa80ab}},	//   sol_, rvän, ptum_, _গোপন,
   {{0x69d801ab,0x777702f7,0x7a1200eb,0xb05b0106}},	//   याबी, _bexx, nāti, svän,
   {{0x88bd809a,0x248dba32,0x60c9804f,0x4425ba33}},	//   _wyśw, mrem_, _mrem, qol_,
   {{0x7ddc8117,0x645b9220,0xf74602c7,0x200a3a34}},	//   _rész, lqui, рево, ribi_,
   {{0xdd921baf,0x644e3a35,0x06af80ab,0x8e55035f}},	//   تور_, _sibi, কিপি, стрі,
   {{0x7a3614b5,0x9f4780f7,0xa3d2064a,0x248d808e}},	// [2500] láto, ghnú_, वाल_, nrem_,
   {{0x907b0158,0x7bc1ba36,0x2ca0005f,0x187b00be}},	//   _שטיי, ndlu, rtid_, _שטיב,
   {{0x2ca03a37,0xe29a027e,0x7a360c83,0xdb1503a7}},	//   stid_, тае_, náto, _razã,
   {{0x60c98456,0x7ae31aff,0x50669988,0xb05b016d}},	//   _brem, änta, атка, kväl,
   {{0x270e8085,0xe046b0ed,0x76440041,0xf8b80074}},	//   _sən_, анди, mmiy, ेटिय,
   {{0x76443a38,0x24803a39,0x7a360c83,0xdb073a3a}},	//   lmiy, msim_, káto, _cajó,
   {{0x44443a3b,0x764402a3,0x60c9ba3c,0x7a3d28d6}},	//   mm_, omiy, _erem, léte,
   {{0x60c98ac6,0xe5c68544,0x806680e8,0x61e43a3d}},	//   _frem, рско, _вваж, _noil,
   {{0x2bd2800d,0x7a388aae,0x6aa9026c,0x44443a3e}},	//   ताला, cíta, _ćefi, om_,
   {{0x44443a3f,0x69c2838e,0xdb1c06c0,0x628781b9}},	//   nm_, ldoe, _parè, ġjon,
   {{0x4444245f,0x78ad003a,0x78a28a9e,0x4b7b00be}},	//   im_, _spav, ltov, כטיג,
   {{0x61e40083,0x261704b7,0xdca68d91,0x248dba40}},	//   _coil, għol_, _вади, brem_,
   {{0x78a284e8,0xfeb804c0,0x69c0ba41,0xb4c206a7}},	//   ntov, یافت_, _mame, ्मो_,
   {{0x44443a42,0xb4c22518,0xdb18ba43,0x8c43802e}},	//   jm_, ्मै_, _haví, _дече,
   {{0x69c08012,0x61e41a2f,0xc9872791,0x0cb6ac4c}},	//   _oame, _foil, _купи, _अनुम,
   {{0x44443a44,0x81ab8a49,0x5d550381,0xdb0504b8}},	//   em_, _কোন_, скат, nehå,
   {{0xa3d20006,0x78a2ba45,0x78ad026c,0xbddb0036}},	// [2510] वां_, jtov, _upav, _bièr,
   {{0x6380001b,0x656d3350,0x6fb509a7,0x7a388c83}},	//   vání, sbah, _امدا, víta,
   {{0x60c9b69f,0xdb1501ac,0x645b8661,0x69c09eda}},	//   _srem, _bazá, zqui, _bame,
   {{0xb5a73a46,0x44443a47,0xc9878966,0xdb18801b}},	//   _трой, am_, ружи, _naví,
   {{0x69d8016f,0x7c2880f1,0x7a3603b0,0xb05b0106}},	//   याती, kodr, záto, kväm,
   {{0x645d82ba,0xa3d22518,0xf1bf002a,0xafe28198}},	//   ísim, वाः_, xoán_, зошл,
   {{0x75ea026f,0x657b820d,0x69c0ba48,0x7a38ba49}},	//   _výzv, tauh, _fame, síta,
   {{0x660d3a4a,0x248dba4b,0x69c0ba4c,0xff1804de}},	//   niak, trem_, _game, יקות_,
   {{0x32f78085,0xf1bf00e1,0x7c28ba4d,0x60c9a65a}},	//   məyə_, hlás_, fodr, _urem,
   {{0x61e421c6,0x69c0ba4e,0x248dba4f,0x660d0102}},	//   _soil, _zame, rrem_, hiak,
   {{0x645bba50,0x61e43a51,0xdb1c3a52,0x69c0ba53}},	//   squi, _poil, _paré, _yame,
   {{0x7a36037d,0x245b8073,0xa06a017c,0xb0c30361}},	//   ráto, _têm_, лама_, शिंग,
   {{0x660d3a54,0x61e402be,0x6e298118,0xfd568039}},	//   diak, _voil, moeb, _השני_,
   {{0x7afe3a55,0x76aa8201,0x7a3d0019,0x7c28b673}},	//   yzpt, _həya, véte, codr,
   {{0x670d83bb,0x229580f7,0xe45f0106,0x528581a8}},	//   िपटक_, _العس, _dröm_, _البك,
   {{0x78a2803e,0x4444146a,0x6459ba56,0x660d3a57}},	//   ytov, wm_, _kuwi, giak,
   {{0x228387d9,0x78a2826f,0x7ae30106,0x146291d3}},	// [2520] lık_, xtov, äntn, _kọọp,
   {{0x444410af,0x69c0ba58,0x76443a59,0x24803a5a}},	//   um_, _same, smiy, rsim_,
   {{0x62818422,0x7d090503,0xdcef0029,0x24803a5b}},	//   nslo, _žest, _vecā, ssim_,
   {{0x44443a5c,0xe8fa8b79,0x69c0b0a1,0x6579ba5d}},	//   sm_, лле_, _qame, _newh,
   {{0x69c2ba5e,0x17549afd,0x6459ba5f,0xb3b7ba60}},	//   rdoe, овля, _nuwi, _असंख,
   {{0x69c080f6,0x78a2ba61,0xab2a1db0,0x62838503}},	//   _wame, rtov, _бога_, _ovno,
   {{0x78a2ba62,0x69c0ba63,0x76aa8085,0xdb18b8fa}},	//   stov, _tame, _bəya, _paví,
   {{0x8a06875a,0x78a2ba64,0x22838214,0x6459820d}},	//   _узбе, ptov, dık_, _buwi,
   {{0x628380d2,0xb87b0019,0x7a388061,0x645989c4}},	//   _avno, nyít, líto, _cuwi,
   {{0x660d3a65,0x2cbd82d5,0x27e58326,0x6459ba66}},	//   ziak, _dswd_, _goln_, _duwi,
   {{0x02a39ff8,0xdb050106,0x91bc914f,0x6281a2c9}},	//   прям, pehå, _ईसाई, gslo,
   {{0x7f3b8158,0x22403a67,0x224680b9,0x200e811c}},	//   _געבו, _chik_, nmok_, lifi_,
   {{0x25b7803d,0x22401abb,0x9f4101d6,0xe9df0061}},	//   _دهند_, _dhik_, _dlhý_, rjú_,
   {{0x765aa00a,0x7bcd84b9,0x26cc81a1,0xe8d9082e}},	//   _kuty, _ɗauk, _krdo_, _ndụ_,
   {{0xa3d583a4,0xa3cc2f7b,0x6b7b83c8,0x4b7b810f}},	//   हार_, _शोध_, _גרונ, _גאוו,
   {{0xe8d901bc,0x765a8c2e,0xf1bf0019,0x75f581d0}},	//   _adụ_, _muty, rlás_, _lázn,
   {{0xc4b681fe,0x660d0695,0xae023a68,0x045b00d7}},	// [2530] _अनोख, riak, रोइन_, اجرت_,
   {{0x3a2d81b0,0x60cd018e,0x41a5000c,0x660d3a69}},	//   _skep_, _iram, ग्रस, siak,
   {{0x1dc43a6a,0xbddb06c0,0x660d3a6b,0x31698333}},	//   _लोकत, _chèc, piak, ñazo_,
   {{0x60cd3a6c,0x3f9e80e7,0xdb0183ba,0x2246a022}},	//   _kram, _actu_, relø, gmok_,
   {{0x200e84bb,0x26ccba6d,0x777a8580,0xf8c903db}},	//   fifi_, _ardo_, _betx, िटिय,
   {{0x26cc8052,0x765aba6e,0x6281ba6f,0x26c7817f}},	//   _brdo_, _buty, yslo, tvno_,
   {{0x6e29ba70,0x7bd53a71,0xa91d8267,0xe7398009}},	//   toeb, _inzu, _idžm, шек_,
   {{0x7d0907ca,0xdb0a82af,0x25a93a72,0x63b7026f}},	//   _þess, _dafü, nfal_, lexn,
   {{0x38690072,0xa3bd116e,0xa3d58ebf,0x79898176}},	//   _ntar_, _आसा_, हाल_, _idew,
   {{0x7bc50077,0x228387d9,0x98178b8c,0x52a98319}},	//   ndhu, tık_, _ابرا, авом_,
   {{0x60cd3a73,0xbf1580f7,0xa3ab03dd,0x28c78424}},	//   _aram, _بواب, क्य_, लिवि,
   {{0x6459ba74,0x75f59c32,0x60cd3a75,0x7a3601d0}},	//   _tuwi, _zázn, _bram, mátk,
   {{0x7a36026f,0x316d2564,0x89360bbe,0x6281a03c}},	//   látk, ñeza_, تعدا, sslo,
   {{0x6281ba76,0xcb6980e8,0x6283ba77,0x7a1201a9}},	//   pslo, _таке_, _tvno, vātu,
   {{0x26cc1313,0x7bc3802e,0x60cd3a78,0x65c60081}},	//   ído_, _ianu, _eram, обва,
   {{0x60cd3a79,0x7bd502af,0x660b80b9,0x7989ba7a}},	//   _fram, _anzu, _jmgk, _ndew,
   {{0xdca31982,0x69d63a7b,0x7bc3ba7c,0x64a33a7d}},	// [2540] мати, _inye, _kanu, мата,
   {{0x69c40102,0x38a43a7e,0x7bc53a7f,0x7989ba80}},	//   _haie, mör_, gdhu, _adew,
   {{0x75f5ba81,0x7bc39e78,0x2bce035a,0x0576080b}},	//   _názo, _manu, _होणा, _واحد,
   {{0xa3d58e88,0x7bc3ba82,0x69c4011b,0x69c63a83}},	//   हाँ_, _lanu, _jaie, ndke,
   {{0x79898114,0x2db70039,0x7a388019,0x3ebeba84}},	//   _ddew, _ולכן_, síto, _sstt_,
   {{0x7a38ba85,0x629701df,0x7bc3ba86,0xdb1c06a5}},	//   píto, buxo, _nanu, _harí,
   {{0x81e68a49,0x38a42a9c,0x69d63a87,0xf1ca000c}},	//   যোগ_, hör_, _onye, ियान,
   {{0x85f70158,0x2bce2594,0x442e88dc,0x69d601bc}},	//   ַציע_, _होता, _skf_, _nnye,
   {{0xdb1c3a88,0xa3d5881f,0x6283026f,0x1da6a13e}},	//   _marí, हां_, ánov, क्षत,
   {{0x7a360013,0xe9ff8028,0x69d60247,0x60c080fc}},	//   láth, _kiến_, _anye, _ismm,
   {{0x6fde01aa,0x69c40c50,0x38693a89,0xada68196}},	//   मानं, _baie, _star_, _мажл,
   {{0x38a43a8a,0x61e2ba8b,0x60cd3a8c,0x7a3601a8}},	//   för_, njol, _pram, náth,
   {{0x38a4016d,0xa3ab00d4,0x7a3d00e7,0x10741273}},	//   gör_, क्ड_, géta, мляю,
   {{0x69d6082e,0x7bc3ba8d,0x9f45826b,0x248681f4}},	//   _enye, _ganu, _bolè_, _ivom_,
   {{0x226380e1,0x98ac00eb,0x61e283ba,0xdb1c046d}},	//   ľské_, ādā_, kjol, _barí,
   {{0x442cba8e,0x2d580153,0xc333812a,0xa5bb026b}},	//   lod_, жить_, _קוק_, _akór,
   {{0x80ba8c28,0x2902009a,0xa8028214,0xdb1c05e4}},	// [2550] _शैले, czka_, şıyo, _darí,
   {{0x69a71094,0x442cba8f,0xe9ff8028,0x7bc38079}},	//   ट्री, nod_, _biến_, _xanu,
   {{0x20113a90,0xdb1c2333,0x2c608247,0x7bc53a91}},	//   mizi_, _farí, _lòd_, rdhu,
   {{0x24868025,0x5bb783dd,0x2011270e,0x442cba92}},	//   _ovom_, _अस्व, lizi_, hod_,
   {{0x442cba93,0x7e6202d4,0x3f69ba94,0xead0826b}},	//   kod_, _čopi, било_, _jẹbi_,
   {{0x657d1b74,0xcc76012a,0x20113a95,0x442c8682}},	//   _hesh, _מעשה_, nizi_, jod_,
   {{0x657d135e,0xfd4c8028,0x5334326c,0x645d0010}},	//   _kesh, _triể, _жерт, _husi,
   {{0x645d27cb,0x657d3a96,0x7bc39bcc,0xf0768065}},	//   _kusi, _jesh, _sanu, _کیوں_,
   {{0x7bc3ba97,0x64552fa7,0x442c831d,0x657d3a98}},	//   _panu, _kizi, fod_, _mesh,
   {{0x7a361313,0x442cba99,0x7bc38201,0x1c42af84}},	//   máti, god_, _qanu, нным,
   {{0x69c43a9a,0x64553a9b,0x7bc3ba9c,0x645d3a9d}},	//   _paie, _mizi, _vanu, _lusi,
   {{0x38a43a9e,0x61e9a388,0x3d0f8072,0x273481a8}},	//   tör_, _joel, _तेथे_, súnú_,
   {{0x645d01e2,0x442c831d,0x7bc3ba9f,0xa01b02af}},	//   _nusi, bod_, _tanu, rsön,
   {{0x76499d84,0x64553aa0,0x7a3d3aa1,0x7fd50d8e}},	//   lmey, _nizi, réta, місі,
   {{0x61fbbaa2,0x657d3aa3,0x645d1af6,0x290224a3}},	//   _olul, _besh, _ausi, szka_,
   {{0xd90d03f8,0x645d3aa4,0xe8860b5b,0x661bbaa5}},	//   ایی_, _busi, _егип, nnuk,
   {{0x64553aa6,0x657d3aa7,0xdb0a8125,0xdb1c3aa8}},	// [2560] _bizi, _desh, _hafð, _varí,
   {{0xf7461fee,0x6b81baa9,0x2d800036,0x7a36041c}},	//   _непо, nalg, saie_, dáti,
   {{0x1dbd863a,0x64553aaa,0x62853aab,0x7a388019}},	//   ्यात, _dizi, gsho, sítm,
   {{0x6d59882e,0x442cbaac,0xa3cc0105,0x61e9baad}},	//   _ngwa, zod_, _शोर_, _coel,
   {{0x61e98b3c,0x442c97ea,0xed52003d,0x6b81baae}},	//   _doel, yod_, _سپس_, kalg,
   {{0x62853aaf,0xe9ff8028,0x2609800f,0x6d59bab0}},	//   bsho, _tiến_, ़ोसी_, _agwa,
   {{0x8c432c65,0x24868025,0x04430607,0xe2970ba7}},	//   _чере, _svom_, _черн, _нар_,
   {{0xd49a85f1,0xceb30051,0x442c8428,0x645506a0}},	//   бро_, גיה_, wod_, _zizi,
   {{0x38c883f8,0x442cbab1,0x7d043ab2,0x290280f2}},	//   _بازی_, tod_, nzis, _åka_,
   {{0xe7d700ab,0x7e6d8279,0xcfaa803d,0x6e2d0ece}},	//   _হত্য, ćapr, _دارم_, zoab,
   {{0x764280dd,0x644880eb,0x394021ba,0x20113ab3}},	//   _thoy, rmdi, _azis_, vizi_,
   {{0x24868052,0x442cbab4,0x7a38816b,0x61e98118}},	//   _tvom_, sod_, dítk, _xoel,
   {{0x657d3ab5,0x6b81bab6,0x50672c39,0x20113ab7}},	//   _resh, balg, ятна, tizi_,
   {{0x645d3ab8,0x1ae200c8,0x657d3ab9,0xdb0e3aba}},	//   _rusi, _গেছে_, _sesh, _jabó,
   {{0x645d2ad0,0xa3e02e45,0x657d3abb,0xa3c20e88}},	//   _susi, थान_, _pesh, ्यन_,
   {{0x63bababc,0x64553abd,0x645d3abe,0xa4d500e8}},	//   letn, _sizi, _pusi, мобі,
   {{0x629ababf,0x657d00f1,0x2718809a,0x61e9910f}},	// [2570] luto, _vesh, धपुर_, _roel,
   {{0x62851e1d,0x6455029a,0xf045026a,0x78fc0039}},	//   tsho, _qizi, _تعبی, _לפחו,
   {{0x64553ac0,0x3f830025,0x629a90dd,0x2bae816f}},	//   _vizi, maju_, nuto, ज्या,
   {{0x2fc58bc5,0x62853ac1,0x645d3ac2,0x64551ec7}},	//   _salg_, rsho, _tusi, _wizi,
   {{0x48aba523,0x645d0364,0x63babac3,0x61e9838e}},	//   стем_, _uusi, ketn, _voel,
   {{0x63babac4,0x629abac5,0x7a36016b,0x2ca90106}},	//   jetn, kuto, ráti, mtad_,
   {{0x2ca93ac6,0x61e9837a,0x6b81bac7,0x2fc58257}},	//   ltad_, _toel, valg, _valg_,
   {{0x629abac8,0x3f831dc1,0x61fbbac9,0x661b985b}},	//   duto, haju_, _ulul, unuk,
   {{0x3f83003b,0x6b81baca,0x2ca93acb,0x76498214}},	//   kaju_, talg, ntad_, rmey,
   {{0x3f830025,0x9f638009,0x798d00a4,0x3e7a80eb}},	//   jaju_, ävät_, _adaw, būt_,
   {{0x3f830289,0x7bc70c9e,0x629abacc,0x7a3d026f}},	//   daju_, _maju, guto, rétn,
   {{0x7bc73acd,0x2ca93ace,0x7bd8bacf,0xa91d81a1}},	//   _laju, ktad_, _envu, _adži,
   {{0xa3c88e18,0xb4bc009a,0xa3c21b91,0x3ce00118}},	//   _लोक_, _आने_, ्यम_, xxiv_,
   {{0x63ba80d2,0xfd108bbe,0xdb0e002a,0x2d9f841c}},	//   cetn, _حجم_, _xabó, lgue_,
   {{0xe9ff8028,0x67ef806a,0xa3d1109b,0x798d0197}},	//   _nhắn_, _højs, वयन_, _fdaw,
   {{0xa3ab0305,0xee3a0d13,0x51560d5f,0x6009026c}},	//   क्स_, іна_, _отпу, džmu,
   {{0x3f830025,0xd0408201,0xbc6a08ca,0x2ca93ad0}},	// [2580] baju_, _ermə, زمان_, gtad_,
   {{0x3f830025,0x60c43ad1,0x7d043ad2,0xdb1c0722}},	//   caju_, _isim, rzis, _parà,
   {{0xdb1c3ad3,0x09e699bb,0x7bc72bc9,0xe9ff801c}},	//   _bará, можн, _daju, _chắn_,
   {{0xdb1c2c70,0xaca40135,0xaca38133,0xdb0e2d83}},	//   _cará, _akụr, _anọk, _sabó,
   {{0x7a38bad4,0x307a00be,0xdb0e24fe,0x7bc89113}},	//   níti, קאַנ, _pabó, yddu,
   {{0x60c40010,0x7bc73ad5,0x386010eb,0x7a363ad6}},	//   _msim, _gaju, _muir_, mátu,
   {{0xa3c880cf,0xdb1c3ad7,0x25adbad8,0x63babad9}},	//   _लोग_, _fará, ffel_, vetn,
   {{0xdb1c037d,0x60c43ada,0x3f8300d2,0x25a03adb}},	//   _gará, _osim, zaju_, ngil_,
   {{0x80a68bca,0x7bc72f70,0x60c43adc,0x063703de}},	//   _زمان, _yaju, _nsim, ונקט_,
   {{0xa3d58ee6,0x427487b6,0xdb1c3add,0xb05b0192}},	//   हाग_, нгос, _zará, hwäc,
   {{0x3f830025,0x59d00074,0x7bc88c72,0x629a82d5}},	//   vaju_, _तोहर, rddu, uuto,
   {{0x629abade,0x3f8310ab,0x51f80a14,0x27ec80e1}},	//   ruto, waju_, днюю_, _hodn_,
   {{0x38601536,0x3f830025,0x6e2290ab,0xd90f04c0}},	//   _cuir_, taju_, _ijob, شید_,
   {{0x629abadf,0x67ef813c,0x2d84bae0,0x59dd001b}},	//   puto, _højr, lame_, याहर,
   {{0x3f830025,0x60c43ae1,0x7bc73ae2,0xa01b0338}},	//   raju_, _esim, _raju, lsök,
   {{0x3f830052,0x7c3abae3,0x4d7b80be,0x2ca93ae4}},	//   saju_, lltr, ַרבע, ttad_,
   {{0x6458bae5,0x3f830052,0xe81fbae6,0x7bc7031b}},	// [2590] _kivi, paju_, _बदला_, _paju,
   {{0x2ca93ae7,0x2c64016d,0x2d84bae8,0x59dd016f}},	//   rtad_, _död_, hame_, यावर,
   {{0xa3ab053f,0x6fdd835a,0x3a2fbae9,0x2ca93aea}},	//   क्ष_, पासू, togp_, stad_,
   {{0x6458baeb,0xdb260077,0x2d848110,0x7bc70010}},	//   _livi, رونی, jame_, _waju,
   {{0x7bc73aec,0x9f5800f7,0x6d5d0420,0x25ad8106}},	//   _taju, mhrá_, _igsa, vfel_,
   {{0x764d1d84,0x24893aed,0x07a29182,0xbcfb0032}},	//   lmay, msam_, гашн, _agég,
   {{0x25ad8012,0x49bb8077,0x9f458722,0x82a401a1}},	//   tfel_, _وارد_, _allò_, _иште,
   {{0xcf58004c,0xa3ab09a3,0x2d84baee,0x764d03bf}},	//   ובות_, क्र_, game_, nmay,
   {{0x2d9fbaef,0xed5982ce,0x24893af0,0x25adbaf1}},	//   rgue_, ježe_, nsam_, rfel_,
   {{0x3ec48364,0x69cbbaf2,0x6e229d60,0x5ba980bf}},	//   ästä_, ldge, _ejob, чком_,
   {{0xa91d807a,0x61ed0087,0x3d0f8035,0x764d02d0}},	//   _deže, _boal, _तेरे_, kmay,
   {{0x61ed3af3,0x69cb84eb,0xc7a90bea,0x25e0816f}},	//   _coal, ndge, _לב_, काणी_,
   {{0xe9ff8104,0x7e61837a,0x69c9808e,0x9f45823e}},	//   _nhận_, _hulp, _maee, _molí_,
   {{0x7a38baf4,0xb8e8001b,0x2c64016d,0x6e3b9a87}},	//   ríti, _ईन_, _röd_, llub,
   {{0x6e29016b,0x1da686a7,0xb87b01df,0xf6262cab}},	//   čebn, क्कत, rxía, едво,
   {{0x60c43af5,0x4423008e,0xa2c300bc,0x91fd01a9}},	//   _tsim, _ajj_, रबन्, spār,
   {{0xdd8f0c48,0x79863af6,0x24891849,0x60c43af7}},	// [25a0] صول_, makw, gsam_, _usim,
   {{0x61ed0613,0x26c5835f,0x2d84baf8,0x7aea0106}},	//   _zoal, _oslo_, zame_, äfto,
   {{0x6e3bbaf9,0xdb1c0073,0xeac9877f,0x2bf68158}},	//   klub, _març, _jẹ_, עמען_,
   {{0xeac98028,0x79863afa,0x5fde001b,0x4911852a}},	//   _mẹ_, nakw, मावल, _देहो_,
   {{0x2d84bafb,0xdb1a80f1,0x6b850748,0x27fe82f7}},	//   vame_, tetë, bahg, _pltn_,
   {{0xfaa63afc,0xe7e30035,0xdcc88129,0x290688f1}},	//   _паго, खाया_, _rỉ_, rzoa_,
   {{0x75f8026f,0x4df43432,0x2d84bafd,0x2d823afe}},	//   _nízk, _इकाई_, tame_, _keke_,
   {{0x6458baff,0x63be3b00,0x433b0158,0xc1ca0bb8}},	//   _sivi, lepn, _זעלב, ियोग,
   {{0x2d84bb01,0x61ed3b02,0xdb1c3b03,0x79863b04}},	//   rame_, _roal, _barç, dakw,
   {{0xdee68b9c,0xa01b04b8,0x61ed0812,0xdb1abb05}},	//   _пози, rsök, _soal, leté,
   {{0x645891b9,0x645d8091,0x629e3b06,0x59dd001b}},	//   _vivi, ísir, nupo, यालर,
   {{0x2d820025,0xdb1a8019,0xf54f0a2c,0xaca48133}},	//   _neke_, neté, _bụla_, _abụz,
   {{0xa3c23b07,0x66040ce1,0xed59811f,0x61ed0493}},	//   ्या_, dhik, teže_, _voal,
   {{0x2bd7823c,0x629e2834,0xa91dbb08,0xdb1c3b09}},	//   _भोपा, kupo, _idžt, _garç,
   {{0x79863b0a,0x764d03bf,0xed599502,0xf647016c}},	//   bakw, tmay, reže_, ехан,
   {{0xbddb02be,0xe9ff801c,0x7bdc01ec,0x7bcabb0b}},	//   _thèm, _phận_, _anru, _hafu,
   {{0xdbf98063,0x76aa8201,0x764d3b0c,0x5d550ae7}},	// [25b0] _głów, _dəyi, rmay, ткат,
   {{0xb60381ac,0x7bca87de,0xdd868061,0xb60680ce}},	//   čšin, _jafu, _ھو_, lešć,
   {{0x7bca822e,0x24893b0d,0x764d01cc,0xb05b0338}},	//   _mafu, ssam_, pmay, sväs,
   {{0x66043b0e,0x38a9bb0f,0xe9ff80ff,0x7bcabb10}},	//   chik, túr_, _thận_, _lafu,
   {{0x8fa599bb,0x69cbbb11,0x491180c2,0x28f8804a}},	//   вале, rdge, _देशो_, нець_,
   {{0x7bca819e,0xe7398ce6,0x673a8123,0xe8d9027d}},	//   _nafu, мел_, _bytj, _ngọ_,
   {{0x38a981a8,0xd00eac7d,0x79862acc,0x3d150072}},	//   súr_, تلو_, yakw, _नेते_,
   {{0xa91da3b8,0x53340615,0xeac9877f,0xed59a252}},	//   _vežb, _сест, _rẹ_, мой_,
   {{0xdb1c03bf,0x6e3bbb12,0x7bcaa05e,0xf1bf00e1}},	//   _parç, rlub, _bafu, deá_,
   {{0x75f5803e,0x79863b13,0x6e3bbb14,0x7bca87b6}},	//   _názv, wakw, slub, _cafu,
   {{0xf1dd053e,0x91f581ab,0x79863b15,0xfbd20039}},	//   यांन, _आवाज_, takw, בתי_,
   {{0x22490205,0xa5bb007b,0x3f87bb16,0xe8d9019d}},	//   _chak_, _sjón, lanu_, _egọ_,
   {{0x2d823b17,0x7986062b,0xd9e380ab,0x63b50654}},	//   _reke_, rakw, _মতাম, _obzn,
   {{0xdb1a8065,0x35a7800f,0x3dcdbb18,0x2d823b19}},	//   zeté, _गाड़, ldew_, _seke_,
   {{0x44333b1a,0x2d823b1b,0x66043b1c,0xb05b0106}},	//   dox_, _peke_, thik, tvär,
   {{0x6b839755,0x25bf82b1,0xf1bf00f7,0xdb0181ec}},	//   _heng, neul_, ceá_, rflä,
   {{0x2cada59e,0x44333b1d,0x7bcaafa7,0x6b83bb1e}},	// [25c0] nted_, fox_, _yafu, _keng,
   {{0x395f9e90,0x66043b1f,0x389b0158,0x0e6600ae}},	//   _agus_, shik, _קיינ, _икон,
   {{0x6b839dda,0x20183b20,0x3f87bb21,0x395f8359}},	//   _meng, miri_, danu_, _bgus_,
   {{0x629e3b22,0x20183b23,0xb33c84b7,0x63be02f7}},	//   rupo, liri_, ngħa, sepn,
   {{0x629e3b24,0x25bf82b1,0x2cadb51b,0xf1aa0c28}},	//   supo, deul_, jted_, _कानन,
   {{0x934621d2,0x3f87bb25,0xe9ff8028,0xf1e40105}},	//   _анге, ganu_, _phản_, गाड़_,
   {{0xcac702de,0x2ca00fb0,0xa2e33b26,0x1ae30436}},	//   _игре_, luid_, _корд, _корм,
   {{0x645c011e,0x20183b27,0x7c3e203c,0x25bfbb28}},	//   _hiri, hiri_, llpr, geul_,
   {{0x20183b29,0x6b83bb2a,0x44383b2b,0x69d3826f}},	//   kiri_, _beng, _kkr_, ádež,
   {{0x69a5035a,0x645c3b2c,0x20183b2d,0x44382eec}},	//   _काही, _jiri, jiri_, _jkr_,
   {{0x6b839dda,0x20182137,0xcfa99a43,0x25bf8a2a}},	//   _deng, diri_, _سالم_, beul_,
   {{0xc333073a,0x7a388510,0x645c3b2e,0x7bcaa7cb}},	//   יות_, pítu, _liri, _wafu,
   {{0x6b83b8b9,0x2cad8051,0x20183b2f,0x7bca8b4a}},	//   _feng, cted_, firi_, _tafu,
   {{0x6b83bb30,0xdb1703a7,0xaca4082e,0x3eba02f7}},	//   _geng, nexã, _chọr, _bppt_,
   {{0x6602a315,0xbe881d7b,0x6d460102,0x7a3d0036}},	//   _klok, ксте_, _azka, héti,
   {{0x443ebb31,0x645c3b32,0x3f878024,0xa91dbad9}},	//   llt_, _airi, zanu_, _leža,
   {{0x645c3b33,0x2018260d,0x73d93b34,0x6b838d4e}},	// [25d0] _biri, biri_, ндар_, _yeng,
   {{0x33740b01,0xaca40133,0x46ac06a7,0x25bf8087}},	//   игур, _ghọr, _चहचह, zeul_,
   {{0x443ebb35,0x6602bb36,0x3f87bb37,0x7d09847f}},	//   ilt_, _olok, vanu_, zzes,
   {{0x443e82af,0x645c3b38,0xa2940d8e,0x3f87bb39}},	//   hlt_, _eiri, раці, wanu_,
   {{0x69349db0,0x3f87bb3a,0xa91dbb3b,0xe1348110}},	//   анцу, tanu_, _beža, анцы,
   {{0x645c3b3c,0x6602bb3d,0x13a7015b,0x2fde8118}},	//   _giri, _alok, _جنسی_, _cntg_,
   {{0x6b83bb3e,0x7a388065,0x6b888144,0x2be00f97}},	//   _reng, gíts, dadg, नारा,
   {{0x6b83a55a,0x20183b3f,0x656d3745,0x9d458b79}},	//   _seng, ziri_, ncah, лейд,
   {{0x6b83859c,0x629abb40,0x765d2bb5,0x89378875}},	//   _peng, erto, _misy, _شعرا,
   {{0x6602b1ab,0x60c9bb41,0x645c02a3,0x2cadbb42}},	//   _elok, _isem, _xiri, rted_,
   {{0x6602bb43,0x2cadbb44,0x6b83bb45,0x7d09900b}},	//   _flok, sted_, _veng, szes,
   {{0x6b83bb46,0x201839b3,0x3f85bb47,0x443ebb48}},	//   _weng, wiri_, _helu_, alt_,
   {{0x25e0853f,0x20183b49,0x657b903b,0x6b888079}},	//   कारी_, tiri_, mbuh, badg,
   {{0x9d1a8158,0x5ebb00c8,0x60c9bb4a,0x765d178f}},	//   _אונט, _উপজে, _msem, _aisy,
   {{0x20183b4b,0x657b82a5,0x7bc18e9a,0x3f85bb4c}},	//   riri_, obuh, melu, _melu_,
   {{0x645c3b4d,0x20183b4e,0x60c9bb4f,0xa3cc0beb}},	//   _siri, siri_, _osem, _शोज_,
   {{0x271f890a,0x2018266b,0x765d3b50,0x248dbb51}},	// [25e0] यपुर_, piri_, _disy, nsem_,
   {{0xdb150118,0x20180168,0xdb08bb52,0x6d4603c1}},	//   _nazó, qiri_, yedü, _vzka,
   {{0x645c3b53,0x60c9bb54,0xa91d99ba,0x200783ed}},	//   _viri, _asem, _reža, dhni_,
   {{0x7a3d10dd,0x645c3b55,0x3f8a3b56,0x248dbb57}},	//   téti, _wiri, labu_, ksem_,
   {{0x645c3b58,0x7bc1a645,0x3f85bb59,0x44383b5a}},	//   _tiri, kelu, _belu_, _tkr_,
   {{0x3f85bb5b,0x67d4b0fe,0x7a3d0866,0x645c051e}},	//   _celu_, року, réti, _uiri,
   {{0x60c9bb5c,0x7bc1bb5d,0x3f85ac62,0x6602bb5e}},	//   _esem, delu, _delu_, _plok,
   {{0x4427826c,0x7bce3b5f,0x3f8a28b8,0x629a80e1}},	//   _ajn_, _habu, habu_, vrto,
   {{0xa91d86c2,0x2fde80dd,0xed59812b,0x7a38bb60}},	//   _teža, _tntg_, teža_, síts,
   {{0x7bc1844e,0x20078b04,0x443ebb61,0x7bce3b62}},	//   gelu, chni_, ult_, _jabu,
   {{0x7bce33a8,0xd43700be,0xed59826c,0x81ce0264}},	//   _mabu, רטיי_, reža_, রান_,
   {{0x7bce3b63,0x5fe2863a,0x6602922e,0xd7e28072}},	//   _labu, पावल, _ulok, पावच,
   {{0x7bc1bb64,0x78a281e8,0x765d00b9,0x69cf0106}},	//   belu, nuov, _risy, rdce,
   {{0x7bce3938,0xdb1abb65,0xb8ed03e8,0xbcfb0118}},	//   _nabu, letí, _रन_, _ofér,
   {{0x3219096a,0xa91dbb66,0xf3f90087,0x78a29639}},	//   pisy_, _nežn, _îţi_, huov,
   {{0xe66410f8,0x7bce3b67,0x2bc706a7,0x78a2bb68}},	//   стро, _aabu, रजभा, kuov,
   {{0x3f8a022e,0x2616108a,0x7bce2bd8,0x69c28bc5}},	// [25f0] babu_, _नगरी_, _babu, deoe,
   {{0x59dd016f,0x26e49db4,0xa91d81ac,0x5d541860}},	//   याकर, _कपूर_, _bežn, скут,
   {{0x753d0063,0xdb152e3c,0x7afa8f06,0x63a501a8}},	//   _wysz, _razó, nytt, rghn,
   {{0x3f858067,0x6562836a,0x2614016f,0x7bc1bb69}},	//   _selu_, _ngoh, नोदी_, zelu,
   {{0x3f8590ab,0xa3d486ab,0x7afabb6a,0x2259128a}},	//   _pelu_, हया_, hytt, írky_,
   {{0xb8cd923a,0xb4c101fe,0xa3ac01b6,0xa3c23b6b}},	//   _कम_, ंबी_, _गाय_, ्यः_,
   {{0x7bc1802e,0x2c6980e1,0x69c29c2b,0x3f858609}},	//   velu, _súd_, beoe, _velu_,
   {{0x7bce3b6c,0x2007bb6d,0x6b870b80,0x7bc1bb6e}},	//   _zabu, shni_, _hejg, welu,
   {{0x81ce0a49,0xccf20158,0x7bc1bb6f,0xb882000d}},	//   রাম_, ַכט_, telu, říze,
   {{0x3ea300f1,0x798bbb70,0x1da781ab,0x5e8781e2}},	//   kujt_, lagw, _गावत, _будз,
   {{0x200581b9,0x248dbb71,0xa72000ab,0x7bc18087}},	//   _illi_, ssem_, _ধর্ম_, relu,
   {{0x186a0c8e,0xdb052a9c,0x7bc1b86a,0xc04903c8}},	//   ками_, behö, selu, _חז_,
   {{0x39490063,0x3f8a3b72,0x7d0d0bcf,0x2b158074}},	//   _czas_, tabu_, jzas, _फेरु_,
   {{0x2bd505b3,0x661b8110,0x68e204b7,0x8fa600a9}},	//   _डोला, liuk, _ġodd, јаве,
   {{0x7bce3b73,0x539a8039,0x3f8a3b74,0xe73a2639}},	//   _rabu, _סיקו, rabu_, тев_,
   {{0x7bce3b75,0x3f8a004f,0x75f5816b,0xa91dbb76}},	//   _sabu, sabu_, _zázr, _režn,
   {{0xdca60ba8,0xd46718a0,0x7bce1b5c,0xed5a00a9}},	// [2600] рази, иите_, _pabu, тоа_,
   {{0x9f4c3240,0x7bce3b77,0x4f963b78,0x25ab0609}},	//   ódó_, _qabu, _триу, _eccl_,
   {{0xbf9b012a,0x6441bb79,0x213f8748,0x661bbb7a}},	//   _בייש, illi, _ayuh_, kiuk,
   {{0x7bce3b7b,0x64a63341,0xbcfb0019,0x2005bb7c}},	//   _wabu, _кама, _igén, _alli_,
   {{0x7fe9325e,0xe7e29a22,0xb5fb0118,0x5fe2801b}},	//   _شریف_, पालप, _fiáb, पालल,
   {{0xdb17002a,0x7afa8198,0x224d9fe7,0x26da1502}},	//   sexá, yytt, _ehek_, _krpo_,
   {{0x9e06a43b,0xddc400eb,0x2900a978,0x42d505a8}},	//   ичил, rmiņ, šia_, _літу,
   {{0xa01b257d,0x64418009,0xdef78190,0x88818065}},	//   nsör, elli, рыш_, _کیون,
   {{0xafe6bb7d,0xa06a8198,0x75fc8176,0x07a6b0bb}},	//   _коал, _раза_, _jézi, _вазн,
   {{0x34b70051,0xe9ff8104,0xf366a5ab,0x690883bf}},	//   ספים_, _phần_, штин, ırdı,
   {{0xa3ab1391,0x8aa39ff8,0x6609805d,0x03d7007c}},	//   क्ट_, оряд, bhek, בוים_,
   {{0xf2d30158,0x9f5800f7,0x6609804f,0x6441ba6b}},	//   קער_, bhrú_, chek, alli,
   {{0x1bd48698,0xc31a00c8,0xbcfb3516,0x7afa8009}},	//   _голя, _তুমি_, _agén, sytt,
   {{0xe9ff8028,0x2005007b,0x9f4c816b,0x331780d7}},	//   _thần_, óli_, _lodí_, ازید_,
   {{0x543980be,0x798b8545,0xf8ae053d,0xc66809a5}},	//   _געװא, yagw, وکی_, иште_,
   {{0x442a3b7e,0x7a2801cc,0xe9df002a,0x443c80c3}},	//   _ajb_, nıtl, flúe_, _hkv_,
   {{0xf36701f3,0x39490289,0x442a3b7f,0x201cbb80}},	// [2610] атен, _uzas_, _bjb_, kivi_,
   {{0x60cd3b81,0x442a0b80,0x81ce00ab,0x224d8168}},	//   _isam, _cjb_, রাণ_, _shek_,
   {{0xb5fb0118,0xa91d81a1,0x2c7d0032,0x931901a8}},	//   _viáb, _pežo, _bádò_, دقاء_,
   {{0x38690748,0xa2d7bb82,0x644e0f3e,0xdb019277}},	//   _kuar_, यित्, _ehbi, rflø,
   {{0x98c7917e,0xe9df04c3,0x442a1142,0xe9ff801c}},	//   рсел, clúe_, _fjb_, _nhấn_,
   {{0x38693b83,0x25a93b84,0x60cd004f,0x7e68810c}},	//   _muar_, lgal_, _msam, _budp,
   {{0x386914ff,0x6609bb85,0xa91d817f,0x2294160e}},	//   _luar_, thek, _težo, _миря,
   {{0xc485bb86,0x25a93b87,0xf1cf8105,0x5bc711bc}},	//   блик, ngal_, _सोचन, _रघुव,
   {{0x201c811f,0x999f826f,0x386900b9,0xe9ff80ff}},	//   bivi_, _chuť_, _nuar_, _chấn_,
   {{0x75f58feb,0xf09f3b88,0x6609bb89,0x2005bb8a}},	//   _vázq, drà_, shek, _ulli_,
   {{0xd7f88554,0x60cd3b8b,0x7c2200e7,0xf09f047f}},	//   _тут_, _asam, éori, erà_,
   {{0xa3de035a,0x60cd00b9,0x7bc50168,0x6441bb8c}},	//   _दोन_, _bsam, hehu, slli,
   {{0x7bc52205,0xed4e9dd5,0xa3e803db,0x7989bb8d}},	//   kehu, _хо_, _मचल_, _meew,
   {{0x6d4bbb8e,0x438580f7,0x183580be,0x7989bb8f}},	//   _izga, _الثق, מאָל_, _leew,
   {{0x60cd3b90,0xa3ab0cf0,0xf09f023e,0x249f9a1c}},	//   _esam, क्छ_, arà_, lrum_,
   {{0x25a9015b,0x60dbbb91,0x38693b92,0x4d66044f}},	//   ggal_, _orum, _fuar_, скав,
   {{0x61e42963,0xe3ba0fbe,0x7a3d007b,0x1b1500ab}},	// [2620] _inil, лба_, rétt, _তুলে_,
   {{0x69c63b93,0x25a900f7,0xf1bf00f7,0x7bc53b94}},	//   leke, agal_, nnán_, gehu,
   {{0xa3b92e04,0x60dba676,0x7a280214,0x59dd06ae}},	//   _अउर_, _arum, yıtl, याचर,
   {{0x61f60901,0xdb1a87f0,0x7a3d3b95,0x994a81a8}},	//   _joyl, netá, létr, هلال_,
   {{0x201cbb96,0x2d803b97,0x10a3bb98,0x98a392b2}},	//   tivi_, mbie_, зичн, зиче,
   {{0x60dbbb99,0x76443b9a,0x7a3d3b9b,0x69c63b9c}},	//   _drum, lliy, nétr, heke,
   {{0xfaa32df8,0x69c63b9d,0x201c939a,0x443a3b9e}},	//   _наро, keke, rivi_, mop_,
   {{0x44443b9f,0x60dbbba0,0xa3c20076,0x5c74bba1}},	//   ll_, _frum, ्यक_, олит,
   {{0x69c60065,0x8cdb01a2,0x60dbbba2,0x2a6a00b9}},	//   deke, नियो, _grum, _hubb_,
   {{0x61e43ba3,0xda7a8d70,0x44443ba4,0x443a3ba5}},	//   _anil, лям_, nl_, nop_,
   {{0x44441dd9,0x76443ba6,0x61f63ba7,0xdb1a8144}},	//   il_, kliy, _boyl, fetá,
   {{0x69c63ba8,0x64a6af16,0x444413ac,0xf09f1e37}},	//   geke, _гада, hl_, trà_,
   {{0x443a3ba9,0x41aa101e,0x63bc0824,0x4444083d}},	//   kop_, _कारस, _obrn, kl_,
   {{0x3e6e000d,0x44443baa,0xf09f19c2,0x6e3d00b9}},	//   _být_, jl_, rrà_, _sksb,
   {{0xd5bb214a,0x69c63bab,0x76443bac,0xa3d5801b}},	//   лса_, beke, fliy, ाएर_,
   {{0x44443bad,0x60cd3bae,0x7c3ab937,0x69c63baf}},	//   el_, _tsam, lotr, ceke,
   {{0x320910ba,0x6fa9816f,0x7bc53bb0,0x3f8eb22c}},	// [2630] _ilay_, _घालू, tehu, kafu_,
   {{0xf3673bb1,0x44443bb2,0x7b671287,0x7c28bbb3}},	//   стан, gl_, стае, nndr,
   {{0x76443bb4,0x2ca00074,0xb99592c8,0x2367007a}},	//   bliy, arid_, قلاب, žnjo_,
   {{0xddc1802e,0x80cc00ab,0x7a28011c,0xdb088338}},	//   _mulţ, ামর্, yıtm, bedö,
   {{0x4444031d,0xb05b00e1,0x7bc53bb5,0x3f8e89ab}},	//   bl_, dväz, pehu, fafu_,
   {{0x69c63bb6,0x7c3a9c89,0x63bc008e,0x249fbbb7}},	//   zeke, jotr, _gbrn, vrum_,
   {{0x41aa0f12,0x2d8b3bb8,0x1dda8105,0x3209007e}},	//   _कालस, _kece_, _मोहत, _olay_,
   {{0xa3e70076,0xf1d9000f,0xd346003d,0x64453bb9}},	//   भाव_, _बोलन, _بیمه_, llhi,
   {{0x7c3abbba,0xdb1e0087,0x60dbbbbb,0x69c63bbc}},	//   fotr, cepâ, _urum, veke,
   {{0x32093bbd,0x69c63bbe,0x61e43bbf,0x249fbbc0}},	//   _alay_, weke, _snil, rrum_,
   {{0x69c63bc1,0x2fc7bbc2,0x5fae816f,0x26c101c0}},	//   teke, meng_, _घातल, _npho_,
   {{0x2d8b02a5,0x2fc7bbc3,0x3ea78722,0xf1bb80d4}},	//   _nece_, leng_, munt_, ोजिन,
   {{0x6e3b8024,0x443a10c1,0x29041f31,0x660d003d}},	//   moub, yop_, áma_, dhak,
   {{0x69c63bc4,0x2fc783f8,0x78a60289,0x290c009a}},	//   seke, neng_, rukv, ąda_,
   {{0x4444006a,0xdb1abbc5,0x69c63bc6,0x764407c0}},	//   vl_, petá, peke, tliy,
   {{0x3d150665,0x2fc7bbc7,0x2d8b3bc8,0x660d2a0f}},	//   _नइखे_, heng_, _cece_, ghak,
   {{0x2d8b0eef,0x76440201,0x2fc7bbc9,0x4444300d}},	// [2640] _dece_, rliy, keng_, tl_,
   {{0x44443bca,0x2fc78077,0xa91d82d4,0x41aa03eb}},	//   ul_, jeng_, _težj, _काँस,
   {{0x42ca0071,0x443a3bcb,0x2fc7bbcc,0x2d8b047f}},	//   рген_, rop_, deng_, _fece_,
   {{0xa3d58063,0xe0da9935,0x660d3bcd,0xfce616df}},	//   ाएँ_, иве_, chak, _домо,
   {{0x7e628118,0x7c288558,0x9989136f,0x660403e4}},	//   _riop, yndr, _dlaň_, mkik,
   {{0x2bae9305,0x7e62bbce,0x2fc7bbcf,0xdc3987c0}},	//   ज्ञा, _siop, geng_, kçıl,
   {{0x491a800d,0x23270098,0xe2970d5f,0x6fad000f}},	//   _मेरो_, _дори_, _мар_, _जासू,
   {{0x16378013,0x7ae10065,0xd5b78987,0xb5fb38fa}},	//   يسية_, _álta, ось_, _lián,
   {{0xa3d58063,0x3f8e84cd,0xf6530039,0x7982a54d}},	//   ाएं_, pafu_, וצה_, mbow,
   {{0x22400019,0x3ea78176,0x224681b9,0x60cd9b32}},	//   _akik_, bunt_, llok_, çame,
   {{0x32093bd0,0xdd8f8279,0xe73a804a,0x66042d82}},	//   _play_, _ош_, _теж_, kkik,
   {{0x7c3abbd1,0x601000f2,0x80ac0816,0x2246808e}},	//   sotr, _jämf, _जमशे, nlok_,
   {{0x7c3abbd2,0xfbcf87d2,0x2d8b3bd3,0xd2580a8e}},	//   potr, رتی_, _rece_, юць_,
   {{0x6e20bbd4,0x39450029,0xd83b234b,0xb4d690be}},	//   limb, āls_, рэм_, ाटी_,
   {{0x28d1800c,0x2246bbd5,0x660d3bd6,0x78a2826c}},	//   _दैनि, klok_, thak, hrov,
   {{0x6e208397,0x2246bbd7,0xdb1c02af,0xa5bb008b}},	//   nimb, jlok_, _darü, _njót,
   {{0x2d8b0052,0x660d3bd8,0x31690019,0x78a288ae}},	// [2650] _vece_, rhak, _igaz_, jrov,
   {{0x660d0578,0x6e20bbd9,0xdb1c3bda,0x69bc0f8d}},	//   shak, himb, _naró, ष्ठी,
   {{0x3f913bdb,0x6e209e79,0xa91d8353,0x660d005d}},	//   mazu_, kimb, _težk, phak,
   {{0x3f91005c,0xdce982ee,0x2fc7bbdc,0x2a649600}},	//   lazu_, zbeđ, weng_, _cimb_,
   {{0x2fc783f8,0x78a2826f,0xdb1c3bdd,0xdb150187}},	//   teng_, grov, _baró, _razõ,
   {{0xf77185ff,0xdb1c01df,0xa3da9344,0x7bc88369}},	//   رات_, _caró, _ढोल_, jedu,
   {{0x2fc7bbde,0x44210824,0x2246bbdf,0x63b405b9}},	//   reng_, mih_, blok_, žený,
   {{0x3ea7bbe0,0x2fc7bbe1,0xc4859e58,0xed59ab0d}},	//   runt_, seng_, плик, leži_,
   {{0x629c84c3,0x2fc78d6d,0x6e299df7,0x442e81a1}},	//   áron, peng_, rneb, _bjf_,
   {{0xa91dbbe2,0x3ea7bbe3,0xdc39880a,0x7bc8bbe4}},	//   _neži, punt_, tçıl, gedu,
   {{0x7bd53be5,0xf8a9010f,0x6e20bbe6,0x661d3204}},	//   _mazu, _תש_, bimb, _omsk,
   {{0x44213be7,0xdeba8039,0xdb1c0035,0x06c380ab}},	//   hih_, _למעל, _zaró, ্মদি,
   {{0x44213be8,0xfce5bbe9,0x3e71bbea,0xa5bb0125}},	//   kih_, _холо, _hát_, _ljós,
   {{0x442102f7,0xed59b7a2,0x913a80be,0x7bc8bbeb}},	//   jih_, ježi_, מערק, cedu,
   {{0x26de01df,0xa3c10ebf,0x8c3d8214,0xdee3369c}},	//   íto_, ्जन_, nuşm, нори,
   {{0x799b8077,0x3e71801c,0x386d81b0,0x8afa81c6}},	//   _nduw, _mát_, _ouer_, _להצי,
   {{0x3e71bbec,0x66042de5,0x7bd53bed,0x386d8326}},	// [2660] _lát_, rkik, _bazu, _nuer_,
   {{0x66043bee,0x7bd50012,0x6e20bbef,0x69d601b4}},	//   skik, _cazu, zimb, _haye,
   {{0x3f8c8805,0xe6460a13,0x38b60e34,0x6e20bbf0}},	//   _redu_, _неоп, lær_, yimb,
   {{0x23720029,0x3f8cbbf1,0x69d6010c,0x7bc8811b}},	//   _šajā_, _sedu_, _jaye, zedu,
   {{0x4421048f,0x69d62a54,0x38b600b2,0x6e208234}},	//   bih_, _maye, nær_, vimb,
   {{0x2d923bf2,0x4421135a,0x25adbbf3,0x3e71bbf4}},	//   laye_, cih_, egel_, _bát_,
   {{0xc0598cde,0x7bc8bbf5,0x3e7180ff,0xdb1c0511}},	//   ції_, vedu, _cát_, _varó,
   {{0x3e71826f,0x78a2bbf6,0x25adbbf7,0x69d63bf8}},	//   _dát_, prov, ggel_, _naye,
   {{0x6e20bbf9,0x7bd50309,0xb4d68744,0xb05b0106}},	//   rimb, _yazu, ाटे_, pväx,
   {{0x6e2081d3,0x798d323e,0x2d923bfa,0x6d4600ee}},	//   simb, _seaw, haye_, _myka,
   {{0x69d63bfb,0x600b0201,0x60c43bfc,0x26de80e5}},	//   _baye, _nüma, _apim, _urto_,
   {{0x69d63bfd,0xa3de10f7,0x38b60e51,0xb05b0865}},	//   _caye, _दोस_, fær_, hwät,
   {{0xb5fb2b49,0x7bc8bbfe,0x2d923bff,0x5c068098}},	//   _diál, pedu, daye_, _няка,
   {{0xdb1a8009,0xba73803d,0x7c3e026c,0x545380e8}},	//   tetä, بایت, jopr, _звіт,
   {{0x645a8125,0x69c081ac,0x98be00eb,0xdd9b0a42}},	//   mmti, _obme, ātā_, йша_,
   {{0x443eb934,0x442103f8,0x2d923c00,0x7e6600b9}},	//   lot_, wih_, gaye_, _cikp,
   {{0x42380bea,0xa91d803a,0xed5980fe,0x200c852a}},	// [2670] _מנהל_, _teži, teži_, _oldi_,
   {{0x443ebc01,0xf0920bea,0x442cbc02,0x69c08192}},	//   not_, _שני_, nnd_, _abme,
   {{0x2d923c03,0x44213c04,0x7bd5002e,0x8c4181ec}},	//   baye_, rih_, _vazu, äßig,
   {{0x442114e5,0xa2a483eb,0x200cbc05,0x661d3c06}},	//   sih_, _किन्, _aldi_, _umsk,
   {{0x443ebc07,0xddc41010,0x386d8073,0x89378013}},	//   kot_, lmiş, _quer_, أعضا,
   {{0xd3668013,0x443e8029,0x442101a5,0x7642930c}},	//   _له_, jot_, qih_, _akoy,
   {{0x443ebc08,0x6e2d3c09,0x29021d4b,0xddc40457}},	//   dot_, onab, zyka_, nmiş,
   {{0x6e2d02ec,0x6448a06b,0x442c9527,0xcfcd80ab}},	//   nnab, eldi, end_, লাইন,
   {{0x62988081,0x442c807b,0x443ebc0a,0x4c358084}},	//   _avvo, fnd_, fot_, дэнт,
   {{0x443ebc0b,0x69d9aaa9,0x69d63c0c,0x69cbbc0d}},	//   got_, ldwe, _saye, lege,
   {{0x61fbbc0e,0x81d700ab,0xdb1c007b,0x69d612b6}},	//   _koul, সান_, _jarð, _paye,
   {{0x69d9bc0f,0xa3c10076,0x29020063,0x61fb8009}},	//   ndwe, ्जड_, tyka_, _joul,
   {{0x200403a7,0x51553c10,0x6e2d0114,0xaca381bc}},	//   êmio_, етру, dnab, _maịk,
   {{0xb8f61008,0x443ebc11,0x61fbbc12,0x69d6029b}},	//   _सन_, cot_, _loul, _waye,
   {{0x7c3e007d,0xf7430767,0x7f430009,0x2d923c13}},	//   vopr, веро, верж, taye_,
   {{0x237801dd,0x6e2d3c14,0x69cbbc15,0x249900b9}},	//   _sfrj_, gnab, jege, _bvsm_,
   {{0x7c3e3c16,0x2d923c17,0x69cbbc18,0x60c4265a}},	// [2680] topr, raye_, dege, _upim,
   {{0x2d8f8c39,0x61e9bc19,0x2d923c1a,0xa91d81a1}},	//   _lege_, _anel, saye_, _ježu,
   {{0x61fbbc1b,0x76499632,0x320d828d,0x628182d6}},	//   _boul, kley, _bley_, nplo,
   {{0x61fb8809,0x69cb8c1b,0x6b8e0102,0x443ebc1c}},	//   _coul, gege, _webg, zot_,
   {{0x443ebc1d,0x442c807b,0x64488bbd,0x61fbbc1e}},	//   yot_, ynd_, yldi, _doul,
   {{0xd12f9a3e,0x6e243c1f,0x656b80e5,0x237802df}},	//   جمه_, liib, _aggh, _ufrj_,
   {{0x443e86d4,0xdb1c007b,0x61fbbc20,0x2d8fbc21}},	//   vot_, _garð, _foul, _bege_,
   {{0xceb30051,0xd49a813a,0x3ea0801b,0x442cbc22}},	//   דיה_, оро_, čit_, wnd_,
   {{0x443ebc23,0x7d040a40,0x64a383a7,0x2d8fbc24}},	//   tot_, nyis, вања, _dege_,
   {{0x442c8051,0x61fb8bfe,0xed598654,0x9f5a03ed}},	//   und_, _zoul, ježu_, _copë_,
   {{0x443ea6a5,0xa3c10054,0x442cbc25,0x271c8264}},	//   rot_, ्जत_, rnd_, _পুরো_,
   {{0x443ebc26,0x2d8f90ab,0x20ca0540,0x7d040009}},	//   sot_, _gege_, िबंध, kyis,
   {{0xb4bd1880,0x9cb381a8,0xe8e081bc,0x6e2401b4}},	//   _आहे_, _لمنت, daịs_, diib,
   {{0x36d5146c,0xdb1e0187,0xa29483a9,0x2d8fbc27}},	//   ногр, cepç, _закі, _zege_,
   {{0x80d5800f,0x69cbbc28,0x683f01d0,0xc5fb0073}},	//   _मैने, yege, vádě, оѓа_,
   {{0xc3338039,0xddc40059,0x7640bc29,0x7bd88bdf}},	//   _שוק_, rmiş, nomy, _havu,
   {{0x61fb9dd8,0x69cbbc2a,0x7bd8bc2b,0x54550103}},	// [2690] _roul, vege, _kavu, еват,
   {{0x69cbbc2c,0x61e9bc2d,0x61fbbc2e,0x2a69022c}},	//   wege, _snel, _soul, _hiab_,
   {{0x69cbb0a8,0x61fbbc2f,0x2a690069,0x7640bc30}},	//   tege, _poul, _kiab_, komy,
   {{0x7bd8bc31,0xdb1c007b,0x7640809a,0xe4a70087}},	//   _lavu, _varð, jomy, _орго,
   {{0xf1c1052a,0x61fb82be,0x69d9800b,0x7d16009a}},	//   ष्यन, _voul, rdwe, czys,
   {{0x61fbbc32,0x2a6901c5,0x78ab8cfa,0x7bd8ae0a}},	//   _woul, _liab_, rugv, _navu,
   {{0x61fbbc33,0x7649bc34,0x69cbb0d4,0x2007bc35}},	//   _toul, tley, pege, rkni_,
   {{0xb8d580c8,0x61e9bc36,0x2a69022c,0x6ec206a7}},	//   _জন_, _unel, _niab_, _लहसु,
   {{0x3e753c37,0xdd918117,0x7bd8bc38,0x3949022c}},	//   _låt_, نوں_, _bavu, _nyas_,
   {{0x7649bc39,0x6281b711,0x3707a29c,0xaf078992}},	//   sley, tplo, _очев, _очек,
   {{0x3e75016d,0x76498ce9,0x7bd8bc3a,0xdbcc9434}},	//   _nåt_, pley, _davu, róðu,
   {{0x2a69022c,0x7afc816d,0xaca38135,0x6e240079}},	//   _ciab_, ärta, _abụk, xiib,
   {{0xa3c1053f,0x7bd8822b,0xed59812b,0x2a690176}},	//   ्जा_, _favu, težu_, _diab_,
   {{0x7bd8bc3b,0x66099df7,0x39490122,0x3d188035}},	//   _gavu, lkek, _dyas_, _बेटे_,
   {{0x7bc3836e,0x6e2402ec,0x2a690037,0x84648081}},	//   _ibnu, tiib, _fiab_, _ръце,
   {{0x7d040364,0x6441bc3c,0xee3a00e8,0x7bd89ad6}},	//   tyis, loli, їна_, _zavu,
   {{0x44259a2f,0xdca30e6b,0x7bd882a0,0x64a30f04}},	// [26a0] oil_, лати, _yavu, лата,
   {{0x7d160d38,0xa3e7073c,0x4425bc3d,0x68e43c3e}},	//   rzys, भाग_, nil_, _irid,
   {{0xa3b7835a,0x387fbc3f,0xad9b3c40,0x68e40140}},	//   _छान_, _atur_, _clús, _hrid,
   {{0x44259882,0xa2d51516,0xaca401bc,0x68e43c41}},	//   hil_, णिज्, _ajụr, _krid,
   {{0x6441b9d4,0x394901c0,0x69c43c42,0xc0e38a41}},	//   koli, _xyas_, _mbie, лоцк,
   {{0x4425ad26,0x2ab88065,0xe8d9001c,0x6441bc43}},	//   jil_, yéb_, _ngờ_, joli,
   {{0x6441bc44,0x69c43c45,0x0cd0146d,0xa3e70254}},	//   doli, _obie, _हनुम, _ядра_,
   {{0x6ed38086,0x7bd8bc46,0x68e4026c,0xe7e080d4}},	//   _xəbə, _savu, _orid, _गोरा_,
   {{0x6441bc47,0xddde00eb,0xf8d49513,0xdb1e25ac}},	//   foli, _atpū, _धनिय, sepä,
   {{0x69c43c48,0x6441bc49,0x2a6910af,0x600b0059}},	//   _abie, goli, _siab_, _cüml,
   {{0x68e43c4a,0xa3b6801b,0x2a6901c0,0xdb1c3c4b}},	//   _arid, ङ्ग_, _piab_, _obrí,
   {{0xdc12817b,0xc3330039,0x44258c5e,0x7bd8bc4c}},	//   rşıl, טות_, ail_, _wavu,
   {{0x6e22bc4d,0x68e43c4e,0x3d189513,0xc05b00e8}},	//   _imob, _crid, _बेचे_, зів_,
   {{0x4425bc4f,0x6441bc50,0x20d60efd,0x6ed38201}},	//   cil_, coli, džić_, _səbə,
   {{0x9f34021e,0x68e436a0,0x2a690282,0x80c400ab}},	//   гері, _erid, _tiab_, শিষ্,
   {{0x68e43c51,0xe7e786a7,0x45d4004a,0x44d202d6}},	//   _frid, _टोना_, лосс, _bņ_,
   {{0x629aa1dd,0x629c0201,0x61ed3c52,0x68e43c53}},	// [26b0] lsto, _avro, _inal, _grid,
   {{0x69cf0179,0x69c421f3,0x600b03e3,0xdb01bc54}},	//   lece, _zbie, _kümm, rflö,
   {{0xd0110117,0x61ed3c55,0xdb1a806a,0xc1740041}},	//   _ملک_, _knal, getø, _haɗa_,
   {{0x69cf3c56,0x6441bc57,0xdbd708e5,0x629abc58}},	//   nece, zoli, _sääs, isto,
   {{0x629c3c59,0xdbd703ff,0x4425bc5a,0x6441bc5b}},	//   _evro, _pääs, yil_, yoli,
   {{0x635527d4,0x44258201,0x44251bd7,0x2ca93c5c}},	//   _авгу, xil_, _öl_, mrad_,
   {{0x629a803b,0x25bfbc5d,0x61ed3c5e,0x4425bc5f}},	//   jsto, tful_, _onal, vil_,
   {{0x62853c60,0x4425bc61,0x78a48024,0x764d3c62}},	//   mpho, wil_, šiva, nlay,
   {{0x629a81ac,0x6fb2009a,0x442300b9,0xc1740300}},	//   esto, _जालं, _kmj_, _naɗa_,
   {{0x2367003b,0x62853c63,0x69db811e,0x629abc64}},	//   žnju_, opho, _haue, fsto,
   {{0x15b981e5,0x764d07d9,0x68e40140,0x629abc65}},	//   _жылы_, klay, _srid, gsto,
   {{0x68e43c66,0x4425bc67,0xa2c40a74,0xf2d200be}},	//   _prid, sil_, _रहस्, בעט_,
   {{0x4425bc68,0x764d3c69,0x66068019,0x22423c6a}},	//   pil_, dlay, ökke, rokk_,
   {{0x60c98133,0x68e40b81,0x7fd50558,0x61ed3c6b}},	//   _mpem, _vrid, лісі, _enal,
   {{0x69cf0207,0xa0673c6c,0x629abc6d,0x80b3864a}},	//   bece, тара_, csto, उंडे,
   {{0x6458820f,0x764d3c6e,0x940c0201,0xf1bf0333}},	//   _zhvi, glay, ələr_, lián_,
   {{0x2ca91487,0xdd8f0875,0x05661289,0x8e5500e8}},	// [26c0] grad_, زول_, тван, утрі,
   {{0x61ed3c6f,0x7bc1bc70,0x6d4b851e,0x62868904}},	//   _znal, nflu, _myga, ćkov,
   {{0xe2970bac,0x3f9804b9,0x69db81ec,0x442300c3}},	//   вах_, maru_, _baue, _dmj_,
   {{0x3ced017f,0x69db9ed6,0xaca38091,0x2ca93c71}},	//   _ševe_, _caue, _apọj, brad_,
   {{0x69db9919,0xa967951b,0xd7fa8162,0x8c3dbc72}},	//   _daue, вица_, дуй_, luşu,
   {{0xbcfb0065,0x442300ee,0x25daa7cf,0x9f6580e1}},	//   _egés, _gmj_, _खोजी_, _štát_,
   {{0x48ee8063,0x69cf07d9,0x59dd93ba,0x8c3d82d0}},	//   _आपको_, yece, _नोकर, nuşu,
   {{0x44443c73,0x7bdc3c74,0xe5c68895,0x3f983c75}},	//   lo_, _haru, тско, haru_,
   {{0x2603a797,0x3f9803c3,0x7bdc3c76,0x629abc77}},	//   _años_, karu_, _karu, wsto,
   {{0x44443c78,0x629a8a10,0x7bdc09ab,0x7bde000b}},	//   no_, tsto, _jaru, ndpu,
   {{0x44443c79,0x6e2281e0,0x60148722,0x81dc00ab}},	//   io_, _tmob, _càme, ঠান_,
   {{0x44443c7a,0x7bdc3c7b,0x3f933c7c,0x7e6b8122}},	//   ho_, _laru, _sexu_, _gigp,
   {{0x44443c7d,0x3e78bc7e,0x69dd3c7f,0xf1bf188b}},	//   ko_, _hét_, rdse, bián_,
   {{0x44443c80,0x3e788065,0x629a84fe,0x69cf3c81}},	//   jo_, _két_, psto, sece,
   {{0x44443c82,0x5f943c83,0x7c28bc84,0xa3ac064a}},	//   do_, рист, midr, _गाज_,
   {{0x444422f8,0x3ce6805c,0x7bdc0091,0x61ed3c85}},	//   eo_, _krov_, _aaru, _unal,
   {{0x444405ee,0x68e29487,0x7bdc3c86,0x764d0059}},	// [26d0] fo_, jvod, _baru, rlay,
   {{0x7bdc10da,0x600b0182,0x69dbbc87,0x2ca93c88}},	//   _caru, _mümk, _saue, rrad_,
   {{0x764d3c89,0xf8bf00e7,0x3e78801c,0xba7401a8}},	//   play, lté_, _nét_, لانت,
   {{0xc3338051,0x68e20029,0xb05b0884,0x60100106}},	//   בוע_, _šodi, städ, _jämn,
   {{0x44443c8a,0xf8bf3c8b,0x7bdc3c8c,0x3ce68069}},	//   bo_, nté_, _faru, _nrov_,
   {{0x601004b8,0x7bdc3c8d,0xf8bf00e7,0x8c3d82d0}},	//   _lämn, _garu, ité_, nuşt,
   {{0xaa67b385,0x8cdb0c1c,0xf1bf0118,0x7afc8338}},	//   _атак, निको, vián_, ärtl,
   {{0x53340ab5,0x64451066,0x7bdc136f,0x6010016d}},	//   _тест, lohi, _zaru, _nämn,
   {{0xc104a1d7,0x29198711,0x7bdc3c8e,0x660d3c8f}},	//   _پولي, _åsa_, _yaru, ikak,
   {{0x6b950024,0x22490ad4,0x7bdc02a3,0xa2a480d4}},	//   _jezg, _akak_, _xaru, _किश्,
   {{0x3f983c90,0x7bc1bc91,0x660d3c92,0xdd91803d}},	//   varu_, rflu, kkak, _هوا_,
   {{0x644504b9,0x3f980f3d,0x7999a9cf,0x9d199290}},	//   hohi, waru_, naww, _поет_,
   {{0x3ce68bbd,0x625880f7,0x644532b3,0x7c2884e1}},	//   _grov_, líoc, kohi, bidr,
   {{0x44443c93,0x3e718038,0x31568158,0x6e29bc94}},	//   xo_, _ešte_, טירן_, lieb,
   {{0xdb1c0a56,0x6da61ff3,0x3f983c95,0x3e78801c}},	//   _obrá, лива, raru_, _xét_,
   {{0x44443c96,0x7bdc3c97,0x660d04d2,0x2bc606b7}},	//   wo_, _saru, gkak, र्ना,
   {{0x44442639,0x7d098a5a,0xf8bf02be,0xe45a0abe}},	// [26e0] to_, nyes, cté_, ежа_,
   {{0x78a90904,0x2013008e,0x44441823,0x6e298192}},	//   ševc, _glxi_, uo_, hieb,
   {{0x7bdc3c98,0x91e6b012,0x81d700ab,0x2cbf8074}},	//   _varu, ложе, সার_, htud_,
   {{0x44443c99,0x7bdc3c9a,0xe947804e,0x2cbf8122}},	//   so_, _waru, گرمی, ktud_,
   {{0x859b0051,0x7bdc3c9b,0xa3b3816f,0x69c2bc9c}},	//   _אשכו, _taru, टला_, rfoe,
   {{0xd6da860a,0xa2a4816f,0x44443c69,0xa0679ae2}},	//   ети_, _किल्, qo_, гача_,
   {{0x5fb20076,0x62588013,0x7c28bc9d,0x645c00e1}},	//   _जाईल, ríob, vidr, _ihri,
   {{0x3ce6bc9e,0xa5bd8084,0xf8bf04e8,0x7c288799}},	//   _prov_, liųj, yté_, widr,
   {{0x27ef800d,0x7c28bc9f,0x20183ca0,0x247202d6}},	//   ální_, tidr, khri_, _fņme_,
   {{0xd12f87bd,0x610a80eb,0x660d358b,0x63ad8041}},	//   _عمل_, _vēlā, zkak, _ɓang,
   {{0xa68697f9,0x2bc62418,0xfbc60f1b,0x629e3ca1}},	//   _след, र्या, र्यम, nspo,
   {{0x54e688ca,0xaca42aaa,0xf8bf2593,0x9f5e9b48}},	//   _مستق, _akọr, tté_, _noté_,
   {{0xf8bf02be,0x02d110a1,0x645c3ca2,0xe9df3ca3}},	//   uté_, _सन्न, _ohri, rdú_,
   {{0x2bc6053f,0xddd00503,0xf8bf02be,0xc1740326}},	//   र्मा, _češk, rté_, _faɗo_,
   {{0xf8bf3ca4,0x6b7b812a,0x6e95079e,0xdce083bf}},	//   sté_, _ארונ, рибу, mamı,
   {{0x66028006,0xdce083bf,0x629e3ca5,0xf8bf00e7}},	//   _jook, lamı, dspo, pté_,
   {{0x64450284,0x660d3ca6,0x645c0083,0x8234026a}},	// [26f0] tohi, rkak, _bhri, _دروا,
   {{0x6b9a809f,0x6602bca7,0x645c3ca8,0xbd6817ae}},	//   natg, _look, _chri, урсе_,
   {{0x64453ca9,0x629e3caa,0xdddc011f,0xdb1a8118}},	//   rohi, gspo, sprš, metó,
   {{0xfde912c6,0x660285ee,0x60cd0133,0xb5fb268b}},	//   _ऑफिस_, _nook, _kpam, _ciát,
   {{0x69df00f1,0x26cc82c4,0x645c0635,0x02d1bcab}},	//   _maqe, _apdo_, _fhri, _तन्न,
   {{0x60cd313e,0x645c032f,0x60103cac,0x7999bcad}},	//   _mpam, _ghri, _näml, saww,
   {{0x6602bcae,0x629e0088,0xe57180f7,0x6e29bcaf}},	//   _book, cspo, يطة_, tieb,
   {{0x82378013,0x62588013,0x7aea013c,0x6602bcb0}},	//   _إرسا, ríoc, æfte, _cook,
   {{0xf1bf003e,0x6e29bcb1,0x1fa79a1f,0xdd99816b}},	//   riál_, rieb, _брег, raň_,
   {{0x60dbbcb2,0x68e9aa98,0x2cbf8151,0x6e29bcb3}},	//   _isum, _ired, rtud_, sieb,
   {{0xfbd20039,0xa5bb026b,0x60cd08f9,0x2cbfbcb4}},	//   חתי_, _amóm, _apam, stud_,
   {{0x01660656,0xaab682f1,0x998f8084,0xb34587f1}},	//   икно, _अमरक, mogų_, _alçà,
   {{0xe0d70098,0x291da1ee,0xaca4019d,0x2d8dbcb5}},	//   авя_, nzwa_, _kwụt, mbee_,
   {{0xb8ee023c,0x6b9a87f1,0x6e2600b9,0x6602838a}},	//   _रह_, catg, _smkb, _zook,
   {{0x44d68d38,0x69df00f1,0x6602846d,0xd62a07a1}},	//   _zł_, _faqe, _yook, вове_,
   {{0x78a90db7,0x0d860470,0x3ced017f,0xee372432}},	//   ševa, рлан, _ševa_, анс_,
   {{0x249fbcb6,0x8fa60294,0x629e3cb7,0x645c082a}},	// [2700] nsum_, _капе, wspo, _phri,
   {{0x389b00be,0x2246bcb8,0x69c982ec,0x515b01c6}},	//   _שיינ, wook_, _abee, _בכפו,
   {{0x60dba419,0xf1eb01ce,0x68e9bcb9,0xf77881b9}},	//   _asum, _जोड़_, _ared, _naħa_,
   {{0x68e992f1,0x00e6919d,0xb05b016d,0x249fbcba}},	//   _bred, ижен, ptäc, ksum_,
   {{0x68e9b3b0,0x6602bcbb,0x2246bcbc,0x60100009}},	//   _cred, _rook, rook_, _lämm,
   {{0xb8ce8403,0xa2e60364,0x2cadb8b4,0x6602b258}},	//   _कि_, _когд, dred_, _sook,
   {{0xe29734fd,0x68e99d95,0xfaa302cb,0x2bc606bf}},	//   _вас_, _ered, _маро, र्णा,
   {{0x68e98082,0x2d801122,0x28da8006,0x3e7c001b}},	//   _fred, ncie_, _मैथि, _mít_,
   {{0x68e9bcbd,0x6b9a809f,0x999901ac,0xfbc62518}},	//   _gred, tatg, nosť_, र्थम,
   {{0x5fb20076,0xe3b89014,0x60c2bcbe,0x66028b99}},	//   _जागल, lnız_, mtom, _wook,
   {{0x2d802201,0x6b9a8722,0x33770039,0x61e089c4}},	//   kcie_, ratg, יעים_, _kaml,
   {{0x61e2bcbf,0x2bc604c5,0x6ab681ce,0x2cadbcc0}},	//   ndol, र्ता, _अमीर, bred_,
   {{0x61e08010,0x3e7195db,0x63bc00d2,0x6b9abcc1}},	//   _maml, _išta_, _ocrn, patg,
   {{0x61e28364,0x44278b99,0x6b9a8197,0x2d80009a}},	//   hdol, _gmn_, qatg, ecie_,
   {{0x6448bcc2,0xf09f3cc3,0xd5bb0d5f,0xdb1abcc4}},	//   modi, ssà_, кса_, retó,
   {{0x442cbcc5,0x248901bf,0xef190035,0xdb1a8118}},	//   lid_, tpam_, ąż_, setó,
   {{0x60cd3cc6,0x442cbcc7,0x3f9cbcc8,0x61e28114}},	// [2710] _upam, oid_, kavu_, ddol,
   {{0x4ada8006,0x6448bcc9,0x442cbcca,0x3f9ca786}},	//   _बनाव, nodi, nid_, javu_,
   {{0x2bc60778,0xb5fb3ccb,0x25a6bccc,0x61e085e7}},	//   र्धा, _diár, _odol_, _baml,
   {{0x68e9bccd,0xa3e705fc,0x6448a1f8,0x2d8000e5}},	//   _pred, _मोर_, hodi, ccie_,
   {{0x69bc016f,0x442cbcce,0x95080065,0x84670098}},	//   ष्टी, kid_, _پہلے_, _въве,
   {{0x68e9bccf,0x6e2d3cd0,0xe7398e97,0x442cbcd1}},	//   _vred, liab, лел_, jid_,
   {{0x2486bcd2,0x7d0d3bac,0x61e0856c,0x2d993cd3}},	//   _atom_, lyas, _faml, _kese_,
   {{0x61e08558,0x249f856c,0x68e9904a,0x625880f7}},	//   _gaml, tsum_, _tred, líon,
   {{0xa3ab0d38,0x2d993cd4,0x7d0d3cd5,0x893993f7}},	//   _गया_, _mese_, nyas, _спас_,
   {{0x6448803a,0x6e2d3826,0x249fbcd6,0x2d993cd7}},	//   godi, hiab, rsum_, _lese_,
   {{0x9cf98a49,0x249fbcd8,0x81da80c8,0x8c1a0039}},	//   েছেন_, ssum_, ়ার_, רותי,
   {{0x2d993cd9,0x442cbcda,0xf53f0106,0x20058428}},	//   _nese_, aid_, _oxå_, _holi_,
   {{0xeb8e80ae,0xddc602a5,0x2005bcdb,0x44278359}},	//   _ни_, _nikš, _koli_, _tmn_,
   {{0x999901ac,0x7d0d3cdc,0x6b98826c,0x4427926a}},	//   vosť_, dyas, _gevg, _umn_,
   {{0x81bf00c8,0x20058668,0x2d993cdd,0xddc60110}},	//   ীয়_, _moli_, _bese_, _aikš,
   {{0x3f9c8da8,0x2d990511,0x2ca00074,0xdb170187}},	//   zavu_, _cese_, tsid_, nexõ,
   {{0x2d993cde,0x2aa38201,0x2d803cdf,0x61e0a715}},	// [2720] _dese_, lıb_, rcie_, _raml,
   {{0x61e08370,0xe7e782f1,0x25e80816,0x80ad04c5}},	//   _saml, _टोला_, _चोरी_, _जिते,
   {{0xe80d0063,0x2ca002f1,0x2aa38201,0x2a600282}},	//   _सकता_, ssid_, nıb_, _khib_,
   {{0x60c2bce0,0x6e2d3ce1,0x753d8035,0x6448b4e6}},	//   ttom, ciab, ższy, zodi,
   {{0x2005bce2,0x442cbce3,0xdb1e0019,0x81da80ab}},	//   _boli_, yid_, lepü, ়াল_,
   {{0x60c2bce4,0x66061e9a,0x442cbce5,0xa5bb0032}},	//   rtom, _hokk, xid_, _amóh,
   {{0x660618c2,0x442a3ce6,0x60c2a82f,0x2005bce7}},	//   _kokk, _imb_, stom, _doli_,
   {{0x6b989010,0x442cbce8,0x3f9a0904,0xd5ba8d91}},	//   _sevg, wid_, _lepu_, уск_,
   {{0x8fa6bce9,0x38cb815b,0xa3b3816f,0x2005bcea}},	//   _газе, _مالی_, टलं_, _foli_,
   {{0xb5fb0104,0x442a0267,0xdbf0801b,0x66060a64}},	//   _khác, _jmb_, _tříd, _lokk,
   {{0x442cbceb,0x6448bcec,0xe9f90160,0x95ca80e8}},	//   rid_, rodi, анні_, _була_,
   {{0x442c8665,0x661b822e,0x66060125,0x2a6001c0}},	//   sid_, chuk, _nokk, _chib_,
   {{0xa3b8023c,0x442a01e0,0x799d3ced,0x2486bcee}},	//   छला_, _omb_, rasw, _utom_,
   {{0x2d993cef,0x7d0d3cf0,0x3f9a3cf1,0xa3e706a7}},	//   _sese_, vyas, _cepu_, _मों_,
   {{0x2d993cf2,0x877b82f6,0x59c88540,0x66063cf3}},	//   _pese_, ראלי, रभार, _bokk,
   {{0x442a138d,0x7d0d3cf4,0xb5fb01a8,0xdceb81b9}},	//   _amb_, tyas, _sháb, _qegħ,
   {{0x62871434,0x2d993cf5,0x442a3cf6,0x26c30353}},	// [2730] _stjo, _vese_, _bmb_, stjo_,
   {{0x224b3cf7,0x6e2d056c,0x2d993cf8,0x7d0d3cf9}},	//   lock_, siab, _wese_, ryas,
   {{0x7d0d3cfa,0x68ed03fb,0x625880f7,0x2005bcfb}},	//   syas, _hrad, ríon, _roli_,
   {{0x09ab00c8,0x41558a08,0x66063cfc,0x3abb80be}},	//   গ্রা, овес, _gokk, רמאנ,
   {{0xed468986,0x09e300c8,0x26de9fe7,0x2aa38085}},	//   _آپ_, যাপা, _asto_, zıb_,
   {{0x2aa38201,0xa29506b5,0x68ed0010,0x62588118}},	//   yıb_, _магі, _mrad, líol,
   {{0xb05b0009,0x66063cfd,0x661bbbd6,0x2a668282}},	//   ytän, _yokk, thuk, bmob_,
   {{0xf2d2093f,0x68ed3cfe,0xc48584dd,0x7bd73cff}},	//   _קען_, _orad, олик, lexu,
   {{0x2bc614a7,0x26de9220,0xe3b19e44,0x2a6001c0}},	//   र्वा, _esto_, ورد_, _rhib_,
   {{0x5ac9bd00,0x661bbd01,0x2aa38085,0x2a6010ba}},	//   алом_, shuk, tıb_, _shib_,
   {{0x68ed3c72,0x78a9005c,0xb05b0009,0xd7f8801c}},	//   _arad, ševl, ttän, _khăn_,
   {{0x2a6001c5,0x2aa38085,0xb6868019,0xdd1e928a}},	//   _qhib_, rıb_, _بھول_, _síťo,
   {{0x786004b8,0x6e2b826b,0x7e7a890d,0xb05b3d02}},	//   höve, _imgb, _zutp, rtän,
   {{0xb05b3d03,0x799b82f7,0x66063d04,0x68ed3d05}},	//   stän, _leuw, _sokk, _drad,
   {{0xdee3117e,0x442a3d06,0x66e33d07,0x2a600069}},	//   мори, _rmb_, мора, _thib_,
   {{0x68ed3d08,0x78a414a2,0xe1ff0511,0x39401d91}},	//   _frad, _tviv, lmón_, _txis_,
   {{0xad660077,0x64430353,0x3f9a3d09,0x248d80b9}},	// [2740] زاره, čnin, _tepu_, npem_,
   {{0x6b562345,0x66063d0a,0x61e63027,0xc17400fc}},	//   отех, _wokk, ldkl, _naɗi_,
   {{0x61e402b8,0x59c10107,0x86460f75,0x68ed04e8}},	//   _kail, ष्कर, _множ, _zrad,
   {{0xd7f880ff,0x62588118,0x3f858162,0xdcfd0084}},	//   _chăn_, cíol, _aflu_, _nesė,
   {{0x25a03d0b,0xe8949a97,0x2d9201d3,0x10a3b9f1}},	//   mail_, чаль, mbye_, дичн,
   {{0x4aa9853e,0xeeaabd0c,0xacd90158,0x76aabd0d}},	//   _किंव, атик_, _פֿרי, атив_,
   {{0xa01b0198,0xc1740300,0x09b20264,0x26de8037}},	//   mpöt, _daɗi_, ট্যা, _qsto_,
   {{0x78ad8025,0x25a03d0e,0x61469577,0x6b9c3d0f}},	//   šava, nail_, _деба, _herg,
   {{0x07a69cd5,0x625880f7,0x6b9c0074,0x7aee007a}},	//   _маан, níom, _kerg, _hrbt,
   {{0x25a004bc,0x3eb800f1,0x6b9c3d10,0x9b6aa639}},	//   hail_, kurt_, _jerg, ишна_,
   {{0x61e4154c,0xa5bb0073,0x25a03d11,0x68ed3d12}},	//   _bail, _imóv, kail_, _srad,
   {{0x68ed01e2,0x61e43d13,0x201a00df,0xba2b00e8}},	//   _prad, _cail, _alpi_, ріод_,
   {{0x25a0125b,0xcd368c2b,0x660f9614,0x61e43d14}},	//   dail_, _براب, öcke, _dail,
   {{0xcbd500c8,0x3eb83d15,0x6b9c3d16,0x7c2aab86}},	//   _হচ্ছ, furt_, _nerg, _umfr,
   {{0x09d000c8,0xdd9b0615,0x25a03d17,0xdb4f80e8}},	//   িয়া, иша_, fail_, _цю_,
   {{0x3ead0775,0x61e43d18,0x25a00014,0x7bce01b9}},	//   čet_, _gail, gail_, _abbu,
   {{0x6b9c3d19,0x2fd80338,0x68ed1408,0xc05b035f}},	// [2750] _berg, berg_, _urad, _він_,
   {{0xa2a490f7,0x6b9c3d1a,0x7c3abd1b,0x61e40102}},	//   _किञ्, _cerg, nntr, _zail,
   {{0x23c2800f,0x25a00013,0x926ba432,0x6b9c3d1c}},	//   _शानद, bail_, арда_, _derg,
   {{0x25a0008c,0x7c3abd1d,0x6b9c1384,0x69c0bd1e}},	//   cail_, hntr, _eerg, _ccme,
   {{0x6b9c301d,0xc5fa0039,0x6d5d1247,0x00000000}},	//   _ferg, _הפרט, _uzsa, --,
   {{0x3abb03f8,0x6b9c3d1f,0xe8d90133,0x66e598d1}},	//   _پاسخ_, _gerg, _nzọ_, зока,
   {{0xa195835f,0x19959e47,0x7e628a15,0x160f08d4}},	//   _навч, _навя, _bhop, _सवार_,
   {{0x7c3abd20,0x6b9c0102,0xe8d901bc,0xd6ce80f7}},	//   entr, _zerg, _azọ_, اقي_,
   {{0x69d9bd21,0x6d4301ec,0xc1740326,0x81198652}},	//   mewe, ßnah, _taɗi_, _ужас_,
   {{0x69d9bd22,0x4b258221,0x3e71826c,0x6b9c0118}},	//   lewe, змов, _tšto_, _xerg,
   {{0x81e500c8,0xef20009a,0xb05b0106,0x91e61617}},	//   নান_, ążki_, rtäl, поне,
   {{0xb05b04b8,0x7a362d77,0x6eca811c,0x61463d23}},	//   stäl, kšte, _məbl, зема,
   {{0x25a002be,0x61e60123,0x61e43d24,0x7e698f81}},	//   vail_, rdkl, _vail, mmep,
   {{0x7c94803d,0x601d86c0,0x62890bcf,0xb4d7bd25}},	//   _آشنا, _fème, _čeon, ाबी_,
   {{0x61e43d26,0x81b380ab,0x4e1f8105,0x25a03d27}},	//   _tail, জ্য_, _बताई_, tail_,
   {{0x2cb201b0,0xbddb32e1,0x69d98bfd,0x6e3bbd28}},	//   tryd_, _ajèb, jewe, nnub,
   {{0x25a03d29,0x69d9bd2a,0x2d9d819d,0x3eb83d2b}},	// [2760] rail_, dewe, _mewe_, surt_,
   {{0x2d9d879f,0xdce600eb,0x25a010a2,0x625881a8}},	//   _lewe_, _iekļ, sail_, ríom,
   {{0x6b9c3d2c,0x877b0039,0x51869777,0x9f970039}},	//   _verg, _לאיי, пула, _מדיה_,
   {{0x69d9844e,0x63a1bd2d,0xe8faa4bd,0x320900ff}},	//   gewe, haln, йле_, _xoay_,
   {{0x6b9c0867,0x3dc380c8,0xb5fb001c,0xc5c380ab}},	//   _terg, ্যাল, _khán, ্যাপ,
   {{0x7e629838,0xfaa63d2e,0x9326015b,0x660401c8}},	//   _shop, _наго, _فرزن, ljik,
   {{0xeab680ab,0x8c1b0039,0x7c2e12b8,0x69d99ab8}},	//   _জন্ম, _פולי, _imbr, bewe,
   {{0x91e3bd2f,0x44f49317,0x2d9d8b99,0x66043d30}},	//   _посе, дпис, _cewe_, njik,
   {{0x2ba683bb,0x63a1811f,0x81e500ab,0x7e7e28ff}},	//   jící_, faln, নাম_, _lupp,
   {{0xb05b0364,0x2281808b,0xb5fb00ff,0x2ba681d0}},	//   ttäm, _bók_, _nhán, dící_,
   {{0x81df80c8,0x316036cb,0xe1d9035f,0xeee4803d}},	//   তার_, _aziz_, одні_, _تغذی,
   {{0xddc88267,0x250b804e,0xa194102a,0x752400ee}},	//   _hudž, _گرمی_, наюч, kziz,
   {{0xd6258013,0xb05b3d31,0xf1a40084,0x3f9e80f1}},	//   _تعلي, stäm, эрэн, _ketu_,
   {{0x7a360a21,0x36d51541,0x7afc9614,0x63a1bd32}},	//   všte, могр, ärts, caln,
   {{0x3f9ebd33,0x7bdabd34,0xddc88267,0x628aa205}},	//   _metu_, metu, _mudž, _utfo,
   {{0x7bdabd35,0x3f9e9a7d,0x660400f1,0xe8d901bc}},	//   letu, _letu_, gjik, _afụ_,
   {{0x69d9bd36,0xb05b1c2f,0xb5fb0f35,0x65600a2a}},	// [2770] vewe, ntäk, _fhán, _ùmhl,
   {{0x7bdabd37,0x69d983f7,0x705500d7,0xf7788372}},	//   netu, wewe, _زنجا, _daħk_,
   {{0x442e8390,0x34d9800d,0xd7f8801c,0x6b8501ec}},	//   _mmf_, _भन्द, _chăm_, rchg,
   {{0x7a361601,0x7bda9b23,0x63a186e4,0xe8d92bd6}},	//   pšte, hetu, zaln, _efụ_,
   {{0xddc8bd38,0x37e588ed,0x81df80ab,0x7e7e01e8}},	//   _budž, долг, তাল_, _zupp,
   {{0xacfa0039,0x78ad8390,0x69d9bd39,0x2d9d867f}},	//   _והשכ, šavo, sewe, _sewe_,
   {{0x63a18db7,0x7bdabd3a,0xb05b0009,0x69d985ee}},	//   valn, detu, ttäj, pewe,
   {{0x601000f2,0x44333d3b,0x26c78796,0x63a18035}},	//   _hämt, lix_, rtno_, waln,
   {{0x26c78353,0x7e6993c2,0x9f5e8216,0x78600338}},	//   stno_, rmep, _votá_, höva,
   {{0x2d9d822e,0x7bdabd3c,0x60100106,0x7e6481b9}},	//   _wewe_, getu, _jämt, ċipa,
   {{0x387f838e,0x569484ae,0xfbcf1a4d,0x04ef8264}},	//   _huur_, _захт, स्यम, য়নের_,
   {{0x63a1bd3d,0x3f9e8010,0xdcf98fd3,0xb5fb128a}},	//   saln, _zetu_, _وفات_, _shán,
   {{0x7e7e0213,0x63a18f28,0x3f9e822e,0x6443003a}},	//   _supp, paln, _yetu_, čnij,
   {{0x2281807b,0x387f837a,0x7e7e3d3e,0x2bcf0b84}},	//   _tók_, _muur_, _pupp, स्मा,
   {{0x59c6035a,0x8c428279,0x44333d3f,0x41c60035}},	//   _वापर, _шеше, dix_, _वापस,
   {{0x25bfbd40,0x4433023e,0x2b0a801b,0x7524011b}},	//   ngul_, eix_, ाहरु_, tziz,
   {{0xb5fb0104,0xdca330fe,0x64a3176e,0x387fb6f5}},	// [2780] _thán, кати, ката, _nuur_,
   {{0x661d15f8,0x68e43d41,0x442100dd,0x7e7e3d42}},	//   _elsk, _isid, ghh_, _tupp,
   {{0x2bcf8f21,0x78a98698,0x78ad8301,0x9f458168}},	//   त्या, _avev, šavl, _dalë_,
   {{0x4421368b,0xd378812b,0x81e50264,0x387f91b8}},	//   ahh_, meće_, নাথ_, _buur_,
   {{0xd37890d3,0x7bda804f,0x9f458168,0x02da890f}},	//   leće_, yetu, _falë_, _बन्न,
   {{0x387fbd43,0xd7f8801c,0xd0108c3b,0x2bcfbcab}},	//   _duur_, _thăm_, طلب_, त्मा,
   {{0x7bdabd44,0xa3e7150e,0xd3788904,0x6a8307b6}},	//   vetu, _मोट_, neće_, _алса,
   {{0x78a9003b,0x973c803a,0x3f9e822e,0x25bf9295}},	//   ševi, _neće, _wetu_, ggul_,
   {{0x7bdabd45,0xe3ce8028,0x47c684ae,0x60101a57}},	//   tetu, _dựng_, _обав, _jäms,
   {{0x69c43d46,0xf0638084,0xa3de0054,0x25bf8493}},	//   _acie, _акуп, ढ़ि_, agul_,
   {{0x0bb70051,0xd378a43e,0x22590198,0x387f890d}},	//   ולים_, jeće_, зины_, _zuur_,
   {{0xd378803a,0x7bdabd47,0x442e9849,0xdd90880b}},	//   deće_, setu, _wmf_, _صوت_,
   {{0x200cbd48,0xb4bd02f1,0xa3de0105,0xf1bf0144}},	//   _kodi_, _इमे_, ढ़ा_, rgá_,
   {{0x200c86c0,0x6562b29f,0x44332f5f,0xb8f7170c}},	//   _jodi_, _izoh, xix_, _सह_,
   {{0x200cbd49,0x45d50468,0xe6dca39d,0x76878214}},	//   _modi_, новс, _मनोज, _kıya,
   {{0x200cbd4a,0x59c605e8,0x645a831d,0xf1d0001c}},	//   _lodi_, _वायर, llti, _hạng_,
   {{0x69dd3d4b,0x44333d4c,0x443e81e4,0x2d580b88}},	// [2790] mese, tix_, ont_, дить_,
   {{0x443ea248,0x69dd3d4d,0x200c8114,0xc86700f7}},	//   nnt_, lese, _nodi_, _تطبي,
   {{0x443ea0ee,0x44333d4e,0xf1d00028,0x387f8074}},	//   int_, rix_, _mạng_, _suur_,
   {{0x443e82af,0x201ea6e8,0x44210b17,0x32193d4f}},	//   hnt_, _alti_, shh_, nksy_,
   {{0x629c08d9,0x200cbd50,0x78bd15a0,0x7a36131b}},	//   _ewro, _bodi_, nusv, nšta,
   {{0xb907901b,0x85740d13,0x649a0051,0x7642ae5d}},	//   _बन_, _шлях, _מישה, _ajoy,
   {{0x63a53d51,0x69dd3d52,0x7ac411d5,0x2aa81539}},	//   mahn, kese, _исте, _отто_,
   {{0x443ebd53,0xceb4294d,0x63a51067,0x261c00f7}},	//   ent_, דיק_, lahn, _líon_,
   {{0x2bcf28d7,0x9f45826f,0x61fbbd54,0x2ca90ce9}},	//   स्था, _malé_, _inul, nsad_,
   {{0xd3788024,0x63a53d55,0x69c43d56,0x443ebd57}},	//   zeće_, nahn, _scie, gnt_,
   {{0xf1d0001c,0x61fbbd58,0x69dd1267,0x61e9bd59}},	//   _dạng_, _knul, fese, _kael,
   {{0x2bcf0d86,0x443ebd5a,0x69dd3d5b,0x200cb583}},	//   स्ता, ant_, gese, _zodi_,
   {{0x973c8052,0x61e9822e,0xa1550698,0x63a509ca}},	//   _veće, _mael, върш, kahn,
   {{0xfaa59fe4,0xdb1c0013,0x63a50be6,0x61e9bd5c}},	//   _зако, _scrí, jahn, _lael,
   {{0x63a53d5d,0x8c1a8039,0x69dd3d5e,0xd3789487}},	//   dahn, _מוסי, bese, teće_,
   {{0x69dd3d5f,0x20183d60,0x61e9bd61,0x9f45bd62}},	//   cese, skri_, _nael, _valè_,
   {{0x2edc800d,0xd378812b,0x15f28105,0x63a53d63}},	// [27a0] _मन्त, reće_, _अफसर_, fahn,
   {{0x61fbbd64,0x6fd387d9,0x63a53d65,0x7bc1bd66}},	//   _anul, nıcı, gahn, nglu,
   {{0x3f983d67,0x23c6024c,0x2bc60744,0xa79b007c}},	//   mbru_, र्गद, र्गा, _משיח,
   {{0x6455106d,0x2bcf824c,0xdb0181ac,0xfbcf8a27}},	//   _ekzi, त्ता, galé, त्तम,
   {{0x443ebd68,0x63a53d69,0x6d5982e9,0x6b8081bc}},	//   ynt_, bahn, _nywa, ịgid,
   {{0x69dd3d6a,0xb05b0364,0x9f34b941,0x7bc180ce}},	//   zese, ttäi, келі, jglu,
   {{0x8c430765,0x69dd3d6b,0xd6d78150,0x765bbd6c}},	//   _сере, yese, еты_, fluy,
   {{0x61e9803c,0x2bc28006,0xa3d2bd6d,0x443ebd6e}},	//   _gael, _शाहा, ह्न_, wnt_,
   {{0x59a70063,0x69dd3d6f,0x290280f1,0x2bc70cf0}},	//   _ख़बर, vese, _çka_, _लामा,
   {{0x320dbd70,0x69dd3d71,0xe8d78039,0x443ebd72}},	//   _zoey_, wese, _אומר_, unt_,
   {{0x69dd3d73,0xa19501bb,0x600f83ba,0x443eb480}},	//   tese, канч, _tømr, rnt_,
   {{0xf2d30158,0x765b85b4,0x3a200028,0x2bc70076}},	//   נער_, cluy, _clip_, _लाभा,
   {{0x63a50d92,0x6e243d74,0x09e300ab,0x7bde3d75}},	//   yahn, dhib, যালা, kepu,
   {{0xb05b0009,0x6010016d,0x69dd3d76,0xb803b918}},	//   htäv, _sämr, sese, लायम_,
   {{0x387a026c,0xc22183a4,0x63a5011a,0x69dd3d77}},	//   _dipr_, _मतलब_, vahn, pese,
   {{0x6e243d78,0x63a5010b,0x7a363d79,0x09d580ab}},	//   ghib, wahn, pšta, _সোনা,
   {{0xd90495e4,0xa5bb0118,0xb87b01fa,0x7e6d3d7a}},	// [27b0] _ای_, _alóc, rvís, rmap,
   {{0x7e6d010c,0x2bd80035,0x2ca93212,0xf8bf0144}},	//   smap, ड़गा, rsad_, mué_,
   {{0xa8580051,0x63a53d7b,0x2ca93d7c,0x61e9bd7d}},	//   _איזה_, rahn, ssad_, _pael,
   {{0x6e243d7e,0x63a50d92,0x92b401a8,0x798d0197}},	//   chib, sahn, احلا, _jfaw,
   {{0x91bf81bc,0x2604815c,0x60103d7f,0x9f5a02d6}},	//   _ahụ_, वानी_, _kämp, _anpè_,
   {{0x7bde0012,0xec350158,0xdb01a8d5,0xe05780d5}},	//   cepu, _יאָר_, salé, ریات_,
   {{0xf4c280c8,0x765b9238,0x61fb85ee,0x6d598123}},	//   ্টোব, tluy, _tnul, _sywa,
   {{0xe8d9001c,0x60103d80,0x660f3d81,0x6288002a}},	//   _ngữ_, _lämp, _jock, _édoa,
   {{0x6fd381cc,0xe1ff0035,0x9f5a0176,0x5a4493bf}},	//   tıcı, lmów_, _enpè_, _сэра,
   {{0x2a6902d5,0x660f3d82,0x249680d7,0x6e2402d4}},	//   _ahab_, _lock, کنید_, zhib,
   {{0x23298c24,0xab2990f8,0x7bc1bd83,0x6fd3899b}},	//   фони_, фона_, rglu, rıcı,
   {{0x6595a23c,0x7aea006a,0x8d878081,0x2a690362}},	//   _раду, æfti, _чужд, _chab_,
   {{0xf8bf3d84,0x261c01a8,0x2a6901b4,0xbcfb0061}},	//   gué_, _díol_, _dhab_, _szén,
   {{0x2cbf8079,0x6eca829a,0x00000000,0x00000000}},	//   muud_, _səbi, --, --,
   {{0x07a33d85,0x8fa31597,0x6e243d86,0x317fbd87}},	//   расн, расе, thib, _oguz_,
   {{0x63a3bd88,0x68e2831d,0x7bd501ec,0x661bbd89}},	//   _henn, ywod, _abzu, nkuk,
   {{0x6441bd8a,0x6283bd8b,0x7bde3d8c,0x69d63d8d}},	// [27c0] onli, _huno, tepu, _ibye,
   {{0x6283bd8e,0xd3788289,0x6441bd8f,0xe29a0cf9}},	//   _kuno, leća_, nnli, даж_,
   {{0x81e50a49,0x260480d4,0x63a3bd90,0xb05b0364}},	//   নার_, वामी_, _menn, ttäv,
   {{0x63a3bd91,0x6283bd92,0x7bde3d93,0xaca40133}},	//   _lenn, _muno, sepu, _amụr,
   {{0xe3a7850c,0x0cbc80ab,0x69c2bd94,0x92cd80ab}},	//   _پر_, _অন্ত, rgoe, রিয়_,
   {{0x09d600c8,0x63a3bd95,0x64418a0f,0xb05b0009}},	//   _তোমা, _nenn, jnli, stäv,
   {{0x29008012,0x973c80d2,0x69d63d96,0xc5eb80ab}},	//   ţia_, _beća, _obye, কানা_,
   {{0xd37882fd,0x2bcf815c,0x6441bd97,0x661b809c}},	//   jeća_, त्सा, enli, gkuk,
   {{0x81e88a49,0xd3788025,0x70dc035a,0x24860307}},	//   বাদ_, deća_, यबोल, íomh_,
   {{0x63a3bd98,0xe7c9809a,0x2bc6001b,0x6283bd99}},	//   _cenn, _रायप, र्चा, _buno,
   {{0x63a381a3,0x62838012,0x6d448038,0x0c7380f7}},	//   _denn, _cuno, _žiad, جديد,
   {{0x68f63d9a,0xf8bf00e7,0x6283a00f,0x2a69022c}},	//   _bryd, tué_, _duno, _qhab_,
   {{0xc05b035f,0x63a3bd9b,0xac0a8eef,0xe7c986f0}},	//   дів_, _fenn, _онда_, _रामप,
   {{0x63a3bd9c,0x660f3d9d,0xd9180009,0x69d602ec}},	//   _genn, _sock, тью_, _ebye,
   {{0x6e228259,0x63a88f09,0x2a690282,0x62838087}},	//   _klob, madn, _thab_, _guno,
   {{0x78ad8024,0x33778039,0xd5b80c0e,0x62810036}},	//   šavi, _בתוך_, ксу_, _éloi,
   {{0x2bcf835a,0xf8bf3d9e,0xfbcf81d0,0x63a382ec}},	// [27d0] त्वा, qué_, त्वम, _yenn,
   {{0x61ed3d9f,0x6e228722,0xddc43da0,0x27fe808e}},	//   _haal, _llob, rmiš, _nntn_,
   {{0xe7ec00d4,0x61ed3da1,0x660f011f,0xe29800e8}},	//   _छोटा_, _kaal, _tock, ває_,
   {{0x61ed0079,0x63a8bda2,0xc3338039,0x645e3da3}},	//   _jaal, hadn, סוף_, alpi,
   {{0x61ed3da4,0x25a93da5,0x394980a9,0x660982fd}},	//   _maal, maal_, ças_, vjek,
   {{0xd378803b,0xa3d2ad3b,0x973c9432,0xab9400e8}},	//   zeća_, _हॉल_, _seća, _вирі,
   {{0x63a3bda6,0x973c8699,0xadc40032,0x7a26008b}},	//   _renn, _peća, _ajẹs, _hóte,
   {{0x61ed3da7,0x25a92464,0xdb0380e7,0xa3cf06bf}},	//   _naal, naal_, _fenê, व्र_,
   {{0x69cc826f,0x7e7d3da8,0x661bbda9,0x62838cf4}},	//   ílež, _misp, rkuk, _suno,
   {{0x7bc53d55,0x6283bdaa,0x6609bdab,0x25a928ac}},	//   nghu, _puno, sjek, haal_,
   {{0x63a3bdac,0xc5d5835f,0x61ed3dad,0xbcfb0019}},	//   _venn, _біль, _baal, _szél,
   {{0xb5fb0013,0x61ed02a3,0x63a3949d,0x68f6031d}},	//   _fhái, _caal, _wenn, _pryd,
   {{0x61ed3dae,0x25a93daf,0x04c881a8,0x7a26016a}},	//   _daal, daal_, _لوني_, _nóte,
   {{0x6283bdb0,0x68f601b0,0xf77884b7,0x013680be}},	//   _tuno, _vryd, _taħt_, אָלט_,
   {{0x18671927,0x61ed3a38,0xa3aa000f,0xb05b0004}},	//   уари_, _faal, _गजब_, kräf,
   {{0x2bcf8894,0xc6928158,0x25a902a3,0xfbcfbdb1}},	//   त्रा, מאל_, gaal_, त्रम,
   {{0x05663db2,0xfbb783eb,0xdd8f0bbe,0x30be8264}},	// [27e0] уван, _आयाम, سول_, _ইন্স,
   {{0x69c9802e,0x309b0bea,0x389b010f,0x61ed0365}},	//   _acee, _רשימ, _ריינ, _zaal,
   {{0x3ce58063,0x81e880ab,0x61ed1a2b,0x25a93db3}},	//   _जैसे_, বাস_, _yaal, baal_,
   {{0x69c601da,0x61ed02a3,0xb05b02af,0x63a8807a}},	//   ngke, _xaal, stät, zadn,
   {{0x522d00be,0xc05a81e2,0x9f45bdb4,0xa3cf064a}},	//   וואַ, нік_, _dalí_, _वॉक_,
   {{0x6e2295d8,0xcaa600f7,0x3a26bdb5,0xdd3b03de}},	//   _slob, _مصري, shop_, _װעלכ,
   {{0x44443c37,0x63a8a1f6,0x68e9a4f4,0x94230b5b}},	//   mn_, vadn, _esed, _умре,
   {{0x443a3db6,0x44443db7,0x201c8904,0xa281809a}},	//   lip_, ln_, skvi_, łość_,
   {{0x44443db8,0x61ed0079,0x2ba80651,0x3d0e8074}},	//   on_, _raal, गरपा, िहें_,
   {{0x44443db9,0x443a3dba,0x61ed3dbb,0x60c2bdbc}},	//   nn_, nip_, _saal, muom,
   {{0x44443dbd,0x25a902a3,0x26048aed,0x61ed3dbe}},	//   in_, yaal_, वादी_, _paal,
   {{0xc333078d,0x6eca8201,0xb5fb0013,0x63a8bdbf}},	//   מות_, _qəbu, _thái, sadn,
   {{0x7e7d09ba,0x443a3dc0,0xdddb880a,0x61ed3dc1}},	//   _risp, kip_, lmuş, _vaal,
   {{0x4394aee8,0x44443dc2,0x443a06c0,0xf1bf0013}},	//   _такс, jn_, jip_, chán_,
   {{0x25a928ac,0x61ed0c1f,0x7c3abdc3,0x5f941510}},	//   taal_, _taal, mitr, сист,
   {{0x5eb980ab,0x92b392c8,0x6eca8085,0x387ebdc4}},	//   _আহমে, _احوا, _həbs, _litr_,
   {{0x61e2bdc5,0x25a90c11,0x7e7d0029,0x7a26008b}},	// [27f0] deol, raal_, _visp, _fótb,
   {{0x7c3aabf7,0xddc98214,0x443a3dc6,0x25a68114}},	//   nitr, kleş, gip_, _leol_,
   {{0x45d52b57,0xb05b1aff,0x25a91ae1,0x78bc80eb}},	//   _конс, träf, paal_, _ārva,
   {{0x7c3a811a,0x973c9123,0x3e410110,0x09e300ab}},	//   hitr, _pećn, kėti_, যাকা,
   {{0x44443dc7,0x9f4781d0,0x26d10cdb,0xe94580d7}},	//   bn_, rdní_, ltzo_, جرای,
   {{0x660d2e5c,0x3e4101e2,0xb5fb3dc8,0x25a9807a}},	//   ljak, dėti_, _cháv, _žal_,
   {{0xdb03bdc9,0x7c3abdca,0xdb01bdcb,0x26d10cdb}},	//   _genè, ditr, talí, ntzo_,
   {{0xed59b470,0x645704c3,0x25a68c5e,0xc3320039}},	//   кой_, loxi, _ceol_, _וול_,
   {{0x0c258ab2,0x387ebdcc,0x68e9bdcd,0xac858073}},	//   имин, _fitr_, _used, јгол,
   {{0xdb01bdce,0x2cadbdcf,0x22490458,0x660d156e}},	//   salí, rsed_, _ajak_, hjak,
   {{0x7f849301,0x81e88a49,0x2a6d9d3e,0x69cc800d}},	//   _المن, বার_, _kheb_, _हामी,
   {{0xd5758e02,0x26c33d6c,0xc86904de,0x20010122}},	//   _куль, dujo_, _חן_, _anhi_,
   {{0xeb8ea489,0x444402c1,0x62873dd0,0x443a0214}},	//   _ми_, yn_, _lujo, yip_,
   {{0x7c288014,0x7c3abdd1,0x63a7001b,0xa06a01e2}},	//   chdr, citr, _nejn, тага_,
   {{0x44440b40,0x81ab80ab,0x28b20074,0xcc3a80be}},	//   vn_, _খান_, _जिकि, _בעסט,
   {{0x44443dd2,0xe8fa0b30,0x644f80e7,0x64453dd3}},	//   wn_, _али_, écif, enhi,

   {{0x628702be,0x443a3dd4,0x7d098118,0xddc98214}},	// [2800] _aujo, tip_, nxes, zleş,
   {{0x44443dd5,0x6457002a,0x26c30e1b,0xdddb8380}},	//   un_, goxi, bujo_, ymuş,
   {{0x44443dd6,0x63a701c0,0x67bb0039,0x395f80e4}},	//   rn_, _dejn, _במיק, _ayus_,
   {{0xb05b034a,0xe7d201ab,0x7d1b8365,0x2efa2db0}},	//   träg, द्रप, kyus, _irpf_,
   {{0x260481c4,0x61e2bdd7,0x4444301d,0xae0982f1}},	//   वासी_, reol, pn_, वानन_,
   {{0x443a00f1,0x2056bdd8,0x25a680f7,0x64a31988}},	//   qip_, штер, _seol_, _фара,
   {{0x2120935a,0x60c2827e,0x973c812b,0x6e29bdd9}},	//   ših_, suom, _većo, fheb,
   {{0xdb03ab49,0xfe6f80a0,0xddc98214,0xdddba353}},	//   _gené, ودي_, rleş, rmuş,
   {{0x394d0063,0x87da84c0,0x9c469016,0x7c28bdda}},	//   żesz_, _لباس_, ихол, thdr,
   {{0xbcfb0019,0x7ed680e8,0xdb038061,0x6280bddb}},	//   _szék, _відч, _zené, _himo,
   {{0x752d01dc,0x6280bddc,0x233881e2,0x6bd8803d}},	//   zzaz, _kimo, упны_, نوکس_,
   {{0xdb0384c3,0xdd8f8019,0x7c3a8084,0x6cd68019}},	//   _xené, _قوم_, sitr, _نقصا,
   {{0x04948624,0x7c948013,0x6280a1f8,0x6fcd83eb}},	//   _التح, _التص, _mimo, _सामू,
   {{0x251b8e82,0xd83b0087,0x798403f7,0x04dbb7b6}},	//   _בודא, тэм_, _egiw, _סקול,
   {{0x6f1c031d,0xbe880860,0x63a7007a,0x6602bddd}},	//   gyrc, исте_, _rejn, _knok,
   {{0x4b7b812a,0x30a723e1,0x628084a7,0x6d5c8457}},	//   _באוו, _кров, _nimo, ğraf,
   {{0xb05b016d,0x9f45826f,0x786d841c,0x629abdde}},	// [2810] träd, _malá_, lúve, lpto,
   {{0x6e29bddf,0x6280bde0,0x62873de1,0x224680e1}},	//   zheb, _aimo, _pujo, enok_,
   {{0x2d8280e1,0x19b99539,0x2bd89869,0xd8488133}},	//   ľkej_, гуль_, ब्या, kọb_,
   {{0x62870279,0x2a6d8282,0x645c03ec,0x6457002a}},	//   _vujo, _qheb_, _ekri, soxi,
   {{0x6280bde2,0x26dea769,0xb5fb01a8,0xe8038072}},	//   _dimo, _apto_, _dhát, लाला_,
   {{0x09e300ab,0x7a263de3,0x6602b8ed,0x1d1601c6}},	//   যাটা, _móta, _anok, _הקשר_,
   {{0xdb0386a5,0x2a7f8748,0xdb018c83,0x316981d6}},	//   _tené, _tiub_, kalá, ťaz_,
   {{0xb8cd80c8,0xf2d204de,0x62809fb0,0x26dea62c}},	//   _কম_, _מעל_, _gimo, _dpto_,
   {{0x6e29bde4,0xbc198048,0x7a2601a8,0x2bc284c5}},	//   rheb, гіні_, _nóta, _शाखा,
   {{0x40849cf2,0x98148077,0x9b440117,0x68fb811e}},	//   _футб, _وبلا, _انہو, _irud,
   {{0x44213de5,0xdce78182,0x682b0201,0x68ed3de6}},	//   ikh_, ımız, _müdd, _asad,
   {{0xdb018019,0x6eca8085,0xf8bf023e,0xa5bb008b}},	//   galá, _təbr, fré_, _blóm,
   {{0x2604bde7,0x291dbde8,0xc9560009,0x8505803d}},	//   वारी_, nywa_, стны, _دوشن,
   {{0x765d0e87,0x2cbfb745,0x3cfe01d0,0xc2c880d7}},	//   _aksy, mrud_, _čtv_, دبیل_,
   {{0xdb0184be,0x66f98107,0xd62a260c,0xf99f01e8}},	//   balá, ्मिक_, гове_, bbè_,
   {{0x645c0bbd,0xf8bf003e,0x0d861c0b,0x442102a3}},	//   _skri, bré_, слан, ekh_,
   {{0x61e63de9,0xcc888104,0x44383dea,0x6280bdeb}},	// [2820] mekl, _lớn_, _pmr_, _rimo,
   {{0x69db85a4,0x44278890,0x61e63dec,0x4adb8fb8}},	//   _abue, _jln_, lekl, _बहाव,
   {{0x4427bded,0xfc3f07e2,0x6d4f3db4,0x25adbdee}},	//   _mln_, _avís_, _exca, kael_,
   {{0x68fb84fe,0x80cb00c8,0x61e63def,0xd2598d8e}},	//   _brud, িবর্, nekl, аці_,
   {{0x25a00393,0x6280a755,0x25ad8114,0xddcd1c08}},	//   mbil_, _vimo, dael_, llaş,
   {{0x645c3df0,0x25a03df1,0xe447bdf2,0x44383df3}},	//   _ukri, lbil_, _رض_, _umr_,
   {{0x6280bdf4,0xddcd0059,0x61e60214,0x09b200ab}},	//   _timo, nlaş, kekl, য়্যা,
   {{0x61e6111b,0x7e64020d,0x25a004e1,0xa5bb026b}},	//   jekl, nlip, nbil_, _alój,
   {{0xa9268009,0x4427a84c,0x61e63df5,0x998d81a1}},	//   _удал, _bln_, dekl, _umeš_,
   {{0xddcd0214,0xf8bf00e7,0xb34682df,0xe8248061}},	//   klaş, vré_, jeçõ, _بذری,
   {{0xdb01bdf6,0x5c5b00be,0x7a263df7,0x2bf701c6}},	//   talá, רדיק, _sóta, זמין_,
   {{0xad9b0073,0x5d868013,0x2604816f,0x5b7b03c8}},	//   _anún, _الإل, वाळी_, טריא,
   {{0xfdf78039,0x44213df8,0x661dbd02,0xf8bf3df9}},	//   _לצאת_, ykh_, öske, uré_,
   {{0xa2c08ec5,0xf8bf3dfa,0xb9218032,0x96eb0b79}},	//   _विप्, rré_, _aisọ_, льба_,
   {{0x443ebdfb,0x6fda800f,0x501b8039,0x543b80be}},	//   mit_, प्यू, נולו, _געגא,
   {{0x645abdfc,0xe8d90028,0x7bdc3dfd,0x61e63dfe}},	//   loti, _ngủ_, _abru, cekl,
   {{0x68ed0510,0x2bcf89a9,0x973c8b67,0x3a2902c4}},	// [2830] _usad, त्का, _bećk, _ilap_,
   {{0x44273dff,0x645abe00,0x3ce0800f,0x97a70087}},	//   ón_, noti, _कहने_, _урил,
   {{0x6448be01,0x3a293e02,0xfa8980ff,0x68fb8115}},	//   indi, _klap_, _lẫn_, _srud,
   {{0x443ebe03,0xc1b70c28,0x1df90009,0x7e643e04}},	//   hit_, _अयोग, _темы_, clip,
   {{0x443eb39e,0x645abe05,0x7a36012b,0x65628db1}},	//   kit_, koti, ušti, _nyoh,
   {{0x62988b5d,0x443ebe06,0x63aa8125,0x645abe07}},	//   _otvo, jit_, _nefn, joti,
   {{0xa3be92ee,0x443ebe08,0x645abe09,0x6562be0a}},	//   ेलन_, dit_, doti, _ayoh,
   {{0x7a36003b,0xe619ad01,0x644898f2,0x68fbae02}},	//   pšti, рди_, endi, _trud,
   {{0x44278894,0x25adbe0b,0x6448be0c,0x64890b80}},	//   _pln_, rael_, fndi, _džig,
   {{0x443ebe0d,0xfa898104,0xddcd05c5,0x63aa831d}},	//   git_, _dẫn_, ylaş, _cefn,
   {{0xcb69be0e,0x63aa8355,0x27e7be0f,0xdb1c00f7}},	//   ране_, _defn, menn_, _scrú,
   {{0x69cb8397,0x27e7be10,0x60c615bd,0x64488010}},	//   ngge, lenn_, tukm, andi,
   {{0xe3ae8c8e,0x645abe11,0x61e63e12,0xa3aa27cf}},	//   _об_, boti, rekl, _गजल_,
   {{0x442cbe13,0x61e63e14,0x645abe15,0x27e7be16}},	//   chd_, sekl, coti, nenn_,
   {{0xa3d28063,0x26c7be17,0x224d81bf,0x61e63e18}},	//   _हॉट_, nuno_, _ojek_, pekl,
   {{0x22b580eb,0xddcd08c5,0x27e7be19,0x7649be1a}},	//   māk_, rlaş, henn_, nney,
   {{0x3ea0805c,0x22b580eb,0x7e6412b0,0x81d300ab}},	// [2840] ćiti_, lāk_, rlip, _হোক_,
   {{0x25a03e1b,0x27e78f7c,0xebe33e1c,0xddcd099b}},	//   sbil_, jenn_, моуп, plaş,
   {{0x27e786c4,0x6e2d179f,0xd24f004e,0x22b580eb}},	//   denn_, bhab, _سنی_, nāk_,
   {{0x6e2d3e1d,0x443ebe1e,0xe8fa999a,0xddcd002e}},	//   chab, zit_, иле_, rmaţ,
   {{0x3ead003b,0x644892fa,0x645abe1f,0x28f8be20}},	//   ćete_, yndi, yoti, сель_,
   {{0x443ebe21,0x6489017f,0x973c826c,0x224d80dd}},	//   xit_, _džid, _heći, _ejek_,
   {{0x645a8025,0xdcf60059,0x26c7be22,0xdb03b673}},	//   voti, mayı, guno_, _bení,
   {{0xdcf60182,0x443ebe23,0xdb0381d0,0x629e0a6f}},	//   layı, wit_, _cení, mppo,
   {{0x443ebe24,0x62988025,0x645abe25,0xdb03801b}},	//   tit_, _stvo, toti, _dení,
   {{0x186a8698,0xfa898028,0xd37882a5,0x47c39194}},	//   _тази_, _vẫn_, leći_, _обув,
   {{0x443e8e79,0x2bcf12e0,0x7e9180eb,0x1bfb00be}},	//   rit_, स्टा, _tāpa, בליב,
   {{0x2d9287d9,0x443ebe26,0xed5a9d5e,0xd37882a5}},	//   _üye_, sit_, _кое_, neći_,
   {{0x443eb942,0xda7b8051,0x9f5ebe27,0xb4e918b8}},	//   pit_, ינטר, _totó_, _मने_,
   {{0xe8d92bd6,0x76408110,0x22b580eb,0x443e8168}},	//   _ngụ_, limy, bāk_, qit_,
   {{0x261c0307,0x5694044f,0x60c2be28,0x69cb8bc5}},	//   _níos_, даст, hrom, ygge,
   {{0x2bdd0beb,0x60c2803e,0xd378805c,0x27e782d6}},	//   न्ना, krom, jeći_, zenn_,
   {{0xd378803a,0x98be002e,0x6e2d3e29,0x60c28bcf}},	// [2850] deći_, ătă_, rhab, jrom,
   {{0x60c2a876,0x6e2d2af0,0x26c7be2a,0x1c050105}},	//   drom, shab, yuno_, राइल_,
   {{0x2c000076,0xce5907b6,0x261c01a8,0x764981b4}},	//   राजू_, _ганц_, _cíos_, yney,
   {{0x26c78ca2,0x9f4c8980,0xcb138e82,0xa49b0580}},	//   vuno_, _cadí_, ולע_, _pròd,
   {{0x260809a3,0x8cc20996,0x22b580eb,0x22a78019}},	//   हारी_, _लियो, zāk_, zők_,
   {{0x442a01bc,0xf8078d0e,0xd3e300d5,0x261c03a8}},	//   _glb_, ючен, _تقسی, _fíos_,
   {{0xd00e80f7,0x224d813c,0xdb03801b,0xd378825b}},	//   الى_, _tjek_, _pení, beći_,
   {{0xdb08a5a8,0x0609b09a,0x3e61808b,0x44ed3e2b}},	//   gadí, сник_, jótt_, _kž_,
   {{0x27e7be2c,0x7649be2d,0xe4d680f7,0xdb03be2e}},	//   penn_, rney, كويت_, _vení,
   {{0x1fa78a08,0x22a78019,0x26c78ce9,0x870780f7}},	//   _фраг, tők_, puno_, _وبال,
   {{0xa3dd2714,0xdb039099,0x98b00067,0x2bdd0744}},	//   थ्य_, _tení, đača_, न्या,
   {{0x22b58341,0x2c6d0efc,0x26f98740,0x9f5e81e8}},	//   rāk_, _vždy_, ्मीर_, _totò_,
   {{0x48fe80ba,0x78720366,0x601d82d6,0x22b581a9}},	//   लियो_, hæve, _fèmt, sāk_,
   {{0xd378807d,0x3ce0809a,0x261c00f7,0xfe7981d0}},	//   zeći_, _कहते_, _níor_, lmů_,
   {{0x6441be2f,0x44ed0a56,0x973c8289,0x91cc801b}},	//   mili, _až_, _peći, _हालै,
   {{0x261c3dce,0xe1ff02ba,0xa2c0923a,0xddcd026c}},	//   _ríos_, llón_, _वित्, tmaš,
   {{0x973c803a,0x52db81ab,0x261c0013,0xd37882a5}},	// [2860] _veći, _बहुस, _síos_, veći_,
   {{0x44ed3e30,0x29003e31,0xb4633e32,0x6e243e33}},	//   _dž_, _iria_, екул, skib,
   {{0x61f63e34,0xd378805c,0x62978333,0xbcfb0061}},	//   _kayl, teći_, _éxod, _szét,
   {{0x7aba8039,0xcc88801c,0x6489298e,0xfe7981d0}},	//   מצעו, _sớm_, _džib, jmů_,
   {{0x6441be35,0x201a1ac1,0xd3788052,0x26d83e36}},	//   kili, _kopi_, reći_, ltro_,
   {{0xd37882a5,0x4425979d,0x6441804f,0xb05b01ec}},	//   seći_, jkl_, jili, hrän,
   {{0x6441be37,0xdb0885dc,0xd378811f,0x442580ee}},	//   dili, tadí, peći_, dkl_,
   {{0x60c2be38,0x682b1014,0x26c50024,0x29003e39}},	//   prom, _müda, šlog_, _oria_,
   {{0x6441be3a,0xdb08be3b,0x628e3e3c,0xbcfb3e3d}},	//   fili, radí, _hubo, _nyél,
   {{0x628e3818,0x26ca3e3e,0x3949802a,0x682f8821}},	//   _kubo, kubo_, úase_, _rødg,
   {{0x644f83d3,0x61f63e3f,0x46a3869b,0x28af000f}},	//   écia, _bayl, _захв, जीनि,
   {{0xb05b00f2,0x7ae101ec,0x645e3da2,0x628e19a2}},	//   grän, _älte, hopi, _mubo,
   {{0x628e3e40,0x21670554,0x2baf009a,0x2900385e}},	//   _lubo, ятог, टरमा, _cria_,
   {{0xb8f53e41,0x629c3e42,0x645e0369,0xe1ff0333}},	//   _हम_, _otro, jopi, clón_,
   {{0x629c827f,0xf1c6016f,0x628e1cd4,0xb05b3e43}},	//   írod, _वाचन, _nubo, brän,
   {{0x29003e44,0xade280d4,0x3e4581a9,0xee49827d}},	//   _fria_, _कॉमन_, bētu_, hẽn_,
   {{0x629c0df1,0x320902c1,0xbcfb0065,0x91bc0039}},	// [2870] _atro, _inay_, _azér, _המחי,
   {{0x628e32a0,0x44ed3e45,0x26ca00e4,0x682f8366}},	//   _bubo, _vž_, bubo_, _køde,
   {{0x41d1809a,0x26ca01e8,0x628e0c1d,0x682f854f}},	//   _हादस, cubo_, _cubo, _jøde,
   {{0x628e003a,0x682f813c,0x3a26820d,0x69cf01f6}},	//   _dubo, _møde, gkop_, ngce,
   {{0xa3be8663,0x44ed3e46,0xbcfb0019,0xd37880d2}},	//   ेला_, _už_, _ezér, meću_,
   {{0x44250355,0x23c303d3,0x9f478efc,0x7a3601ac}},	//   _ôl_, _déjà_, lené_, nštr,
   {{0xe81e9344,0x320902d0,0x6441938e,0x682f805f}},	//   _बकरा_, _onay_, vili, _rødd,
   {{0x64418355,0xc7448013,0xdb03be47,0x764d3e48}},	//   wili, عضوي, _nená, nnay,
   {{0x3d000e5b,0xdb01bb09,0x280881d0,0xdb073673}},	//   रिये_, mblé, átní_, _mejí,
   {{0x61f61b44,0x32093e49,0xe7b582e3,0x09c6016f}},	//   _sayl, _anay_, _آماد, वल्य,
   {{0x61f602bb,0xb05b1bd7,0x1b1f00ab,0x3a2dbe4a}},	//   _payl, trän, _যেতে_, _klep_,
   {{0x6441b1e3,0x2900016f,0x25740125,0xd37895db}},	//   sili, _pria_, _júlí_, jeću_,
   {{0x6441be4b,0x9f478038,0xd37881dd,0x645e0010}},	//   pili, dené_, deću_, yopi,
   {{0x3e458029,0xaac58996,0x26d80098,0x7e69829e}},	//   rētu_, _विपक, ttro_, llep,
   {{0x683000f2,0x2ba381a2,0x26d8002a,0x25b202c4}},	//   _rädd, _ख्या, utro_, tayl_,
   {{0x29000722,0x764d3e4c,0x628e3e4d,0x7bc301fa}},	//   _tria_, gnay, _rubo, ónun,
   {{0x629c3e4e,0x628e003b,0x22403e4f,0x2bd48105}},	// [2880] _stro, _subo, _imik_, _दामा,
   {{0xd7ca003d,0xf1bf0b4c,0x6d4480e1,0x764d01b4}},	//   _بوده_, nkán_, _žiak, anay,
   {{0x645e3e50,0x9f47803e,0x2bdd001b,0x63bc8ff4}},	//   ropi, bené_, न्धा, órni,
   {{0x7e69985c,0xfaf800eb,0x63ae3e51,0x63a90390}},	//   jlep, _šīs_, _webn, _đene,
   {{0x5fc985b3,0x2bc703db,0x249d81c0,0x08979a43}},	//   _राखल, _लाचा, _ntwm_, وضوع_,
   {{0x7e62be52,0x628e3a30,0x0ee20bb8,0x2bdd27ec}},	//   _skop, _tubo, _पहाड, न्दा,
   {{0x44443e53,0x61ebbe54,0x629c3e55,0x63833e56}},	//   mi_, begl, _utro, _агра,
   {{0x26c0be57,0x2487803c,0x64891487,0x7e69be58}},	//   čio_, _ainm_, _užic, glep,
   {{0xdb08862f,0x752402ec,0x01d7830f,0x83fc8654}},	//   dadá, nyiz, _توقع_, hođe,
   {{0x44443e59,0x83fc82fd,0x9f47827f,0xd3788289}},	//   ni_, kođe, zené_, zeću_,
   {{0xcc888142,0x44443e5a,0x764d02a3,0xd6cf806b}},	//   _mới_, ii_, ynay, _نقل_,
   {{0xc7b8803a,0x7e62be5b,0xb5fb0032,0xdb088061}},	//   _dođe_, _ukop, _akán, gadá,
   {{0x9f478a21,0x7e60be5c,0x69dd007b,0xd8488133}},	//   vené_, momp, rfse, họm_,
   {{0x61eb8063,0x7e608812,0x656f81ec,0x601d89c4}},	//   zegl, lomp, üche, _jèmp,
   {{0x5f9417f4,0x83fc803b,0x290d002e,0x2bf3816f}},	//   тист, gođe, ţea_, _असतं_,
   {{0x44443e5d,0x41e70d13,0x5c990a14,0x32090122}},	//   ei_, _ціка, зкая_, _unay_,
   {{0x44443e5e,0x78a2a8d2,0x5c750009,0xd37882a5}},	// [2890] fi_, jpov, елат, reću_,
   {{0x83fc8052,0x78a2803e,0x9f4c026f,0x6f030118}},	//   bođe, dpov, ždá_, _ánco,
   {{0xf1b9803a,0xb5fd84a8,0x64890110,0x9f479c32}},	//   _loše_, loše, _džia, pené_,
   {{0x44443e5f,0x6830016d,0xdb1c2d84,0x7d02be60}},	//   ai_, _väde, _acró, _oros,
   {{0x5d85306f,0xb5fd80ce,0x0ef7809a,0x798d0c53}},	//   _سلسل, noše, ंट्स_, _mgaw,
   {{0x61eb8353,0x160d016f,0x661d0901,0xd848819d}},	//   segl, हावर_, _hosk, bọm_,
   {{0x661d0364,0xa2c08b84,0x6445354a,0x7e69be61}},	//   _kosk, _विष्, mihi, tlep,
   {{0x7d02be62,0x64453e63,0x798d0c14,0x661d0009}},	//   _bros, lihi, _ngaw, _josk,
   {{0x661d3e64,0x7e69810b,0xb5fd8279,0xdfdb8098}},	//   _mosk, rlep, joše, _мъж_,
   {{0xa2c090c5,0xa2c4035a,0x7d02be65,0x64453e66}},	//   _विश्, ांच्, _dros, nihi,
   {{0x7d02b0a2,0xdb039d44,0xdb0894a8,0x7e69be67}},	//   _eros, _menç, tadá, plep,
   {{0x44443e68,0x83fc8025,0xb87b11b9,0x64453e69}},	//   zi_, vođe, ntíf, hihi,
   {{0xdb08be6a,0x660b8288,0xfce5835f,0x64453e6b}},	//   radá, _ingk, _чоло, kihi,
   {{0x26c78098,0x7af50019,0x6e298aa2,0x95cc8085}},	//   orno_, _oszt, lkeb, _çərç,
   {{0x44440743,0xdee30328,0xbcfb0019,0x2edd8ebf}},	//   vi_, лори, _szép, _महोत,
   {{0x444439c5,0x26128bb8,0x83fc805c,0x9f583e6c}},	//   wi_, थायी_, rođe, ndré_,
   {{0x61e43e6d,0x661d198a,0x660b8359,0x7af50019}},	// [28a0] _ibil, _dosk, _mngk, _aszt,
   {{0x44442cbe,0x799b8300,0x76443e6e,0x394d03a8}},	//   ui_, _afuw, siiy, úese_,
   {{0x4fd7093f,0xe7c983db,0x7fd70158,0x660b8e60}},	//   _אויב_, _राजप, _אויס_, _ongk,
   {{0xcc888142,0x3ce08006,0x09c700ab,0x6ad00035}},	//   _với_, _कहले_, ষ্ঠা, _हमीर,
   {{0x44440573,0x47b300c8,0x61e428e5,0x64453e6f}},	//   pi_, _জাতী, _mbil, bihi,
   {{0x660b9ade,0xcc888104,0x25dda296,0x44443e70}},	//   _angk, _tới_, क्सी_, qi_,
   {{0x61e40025,0x78a2807d,0x7e6080d7,0xdb0a806a}},	//   _obil, spov, tomp, _udfø,
   {{0x78a280c3,0x6fd2a776,0x7d090118,0x5fd28072}},	//   ppov, _सावं, _áesc, _सावल,
   {{0x5454bd23,0x02e0001b,0xfd1285ff,0x69c08609}},	//   квит, _नहुन, اجع_, _idme,
   {{0x660b8455,0xccf30039,0xf1b981a1,0x7d1d8106}},	//   _engk, רכז_, _voše_, ässa,
   {{0x200cbe71,0x6fd70074,0xdb0e1fd3,0xaa59168a}},	//   _indi_, _बाबू, _bebé, дину_,
   {{0x5ab7093f,0x7d02be72,0xfe7282e3,0x200c876d}},	//   עלכע_, _tros, _صدا_, _hndi_,
   {{0x442e8bc5,0x661d3e73,0x644502a3,0x64a38a4c}},	//   _tlf_, _rosk, yihi, _бача,
   {{0x61e43e74,0xb5fd8796,0xdb070061,0xdb038106}},	//   _ebil, roše, _lejá, _benä,
   {{0x661d1234,0xadf4823c,0xa3d9b9a1,0x201ebe75}},	//   _posk, _आसान_, _डॉट_, _moti_,
   {{0x27fa002a,0xa5bb0032,0x201ebe76,0x78ad0b5e}},	//   _eapn_, _alór, _loti_, _twav,
   {{0x64453e77,0x8bc71285,0xf1bf0c83,0xb05b0338}},	// [28b0] tihi, есед, nkám_, nräk,
   {{0x201eabc5,0x69c087fc,0x61e43e78,0xb4e107e6}},	//   _noti_, _adme, _zbil, _दही_,
   {{0x64453e79,0xdb03a035,0xb5fd8140,0xdb070061}},	//   rihi, _venç, nošc, _bejá,
   {{0x61fd2eba,0x61ef3e7a,0x200c9437,0xaca3019d}},	//   ndsl, necl, _andi_, _amục,
   {{0xd3668077,0x25a904a7,0x7e6d3e7b,0xa5bb3e7c}},	//   _چه_, mbal_, mlap, _flór,
   {{0xd3668077,0x7e6d3e7d,0xdb18802a,0x28980039}},	//   _نه_, llap, _adví, עדון_,
   {{0x6c540470,0xf456007c,0xe4543e7e,0x8f9c00be}},	//   _скру, _יישר_, _скры, ליגי,
   {{0x2499a755,0x60c481e2,0x200cbe7f,0x59d8864a}},	//   ísmo_, šima, _endi_, _डायर,
   {{0x320d8079,0x9f47be80,0x9f4a0722,0xdb0a83a8}},	//   _iney_, mení_, rebé_, _defí,
   {{0x9f47800d,0xb5fb3e81,0x6e29806f,0x61e400e5}},	//   lení_, _skál, skeb, _sbil,
   {{0x68300006,0x61fbbe82,0xbf15819f,0x6fdf00d4}},	//   _näda, _kaul, _جواب, _पॉइं,
   {{0x660b94ec,0xa696810f,0x201e80f1,0x61fbbe83}},	//   _ungk, _סכנה_, _zoti_, _jaul,
   {{0x25a93527,0x463a8158,0x29040376,0x91ba81c6}},	//   dbal_, _קענע, íma_, ומרי,
   {{0x61fbbe84,0x6a7888f1,0x69a23e85,0x25dd8519}},	//   _laul, mífe, _क्री, क्री_,
   {{0xf1b385fc,0x998f8110,0x61e43e86,0x6443be87}},	//   ुणान, nigų_, _tbil, _imni,
   {{0x61e40503,0x9f4783fb,0xe8d18424,0x7e6d1acd}},	//   _ubil, jení_, _समूच, glap,
   {{0x9f47803e,0x0d86174a,0x6a7888f1,0x44313e88}},	// [28c0] dení_, тлан, nífe, _blz_,
   {{0xe0b70f60,0x03a607b6,0x64890084,0x9f5a03ed}},	//   _שליט_, тижо, _džio, _japë_,
   {{0x2bd48076,0x61fbbe89,0xe9da9d1f,0x321f826b}},	//   _दासा, _baul, дке_, _bouy_,
   {{0x201e8205,0x98a69630,0x6489025b,0x831a80be}},	//   _soti_, виде, _užin, וועז,
   {{0x201ebe8a,0x61fb84b9,0xdb0a81df,0x83fc826c}},	//   _poti_, _daul, _refí, hođa,
   {{0x03a3035f,0xf1bf04e8,0x6b9c02df,0x61fb82f9}},	//   _виро, vkám_, _ufrg, _eaul,
   {{0x8c431fee,0x201eab31,0x04432312,0xddcd0087}},	//   _тере, _voti_, _терн, noaş,
   {{0x9f47800d,0x6443be8b,0x61fbbe8c,0x35f4a489}},	//   cení_, _amni, _gaul, упир,
   {{0x29048012,0x61ef0358,0x201e802e,0x9f49816b}},	//   _urma_, vecl, _toti_, čkám_,
   {{0xfa8a0028,0x200cbe8d,0x1e1f03db,0xa84a80b7}},	//   _mẫu_, _undi_, _यक्ष_, _غلام_,
   {{0x83fc812b,0x1db23e8e,0x0bb7025f,0x61fbab8c}},	//   gođa, जरात, כלים_, _yaul,
   {{0x27e985f5,0xf2d30158,0x61e29529,0x60dd0711}},	//   đane_, סער_, nfol, ttsm,
   {{0x9f45826f,0xcc8880ff,0x6a788118,0x2e37825f}},	//   _malý_, _bớt_, cífe, _בראש_,
   {{0x9f47800d,0x36d50328,0xdb05008b,0x69b480d4}},	//   zení_, логр, rahú, आरडी,
   {{0x25a93e8f,0xf1b9805c,0x442cbe90,0x69d382f1}},	//   tbal_, _loša_, mkd_, _डाली,
   {{0x2d8f006a,0x61e2be91,0x64438035,0xe654004a}},	//   øge_, jfol, _zmni, авсь,
   {{0x25a6040e,0x3ea9803a,0x23b6800f,0x9f47800d}},	// [28d0] ñola_, ćati_, _आजाद, vení_,
   {{0x61fba393,0x7e6d189e,0x25a93e92,0x57f5164c}},	//   _saul, slap, sbal_, _спот,
   {{0x61fbbe93,0x68e98098,0x61e2be94,0x9f4783f2}},	//   _paul, _sped, ffol, tení_,
   {{0x6448be95,0x6e36026f,0x61fb80dd,0xe1ff3e96}},	//   hidi, chyb, _qaul, ndó_,
   {{0xdca680f7,0x6e2d3e97,0xe0df3e98,0x660f0b80}},	//   _دى_, mkab, ntò_, _inck,
   {{0xb5fd80eb,0x628d00fc,0x6e2d3e99,0xf1b98115}},	//   doša, _liao, lkab, _doša_,
   {{0x61fbbe9a,0x6448be9b,0x81cb00ab,0x3669960f}},	//   _taul, didi, র্য_, нако_,
   {{0x83fc803a,0xc7b88024,0xc69400be,0x644380b9}},	//   vođa, _vođa_, סאפ_, _smni,
   {{0xf1b98e9f,0x7aea8706,0x7a2601fa,0x4bd981e2}},	//   _goša_, _apft, _mótt, ньня_,
   {{0x6448be9c,0xe5768048,0x62953e9d,0x628d0362}},	//   gidi, ызы_, _kuzo, _aiao,
   {{0x2bd49d2a,0x6e2d3e9e,0xcc888129,0xeab9814c}},	//   _दारा, kkab, _rớt_, эйн_,
   {{0xe9df00f7,0x83fc81dd,0x628d3e9f,0x82361190}},	//   siún_, rođa, _ciao, اردا,
   {{0x6448bea0,0x7d0902a5,0x628d237d,0xfd108154}},	//   bidi, _šesn, _diao, _وجه_,
   {{0xddc4001b,0x9f430009,0xdb03a8f8,0x7a263ea1}},	//   dliš, kejä_, _menú, _rótu,
   {{0x75298019,0xae179664,0xd5b786b7,0x3ebe007b}},	//   lyez, थापन_, _इजाज, étt_,
   {{0x661b8867,0x6e2d043b,0x81cb00ab,0x67210589}},	//   njuk, gkab, র্ব_, älja,
   {{0x7529bea2,0x62950102,0x753bbea3,0x7a26008b}},	// [28e0] nyez, _auzo, nzuz, _dótt,
   {{0x63b50390,0x661b98c2,0x26d10234,0xbc6a0bbe}},	//   _cezn, hjuk, buzo_, رمان_,
   {{0x6e460878,0x49ca9508,0xd62a3ea4,0x61e2804a}},	//   _бенз, елен_, _зоне_, tfol,
   {{0x6448bea5,0x78a42e67,0xb05b0106,0x7afcbea6}},	//   zidi, _ktiv, tsäg, ærti,
   {{0x28f88e86,0xad9b01ac,0x6448bea7,0xdb01816b}},	//   тель_, _vnút, yidi, valý,
   {{0x7d043ea8,0xdb0387e0,0xb8dc8074,0xb5fd80eb}},	//   mvis, _denú, _आब_, voša,
   {{0x62953ea9,0xdb18816b,0xa3d7897d,0xddc401a9}},	//   _guzo, _odvá, िलन_, rniņ,
   {{0xb5fd8029,0xceb30039,0x6448831d,0x69d609c1}},	//   toša, זיה_, widi, _भाषी,
   {{0x2fd68013,0x81cb00c8,0x7d040082,0x3ce03eaa}},	//   _متاح, র্ড_, nvis, ntiv_,
   {{0x69c4011e,0xb5fd80eb,0x2a66809c,0x628281b4}},	//   _adie, roša, loob_, lmoo,
   {{0x78a40073,0xd7938013,0x2f56a8e6,0xb5fd812b}},	//   _ativ, _المخ, _стас, mošn,
   {{0xa2cc0fea,0xb5fdbeab,0x6448beac,0x2a66856c}},	//   _हिन्, lošn, sidi, noob_,
   {{0xa2c08744,0x9f47803e,0x6448bead,0xe1ff3eae}},	//   _विक्, mená_, pidi, rdó_,
   {{0x9f47803e,0x62828282,0x69c43eaf,0xb5fd826c}},	//   lená_, hmoo, _edie, nošn,
   {{0xd904850c,0xf8d1beb0,0x6e22beb1,0xae098023}},	//   _کی_, _सम्प, _koob, वाचन_,
   {{0x63b53eb2,0xadf98bb8,0x69c03eb3,0xddc40088}},	//   _sezn, ्ययन_, ómet, tliš,
   {{0x6e228952,0xdb0e05e4,0xd3a702df,0xbcfb08f9}},	// [28f0] _moob, _debí, греп, _nyét,
   {{0x68ed3eb4,0xad9b0e67,0x6e2d013c,0x224b3eb5}},	//   _ipad, _saúd, skab, lick_,
   {{0x81cb00ab,0x7d043eb6,0xe29800e8,0x09bc80ab}},	//   র্ণ_, avis, гає_, _ইউজা,
   {{0x98a99487,0x6e22beb7,0xdb07016d,0xa4d51138}},	//   šač_, _noob, _rejä, _комі,
   {{0x212b3eb8,0x90e48154,0x9f478a21,0x3ce00087}},	//   nych_, مسون, dená_, ctiv_,
   {{0x63ba8a20,0x43943eb9,0x2ca9003d,0x41268009}},	//   jatn, _гарс, mpad_, рошо_,
   {{0x6e22beba,0x59c5016f,0xc7d8007c,0x2ca93ebb}},	//   _boob, वणार, אווי_, lpad_,
   {{0x6e22bebc,0x06099e4e,0x212b01ac,0x442304e4}},	//   _coob, тник_, kych_, _hoj_,
   {{0x4423146a,0x680b8029,0x63ba9d0c,0xe61694ef}},	//   _koj_, _pēdē, fatn, рды_,
   {{0x4423003a,0x3ce5901b,0x212b3ebd,0xa0c480f7}},	//   _joj_, _कहीं_, dych_, _ديكو,
   {{0x442324ef,0x68ed3ebe,0x6e22bebf,0x9f45bec0}},	//   _moj_, _apad, _foob, _való_,
   {{0x442301e9,0x6e2282a3,0xa2d62774,0xfe9a8039}},	//   _loj_, _goob, मंत्, _סינמ,
   {{0xd1760791,0x61e9bec1,0x63ba8057,0x6721016d}},	//   рыны, _mbel, batn, äljn,
   {{0x80cd89a3,0x7d0412bb,0x98a0803a,0x442301e9}},	//   _सिने, vvis, šić_, _noj_,
   {{0x61e9bec2,0xc4478117,0x6fd703eb,0xdfcf00f7}},	//   _obel, _لیکن_, _बारू, ظيف_,
   {{0x7c2387a3,0x7d043ec3,0x3ce004b7,0x6a761e31}},	//   _honr, tvis, ttiv_, máfo,
   {{0x212b0063,0x1c460110,0xa4463ec4,0x656f0114}},	// [2900] cych_, анам, анад, _cych,
   {{0x629e9313,0x61e9bec5,0x69db85b4,0x442301e9}},	//   _époc, _abel, _acue, _coj_,
   {{0xb87b3ec6,0x68fbbec7,0x25adbec8,0x2bdda594}},	//   stíc, _asud, kbel_, _माना,
   {{0x27ed003a,0x09e69d1d,0x2cbf9922,0xcc888028}},	//   đene_, родн, ksud_, _lớp_,
   {{0x63ba810b,0x6282bec9,0x9f47826f,0x6f088a21}},	//   yatn, rmoo, vená_, _srdc,
   {{0x61e9beca,0x6e22becb,0x3ec68009,0x44230147}},	//   _ebel, _soob, асиб, _goj_,
   {{0x63ba803b,0x212b009a,0x9f58009f,0xb87b05e4}},	//   vatn, zych_, ndrà_, ntía,
   {{0x27e98025,0x2c0a035a,0x63ba89ca,0x2fc5802a}},	//   đana_, _होतं_, watn, _edlg_,
   {{0x63ba89a4,0x80a6826a,0x15e2816f,0x27e08041}},	//   tatn, _ضمان, क्षर_, ƙin_,
   {{0x7c23becc,0x61ff3ecd,0xaca401bc,0x3cf90816}},	//   _conr, _saql, _amịr, _उनसे_,
   {{0x212b0d38,0x25ad923f,0x64890699,0xdfcf81a8}},	//   wych_, bbel_, _džih, _زين_,
   {{0x2ca93ece,0xfce68171,0xade2b2df,0x212b0dee}},	//   ypad_, _водо, क्शन_, tych_,
   {{0x224b3ecf,0x63babed0,0xf99f0722,0x984b0081}},	//   rick_, patn, rcè_, вява_,
   {{0x212b3ebd,0x656f000d,0x26c50289,0xf1a70697}},	//   rych_, _rych, šlom_, _क्रन,
   {{0x442301c5,0xf8bf1b2c,0xc058035f,0xe29780a9}},	//   _roj_, ssé_, рія_, _кај_,
   {{0x44230282,0x7a360084,0x2ca93ed1,0xdda80087}},	//   _soj_, kšty, tpad_, итул_,
   {{0x442301c5,0xdb050013,0xb5fdbed2,0x63b881c0}},	// [2910] _poj_, rbhí, došl, _kevn,
   {{0x656f027f,0x61e989da,0x0ba72f7e,0x442329e7}},	//   _vych, _sbel, ршам, _qoj_,
   {{0xd7dc023c,0xed59803a,0x44230640,0x656f009a}},	//   _बातच, maže_, _voj_, _wych,
   {{0xed598503,0x6298bed3,0x63b8801b,0x2ca90106}},	//   laže_, _muvo, _levn, ppad_,
   {{0x44233ed4,0x3ce58105,0x20010a63,0xe1ff3ed5}},	//   _toj_, _कहें_, _kahi_, llós_,
   {{0x9f5801ca,0x63b880e8,0x81dd00ab,0x20033ed6}},	//   ldrá_, _nevn, ড়ি_, ndji_,
   {{0x26c19385,0x6298bed7,0x752d2015,0xad9b0187}},	//   ého_, _nuvo, lyaz, _gaúc,
   {{0x7c23bed8,0xa2c0825e,0x9f580693,0x26c98067}},	//   _sonr, _विज्, ndrá_, čao_,
   {{0x81dd00c8,0xdd918117,0x68fb8669,0xeb999a1f}},	//   ড়া_, _ہوا_, _usud, лип_,
   {{0xc6e78cde,0x200100ad,0x7c3abe34,0x6a761986}},	//   _відп, _nahi_, ghtr, táfo,
   {{0x26c502a5,0x2a7f8282,0xd6db84ae,0xe365a361}},	//   šloj_, _khub_, _шта_, скни,
   {{0x69d9bed9,0xf59580f7,0x81cb00ab,0x8d9580f7}},	//   ngwe, _الإج, র্স_, _الإش,
   {{0x20013eda,0xbca5803d,0x66ea811c,0xdb15136f}},	//   _bahi_, _امتي, _təkc, _dezé,
   {{0x7c3abedb,0x22490859,0xf1b981dd,0x8fa30cec}},	//   chtr, _emak_, _leš_, заре,
   {{0xe7371860,0x9e5a3edc,0xdb1c016b,0x2ca68122}},	//   бер_, граф_, _odrá, _ztod_,
   {{0x2a7f81c0,0xf1b9bedd,0xb05b3ede,0xb87b1ee8}},	//   _nhub_, _neš_, tsäc, rtía,
   {{0xe57a2118,0xb87b0511,0x15b90196,0x629881ec}},	// [2920] уза_, stía, рысы_, _zuvo,
   {{0x8ccf809a,0xd37e8042,0x9f47bedf,0x09b00264}},	//   _दिनो, šćem_, cenç_, _কাটা,
   {{0xfdf9a418,0xdb0a82af,0xb05b3ee0,0xadf9800c}},	//   ्यास_, _gefä, rrät, ्यान_,
   {{0xd5b90009,0xb05b016d,0xb7b5819d,0xd186ac39}},	//   _всё_, srät, _kọw, блей,
   {{0xa3d78744,0x69db00be,0xb05b0106,0x9c82807a}},	//   िला_, אַוו, prät, ščil,
   {{0x64a321ae,0x33d5035f,0x66043ee1,0xdfcf8013}},	//   _хара, _міст, ldik, فيه_,
   {{0xb5fd8025,0x2ca68082,0x68e2bee2,0xe8190778}},	//   pošl, _stod_, stod, दाता_,
   {{0xb8ce8a49,0x66043ee3,0x60c40669,0x91e38ae7}},	//   _কি_, ndik, _ovim, _носе,
   {{0x63b88efc,0x6298b799,0xe12387b6,0x68300338}},	//   _pevn, _suvo, _емти, _vädj,
   {{0x96ba941e,0x22493ee4,0x4438008e,0x60c2bee5}},	//   _буду_, _smak_, _jlr_, msom,
   {{0x6e969e09,0xe69680f7,0x60c284dc,0x7d0b9384}},	//   _الصا, _الصد, lsom, _ergs,
   {{0xe7178051,0x80dd00c8,0x7c3a80f1,0xc33302f6}},	//   _לחבר_, যবস্, shtr, פור_,
   {{0x63be0877,0x60c2bee6,0x9e6580f7,0xa3ca2d63}},	//   kapn, nsom, _بالن, ोला_,
   {{0xf1db0101,0x60c29149,0x25de99eb,0xdb1c006a}},	//   _भावन, isom, _गाडी_, _idræ,
   {{0x63be09ca,0x9f47bee7,0x02a281bc,0xddc9826c}},	//   dapn, renç_, _klọọ, lleš,
   {{0x66028074,0x22492cf6,0x20012b8c,0xed59b2b2}},	//   _jaok, _umak_, _wahi_, saže_,
   {{0x5fc88aad,0x20013ee8,0x61ed3ee9,0x443800b9}},	// [2930] रणाल, _tahi_, _ibal, _blr_,
   {{0x7bdabeea,0x60c28e23,0x44e2807b,0xb6069487}},	//   ngtu, dsom, ið_, lašć,
   {{0x62808267,0xd37b1401,0x319e8133,0x645c0580}},	//   _bhmo, уча_, _ịza_, _djri,
   {{0x62808858,0x2a7f822c,0x6602ab23,0x998dbeeb}},	//   _chmo, _qhub_, _naok, _aleš_,
   {{0x61ed27c7,0x4ac50076,0x7bc30125,0xf1b984c4}},	//   _mbal, _लटकव, ónus, _veš_,
   {{0xc60100c8,0x9ea992b2,0x16a99485,0xd00981ae}},	//   _একটা_, авка_, авки_, реке_,
   {{0xe7398c6e,0x62358009,0x6e3ba0fd,0x46399156}},	//   рей_, _деву, thub, ичия_,
   {{0x82378f24,0xe7f5809a,0x7bda837a,0x25de816f}},	//   _ارسا, _इसका_, egtu, _गाणी_,
   {{0x6e3b8867,0x7e69838e,0xddc9807a,0x998d9024}},	//   rhub, roep, gleš, _fleš_,
   {{0x61ed3eec,0x6e3bbeed,0x7e6982f7,0x72c58087}},	//   _abal, shub, soep, обоз,
   {{0x60c4003a,0xfbd204de,0x61ed0c2e,0x7c2701a1}},	//   _svim, ותי_, _bbal, _mojr,
   {{0x3cfd90af,0xa2cc05fb,0x6e3b805d,0x7c270168}},	//   _tswv_, _हिस्, qhub, _lojr,
   {{0xb87b12cc,0x644f82be,0xe44e8a08,0x9f478009}},	//   rtín, écis, _жж_, senä_,
   {{0x6e3981c0,0xb5fd8450,0x61ed3eee,0xdfd201a8}},	//   _hlwb, košk, _ebal, بيس_,
   {{0x7d09beef,0xb5fd8052,0x81b900ab,0x969510f8}},	//   lves, jošk, _চার_, зруш,
   {{0x4427bef0,0x27ed003a,0x78a9801b,0x85053ef1}},	//   _hon_, đena_, _otev, रिंट_,
   {{0x66043ef2,0x4427bef3,0x63be3ef4,0x0c263ef5}},	// [2940] rdik, _kon_, tapn, оман,
   {{0x69c982a3,0x4427bef6,0x2aed80a5,0xf20286a7}},	//   _adee, _jon_, _जहाँ_, _रोज़_,
   {{0x442786e3,0x290dbef7,0x6d40afa4,0xf1b985f3}},	//   _mon_, _area_, zzma, _gošk_,
   {{0x290dbef8,0x4427801c,0xe4da003d,0x60c2bef9}},	//   _brea_, _lon_, _پوست_, tsom,
   {{0xa88a8071,0x290db500,0xdb1abefa,0x208a8558}},	//   айда_, _crea_, raté, айди_,
   {{0x4427befb,0xb8f28f1b,0x764b831d,0x29000748}},	//   _non_, _वि_, _amgy, _msia_,
   {{0xab2a0021,0x71a68705,0x26d83efc,0xb5fd826c}},	//   _това_, _мавз, nuro_, cošk,
   {{0x44278af9,0x27f83efd,0x25bfbefe,0x290d8118}},	//   _aon_, hern_, gaul_, _frea_,
   {{0x4427beff,0x629c3f00,0xe4e6835f,0x27f83f01}},	//   _bon_, _huro, ційн, kern_,
   {{0x4427bf02,0x629c3f03,0x44e28125,0x26d83f04}},	//   _con_, _kuro, rð_, kuro_,
   {{0x629c00a9,0x2be20b86,0x44278051,0xa3e205e8}},	//   _juro, _पाना, _don_, _धान_,
   {{0x26d83f05,0x629c3f06,0x64893f07,0x63bc02af}},	//   duro_, _muro, _uživ, _lern,
   {{0x4427bf08,0x3204809a,0x27f83f09,0xc21800e8}},	//   _fon_, _mamy_, fern_, ією_,
   {{0x4427bf0a,0x9f4c027f,0x27f83cac,0xb87b01a8}},	//   _gon_, ždý_, gern_, rtío,
   {{0xd5bb37be,0x764b831d,0x629c0110,0x26c53f0b}},	//   иса_, _ymgy, _nuro, élo_,
   {{0x26cd003a,0x4427bf0c,0x61ed3f0d,0xc7b880ce}},	//   čeo_, _zon_, _ubal, _dođi_,
   {{0x4427bf0e,0x2d8f034a,0x63bc3a54,0xdb0385e4}},	// [2950] _yon_, äge_, _bern, _fenó,
   {{0xf1d8a714,0xfbab0048,0x645abf0f,0x63bc3f10}},	//   _डाउन, ртай_, nnti, _cern,
   {{0x63bc3f11,0xb87b0272,0x26d83f12,0x7d09bf13}},	//   _dern, ntím, curo_, zves,
   {{0xb5fd8db7,0x290d802e,0xf9c7835f,0x629c3f14}},	//   rošk, _prea_, іщен, _duro,
   {{0x8d873811,0x361a04de,0xddc8809a,0xdb188118}},	//   _фунд, _הורד, łośc, _devé,
   {{0x63bc3f15,0x629c3f16,0x290d802e,0x7bce8207}},	//   _gern, _furo, _vrea_, óbul,
   {{0xf1b9812b,0x629c3f17,0x443ebf18,0x9f4781d6}},	//   _loši_, _guro, dht_, lenú_,
   {{0xf1bf87ca,0x4427bf19,0x682f8bc5,0x443e81ec}},	//   _þá_, _son_, _nødv, eht_,
   {{0x63bc3f1a,0x27f8131e,0x7bca802a,0x225fa1ba}},	//   _yern, yern_, _bdfu, _ijuk_,
   {{0x443e804c,0x2900008e,0x69dd3f1b,0x442783e7}},	//   ght_, _rsia_, egse, _qon_,
   {{0x44278943,0xa822803d,0x63a502af,0xdb0e01ec}},	//   _von_, _سکون, ichn, _gebä,
   {{0x2005bf1c,0xdb03862f,0x645abf1d,0xfc3f2f74}},	//   _hali_, _senó, anti, _stíl_,
   {{0x20058859,0x4427bf1e,0x27f83f1f,0xdb0881a8}},	//   _kali_, _ton_, tern_, fadó,
   {{0x443e8bd5,0x26d83f20,0x9f5a047f,0x27f801ec}},	//   cht_, turo_, _papà_, uern_,
   {{0xe7ed9880,0xe7373f21,0x7bc1bf22,0x63bc0d11}},	//   च्या_, пер_, malu, _rern,
   {{0x7bc19a6e,0x200580d7,0x629a00e7,0x26d800b4}},	//   lalu, _lali_, _étoi, ruro_,
   {{0x63bc0393,0x29000057,0xdb1891b9,0x27f83f23}},	// [2960] _pern, _usia_, _revé, pern_,
   {{0x7bc1bf24,0x26d81fbb,0x224dbf25,0x2005bf26}},	//   nalu, puro_, _amek_, _nali_,
   {{0xeb971bd8,0x179b010f,0x62963f27,0xe7b70039}},	//   чих_, _לייב, _kiyo, _מהיר_,
   {{0x63bc0077,0x629610fe,0xd36f12c5,0xdb1c0168}},	//   _wern, _jiyo, دهم_, _herë,
   {{0xe5720b76,0x63bc3f28,0x2005bf29,0x645abf2a}},	//   _سطح_, _tern, _bali_, ynti,
   {{0x66063f2b,0x200582a3,0x7bc1bf2c,0x186794f6}},	//   _hakk, _cali_, jalu, пачи_,
   {{0x2005bf2d,0x81d400c8,0xed59aa06,0x8f9b03c8}},	//   _dali_, স্য_, važa_, זיצי,
   {{0x225a8013,0x442a3f2e,0x7e648088,0x62963f2f}},	//   _الرد_, _hob_, čipo, _niyo,
   {{0x6d440698,0x442a3f30,0x7bc1bf31,0x682f9e01}},	//   nzia, _kob_, falu, _rødv,
   {{0x20058a8e,0x645abf32,0x7bde04a7,0x64891f07}},	//   _gali_, unti, ngpu, _užit,
   {{0x442a3f33,0x62963f34,0xddcd001b,0x62840046}},	//   _mob_, _biyo, hlaš, _bhio,
   {{0x443e88cf,0x1e8691e9,0x442a3f35,0x62843f36}},	//   sht_, _элем, _lob_, _chio,
   {{0x62963f37,0x588713cd,0x7bc1a4b9,0x9f5e809f}},	//   _diyo, зыва, balu, _matí_,
   {{0x6d440063,0x27ed003b,0xc9538051,0x442a3f38}},	//   dzia, đeno_, תמש_, _nob_,
   {{0x6284003c,0x7e6d0955,0x3ce681c0,0x66063f39}},	//   _fhio, toap, _hqov_, _bakk,
   {{0x33778051,0xf4a800c8,0x629606a9,0xa2d30105}},	//   _מתוך_, _ওয়েব, _giyo, _डिब्,
   {{0x81c28a49,0x6a7d040e,0x7e6d002e,0xdb08bf3a}},	// [2970] ংলা_, léfo, roap, padó,
   {{0x442a0069,0x6296132e,0x225f8186,0x78ad3f3b}},	//   _cob_, _ziyo, _sjuk_, _itav,
   {{0x3cf9101c,0x63a50114,0x66062796,0x62963f3c}},	//   _उनके_, rchn, _fakk, _yiyo,
   {{0x63a502af,0xe9df3f3d,0x2005bf3e,0x644e02ec}},	//   schn, ngú_, _sali_, _embi,
   {{0x8c3b0352,0x3ce6822c,0x9984801b,0x443c9d3e}},	//   _auße, _nqov_, _domů_, _olv_,
   {{0x7d0d3f3f,0x6a7612ca,0x66ea8085,0x66063f40}},	//   mvas, ráfi, _təkl, _zakk,
   {{0x7d02bf41,0x7bc193bd,0x2005bf42,0x66060c2e}},	//   _asos, valu, _vali_, _yakk,
   {{0x2005a27f,0x2d998aa2,0x442a06b9,0x78ad3f43}},	//   _wali_, øse_, _zob_, _otav,
   {{0x7bc1bf44,0x799b8122,0x442a0282,0xd0d48081}},	//   talu, _iguw, _yob_, _потъ,
   {{0x62963f45,0x7c2a831d,0x62840c41,0x442a0069}},	//   _siyo, _cofr, _shio, _xob_,
   {{0x37e300c8,0xb05b00f2,0x7bc1bf46,0x6fd7016f}},	//   য়ার, rsäl, ralu, _बाजू,
   {{0x7bc1bf47,0xc7b88052,0x1c0a016f,0x5eac00ab}},	//   salu, _dođu_, _होईल_, _ছিলে,
   {{0xed4e8ea2,0x7bc1bf48,0xdb1c00f1,0xdb1e0511}},	//   _ро_, palu, _perë, rapé,
   {{0xb8f61834,0x40950847,0x66063f49,0x6609bf4a}},	//   _हि_, ерст, _sakk, ldek,
   {{0xdee33f4b,0x628409de,0xe73a0009,0x66e3008f}},	//   кори, _thio, цев_, кора,
   {{0x442a3f4c,0x6d440102,0x644e00dd,0xa3a98a74}},	//   _sob_, tzia, _smbi, गुर_,
   {{0x442a3f4d,0x66063f4e,0x15fd0035,0x6e24008e}},	// [2980] _pob_, _vakk, उज़र_, rjib,
   {{0x6d443f4f,0x66063f50,0x64418234,0x66098198}},	//   rzia, _wakk, nhli, hdek,
   {{0x7d090ef1,0x66063f51,0xdb1c3f52,0xf1b9812b}},	//   _šest, _takk, _keré, _lošu_,
   {{0x7df9800c,0x8c480085,0xa2d5bf53,0xceb304de}},	//   ्योग_, _başç, _भिन्, _שיר_,
   {{0x442a0282,0x81cb00ab,0x66098365,0x201a008e}},	//   _tob_, র্ক_, ddek, _knpi_,
   {{0x76aa9697,0x644e0f38,0x60c9807a,0x9f5806c0}},	//   отив_, _umbi, _dvem, terè_,
   {{0xe80f2714,0xd3721baf,0x64418782,0xdb1abf54}},	//   ायता_, _شهر_, dhli, tatí,
   {{0x60c9011f,0x7c2abf55,0x81d400ab,0x249806ae}},	//   šemi, _sofr, স্ত_, _hirm_,
   {{0x6e2b826b,0x998d826f,0xdb1abf56,0x69c080eb}},	//   _dogb, _pleť_, ratí, _ieme,
   {{0x69c0bf57,0x682f8257,0x2904bf58,0x61e41a5b}},	//   _heme, _døds, _isma_, _acil,
   {{0x69c0bf59,0xda1a0540,0x29123f5a,0xdb1a8511}},	//   _keme, धांत_, _arya_, patí,
   {{0x69c0bf5b,0x78a082a0,0x682f8257,0xc7b880d2}},	//   _jeme, _kumv, _føds, _vođu_,
   {{0x69c08393,0x3946bf5c,0xf8ae015b,0x656f81ec}},	//   _meme, nzos_, یکی_, ücht,
   {{0x644182af,0xdb0e0118,0x69c0bf5d,0x59db0072}},	//   chli, _debú, _leme, _भाकर,
   {{0xfe730c2a,0x76410110,0x7793003d,0x32670081}},	//   ندر_, ūlym, ضیحا, _отив,
   {{0x27e98025,0x69c0bf5e,0xdb15026f,0xe508801c}},	//   đani_, _neme, _nezá, _kỷ_,
   {{0xa2da8b6f,0x3d118076,0x61fd3f5f,0xddc40cd9}},	// [2990] पूर्, तिये_, mesl, bliž,
   {{0x69c088f1,0x32093f60,0x4ea73f61,0x660982d0}},	//   _aeme, _haay_, _орма, zdek,
   {{0x60c9803a,0x69c0bf62,0x2904bbde,0x3ce93f63}},	//   _svem, _beme, _asma_, stav_,
   {{0xfe350158,0x61fd3f64,0xdb18801b,0xdb050b6a}},	//   _נאָך_, nesl, _neví, nché,
   {{0x69c08b0b,0xadd604de,0x29048122,0x320926e9}},	//   _deme, _אורח_, _csma_, _maay_,
   {{0x75160158,0x9f0580f7,0xa3b086ae,0xfd66819d}},	//   _אַלע_, فوتو, टुम_, sspọ,
   {{0x69c0bf65,0x7bc53f66,0x66098fb0,0x20d5807b}},	//   _feme, mahu, tdek, _búið_,
   {{0x69c0915b,0x7bc53f67,0xb87b3f68,0x32090122}},	//   _geme, lahu, luíd, _naay_,
   {{0x6441bf69,0xdb18816b,0x2904bf6a,0x27e98300}},	//   thli, _deví, _gsma_, ƙan_,
   {{0x69c0bf6b,0x7bc51341,0xc9849510,0x61e401a8}},	//   _zeme, nahu, _руси, _scil,
   {{0x69c0bf6c,0x6e2bbf6d,0x35b59138,0xdb1c3e3d}},	//   _yeme, _togb, _збер, _peré,
   {{0xcb120158,0x61fd00c9,0x6a788207,0x6834809f}},	//   אלט_, gesl, tífi, _ràdi,
   {{0x7bc53f6e,0x2d9d882e,0x78a081c0,0x6f053f6f}},	//   kahu, _igwe_, _xumv, _ashc,
   {{0xf8b28039,0xe3d500ab,0x68300106,0x7e7bbf70}},	//   רשם_, স্তব, _räds, llup,
   {{0xdb1c03b0,0x3a3f9d43,0x61fd3f71,0x7bc53f72}},	//   _teré, _olup_, besl, dahu,
   {{0xa49b009f,0x61e4017f,0xdb0381ec,0x7e7b8ff9}},	//   _pròp, _ucil, _benö, nlup,
   {{0xc6928f60,0x69c08fc6,0x7afb20f1,0x6bd60061}},	// [29a0] ראן_, _reme, _ćuta, فتار,
   {{0x69c62b6b,0x7bc53f73,0xdb1a8019,0x7e7b8234}},	//   lake, gahu, latá, hlup,
   {{0x69c095bd,0xe1faabad,0x645e15b3,0x6735009a}},	//   _peme, зге_, rnpi, cyzj,
   {{0xe64611d2,0x69c63f74,0x5186a187,0x4ad1016f}},	//   _чемп, nake, нула, _हिरव,
   {{0x76560be8,0xa3cf8778,0x7bc53f75,0xb87b0ba3}},	//   miyy, षणा_, bahu, buíd,
   {{0x69c63f76,0x76560086,0x26dcbf77,0x3946bf78}},	//   hake, liyy, tuvo_, rzos_,
   {{0x44441e90,0x81cb00c8,0x69c603f8,0x8c1b0158}},	//   mh_, র্ট_, kake, _צולי,
   {{0x76560be8,0x3a3f8668,0x7e7bbf79,0x69c63f7a}},	//   niyy, _glup_, glup, jake,
   {{0xd257810f,0x69c63f7b,0x40a88065,0x7c2e3f7c}},	//   _נשמה_, dake, _آخری_, _kobr,
   {{0x44440142,0xb05b00f2,0x9f47826f,0x224006df}},	//   nh_, rsäk, lený_, _alik_,
   {{0x3fc98077,0x1de10e5b,0x22403f7d,0xb21b3f7e}},	//   _آگهی_, _फालत, _blik_, nlæg,
   {{0x61e2b49d,0xb5fb0065,0x64a6b00b,0xa2d30eed}},	//   ngol, _aján, _зада, _डिस्,
   {{0x76563f7f,0x76443f80,0x44443f81,0x61fd08f8}},	//   diyy, dhiy, kh_, resl,
   {{0x444429a4,0x2c16809a,0x7c2e3f82,0x7984009a}},	//   jh_, ताओं_, _nobr, _dziw,
   {{0x44442832,0xb5fd80d2,0xb87b0e14,0x78ad3f83}},	//   dh_, pošt, ktív, _živč,
   {{0x44443f84,0x442e84eb,0xa2d5800d,0xdb1abf85}},	//   eh_, _hof_, _भित्, catá,
   {{0x7bc53f86,0x5c753306,0x25a93f87,0x9f478a21}},	// [29b0] tahu, влат, rcal_, dený_,
   {{0xddeb0077,0x44443f88,0x25a93f89,0x61e2a4bb}},	//   _کرده_, gh_, scal_, egol,
   {{0xa3e20006,0x7bc53f8a,0xb3e215fb,0xb87b2777}},	//   _धार_, rahu, _पारख, ruíd,
   {{0x7bc50bfb,0x44443f8b,0x61e2ab81,0x442ebf8c}},	//   sahu, ah_, ggol, _lof_,
   {{0x44441523,0x661d3f8d,0x26cc8267,0x7bc53f8e}},	//   bh_, _insk, _avdo_, pahu,
   {{0x44443f8f,0x81cb00c8,0xb87b3f90,0x69c63f91}},	//   ch_, র্চ_, quíd, zake,
   {{0xe8221a42,0xd9d900c8,0x1c0a005e,0x9f47826f}},	//   माता_, ধ্যম, _होटल_, bený_,
   {{0x660d3f92,0x7c2e0ed7,0x645704c3,0x60cd3e5b}},	//   ndak, _zobr, lixi, _ovam,
   {{0x7e7b810b,0xe1ff0019,0xe81e8105,0x26cc82f7}},	//   rlup, deó_, पाशा_, _evdo_,
   {{0x2240021e,0x76560201,0x442e8428,0x69c63f93}},	//   _slik_, ziyy, _cof_, wake,
   {{0x2fc7bf94,0xdb1a8065,0x69c63f95,0xdb0a82af}},	//   mang_, tatá, take, _gefü,
   {{0x2fc7ad1f,0x444400f1,0x3eaa803e,0x38a60187}},	//   lang_, zh_, žité_, _pôr_,
   {{0x69c63f96,0x1d0987eb,0xf1bf0019,0x76560085}},	//   rake, _цели_, pján_, viyy,
   {{0x2fc7ae9b,0x76563c76,0x69c63f97,0x6d458085}},	//   nang_, wiyy, sake, _əhal,
   {{0x64573827,0xe45680be,0x76443f98,0x660b8122}},	//   dixi, _ביסט_, thiy, _kagk,
   {{0xadf99391,0x2fc7b151,0xb17b016d,0x49730a2c}},	//   ्यटन_, hang_, mgån, ụtụ_,
   {{0x44443f99,0xed572109,0x7c2e3f9a,0x660b84d2}},	// [29c0] th_, вот_, _pobr, _magk,
   {{0x661d3f9b,0x2fc7a9fb,0x7bc3bf9c,0xb5fb007b}},	//   _ensk, jang_, _jenu, _hjál,
   {{0x7bc3845c,0x2fc78458,0x3cedbf9d,0x9f480009}},	//   _menu, dang_, htev_, ähän_,
   {{0x44443f9e,0x660b849f,0xb21b0215,0x6289bf9f}},	//   sh_, _nagk, rlæg, _cheo,
   {{0x61f600f1,0x2fc78456,0x9f4780e1,0x69c43fa0}},	//   _mbyl, fang_, rený_, _meie,
   {{0x2fc7bfa1,0x69c43fa2,0x7bc3a628,0xb87b03a7}},	//   gang_, _leie, _nenu, stív,
   {{0x44208104,0x2d80adab,0x660bbfa3,0xd8388390}},	//   _đi_, _šie_, _bagk, _niče_,
   {{0x27ed0025,0x6289bfa4,0x69c400eb,0x442eb8ab}},	//   đeni_, _gheo, _neie, _sof_,
   {{0x2fc7977c,0x18a696be,0x7bc3afc3,0xa0a6885f}},	//   bang_, _разм, _benu, _разд,
   {{0x442e82a3,0x2fc7bfa5,0x7bc3bfa6,0xdb1a82d0}},	//   _qof_, cang_, _cenu, natç,
   {{0x201e81cd,0x60cd3fa7,0x6aa481a1,0xdb188061}},	//   _inti_, _svam, _čifs, _bevá,
   {{0x200cbfa8,0x7d043fa9,0x05e103eb,0xddcd0035}},	//   _hadi_, kwis, _फाइब, ział,
   {{0xe80f035a,0x6a7d02be,0x7bc38915,0x200cbfaa}},	//   ायला_, néfi, _fenu, _kadi_,
   {{0x200c848f,0x6aa384be,0x645711ee,0x78a401ed}},	//   _jadi_, _funf, xixi, _duiv,
   {{0x45d50391,0x7bc8bfab,0x200c83ec,0x69c43fac}},	//   ловс, madu, _madi_, _feie,
   {{0x6d0e01fe,0x200cbfad,0x7bc8bfae,0x7bc3bfaf}},	//   सिंग_, _ladi_, ladu, _zenu,
   {{0xd904a003,0x2fc7ad1f,0x2d580364,0x62898355}},	// [29d0] _بی_, yang_, вить_, _rheo,
   {{0xda2105b3,0x200c990f,0x7642bfb0,0x6289bfb1}},	//   यावत_, _nadi_, _lloy, _sheo,
   {{0x64573fb2,0xddcd009a,0x2fc7800b,0x6289851e}},	//   rixi, riał, vang_, _pheo,
   {{0x2fc7ad1f,0x22590370,0x661d0858,0x629e80e7}},	//   wang_, nisk_, _unsk, _épou,
   {{0x2fc79acd,0x4dda0051,0x200cbfb3,0x7bc8bfb4}},	//   tang_, _אחרו, _badi_, kadu,
   {{0xd366b0f6,0xa2cc3fb5,0x7bc88074,0x7642bfb6}},	//   _هه_, _हिच्, jadu, _aloy,
   {{0x2fc7a9fb,0x660b9856,0x7bc3bfb7,0x200c83f8}},	//   rang_, _pagk, _renu, _dadi_,
   {{0xc3321a6a,0x2fc7be4b,0x6d49811e,0x201e8081}},	//   _פון_, sang_, tzea, _enti_,
   {{0x7bc394ec,0x2fc79291,0x22591da3,0x6e2989ca}},	//   _penu, pang_, disk_, rjeb,
   {{0xb5fb0125,0x7bc8bfb8,0x69c43fb9,0x200cbfba}},	//   _sjál, gadu, _seie, _gadi_,
   {{0x78a403d3,0x7bc3bfbb,0x22590370,0xc73580d5}},	//   _suiv, _venu, fisk_, _حفاظ,
   {{0x22590370,0x76429bc2,0xb17b0106,0x68fb819d}},	//   gisk_, _gloy, rgån, _kpud,
   {{0x7bc3bfbc,0xfe70845b,0x7bc8bfbd,0xc9550048}},	//   _tenu, _بدل_, badu, атры,
   {{0xdee61628,0xdb1c040e,0x6cd28c2a,0x66e60d91}},	//   логи, _serí, _اقوا, лога,
   {{0xdb1c2777,0xe81901ce,0x61e9bfbe,0x22591da3}},	//   _perí, दाजा_, _ocel, bisk_,
   {{0x28dc1d2a,0x3ea58c6e,0x25adbfbf,0x6d410201}},	//   _बिपि, _mult_, ncel_, _əlav,
   {{0xdb0a8125,0x3a20352f,0xdb1c3fc0,0x44313fc1}},	// [29e0] _hefð, _inip_, _verí, _boz_,
   {{0x7d043fc2,0x61e9b448,0x6600803e,0x657d00f1}},	//   rwis, _acel, zemk, _dysh,
   {{0x200c8025,0x59b80076,0x7ae1bfc3,0xddc98025}},	//   _radi_, _आभार, nult, dlež,
   {{0x66ea8201,0x61e60b20,0x2fc583a8,0x645527bf}},	//   _məkt, ngkl, _aelg_, _emzi,
   {{0x7ae1bfc4,0x44310ba3,0x9f5801e8,0xc7b881f4}},	//   hult, _foz_, lerà_, _anđa_,
   {{0x648b1d64,0xdcfd00eb,0x53a32f8d,0x3ea5ab4b}},	//   güid, _uzsā, _гарб, _bult_,
   {{0xf1ba0028,0xa3e9016f,0xe8d901bc,0x9f5801e8}},	//   _đơn_, _यात_, _izụ_, nerà_,
   {{0xe297bfc5,0x7e640074,0x96349adc,0xb05b0106}},	//   _бас_, nnip, рниц, lsät,
   {{0x200c8867,0x7bc8bfc6,0x80a018b8,0x3d170d86}},	//   _tadi_, tadu, _गंगे, निये_,
   {{0xcb1f80d4,0xf1b9826c,0x201e809c,0x61e9801b}},	//   यमंड_, _inša_, _unti_, _zcel,
   {{0x22590370,0xa3e5835a,0xb89380f7,0x7e6414cf}},	//   tisk_, _फार_, _اللع, knip,
   {{0x9f58047f,0xd9150048,0xdb050187,0x80c1864a}},	//   derà_, адмы, lchã, रीवे,
   {{0x22590370,0x7bc8ad8b,0xf1bf0019,0x3ea580f3}},	//   risk_, padu, lják_, _zult_,
   {{0x22590370,0xb5fb03fb,0xe7e300ab,0xbddb09c4}},	//   sisk_, _ukáz, য়্য, _clèn,
   {{0x645abfc7,0x81dc80c8,0x22590370,0x7ae1879a}},	//   miti, ত্য_, pisk_, cult,
   {{0xe8d90870,0x443ebfc8,0x442c8106,0x29090ec9}},	//   _azụ_, lkt_, ljd_, _tsaa_,
   {{0x54551878,0xe8220076,0xa3e90740,0xdc5504bd}},	// [29f0] ават, माशा_, _याद_, авањ,
   {{0xe7e081fe,0x61e98098,0xb87b3fc9,0x645ab433}},	//   _नागप, _scel, dríg, niti,
   {{0x44312755,0x443ebfca,0x20033fcb,0xed59890c}},	//   _voz_, ikt_, meji_, raži_,
   {{0x20033fcc,0xdb1c0073,0x27ed005c,0x645abfcd}},	//   leji_, _serã, đenu_, hiti,
   {{0x25ea146d,0x628d125b,0x91bf819d,0x3ea5bfce}},	//   _छाती_, _mhao, _ajụ_, _sult_,
   {{0x443e8613,0x645abfcf,0x20113fd0,0x7c3e048d}},	//   jkt_, jiti, ndzi_, ckpr,
   {{0xfc3f02ba,0x645abfd1,0xdb1c03a7,0x2fc5bfd2}},	//   _guía_, diti, _verã, _velg_,
   {{0xceb40451,0x6e2d3fd3,0x443e97dd,0x81dc80ab}},	//   זיק_, njab, ekt_, ত্ব_,
   {{0x645abfd4,0x20033fd5,0x7bc7059c,0x1c45960f}},	//   fiti, keji_, _keju, иним,
   {{0x1c1f8cce,0x69cbbfd6,0x7bc73fd7,0xdb1c002a}},	//   बाइल_, lage, _jeju, _herá,
   {{0x3f678a95,0xcb69813a,0x38ab83ba,0x7bc70133}},	//   _стаб, тане_, _hør_, _meju,
   {{0x628d1a2f,0x69cbbfd8,0x660f0004,0x7bc737c1}},	//   _chao, nage, _nack, _leju,
   {{0x645abfd9,0x628d0ad0,0x9f580e67,0xfe708872}},	//   biti, _dhao, derá_, _عدم_,
   {{0x443ebdb7,0x69cbbfda,0x7ae1bfdb,0x9f583ed7}},	//   ckt_, hage, pult, terà_,
   {{0x660f3fdc,0x69cbbfdd,0x38ab8aa2,0x628d0014}},	//   _back, kage, _lør_, _fhao,
   {{0x628d0083,0x660f0b80,0x7aee826f,0x9f583fde}},	//   _ghao, _cack, žití, gerá_,
   {{0xb05b2bf5,0x7afc14e4,0x6486808b,0x69d60420}},	// [2a00] tsät, _sprt, iðin, _idye,
   {{0x7d0b8077,0x628d0326,0x9f583500,0x7bc70144}},	//   _msgs, _zhao, perà_, _ceju,
   {{0xb05b0884,0x9f583fdf,0x660f3fe0,0xf1da2263}},	//   rsät, berá_, _fack, _भयान,
   {{0x9f5810dd,0x660f02a5,0x38ab8a38,0xed598024}},	//   cerá_, _gack, _bør_, lažu_,
   {{0x03a63fe1,0x645a82ec,0x3940bfe2,0x443ebfe3}},	//   _виго, yiti, áis_, ykt_,
   {{0x6604221a,0x645abfe4,0x26dc9c89,0xf1bf0019}},	//   leik, xiti, trvo_, tják_,
   {{0xe7ee023c,0x1c1fa418,0x69cbb29c,0x12e080ab}},	//   _जाना_, बाईल_, bage, _বন্দ,
   {{0x38ab8a38,0x261983e8,0x69cbbfe5,0x7d0b8176}},	//   _før_, _मोदी_, cage, _bsgs,
   {{0x38ab8022,0x6143bfe6,0xed598289,0x645abfe7}},	//   _gør_, _дета, kažu_, titi,
   {{0x6282bfe8,0x628d008c,0x69d63fe9,0x9f5800e1}},	//   lloo, _shao, _adye, zerá_,
   {{0x443ebfea,0x63a380ee,0x3dc680ee,0x6d4d0365}},	//   rkt_, _dgnn, _teow_, zzaa,
   {{0x443e819b,0x645abfeb,0x6282a710,0x2efe826c}},	//   skt_, siti, nloo, _iptf_,
   {{0x645a8c53,0x9f5803a7,0xc05b00e8,0x68e48046}},	//   piti, verá_, вів_, àidh,
   {{0x02a6b03c,0x69cbbfec,0xc05b00e8,0x69d600e4}},	//   _крим, zage, тім_, _edye,
   {{0x628d0ad0,0x9f580207,0x69cbbfed,0x44f0bfee}},	//   _thao, terá_, yage, là_,
   {{0x7bc70867,0xf8a6897d,0xb05b0198,0xe61f00ff}},	//   _seju, खदाय, tsäs, _khôi_,
   {{0x660f00f2,0xdb050a21,0x7bc70458,0x44f0bfef}},	// [2a10] _vack, dchá, _peju, nà_,
   {{0xdb1c040e,0x6d4d0a0f,0x69cbbff0,0x38ab83ba}},	//   _será, rzaa, wage, _rør_,
   {{0x69cbbff1,0xa2f53ff2,0x6282a11c,0x38ab821e}},	//   tage, спеч, floo, _sør_,
   {{0xceb20159,0x80db800f,0xb9100135,0x628289ff}},	//   _מיט_, _निदे, _nanị_, gloo,
   {{0xdb1c0da1,0xe9d88110,0xe7ee0424,0x81d400ab}},	//   _verá, ркі_, _जामा_, স্ক_,
   {{0x6e22bff3,0x44f0bff4,0x7bd53ff5,0xdb0501a8}},	//   _anob, dà_, _udzu, achá,
   {{0xdb1c2ff3,0x6282930d,0x64470197,0x41e785a8}},	//   _terá, bloo, _ilji, _віза,
   {{0x38ab8aa2,0x683d8722,0x6aa09c05,0x7d0b8122}},	//   _tør_, _mèdi, _gimf, _psgs,
   {{0x64868125,0xf80780e8,0x79808114,0x7649bff6}},	//   rðin, _вчен, _gymw, rhey,
   {{0x308580f7,0x7649bff7,0xe0df3ff8,0x61ed0c1d}},	//   _الطف, shey, drò_, _acal,
   {{0x78a98264,0xb87b01df,0x9f58009f,0x442300fc}},	//   _huev, tuín, merç_, _mnj_,
   {{0x78a1bff9,0x66ea811c,0x61fb810c,0x6458913b}},	//   _hilv, _təkr, _jbul, _emvi,
   {{0x78a9be2e,0x25bf9bea,0x66043ffa,0x61fbbffb}},	//   _juev, mbul_, veik, _mbul,
   {{0x78a986a5,0x25bf8122,0x7e7d3ffc,0xf1bf041c}},	//   _muev, lbul_, _aksp, abá_,
   {{0x66043ffd,0xa2d31a42,0x7d098d33,0xddcb28d2}},	//   teik, _डिग्, lwes, _šiša,
   {{0x25bf87d9,0x290d8e1b,0xed598301,0x64470300}},	//   nbul_, _osea_, sažu_, _alji,
   {{0x78a9a797,0x66043ffe,0xddc98035,0x7c3506c4}},	// [2a20] _nuev, reik, wieś, _bozr,
   {{0x61fbbfff,0xdd8f0591,0xaca38133,0x628281e0}},	//   _abul, رول_, _adịk, wloo,
   {{0xdb1c4000,0x25bfc001,0xb09b0039,0x7d09c002}},	//   _merç, kbul_, _תייר, hwes,
   {{0xd910819f,0x7d09805d,0xb87b4003,0x6b7a80be}},	//   ویز_, kwes, críb, ארענ,
   {{0xc05a8d8e,0x6441c004,0x78a98333,0x78a192f1}},	//   лік_, kkli, _cuev, _bilv,
   {{0x78a18341,0x6447005c,0x61fbc005,0xdb1ac006}},	//   _cilv, _glji, _ebul, ratú,
   {{0x6282c007,0x645e4008,0x6441816d,0x7ff380f7}},	//   ploo, mipi, dkli, سسوا,
   {{0x44f081dc,0xc8e0800f,0x6f1a807a,0x44b480e8}},	//   tà_, _निपट, _vrtc, обис,
   {{0xa49b0722,0xdb1c0187,0x7afb0da8,0x68e60711}},	//   _pròx, _berç, _ćuti, jukd,
   {{0x44f0c009,0x61fb80f1,0x645e400a,0x15ea83eb}},	//   rà_, _zbul, nipi, _टावर_,
   {{0x7f868307,0x6d410201,0x44f0bff4,0x547b0039}},	//   _الان, _əlaq, sà_, רטיו,
   {{0xc3331a15,0x7a3f020f,0xe61f0028,0xa5bb39c6}},	//   לות_, _këti, _thôi_, _anón,
   {{0x6da38c48,0x645e400b,0xdb1c0009,0xb87b0118}},	//   _عموم, kipi, _herä, buíl,
   {{0x6441c00c,0xdb1c400d,0x69c01434,0xe0df01e8}},	//   ckli, _gerç, ðmer, rrò_,
   {{0x623507b6,0x7c351d4b,0x466b072a,0xc0580d8e}},	//   _меку, _rozr, грам_, сія_,
   {{0x7bca87ca,0x4caa00ab,0x6447025b,0x68e602c4}},	//   _hefu, _চৌধু, _slji, bukd,
   {{0x69cf0333,0x7c350038,0x7cd9003d,0x7bca80b9}},	// [2a30] mace, _pozr, شواز_, _kefu,
   {{0x69cf0018,0x4d9807ac,0x6aaac00e,0x645e400f}},	//   lace, скую_, _kuff, gipi,
   {{0xe7ee00cf,0xe9f90028,0x78a983a8,0x25a6c010}},	//   _जाता_, _giả_, _suev, _ogol_,
   {{0xa49b0176,0xb87b03cd,0x38af4011,0x04060264}},	//   _asòt, bríc, _kür_, রাগী_,
   {{0x61fbc012,0x7bd880d2,0x78a18b0c,0x78a9a4fe}},	//   _vbul, _odvu, _pilv, _quev,
   {{0x8aa70785,0x02a70a8e,0xdb1c00f2,0x25b3914f}},	//   _град, _грам, _berä, ीर्ण,
   {{0x81d40a49,0xa6b480ab,0x80dbb2df,0x69cf4013}},	//   স্ট_, _টিউট, _निवे, kace,
   {{0xee398abe,0x764d4014,0x7d09c015,0x68e6241c}},	//   рни_, nhay, twes, yukd,
   {{0x82348b76,0x78a18a35,0x7bcac016,0x893784e3}},	//   _عرفا, _tilv, _befu, _اعزا,
   {{0xf9909381,0x22494017,0x7d09c018,0x26199344}},	//   _سبق_, _alak_, rwes, _मोरी_,
   {{0x2007c019,0x6441c01a,0xdb1c401b,0x69cf401c}},	//   meni_, rkli, _gerä, face,
   {{0x2007829b,0x81e200c8,0x6441c01d,0x7d09c01e}},	//   leni_, ন্ন_, skli, pwes,
   {{0x7e7b8052,0xdb1c0073,0xe7ee0074,0xa2d58f0f}},	//   moup, _terç, _जादा_, _भिक्,
   {{0x7bcaaac5,0x2007805d,0x2249401f,0x7e698216}},	//   _gefu, neni_, _elak_, lnep,
   {{0x07a34020,0x2bbfb192,0x032580e8,0x8fa3151a}},	//   дарн, _श्या, _єдин, даре,
   {{0x38af0943,0xb87b4021,0x2007c022,0x7e69c023}},	//   _für_, tríc, heni_, nnep,
   {{0x645e4024,0x2007c025,0x3ea2016d,0xe45a10ee}},	// [2a40] tipi, keni_, _vikt_, ажа_,
   {{0x62864026,0x2a7f8326,0x81b00326,0xc8e080c2}},	//   llko, _akub_, _daɓe, _निबट,
   {{0xe5a60676,0x6da61354,0x41aa81f3,0x7e7b801b}},	//   _мини, _мина, авен_, koup,
   {{0x764d4027,0x645e0b51,0x387e82f7,0xb5fb008b}},	//   chay, sipi, _sktr_, _sjáv,
   {{0xa3e9853e,0xe80f016f,0xaca381bc,0x645e4028}},	//   यला_, ायचा_, _adọk, pipi,
   {{0xd6daa935,0x2007c029,0xdb1c0009,0xdfd080f7}},	//   ати_, geni_, _perä, ريب_,
   {{0x44f40364,0x27e087d9,0x4444402a,0x81e200ab}},	//   lä_, ğin_, mk_, ন্য_,
   {{0x4438402b,0xa534c02c,0x91e60592,0xdb1c02af}},	//   _hor_, знич, _कागज_, _verä,
   {{0x44f40364,0xc6930bea,0x2007c02d,0xd406ac18}},	//   nä_, ואה_, beni_, ояни,
   {{0x4444402e,0x81e200ab,0xb35480e8,0x69cf402f}},	//   nk_, ন্ম_, зкош, wace,
   {{0x444406a8,0x44384030,0x6b838355,0x28c68eed}},	//   ik_, _mor_, _cyng, रीरि,
   {{0x81dc8a49,0xb5fb00ab,0x44381bf6,0xb87b05a4}},	//   ত্র_, _imág, _lor_, dría,
   {{0x443804df,0x7e608812,0x44444031,0x44f40364}},	//   _oor_, mimp, kk_, jä_,
   {{0x44440586,0x6aaac032,0x44f40009,0x7d02c033}},	//   jk_, _tuff, dä_, _ipos,
   {{0x69cf087a,0x764d4034,0x6b838114,0xd838c035}},	//   pace, thay, _gyng, _moč_,
   {{0x2cb90358,0x7e60bbde,0x44444036,0x38af1266}},	//   _ptsd_, nimp, ek_, _tür_,
   {{0x44380bfa,0xa3ae86a7,0xd7fb25f5,0x5d5501f3}},	// [2a50] _bor_, _कला_, _кун_, чкат,
   {{0x44384037,0x64dd835a,0x764d4038,0x68e29adf}},	//   _cor_, _मिसळ, shay, drod,
   {{0x443822fb,0xf8bf253a,0x6d40c039,0x7ae88122}},	//   _dor_, lpé_, hyma, nudt,
   {{0x2007aff2,0x444404e0,0xc3338158,0x7c38c03a}},	//   weni_, ak_, ווע_, _lovr,
   {{0x4438073a,0x2ca30613,0x2007c03b,0x68e2809a}},	//   _for_, _tijd_, teni_, grod,
   {{0x4438403c,0x6d408110,0xd7fb8049,0xf8bf0036}},	//   _gor_, dyma, руд_, ipé_,
   {{0xe739c03d,0x2007812b,0x7d0d403e,0x44298028}},	//   сей_, reni_, lwas, _đa_,
   {{0xb0dc05b3,0x2007b209,0x28dc0054,0x4438403f}},	//   _बिलग, seni_, _बिलि, _zor_,
   {{0xdb050352,0x81e200c8,0x7d0d4040,0x83fc876c}},	//   schä, ন্ড_, nwas, ziđe,
   {{0x20079cd8,0xbebc80eb,0x76444041,0x28e0a263}},	//   qeni_, _brīd, zkiy, _निति,
   {{0x7c388098,0x59cf8aed,0x7d0d4042,0x7d02c043}},	//   _dovr, _हजार, hwas, _epos,
   {{0x7d0d4044,0x83fc8024,0x60c9a73c,0x7e608359}},	//   kwas, viđe, _kwem, cimp,
   {{0x6f1e0b80,0x69cd00c3,0xa56780d7,0x271c8129}},	//   _srpc, _deae, _بدان, _ảnh_,
   {{0x6b8388f3,0x44f40009,0x60c9c045,0x6aa411fe}},	//   _tyng, vä_, _mwem, _wiif,
   {{0xcb6694d6,0x4427c046,0xaa461c79,0xbebc81a9}},	//   _наше_, _inn_, _некл, _grīd,
   {{0x44f4025d,0x7c2706cb,0x6f1e00ce,0xb87b0333}},	//   tä_, _anjr, _vrpc, rría,
   {{0x76444047,0x7d0d1400,0x28e081a2,0x6e39822b}},	// [2a60] rkiy, gwas, _निधि, _mowb,
   {{0x44444048,0x764400a4,0x29120590,0x69db8216}},	//   uk_, skiy, _isya_, _adue,
   {{0x44384049,0xf62601f3,0x6d40809a,0x7d1b8074}},	//   _vor_, _едно, zyma, hvus,
   {{0x4444006f,0x64a61506,0xdca600ae,0x645c01ed}},	//   sk_, _нама, _нами, _wmri,
   {{0x4438404a,0x4427c04b,0xf1a9803d,0x291f80f7}},	//   _tor_, _onn_, زانه_, _crua_,
   {{0x645c2d72,0x68e2a052,0x69db8118,0x69c286a8}},	//   _umri, rrod, _edue, sboe,
   {{0x7d02c04c,0xa91d826f,0x1c020540,0x7bdc00ee}},	//   _spos, _vyža, _रॉयल_, _idru,
   {{0x4427c04d,0x81e20a49,0x7c38c04e,0x6d408d42}},	//   _ann_, ন্ত_, _sovr, tyma,
   {{0x7c388b48,0x7bce0763,0xe297b941,0x48e390ca}},	//   _povr, _kebu, _хат_, _потв,
   {{0x7e60c04f,0xb5fd85f5,0x6d409adf,0x5fd0801b}},	//   simp, više, ryma, _सजिल,
   {{0x29124050,0x7e6088de,0x60c98a0f,0x6d409adf}},	//   _asya_, pimp, _zwem, syma,
   {{0x44278357,0x7bce4051,0x78ad01c0,0x3ce901c0}},	//   _enn_, _lebu, _puav, yuav_,
   {{0xdcf783f8,0x7d028754,0x7c38807a,0x2e3781c6}},	//   _فروش_, _upos, _tovr, _מראש_,
   {{0x7bce4052,0xb905058c,0xb5fd8916,0xa8a416ba}},	//   _nebu, _पट_, riše, ерск,
   {{0x5433826a,0xabfb81c6,0x81e200ab,0xff041d1f}},	//   _سرور, _ההור, ন্ধ_, нятн,
   {{0x7d0d4053,0xb5fd811a,0xf8bf00e7,0xa49b026b}},	//   twas, piše, ppé_, _asòp,
   {{0x59c30327,0x7bce4054,0x3a290359,0xdcef01a9}},	// [2a70] _व्यर, _bebu, _inap_, _izcī,
   {{0xfbab0196,0x81e200c8,0x200a4055,0x6609c056}},	//   стай_, ন্দ_, cebi_, zeek,
   {{0x7529012b,0x64451cdf,0x3d0e9344,0x3a29290e}},	//   _šezd, rkhi, _तैसे_, _knap_,
   {{0xdb15026f,0xfd1f001c,0xdb1ac057,0xa3dc8ebf}},	//   _sezó, _trì_, lató, तृत_,
   {{0xe1f09e44,0xb5fb0125,0x9f5106a5,0x7e6d4058}},	//   اسم_, _fjár, pezó_, mnap,
   {{0x7bce2fc3,0xdb1ac059,0x4174803d,0x6609c05a}},	//   _gebu, nató, رانس, week,
   {{0x66098c56,0xae1eadb8,0x7bc5405b,0x3a290db1}},	//   teek, _मोहन_, mbhu, _onap_,
   {{0xda1d1d2a,0x7bdc202e,0x7e6d2637,0x7bce405c}},	//   _बोलत_, _zdru, nnap, _zebu,
   {{0x5fbf000d,0xe7ee0665,0x66099306,0xd7bf0d14}},	//   ्राल, _जाला_, reek, ्राच,
   {{0x68e48307,0x6609c05d,0x5ee58035,0xbb4595b5}},	//   áide, seek, _टिप्_, деок,
   {{0x7e6d09ff,0xe29a045e,0x3ea68118,0x212000b9}},	//   knap, жан_, _fiot_, _srih_,
   {{0xd9ff8128,0xb87b01a8,0x3a290229,0x9f580144}},	//   ोजित_, frío, _cnap_, perú_,
   {{0x7e6d405e,0xdb0a80f2,0xdb038144,0x68eb833e}},	//   dnap, _affä, _igní, nugd,
   {{0xdb1ac05f,0xe8008f1b,0xa91d816b,0x67218bcf}},	//   gató, ल्पा_, _lyžo, _krlj,
   {{0x81e58a49,0xa0a34060,0x7bce4061,0x224d8327}},	//   ব্য_, тард, _rebu, _olek_,
   {{0x7bce1a6e,0x2ca78006,0x7ae500d2,0x6721812b}},	//   _sebu, _hind_, drht, _mrlj,
   {{0x1be18074,0x7bce02f7,0x62844062,0x2bb203db}},	// [2a80] _खयाल_, _pebu, _ikio, _जलदा,
   {{0x1daa0054,0x225f8642,0x67218140,0xdb1ac063}},	//   _कलकत, _amuk_, _orlj, cató,
   {{0x38b41918,0x28e083eb,0x65c620e2,0x2ca7c064}},	//   _här_, _निहि, _обна, _mind_,
   {{0x7bce4065,0x1bf00105,0x2ca7c066,0xdb18816b}},	//   _webu, _चावल_, _lind_, _nevý,
   {{0x7bce4067,0x83fc826c,0xb17b03a6,0x644f81a9}},	//   _tebu, hiđa, lgår, īcij,
   {{0x7bdc003a,0x224dc068,0x59cc800d,0x46d20105}},	//   _udru, _elek_, ारहर, _तबाह,
   {{0x38b400f2,0x224dc069,0xb17b04e1,0x644e406a}},	//   _lär_, _flek_, ngår, _ilbi,
   {{0x44208193,0x1514a4f5,0x7e64046d,0x442a37bc}},	//   _şi_, едия, niip, _hnb_,
   {{0x38b41918,0x7c3c406b,0x6d440812,0xd8388289}},	//   _när_, _korr, nyia, _liči_,
   {{0xdb1c0aa2,0x6284004f,0x2ca78087,0x67218503}},	//   _berø, _akio, _cind_, _frlj,
   {{0x9e3c826f,0x672180fe,0x60c28d55,0x9f5e823e}},	//   _buďt, _grlj, lpom, _obté_,
   {{0x38b40884,0x81e200ab,0x2ca780f3,0x60c28035}},	//   _bär_, ন্স_, _eind_, opom,
   {{0x2ca7c06c,0xa3c0064a,0xdb1ac06d,0x644e047f}},	//   _find_, ीरा_, tató, _olbi,
   {{0x38b41918,0x7c3c406e,0x6284406f,0x75228db1}},	//   _där_, _norr, _ekio, _iroz,
   {{0xe8009880,0x9f5f07d9,0xb5fd8024,0x7522826f}},	//   ल्या_, _ürün_, liša, _hroz,
   {{0x644e011e,0x443cc070,0x7e6402c4,0x81b00300}},	//   _albi, _hov_, giip, _taɓa,
   {{0x443cc071,0xdb1ac072,0x66028077,0x60c2875f}},	// [2a90] _kov_, catò, _mbok, jpom,
   {{0x7c3c4073,0xe3b88457,0x6f05001c,0x225f806a}},	//   _corr, ncı_, _tphc, _smuk_,
   {{0x443cbf33,0x224d90f4,0x7c3c4074,0x60cd008e}},	//   _mov_, _plek_, _dorr, _hwam,
   {{0x60cd4075,0x443cc076,0x644e0808,0x442a4077}},	//   _kwam, _lov_, _elbi, _enb_,
   {{0x7c3c3dac,0xa8038214,0x6e3d0122,0x67218503}},	//   _forr, _çıkt, _iosb, _srlj,
   {{0x67218052,0x6602b154,0x7c3c4078,0x60cd21bb}},	//   _prlj, _abok, _gorr, _mwam,
   {{0x3949a393,0xddc40353,0x98bf807e,0x60cd2778}},	//   šas_, lniš, ırım_, _lwam,
   {{0x2ca7834a,0x439413cd,0x83fc82a5,0x75228bcf}},	//   _sind_, _расс, viđa, _broz,
   {{0x7522a898,0x60cd0133,0x2ca7c079,0xd7fbc07a}},	//   _croz, _nwam, _pind_, _муж_,
   {{0x660d407b,0xfc318307,0x443c946a,0x20cd407c}},	//   heak, احة_, _cov_, dži_,
   {{0x2ca79699,0x443cbebc,0x60cd407d,0xda661612}},	//   _vind_, _dov_, _awam, евни,
   {{0x23bf873c,0x2bbf8744,0xfbbf853f,0xee2e8a8e}},	//   _श्रद, _श्रा, _श्रम, _ён_,
   {{0xed4ec07e,0x7522c07f,0x1bf00076,0x6e2b8915}},	//   _со_, _groz, _चालल_, _ingb,
   {{0x6aa996a1,0xddc4135a,0x26de0024,0x653a80be}},	//   _lief, dniš, štom_, _מענד,
   {{0x44f9c080,0xdb18802a,0x6619a3b3,0xe73a1289}},	//   lè_, _devó, _kawk, чев_,
   {{0x661bc081,0xb17b0e23,0x62840c53,0x443c8069}},	//   nduk, rgår, _ukio, _zov_,
   {{0xfce32902,0x142630fe,0x60cd03c3,0x660301e5}},	// [2aa0] лото, ндам, _gwam, ыпта,
   {{0x78fb0051,0x443c81e9,0x395704de,0x7e7b0289}},	//   _צפיו, _xov_, _נשים_, čupa,
   {{0x7c3c4082,0x6d441283,0xb5fd8bcf,0x6aa9c083}},	//   _vorr, syia, ziša, _bief,
   {{0xddc40db7,0x7ae34084,0x661bacf6,0x2bb206b7}},	//   bniš, ánta, jduk, _जलवा,
   {{0xa3e9016f,0x442a4085,0x44f986c0,0x6aa986a8}},	//   _याच_, _tnb_, jè_, _dief,
   {{0x7524c086,0x98a38991,0x6e2b826b,0x10a38c9b}},	//   _šizo, гиче, _angb, гичн,
   {{0x91e6964f,0x443c81e9,0x09e6835f,0x7989c087}},	//   _пове, _rov_, _повн, _eyew,
   {{0x7522c088,0x443cc089,0xb87b408a,0x661b8bb1}},	//   _proz, _sov_, quív, gduk,
   {{0x443c81c5,0x6ecc8105,0xc8ca9f33,0x09cc8054}},	//   _pov_, _सबकु, _روان_, ारीय,
   {{0xa2b48076,0x60cd313e,0x61f62651,0x201a0019}},	//   _ईंद्, _rwam, _acyl, _napi_,
   {{0x443cc08b,0xddc4007a,0xdee381a1,0xcf1200ab}},	//   _vov_, zniš, _бохи, হমুদ_,
   {{0xb5fdc08c,0x7649c08d,0xdc3c8042,0x7522c08e}},	//   lišn, ckey, _išču, _troz,
   {{0x81a900c8,0x443cc08f,0x261981ce,0x39468019}},	//   খুন_, _tov_, _मोटी_, nyos_,
   {{0x201a4090,0xa3490032,0xb87b002a,0xb5fdc091}},	//   _capi_, _bọ́t, prím, unšv,
   {{0x45d51630,0x81b000fc,0x660d4092,0x141b81c6}},	//   ковс, _gaɓo, teak, _מוגב,
   {{0x6d1c00d4,0xddc40ee1,0x63ae019d,0x60cd4093}},	//   निंग_, tniš, _agbn, _twam,
   {{0x30a7007f,0xa8a74094,0x31351777,0xb87b008b}},	// [2ab0] _пров, _прок, _репр, nrík,
   {{0xb5fd8052,0xddc4007a,0x7989808e,0x63ba88ae}},	//   jišn, rniš, _ryew, nctn,
   {{0xb5fd803a,0x28b717ba,0xddc4012b,0xf6990dc7}},	//   dišn, _इंडि, sniš, _овој_,
   {{0x44f99c80,0x290901bc,0xd83889d1,0xb926019d}},	//   yè_, _kpaa_, _miču_, _nkwọ_,
   {{0xca749459,0x201a4095,0xdb0187f1,0x00000000}},	//   دالغ, _yapi_, nclò, --,
   {{0x6bd40c2b,0xb92601bc,0x290905ee,0x7e628176}},	//   _متفر, _akwọ_, _mpaa_, _amop,
   {{0x439415fe,0x6aa981ec,0xd838817f,0x79c980f7}},	//   _барс, _tief, _niču_, _يوسف_,
   {{0x44f986c0,0x9f4c8580,0x68fd072c,0x4ada825a}},	//   tè_, _abdó_, ktsd, _भिजव,
   {{0xb5fd8699,0x60db80b8,0x3d170072,0x81b000fc}},	//   bišn, _uvum, निटे_, _saɓo,
   {{0x44f9c096,0xd83881a1,0x26de0061,0x7bd71029}},	//   rè_, _biču_, átok_, naxu,
   {{0x201a0458,0x9f0492dc,0x3a3f86c0,0x26c101c0}},	//   _rapi_, _مولو, _koup_, _ntho_,
   {{0x201a08b3,0x44f9c097,0xa96a235b,0x216a2e8c}},	//   _sapi_, pè_, дима_, дими_,
   {{0x212400f7,0x6486807b,0x9f5801fa,0x44f98037}},	//   ímh_, gðis, rfrí_, qè_,
   {{0x66e600a9,0xed5684ae,0x3a3f92b6,0xb05b148c}},	//   кога, _још_, _loup_, spän,
   {{0xe1ff3aa8,0xfc3f0ba3,0xb5fb008b,0x17790198}},	//   mión_, _luís_, _smáa, есть_,
   {{0x80d280c8,0xe5f3002e,0x201a0010,0x224b1142}},	//   _সমস্, văţă, _wapi_, ckck_,
   {{0x201a0500,0xb87b04c3,0x28dc0d86,0xbea34098}},	// [2ac0] _tapi_, tuít, _बिटि, ратк,
   {{0xe1ff128e,0x3eab0db1,0xf1a701d0,0x224002f9}},	//   nión_, _eict_, _गणतन, _hoik_,
   {{0xb5fd805c,0x3a3f82d6,0x3e7a8ec3,0x00000000}},	//   višn, _boup_, līte_, --,
   {{0x3a3f82be,0x20058bb1,0xb87b4099,0xbebc81a9}},	//   _coup_, _abli_, buís, _brīn,
   {{0x6f088118,0x2444007b,0x99dd8176,0xc7b880fe}},	//   _spdc, _sömu_, _alňs, _lađe_,
   {{0x75360713,0xdb1c0065,0xe9f910ab,0x3ea0409a}},	//   mxyz, _kerü, _diẹ_, lmit_,
   {{0xc7b8805c,0xb5fd8390,0x7c2e409b,0xe8e0001c}},	//   _nađe_, rišn, _inbr, _ước_,
   {{0x2005826c,0xeb972c65,0x9f580144,0x5eea01d0}},	//   _ebli_, _рис_, leró_, _छिन्_,
   {{0x5ea381a8,0xdb1ac09c,0x5275c060,0x00000000}},	//   جميل, natö, _суру, --,
   {{0xe1ff409d,0xe7ee016f,0x9f580388,0x515b807c}},	//   gión_, _जागा_, neró_, _חכמו,
   {{0xad9b04be,0x3d178035,0x2252067f,0xdc3c80c3}},	//   _abúl, _बैठे_, _blyk_, _ušču,
   {{0x28b70540,0xb87b01ac,0xdb1c409e,0xacbb0036}},	//   _इंदि, prík, _heró, _brûl,
   {{0xe1ff04c3,0x81cc00ab,0xb87b016a,0x7c2e1c2b}},	//   bión_, _লাখ_, nsíg, _onbr,
   {{0xe1ff409f,0xd83882a5,0x545386cf,0x14d78158}},	//   ción_, _tiču_, _квіт, _יודל_,
   {{0x386d02fd,0x44d00063,0x3eab02f7,0x9f5801ca}},	//   đer_, eń_, _pict_, deró_,
   {{0x320f0065,0x02a4027e,0x5bcb1905,0x7c2e40a0}},	//   _úgy_, _крым, िर्व, _anbr,
   {{0xf1b98042,0x35b415da,0x9a6800f7,0x5c7511b3}},	// [2ad0] _jaše_, рбур, _جميل_, глат,
   {{0x7ae340a1,0xa5bb40a2,0x7bc582f1,0x54542f8d}},	//   ánto, _anót, _õhut, авут,
   {{0x629f047f,0xe81d80d4,0x6aad004f,0x3ea00039}},	//   _èpos, _योगा_, _kiaf, bmit_,
   {{0x201140a3,0xe45f00f2,0x3ce90353,0x798d3359}},	//   lezi_, _stöd_, prav_, _kyaw,
   {{0x26dec0a4,0xc7b80289,0x91058d15,0x6aad2b8c}},	//   _avto_, žđe_, упле, _miaf,
   {{0xe1ff02ba,0x661d04b9,0x24440106,0x764d40a5}},	//   xión_, _hask, _döms_, lkay,
   {{0x27e9817b,0x9388002e,0x8aa78088,0xead440a6}},	//   ğan_, _аста_, _арад, _вось,
   {{0x1dd30076,0x27e982bb,0x765801e2,0x442e81e0}},	//   तरित, şan_, _įvyk, _anf_,
   {{0xe1ff1727,0x798d0397,0x2a648098,0x442ec0a7}},	//   tión_, _nyaw, _търг, _bnf_,
   {{0x661d40a8,0x69d9c0a9,0x3ea000f1,0xec769619}},	//   _lask, lawe, zmit_, лпы_,
   {{0x7bd540aa,0x6aad40ab,0x25af80dd,0x9f5801e8}},	//   _mezu, _biaf, _tggl_, herò_,
   {{0xe1ff161b,0xceb2804c,0x69d9822e,0x1cb98013}},	//   sión_, _היא_, nawe, _كاتب_,
   {{0xfce58729,0x798d00b4,0xdb0e0032,0x764d40ac}},	//   _соло, _cyaw, _egbè, dkay,
   {{0x44fd40ad,0x7e698110,0x20112542,0xdb1c002a}},	//   dì_, liep, gezi_, _xeró,
   {{0xcfd880c8,0xb87b0ece,0x2d8f01ec,0x69bc064a}},	//   _সামন, tuír, ügen_, _एलपी,
   {{0x661d3f33,0x69d9c0ae,0x6e3b8365,0xe3cd00ab}},	//   _cask, jawe, njub, _লাগব,
   {{0x61e440af,0x3ea00648,0x628640b0,0x9f580388}},	// [2ae0] _idil, rmit_, moko, teró_,
   {{0x628640b1,0x09cc90be,0xdb1c0019,0x3ea040b2}},	//   loko, ार्य, _terü, smit_,
   {{0x272382bb,0x6e3bbd7b,0x661d40b3,0x91d086a7}},	//   _nın_, kjub, _fask, दरलै,
   {{0x2485c0b4,0x661d00a4,0x628640b5,0x69d9c0b6}},	//   holm_, _gask, noko, gawe,
   {{0x1ae039a1,0x186a9bf5,0x9f581e3a,0x91e39f8c}},	//   _पटकथ, нади_, peró_, соче,
   {{0x69d640b7,0x628640b8,0x7bd540b9,0x6d5b8748}},	//   _leye, hoko, _gezu, dzua,
   {{0xeb970bda,0x69d99e8b,0xdb1c0333,0x628640ba}},	//   _бир_, bawe, _veró, koko,
   {{0x660402ee,0xf1b9b8ee,0x60c4072f,0x798923b3}},	//   nfik, _paše_, _otim, żewi,
   {{0x54548e8e,0x20110c2e,0xb21b03ba,0x60c440bb}},	//   ивит, yezi_, klær, _ntim,
   {{0xf1b99f2a,0x4cc380ab,0xdb0e046d,0xe64487c0}},	//   _vaše_, _শিশু, _agbé, ılış,
   {{0x60c440bc,0x798d20a7,0x4394c0bd,0xaa591a03}},	//   _atim, _syaw, ранс, вину_,
   {{0x201ea851,0x20114045,0xe45287d2,0x628640be}},	//   _hati_, wezi_, _گفتگ, goko,
   {{0x201e9afe,0x661d40bf,0x201140c0,0x61e40114}},	//   _kati_, _rask, tezi_, _ddil,
   {{0x61e40a0b,0x661d40c1,0x201e8397,0x76428079}},	//   _edil, _sask, _jati_, _hooy,
   {{0x7bdac0c2,0x661d40c3,0x201e885c,0x201140c4}},	//   matu, _pask, _mati_, rezi_,
   {{0x201e8324,0x7642bca0,0x69d61210,0xdb188192}},	//   _lati_, _jooy, _geye, _bevö,
   {{0x201140c5,0x764d40c6,0xdb0501ec,0xdddb81d0}},	// [2af0] pezi_, rkay, schü, nouš,
   {{0x201ec0c7,0x69c0c0c8,0x44fd40c9,0x661d40ca}},	//   _nati_, _afme, rì_, _wask,
   {{0x7bd50b67,0x69d9a1bb,0x44fd40cb,0x8af902a4}},	//   _vezu, tawe, sì_, тнес_,
   {{0x7bdac0cc,0x7f3a00be,0x21290168,0x7d160428}},	//   hatu, _סערו, _krah_, bwys,
   {{0x7bdac0cd,0x201ec0ce,0xe0df40cf,0x6728c0d0}},	//   katu, _bati_, nsò_, _ardj,
   {{0xe800a8d7,0xd2d7190c,0xb3468214,0x67288b80}},	//   ल्ला_, _مغرب, _kaçı, _brdj,
   {{0xe73982da,0x201ec0d1,0x7bdac0d2,0x629b801c}},	//   тей_, _dati_, datu, _thuo,
   {{0x8aa48aca,0xddc2809a,0xb87b0317,0xa2678098}},	//   _груд, _iloś, crív, _съгл,
   {{0x7bdac0d3,0xee36827e,0x69d640d4,0xb5fd8984}},	//   fatu, рны_, _reye, lišk,
   {{0x6e3bc0d5,0x201e80f1,0x628640d6,0x44213d81}},	//   sjub, _gati_, woko, ndh_,
   {{0x44212832,0x21290397,0x628640d7,0xb5fd8984}},	//   idh_, _arah_, toko, nišk,
   {{0x201e811b,0x3cee8072,0x764281b4,0x2cae8362}},	//   _zati_, _आमचे_, _gooy, _eifd_,
   {{0x628640d8,0x7bda9611,0x443140d9,0x8e8480f7}},	//   roko, batu, _onz_, _النه,
   {{0x7bdac0da,0x9f58007b,0x25bfc0db,0x6c7980be}},	//   catu, ferð_, lcul_, _שאַפ,
   {{0x07a605d3,0x8fa61cfb,0x628640dc,0x45d61354}},	//   равн, раве, poko, ицат,
   {{0x25bf8590,0x13da80ab,0x645540dd,0x6443c0de}},	//   ncul_, _দায়, _alzi, _honi,
   {{0x6443c0df,0x660420d5,0xb4662f02,0x212923c3}},	// [2b00] _koni, rfik, акал, _grah_,
   {{0x752440e0,0x3eaf8a0f,0xe457113f,0x61fb87db}},	//   rviz, _ligt_, ажу_, _acul,
   {{0x3a200a8e,0x6443c0e1,0x44310267,0x201ec0e2}},	//   _kaip_, _moni, _dnz_, _rati_,
   {{0x201e803b,0x4421154c,0x6443946f,0xa9268e97}},	//   _sati_, adh_, _loni, идел,
   {{0x201ec0e3,0xd3788025,0x7bda8545,0x67288904}},	//   _pati_, maće_, yatu, _srdj,
   {{0xdb1c0125,0x7ee68790,0x6443c0e4,0x6aa2c0e5}},	//   _ferð, ацие, _noni, smof,
   {{0x7bdac0e6,0xdb1c0125,0xd6d784d9,0x290d8102}},	//   vatu, _gerð, аты_, _epea_,
   {{0xf53f40e7,0x7bdac0e8,0x7e7601e0,0x96348389}},	//   _igår_, watu, nnyp, сниц,
   {{0x7bdac0e9,0xd90e8bca,0xdd978ca4,0xd49a8256}},	//   tatu, _آیت_, ишь_, кро_,
   {{0x656fc0ea,0x7642885a,0x320902c4,0x6443c0eb}},	//   úcha, _wooy, _sbay_, _coni,
   {{0xc5e880c8,0x0bb70051,0x6f09009a,0xc7b8817f}},	//   ক্ষা_, ילים_, łecz, _gađa_,
   {{0x7bdac0ec,0x3ced8082,0xd3789487,0xaa6740ed}},	//   satu, brev_, jaće_, рток,
   {{0x7bdac0ee,0xdfdb0098,0x6443c0ef,0xd37880ce}},	//   patu, къв_, _foni, daće_,
   {{0x27ed0352,0x6443c0f0,0x588701e2,0xf1b9c0f1}},	//   ßen_, _goni, рыма, _maša_,
   {{0x80d881ce,0x09d780ab,0xe0df3cc3,0x27ed02d0}},	//   _नौसे, _হাসা, ssò_, ğen_,
   {{0xb5fd8110,0x27ed0214,0xe65400e8,0x443e8106}},	//   višk, şen_, овсь, ljt_,
   {{0xf1b9c0f2,0x69dd40f3,0xc7b80289,0x656d81ac}},	// [2b10] _naša_, mase, žđa_, _ľahk,
   {{0x69dd40f4,0x57f505f1,0xa802899b,0x2a690282}},	//   lase, _упот, çıla, _hmab_,
   {{0x94a803a7,0xd3788b67,0xbebc81a9,0x442103ed}},	//   ртта_, baće_, _drīk, rdh_,
   {{0xdb1c07ca,0x69dd40f5,0xb5fd8984,0xc7b882a5}},	//   _verð, nase, rišk, _rađa_,
   {{0x634a8201,0xb5fd8110,0x645a8079,0xe4a703a7}},	//   lənd, sišk, khti, _врво,
   {{0x69dd40f6,0x89348065,0xe2d90065,0xb87b1ee8}},	//   hase, تعما, _مارچ_, crít,
   {{0x81e200c8,0x69dd40f7,0x6d4d0def,0xb92081bc}},	//   ন্ট_, kase, lyaa, _karị_,
   {{0x6443c0f8,0x80b800c8,0x69dd40f9,0xb920819d}},	//   _soni, _অবস্, jase, _jarị_,
   {{0x6d4d40fa,0x6443c0fb,0xb5fd8e63,0x25bf8087}},	//   nyaa, _poni, niši, rcul_,
   {{0x25bfc0fc,0xd37885a2,0x799b8300,0x628d40fd}},	//   scul_, zaće_, _izuw, _akao,
   {{0xd7958013,0x3a2003ac,0x6443c0fe,0x7e6d40ff}},	//   _الاخ, _paip_, _voni, kiap,
   {{0xc0494100,0x64438613,0x69dd4101,0x42561878}},	//   _אז_, _woni, gase, стот,
   {{0xd3788024,0xa3d74102,0x2f01c103,0x2ba7016f}},	//   vaće_, सरा_, lóg_, केता,
   {{0x645ac104,0x29022376,0x7bd8910f,0x10a6002e}},	//   chti, rtka_, _gevu, сигн,
   {{0x3a200a8e,0xd378876c,0xaa4601e5,0xdddb81b9}},	//   _taip_, taće_, _гейл, kluż,
   {{0x7bc1c105,0x765bc106,0x69c101d0,0xaac48a19}},	//   lclu, nhuy, ělec, _بتون,
   {{0xe5a32523,0xd37881dd,0x6da34107,0x3ae382d0}},	// [2b20] зити, raće_, зита, lıp_,
   {{0xf1b981f4,0xd3788390,0xb87b2272,0xb3d58264}},	//   _raša_, saće_, rsíc, _দাঁড়,
   {{0x3ce01031,0xf1b9979d,0x68e4013c,0x6d4d0d92}},	//   ssiv_, _saša_, _hvid, ayaa,
   {{0xeb9702c7,0xe8040105,0xddcd0087,0xb5fd8115}},	//   щих_, श्रा_, rnaţ, biši,
   {{0xcfcf80c8,0xaca40135,0x7bc194a2,0xdd920c2a}},	//   _রাজন, _anụr, kclu, _روس_,
   {{0xf1b9c108,0x3ae382d0,0x6e2408bf,0x99dd84e8}},	//   _vaša_, kıp_, ldib, _voňa,
   {{0x76460110,0x7bd8c109,0x69dd410a,0x7bde410b}},	//   _koky, _revu, yase, mapu,
   {{0x6e24410c,0xdb1c016d,0x645d80f1,0xceb30039}},	//   ndib, _berö, ësin, היה_,
   {{0x7d04410d,0x764601e2,0x69dd03ca,0x7bd881a1}},	//   ntis, _moky, vase, _pevu,
   {{0x7bde103b,0xb4d6000d,0x409680f7,0xe7f28592}},	//   napu, _सबै_, _الطر, _घाटा_,
   {{0x69dd410e,0x7d04410f,0x68e40e94,0x539880e8}},	//   tase, htis, _avid, рвня_,
   {{0x645a820f,0x7d04120b,0x7ae30511,0xf363876a}},	//   shti, ktis, ánti, ятын,
   {{0x7bde3adf,0xd90f0077,0x6443016d,0x6d4d0079}},	//   kapu, رید_, önik, xyaa,
   {{0x80b800ab,0x634a8085,0x69dd4110,0x68e901a1}},	//   _অবশ্, tənd, sase, šedo,
   {{0xf773115f,0x6fda0ee6,0x69dd4111,0x764602c4}},	//   ساس_, _बजरं, pase, _boky,
   {{0xdceb0a21,0x8afc809a,0x7d044112,0x6e242a0f}},	//   žičk, rzęd, ftis, gdib,
   {{0x76464113,0x68e40dc1,0x26de14b5,0x68e28824}},	// [2b30] _doky, _gvid, átor_, jsod,
   {{0x7e6d1083,0xb5fd811f,0x7bde4114,0x6d4d0079}},	//   siap, riši, gapu, ryaa,
   {{0x6d4d07d5,0xb87b002a,0x6e242bca,0xb5fd8088}},	//   syaa, brír, bdib, mišv,
   {{0x09ad00c8,0x9989003a,0x200cc115,0xa3c90424}},	//   _ক্যা, _znaš_, _abdi_, ैरह_,
   {{0xab620182,0x645885b4,0x7d044116,0xe9d88a8e}},	//   _çünk, _olvi, ctis, скі_,
   {{0x3ae38214,0xd5e28032,0x7ff5803d,0x1ec98878}},	//   yıp_, _amò, زستا, алки_,
   {{0x8fa2867c,0xaad786a7,0xb87b0144,0x70b50035}},	//   маше, _भौंक, nríq, ंदुल,
   {{0x245b83d3,0x44234117,0x6e22c118,0x2f01c119}},	//   _même_, _haj_, _caob, róg_,
   {{0x4423411a,0x64470025,0x628b9f5d,0x1fa61d6a}},	//   _kaj_, _koji, mogo, _खण्ड,
   {{0x628bc11b,0xdb1c10f6,0x3d098321,0x60c9b780}},	//   logo, _verö, _वहीं_, _item,
   {{0x68e4011f,0xeb99c11c,0x64900364,0x3b099ad3}},	//   _svid, рин_, päiv, шено_,
   {{0x4423411d,0x6447411e,0x7bde01df,0xa3b58ebf}},	//   _laj_, _loji, zapu, _झलक_,
   {{0x7bde2e4d,0xe820800d,0x229c816b,0xa3a92c17}},	//   yapu, _यसमा_, níka_, खेत_,
   {{0x4423411f,0x9f5800e7,0x6e228b5d,0x660998e8}},	//   _naj_, lgré_, _zaob, lfek,
   {{0xe29a1ba8,0x61e99bba,0xa7aa4120,0xf1b98353}},	//   _как_, _odel, рква_, _našo_,
   {{0x69db8352,0x7bde04cd,0x61e9803d,0x6e242898}},	//   _neue, wapu, _ndel, udib,
   {{0x6447025b,0x7bde3097,0x0eb6000f,0x628bc121}},	// [2b40] _boji, tapu, _आंकड, dogo,
   {{0x7659831d,0x44234122,0x61e9c123,0x64474124}},	//   _llwy, _caj_, _adel, _coji,
   {{0xb7240077,0x7c238722,0x8fa628fb,0xe73a1bf5}},	//   _عکسه, _manr, _фане, _тен_,
   {{0x20180179,0x7afd8063,0x212000dd,0x6b7a80be}},	//   leri_, ństw, _ksih_, ברענ,
   {{0x44234125,0x64a602cb,0x69c284c3,0x7bde4126}},	//   _faj_, _мама, rcoe, papu,
   {{0x6e22a997,0x20184127,0x61e9c128,0x2912022e}},	//   _saob, neri_, _edel, _mpya_,
   {{0xf8bf8a0f,0x6609a0e5,0x68e2c129,0x69db81ec}},	//   _één_, ffek, ssod, _feue,
   {{0x442301e9,0x7bdc412a,0x2018412b,0xe3b8817b}},	//   _zaj_, _heru, heri_, rdım_,
   {{0x7bdc07d5,0x7c23c12c,0xd378911b,0x442301c5}},	//   _keru, _banr, daća_, _yaj_,
   {{0x2018003a,0xddc421f8,0x344a9810,0x44230069}},	//   jeri_, jniž, рчин_, _xaj_,
   {{0x7bdc1a6e,0x6e228ad0,0x64900009,0x61e9806a}},	//   _meru, _taob, läis, _ydel,
   {{0xbebc8029,0xf1b18105,0xbddb0036,0x7529811a}},	//   _brīv, ुँचन, _poèm, bvez,
   {{0x2906c12d,0x64900198,0xe53486d2,0xddcd01d0}},	//   ntoa_, näis, _хель, chař,
   {{0x2018412e,0x7bdc412f,0x7c238114,0xe3af8019}},	//   geri_, _neru, _ganr, عری_,
   {{0x64473673,0x6abc00dd,0x466b4130,0xe9f9001c}},	//   _roji, _nurf, арам_, _chả_,
   {{0x44234131,0x644704b9,0x64900009,0x7bdc4132}},	//   _saj_, _soji, käis, _aeru,
   {{0x7bdc4133,0x20184134,0x44234135,0x628b8503}},	// [2b50] _beru, beri_, _paj_, vogo,
   {{0xb5fd803a,0x20184136,0x7bdc4137,0xf1b9b99a}},	//   lišt, ceri_, _ceru, _pašo_,
   {{0x442301e9,0x628b8503,0x60c987ea,0x7bdc4138}},	//   _vaj_, togo, _stem, _deru,
   {{0x61fd1da3,0xf1b9807a,0xb87b0187,0x78bb87b8}},	//   ngsl, _vašo_, juíz, _puuv,
   {{0x44230025,0x3ea90364,0x7bdc4139,0x61fd413a}},	//   _taj_, mmat_, _feru, igsl,
   {{0x7bdc044e,0x3ea91f9f,0xb5fd807a,0x44b40098}},	//   _geru, lmat_, hišt, _обяс,
   {{0x7bc51b8f,0xa2ab8697,0x69db81ec,0x6abc0041}},	//   mchu, जगद्, _teue, _gurf,
   {{0xee399c74,0xe9df87ca,0xb5fd90d1,0x61e9c13b}},	//   сни_, _þú_, jišt, _udel,
   {{0x7bdc1d45,0x1c0b000d,0x1a68803d,0x195881bb}},	//   _yeru, स्थल_, _بینی_, _даты_,
   {{0x200100f6,0x75298065,0x3ea9287c,0x7bc5413c}},	//   _nchi_, rvez, hmat_, nchu,
   {{0xf9890159,0x7c23c13d,0x3ea9059c,0x260c11bc}},	//   _ער_, _vanr, kmat_, ड्डी_,
   {{0xc86904de,0x98a90279,0x6721817f,0x2018413e}},	//   _גן_, _drač_, _islj, weri_,
   {{0x2018413f,0x3ea90ad4,0xd378812b,0x7c23861c}},	//   teri_, dmat_, raća_, _tanr,
   {{0xb5fdbd79,0x39408198,0x2a7f82d4,0x649020c3}},	//   rišu, äisi_, _ljub_, häir,
   {{0x2bd1835a,0x7bdc11ee,0x20184140,0x43758158}},	//   _द्या, _reru, reri_, _מײַן_,
   {{0x7bdc085c,0x20010133,0x3ea94141,0x98a008ae}},	//   _seru, _echi_, gmat_, _orić_,
   {{0x7bdc4142,0x959a3d00,0x20184143,0x056638a9}},	// [2b60] _peru, ству_, peri_, чван,
   {{0xf1bf4144,0x14231b78,0xdb0e04be,0x69c608f9}},	//   ndán_, ндум, _agbá, lcke,
   {{0x7bdc4145,0x2ba704e5,0xdc9a80be,0x68f981ed}},	//   _veru, केला, ציעל, euwd,
   {{0x64900364,0xb87b01df,0x645e4146,0xfc3f01df}},	//   täis, xuíz, shpi, _xuíz_,
   {{0x7bdc03ac,0xc5f3012a,0x3a26800b,0xf91880d7}},	//   _teru, _אדר_, rdop_, تراژ_,
   {{0x7bc54147,0xb5fd8668,0x2a7fb499,0x6e26020d}},	//   cchu, zišt, _ejub_, _hakb,
   {{0x64a30be4,0x2906c148,0x98a00b80,0x63830251}},	//   _чара, stoa_, _erić_, _згра,
   {{0x44444149,0xb86680d5,0xa534c14a,0x6490414b}},	//   lj_, _کارو, днич, päis,
   {{0x444401e9,0xb5fda9c7,0xfc3f157a,0x6e26414c}},	//   oj_, višt, _ruíz_, _makb,
   {{0x4444414d,0x3ea9414e,0xfd0f81a8,0x6aa405ee}},	//   nj_, zmat_, اجي_, _ahif,
   {{0x444401c5,0x443801b0,0xb5fdaf08,0x04fe80ab}},	//   ij_, _mnr_, tišt, ্টের_,
   {{0x6aa4414f,0x7f3b8039,0x20014150,0x61e2c151}},	//   _chif, _לעבו, _schi_, naol,
   {{0xb5fd803a,0x444400ee,0x3ebe9670,0x81e180ab}},	//   rišt, kj_, _hutt_, _দাম_,
   {{0x8c438652,0xb5fd8115,0x042080ab,0x7b058198}},	//   _пече, sišt, বাহী_, öttö,
   {{0xb5fd801b,0xe9ff801c,0x6e264152,0x98a68088}},	//   pišt, _loạn_, _bakb, jvoč_,
   {{0x44444153,0x7afac154,0x6aa40d8b,0x5f9400e8}},	//   ej_, mutt, _ghif, хист,
   {{0x644ac155,0x7afac156,0x61ed33eb,0x628f01ac}},	// [2b70] _kofi, lutt, _idal, moco,
   {{0x60cd4157,0x5ba71777,0x7c2894ba,0x628f0c1d}},	//   _itam, през, nddr, loco,
   {{0x7afaab1e,0x7bc54158,0x644a8915,0x660281a1}},	//   nutt, rchu, _mofi, _ocok,
   {{0x444410af,0xe1ff4159,0x7bc5415a,0x27e3415b}},	//   aj_, ngó_, schu, lajn_,
   {{0xa95480e8,0x92b48060,0xb5fb04be,0x7afaabcb}},	//   нкці, رحما, _alág, hutt,
   {{0xf77083f8,0x7afac15c,0xe0d08591,0x644ac15d}},	//   گاه_, kutt, ازن_, _nofi,
   {{0x9ea98056,0x69c600f2,0x16a99240,0x628f415e}},	//   овка_, ycke, овки_, koco,
   {{0x7c27415f,0x61ed4160,0x7afaa234,0x2a7fc161}},	//   _hajr, _ndal, dutt, _ujub_,
   {{0x644ac162,0x68e480f7,0x3e6a803d,0x60cd31d8}},	//   _bofi, áidt, تجوی_, _ntam,
   {{0x61ed045c,0x644ac163,0x6aa44164,0x8b07928a}},	//   _adal, _cofi, _shif, _naří,
   {{0x60cd4165,0x1c020b04,0x6721856f,0x28b728bf}},	//   _atam, र्टल_, _uslj, _इंजि,
   {{0x628f002a,0x60db8a03,0x2d8e8135,0x68e9c166}},	//   goco, _kwum, ịlị_, _kved,
   {{0x752d02a5,0x660d4167,0x98a48087,0x61ed4168}},	//   jvaz, dfak, _urmă_, _ddal,
   {{0x764b8065,0x6e298ca6,0x7afabee2,0x7c274169}},	//   _hogy, ldeb, butt, _najr,
   {{0x2dcb0a2c,0x28dd8b75,0x628f416a,0x60cd36a0}},	//   _ụlọ_, नीति, boco, _etam,
   {{0x44279eb4,0x444401e9,0x661bc16b,0x96952bad}},	//   _han_, wj_, neuk, еруш,
   {{0x4427c16c,0x7c272719,0x644a8b99,0xfce30009}},	// [2b80] _kan_, _bajr, _yofi, кото,
   {{0x444410af,0x4427c16d,0xb5fb416e,0x660d036e}},	//   uj_, _jan_, _alád, afak,
   {{0x4427c16f,0x6e264170,0x7d09c171,0xe1ff406d}},	//   _man_, _takb, htes, ciós_,
   {{0x4427c172,0x8b07801b,0x7d09c173,0xe1ff009a}},	//   _lan_, _zaří, ktes, chód_,
   {{0x09e390f8,0x44278129,0xe3e380ab,0x61e2c174}},	//   точн, _oan_, _মানব, raol,
   {{0x4427c175,0x645c048d,0xdfcf80a0,0x68e981a1}},	//   _nan_, _ulri, ليه_, _dved,
   {{0x63bc01a1,0x61e280e5,0xdde181f4,0x60dbc176}},	//   _igrn, paol, _šuša, _ewum,
   {{0x4427c177,0x27e329b4,0x661b804f,0x7afa8198}},	//   _aan_, zajn_, geuk, vutt,
   {{0x4427c178,0x628f1d64,0xe7cfbe85,0xc7b8826c}},	//   _ban_, voco, _स्वप, _lađi_,
   {{0x4427804c,0x7afac179,0x61e0816d,0x3ebe847f}},	//   _can_, tutt, _heml, _tutt_,
   {{0x4427c17a,0x764b8019,0x68e98259,0x61e0c17b}},	//   _dan_, _fogy, _zved, _keml,
   {{0xc7b8c17c,0x60c0c17d,0x7afaac2f,0x4427c17e}},	//   _nađi_, _kumm, rutt, _ean_,
   {{0x4427c17f,0x27e3012b,0xe8058e5b,0x60c0c180}},	//   _fan_, tajn_, _रामा_, _jumm,
   {{0x4427c181,0x60c0c182,0xa3dfc183,0x628f4184}},	//   _gan_, _mumm, तरण_, soco,
   {{0x764b88b3,0x27e304b7,0x2bdd0072,0x7bca82a6}},	//   _yogy, rajn_, यरसा, _iffu,
   {{0x61ed4185,0x4427c186,0x61e0c187,0xfe1480d4}},	//   _udal, _zan_, _neml, _थॉमस_,
   {{0x4427c188,0x60c0c189,0x60cd04bf,0x6e940db6}},	// [2b90] _yan_, _numm, _utam, титу,
   {{0x201c803a,0x752d418a,0x69c980f3,0x4cc800ab}},	//   jevi_, rvaz, _sfee, _লিখু,
   {{0xa3a90d38,0x68e9c18b,0xc7d60051,0xd3711e44}},	//   खें_, _sved, _אותי_, دها_,
   {{0xa4d500e8,0x3a292dae,0x7d09c18c,0xd3a4066a}},	//   _помі, _jaap_, ytes, труп,
   {{0xb5fb003e,0x7c270197,0xe6ed81ac,0xcce700f7}},	//   _vlád, _tajr, _väčš, _تسجي,
   {{0x07a5838d,0x8fa58847,0xa15801c6,0x78fc01c6}},	//   налн, нале, ובדה_, קלופ,
   {{0x4427c18d,0x3eb9418e,0x26c1418f,0x2eb591d0}},	//   _ran_, _kist_, _juho_, нсис,
   {{0x6d258dcd,0x7bcac190,0x2d990198,0x26c14191}},	//   едиз, _affu, _kyse_, _muho_,
   {{0x68e9827f,0x6fca90c5,0x3eb94192,0xe5798009}},	//   _uved, _स्कू, _mist_, язи_,
   {{0xf1b9bf13,0x3eb94193,0x201cc194,0x224d83b2}},	//   _naši_, _list_, cevi_, _hoek_,
   {{0x4427c195,0xe29a0d69,0x09ad00ab,0xdbdc81fa}},	//   _van_, зан_, _ক্লা, ráði,
   {{0x4427c196,0x7bca8c2e,0x60c0a0f8,0xc332007c}},	//   _wan_, _effu, _yumm, אוט_,
   {{0x3ead8f06,0xdb1c00f2,0xddc98029,0x4427c197}},	//   mmet_, _ifrå, cieš, _tan_,
   {{0x3eadc198,0x4427c199,0x26c1419a,0x3eb90362}},	//   lmet_, _uan_, _buho_, _aist_,
   {{0x3eb9419b,0x4ac6903e,0xa0a33941,0x66c782d0}},	//   _bist_, _रूपव, уард, _yıka,
   {{0x09da00ab,0xb5fb419c,0xe61f00e1,0x3e7a81a9}},	//   _থাকা, _aláb, _skôr_, tīti_,
   {{0x61e6419d,0x33f6183a,0xdbe2826b,0x3ead8386}},	// [2ba0] makl, ечес, _béèd, imet_,
   {{0x61e6419e,0x60c0c19f,0x3eadc1a0,0xa3df8c28}},	//   lakl, _rumm, hmet_, तरि_,
   {{0x224d8b3c,0x09d780c8,0xaca38135,0x60c0c1a1}},	//   _boek_, _হাজা, _ahịh, _summ,
   {{0x2cb8034a,0x3ead80f1,0xb34683a7,0x224d8267}},	//   _wird_, jmet_, laçõ, _coek_,
   {{0x645b0065,0x3eadc1a2,0x201cc1a3,0x601382d0}},	//   áció, dmet_, tevi_, kımı,
   {{0xeee70077,0x20c6001c,0xddc98bb6,0xd6da8c24}},	//   _تغیی, _môi_, vieš, пти_,
   {{0x442a0282,0x03a341a4,0xf093012a,0xda200105}},	//   _iab_, _биро, אנג_, _बसंत_,
   {{0x9634867c,0x442a41a5,0x60c0c1a6,0xddc981a9}},	//   тниц, _hab_, _tumm, tieš,
   {{0x06e085fc,0x644e0063,0x61e61cc9,0x442a41a7}},	//   _गौरव_, _kobi, dakl, _kab_,
   {{0x224d8613,0x545498a0,0xddc9c1a8,0x2cb8816d}},	//   _zoek_, твот, rieš, örd_,
   {{0x442a41a9,0x3ea68168,0xb346841c,0x7e640234}},	//   _mab_, _thot_, daçõ, khip,
   {{0xf1b981a1,0x2456007b,0x20c600ff,0xa75b825f}},	//   _saši_, _dæmi_, _bôi_, _מדבר,
   {{0x2bd1b0ee,0x518441aa,0x7e6409c4,0x26c141ab}},	//   _द्वा, гура, dhip, _suho_,
   {{0x442a0069,0x3eb9035f,0xb346c1ac,0x634a8085}},	//   _nab_, _sist_, gaçõ, lənm,
   {{0xf1b9c1ad,0x61f40106,0x5f95041c,0x443f0129}},	//   _vaši_, ådlö, тивт, _đu_,
   {{0x78bac1ae,0x61e60214,0x3a293e34,0x439b8039}},	//   _litv, cakl, _uaap_, _מבוג,
   {{0x442a3bde,0x3eb941af,0x8d770eca,0x442c8114}},	// [2bb0] _bab_, _vist_, رارا, odd_,
   {{0x442a41b0,0x645ac1b1,0xb3468073,0xe8058beb}},	//   _cab_, nkti, caçõ, _राधा_,
   {{0x442a01e9,0x442cb5a1,0x443c81a1,0x2d99067f}},	//   _dab_, idd_, _mnv_, _wyse_,
   {{0x7c2a83ec,0xdbe2846d,0x442a1fe7,0x6013a353}},	//   _lafr, _dééd, _eab_, zımı,
   {{0x442a3f33,0x6e3d01ec,0x26dec1b2,0x99800088}},	//   _fab_, _insb, _awto_, _kaiš_,
   {{0x644e1e86,0x61e61286,0xa3bc8fcc,0x442a41b3}},	//   _gobi, zakl, _अलग_, _gab_,
   {{0x7d0d41b4,0xddcd0087,0x81e70264,0xdb1c08f9}},	//   ltas, ciaţ, _পান_, _ngrè,
   {{0x6e2d41b5,0xb34680a9,0x442c8355,0x3eb9c1b6}},	//   ndab, zaçõ, edd_, öst_,
   {{0x3eadc1b7,0x442a41b8,0x12bd80c8,0x443cbcf6}},	//   rmet_, _yab_, _আবেদ, _bnv_,
   {{0x09e100ab,0x3eadc1b9,0x442a0069,0x61e600b9}},	//   _ভাষা, smet_, _xab_, wakl,
   {{0x6fca800f,0x61e6232c,0x764f41ba,0x601382bb}},	//   _स्टू, takl, _oocy, rımı,
   {{0x27e7c1bb,0x16112774,0x7d0d4173,0x799b808e}},	//   lann_, _डॉलर_, ktas, _kyuw,
   {{0xed4e86f1,0xb3468073,0x61e641bc,0x6e2d0079}},	//   _то_, taçõ, rakl, ddab,
   {{0x27e78013,0x7d0d013c,0x38a4016d,0xfaf880eb}},	//   nann_, dtas, föra_, brī_,
   {{0x644e2201,0x442a41bd,0xb3468073,0x6b66a5b9}},	//   _robi, _rab_, raçõ, _végé,
   {{0x442a01e9,0x20c60104,0x644e41be,0x27e7ae85}},	//   _sab_, _tôi_, _sobi, hann_,
   {{0xd0408086,0x442a10af,0x6e2ba705,0x644e1188}},	// [2bc0] _etmə, _pab_, _magb, _pobi,
   {{0x442a01e9,0x61e42c9f,0x644e02f7,0x6e2b84be}},	//   _qab_, _heil, _qobi, _lagb,
   {{0x2c138c28,0x442a41bf,0xbddb3dc9,0x27e7c1c0}},	//   त्यं_, _vab_, _poèt, dann_,
   {{0x6aa9c1c1,0x6e2ba705,0x7afe41c2,0x60c40010}},	//   _chef, _nagb, rupt, _kuim,
   {{0x442a01e9,0x442ca0af,0xe3b88059,0x27e7c1c3}},	//   _tab_, ydd_, ndır_, fann_,
   {{0xcee919f7,0x27e7c1c4,0x442a41c5,0x644e005c}},	//   _ترین_, gann_, _uab_, _uobi,
   {{0x8a069c74,0xb8c98fd5,0x7c2ac1c6,0xa7fc8457}},	//   _изве, _गी_, _rafr, _alıc,
   {{0xfaa6c1c7,0x660441c8,0x61e441c9,0x442c831d}},	//   _рабо, ngik, _neil, wdd_,
   {{0xd3788067,0x27e7c1ca,0x47e180ab,0xa3d600a5}},	//   maći_, bann_, _নারী, _सभा_,
   {{0x78ba85f8,0xdb1c00e7,0x27e79a2c,0x6b9c41cb}},	//   _uitv, _agré, cann_, _kyrg,
   {{0x6fd8873c,0x442c8355,0x68ed0b48,0x7d0d3193}},	//   _न्यू, rdd_, _svad, ztas,
   {{0xd3788a20,0x6f798158,0x6282c1cc,0x7d0d41cd}},	//   naći_, _אָנג, nnoo, ytas,
   {{0x61e441ce,0x60c40ad0,0x94030105,0x6e20c1cf}},	//   _deil, _cuim, _लालच_, memb,
   {{0x6e20a015,0x58d4229c,0xa2cac1d0,0x645d8168}},	//   lemb, рорт, _संप्, ësit,
   {{0x7e62c1d1,0x61e441d2,0x260f8701,0x8c1b8039}},	//   _klop, _feil, थ्वी_, _חווי,
   {{0x6e20c1d3,0x60c441d4,0x7d0d0e20,0x61e441d5}},	//   nemb, _fuim, ttas, _geil,
   {{0xa5070009,0x3944016d,0x7d00c1d6,0x16df9513}},	// [2bd0] ъявл, ämst_, nums, _नब्ब,
   {{0x7d0d41d7,0xbbdd0540,0x6e209ba4,0x61e40f67}},	//   rtas, यरेक, hemb, _zeil,
   {{0x27e7c1d8,0xddc6009a,0x3946802a,0x7d008088}},	//   vann_, _dokł, exos_, hums,
   {{0x6e20c1d9,0x27e7c1da,0x628287b8,0x625396f0}},	//   jemb, wann_, gnoo, _açor,
   {{0x7d00c1db,0x6e208365,0x27e7c1dc,0x6f1a8118}},	//   jums, demb, tann_, _aptc,
   {{0x6e2bc1dd,0xfa2380ab,0x628281b4,0xaa20050a}},	//   _sagb, ফাইল_, anoo, _बस्छ_,
   {{0x6e2bacb7,0x27e7c1de,0x4421195a,0x12bd80ab}},	//   _pagb, rann_, meh_, _আব্দ,
   {{0x44210fc7,0x27e7c1df,0xddcd0029,0x05a70b75}},	//   leh_, sann_, skaņ, _खराब,
   {{0x27e7c1e0,0x61e441e1,0xf1b980eb,0x3a3f8122}},	//   pann_, _reil, _pašu_, _inup_,
   {{0x442141e2,0x60c405f8,0xe9f9001c,0x61e42e29}},	//   neh_, _ruim, _thẻ_, _seil,
   {{0x6e2bc1e3,0x91e61da6,0x60c40cdd,0x21292c30}},	//   _tagb, лоне, _suim, _asah_,
   {{0x442141e4,0xcd358416,0x7d00c1e5,0x940389ab}},	//   heh_, _مرتب, bums, ƙƙoƙ,
   {{0x61e441e6,0x645d820f,0x4421085c,0x290f839c}},	//   _veil, ësis, keh_, ntga_,
   {{0xe3b882bb,0x4421120e,0x26c5c1e7,0x61e441e8}},	//   rdır_, jeh_, _kulo_, _weil,
   {{0x61e441e9,0x91e38074,0x212900b9,0xf1b980c3}},	//   _teil, खराज_, _esah_, _zašt_,
   {{0xa2060fdd,0x26c5c1ea,0x752441eb,0x7874011c}},	//   _спид, _mulo_, twiz, _müvə,
   {{0x0eb90b71,0x96b909c7,0xe9f9001c,0x22400242}},	// [2be0] туры_, туру_, _nhẹ_, _inik_,
   {{0x6e20c1ec,0x290241ed,0x442141ee,0x75240db1}},	//   zemb, muka_, geh_, rwiz,
   {{0x7d00c1ef,0x6e20c1f0,0xd37884a8,0xb17d80e1}},	//   zums, yemb, taći_, _reťa,
   {{0x1efb03c8,0x26d841f1,0x1c1383eb,0x2c13808e}},	//   _אלטע, mpro_, त्तल_, त्तं_,
   {{0x290241f2,0x6282bcbc,0x44210077,0xb87b041c}},	//   nuka_, rnoo, beh_, rsív,
   {{0x3cf98063,0xb87b00a9,0x3ea041f3,0x66c787d9}},	//   ोंने_, ssív, llit_, _tıkl,
   {{0x6e208980,0x26c5c1f4,0xe8162b07,0x290200b4}},	//   temb, _culo_, द्या_, huka_,
   {{0x7c2e41f5,0xe3c1080a,0x26c5820d,0x290241f6}},	//   _habr, ğış_, _dulo_, kuka_,
   {{0x6e20c1f7,0x5986b4ad,0x634a8201,0x7c2e41f8}},	//   remb, _слаб, məni, _kabr,
   {{0x634a8085,0x7ea58019,0x3e7a80eb,0xd91b807c}},	//   ləni, rópa, tīts_, _אומל,
   {{0x6e20c1f9,0x7d00c1fa,0x7c2e1b51,0x3ea041fb}},	//   pemb, sums, _mabr, klit_,
   {{0x7c2e41fc,0xfce6c1a4,0x290241fd,0xa2950221}},	//   _labr, _бодо, fuka_, рамі,
   {{0x6e938624,0xf1b9826c,0x442141fe,0x667b80be}},	//   _النا, _hašr_, yeh_, _אטאק,
   {{0x2240026c,0xe1ff0333,0x36d50eef,0x6d468198}},	//   _enik_, chón_, иогр, äkau,
   {{0xe7f7946d,0x395f0bb6,0x442e816d,0x2bda801b}},	//   ीलता_, šus_, _iaf_, _म्या,
   {{0x3ea041ff,0x44212793,0x442ec200,0xf8bf0036}},	//   glit_, weh_, _haf_, uvés_,
   {{0x3cee0063,0x2129078a,0xf8bf02be,0x44214201}},	// [2bf0] ेंगे_, _usah_, rvés_, teh_,
   {{0x442ec202,0x225d861b,0xb5fb0511,0x35b43eb9}},	//   _jaf_, wkwk_, _glán, сбур,
   {{0x2baa035a,0x9f4780f1,0x44214203,0x69dd02c4}},	//   _करणा, ranë_, reh_, obse,
   {{0x44214204,0x60cd9986,0x27e588ae,0x644806c0}},	//   seh_, íamo, _seln_, _òdin,
   {{0x7c2e4205,0x44214206,0xd378812b,0xa5bb1e31}},	//   _fabr, peh_, maću_, _caót,
   {{0x46f5a457,0x442ec207,0x3f9e826f,0x26c5c208}},	//   ачит, _naf_, _bytu_, _pulo_,
   {{0xf771936d,0x36698dc7,0xe7e6016f,0x29024209}},	//   غات_, како_, करता_, zuka_,
   {{0xee398be2,0x7c2e1620,0xbb840013,0x7c21c20a}},	//   тни_, _zabr, _الفي, welr,
   {{0x81eb00ab,0x656d420b,0x9f43001b,0x98b9c1a4}},	//   মলা_, nzah, dají_, _алат_,
   {{0x9f6b8021,0x26c5c20c,0x5c559c56,0xd3788858}},	//   _през_, _tulo_, ртиф, haću_,
   {{0x9f47c20d,0x290201d3,0x6aad0706,0x68fd000b}},	//   kané_, wuka_, _bhaf, ersd,
   {{0x61eb8c27,0x6f03b5a3,0x6aad420e,0x2902420f}},	//   nagl, munc, _chaf, tuka_,
   {{0x9f47c210,0x6f03c211,0xb5fb003e,0xaca3819d}},	//   dané_, lunc, _plán, _agụk,
   {{0x29024212,0x442ec213,0x61eb948c,0x2007c214}},	//   ruka_, _gaf_, hagl, ngni_,
   {{0x6f03a68e,0xfaa62150,0x66e64215,0x29024216}},	//   nunc, _како, роба, suka_,
   {{0x22404217,0xdbdf0125,0x7afcc218,0x2902004f}},	//   _unik_, _síðu, árte, puka_,

   {{0x6d5b81c5,0x7c2e4219,0x3ea0007b,0x69c426e8}},	// [2c00] nyua, _pabr, rlit_, _igie,
   {{0xa7fc82bb,0x6f03c21a,0x3ea0421b,0x2baa02f1}},	//   _alın, kunc, slit_, _करदा,
   {{0x6287003e,0x9f47c21c,0xf1a900d7,0x6d5b808e}},	//   čkov, bané_, _لایه_, hyua,
   {{0xeb972d3a,0x2c64016d,0x62864004,0x6f038bcf}},	//   ших_, _döda_, nnko, dunc,
   {{0x7c2e421d,0x7bc38081,0xb17d80e1,0x6d5b81c0}},	//   _tabr, _ognu, _deťo, jyua,
   {{0x7d044062,0xa073835f,0xceb40085,0x2c640106}},	//   muis, огіч, lmə_, _föda_,
   {{0x7d04421e,0x53aa06b7,0xa2ca8935,0x61eb80e5}},	//   luis, _करिश, _संध्, bagl,
   {{0xa2cb09c8,0x62898168,0x2bd21130,0x61ebc21f}},	//   _तंत्, _gjeo, दुरा, cagl,
   {{0x9f43001b,0x7d044220,0x6d5b81c0,0xbebc81a9}},	//   vají_, nuis, gyua, _krīz,
   {{0x62864221,0x442ec222,0x9f479c32,0xb806803d}},	//   enko, _qaf_, zané_, _خبره,
   {{0xe9f90028,0x6f03c223,0x7d044224,0x9f478077}},	//   _chế_, cunc, huis, yané_,
   {{0xc3330051,0x7d044225,0x7e69c226,0x442ec227}},	//   קור_, kuis, chep, _waf_,
   {{0x9f478a56,0x442e9ad9,0x7d044228,0x61f6031d}},	//   vané_, _taf_, juis, _ddyl,
   {{0x786201ac,0x0377804e,0x7d044229,0x251b807c}},	//   _dôvo, احیت_, duis, _סווא,
   {{0xe816035a,0x9f47c22a,0xb4c0000d,0xe9f9001c}},	//   द्धा_, tané_, ँदै_, _ghế_,
   {{0x798d10af,0x2c64016d,0xdce60214,0x5f94422b}},	//   _txaw, _röda_, _aykı, цист,
   {{0x7d04422c,0x764d1cdf,0x9f47c22d,0xd90482e3}},	// [2c10] guis, rjay, rané_, _تی_,
   {{0xe8160778,0x9f47c22d,0xea00001c,0x98650065}},	//   द्दा_, sané_, _trải_, _ایسے_,
   {{0x61ebc22e,0x9f47c20d,0x5b15148d,0x656d0192}},	//   tagl, pané_, смет, szah,
   {{0x09bb00c8,0x7d04422f,0xe8f580f7,0xdddb826c}},	//   _অ্যা, buis, مستخ, knuš,
   {{0xe1f88048,0x3cfe0063,0x200c8a03,0x7e7b80c3}},	//   ргі_, _लिये_, _bcdi_, viup,
   {{0x6f039e8a,0xf1bf0061,0x6d5b81c0,0x26d984e8}},	//   tunc, ldás_, vyua, _čsob_,
   {{0xda3597ae,0x61eb809c,0xb5fb0388,0x7e7b80dd}},	//   _левы, pagl, _llám, tiup,
   {{0x44314230,0x7ea58118,0x6d498102,0x6f03c231}},	//   _haz_, rópo, txea, runc,
   {{0xee36827e,0x44314232,0x2aff0054,0x7ea5c233}},	//   сны_, _kaz_, शंकु_, sópo,
   {{0x44310db7,0x3c658364,0xb4658364,0x629982ec}},	//   _jaz_, ског, скол, lowo,
   {{0x64554234,0x61e98006,0x6d5bc235,0x20128085}},	//   _mozi, _keel, syua, əyi_,
   {{0x6455003a,0x99808038,0x786201ac,0x60c1c236}},	//   _lozi, žiť_, _pôvo, _hilm,
   {{0x61e9c237,0xf6528039,0x61e4a37b,0xd54892c5}},	//   _meel, _מצא_, ðili, _نجوم_,
   {{0xe9f90104,0x1c030665,0x753680be,0x64554238}},	//   _thế_, _लागल_, _לאנד_, _nozi,
   {{0x4425c239,0x6443c23a,0x6299c23b,0xceb40085}},	//   mel_, _inni, kowo, tmə_,
   {{0x6609c23c,0x9f4583fb,0x7d0404fa,0xcf9283de}},	//   ngek, _celé_, tuis, פטן_,
   {{0x6299c23d,0x4431423e,0x75298a0f,0x6e24423f}},	// [2c20] dowo, _baz_, nwez, reib,
   {{0x64550073,0x44314240,0x2292016b,0xa3ab8576}},	//   _cozi, _caz_, váky_, _खरा_,
   {{0x61e98c11,0x64553ea9,0x291f8009,0xddcb8035}},	//   _beel, _dozi, _apua_, _mogł,
   {{0x4425c241,0x61e98079,0x2018213c,0x2292016b}},	//   hel_, _ceel, lfri_, táky_,
   {{0x4425c242,0x60c19010,0x61e98b3c,0x44314243}},	//   kel_, _bilm, _deel, _faz_,
   {{0xd2598029,0xbb460b88,0xd90d80d5,0x38a9c244}},	//   _viņa_, _легк, ئیل_, túra_,
   {{0xe80e8e18,0x26c24245,0x60c1c246,0xf1bf00e1}},	//   _साठा_, _kiko_, _dilm, ndár_,
   {{0x4425838e,0x61e9ab3b,0x6299809a,0x6609836c}},	//   eel_, _geel, cowo, ggek,
   {{0x4425c247,0x64550db1,0x443103bf,0x89669821}},	//   fel_, _yozi, _yaz_, _укаж,
   {{0xddc28efc,0x61e9c248,0x26c24249,0xe8d781c6}},	//   _umož, _zeel, _liko_, _לומר_,
   {{0x61e982a3,0xfd0f80d5,0xb4db0722,0xf743c24a}},	//   _yeel, وجی_, _gràf, _нефо,
   {{0x32670dea,0x6443c24b,0x2120008e,0x466980e8}},	//   стов, _enni, _bpih_, _крім_,
   {{0x9f45c24c,0x4425c24d,0xb5fb0118,0x201801b9}},	//   _relé_, bel_, _imáx, ffri_,
   {{0x4425c24e,0x26c20041,0x27ee808b,0x2e3501bc}},	//   cel_, _aiko_, nafn_, _ụf_,
   {{0x44312201,0x27ff0182,0x26c20870,0xeac9801c}},	//   _raz_, ğun_, _biko_, _hẹn_,
   {{0x6455424f,0x26c24250,0xea00001c,0xf1ba97ba}},	//   _sozi, _ciko_, _trại_, ेशान,
   {{0x54552c60,0x443110dd,0x26c202d5,0xa7fc82d0}},	// [2c30] оват, _paz_, _diko_, _alım,
   {{0x2a690282,0x61e9c251,0x44310085,0x61ef117d}},	//   _hlab_, _seel, _qaz_, lacl,
   {{0x64551874,0x94a80698,0x50d40065,0x212b031d}},	//   _vozi, стта_, _وزیر, lwch_,
   {{0x4425c252,0x60c1843d,0x61ef4253,0xdb0e0091}},	//   zel_, _silm, nacl, _agbó,
   {{0x6299b94f,0x60c985a4,0x44314254,0xe3e800c8}},	//   rowo, _quem, _taz_, _পারব,
   {{0x212d8353,0x60c1a828,0x81e180ab,0x6299c255}},	//   _vseh_, _qilm, _দাও_, sowo,
   {{0x4425c256,0x2bdf1a8f,0x786b07d9,0xb8d0873c}},	//   vel_, _प्या, _güve, _टी_,
   {{0x442585ad,0x0f7c0039,0xd04d00fc,0x826589c4}},	//   wel_, טרול, _kwaɓ, _بهرن,
   {{0x60c1c257,0x4425c258,0x61ef0118,0x6609b7cc}},	//   _tilm, tel_, dacl, rgek,
   {{0x66099591,0x2a6900e4,0x212b0114,0x752981ed}},	//   sgek, _alab_, dwch_, rwez,
   {{0x2dd5b921,0x4425c259,0x2a6900c3,0x7e6d425a}},	//   _джер, rel_, _blab_, khap,
   {{0x4425c25b,0x753d0065,0xd6ab8591,0x9f47abd3}},	//   sel_, _orsz, _صدام_, naní_,
   {{0xa4f7826a,0x26c2425c,0x7e6d1abb,0x212b0428}},	//   _اکبر_, _riko_, dhap, gwch_,
   {{0x6443807b,0x8c4581a1,0x26c2425d,0x2a6902f1}},	//   _unni, _феке, _siko_, _elab_,
   {{0x81ea80ab,0x18a301e2,0xa0a33eb9,0xe81b8072}},	//   _মাস_, фарм, фард, प्या_,
   {{0x2a6902c4,0x8afc8035,0x00ca425e,0xf1bf0118}},	//   _glab_, rzęt, _клик_, meán_,
   {{0x63a3831d,0xf1bf00f7,0xec7a0615,0x9f47abd3}},	// [2c40] _hynn, leán_, апа_, daní_,
   {{0x63a3c25f,0x67218024,0x0c230198,0x3e6702f1}},	//   _kynn, _oplj, ммун, _võta_,
   {{0x49ca9354,0xeac9801c,0xa5bb026b,0xdb0e0032}},	//   ален_, _mẹo_, _abód, _agbò,
   {{0x7e6d4260,0xe81600c2,0x63a3c261,0xa3d602f1}},	//   chap, द्रा_, _mynn, _सभक_,
   {{0x2ba6864a,0xb4db0706,0xdfd48a41,0xb5fd81d6}},	//   _ऑर्थ, _cràd, полы, chši,
   {{0x6e360110,0x3a26808e,0x29020df6,0x00000000}},	//   ldyb, seop_, irka_, --,
   {{0xed508019,0xdb0e046d,0x42d60a18,0x03a335aa}},	//   کھا_, _egbò, _фігу, _жиро,
   {{0x6e364262,0x63ae026c,0x6722026c,0xf1bf00f7}},	//   ndyb, _izbn, _ćojl, deán_,
   {{0xceb304de,0xddc2809a,0xd25980eb,0xd00a84ae}},	//   ויה_, _umoż, _ziņo_, _везе_,
   {{0x31e3016f,0x09e30d14,0x0bf38009,0x63a38114}},	//   पर्ध, पर्य, мпью, _bynn,
   {{0x2a690069,0x63a38355,0x61ef4263,0x20d0801c}},	//   _plab_, _cynn, tacl, _hài_,
   {{0x61e2c264,0xb5fb03c1,0x212b0114,0x63b5816b}},	//   nbol, _vlák, twch_, ýzna,
   {{0xa2ca85b3,0x26ccc265,0x17e200ab,0x61ef286f}},	//   _सूर्, _hudo_, _বাড়ি, racl,
   {{0x80dd00c8,0x26cc8168,0x212b0114,0x61ef00e5}},	//   _বিদ্, _kudo_, rwch_, sacl,
   {{0x63a38355,0x61e2c266,0x8f343f21,0x29024267}},	//   _gynn, kbol, мерц, arka_,
   {{0x26cc81b4,0xfb8780d7,0x6458b5aa,0x60dd2130}},	//   _mudo_, _بدهی, _hovi, ppsm,
   {{0x9f479ded,0x61e2813c,0x6458c268,0x7e6d4164}},	// [2c50] vaní_, dbol, _kovi, rhap,
   {{0x64588390,0x97152f36,0x61ed1357,0x7e6d4269}},	//   _jovi, _емоц, _heal, shap,
   {{0x6458c26a,0xd498426b,0x8c2580c8,0x7e6d426c}},	//   _movi, іру_, বাচন_, phap,
   {{0x20d08142,0x7c288358,0x6458c26d,0x61e2c26e}},	//   _bài_, hedr, _lovi, gbol,
   {{0xdd868307,0x20d08028,0xcfbd00ab,0x9f47826f}},	//   _أو_, _cài_, _অভিন, raní_,
   {{0x20d08028,0x61ed426f,0x55ba0039,0x26ccc270}},	//   _dài_, _leal, _למרו, _budo_,
   {{0x61e2c271,0x26cc8699,0xdb0385b9,0x752d4272}},	//   bbol, _cudo_, _ozná, lwaz,
   {{0x660d4273,0x29024274,0x26cc8216,0x69db15c7}},	//   ngak, yrka_, _dudo_, ñuel,
   {{0x7c28c275,0xd840026f,0x63a3c276,0xb5fb00f7}},	//   fedr, íčky_, _synn, _clái,
   {{0x7c28c277,0x26cc88ec,0x60db8d57,0x68e981bc}},	//   gedr, _fudo_, _itum, _iwed,
   {{0x61ed17ca,0x628b8010,0x7c354278,0x6458c279}},	//   _beal, ongo, _mazr, _dovi,
   {{0x752d427a,0x213f8988,0xf1bf00f7,0x61ed0ae3}},	//   kwaz, _kruh_, reán_, _ceal,
   {{0x7c28c27b,0xf1bf00f7,0x752d1118,0x20d080ff}},	//   bedr, seán_, jwaz, _xài_,
   {{0x60db822e,0x7d09c27c,0x653a80be,0x7c35427d}},	//   _mtum, mues, _לענד, _nazr,
   {{0x629d28bd,0x69c99e6e,0xa7aa1269,0x61ed427e}},	//   boso, _ogee, сква_, _feal,
   {{0x64470057,0x61ed0083,0x6458817f,0xc6c33a46}},	//   _anji, _geal, _zovi, ейск,
   {{0x2bd2a0c0,0xf1bf00f7,0x60cd00ee,0x7d098168}},	// [2c60] _सलमा, neál_, _guam, nues,
   {{0x7e64427f,0x39404280,0x69c99a1a,0x673e05f3}},	//   skip, _iris_, _agee, _trpj,
   {{0xe8059039,0x6d4b016d,0xf8b30039,0x60dbc281}},	//   _राजा_, ägar, _רשת_, _atum,
   {{0x39404282,0x64474283,0xf53f021e,0x7659809a}},	//   _kris_, _enji, _frå_, _nowy,
   {{0x7c3500b9,0xf53f01a3,0x463b00be,0xb5fb0091}},	//   _fazr, _grå_, _העכע, _aláw,
   {{0xb8f4a402,0x26cc85a4,0x61e2afc7,0x20d0801c}},	//   _सं_, _pudo_, sbol, _vài_,
   {{0x7c28c284,0x7522a01b,0xb5fb00f7,0x91e6c285}},	//   vedr, _spoz, _slái, _нове,
   {{0x20d08104,0x80dd00c8,0x39400091,0xfaa380e8}},	//   _tài_, _বিস্, _oris_, _засо,
   {{0x6458c286,0x2ab20019,0x394001c0,0x68e98114}},	//   _povi, kább_, _nris_, _gwed,
   {{0x26cc80a9,0x7d044287,0xf044826a,0x6282c288}},	//   _tudo_, iris, _تعری, lioo,
   {{0x61ed0665,0x60cd0867,0xe61a8f2f,0x7c288082}},	//   _peal, _suam, _где_, redr,
   {{0x7d044289,0xe81f052a,0xaf4980f7,0xcf2580f7}},	//   kris, म्ना_, _بشكل_, _تركي,
   {{0x8c469232,0x7d098693,0xb5fb027f,0xf487881b}},	//   _неде, cues, _kláv, _کانی,
   {{0x629d428a,0x7d04428b,0x61e0007e,0x80e18264}},	//   soso, dris, ımla, _নিম্,
   {{0xda0d823c,0x25afc28c,0x60c502f1,0x628b8428}},	//   _हालत_, _zzgl_, _vihm, yngo,
   {{0x443f07d9,0x752d428d,0x7d04428e,0x7c350289}},	//   _şu_, twaz, fris, _sazr,
   {{0xe7cc8076,0x224901ac,0x660d428f,0xba3b0cd1}},	// [2c70] ाशाप, _inak_, rgak, roïd,
   {{0x628b8114,0x29194290,0xb4db2641,0xdfd101a8}},	//   wngo, mtsa_, _aràc, _جيد_,
   {{0xaac70c48,0x7d044291,0x290b4292,0x752d4293}},	//   ستان, aris, luca_, swaz,
   {{0x7d044294,0xe3b00013,0x7d180013,0x68e9809c}},	//   bris, ارك_, éasá, _pwed,
   {{0x6e29c295,0xaca481bc,0x9f47826f,0x29194296}},	//   veeb, _agọz, daná_, ntsa_,
   {{0x3ea94297,0xf9940158,0xad9b0032,0x8fa58323}},	//   llat_, ערס_, _adúg, мале,
   {{0xe80e83db,0xb8f48e5b,0x12c780ab,0x7659aa6d}},	//   _सारा_, _सू_, _শব্দ, _powy,
   {{0xd87783f8,0xb4db07e2,0x7d0980f1,0x645cc298}},	//   _کارب, _gràc, tues, örin,
   {{0x60db822e,0x63a70168,0x6e2991c9,0x290b4299}},	//   _utum, _hyjn, reeb, juca_,
   {{0x22491397,0x7d0980f1,0x2a6dc29a,0x78700198}},	//   _anak_, rues, _hleb_, _käve,
   {{0x6ee7c29b,0x2ab20065,0x3ea90587,0x7d0980f1}},	//   _رسال, vább_, klat_, sues,
   {{0x39401da3,0x7d099220,0x38a402af,0x7d04007b}},	//   _pris_, pues, hört_, yris,
   {{0x7d09c29c,0x3ea9429d,0x66c782d0,0xbbaa0bbc}},	//   ques, dlat_, _fıkr, _कर्क,
   {{0x80dd0a49,0x2249429e,0x638585c2,0x3e83846d}},	//   _বিশ্, _enak_, _огла, _fètè_,
   {{0x07a30a13,0xb8d50006,0xc79517ae,0xe29f007b}},	//   варн, _छी_, ерты, boð_,
   {{0xe1ff1e51,0x38a4008b,0xecea24c7,0xe05800d7}},	//   lkón_, vöru_, ждал_, _کیست_,
   {{0x32d38028,0x14c80077,0xe80e81ab,0x38a40106}},	// [2c80] _hãy_, سهای_, _साला_, fört_,
   {{0x26cc1313,0x81ea8264,0x9f479f1c,0xa2e6062c}},	//   ídos_, _মাই_, zaná_, дожд,
   {{0x3ea9429f,0xb4db009f,0x98a90669,0x3e7a81a9}},	//   blat_, _pràc, _građ_, sūti_,
   {{0x41aa8f80,0xb5fb0a21,0x7d0410b6,0xaca4019d}},	//   овен_, _sláv, pris, _inọr,
   {{0x9f47803e,0x20d40406,0xb5fb42a0,0x62828074}},	//   vaná_, _jäi_, _cláu, rioo,
   {{0xd6dac2a1,0x62828006,0xbddb010c,0xa3c80576}},	//   оти_, sioo, _anèh, _उलट_,
   {{0x443842a2,0xdca31cae,0x9f47b721,0x645c42a3}},	//   _iar_, _рари, taná_, _iori,
   {{0x443842a4,0x645c42a5,0xa3c390c5,0x1d3488cc}},	//   _har_, _hori, ्शन_, ения,
   {{0x645c003a,0x44382588,0x64c895fb,0x9f47c2a6}},	//   _kori, _kar_, रदेश, raná_,
   {{0x645c42a7,0x628081c0,0x83868071,0x6aa442a8}},	//   _jori, _hmmo, дыме, _akif,
   {{0x645c42a9,0xd37a80e8,0x443810b6,0x9f47c2aa}},	//   _mori, ючи_, _mar_, paná_,
   {{0xaacf853f,0x6ab6031d,0x05668012,0x32d38129}},	//   _संरक, _chyf, _овен, _dãy_,
   {{0x3ea942ab,0xa2ca800c,0xaca401bc,0x7c3e8118}},	//   vlat_, _संक्, _anọr, _ópro,
   {{0x645c1c3a,0xb9072e04,0x443842ac,0xdbf3080a}},	//   _nori, _पऽ_, _nar_, _işçi,
   {{0xc05805e9,0x442ca482,0x25ad1fd8,0xd8388503}},	//   фія_, med_, _šel_, _mač_,
   {{0x442cc2ad,0x7c38c2ae,0x3ea942af,0x60c8c2b0}},	//   led_, _havr, ulat_, _lidm,
   {{0x67d539df,0x442c8114,0x443801c6,0x7c3882d0}},	// [2c90] _попу, oed_, _bar_, _kavr,
   {{0x6280c2b1,0xb5fb42b2,0x645c42b3,0x3ea9001b}},	//   _ammo, _alát, _cori, slat_,
   {{0x443842b4,0x645c42b5,0x2a6d81c0,0x7c38c2b6}},	//   _dar_, _dori, _pleb_, _mavr,
   {{0x23df08d4,0x442cc2b7,0x68ed42b8,0xdd140038}},	//   _प्रद, hed_, _kwad, _súťa,
   {{0x6025a375,0x645c42b9,0x26de8081,0x6d448110}},	//   едла, _fori, _atto_, _šian,
   {{0x3e71803e,0x442cc2ba,0x443842bb,0x7d0d010b}},	//   _máte_, jed_, _gar_, muas,
   {{0x442c804c,0x7d0d404f,0x8fa2c2bc,0x6d428cdb}},	//   ded_, luas, лаше, _aroa,
   {{0x4438003a,0xbb480077,0x9f45826f,0x645c0102}},	//   _zar_, _تلفن_, _celá_, _zori,
   {{0x645c026b,0xddc2a840,0x443842bd,0x38b60aa2}},	//   _yori, _ploš, _yar_, lære_,
   {{0xe4518013,0x765d42be,0x6aa40257,0x645c42bf}},	//   اضة_, _losy, _skif, _xori,
   {{0x7c3883bf,0x68ed42c0,0x6d42c2c1,0x09c80d72}},	//   _davr, _awad, _eroa, रख्य,
   {{0x7d0d0590,0x644ac2c2,0xdb1e81d0,0x68ed42c3}},	//   kuas, _enfi, áván, _bwad,
   {{0x764b8065,0x442342c4,0x6d428087,0x3e6e008b}},	//   _ingy, _obj_, _groa, _nýta_,
   {{0x60c88201,0x2bdf0305,0x442caeff,0xddc28d2f}},	//   _xidm, _प्ला, ced_, _uloš,
   {{0x7c2380ee,0x7d1bc2c5,0x765d010c,0x68ed42c6}},	//   _ibnr, ltus, _bosy, _ewad,
   {{0x7c3882a5,0x998d012b,0x7ea58228,0x443842c7}},	//   _zavr, žeš_, cópt, _sar_,
   {{0x443842c8,0xeb1f80cf,0x628642c9,0x645c42ca}},	// [2ca0] _par_, _बहुत_, miko, _pori,
   {{0x628642cb,0x69dbc2cc,0x7d1b8009,0x645c01b4}},	//   liko, _afue, itus, _qori,
   {{0x443842cd,0x02069c1c,0xb5fb42ce,0x645c42cf}},	//   _var_, езен, _clás, _vori,
   {{0xe29799bb,0xfce604a9,0x628642d0,0x442cc2d1}},	//   нах_, _помо, niko, zed_,
   {{0x443842d2,0xa96796d9,0x216790ca,0x645c30af}},	//   _tar_, ница_, ници_, _tori,
   {{0x9f4301ac,0x628642d3,0xdfcf80f7,0x29068102}},	//   vajú_, hiko, ميه_, rroa_,
   {{0x628642d4,0x442c8051,0x6e398420,0x7bce42d5}},	//   kiko, ved_, _bawb, _igbu,
   {{0x7c38803a,0xb65b0158,0x6d42c2d6,0x442cc2d7}},	//   _savr, ִדיש, _proa, wed_,
   {{0x442c804c,0x628642d8,0xb5fb42d9,0x2dd780f7}},	//   ted_, diko, _klár, ربية_,
   {{0x6aa280c9,0x99808110,0x9f4300e1,0x764bc2da}},	//   loof, žių_, rajú_, _engy,
   {{0x442cc2db,0x628642dc,0x141b00be,0x68ed353f}},	//   red_, fiko, הויב, _swad,
   {{0x442c8434,0x79a70c9d,0x628642dd,0x2bd28fb2}},	//   sed_, ерге, giko, _सलवा,
   {{0x442c8039,0x3ea6876d,0x7bce2e3b,0x7bdc03ed}},	//   ped_, _ikot_, _ogbu, _ofru,
   {{0x765d3cdc,0xd25980eb,0x7413803d,0x6aa29e12}},	//   _sosy, _viņi_, _موها, hoof,
   {{0x02a71b06,0x533495b5,0x62861b25,0xc90d801b}},	//   _прим, _рейт, biko, _सम्म_,
   {{0x68ed42de,0xb5fb04be,0x7bce42df,0x7d0d12af}},	//   _twad, _alár, _agbu, tuas,
   {{0x6e2d2360,0xe59810ac,0xbbeb01a8,0x9f4a02df}},	// [2cb0] reab, екті_, كرام_, rabá_,
   {{0xb5fb0307,0xb4ab000f,0x7bdac2e0,0x6e2d42e1}},	//   _clár, खते_, nctu, seab,
   {{0x68fb8024,0x229c816b,0xf99009a7,0x200101b4}},	//   _svud, líky_, _نبی_, _idhi_,
   {{0x7d0d010b,0x7bce0135,0x636b8061,0x212900ff}},	//   puas, _egbu, lönö, _kpah_,
   {{0x229c83c1,0x865a025f,0x7d0d0037,0x81c98264}},	//   níky_, _חדרי, quas, লুন_,
   {{0x628642e2,0x38b62474,0x1ae68264,0x7afaa86c}},	//   ziko, pære_, _কিনে_, kstt,
   {{0x201a8722,0x62860cb7,0xd00e81a8,0xdb1506c4}},	//   òpia_, yiko, زلي_, _egzò,
   {{0x628642e3,0x7c238359,0x7d1ba31d,0x21290d8b}},	//   xiko, _sbnr, ttus, _opah_,
   {{0xee36827e,0x44ef23b3,0x26d30ba3,0x7e69c2e4}},	//   тны_, nż_, _luxo_, rkep,
   {{0x44658895,0x2bb80424,0x58d48abe,0x290fc2e5}},	//   твов, _अरमा, _софт, muga_,
   {{0xe29a42e6,0x628642e7,0x7d1ba4da,0xfbd20051}},	//   дан_, tiko, stus, יתי_,
   {{0x7ea5c2e8,0x225f86c0,0x200142e9,0xa3b91a42}},	//   róps, _jouk_, _adhi_, _चरन_,
   {{0x628642ea,0x3eadc2eb,0xa56480f7,0x290fb1c9}},	//   riko, mlet_, _مدون, nuga_,
   {{0x3ea0931b,0x26d30118,0x291d804f,0x3ebfc2ec}},	//   čite_, _buxo_, itwa_, lmut_,
   {{0x44ef0063,0x26d301df,0x8fa600b3,0x26cb42ed}},	//   eż_, _cuxo_, таве, _bico_,
   {{0x7bdc42ee,0x7aed809a,0x26cb0140,0x291d86c0}},	//   _sfru, _łatw, _cico_, ktwa_,
   {{0xc5f28451,0x7d09c2ef,0x26cb42f0,0x3eadc2f1}},	// [2cc0] ידן_, nres, _dico_, ilet_,
   {{0xb4db42f2,0x3eadc2f3,0x69c2001b,0x224d8b09}},	//   _tràn, hlet_, रेणी, _anek_,
   {{0x3eadc2f4,0x26cb42f5,0x7d0981ec,0x78a3c2f6}},	//   klet_, _fico_, hres, donv,
   {{0x290f8365,0x6d448110,0x5186a7d6,0xe8df81bc}},	//   fuga_, _šiam, кула, _erọn_,
   {{0xc05a80e8,0x6aa2c2f7,0x290fc2f8,0x78a3c2f9}},	//   дій_, roof, guga_, fonv,
   {{0x7afc3275,0xa3c392ee,0x7d09c2fa,0x80e180ab}},	//   _tvrt, ्शा_, dres, _নিশ্,
   {{0x7c3c0af9,0x644e42fb,0xb4c0009a,0x3eadc2fc}},	//   _iarr, _inbi, ुदी_, flet_,
   {{0x80e18a49,0x7d09c2fd,0x290f81d3,0x6d460267}},	//   _নির্, fres, buga_, _krka,
   {{0x7c3c42fe,0x7d099b90,0x291d8035,0x08c6a34b}},	//   _karr, gres, ctwa_, _абан,
   {{0x7c3c00ad,0x628442ff,0x225fc300,0x6d4601a1}},	//   _jarr, _amio, _zouk_, _mrka,
   {{0x7c3c4164,0xd7a99a42,0xd25102e3,0x3eadc301}},	//   _marr, _चुपच, مند_, blet_,
   {{0x7c3c011e,0x7d09a0e6,0x6d464302,0x9e669db0}},	//   _larr, bres, _orka, _швед,
   {{0x9553803d,0xa2d4064a,0x316d0333,0x518401ae}},	//   _نخوا, _बूस्, áez_, аура,
   {{0x58870048,0x26d301df,0x8cd60105,0x8c0800ab}},	//   тыма, _puxo_, _बढ़ो, র্তন_,
   {{0x54338c2a,0x26cb0207,0x443c8282,0xd25980eb}},	//   _ضرور, _pico_, _iav_, _ziņu_,
   {{0x443ec303,0x443cbf33,0x3cfe000f,0x644e4304}},	//   ldt_, _hav_, _लिखे_, _anbi,
   {{0x80dd00c8,0x443c81c5,0x27f820e5,0x2129010b}},	// [2cd0] _বিক্, _kav_, barn_, _upah_,
   {{0x443ec305,0x7c3c37fe,0x290f8578,0x443cc306}},	//   ndt_, _carr, vuga_, _jav_,
   {{0x7c3c4307,0x443c822c,0x3e71c308,0x225f807a}},	//   _darr, _mav_, _láta_, _pouk_,
   {{0x443cc309,0x7c3c0ad0,0x6602c30a,0x99848110}},	//   _lav_, _earr, _ndok, _namų_,
   {{0x7c3c430b,0x3eadc30c,0xe8df80ff,0x443cc30d}},	//   _farr, vlet_, _trọn_, _oav_,
   {{0x443c8341,0x7c3c159d,0x290fc30e,0x443e80f3}},	//   _nav_, _garr, ruga_, jdt_,
   {{0x28da0996,0x6d4600e1,0x290fc30f,0x6e3d4310}},	//   _यूनि, _zrka, suga_, _kasb,
   {{0x443e80f3,0x3ebf8980,0x7e6d4311,0x224d8573}},	//   edt_, umut_, nkap, _unek_,
   {{0x3ebfc312,0x6e3d4313,0x9a848b5b,0x3ead8eb9}},	//   rmut_, _masb, _турл, rlet_,
   {{0x443c8069,0x3eadc314,0x3e71c315,0x649d809f}},	//   _cav_, slet_, _dáta_, nèix,
   {{0x443c81c5,0x46158fc5,0x7e6d24ab,0x27f842ab}},	//   _dav_, _موار, kkap, varn_,
   {{0x7d09c26a,0x3f7a8158,0x6e3d4316,0xe0c900be}},	//   pres, _אָדע, _nasb, _זײ_,
   {{0x32368158,0x81ac00ab,0x321e0035,0x443e8118}},	//   נטשן_, কেন_, ęty_, bdt_,
   {{0x40954317,0x443c93c2,0x81ea80ab,0xe81f001b}},	//   арст, _gav_, _মাছ_, म्ला_,
   {{0xd62a24dc,0xdc9a807c,0x7c3c0041,0x61f9893d}},	//   нове_, _איסל, _rarr, kawl,
   {{0x7e6d4318,0x7c3c4319,0x442780b9,0x6aa98088}},	//   gkap, _sarr, _hbn_, _nkef,
   {{0x26c0431a,0x0c262118,0x443c81c5,0xa50730be}},	// [2ce0] rmio_, лман, _yav_, лета_,
   {{0x443c90af,0xf54f81bc,0x7c3c431b,0x786f83ba}},	//   _xav_, _bụzi_, _qarr, _søvn,
   {{0xa3b903eb,0x7c3c431c,0x9f4c8388,0x6e3d01a1}},	//   _चरण_, _varr, _pedí_, _fasb,
   {{0x2ca5c31d,0x6d460904,0x998d809a,0xe3c580ab}},	//   hold_, _trka, _oceń_, _এভাব,
   {{0x7c3c431e,0x64430073,0x442780cd,0x6abb81b4}},	//   _tarr, ônic, _obn_, _dhuf,
   {{0x61f6431f,0x4427bd81,0x3e7181a8,0x60d602c4}},	//   _leyl, _nbn_, _ráta_, _muym,
   {{0x6d444320,0x9f580168,0x3ea4c321,0x4acf8c28}},	//   lvia, darë_, tomt_, _संगव,
   {{0xa3b90076,0x7ae302b7,0x443cc322,0x9b9300f7}},	//   _चरत_, ínte, _sav_, _الفت,
   {{0x5c74a6c5,0x443cc323,0x6d44009f,0x6143c324}},	//   илит, _pav_, nvia, _лета,
   {{0xd5c085e8,0x290b00d2,0x3ea48aa2,0x443c8282}},	//   शेषज, vrca_, somt_, _qav_,
   {{0x443ec325,0x5fa40076,0x68e40110,0x7e6d076d}},	//   rdt_, _खुलल, _atid, ykap,
   {{0x201a0197,0x673a911b,0x66028f90,0xd7f88129}},	//   _acpi_, _istj, _udok, _xoăn_,
   {{0x443cc326,0x6d4401ac,0x2ca5c327,0x6c548073}},	//   _tav_, jvia, bold_, _вклу,
   {{0x443cc328,0x6d3b8039,0x9f4780e1,0xb8fd4329}},	//   _uav_, _נתונ, vanú_, _तं_,
   {{0xb4c08e00,0xb4c286a7,0x68e406c0,0x99990019}},	//   ंगी_, ्दी_, _etid, reső_,
   {{0x58d50021,0xe80e8996,0x4ea70048,0x228b026b}},	//   _коит, _साझा_, урга, _dòkè_,
   {{0xb4db0722,0xb8049199,0x260a03db,0x6e3d432a}},	// [2cf0] _tràm, रणाम_, िलजी_, _vasb,
   {{0x7870016d,0x7e6d432b,0x673a82f1,0x6e3d1412}},	//   _jävl, skap, _ostj, _wasb,
   {{0x6e3d00ee,0xe7eb016f,0x649d809f,0xd498432c}},	//   _tasb, _ज्या_, rèix, урт_,
   {{0x3949432d,0x6e3d008e,0xb4c2c32e,0x61f6011c}},	//   _kras_, _uasb, ्दु_, _xeyl,
   {{0x61f9bcc0,0x673a8609,0xc5fa01c6,0xa3ab801b}},	//   rawl, _astj, _בפרט, _कुन_,
   {{0x216684ae,0x1bd40cb1,0x7d0d432f,0xa3d401cf}},	//   риши_, _горя, mras, _горч,
   {{0x6fcc80d4,0x21de819d,0x2ca593c2,0x9f5803ed}},	//   ाशगं, _ịhe_, vold_, varë_,
   {{0x39492fee,0x0e658c9b,0x7e6285d8,0x2ca5c330}},	//   _oras_, ркин, _coop, wold_,
   {{0x7ae48025,0xb4c2a78a,0x7d0d4331,0x9f5800f1}},	//   _čita, ्दू_, nras, tarë_,
   {{0x3ea080d2,0x4b259958,0xac859be4,0x4c85a4dc}},	//   čita_, амов, ргол, рлов,
   {{0x68e40052,0xeb999017,0x39494332,0x7d0d4333}},	//   _stid, тин_, _aras_, hras,
   {{0x80dd0a49,0xfaa62ce0,0x628b8428,0x39494334}},	//   _বিজ্, рамо, nigo, _bras_,
   {{0xe29719e0,0x9f584335,0x201a03a8,0x61e90118}},	//   рая_, maré_, _pcpi_, ñela,
   {{0x7870016d,0xd4668b30,0x39493245,0x628bc336}},	//   _gävl, _више_, _dras_, higo,
   {{0xb8fd1551,0xe7e50b9f,0x3949268b,0x628b8545}},	//   _तू_, कड़ा_, _eras_, kigo,
   {{0x7e628609,0xddc9179d,0x63ae06e1,0x26cf84b9}},	//   _xoop, _šošt, _rybn, _jigo_,
   {{0x7d0d4337,0x291f81c0,0x39490f7c,0xac860cf9}},	// [2d00] gras, _nqua_, _gras_, агал,
   {{0xd12f00d5,0x26cfc338,0x0eb8016f,0x9f580144}},	//   _کمی_, _ligo_, _आठवड, haré_,
   {{0x2bab8592,0x2abc8e1b,0x7d0d4339,0xdddd0019}},	//   _घुमा, híbe_, aras, _első,
   {{0x9f4c826f,0x628bab81,0x6441808e,0x6da6004a}},	//   _nedá_, gigo, hdli, _вима,
   {{0x44e98510,0x7d0d433a,0x2240433b,0x290083a7}},	//   _nº_, cras, _maik_, éia_,
   {{0x2018433c,0x26cf82f7,0x37069d1f,0x403495b7}},	//   ngri_, _aigo_, ачив, секс,
   {{0x628bc33d,0x26cfc33e,0x291f80e5,0x9f580580}},	//   bigo, _bigo_, _equa_, faré_,
   {{0xf2a38e8e,0x22400483,0x644182af,0x26cf882c}},	//   _дисп, _naik_, edli, _cigo_,
   {{0x26cfa755,0xd5b78987,0x61ed86a5,0xf8bf0866}},	//   _digo_, ись_, ñale, ltée_,
   {{0xb4c08063,0x8c668012,0xceea80e8,0xb4c2adb8}},	//   ंगे_, ртид, _адже_, ्दे_,
   {{0x22401a6e,0x3e75016d,0x39468110,0x225209ca}},	//   _baik_, _låta_, lvos_, _bnyk_,
   {{0xc5f080c8,0xbd878416,0x394900d7,0x1bf283a4}},	//   _টাকা_, انین_, _pras_, _आजकल_,
   {{0x787000f2,0xcd36826a,0x224000b9,0x3946802a}},	//   _tävl, _خراب, _daik_, nvos_,
   {{0x83f89c9b,0x5334c33f,0x27fc83ba,0xe9df4340}},	//   _секс_, _гект, navn_, scú_,
   {{0x1cbb8158,0x443331fc,0x06fd81d0,0x22404341}},	//   _שמוע, vex_, žívá_, _faik_,
   {{0x3949040e,0x27fc8edd,0xaa2d0198,0x2c190072}},	//   _tras_, havn_, ämää_, _पाहू_,
   {{0xddc40289,0x61ef00b9,0xdb1c0035,0x6d4002d4}},	// [2d10] tkiš, mbcl, _ogró, _šmar,
   {{0xe1ff0035,0xc3cb01a8,0x61fd20d8,0xeaca0129}},	//   tków_, نظام_, lasl, _hẹp_,
   {{0x44334342,0x628b8e67,0x389c098a,0x1da727bc}},	//   rex_, tigo, _ביזנ, _कुरत,
   {{0x7d0d4343,0xde590221,0xa3e68eed,0x7d028654}},	//   pras, _самі_, युत_, _ovos,
   {{0x394982ba,0x3ce6822c,0x26cf87e4,0x0dcb00a9}},	//   ías_, _ntov_, _rigo_, _јуни_,
   {{0x26cfc344,0x628bc345,0xb4c2801b,0xb4c091be}},	//   _sigo_, sigo, ्दो_, ंगो_,
   {{0xb4c283bb,0x61fd011e,0x261b816f,0x9f584346}},	//   ्दै_, kasl, _यादी_, taré_,
   {{0xee39998e,0x201809d1,0x2f9801c6,0xb4db0706}},	//   уни_, zgri_, יכון_, _arài,
   {{0x26cf87f4,0x656d4347,0x88078c2b,0x6289c348}},	//   _vigo_, nyah, _نظام, _imeo,
   {{0x7d02811f,0x6aad4349,0x3e7181ac,0x101781f9}},	//   _dvos, _akaf, _táto_, _خبرد,
   {{0x6441c34a,0x69cb9c9d,0xa25b0187,0x9f58434b}},	//   rdli, _तृती, rmôn, paré_,
   {{0xc869093f,0x2721ae3c,0x6f15434c,0x625a326c}},	//   _אן_, món_, duzc, урор_,
   {{0x272188a4,0xa5098b9c,0x2c6980e1,0xeaca0129}},	//   lón_, _села_, _súdu_, _dẹp_,
   {{0x645cb31b,0xb4db051e,0x656d0df6,0x37e301a1}},	//   örit, _grài, dyah, зорг,
   {{0x2721862f,0x628981e8,0x224000ee,0xb21b006a}},	//   nón_, _omeo, _taik_, dhæf,
   {{0x442a434d,0x61fd0279,0xaad006b7,0x27218118}},	//   _sbb_, casl, _सूचक, ión_,
   {{0x442a0886,0x61e4434e,0xed57434f,0x2721c350}},	// [2d20] _pbb_, _ifil, бот_, hón_,
   {{0x98a90110,0x6289b059,0xa3ab8853,0xe09e8135}},	//   _ypač_, _ameo, कअप_, kọọ_,
   {{0x29024351,0x2721c352,0xf8bf0036,0x656d26e9}},	//   lska_, jón_, utée_, ayah,
   {{0x27218c58,0x786b0085,0xd9fa03eb,0xf1fa8124}},	//   dón_, _qüvv, ्णित_, اعات_,
   {{0x19588fe6,0x186a8bc7,0xceb40085,0x656d00b4}},	//   ралы_, лади_, mlə_, cyah,
   {{0xfce34353,0x2721c315,0x76440085,0x29020079}},	//   _хоро, fón_, ldiy, iska_,
   {{0x6d4bc354,0x3946c355,0x272182ba,0x44444356}},	//   _arga, svos_, gón_, md_,
   {{0x22968013,0x3ea0803b,0x76444357,0x329681a8}},	//   _الرس, čito_, ndiy, _الرأ,
   {{0x75244358,0x2d804359,0x4444435a,0x26da435b}},	//   ntiz, nzie_, od_, _lupo_,
   {{0xd6d28872,0xb865b06f,0x290202a5,0x2721c35c}},	//   _فقط_, _والو, dska_, bón_,
   {{0x6d4bc35d,0x27218d76,0xceb40085,0xae209a42}},	//   _erga, cón_, klə_, _यापन_,
   {{0x6d4481e2,0x4444435e,0x9c8701d0,0x6d898019}},	//   _šiau, hd_, _kočá, امیہ_,
   {{0x0c738077,0x61e4002a,0xd0418085,0x7644435f}},	//   زدید, _dfil, _ailə, ddiy,
   {{0x2d800d38,0x69d60117,0xd0418086,0x44440613}},	//   dzie_, _egye, _bilə, jd_,
   {{0x444420af,0x1bfb8051,0x93fb810f,0xaae68bbe}},	//   dd_, _גלוב, _גלוי, _استو,
   {{0x44444360,0x5f94138c,0x656d056a,0xa19526e8}},	//   ed_, чист, tyah, _майч,
   {{0x2721840e,0x9f47826f,0x44440a0f,0x2d5824b6}},	// [2d30] zón_, daný_, fd_, бить_,
   {{0x44444361,0x80dc809a,0x656d0079,0xd37b0f13}},	//   gd_, _पढ़े, ryah, лче_,
   {{0x272181df,0x45d51775,0xb5fd807a,0x57fa01c6}},	//   xón_, _монс, ljše, _דלתו,
   {{0x44444362,0x7ae480ce,0x656d16fb,0x61e281f6}},	//   ad_, _čitl, pyah, gcol,
   {{0xae1a0158,0xd5a689a7,0x444402f7,0xb5fd82d4}},	//   _דורכ, _آف_, bd_, njše,
   {{0x2721988b,0xd7fb8037,0x26da004f,0x628f0493}},	//   tón_, ууд_, _yupo_, hico,
   {{0x64554363,0x320901b4,0x628f4364,0x7e7b8234}},	//   _inzi, _oday_, kico, thup,
   {{0x272188a9,0x29020079,0x644502a3,0x628f0503}},	//   rón_, yska_, ldhi, jico,
   {{0x6499840d,0x2721988b,0xb5fb4365,0xec79964f}},	//   итор_, són_, _bláz, ипи_,
   {{0x64454366,0x27218511,0x61fbc367,0x61e44368}},	//   ndhi, pón_, _heul, _sfil,
   {{0xe82009a3,0x628f1313,0x76440201,0x68f60355}},	//   _बाबा_, fico, ydiy, _swyd,
   {{0x2902012b,0xd5759a97,0x60dbc369,0x628f436a}},	//   tska_, _муль, _kuum, gico,
   {{0x444402a3,0x787004a2,0xddc2c36b,0x26da0216}},	//   yd_, _hävi, _zlož, _supo_,
   {{0x60dbc36c,0x26da04be,0x38b6006a,0x78700198}},	//   _muum, _pupo_, mærk_, _kävi,
   {{0x61e2a651,0xceb40085,0x6d49c36d,0x4444004a}},	//   ycol, tlə_, lvea, vd_,
   {{0x6455436e,0x7524436f,0xee3a09a5,0x61fbc370}},	//   _anzi, ttiz, јна_, _neul,
   {{0x6443c371,0x9f478a56,0xa3c383b7,0x76440201}},	// [2d40] _kani, vaný_, ्शक_, rdiy,
   {{0x3e78c372,0x6299867f,0xa3bd8424,0x44444373}},	//   _méta_, enwo, _आरा_, ud_,
   {{0x673e030b,0x75244374,0x61fb851e,0x213f8c68}},	//   _uspj, stiz, _beul, _asuh_,
   {{0x44444375,0x75244376,0x64554377,0x6443c378}},	//   sd_, ptiz, _enzi, _lani,
   {{0x81ac00c8,0x61e2c379,0x394dc37a,0x61ed85a4}},	//   কের_, rcol, _cres_, ñala,
   {{0x6443bf66,0x61e2c37b,0xb902ab6c,0xd90d803d}},	//   _nani, scol, _नं_, ایل_,
   {{0x394d9726,0x25e10076,0xe3a7819f,0xdfcf80f7}},	//   _eres_, _कलमी_, _آر_, نيه_,
   {{0xddc29807,0x628f437c,0x61fbc37d,0x39400f29}},	//   _vlož, xico, _geul, _osis_,
   {{0x7d04437e,0x6443c37f,0x261b8054,0xd90d8fd3}},	//   nsis, _bani, _यारी_, _مین_,
   {{0x6443c380,0x7d044381,0x2246c382,0xe46a9b4f}},	//   _cani, isis, ldok_, ршил_,
   {{0xddc287df,0x628f4383,0x39400084,0x9f5c84e8}},	//   _ulož, tico, _asis_, kavé_,
   {{0x7d044384,0xd3778110,0x0dca9c45,0xdb214385}},	//   ksis, ючы_, _кули_, étét,
   {{0x628f4386,0x21268867,0x66008d92,0x394d1e3a}},	//   rico, ntoh_, mamk, íes_,
   {{0x628f2602,0x6443c387,0x66008079,0xfbcf82e3}},	//   sico, _gani, lamk, عتی_,
   {{0x368b27d4,0x628f1820,0x81ac00ab,0x44e0c388}},	//   асан_, pico, কেল_, _hò_,
   {{0x44e0c389,0xcb138bea,0x7c2e438a,0x66008010}},	//   _kò_, _חלק_, _abbr, namk,
   {{0xd90489d7,0x7d0402b8,0x95cb0323,0x628d0b80}},	// [2d50] _جی_, gsis, рува_, _imao,
   {{0x44e0c38b,0x61fb82be,0x60dba244,0x6600c38c}},	//   _mò_, _seul, _ruum, hamk,
   {{0x44e0c38b,0x68e993e1,0x3e7180f7,0x6445438d}},	//   _lò_, _sted, _fáth_, rdhi,
   {{0x9f45803e,0x660089ca,0x7c2e0ab3,0xb4db051e}},	//   _celý_, jamk, _ebbr, _bràt,
   {{0x2a69438e,0x61fba636,0x44e083ec,0x6600c38f}},	//   _moab_, _veul, _nò_, damk,
   {{0xbca500f7,0x68e980e1,0x38b6006a,0x3e7c01d0}},	//   _رمزي, _vted, værk_, _víte_,
   {{0xf7719dd2,0x644382a5,0x2cac831d,0x61fbc390}},	//   عات_, _rani, dodd_, _teul,
   {{0x394da8f8,0x44e0c391,0xe1ff8125,0x29194392}},	//   _tres_, _bò_, _þó_, kusa_,
   {{0x6443c393,0x44e0c394,0x7982809a,0x2cac831d}},	//   _pani, _cò_, czow, fodd_,
   {{0x44e090ab,0x629d4395,0x628d0133,0xc48283c7}},	//   _dò_, éron, _amao, ельк,
   {{0xf1a90159,0x3e718324,0x22920110,0xa3ab9513}},	//   _עס_, _láti_, eška_, _कुश_,
   {{0x644395bd,0xe29a108d,0x44e0c396,0x394002f7}},	//   _wani, сам_, _fò_, _psis_,
   {{0x44e09b5b,0x2eaa8117,0x6443c397,0xbbb8000d}},	//   _gò_, _اپنی_, _tani, _अर्क,
   {{0xf09f3edf,0x26c20168,0xb87b00e1,0x15429092}},	//   dràs_, _shko_, dpís, _чешм,
   {{0x1fb52432,0x38ca0019,0xeb96911c,0x9f5c936f}},	//   дстр, لاڑی_, _ниш_, tavé_,
   {{0x3940146a,0x29194398,0x3e6e007b,0x7d044399}},	//   _tsis_, busa_, _nýtt_, tsis,
   {{0x2919439a,0x9f5c816b,0xed57439b,0x44e080e5}},	// [2d60] cusa_, ravé_, пот_, _xò_,
   {{0x7d04439c,0x3d13a7cf,0xf5070e49,0x99dd80e1}},	//   rsis, _दिने_, янул_, _raňa,
   {{0x9f45c39d,0x2baf06a7,0xb4db026b,0x7ae48140}},	//   _meló_, _जुदा, _bràs, _čitk,
   {{0x81ac00ab,0xfaa385a8,0xf8bf439e,0x3202016b}},	//   কেঃ_, нахо, ntén_, naky_,
   {{0x2fda00b9,0x6d4f00c3,0x9f58023e,0xb4db01e4}},	//   _kgpg_, _grca, larà_, _dràs,
   {{0x44e08324,0x38b6007b,0x79828035,0x55bb01c6}},	//   _rò_, færi_, rzow, _למכו,
   {{0x44e0c39f,0xa3ab80a5,0x9f580722,0x764630ef}},	//   _sò_, _कुल_, narà_, _kaky,
   {{0x44e0c3a0,0x443a43a1,0x3202016b,0x7e6402f7}},	//   _pò_, lep_, jaky_, njip,
   {{0x2919036a,0xa3c9800c,0x764643a2,0x1dbe0743}},	//   xusa_, लेस_, _maky, ्धित,
   {{0x628d0ad0,0x443a3e3d,0xa3e6864a,0x2292007a}},	//   _smao, nep_, युं_, vška_,
   {{0x59a51055,0xd25102e3,0x44e0877f,0x200c8114}},	//   _गुजर, نند_, _wò_, _iddi_,
   {{0x44e090ab,0x443a43a3,0x9f580722,0x76460c2e}},	//   _tò_, hep_, darà_, _naky,
   {{0x443a39d2,0x442ec3a4,0xc05b00e8,0x41c70035}},	//   kep_, _tbf_, бів_, रेंस,
   {{0x291943a5,0x443a02ce,0xdd3b8039,0x764600e4}},	//   rusa_, jep_, _לעדכ, _aaky,
   {{0xb5fd84c4,0x6458c3a6,0x3ae18028,0x6d4f00d2}},	//   ljša, _invi, _góp_, _srca,
   {{0xfbb78051,0x81ac00ab,0x291943a7,0x26deacf7}},	//   _מפות_, কেই_, pusa_, _muto_,
   {{0x2d580364,0x26dec3a8,0xb5fd807a,0x76463c76}},	// [2d70] пить_, _luto_, njša, _daky,
   {{0x443a003d,0x6448c3a9,0x9f580722,0xf09f023e}},	//   gep_, nddi, barà_, rràs_,
   {{0x200343aa,0x9f580722,0x64488114,0x61ed8333}},	//   maji_, carà_, iddi, ñalo,
   {{0x2ea8035a,0x6d4f02a5,0x63b5026f,0x7c3ac3ab}},	//   ककृत, _trca, _vyzn, hetr,
   {{0xa06994bc,0x9f581986,0x7c3a81a3,0x6d4f0162}},	//   жала_, mará_, ketr, _urca,
   {{0x26dec3ac,0x9f58018a,0x443a43ad,0x200343ae}},	//   _buto_, lará_, cep_, naji_,
   {{0x60df3843,0x6d42802a,0xa6c98572,0x442300ee}},	//   _luqm, _asoa, олка_, _icj_,
   {{0x9f581f9e,0x644743af,0x200343b0,0x442c81ed}},	//   nará_, _haji, haji_, efd_,
   {{0x64471600,0x6d4d18c7,0x200343b1,0x61e9846d}},	//   _kaji, nvaa, kaji_, _ifel,
   {{0x7c3ab864,0x200343b2,0x644743b3,0xd90d8019}},	//   getr, jaji_, _jaji, _میچ_,
   {{0x644743b4,0x29090364,0xe8171c58,0x68ed43b5}},	//   _maji, _avaa_, _ताजा_, _atad,
   {{0x6458c3b6,0x644743b7,0xdd8e826a,0x9f5843b8}},	//   _envi, _laji, اوی_, jará_,
   {{0xda1f1499,0x76460455,0xe8f70554,0x9f582b49}},	//   _भारत_, _raky, мля_, dará_,
   {{0x64470c9e,0xf8bf02b7,0x9f580722,0x200343b9}},	//   _naji, stén_, tarà_, gaji_,
   {{0x4aad8076,0x68ed43ba,0xa3c9858c,0x7529bb37}},	//   टकाव, _etad, लेश_, ltez,
   {{0x9f580a3e,0x44230176,0x7649c3bb,0xe82043bc}},	//   gará_, _acj_, ndey, _बावा_,
   {{0x443a43bd,0x200343be,0x7529b50a,0xdb0e001b}},	// [2d80] tep_, baji_, ntez, _vybí,
   {{0x69dbc3bf,0x7e7d0362,0xfbd2030f,0x9f58023e}},	//   _ague, _elsp, نتا_, parà_,
   {{0x443a43c0,0x764643c1,0xaec60ff0,0x9f581986}},	//   rep_, _taky, _обол, bará_,
   {{0x9f580acf,0x443a29e9,0xe297a48f,0x99dd826f}},	//   cará_, sep_, мах_, _daňo,
   {{0x6448a0af,0xd1308416,0x66043a57,0x7649c3c2}},	//   yddi, امت_, maik, ddey,
   {{0x660443c3,0x2906862f,0xd6ea8ae7,0x64471ce9}},	//   laik, rsoa_, офил_, _gaji,
   {{0x29068073,0x7bdc43c4,0xdfd081a8,0x7c3ac3c5}},	//   ssoa_, _igru, ديث_, vetr,
   {{0x2003022e,0x660416d5,0x667b00be,0xc9568364}},	//   zaji_, naik, ַװיג, _отзы,
   {{0x9f5e80f1,0x644743c6,0x6f1c3d08,0x2d848289}},	//   _ketë_, _yaji, hurc, uzme_,
   {{0x9f5e820f,0x9f5843c7,0x3e78800d,0x26de801b}},	//   _jetë_, zará_, _této_, _tuto_,
   {{0xd62a9289,0x660443c8,0x6448c3c9,0xa3c98072}},	//   _може_, kaik, rddi, लेल_,
   {{0x6f1c02af,0x7d1bc3ca,0x6282b052,0x2003004f}},	//   durc, buus, nhoo, waji_,
   {{0x941e023c,0x7c3ac3cb,0x2003022e,0x9f582b49}},	//   _पांच_, petr, taji_, vará_,
   {{0xddcd10d3,0xc05801b5,0x656f81ec,0x7bdc003d}},	//   jkaš, міс_, äche, _ngru,
   {{0x9f581313,0x644743cc,0x26c6c3cd,0xe8202b6c}},	//   tará_, _raji, _khoo_, _बारा_,
   {{0x4ea418a0,0x7bdc2fe5,0x64471eec,0x660443ce}},	//   вруа, _agru, _saji, gaik,
   {{0x9f582018,0xdd9401bb,0xa5bb0118,0x64470168}},	// [2d90] rará_, ваты, _ecón, _paji,
   {{0x31560051,0xf5488135,0x6d4d43cf,0x9f582b49}},	//   _ניתן_, _mụ_, rvaa, sará_,
   {{0x66040867,0x9f582755,0xf8bf0073,0xa5bb00f7}},	//   baik, pará_, ntém_, _gcón,
   {{0xb4ca84e5,0xfd5e80ff,0x387e8037,0x6d4d090d}},	//   लगु_, _quyể, _altr_, pvaa,
   {{0x224901d8,0xc6160051,0x50b581bb,0x801807d2}},	//   _maak_, _אחרי_, нску, _عزیز_,
   {{0x26d943d0,0x7d1b862c,0x2b430980,0x9f5e826b}},	//   _hiso_, vuus, _tsjc_, _ketè_,
   {{0xfd5e8028,0x7afc0114,0x38b603ba,0x9f5c84e8}},	//   _tuyể, _gwrt, mært_, baví_,
   {{0x26c6c3d1,0xf548b7a0,0x06098d5f,0x7d1b82ec}},	//   _choo_, _bụ_, чник_, tuus,
   {{0xf5488028,0xdc3a8201,0x2a7f8420,0x0c95af16}},	//   _cụ_, _açıq, _ilub_, ешня,
   {{0x7529c3d2,0x2a7f81e9,0x6ac800d4,0x291dc3d3}},	//   rtez, _hlub_, रग्र, muwa_,
   {{0x44211523,0x7d1bc3d4,0xa3c98740,0xe8d68039}},	//   igh_, suus, लें_, _נוער_,
   {{0xbbdc000f,0x26d90353,0x395201b0,0x25a0811a}},	//   _बल्क, _niso_, _prys_, _žile_,
   {{0xf548abd6,0xaca381bc,0x66040d15,0xb5fd81a1}},	//   _gụ_, _azụk, vaik, ljšo,
   {{0x660401bc,0xd11c1344,0x2a6dc3d5,0xf1b9816b}},	//   waik, भूषण_, _loeb_, _myš_,
   {{0xc7b2893f,0x6ab6324a,0x7d098bc5,0x2baf00a5}},	//   ָבן_, _псих, lses, _जुला,
   {{0x291da11f,0x9f5c1ca8,0x68339010,0x7bc38024}},	//   kuwa_, _því_, lıdı, _iznu,
   {{0x26d943d6,0x660443d7,0xafe60391,0xf8af8beb}},	// [2da0] _diso_, raik, _попл, टवाय,
   {{0x660443d8,0x6457a755,0x7d098009,0x224900f3}},	//   saik, _óxid, ises, _zaak_,
   {{0xddcd0067,0x9f5ec3d9,0x660443da,0x3ce506a7}},	//   rkaš, _vetë_, paik, _झूठे_,
   {{0x09e6b553,0x7d09c3db,0x2366003a,0x442101e4}},	//   ходн, kses, ćoj_, agh_,
   {{0x6282c3dc,0x941e0076,0xaca40135,0x9f5c83fb}},	//   rhoo, _पाऊच_, _abụr, raví_,
   {{0x6d4643dd,0x3b0a1957,0x6282c3de,0xe3b10117}},	//   _iska, _него_, shoo, ارے_,
   {{0x64a32070,0x645c43df,0x3ea00168,0x26c681c0}},	//   _сара, _inri, onit_, _phoo_,
   {{0x3ea01aff,0x291d84b9,0xfd55019d,0x9405811c}},	//   nnit_, buwa_, _nkaọ, milə_,
   {{0x6280825d,0x2249079f,0x3ea03934,0xdd90803d}},	//   _ilmo, _raak_, init_, شود_,
   {{0xf5488104,0x224901b0,0xfd550133,0x6386c3e0}},	//   _vụ_, _saak_, _akaọ, _néné,
   {{0x69c40698,0x7ae928d2,0xa5bb0118,0xfd4981bc}},	//   _azie, _četk, _acól, _kalị,
   {{0x6d4643e1,0x09d480c8,0x7d0982f7,0xf54880ff}},	//   _oska, _হ্যা, bses, _tụ_,
   {{0x22490a0f,0xf8bf027f,0x638682be,0x26d943e2}},	//   _vaak_, stém_, _béné, _riso_,
   {{0x69c443e3,0x3ea0825b,0x638689c4,0xf1c70035}},	//   _dzie, čitu_, _céné, रेगन,
   {{0x443e83ed,0x6d4643e4,0x26d9275e,0x60dac3e5}},	//   met_, _aska, _piso_, _mitm,
   {{0x644ac3e6,0x2001010c,0x291d80a4,0x62670b8c}},	//   _hafi, _wehi_, yuwa_, _سابق,
   {{0x644ac3e7,0x26d943e8,0x7c3e01f4,0xdb0e026f}},	// [2db0] _kafi, _viso_, fepr, _rybá,
   {{0x638683d3,0x44210051,0x7d1d8722,0x64848014}},	//   _géné, ugh_, àssi, _dòig,
   {{0x6d4600ad,0x7f4500f1,0xa3c2ba6a,0x41ee819d}},	//   _eska, _ushq, ्धि_, _ịsị_,
   {{0x443ec3e9,0xa3cd0b6f,0x644a80a4,0x291dc3ea}},	//   het_, शेष_, _lafi, tuwa_,
   {{0x443ec3eb,0x765d43ec,0xfe79800d,0xd9458abe}},	//   ket_, _insy, vků_, тели,
   {{0x443ec3ed,0x22498025,0xa3c28894,0x291dc3ee}},	//   jet_, žak_, ्धा_, ruwa_,
   {{0x443e920b,0xb4bd0b9f,0x752d0211,0x291dc3d3}},	//   det_, आती_, ltaz, suwa_,
   {{0x764d43ef,0x81ac00ab,0x644a846d,0x7d098074}},	//   nday, কেট_, _aafi, tses,
   {{0x752d25d4,0x443ec3f0,0x644ac3f1,0x290b009a}},	//   ntaz, fet_, _bafi, jsca_,
   {{0x443e8a33,0x60da8214,0x6ab62e3d,0xf9908199}},	//   get_, _gitm, _skyf, _طبق_,
   {{0x2007c3f2,0x5f798077,0x8c3c87d9,0x03a5818b}},	//   mani_, _تماس_, toğr, тино,
   {{0x20079ffb,0x752d0695,0x7c3e009a,0x7d09c3f3}},	//   lani_, ktaz, zepr, pses,
   {{0x443ec3f4,0x764d0ec8,0x644ac3f5,0xb4db026b}},	//   bet_, dday, _fafi, _asàm,
   {{0x2007c3f6,0x764b8065,0x7e69c3f7,0x62888110}},	//   nani_, _hagy, ljep, _įdom,
   {{0x764bc3f8,0x66e604ae,0x290b1947,0xe7271290}},	//   _kagy, тоба, asca_, корд_,
   {{0x644ab8b6,0x764d43f9,0x7e7b8168,0x7e69c3fa}},	//   _zafi, gday, nkup, njep,
   {{0x764b8117,0x2007c3fb,0x7c3e43fc,0x3ea043fd}},	// [2dc0] _magy, kani_, tepr, rnit_,
   {{0x7ae3c3fe,0x644a8079,0x3ea043ff,0x711b00be}},	//   _kunt, _xafi, snit_, _קויפ,
   {{0x290d8012,0x7ae3c400,0x7c3e385d,0x68e4038e}},	//   _avea_, _junt, repr, _huid,
   {{0x764b8117,0x7ae3c401,0x443ec402,0x68e40006}},	//   _nagy, _munt, zet_, _kuid,
   {{0x443ec403,0x2007c404,0x94058085,0x6d464156}},	//   yet_, fani_, silə_, _uska,
   {{0x443e4405,0x68e4043d,0xf1a9803d,0x6602c406}},	//   _út_, _muid, رانه_, _seok,
   {{0x443e8370,0x644a8c9e,0x7ae3c407,0x764bc408}},	//   vet_, _rafi, _nunt, _bagy,
   {{0x6e244409,0x443ec40a,0xf8bf0019,0x7e7bacbf}},	//   ngib, wet_, tték_, gkup,
   {{0x7ae9003b,0x443e8e79,0x2007c40b,0x48e6835f}},	//   _četi, tet_, bani_, _розв,
   {{0x7ae3c40c,0x60da8cfa,0xa3d7047d,0x443ec40d}},	//   _bunt, _uitm, ाखच_, uet_,
   {{0x443ec40e,0x8c1b0158,0x7ae3c40f,0x8fa38bc7}},	//   ret_, וויי, _cunt, _кафе,
   {{0x443ec156,0x68e40014,0x92580009,0x644aa6b4}},	//   set_, _buid, вают_, _wafi,
   {{0x68e410eb,0x443e85a0,0x644a80a4,0x61ed8511}},	//   _cuid, pet_, _tafi, ñali,
   {{0xa8a44410,0x1c1e0592,0xcb548b76,0x443e820f}},	//   арск, _पागल_, _منتظ, qet_,
   {{0xd6db130f,0x764d4411,0x290b01a1,0x6b8d8326}},	//   дта_, tday, ssca_, _ƙage,
   {{0x34db035a,0x752d4412,0x0bb78039,0x6e24245a}},	//   बद्द, ttaz, _שלהם_, ggib,
   {{0x2007c413,0x68e4114e,0x51870d8e,0xb6040249}},	// [2dd0] yani_, _guid, _шука, ряск,
   {{0x752d4414,0x1acb8eed,0x041480c8,0x63bc4415}},	//   rtaz, िष्ठ, ত্রী_, _byrn,
   {{0x2007c416,0x7ae387f4,0x752d4417,0x68e400f3}},	//   vani_, _xunt, staz, _zuid,
   {{0x2007c418,0xf67900be,0x3d13816f,0x657200f1}},	//   wani_, _נאָמ, _दिले_, ëdhë,
   {{0x2007c419,0x7640c41a,0x66ea8035,0x9564047f}},	//   tani_, demy, _ręka, _кърд,
   {{0xfaf30277,0xb4ac801b,0x7d0d441b,0x66d58084}},	//   _نثر_, कको_, msas, _iški,
   {{0x2007c41c,0x61e49601,0x3e750687,0x442797e9}},	//   rani_, žila, _fått_, _rcn_,
   {{0x7ae3c41d,0x3e750448,0xdd918065,0xdb258019}},	//   _runt, _gått_, یوں_, épít,
   {{0x7ae3c41e,0x764bc41f,0x7e7bb0a1,0x78b50503}},	//   _sunt, _vagy, rkup, kozv,
   {{0x68e44420,0x3a2900dd,0x1abe020e,0x764b85ee}},	//   _ruid, _acap_, ोष्ठ, _wagy,
   {{0x39494421,0x68e44422,0xb0b680be,0xe29a1b2f}},	//   _asas_, _suid, _עפעס_, еан_,
   {{0x68e42deb,0x2005b3ec,0xad9b04f0,0x7d0d4423}},	//   _puid, _heli_, _reún, ksas,
   {{0x2005c424,0x78b501a1,0x64848362,0xc871826b}},	//   _keli_, fozv, _dòib, _ko̟_,
   {{0x7ae3c425,0x3ebf8364,0x2005811f,0x628600f1}},	//   _tunt, llut_, _jeli_, shko,
   {{0x39494426,0xe29a1927,0xa3c98778,0x2005c427}},	//   _esas_, _пак_, लेख_, _meli_,
   {{0x6441c428,0x224d8b99,0x44e990ab,0x20058234}},	//   leli, _naek_, _kú_, _leli_,
   {{0x44e9c429,0xa3e7a78a,0x7d0d02b8,0x62844348}},	// [2de0] _jú_, _भला_, gsas, _ilio,
   {{0x6441c42a,0x44e9877f,0x629d026f,0x7640809a}},	//   neli, _mú_, érov, zemy,
   {{0x44e99ccc,0x224d90e4,0x25ab442b,0x6609a497}},	//   _lú_, _baek_, _excl_, kaek,
   {{0xa3ab9499,0x64418a92,0x200a352d,0x60de008e}},	//   _कुछ_, heli, labi_, _hipm,
   {{0x44e9c42c,0x2005c42d,0xd378809a,0x7d0d442e}},	//   _nú_, _beli_, zyć_, csas,
   {{0x7ae9003b,0x6441c42f,0x200a3140,0xf8b40b9f}},	//   _četv, jeli, nabi_, ंकिय,
   {{0x64418de8,0xd6dac430,0x2005c431,0x09b580ab}},	//   deli, нти_, _deli_, জেলা,
   {{0x44e9c432,0x644e05d8,0x26dd8300,0x26c000e5}},	//   _bú_, _habi, _ciwo_, nlio_,
   {{0x66061f9a,0x6441c433,0xd49ac434,0x7640c435}},	//   _mekk, feli, ерн_, remy,
   {{0x6441c436,0x66064437,0x27f7800d,0x62840010}},	//   geli, _lekk, čení_, _alio,
   {{0x644e4438,0xd7ef80f7,0x44380706,0x2a60008e}},	//   _mabi, _ركن_, _mbr_, _bnib_,
   {{0x644e200b,0x20058052,0x6284051e,0x66064439}},	//   _labi, _zeli_, _clio, _nekk,
   {{0x44e99e85,0xa3d606b7,0x4438443a,0x9f5e8216}},	//   _gú_, ाइड_, _obr_, _metí_,
   {{0xac18835f,0x6441a353,0x200a443b,0x224d1d1a}},	//   _року_, celi, gabi_, žek_,
   {{0x447b8158,0x6606443c,0x1ee7003d,0xe80c897d}},	//   _אנגע, _bekk, اوری_, _सजना_,
   {{0x26c00021,0x44383009,0x3a2932bb,0x62841581}},	//   glio_, _abr_, _ucap_, _glio,
   {{0x644e307a,0xe21400a0,0x6606443d,0x44380366}},	// [2df0] _babi, _طبيع, _dekk, _bbr_,
   {{0x7d0d443e,0x888300d7,0x229202d4,0x320b066f}},	//   rsas, _ایسن, vški_, lacy_,
   {{0x644e443f,0xaca48135,0x62840009,0x20059c5d}},	//   _dabi, _azịz, _ylio, _reli_,
   {{0x6441c440,0x66061c2b,0x62359c57,0x44380428}},	//   zeli, _gekk, реду, _ebr_,
   {{0x9f5e80e1,0x44258114,0x2005c441,0x6441c442}},	//   _detí_, ygl_, _peli_, yeli,
   {{0x44e990ab,0x8f15808f,0x44250aa2,0x7e6d0074}},	//   _rú_, афич, _øl_, ljap,
   {{0x44e9c443,0x200585f3,0xb5fd807a,0x7d029c19}},	//   _sú_, _veli_, ljši, _awos,
   {{0x6441bbcb,0x7f3c00be,0x20058079,0x225f8503}},	//   weli, געהו, _weli_, _unuk_,
   {{0xc4858251,0x644e1eda,0x6f04811f,0x26c380eb}},	//   илик, _yabi, ćica, ējo_,
   {{0x99848013,0x7ae700f1,0x3ebf80f2,0x7d1ba083}},	//   _الكو, _kujt, slut_, rrus,
   {{0xda661264,0x626600af,0x26c00114,0x200a4444}},	//   авни, авна, ylio_, vabi_,
   {{0x44e9c445,0xe29a1052,0xc5d5835f,0x6723b8c4}},	//   _tú_, там_, _кіль, munj,
   {{0x27318104,0x64418436,0x67238359,0x200a4446}},	//   _hơn_, peli, lunj, tabi_,
   {{0xe3b0803d,0x6d59a6da,0x66064447,0x8d748f24}},	//   _کره_, _irwa, _sekk, _داما,
   {{0x67238867,0x200a4448,0xb4c383dd,0xb4c1b6cf}},	//   nunj, rabi_, ्षी_, ंती_,
   {{0x644e4449,0x6284022e,0x200a444a,0x7ebe80f1}},	//   _sabi, _ulio, sabi_, tëpi,
   {{0x644e15d0,0xb2bb0039,0x61e4444b,0xf5e72a96}},	// [2e00] _pabi, _במקר, _igil, рмул_,
   {{0x26c00025,0x644e444c,0x4463035f,0x6723912e}},	//   slio_, _qabi, овув, kunj,
   {{0x26c006a5,0x66060074,0x644e007a,0xf1bf22ef}},	//   plio_, _tekk, _vabi, ngán_,
   {{0x53368158,0xb4c1a776,0x67238699,0x6d59a580}},	//   ינען_, ंतु_, dunj, _orwa,
   {{0x644e444d,0x656f81ec,0xe046824f,0xa06a8eef}},	//   _tabi, ächl, инди, када_,
   {{0xfb26003d,0x442a01e0,0x4438026c,0x764f023b}},	//   _پرسپ, _ucb_, _ubr_, _zacy,
   {{0x6d4bc44e,0x6d59c44f,0x3cec0540,0x61e40106}},	//   _asga, _arwa, _अंडे_, _ogil,
   {{0x2baf08fd,0x66c58125,0x61e4255a,0x7d0286c0}},	//   _जुटा, sókn, _ngil, _pwos,
   {{0x320b4450,0xe7fb0ebf,0x444403e4,0x657b82c4}},	//   vacy_, ्रमा_, oe_, gyuh,
   {{0x37b28264,0x7ae09867,0x22920196,0x00000000}},	//   টেগর, _himt, išku_, --,
   {{0x94738307,0x44444451,0x6d5982af,0xe8204452}},	//   تديا, ie_, _erwa, _बाजा_,
   {{0x44444453,0x1eda80f7,0x48fd800d,0x7d028a03}},	//   he_, _شباب_, रीको_, _twos,
   {{0x64a69a88,0xe29801e2,0x673e0580,0x81e88264}},	//   _када, раў_, _appj, _মজা_,
   {{0x653b83c8,0x61e44454,0x69c09dbf,0x27248133}},	//   _סעוד, _egil, _myme, _ịnye_,
   {{0x7e629254,0xa3b7826a,0x9e070f27,0xddc60035}},	//   _knop, _پاور_, ичал, _nakł,
   {{0x44444455,0x9f5e8081,0x962100d4,0x33db81c6}},	//   ee_, _metà_, यलेट_, _בחוד,
   {{0x629d4456,0x7524002a,0x44444259,0x7e6d20c3}},	// [2e10] miso, guiz, fe_, rjap,
   {{0xfd4d0104,0x91bc0039,0x629d4457,0x6abb8aa2}},	//   _khoả, _במחי, liso, _skuf,
   {{0x7ae0808e,0x69c0c458,0xf3674459,0x7e62c45a}},	//   _bimt, _ayme, штан, _onop,
   {{0x4444445b,0x4b378051,0x6723a8b8,0x69c0867f}},	//   ae_, שראל_, vunj, _byme,
   {{0x4444445c,0x660d02d8,0x2731801c,0x463a00be}},	//   be_, maak, _sơn_, _גערע,
   {{0x67238590,0x660d445d,0x6c8500f7,0x6d9e0609}},	//   tunj, laak, _السم, _dħaħ,
   {{0x629d445e,0xf8bf25b9,0x6445004f,0x3f8184e8}},	//   kiso, ltés_, mehi, áhu_,
   {{0x9aa58077,0x7ebe80f1,0x6445400a,0x660d445f}},	//   _امرو, këpu, lehi, naak,
   {{0xf8bf25b9,0x3e788125,0xddc6009a,0x1fd410c8}},	//   ntés_, _rétt_, _zakł, _दण्ड,
   {{0x4c8598a2,0xd8748013,0xb4c38d14,0xcc89803d}},	//   слов, _والب, ्षे_, انده_,
   {{0x3a2d011b,0x5f79987e,0x09e62626,0xdb1c00e7}},	//   мep_, _حماس_, йонн, _pyré,
   {{0x44441ed0,0x68e1c460,0x629d2010,0x6d59809a}},	//   ze_, _hild, giso, _trwa,
   {{0x44444461,0x6d5980b4,0x68e184d6,0x6e2994f9}},	//   ye_, _urwa, _kild, mgeb,
   {{0x44444462,0x037989a7,0x68e18bce,0x6e29a0ff}},	//   xe_, _محبت_, _jild, lgeb,
   {{0x177911d2,0x629d1f73,0x44fb802a,0x03a28037}},	//   асть_, biso, _hª_, _нишо,
   {{0x07a31af1,0x75244463,0x6e3b0144,0x6e29b480}},	//   часн, tuiz, _ñubl, ngeb,
   {{0x6ab98362,0x7ae08084,0x0dca0b69,0x64848229}},	// [2e20] dowf, _rimt, улай_, _mòin,
   {{0x7ae94464,0x44444465,0x7ae0c466,0x44fbae42}},	//   _četr, ue_, _simt, _mª_,
   {{0x18770039,0x48ee11bc,0xe9f90032,0xb5fd807a}},	//   _העיר_, _इंडो_, _ajẹ_, ljšu,
   {{0x366a0fe7,0x69c086a5,0x2c21816f,0x7f3b00be}},	//   _само_, _pyme, _माझं_, _געטו,
   {{0x68e1b45d,0x7524016a,0x6e299337,0xf8bf4467}},	//   _bild, quiz, dgeb, ctés_,
   {{0xb4c386b7,0x69c08a21,0x44444468,0x629d4469}},	//   ्षो_, _vyme, qe_, ziso,
   {{0x43860013,0x394d84c3,0x68e18965,0xd6d096a5}},	//   _الأق, _eses_, _dild, وقت_,
   {{0xdd080038,0x8cf4c46a,0x39401893,0x44f4817c}},	//   _môže, озиц, _opis_, опис,
   {{0x68e9c46b,0x3940446c,0xf65301c6,0xbcfb046d}},	//   _gued, _npis_, לצה_, _eréf,
   {{0x68e1807b,0x6282c46d,0x0466c46e,0x44fb802a}},	//   _gild, lkoo, стим, _dª_,
   {{0x2d82895e,0x629d446f,0x44fb8118,0x7c288bfd}},	//   ške_, tiso, _eª_, rgdr,
   {{0x6282c470,0x25a98289,0x6d49c471,0x7e62c472}},	//   nkoo, _žale_, bwea, _unop,
   {{0x787d8247,0x68e19238,0xe1ff4473,0x660d0365}},	//   _sèvi, _yild, rbó_, vaak,
   {{0x629d4474,0x200e8239,0x68e18079,0xd9180009}},	//   siso, nafi_, _xild, щью_,
   {{0x6282c475,0x5c3784de,0x443c8dcc,0x64450087}},	//   kkoo, _הטוב_, _ibv_, vehi,
   {{0xf96b0098,0x62828952,0x61e481a1,0xfaa42cab}},	//   _брой_, jkoo, žilj, _најо,
   {{0xe29f0125,0x6282c476,0x660d4470,0xf8bf02be}},	// [2e30] mið_, dkoo, raak, utés_,
   {{0xe29f0125,0x68e9c477,0x660d25d5,0xa3cf8fd5}},	//   lið_, _rued, saak, _शरम_,
   {{0x660d4478,0x64454479,0xda7b85e9,0xe80c8105}},	//   paak, rehi, ляд_, _सज़ा_,
   {{0x68e9a797,0xaac90f21,0x02c903b7,0x7aeac47a}},	//   _pued, रतिक, रतिभ, _muft,
   {{0x68e9ae3c,0x7aeac47b,0x68e1c47c,0x6aad00f1}},	//   _qued, _luft, _pild, _mjaf,
   {{0x46f59c78,0xbcfb02be,0x68e1a828,0xa3d60424}},	//   очит, _préf, _qild, ाइश_,
   {{0xe29f07ca,0x68e1c47d,0x6e299781,0x3ea913f0}},	//   kið_, _vild, tgeb, onat_,
   {{0x3ea91c2f,0x62349509,0xa3bc80c2,0x68e1c47e}},	//   nnat_, _несу, _आड़_, _wild,
   {{0x6e298df3,0x7aea82af,0xd131b1a7,0xe29f008b}},	//   rgeb, _auft, _زما_, dið_,
   {{0x6d5d02a5,0x6e298223,0x6aad0032,0x3ea9447f}},	//   _mrsa, sgeb, _ajaf, hnat_,
   {{0xe29f0125,0x3ea94480,0x39404481,0x37aba17e}},	//   fið_, knat_, _spis_, _стан_,
   {{0x6d4f4482,0xe29f0125,0x6d5d4483,0x442e8358}},	//   _osca, gið_, _orsa, _ecf_,
   {{0xa509902f,0x3eb88019,0x3ea901d0,0x442e8580}},	//   _тела_, _írta_, dnat_, _fcf_,
   {{0x62898355,0x39408085,0x3940007a,0x70b40c28}},	//   _lleo, çisi_, _vpis_, ंकेल,
   {{0x62899cd5,0x39400035,0x6d5d4484,0xafe310ac}},	//   _oleo, _wpis_, _arsa, дорл,
   {{0x3ea94485,0x6d5d036e,0x6aad008b,0xd1322c7d}},	//   gnat_, _brsa, _gjaf, _قمع_,
   {{0x3940005c,0x660b8065,0x3ce300f3,0xf8bf286c}},	// [2e40] _upis_, _megk, _bijv_, rtér_,
   {{0x3ea93acd,0xa3d60740,0x85218e33,0x660b8019}},	//   anat_, ाइल_, _मिनट_, _legk,
   {{0x7ae43186,0x6d5d0910,0x2a6480b9,0x6d4f0c8c}},	//   _kiit, _ersa, _pnmb_, _esca,
   {{0x6d4f0580,0xfaa39246,0x7ae40df6,0x09de0264}},	//   _fsca, махо, _jiit, _ভ্যা,
   {{0xbcfb12ab,0x628290bd,0x82d703de,0x3ea04486}},	//   _créd, rkoo, קונג_, miit_,
   {{0x7ae40a92,0x6282c487,0x3ea04488,0xb4b3800f}},	//   _liit, skoo, liit_, झको_,
   {{0x200ea407,0xbcfb05db,0x443c81a1,0x8cb9175d}},	//   rafi_, _prég, _rbv_, ्तरो,
   {{0x7ae40364,0xf41f00ab,0x9f583673,0xbcfb0036}},	//   _niit, ন্দর_, laró_, _fréd,
   {{0xe29f01fa,0x78bc4489,0x2d801c5d,0x442e9a25}},	//   við_, korv, nyie_, _pcf_,
   {{0xb5fb1313,0x6fc0016f,0x7d1d8019,0x6aad02f7}},	//   _anál, _शुभं, ássa, _sjaf,
   {{0xe29f07ca,0x7bc3831d,0x7ae4448a,0x69c4448b}},	//   tið_, _cynu, _biit, _ayie,
   {{0xe8d90028,0xf8bf04c3,0x442e8609,0x81af0264}},	//   _trị_, guén_, _wcf_, _করব_,
   {{0xe29f07ca,0x3ea9001b,0x7ae4448c,0x78bc03ba}},	//   rið_, vnat_, _diit, forv,
   {{0xe29f007b,0x50ca852a,0x6d428037,0x7aeac48d}},	//   sið_, ितिष, _ipoa, _tuft,
   {{0x3f85003e,0xc058035f,0x200ca0b2,0x6448c48e}},	//   álu_, ція_, _medi_, medi,
   {{0x6448c48f,0x3ea000e4,0xe298038c,0x442cc490}},	//   ledi, giit_, _мај_, lgd_,
   {{0x3ea94491,0x7bce0088,0x442c81ed,0x98ca8035}},	// [2e50] rnat_, _azbu, ogd_, िताए,
   {{0x6448c492,0x442c9808,0x6d5d19ba,0x28d20035}},	//   nedi, ngd_, _vrsa, _दीपि,
   {{0x20114493,0x442cc494,0xa801816a,0x3ea92d24}},	//   mazi_, igd_, _íñig, pnat_,
   {{0xbcfb12ab,0x68ed4495,0x6d5d09d1,0x6abd1e34}},	//   _préd, _kuad, _trsa, nosf,
   {{0x68ed0748,0x6d4f0087,0x6d5d4496,0x59d34497}},	//   _juad, _usca, _ursa, _सरफर,
   {{0x64488025,0xbcfb03d3,0x201106a0,0x200c81a1}},	//   jedi, _crée, nazi_, _cedi_,
   {{0x02a78f04,0x200c817b,0x6448c498,0x6d4d4499}},	//   _драм, _dedi_, dedi, lwaa,
   {{0x6e2d449a,0x2011449b,0x6455449c,0x200c846d}},	//   ngab, hazi_, _hazi, _eedi_,
   {{0x20114289,0x7ae40009,0xe8d90133,0x61e98f3e}},	//   kazi_, _riit, _arọ_, _igel,
   {{0x7ae40364,0x442c8106,0x2011449d,0x68fb8122}},	//   _siit, ggd_, jazi_, _itud,
   {{0x6455449e,0x2909019d,0x395f8573,0x69c400b9}},	//   _mazi, _awaa_, _hrus_, _syie,
   {{0x6d4d449f,0x645544a0,0x442c8a0f,0x395f8461}},	//   kwaa, _lazi, agd_, _krus_,
   {{0x7ae444a1,0x68ed0c15,0x764982a3,0x6448c4a2}},	//   _viit, _cuad, meey, bedi,
   {{0x645544a3,0x6448be92,0x6d4d4499,0x20113e3e}},	//   _nazi, cedi, dwaa, gazi_,
   {{0x6e2d01ec,0x2aa40061,0x366a2639,0x7ae418c2}},	//   fgab, rűbb_, баво_, _tiit,
   {{0x61e9840c,0x61e482ce,0xf8bf44a4,0x68ed10eb}},	//   _ngel, žili, quén_, _fuad,
   {{0x645544a5,0x68ed4090,0x6d4d44a6,0x201144a7}},	// [2e60] _bazi, _guad, gwaa, bazi_,
   {{0x645544a8,0x31370051,0x6ad100c8,0xf8bf02be}},	//   _cazi, _צריך_, _সংযো, trée_,
   {{0xb5fb003e,0x645a00a9,0x395f8458,0x307b0039}},	//   _znám, _ótim, _arus_, _האינ,
   {{0x25ad003a,0x20c98013,0x31603cfa,0x3d1c8740}},	//   _žele_, súil_, _kriz_, _मिले_,
   {{0x645544a9,0x660439d1,0x200cc4aa,0x76498079}},	//   _fazi, mbik, _pedi_, deey,
   {{0x61ff8201,0x644881df,0x645544ab,0x660444ac}},	//   ıqla, xedi, _gazi, lbik,
   {{0x43430e86,0x200c8098,0x7d160b81,0x68fb902d}},	//   _перв, _vedi_, lsys, _etud,
   {{0x200ca0af,0xd90d8bca,0x20112767,0x64550234}},	//   _wedi_, _چین_, zazi_, _zazi,
   {{0x644887d9,0xc10680f7,0x395f92f1,0x7d1644ad}},	//   tedi, _رواي, _grus_, nsys,
   {{0x672380fe,0x6aa2804f,0x6f150035,0xc917807c}},	//   brnj, liof, yszc, _מחמת_,
   {{0x68ed1286,0x442c80f3,0x6448abc2,0x201144ae}},	//   _suad, rgd_, redi, vazi_,
   {{0x6448c4af,0x201144b0,0x752444b1,0xa25b00e7}},	//   sedi, wazi_, kriz, plôm,
   {{0x201130e1,0x6448c4b2,0x7aee022c,0x68ed1f21}},	//   tazi_, pedi, _lubt, _quad,
   {{0xe521800d,0xe8d900ff,0xb4db026b,0xe4d780d7}},	//   _मिति_, _trọ_, _apàn, _فونت_,
   {{0x645506b9,0x201144b3,0xddc9920e,0x6af380f7}},	//   _razi, razi_, mješ, _كثير,
   {{0xddc9af56,0x645544b4,0x6d4d44a6,0x68e5008e}},	//   lješ, _sazi, twaa, _wihd,
   {{0x645544b5,0x6e2d44b6,0xc8670ab2,0x95cb0f9c}},	// [2e70] _pazi, rgab, _етни, сува_,
   {{0x6d4d2229,0x2a690069,0x6e2d44b7,0x787d8036}},	//   rwaa, _hnab_, sgab, _lèvr,
   {{0x81af00c8,0x64550e64,0x628d190f,0x6d4d44b8}},	//   _করি_, _vazi, _klao, swaa,
   {{0x645528b2,0x752444b9,0x7aee009f,0x76498079}},	//   _wazi, briz, _dubt, xeey,
   {{0xdb188364,0x75240098,0x6d4d0359,0x645536a0}},	//   _hyvä, criz, qwaa, _tazi,
   {{0x81af0a49,0x26c90661,0x76499a2b,0x224b44ba}},	//   _করা_, llao_, weey, heck_,
   {{0xe73999b8,0xdb188198,0x7649c4bb,0x7aee0df6}},	//   цей_, _jyvä, teey, _gubt,
   {{0x61e900ce,0x395f8854,0xbcfb00e1,0x6564826c}},	//   želj, _trus_, _gréc, _šiha,
   {{0x395f9083,0xb3458073,0x764982a3,0x9f5c816b}},	//   _urus_, _opçã, reey, mavý_,
   {{0x660f44bc,0x3b85ac25,0x6d5b9ca7,0x212b016b}},	//   _leck, длог, rvua, duch_,
   {{0xf8bf0073,0x78a3807a,0x26c90699,0x628d0f35}},	//   guém_, minv, klao_, _blao,
   {{0x76498079,0x316044bd,0x628d0834,0xedd581a8}},	//   qeey, _priz_, _clao, _قياد,
   {{0x752987a3,0x62860364,0x3ead8687,0xcdcb853d}},	//   quez, rkko, mnet_, _اذان_,
   {{0x3ebf8e35,0x62860006,0x92ae00ab,0x661d128d}},	//   lout_, skko, কতে_, _adsk,
   {{0xfbd182f1,0x23d18035,0x81df00ab,0x3ead8168}},	//   _हरिम, _हरिद, দুল_, onet_,
   {{0x3eadc4be,0x3ebf800d,0x752444bf,0x212b44c0}},	//   nnet_, nout_, triz, buch_,
   {{0x660433b8,0x6da3002e,0xec7a24b2,0xe5a344c1}},	// [2e80] rbik, вита, опа_, вити,
   {{0x3eadc4c2,0x7524011e,0xfbd1903e,0x3ebf9151}},	//   hnet_, rriz, _हराम, hout_,
   {{0xbcfb03d3,0x3ebf83ec,0x752400dd,0x93c30087}},	//   _préc, kout_, sriz, _ţări,
   {{0x660f1486,0x8b651e09,0x65690fee,0x3ebf9a25}},	//   _geck, عالم, _šehe, jout_,
   {{0xd910803d,0x3cfd81c0,0xa3df02f1,0x2ee68362}},	//   ایط_, _ntwv_, देब_, _riof_,
   {{0x3eadc4c3,0xb5fb0144,0x32e802d0,0x787d8866}},	//   enet_, _anáh, _eşya_, _sèvr,
   {{0xddc98499,0x3eadc4c4,0xfaa6853b,0x44f28162}},	//   vješ, fnet_, _жаво, _sâ_,
   {{0x3ebf8e35,0x3ead920b,0xdb0e0035,0x7c3e0901}},	//   gout_, gnet_, _wybó, lfpr,
   {{0x3206c4c5,0xa3d60035,0xbcfb09c4,0xddc98140}},	//   mboy_, ाइक_, _kréa, tješ,
   {{0x3374879e,0x2126808e,0xb866a105,0x6ef58609}},	//   егор, mroh_, _تارو, _iġbn,
   {{0x3ebfc4c6,0xddc98639,0x3eadc4c7,0xda350e11}},	//   bout_, rješ, bnet_, нены,
   {{0xcfa98064,0x3206c4c8,0xdddb807a,0xbd4680f7}},	//   _عالم_, nboy_, skuš, _يناي,
   {{0xddc98499,0x68e8c4c9,0x224b1230,0xdb0a8106}},	//   pješ, _kidd, reck_, _nyfö,
   {{0x55778158,0x660f44ca,0x212b44cb,0x3dcd01b9}},	//   _קעגן_, _seck, ruch_, _ġew_,
   {{0x6d460bb6,0x212b01ec,0x660f136f,0x320682c4}},	//   _apka, such_, _peck, kboy_,
   {{0x443ec4cc,0x68e8c4cd,0x64588a55,0xbcfb010c}},	//   lft_, _lidd, _havi, _aréa,
   {{0x660f04b8,0xf8ae0077,0x6458c4ce,0x2d84b1f1}},	// [2e90] _veck, شکی_, _kavi, nyme_,
   {{0x645880ce,0xbcfb03d3,0xdb1880f2,0x26c9005c}},	//   _javi, _créa, _tyvä, slao_,
   {{0x660f00f2,0x3ead8aa2,0x443ec4cf,0x6458c4d0}},	//   _teck, ynet_, ift_, _mavi,
   {{0x64588247,0x661d013c,0xe29880e8,0x69dd816b}},	//   _lavi, _udsk, має_, _úsek,
   {{0x29190364,0xa069a48f,0xaca3019d,0xdb1c05b9}},	//   nssa_, зала_, _abục, _vyrá,
   {{0xbcfb0013,0x68e8c4d1,0x443e8a0f,0x29190364}},	//   _gréa, _cidd, jft_, issa_,
   {{0x68e88114,0x78a3c4d2,0x65628db1,0x3eadc4d3}},	//   _didd, rinv, _aroh, tnet_,
   {{0x61ed44d4,0x443e80f3,0x68e88114,0x6458aeac}},	//   _ngal, eft_, _eidd, _aavi,
   {{0x443eb13a,0xdbd68364,0xc0cbc4d5,0x3ebf9823}},	//   fft_, _lääk, _дуже_, rout_,
   {{0xe1fa00ba,0x6458c4d6,0x61ed44d7,0xb4b981ab}},	//   ूर्ण_, _cavi, _agal, चवे_,
   {{0x6458c4d8,0x29190364,0x7ae98084,0x53c980e8}},	//   _davi, essa_, _kiet, ягом_,
   {{0x60c5008e,0x7e7d00eb,0x2d848216,0x656f8192}},	//   _akhm, _nosp, byme_, ächs,
   {{0x7ae9c4d9,0xf2d280be,0x961500ab,0x61fb804f}},	//   _miet, טעט_, িলাম_, _mful,
   {{0x7ae9c4da,0x61ed44db,0xe00282f1,0x752d0ab3}},	//   _liet, _egal, रुपद_, duaz,
   {{0x2bc69664,0xb4cb8361,0xfbc6800d,0x26c0047f}},	//   _रुपा, लती_, _रुपम, toio_,
   {{0x7ae9c4dc,0x64588b48,0xe81c000d,0x139a8039}},	//   _niet, _zavi, _भएका_, _מבצע,
   {{0x7e7d1284,0x753bc4dd,0x69c9c4de,0xd9de00ab}},	// [2ea0] _dosp, ntuz, _nyee, _ভ্রম,
   {{0xe0d22219,0x6ab88996,0x6458c4df,0x26c000e5}},	//   _حزب_, इक्र, _xavi, soio_,
   {{0x7ae9c4e0,0x389b0158,0xb2269cae,0x7e6b82c4}},	//   _biet, _זיינ, емел, _ongp,
   {{0x68e8c4e1,0x7ae980eb,0x7e7d44e2,0x2ca5977a}},	//   _sidd, _ciet, _gosp, hild_,
   {{0xc1e78009,0x290d8326,0xe9478019,0x752d00e5}},	//   ньше_, _cwea_, ٹرنی, cuaz,
   {{0x59d304e5,0x7e6b81e0,0x66160df6,0x61fb8c2e}},	//   _सरसर, _angp, layk, _eful,
   {{0xb5fb0013,0x7ae9a6bc,0x6458c4e3,0x0cbe14d5}},	//   _snái, _fiet, _ravi, ्तीम,
   {{0x6458b386,0xd6d784d9,0xddcd01dd,0x661601e0}},	//   _savi, нты_, ljaš, nayk,
   {{0x6458c4e4,0xa90a80a0,0x7ae38fb0,0x290001c0}},	//   _pavi, _ريال_, ïnte, _ntia_,
   {{0xd91b8051,0x4f96a7d4,0x253700be,0xb4db026b}},	//   _מומל, _преу, עניש_, _apàj,
   {{0xa3d6005e,0x443ec4e5,0x64588b80,0x61ed00b9}},	//   ाइट_, rft_, _vavi, _pgal,
   {{0x273a80f1,0xdbd68074,0x2d848216,0x6458c4e6}},	//   mën_, _rääk, pyme_, _wavi,
   {{0x2ca5c4e7,0x273a80f1,0xd2510077,0x1a9b80be}},	//   bild_, lën_, هنگ_, ליטע,
   {{0x7e7d44e8,0xbcfb0176,0xdbd68198,0x3a2002d0}},	//   _sosp, _brén, _pääk, _edip_,
   {{0x921089a3,0x273a820f,0xd9048117,0x6e671383}},	//   ाराज_, nën_, _گی_, нтаж,
   {{0x41de0076,0x752d44e9,0x61ed44ea,0xadc3846d}},	//   नेहस, tuaz, _ugal, _akẹk,
   {{0xd90499f7,0x273a80f1,0xdd9401bb,0x7ae9c4eb}},	// [2eb0] _دی_, hën_, гаты, _riet,
   {{0x7ae9c4ec,0x273a80f1,0xe802801b,0x752d0ab3}},	//   _siet, kën_, रुमा_, ruaz,
   {{0x7ae9c4ed,0x273a80f1,0x7e7d1c33,0x69c982c4}},	//   _piet, jën_, _tosp, _syee,
   {{0xed510117,0x386c8267,0x78a700f3,0x273a8168}},	//   _پھر_, _andr_, lijv, dën_,
   {{0x7ae9c4ee,0xe8f88221,0x273a80f3,0xddcd0503}},	//   _viet, елі_, eën_, bjaš,
   {{0x07a590ca,0x8fa59597,0x26c6a9cf,0xad9b026b}},	//   калн, кале, _akoo_, _afúg,
   {{0x7ae9c4ef,0x273a80f1,0x6b83016d,0x394900ee}},	//   _tiet, gën_, ängd, _lpas_,
   {{0xdddd00eb,0x2ca5874c,0x92588071,0x78a701ed}},	//   _nosū, wild_, _паст_, hijv,
   {{0x2d8b83cb,0x648d80f7,0x39490282,0x81b00326}},	//   áce_, _dúin, _npas_, _keɓe,
   {{0xb4cba967,0x44330683,0x4c8582eb,0x9d44b1a7}},	//   लते_, ngx_, тлов, ائين,
   {{0x394944f0,0x7d042f09,0x3a200101,0x6aa62793}},	//   _apas_, zpis, _pdip_, tikf,
   {{0xfeb88013,0x60c39727,0xddcd011f,0xfaa644f1}},	//   _كانت_, lonm, zjaš, тамо,
   {{0xe297334f,0x82768158,0x6609c4f2,0x7e9a83de}},	//   тая_, דערע_, mbek, _קסנו,
   {{0xbcfb3b9b,0x9103002e,0x9345813a,0x26cd816a}},	//   _prén, рпре, _анке, lleo_,
   {{0xe7370256,0x7d1bc4f3,0xb8ca341c,0x3f8c016b}},	//   кер_, lsus, _खग_, ádu_,
   {{0x7d040025,0x61ed811f,0xbcfb2f76,0xe3e880be}},	//   tpis, žalj, _créo, _אַפֿ,
   {{0xdee33504,0x7bd50081,0x66e303c7,0x66160079}},	// [2ec0] роти, _azzu, рота, rayk,
   {{0x14c803f8,0x0cbe023c,0xbcfb03b0,0x7d040057}},	//   رهای_, ्तेम, _trén, rpis,
   {{0x201844f4,0x91f6000f,0xddc2805c,0x7dd8026b}},	//   mari_, _इलाज_, _mnoš, _búsí,
   {{0x201844f5,0x7d1ba88c,0x273a80f1,0xd36f00f7}},	//   lari_, ksus, vën_, تهم_,
   {{0xdb0e0106,0x2a7f8242,0x7bd5038a,0xc02f0129}},	//   _nybö, _doub_, _ezzu, _điếu_,
   {{0x273a88cf,0xa3df0b75,0xd90d80d5,0xe0438012}},	//   tën_, देह_, سیم_, инчи,
   {{0x64a32183,0xdca30a7c,0xdb1c01a3,0x75298c2e}},	//   _тара, _тари, _byrå, erez,
   {{0x273a820f,0x201844f6,0x6b830b2f,0x66098091}},	//   rën_, hari_, änge, gbek,
   {{0x645c44f7,0x64419849,0x273a820f,0x7d1b9066}},	//   _kari, ffli, sën_, gsus,
   {{0xa3df03b7,0x201844f8,0x290686cb,0x3eb20009}},	//   देव_, jari_, mpoa_, hnyt_,
   {{0xf4fc8133,0x7529c4f9,0xbddb010c,0x5fb6873c}},	//   _dịịr, arez, _abèl, _अखिल,
   {{0x645c44fa,0x26cda3a5,0x2fd7803d,0xc33302f6}},	//   _lari, cleo_, _شوند_, סור_,
   {{0x81e480c8,0x6280c4fb,0x6e228135,0x7529a4f5}},	//   পুর_, _momo, _idob, crez,
   {{0x645c44fc,0x4ec400ab,0x9f35102a,0x6280c4fd}},	//   _nari, ্দোল, легі, _lomo,
   {{0x9cd78039,0x78a744fe,0x6cd980be,0xbcfb0036}},	//   _שווה_, rijv, _אַקצ, _préo,
   {{0x6280c4ff,0x645c4500,0x9f98826f,0x26c4c501}},	//   _nomo, _aari, jším_, nomo_,
   {{0x645c4502,0x20184503,0x35f44504,0x44384505}},	// [2ed0] _bari, bari_, рпур, _bcr_,
   {{0x645c4506,0x7d1d83a7,0x26c481e0,0xa855260c}},	//   _cari, ássi, homo_, _скоч,
   {{0x645c16a7,0x26c494c6,0x6280bef3,0x7aed276f}},	//   _dari, komo_, _bomo, _kiat,
   {{0x3e040081,0x6e22c507,0x7aed0609,0x60da852a}},	//   _вярв, _ndob, _jiat, _ahtm,
   {{0x645c4508,0x6280c509,0x7aed0065,0xbcfb037d}},	//   _fari, _domo, _miat, _krém,
   {{0x645c1a8d,0x3ea9450a,0x765d111e,0x2ecb89c2}},	//   _gari, liat_, _hasy, ात्त,
   {{0xb6a59a07,0xa3df450b,0xa283803d,0x7d02c50c}},	//   ликл, देश_, _پیشو, _atos,
   {{0x7529c50d,0x645c450e,0x7d1b8006,0x2018450f}},	//   trez, _zari, tsus, zari_,
   {{0xd4159641,0x20184510,0x765d1904,0x59b7800f}},	//   льны, yari_, _masy, _आखिर,
   {{0x645c4511,0x13098364,0x7529c512,0x6e228135}},	//   _xari, нной_, rrez, _edob,
   {{0x26cd85b4,0x3eb20364,0x6280836a,0x6441c513}},	//   pleo_, ynyt_, _yomo, rfli,
   {{0x765d0247,0x26c4b8ef,0x7aed4514,0x64419bd9}},	//   _nasy, como_, _ciat, sfli,
   {{0x7aed0500,0x3ea94515,0x8c458be2,0xe56e84ae}},	//   _diat, diat_, _беле, _уз_,
   {{0x6d59bb77,0x03198013,0x7e7b805c,0xddc2825b}},	//   _iswa, _كتبت_, ljup, _unoš,
   {{0x20184516,0x645c04b9,0x7aed0019,0x765d4517}},	//   rari_, _rari, _fiat, _basy,
   {{0x645c4518,0x7aed4519,0x998601ad,0xbcfb026b}},	//   _sari, _giat, _ملبو, _erém,
   {{0xcbb00a49,0x056611e9,0x8d662252,0x765d0359}},	// [2ee0] _করেছ, ыван, ывае, _dasy,
   {{0x628090dd,0x645c451a,0x399b01c6,0x6d59a7c7}},	//   _somo, _qari, _נייד, _mswa,
   {{0x032628b4,0x3ea9451b,0x26c4804f,0x4b2602de}},	//   уден, biat_, yomo_, умев,
   {{0xe297c51c,0x3ea913f0,0x6d4bc51d,0xdce284b7}},	//   лах_, ciat_, _opga, _proċ,
   {{0x645c451e,0xa9678d69,0x19588190,0x9f98816b}},	//   _tari, лица_, талы_, rším_,
   {{0x44380216,0xd00f81a8,0xe8d90129,0x6e36451f}},	//   _ucr_, كله_, _trễ_, lgyb,
   {{0x7af500ad,0x7d028063,0x6d4b8bb6,0xb4e02120}},	//   _guzt, _stos, _apga, दगी_,
   {{0x21200025,0x7f3b00be,0x44443780,0x212b0114}},	//   _ovih_, געקו, lf_, yrch_,
   {{0x7aed4520,0x26c4c521,0xa8368065,0xddc404b7}},	//   _riat, romo_, _معاش, jjiż,
   {{0xb99380f7,0x26c4a1bb,0x212b016b,0xb80a81a8}},	//   _الكب, somo_, vrch_, _أيام_,
   {{0x44444522,0x7aed4523,0x6d4b8118,0x69cd008e}},	//   if_, _piat, _epga, _syae,
   {{0x6e228805,0xf1b88c87,0x6484851e,0x92580198}},	//   _udob, _अशान, _còir, гают_,
   {{0x7aed285e,0xa802017b,0x3ea94524,0x32190690}},	//   _viat, ğınd, viat_, rasy_,
   {{0x44440613,0xa80202bb,0xe3a4803d,0x7c38817f}},	//   jf_, şınd, _پشتی, _ucvr,
   {{0xd6db00ae,0x765d4525,0x7ae2816d,0x6d408965}},	//   ета_, _pasy, kmot, ltma,
   {{0x7bd8803a,0x6e36008e,0x61ed811f,0x5e5800e8}},	//   _izvu, ggyb, žali, лися_,
   {{0x44444526,0x6d40c527,0x1fe1ab38,0xf1a48035}},	// [2ef0] ff_, ntma, _पण्ड, _खेलन,
   {{0x3ea911d6,0x78a5007b,0xe1ff4528,0x765d3b39}},	//   siat_, _umhv, lcó_, _wasy,
   {{0x3ea94529,0x1cbb80be,0x75eb8019,0x3d1b026b}},	//   piat_, עמבע, _közü, _bàwá_,
   {{0x44440c72,0xe1ff0216,0x291d8a03,0x7ae2c52a}},	//   af_, ncó_, tswa_, gmot,
   {{0x660d3bde,0x224908b3,0x444400b9,0x81b009ab}},	//   mbak, _mbak_, bf_, _keɓa,
   {{0x660d035f,0x3ea69cca,0x5f05a844,0x60c70168}},	//   lbak, _amot_, азка, nojm,
   {{0x96958088,0x752d00b9,0x7ae29500,0x3d1b026b}},	//   ириш, lraz, bmot, _fàwá_,
   {{0x31690d38,0x660d0102,0xada600e1,0x752d0ab3}},	//   _oraz_, nbak, slúž, oraz,
   {{0x212b8028,0x60c7452b,0xef190035,0xdf61846d}},	//   _ích_, kojm, ąży_, _bẹ́è,
   {{0x3ea680f2,0x66f18029,0x1035803d,0x6aab928d}},	//   _emot_, _sāku, _خبرگ, ligf,
   {{0x21200025,0xe29a1612,0x752d001b,0x2bfb85fc}},	//   _svih_, ван_, hraz, लुगू_,
   {{0x09e61056,0xfc3f800d,0x91e60652,0x752d452c}},	//   ионн, ří_, ионе, kraz,
   {{0x6d59c52d,0x89d6021e,0x6f050090,0x6d408bfd}},	//   _uswa, рінш, _athc, ctma,
   {{0x661bc52e,0x752d0503,0x7ae28289,0x225fc52f}},	//   lauk, draz, zmot, _lauk_,
   {{0x44fb879f,0x752d011e,0x7d09987a,0xdb038980}},	//   _hê_, eraz, lpes, _exnò,
   {{0x44fb801c,0xfb24803d,0x316903ec,0x75eb83bf}},	//   _kê_, _اروپ, _fraz_, _gözü,
   {{0x752d2444,0xf8bf4530,0xa3e8086a,0x394d8282}},	// [2f00] graz, gués_, मेन_, _npes_,
   {{0x44444531,0x2a600282,0x661bc532,0x44fb801c}},	//   uf_, _haib_, hauk, _mê_,
   {{0x44444533,0x66f18029,0x44fbc534,0x660d4535}},	//   rf_, _māks, _lê_, bbak,
   {{0x752d0ed7,0xd7bb0051,0xe24680f7,0x661bc536}},	//   braz, _יציר, شخصي, jauk,
   {{0x28db1094,0x661b86ac,0x752d047f,0x444401ec}},	//   _मीडि, dauk, craz, pf_,
   {{0xdce28025,0x2a600282,0x7e0e863a,0x6284159d}},	//   _proč, _laib_, सर्ग_, _loio,
   {{0xe7e18074,0xd3721a3e,0x20c981a8,0xc1d34537}},	//   गेला_, _ظهر_, túir_, _सर्ग,
   {{0xdce28353,0x2a604538,0x629981ec,0x44fb80ff}},	//   _vroč, _naib_, chwo, _bê_,
   {{0x8c3c8214,0xddc98214,0x394001c5,0x66fc016b}},	//   liği, rdeş, _nqis_, _očko,
   {{0x44fbc539,0x6721081d,0x75eb8059,0x07a68389}},	//   _dê_, šlji, _sözü, _казн,
   {{0x99920176,0x628407b6,0x3169128a,0x57fbb7b6}},	//   _deyō_, _boio, _sraz_, _סלאו,
   {{0x201cc53a,0x38ad0267,0x661b82f7,0x62840362}},	//   lavi_, džra_, cauk, _coio,
   {{0x6602c53b,0x2a6001c0,0xe1ff1d4e,0x60c70168}},	//   _ifok, _daib_, rcó_, tojm,
   {{0xda0712e0,0x8d85804e,0x6296453c,0xe1ff453d}},	//   _व्रत_, _دشمن, _elyo, scó_,
   {{0x2a600069,0x629602f7,0x629880eb,0x60c70fd4}},	//   _faib_, _flyo, īvoj, rojm,
   {{0x35f5453e,0x8c3c87d9,0x2a60061b,0x316903a7}},	//   спар, diği, _gaib_, _traz_,
   {{0x201c8796,0x95cb0f9c,0x752d28a4,0x44fb827d}},	// [2f10] kavi_, тува_, uraz, _xê_,
   {{0x752d282d,0x70551125,0x7af881c0,0xf367453f}},	//   rraz, _اندا, _kuvt, итен,
   {{0x201c8214,0x6a1780f7,0xa8560039,0x6aabc540}},	//   davi_, لبشر, _היתה_, tigf,
   {{0x752280d2,0x2a6001c5,0x6235acab,0x99d981a8}},	//   _ovoz, _xaib_, седу, هواء_,
   {{0xf8bf4541,0xaca48032,0xe8d90133,0x7afb0390}},	//   qués_, _ajọy, _nsị_, _čutu,
   {{0x386102af,0x88c880e8,0x6602826b,0x6d5d4542}},	//   _jahr_, алів_, _afok, _issa,
   {{0xfbe5150b,0xe3e500c8,0x44fb84df,0xb3e500c8}},	//   _প্রত, _প্রব, _sê_, _প্রজ,
   {{0x02a4c543,0x9454011c,0xbcfb4544,0xcfb801c6}},	//   _друм, _çərş, _préh, ילוי_,
   {{0x201c803a,0x661bc545,0x6aa99d23,0x443c8144}},	//   bavi_, rauk, _imef, _bcv_,
   {{0x661b8029,0x2a6001e9,0x44fbc546,0x7522acf6}},	//   sauk, _saib_, _vê_, _dvoz,
   {{0x7d09c547,0x1fa7af63,0x661b8009,0x2a600282}},	//   spes, _траг, pauk, _paib_,
   {{0x7d09ae2b,0xdb1e801b,0x2a600069,0xc7b281c6}},	//   ppes, íván, _qaib_, _צבא_,
   {{0xddc982fd,0xd6c68077,0x3eadc548,0x75229487}},	//   ljež, _امنی, miet_, _gvoz,
   {{0x3eadc549,0xbcfb01a8,0xe73a33e5,0x40951229}},	//   liet_, _gréi, лег_, орст,
   {{0xd62a0539,0xdfd200f7,0x2a600748,0x6d5d454a}},	//   лове_, سير_, _taib_, _assa,
   {{0x3eadb5ab,0x629880eb,0x201c935a,0x6abb826c}},	//   niet_, īvok, zavi_, _njuf,
   {{0x6b830884,0x44278748,0xa2c50519,0x98a60198}},	// [2f20] ängn, _kdn_, रवर्, _гипе,
   {{0xb97b0039,0x6aa9804f,0x8c3c8214,0xa3ab83eb}},	//   _עניי, _amef, tiği, _गधा_,
   {{0x6d5d454b,0x8c1a8039,0x201c8669,0x0b461383}},	//   _essa, רועי, vavi_, снен,
   {{0x3eadb086,0xf8bf0019,0x320239cb,0x8c3c82d0}},	//   jiet_, tség_, ncky_, riği,
   {{0x7243803d,0x3eadc54c,0x64430722,0x442780fe}},	//   سپول, diet_, ònic, _odn_,
   {{0x2eb29c5f,0x6aa98133,0xddcd0085,0x0496066e}},	//   ुक्त, _emef, ldaş, _السح,
   {{0x6d44454d,0xf8bf0019,0x9f580216,0xe809016f}},	//   ltia, sség_, mbró_, वडता_,
   {{0xddcd0059,0x201a179d,0xe297c54e,0x7e64454f}},	//   ndaş, _lepi_, _лас_, ndip,
   {{0x6d444550,0x4427c551,0x25a0011c,0x5eff03b7}},	//   ntia, _bdn_, nzil_, _शून्_,
   {{0x201a010c,0xb4c298b8,0x81ae0264,0x6d444552}},	//   _nepi_, ंवे_, কথা_, itia,
   {{0x3eadc553,0x6d444554,0xf8bf0036,0x2cacc555}},	//   biet_, htia, nsée_, ridd_,
   {{0x59aa09a3,0x6d44085c,0x3eadc556,0x4427acfe}},	//   _चेहर, ktia, ciet_, _edn_,
   {{0xbcfb00f7,0x7e644557,0xad9b4558,0x6d4401c0}},	//   _tréi, ddip, _afún, jtia,
   {{0x443c8144,0x321d8035,0xf99f0037,0x201a2153}},	//   _ucv_, zawy_, rzè_, _cepi_,
   {{0x201a0205,0x7e6282c4,0x25a00122,0x2bcfbb6b}},	//   _depi_, _kaop, ezil_, _सुपा,
   {{0xa3be0074,0x38610192,0x7c3a8a53,0x644889ff}},	//   ुअन_, _wahr_, lgtr, lfdi,
   {{0x7bdc00ee,0x6d44022c,0x9419098d,0xad9b0032}},	// [2f30] _azru, gtia, ижат_, _efún,
   {{0x7c3ac559,0x3ead81a9,0x1dba0a27,0x00000000}},	//   ngtr, ziet_, _इशरत, --,
   {{0xd3710013,0x69c082a3,0xd9f995fe,0x321d8035}},	//   بها_, _axme, анец_, tawy_,
   {{0xddc9920e,0x7e629c32,0xa3e8064a,0x6aaf0122}},	//   vjež, _naop, मेध_, nicf,
   {{0x2bcf85e8,0xa92480e8,0x2bdb05fc,0xbcfb016a}},	//   _सुना, зділ, _भरवा, _arév,
   {{0x2003009a,0xa069942e,0x2909004f,0xd8388b80}},	//   ncji_, рака_, _mtaa_, _omču_,
   {{0x3eadc55a,0x7d0d0137,0xe8d90870,0x6457455b}},	//   tiet_, lpas, _nsọ_, mexi,
   {{0x6457455c,0x44278ad4,0x6aa980b8,0x7e62c55d}},	//   lexi, _sdn_, _umef, _caop,
   {{0x0c798e11,0x20030063,0x7d0d455e,0xe8d901bc}},	//   асны_, kcji_, npas, _asọ_,
   {{0x64570baf,0x3eadc55f,0x4b25a523,0x8d5c025f}},	//   nexi, siet_, омов, רכזי,
   {{0x6d44011e,0x3f678289,0xa49b2c5a,0x68fb8198}},	//   ztia, _uđu_, _atòk, _huud,
   {{0x201a4560,0x7d0d06cb,0x316d8267,0x39ea229c}},	//   _sepi_, kpas, _krez_, идно_,
   {{0x6abd0661,0x7d0d090d,0x224d88f9,0x68fbc561}},	//   érfa, jpas, _mbek_, _juud,
   {{0x68fb8006,0x64b80a0d,0xfd62819d,0xf8bf1dd8}},	//   _muud, _आदेश, _latị, ysée_,
   {{0x6b831647,0x7c648019,0xaac9a7cf,0x921983eb}},	//   ängl, _راول, िकाक, दराज_,
   {{0x6e3bc1d3,0x6d444562,0x52763592,0x316d8162}},	//   ngub, ttia, _фуку, _orez_,
   {{0x201a010b,0x7d0d10c1,0xddcd0085,0x64968087}},	// [2f40] _tepi_, gpas, rdaş, _mâin,
   {{0x3a3f8580,0x7698026b,0x61e6928a,0x224d82f9}},	//   _acup_, _díya, _úkli, _abek_,
   {{0x6d444563,0x2bcf816f,0x7d0d4564,0xe1fa82ee}},	//   stia, _सुमा, apas, аге_,
   {{0x316d8db7,0x2005c565,0x7bdc016b,0x6d444566}},	//   _brez_, _afli_, _vzru, ptia,
   {{0xf8bf00e7,0x18748d8e,0x6f088144,0xc7b880fe}},	//   ssée_, згля, _stdc, _međe_,
   {{0x7e62a997,0xf72aa001,0xbcfb4567,0x24878247}},	//   _saop, аций_, _prév, _nonm_,
   {{0xab274568,0xd2598176,0x644e0372,0x7bdc4569}},	//   _мора_, _djņb_, _ibbi, _uzru,
   {{0x660409c3,0xf5269b02,0x6569456a,0xc7b8826c}},	//   ncik, офон, _šehi, _neđe_,
   {{0x75243a05,0x7e9b03c8,0x22b601a9,0x20030035}},	//   nsiz, יסקו, cāki_, ycji_,
   {{0x7afc456b,0x22404001,0x60c200f7,0x62828009}},	//   _kurt, _acik_, _íomh, ljoo,
   {{0x660403ac,0x442a011c,0x316002d6,0xc60681e2}},	//   kcik, _mdb_, _asiz_, _дзей,
   {{0x6282c56c,0x929401e2,0x39468084,0x752438ad}},	//   njoo, даюц, otos_, ksiz,
   {{0x394687a3,0x6e20c56d,0x644e01e8,0x6ef58084}},	//   ntos_, mamb, _obbi, _išba,
   {{0x6e20c392,0x3946b09d,0x6ab786ab,0xc0cb407a}},	//   lamb, itos_, _अद्र, руме_,
   {{0x58d41cae,0x7d0d0037,0x14c78d1c,0xeeab456e}},	//   форт, wpas, रकरण, атак_,
   {{0x644e456f,0x7d0d0f33,0x3946adab,0xc3338039}},	//   _abbi, tpas, ktos_, _חוק_,
   {{0x6457062f,0x7afc0102,0x6e20804f,0xa3e81130}},	// [2f50] texi, _aurt, iamb, मेस_,
   {{0x6e20be9d,0x644e026c,0xd5b80d8e,0xc954007c}},	//   hamb, _cbbi, іст_, _חמץ_,
   {{0x68fbc570,0x7afc1f21,0xdce4016b,0x2a648326}},	//   _suud, _curt, cvič, _bamb_,
   {{0x7d0d4571,0x68fb8006,0xbcfb087a,0x6e20c045}},	//   ppas, _puud, _brét, jamb,
   {{0x661d0bb6,0xa9698dfd,0x21390147,0x21698258}},	//   _iesk, сила_, nush_, сили_,
   {{0xa5bb01a8,0x7afc4572,0xacfa01c6,0x26cf81a1}},	//   _ndói, _furt, _להשכ, _skgo_,
   {{0x44210812,0x661d0181,0x7afc4573,0x2a6680e4}},	//   mah_, _kesk, _gurt, bdob_,
   {{0x4421059c,0x6e208f18,0xbcfb07ca,0x213900f1}},	//   lah_, gamb, _frét, kush_,
   {{0x661d4574,0x3946c575,0x395f9295,0x2d8b82be}},	//   _mesk, ctos_, _usus_, âce_,
   {{0x442120a7,0x23bf035a,0x6aad1eda,0x7afc02d0}},	//   nah_, _एखाद, _amaf, _yurt,
   {{0x44214576,0x6e20acf2,0x2d82804a,0xbb428190}},	//   iah_, bamb, øker_, неэк,
   {{0x44214577,0x661d4578,0x6e20c579,0x213902f7}},	//   hah_, _nesk, camb, fush_,
   {{0x44210812,0xed58804a,0xe80281d0,0x24878242}},	//   kah_, _мої_, रुका_, _tonm_,
   {{0x20cb9e3c,0xf8bf1ee8,0xdce4222b,0x450900ab}},	//   िविध, drés_, tvič, _লিংক_,
   {{0x442114ec,0x66e628a7,0x661d457a,0x39468019}},	//   dah_, зова, _besk, ztos_,
   {{0xa5bb002a,0x661d1f3e,0x75242353,0x442a1a25}},	//   _xeóg, _cesk, tsiz, _sdb_,
   {{0x4421059c,0x7afc457b,0xf8bf3dc9,0x442a02f7}},	// [2f60] fah_, _surt, grés_, _pdb_,
   {{0x4421059e,0x7afc14ed,0x6e208dbb,0x7c218b81}},	//   gah_, _purt, zamb, nalr,
   {{0x6e20c57c,0xbcfb0036,0x7afc0085,0x6289810c}},	//   yamb, _brés, _qurt, _boeo,
   {{0x661d079f,0xbcfb0036,0x37d18264,0x254e0ec3}},	//   _gesk, _prét, াধার, tēlā_,
   {{0x4421457d,0x22b8807a,0x6e20c57e,0x62829c0a}},	//   bah_, nčki_, vamb, rjoo,
   {{0x442122b0,0x98a39e4e,0x6e208f0d,0x10a39017}},	//   cah_, ниче, wamb, ничн,
   {{0xb4d809a3,0x6e208545,0xfbc30221,0x7ae429db}},	//   ाती_, tamb, _збро, _ohit,
   {{0x39468511,0x2bcf89a9,0x3da680e8,0x7e664069}},	//   ptos_, _सुधा, зроб, _jakp,
   {{0x6e20c57f,0xa3e8009a,0x7e664507,0xa49b4580}},	//   ramb, मेर_, _makp, _awòy,
   {{0x7ae4313e,0x61e08bcf,0x7af60176,0x32068144}},	//   _ahit, _izml, _aiyt, lcoy_,
   {{0x6e208010,0x7ae40046,0xb5fb04be,0x623516cf}},	//   pamb, _bhit, _baál, мену,
   {{0x7ae44581,0x4421457d,0x201e95c8,0xb4d8114f}},	//   _chit, zah_, _heti_, ातु_,
   {{0x44213745,0x5bb903ca,0xa3d3000d,0xcfaa00ab}},	//   yah_, _आश्व, _हुन_, _খুলন,
   {{0x7ae40006,0x201e80ee,0x212d001b,0xa3b480e8}},	//   _ehit, _jeti_, šeho_, _облі,
   {{0xc7c40758,0x44214582,0x4fc40ff7,0x661d04c4}},	//   ести, vah_, еста, _pesk,
   {{0x44210812,0xddc29807,0x443e95ce,0x201ec583}},	//   wah_, _množ, lgt_, _leti_,
   {{0x4421059e,0x7e6603e9,0xbcfb046d,0x661d4584}},	// [2f70] tah_, _dakp, _arér, _vesk,
   {{0x645ac03f,0x6728830b,0x443e81e3,0x656f05b9}},	//   neti, _ovdj, ngt_, _vrch,
   {{0x44211e92,0xbcfb03d3,0x661d0025,0x6abd4585}},	//   rah_, _prés, _tesk, onsf,
   {{0xd3668077,0xb184826f,0xf8bf07f1,0xdd9501e5}},	//   _یه_, _šťas, prés_, _жамы,
   {{0x442139c5,0x656f0c41,0x201e8102,0x22b601a9}},	//   pah_, _urch, _beti_, cāku_,
   {{0x68ff02c1,0x443e8a0f,0x44210455,0xe7e41344}},	//   _muqd, jgt_, qah_, _गरमा_,
   {{0x645ac586,0x201e8038,0xbcfb4587,0x65628a03}},	//   deti, _deti_, _trés, _asoh,
   {{0x443ec588,0x22b600eb,0x2d9596ba,0x68f701b4}},	//   egt_, nākt_, дрос, _lixd,
   {{0xdddd009a,0x62988029,0x7c218c44,0x3a2d810c}},	//   _hasł, īvot, talr, _idep_,
   {{0x7ae44589,0x443ec58a,0x7305816c,0x201e807b}},	//   _shit, ggt_, мпоз, _geti_,
   {{0xe1ff05e4,0x9c87001b,0x7fb980d7,0x60c481a8}},	//   rdón_, _začá, _بهار_, éime,
   {{0xd5ae8bca,0x443e8a0f,0xe2970c73,0x648d81a8}},	//   افی_, agt_, даю_, _cúir,
   {{0x645ac58b,0x648d80f7,0x8c458dbd,0x7c2988ed}},	//   beti, _dúir, _желе, _долг_,
   {{0x7ae40039,0x645ac58c,0x7e66458d,0x22b882d4}},	//   _whit, ceti, _sakp, rčki_,
   {{0x6d499a2f,0x61fbc58e,0x7ae4458f,0x7e664590}},	//   ltea, _ogul, _thit, _pakp,
   {{0xe8d90028,0x61fbc591,0x7e69a86c,0x7ae44592}},	//   _trở_, _ngul, ndep, _uhit,
   {{0x3ea01384,0x6fe71a25,0x17fa01a8,0x75d30174}},	// [2f80] rhit_, técé, _وردة_, نيفا,
   {{0x62860024,0x61fbc593,0xb4d800dc,0xc7b8805c}},	//   ljko, _agul, ाते_, _leđa_,
   {{0xe814053e,0xa3e8101c,0x307b0039,0x201ec594}},	//   _त्या_, में_, _ואינ, _reti_,
   {{0x645ac595,0x673c16f2,0x201ec596,0xe9da8b41}},	//   zeti, murj, _seti_, оке_,
   {{0x443e8bfa,0xbcfb00e7,0xba480110,0x645ac597}},	//   ygt_, _fréq, _grįž, yeti,
   {{0xd00f8624,0xf2bb1a42,0x3a2dc598,0x6d4980f7}},	//   لله_, _उद्घ, _edep_, dtea,
   {{0x201ec599,0x290d8118,0x36d48878,0x321f8176}},	//   _veti_, _etea_, нокр, _feuy_,
   {{0xebe317ae,0xcfc000ab,0x6e24459a,0x769c810c}},	//   _росп, _ইরান, naib, _béya,
   {{0x645ac59b,0x1ee88065,0x8146803d,0x63ae0084}},	//   teti, _ہوئی_, _زنان, žinė,
   {{0xe57100be,0x2bcf8c2d,0x443ec59c,0x61fb8140}},	//   אַט_, _सुहा, ugt_, _zgul,
   {{0x443ec59d,0xd6cfc107,0x6e24009c,0xc7b8826c}},	//   rgt_, _ат_, kaib, _feđa_,
   {{0x645a825b,0x3a2008e9,0x6e2410e1,0x656280a4}},	//   seti, _ceip_, jaib, _tsoh,
   {{0x7c2e2997,0x659691cc,0x6d49aab0,0xbcfb002a}},	//   _odbr, _تجار, ctea, _asén,
   {{0xe3af95e4,0x29000980,0x69b1820e,0x2bcfa7fb}},	//   اری_, _duia_, _आइसी, _सुवा,
   {{0xf3638048,0xf1b98916,0xbddb026b,0xceb40085}},	//   _атын, _meša_, _abèp, fiə_,
   {{0x1de285b3,0x76408683,0xdddb9487,0x6e24459e}},	//   _परात, ngmy, ljuš, gaib,
   {{0x2900459f,0x3d1a001b,0xd7fb1a51,0x7d0d83ed}},	// [2f90] _guia_, मीले_, _мун_, _çast,
   {{0x2a692eb6,0xdddb80fe,0x66de83ed,0x61e01238}},	//   _haab_, njuš, këko, ümle,
   {{0x5fae8076,0x656d1ea9,0x5a3595fd,0x6d498102}},	//   _झेलल, svah, енет, ztea,
   {{0x6e2445a0,0x38ad0267,0x6aa28428,0x99920176}},	//   caib, džri_, ghof, _deyņ_,
   {{0x7e6980e1,0xc7b881a1,0x49b8803d,0xa3b40c33}},	//   vdep, _ređa_, واهد_, _जेठ_,
   {{0x2bbe170c,0xfc4e827d,0x2a690df6,0xf09f07f1}},	//   ्थशा, _sửng_, _laab_, mpàs_,
   {{0xb906800d,0x46f5a902,0x7c2545a1,0xe739b0f0}},	//   _यी_, нчит, mahr, чей_,
   {{0x6d49c5a2,0x2a6901c0,0x6aa281f8,0x61fb011f}},	//   ttea, _naab_, chof, žulj,
   {{0x81b400c8,0x7e69c5a3,0xee368048,0x2d99c5a4}},	//   _জুন_, rdep, хны_, áse_,
   {{0x6d49a1c6,0xb21b006a,0x31788019,0x442e8a03}},	//   rtea, sjæl, _تحفظ_, _cdf_,
   {{0x6d49c5a5,0x7a6a1c9b,0x2bcf9a4d,0x03228162}},	//   stea, пинг_, _सुशा, лдэн,
   {{0x9cea8117,0x6d49c5a6,0x51f70065,0x7c2500b9}},	//   _ہونے_, ptea, کسپر, hahr,
   {{0xbddb00e7,0x349581e2,0x442ec5a7,0x2bcfb07c}},	//   _scèn, _падр, _fdf_, _सुरा,
   {{0x92c200c8,0x6f018019,0x442e8350,0x7c250192}},	//   ্গে_, _kulc, _gdf_, jahr,
   {{0x6e2445a8,0x3a200356,0x61dc801b,0x7bd88084}},	//   taib, _teip_, _बर्ष, _gyvu,
   {{0xb4d80e70,0x6609c5a9,0x3ebf8364,0xbcfb02be}},	//   ात्_, ncek, nnut_, _prép,
   {{0x7c250352,0x6e24217a,0xed5700a9,0x69c10214}},	// [2fa0] fahr, raib, нот_, şler,
   {{0x6441c5aa,0x03a60604,0x6e2445ab,0xa3be00d4}},	//   ngli, низо, saib, ुअल_,
   {{0x201845ac,0xdce98353,0x6e240637,0x2a6901b4}},	//   mbri_, jveč, paib, _yaab_,
   {{0x4425c5ad,0x2ebd0a74,0xe814081f,0xfaa39988}},	//   hal_, ्कृत, _त्ता_, лахо,
   {{0x4425c5ae,0x7d04373e,0xaca384be,0x26d208ce}},	//   kal_, qqis, _ayọk, moyo_,
   {{0x6cd600f7,0x6aa2c5af,0x7c2e006a,0xfbd10019}},	//   _أقسا, shof, _udbr, اتے_,
   {{0x442e9caa,0x59dc800f,0xf1b9825b,0x82a680e8}},	//   _rdf_, _बरकर, _veša_, _завж,
   {{0x3ebf8052,0x6f01c5b0,0x645e45b1,0x61e40bcf}},	//   gnut_, _dulc, lepi, _ozil,
   {{0x4425c5b2,0x8ffa826a,0xfd0f853d,0x26c045b3}},	//   fal_, _فرار_, یجی_, inio_,
   {{0x2a690006,0x4425c5b4,0xc5f30158,0x645e45b5}},	//   _saab_, gal_, נדז_, nepi,
   {{0x2a6901c0,0x34b7025f,0x61e445b6,0xc61f8264}},	//   _paab_, תפים_, _azil, _ধারা_,
   {{0x6ee5c5b7,0x4425a8d4,0x645e45b8,0xa3d30d86}},	//   tóbe, aal_, hepi, _हँस_,
   {{0x26c045b9,0x44259357,0xa3e481a2,0x672a804a}},	//   dnio_, bal_, पेज_, lsfj,
   {{0x44259967,0x645e120e,0x7c2d8300,0x26c045ba}},	//   cal_, jepi, _ɓark, enio_,
   {{0x645e45bb,0x7ea30074,0xdfd52252,0x61e445bc}},	//   depi, _lõpe, товы, _ezil,
   {{0xa3e705b3,0xd6d84317,0x7bdb84de,0x7c2501ec}},	//   _परब_, ету_, _מקוו, wahr,
   {{0x661d8125,0xa2ce1391,0x2d582d5d,0x7d02827e}},	// [2fb0] ðski, सवर्, нить_, _juos,
   {{0x6ac98f21,0x2d870e78,0xc60d8f12,0xc7b8826c}},	//   िक्र, ćne_, _सभ्य_, _neđo_,
   {{0x212b45bd,0x2be60072,0x7d1d8e06,0x26d245be}},	//   lsch_, _करणं_, ássz, boyo_,
   {{0x4425c5bf,0xc5fe8ec3,0xe8d91029,0x00000000}},	//   zal_, šējo_, _trồ_, --,
   {{0x7d028110,0x212b0b2f,0x62999c2b,0x68faa0d8}},	//   _nuos, nsch_, rkwo, _bitd,
   {{0x6f01c5c0,0x7e6d45c1,0x4425c5c2,0xf1b981a1}},	//   _pulc, ldap, xal_, _fešn_,
   {{0x2bb80013,0x23cfaf52,0x6d4d45c3,0x46a58abe}},	//   _كافة_, _सुंद, ltaa, какв,
   {{0x7e6d0393,0x442345c4,0x44312c14,0x6d4d05ee}},	//   ndap, _hej_, _hdz_, otaa,
   {{0x6d4d45c5,0x64418352,0x6e22c22b,0xc05b80e8}},	//   ntaa, tgli, _deob, _ніж_,
   {{0x44231bc3,0xeb99997d,0x1fa790ca,0xd90d8077}},	//   _jej_, дио_, _прег, _هیچ_,
   {{0x4425c5c6,0x442345c7,0x28b685b3,0xfaa645c8}},	//   ral_, _mej_, _अगति, вано,
   {{0x442345c9,0x645e0063,0xddc4002e,0x64418114}},	//   _lej_, zepi, ndiţ, sgli,
   {{0x6455003a,0x81d380ab,0x7afb8061,0x672481a1}},	//   _obzi, হের_, _miut, ćije,
   {{0x442345ca,0x7e7d45cb,0x4425ba33,0xe3b99bd8}},	//   _nej_, _ansp, qal_, _обл_,
   {{0x26c0009a,0x6e228101,0x26d205ee,0x03a2804a}},	//   tnio_, _yeob, toyo_, _вищо,
   {{0x7c238082,0x645527a6,0x443102b6,0xc6c309a8}},	//   _henr, _abzi, _adz_, айск,
   {{0x6d4d2afd,0x7e6ba705,0xa2c0800f,0x26d23e34}},	// [2fc0] gtaa, _magp, लचस्, royo_,
   {{0x7afb8698,0xeb9a07b6,0x26c045cc,0x7e7d03ec}},	//   _aiut, миз_, snio_, _ensp,
   {{0x442301e9,0x8fa61287,0x6d4d057b,0x645e16d8}},	//   _dej_, _ране, ataa, repi,
   {{0xe2978554,0x7ae9ba87,0x7afb87e2,0x7e6b97ef}},	//   ках_, _chet, _ciut, _nagp,
   {{0x6d4d308e,0x7ae981e4,0x7ceb01ec,0x6e228980}},	//   ctaa, _dhet, dürf, _reob,
   {{0x442345cd,0xf7728b8c,0x212d8353,0xaca4019d}},	//   _gej_, لاع_, _dveh_, _kpọs,
   {{0x7d028364,0xb17d81ac,0x6b8305ec,0x6d5986c4}},	//   _suos, _vzťa, ängt, _apwa,
   {{0x764445ce,0xa3e7035a,0x444445cf,0x7afbc5d0}},	//   ngiy, _परत_, lg_, _giut,
   {{0xceb3004c,0x444445d1,0xa2cf83eb,0xade380e8}},	//   ייה_, og_, धकर्, ицьк,
   {{0x7d028364,0x68fa85f8,0xb4ccc5d2,0xb86582e3}},	//   _vuos, _uitd, लवे_, _مامو,
   {{0xdeef9641,0x444420ee,0xa2951af1,0x387e8012}},	//   _вы_, ig_, гані, _intr_,
   {{0x29048a73,0x7bdc03ac,0x7d028009,0x98b1026c}},	//   _kuma_, _myru, _tuos, _čađu_,
   {{0xf2d38158,0xe53487ac,0x2904c5d3,0x386cc5d4}},	//   שער_, _сель, _juma_, _kadr_,
   {{0x44440a0f,0x212b3ede,0x2904c5d5,0x25a904e8}},	//   jg_, rsch_, _muma_, vzal_,
   {{0x6d408086,0x87040698,0xb8cb1990,0x29048b09}},	//   luma, ияте, _खत_, _luma_,
   {{0x444445d6,0x7c28c5d7,0x7e60a645,0x6d4d0009}},	//   eg_, ladr, nemp, ttaa,
   {{0x6d40c5d8,0xdef825f5,0x7e6d2853,0x44230069}},	// [2fd0] numa, тыр_, rdap, _pej_,
   {{0x4444021e,0x6d4d2b3b,0x7e60c5d9,0x7ae9c5da}},	//   gg_, rtaa, hemp, _shet,
   {{0x6d4d06dc,0x6d40c5db,0x50b826c2,0x44230022}},	//   staa, huma, _جديد_, _vej_,
   {{0x444445dc,0x6d40c180,0x6d4d059c,0x7e60c5dd}},	//   ag_, kuma, ptaa, jemp,
   {{0xdd868b8c,0x442345de,0x7c28bba4,0x6d40c5df}},	//   _او_, _tej_, kadr, juma,
   {{0x98e580f7,0x7c2880e1,0x6d40c5e0,0x6b8305ec}},	//   دكتو, jadr, duma, ängs,
   {{0x7e6b9856,0xa3e72c5d,0x005804de,0x22490214}},	//   _pagp, _परि_, דשות_, _ocak_,
   {{0xdb240307,0x660d01bf,0x6d40bc50,0x7c23a782}},	//   _úsái, ncak, fuma, _senr,
   {{0x6d40c5e1,0xb5fd920e,0x752d2b31,0x41b780d4}},	//   guma, ješe, nsaz, _अधिस,
   {{0x64451023,0x3485976e,0x2a7f90af,0x22492acb}},	//   nghi, угог, _hnub_, _acak_,
   {{0x7c23862f,0x94758077,0x7e6bc5e2,0x64450014}},	//   _venr, ندگا, _tagp, ighi,
   {{0xc86902f6,0x6d40c5e3,0x7e6089c4,0x200100e5}},	//   _מן_, buma, cemp, _aghi_,
   {{0x661bbe2f,0xf2d2810f,0x7c23c5e4,0x7bcaa4fe}},	//   mbuk, מעט_, _tenr, _exfu,
   {{0x91030628,0xb4bf000d,0x7c28c5e5,0x91ba8039}},	//   спре, ुको_, cadr, תמשי,
   {{0x2d8f1bd7,0x3f9e026f,0xb4c199eb,0xb8dc2774}},	//   ägen_, átu_, ्की_, _आग_,
   {{0x444401c5,0x6b9c8edd,0x661bc5e6,0x2bb28697}},	//   wg_, ørge, nbuk, ुपरा,
   {{0x83fc8025,0x444445e7,0x394d8069,0x6aa4004f}},	// [2fe0] ređe, tg_, _nqes_, _ilif,
   {{0x444401e9,0x7e60c5e8,0xf06645e9,0x2904c5ea}},	//   ug_, zemp, _скоп, _ruma_,
   {{0xe29abb78,0x7e60c5eb,0xd62a0098,0xeb9707b6}},	//   наж_, yemp, _поне_, лиф_,
   {{0x44440046,0x6d40aeb5,0x094a9505,0x386c80fc}},	//   sg_, yuma, ечки_, _sadr_,
   {{0x78b885a2,0x5f76053d,0x38a2807b,0xa3e80697}},	//   tivv, _شاگر, _aðra_, मेज_,
   {{0x4b26136d,0x386cc5ec,0xddc2817f,0x2ee00713}},	//   _معرف, _qadr_, _naoš, llif_,
   {{0x6aa445ed,0xd6d0a105,0x394206ae,0x3a24c24d}},	//   _olif, يقت_, huks_, _temp_,
   {{0x1d349194,0xa534a7d4,0x661ba022,0x6b83016d}},	//   ания, анич, gbuk, ånge,
   {{0x7e60c5ee,0x6280b928,0x22938013,0x656d826c}},	//   remp, _inmo, _القس, _šahr,
   {{0x6d40c5ef,0x7e608821,0xd5638698,0x6aa445f0}},	//   ruma, semp, стъп, _alif,
   {{0x2ee00059,0x6d40c5f1,0x661bc5f2,0xf8bf0e06}},	//   klif_, suma, bbuk, ssék_,
   {{0x2246c5f3,0x7c28879f,0x6d40c5f4,0x753b8037}},	//   ngok_, sadr, puma, bruz,
   {{0x629d06be,0xc05b035f,0x753b9e31,0x7c28c5f5}},	//   rkso, нів_, cruz, padr,
   {{0x6fd60540,0x2a6d001b,0x6aa445f6,0xdced011f}},	//   _मुहू, žeb_, _elif, tvač,
   {{0x62808629,0xb5fd8916,0x7d0645f7,0xa3b4123a}},	//   _onmo, reše, _auks, _जेल_,
   {{0x7d0645f8,0x7d0d80f7,0xb4bf064a,0xddc28390}},	//   _buks, _éasc, ुक्_, _zaoš,
   {{0x660d45f9,0x7aed45fa,0xa3b8816f,0x6e262dae}},	// [2ff0] rcak, _ihat, _घेत_, _dekb,
   {{0x6280c5fb,0x660d45fc,0x752d2e31,0x68fe0122}},	//   _anmo, scak, rsaz, _gipd,
   {{0x7aed45fd,0x64452678,0x752d45fe,0xb4b51344}},	//   _khat, rghi, ssaz, _जगी_,
   {{0x660291e8,0x7ceb45ff,0xa3be903e,0x19b98110}},	//   _ngok, würd, _ेशन_, куль_,
   {{0x2169869b,0xa9698258,0x7aed01e4,0xa5bb0118}},	//   тили_, тила_, _mhat, _xeól,
   {{0xe739c600,0x7c8701bb,0xf4870221,0x3ea90061}},	//   век_, _суме, _сумн, lhat_,
   {{0xe8d901bc,0x7aed4601,0x75229210,0x07a59f91}},	//   _apị_, _ohat, _awoz, райн,
   {{0x7aed2bd6,0x753bab31,0x8d55ad5d,0x7d0638ad}},	//   _nhat, truz, аточ, _yuks,
   {{0x661b94ec,0x7e6f051e,0x315880f7,0x78478019}},	//   rbuk, _macp, _مجلة_, _مضام,
   {{0x753ba5d4,0xdd99952c,0x6602811e,0xb4c19299}},	//   rruz, ryň_, _egok, ्के_,
   {{0xe2860fe7,0x61e10201,0x23cf85fc,0x7aed01e4}},	//   ални, əlli, _सुखद, _bhat,
   {{0x7f438098,0x753b82a5,0x39420074,0x25b6803d}},	//   munq, pruz, tuks_, اهید_,
   {{0x7aed4602,0x6e264603,0x7f438081,0xcad68039}},	//   _dhat, _rekb, lunq, שורת_,
   {{0x8c42b2de,0x7c2701d0,0x7d064604,0x7ebe9d70}},	//   _деше, _nejr, _ruks, rūpe,
   {{0x7d064605,0x6d5d06f7,0xd62a20a9,0x8c2400ab}},	//   _suks, _apsa, кове_, _পালন_,
   {{0x4427c606,0xa3ea8076,0x3ea94607,0xa5bb0207}},	//   _hen_, _मरत_, ghat_, _teól,

   {{0xcbe20a49,0x4427c608,0x0c260103,0xe9df01df}},	// [3000] _বলেছ, _ken_, иман, lgún_,
   {{0x4427800d,0xac83176e,0x7d060bcf,0x25adb1fc}},	//   _jen_, огул, _vuks, izel_,
   {{0x44278039,0xa3d30063,0xe9df040e,0x6e264609}},	//   _men_, _हुआ_, ngún_, _tekb,
   {{0x4427b5d5,0x3ea9460a,0x7d06460b,0x5b5683de}},	//   _len_, chat_, _tuks, ישען_,
   {{0x7c27006a,0x6d5d011b,0x19588a41,0x4427c60c}},	//   _fejr, _gpsa, уалы_, _oen_,
   {{0xb4c18023,0x61e980eb,0x64a6460d,0xddcd0493}},	//   ्को_, _dzel, _тага, leaş,
   {{0x61e9c60e,0x25adaa0a,0x6d440493,0xb4c181d0}},	//   _ezel, ezel_, luia, ्कै_,
   {{0x83fc920e,0x3ea0460f,0x442782f9,0xe297b941}},	//   jeđa, nkit_, _aen_, _кас_,
   {{0xe8fa8c9b,0x3b078216,0xc7b881f4,0x74c68081}},	//   _ала_, _aunq_, _međi_, ищож,
   {{0x7aed2fe3,0x44278e3a,0x7ae2c610,0xaa1f001b}},	//   _shat, _cen_, llot, पर्छ_,
   {{0x44278257,0xb4790158,0x7aed4611,0x9e668b88}},	//   _den_, אָרי, _phat, _введ,
   {{0x44279302,0x96fa8829,0xd90f1abb,0x6b814612}},	//   _een_, _شعار_, ویب_, _álge,
   {{0xa3d30063,0x4427b984,0xad9b0032,0x7ae28037}},	//   _हुई_, _fen_, _agún, ilot,
   {{0x44278f23,0xa8a416d9,0x7aed2d12,0xa3e70074}},	//   _gen_, орск, _what, _परल_,
   {{0x7c658288,0x7aed4613,0x442cc614,0xb5fdc615}},	//   _دانل, _that, mad_, meša,
   {{0x442780ad,0x93fb8158,0x7c274616,0x442cc617}},	//   _zen_, _בלוי, _sejr, lad_,
   {{0x44278077,0x3ea94618,0x78bc0118,0xad9b0091}},	// [3010] _yen_, rhat_, birv, _egún,
   {{0x442c888b,0x442700f7,0x3ea94619,0xe8d901bc}},	//   nad_, ún_, shat_, _kpọ_,
   {{0x61e98019,0x7c27006a,0x3ea68722,0x6448809c}},	//   _szel, _vejr, _olot_, igdi,
   {{0x442cc61a,0xdd910065,0x3ea0461b,0x42d8902a}},	//   had_, _فوج_, ckit_, афія_,
   {{0x8d8707a1,0x290101e0,0x777a8102,0x6d440162}},	//   _тунд, _kiha_, _artx, cuia,
   {{0x4174819f,0x442c8665,0xb5fd920e,0x6e2d02a3}},	//   غانس, jad_, ješa, laab,
   {{0x442cc61c,0x4427b85d,0xb5fd8024,0x290104c4}},	//   dad_, _ren_, deša, _miha_,
   {{0x4427c61d,0xa3d30d38,0x6e2d02ec,0x3ea6acdc}},	//   _sen_, _हुए_, naab, _clot_,
   {{0xddc60db7,0x17e40697,0x442cc61e,0xf2d280be}},	//   _kakš, _गर्व_, fad_, _זען_,
   {{0x442cc61f,0x3eb900b9,0x44278168,0xdce28115}},	//   gad_, _lmst_, _qen_, _brođ,
   {{0xe29a2167,0x4dde03bb,0xc62680c8,0x3ea6813c}},	//   ган_, _कुनै_, _যারা_, _flot_,
   {{0x4427c620,0x3a290219,0x6e2d01b4,0x7c3b00fc}},	//   _wen_, _ceap_, jaab, _ɓura,
   {{0x442cc621,0x83fc8904,0xc7b881a1,0x442781c6}},	//   bad_, ređa, _ređi_, _ten_,
   {{0x7d1bc622,0x442cc623,0xb5fd85a2,0x7cf002f1}},	//   mpus, cad_, ceša, märg,
   {{0x2bcf8d14,0x2901033e,0x31ae8061,0x78bc008b}},	//   _सुचा, _diha_, _közé_, rirv,
   {{0x539a84de,0x7649c624,0x42262af7,0xb2261ada}},	//   _תיקו, ngey, _удив, _умил,
   {{0x395f81c0,0x290101b9,0x3ea01619,0x7e644625}},	// [3020] _npus_, _fiha_, rkit_, reip,
   {{0x62964626,0x3ea02e8f,0xbcfb026b,0x61e08338}},	//   _hoyo, skit_, _apéb, _ryml,
   {{0x395fc627,0x2d8f006a,0x6e2d1a2b,0x62964628}},	//   _apus_, øger_, baab, _koyo,
   {{0x442c825b,0x20058098,0x63ae1487,0x6e2d0079}},	//   zad_, _agli_, _đinđ, caab,
   {{0x442caafd,0x6d442777,0xc05a85a8,0x629605fe}},	//   yad_, quia, гій_, _moyo,
   {{0x7ae2838e,0x940738a9,0x987a00be,0x28f89b62}},	//   slot, _герб_, ראַט, шель_,
   {{0x442cae04,0x7ae2870d,0x44384629,0xb4d4462a}},	//   vad_, plot, _idr_, हकी_,
   {{0x442a462b,0x442cc62c,0x20058081,0xe6668ea6}},	//   _heb_, wad_, _egli_, стко,
   {{0x442cc62d,0x442a462e,0x7d1bacbf,0x7c3c8511}},	//   tad_, _keb_, gpus, órro,
   {{0xdce2805c,0xfd4d0135,0x442a00eb,0x26dd81bc}},	//   _prođ, _achị, _jeb_, _ekwo_,
   {{0x442cc62f,0xef1a95fd,0x44384630,0xf1b9979d}},	//   rad_, _сме_, _mdr_, _reši_,
   {{0x442cc631,0x442a4632,0x6e2d0079,0xe8d9001c}},	//   sad_, _leb_, xaab, _trừ_,
   {{0x645c4633,0x588707ac,0xb5fdc634,0x81da80ab}},	//   _obri, быва, peša, ডের_,
   {{0x442a3f4d,0x224d4635,0x6e2d31c0,0x442cc636}},	//   _neb_, żek_, waab, qad_,
   {{0x49930077,0xdce280d2,0x6e2d25d5,0xdbf1001b}},	//   زیگر, _urođ, taab, _přím,
   {{0x629604b9,0x237f05f3,0x59da3b82,0x6284051e}},	//   _goyo, _čuj_, _युवर, _gnio,
   {{0x38ab8aa2,0x442a028d,0xca380039,0xd8388267}},	// [3030] _høre_, _beb_, _הנחה_, _elči_,
   {{0x39468c52,0x38ab813c,0xa3cc809a,0x6e2d1a2b}},	//   duos_, _køre_, _रखा_, saab,
   {{0x442a4637,0x395f802e,0xb5fd920e,0x62960010}},	//   _deb_, _spus_, ješn, _yoyo,
   {{0x645c0114,0x442a4638,0x7c2ac639,0x38ab80e8}},	//   _ebri, _eeb_, _lefr, _møre_,
   {{0xc7b88025,0xddc60353,0x3946c63a,0x2bd90105}},	//   _među_, _takš, guos_, _बुरा,
   {{0xb608003e,0x7cf0016d,0x6d40825b,0xb5fb0032}},	//   _vyšš, gärd, drma, _abág,
   {{0x6d40a580,0x7cef83ba,0x26c90c93,0x44210865}},	//   erma, nøre, onao_, mbh_,
   {{0x442a01c5,0x6f0294ed,0x44210046,0x6aa28c54}},	//   _zeb_, _cioc, lbh_, ckof,
   {{0xa2d68b84,0x44210ad0,0x1a6880d5,0x764982a3}},	//   यकर्, obh_, _دینی_, rgey,
   {{0x40349e0b,0x44210cb5,0x442a022c,0x6569c63b}},	//   _неус, nbh_, _xeb_, rweh,
   {{0x61ed463c,0xda6636b8,0x4421152f,0x6d40c63d}},	//   _azal, овни, ibh_, arma,
   {{0x6f028698,0x2a720079,0xc3320496,0x38ab8366}},	//   _gioc, _qayb_, ווט_, _døre_,
   {{0xdce9803b,0x7cf012d2,0x3ead9f5f,0x7de791cc}},	//   jveć, läre, mhet_, _اسام,
   {{0x2ee20ebf,0x03a598a2,0x7c2a9ab8,0x7cef8b40}},	//   पत्त, _мило, _gefr, føre,
   {{0x38ab8022,0x7d0bb8b9,0x656f463e,0x7cf00884}},	//   _gøre_, _hugs, _asch, näre,
   {{0x442a463f,0xe61a197d,0x3eada61b,0x7d03c640}},	//   _seb_, рда_, nhet_, _hins,
   {{0x442a146a,0x7d03c641,0x6e2b8019,0xe1ff0511}},	// [3040] _peb_, _kins, _megb, león_,
   {{0x7d03c642,0x6e2bc643,0x6aa9846d,0x442a0069}},	//   _jins, _legb, _alef, _qeb_,
   {{0x7d03c644,0xbcfb03d3,0x7cf02fc8,0x8b6a0009}},	//   _mins, _spéc, värd, риев_,
   {{0x442a3f19,0x6aa9c645,0xf99f00e7,0x4421032f}},	//   _web_, _clef, ccès_, abh_,
   {{0x442a10af,0x644302ba,0x3eadc646,0x443802f7}},	//   _teb_, ónic, dhet_, _tdr_,
   {{0x98a39194,0x7d03c647,0x7cf0016d,0x2a6690e4}},	//   миче, _nins, färe, seob_,
   {{0xf093093f,0x7d0b8029,0xfaa68084,0xb86580f7}},	//   ונג_, _augs, _даво, ثانو,
   {{0x7d03c648,0x3ead904d,0x60dc0057,0x7d0b9a7e}},	//   _ains, ghet_, horm, _bugs,
   {{0x61e4325e,0x6d561072,0x60dc0061,0x7d03c649}},	//   _nyil, ntya, korm, _bins,
   {{0x26c9003b,0xb5fd9734,0x59c086b7,0x7d03c64a}},	//   znao_, pešn, _शेयर, _cins,
   {{0x7d03c64b,0x61ed247d,0xdee69285,0x6f028635}},	//   _dins, _szal, _дожи, _tioc,
   {{0x7d03c64c,0x2bbd0bb8,0x3eadc2e0,0xddcd0162}},	//   _eins, ्पता, chet_, ndaţ,
   {{0x7d03b613,0x672d812b,0x26c9017f,0x61e40a03}},	//   _fins, ćaje, vnao_, _cyil,
   {{0x7d03c64d,0x1c0e8fd5,0x7cef8aa2,0xf7730c48}},	//   _gins, _सलिल_, tøre, واز_,
   {{0x09b7885d,0xb4e6816f,0x788080e1,0xeabf00e5}},	//   _अध्य, पती_, _závä, più_,
   {{0x7d03c64e,0x9d15176e,0x7cef83ba,0x69da0162}},	//   _zins, здач, røre, ştea,
   {{0x61ed464f,0x6d5602d5,0x7d03c650,0x5fdb2b07}},	// [3050] _uzal, gtya, _yins, _मुरल,
   {{0x3eadc651,0xd37b4652,0xde8f80ff,0x92c780ab}},	//   zhet_, иче_, _kịch_, _উঠে_,
   {{0x44210ad0,0xdce9803b,0xf8bf00e7,0xd7df816f}},	//   rbh_, sveć, ssés_, _पुढच,
   {{0x1dca82f1,0x656f3c94,0x69c000d4,0x44214653}},	//   ापात, _tsch, _लेडी, sbh_,
   {{0xde8f8104,0x249817af,0x656f1075,0xa92480e8}},	//   _lịch_, _form_, _usch, дділ,
   {{0x3cf6800f,0xc5fa0039,0x7d0b8110,0x6ee581df}},	//   ीदों_, _לפרט, _rugs, móbi,
   {{0x6562c654,0x656d4655,0x248980ff,0x3eadc656}},	//   _apoh, lwah, _đam_, thet_,
   {{0x32090028,0x764d4657,0x7d03c658,0x6abb8cb7}},	//   _ngay_, ngay, _sins, _umuf,
   {{0x3eadc659,0x7d03c65a,0x3ebf80f1,0x656d465b}},	//   rhet_, _pins, riut_, nwah,
   {{0x2ca991b3,0x3eadc65c,0x32090bb1,0x6e2b9591}},	//   скоп_, shet_, _agay_, _wegb,
   {{0x3c21811b,0x7d039020,0x61e403ac,0x60dc1eb2}},	//   _vгv_, _vins, _syil, vorm,
   {{0xde8f8104,0x7d039412,0x656d0518,0xa96a465d}},	//   _dịch_, _wins, kwah, бима_,
   {{0x290580f6,0xb7bc8029,0x7d0381b9,0x49990198}},	//   _kila_, _reģi, _tins, отря_,
   {{0x23bd1d6a,0xa3ab0b85,0x764d0ef2,0x320902c4}},	//   ्पाद, गना_, egay, _egay_,
   {{0x17790364,0xfaa636a2,0x29058695,0xd00f1a05}},	//   ость_, _нако, _mila_, الف_,
   {{0x60dc2e17,0x539a81c6,0x6b9c9d5b,0xf77283de}},	//   sorm, _ליצו, ärge, עקן_,
   {{0x60dc10c1,0xb5fb0118,0xa11300f7,0xdb0d01d6}},	// [3060] porm, _abáb, _كويت, ľkým,
   {{0x290584d2,0x6aac1244,0xb17b03c8,0xf8a5826a}},	//   _nila_, _चतुर, _פטיר, _شک_,
   {{0x389b0f60,0x2498465e,0x309b0039,0x6d563abf}},	//   _היינ, _vorm_, _השימ, stya,
   {{0x2905ac3a,0xf1e10424,0xe9f90091,0x3a2d8197}},	//   _aila_, _गुड़_, _alẹ_, _ceep_,
   {{0xbefa000f,0x6e240365,0x2498465f,0x055527ee}},	//   ्दीन_, mbib, _torm_, _отря,
   {{0x2905820f,0x6e24004a,0xa3cc82f1,0x7ceb2353}},	//   _cila_, lbib, _रखल_, nürl,
   {{0x36d4c660,0x38cb815b,0xa8570039,0x2905c661}},	//   мокр, حانی_, פיקה_, _dila_,
   {{0x877b00be,0x6e2405ee,0x6d4412a5,0x7c2e4617}},	//   מאצי, nbib, oria, _hebr,
   {{0x6ce681e5,0x6d49818a,0x29058558,0x614396cf}},	//   зіне, guea, _fila_, _пета,
   {{0x29058057,0x6d444662,0xf1b981a1,0xd00f81a8}},	//   _gila_, iria, _vešt_, _ملك_,
   {{0xe45700be,0x6d444663,0xccf881d0,0x7ceb02d0}},	//   הייט_, hria, rmě_, dürl,
   {{0x2905c12f,0xa3bd8035,0x6d4430c6,0xdc02936f}},	//   _zila_, _इधर_, kria, _učím,
   {{0x867b8039,0xc50a80f7,0x6d441b7c,0x69da0087}},	//   _לראו, _اتصل_, jria, şten,
   {{0xddeb893f,0xb1138a2c,0x200c37bc,0x6d444664}},	//   _פֿאָ, wụkw, ždin_, dria,
   {{0x7127026a,0x7b0681d0,0xd7f808b0,0x443c81e8}},	//   _کربل, ístě, зут_, _idv_,
   {{0xdce4003b,0x56941db0,0x442e8125,0x6e2402b8}},	//   dviđ, наст, _hef_, gbib,
   {{0x7c2e4665,0x1df801bb,0x764d4666,0x5c990fe6}},	// [3070] _bebr, зеты_, rgay, окая_,
   {{0x7c2e4667,0xd01104c1,0x656d4668,0xe8d30065}},	//   _cebr, _جلد_, rwah, _سمجھ,
   {{0x656d4669,0xdced0a20,0x7c2e0eb9,0x98ab0087}},	//   swah, hvać, _debr, ască_,
   {{0x2905c66a,0x38af0192,0x442ec66b,0x3f57011c}},	//   _sila_, _würd_, _lef_, mçu_,
   {{0x29059341,0x6d44041c,0x63ad8326,0x3f57011c}},	//   _pila_, cria, _ƙank, lçu_,
   {{0x7c2e0574,0x6aad466c,0x26f79053,0x442ec66d}},	//   _gebr, _llaf, ुद्र_, _nef_,
   {{0xb4d9035a,0xb8f589f2,0x3f57466e,0xa3d40071}},	//   ावी_, _हद_, nçu_, _зорч,
   {{0x4433466f,0x443ca014,0x7c2e4670,0x317f82f7}},	//   lax_, _adv_, _zebr, _truz_,
   {{0x2905c671,0xa91d80d2,0x442ec672,0x7cf01cce}},	//   _tila_, _brže, _bef_, lära,
   {{0x6aad4673,0x4c69b9df,0x6e240bcf,0x443c8299}},	//   _alaf, цион_, zbib, _cdv_,
   {{0x62030086,0x443c8353,0x60c38a6e,0x32460048}},	//   ətlə, _ddv_, minm, менг,
   {{0x60c3c674,0x7d070a0f,0x7c250cb5,0x929d809a}},	//   linm, _lijs, hbhr, _miło,
   {{0x7ceb419b,0x6d49c36a,0x3ea2816d,0x27e08214}},	//   türl, quea, ökte_, ğine_,
   {{0x1dd8000f,0xfbc58a29,0xb69b03a7,0x60c38041}},	//   _भुगत, _обло, _diâm, ninm,
   {{0x66e6141e,0x7c2e1f5e,0xdee64675,0x44330079}},	//   дова, _rebr, дови, dax_,
   {{0x26f80074,0xb5fd911b,0x26cd8118,0x7d0f305d}},	//   ंगेर_, ješk, nneo_, _bucs,
   {{0x38af0214,0x7c2e4676,0xed5700a9,0x60c3c677}},	// [3080] _süre_, _pebr, мот_, kinm,
   {{0xf8d20327,0x6f062ae0,0x443301b4,0x6d444678}},	//   _सदिय, _wikc, gax_, rria,
   {{0xddcd4679,0xbddb09c4,0x7cf00106,0x7d07467a}},	//   rdaš, _adèd, gära, _dijs,
   {{0x9c7cc67b,0x7d0f0350,0x6d44467c,0xeb9680be}},	//   moče, _fucs, pria, ודער_,
   {{0x9c7ca02e,0x26cd8279,0x657b026c,0x443301b4}},	//   loče, dneo_, _šuhv, bax_,
   {{0x1de1823c,0xfbd90996,0xab2a0098,0x60c3808b}},	//   _पड़त, _बुकम, _мога_, ginm,
   {{0xb4ea0af3,0xfc030012,0x443c8036,0xd83882d4}},	//   मती_, _апро, _rdv_, _noče_,
   {{0x3da692c0,0x442ec67d,0x6b83013c,0x629b8122}},	//   дроб, _sef_, ænge, _gouo,
   {{0x443c8a20,0x63bb04b9,0xa91d812b,0x672d8904}},	//   _pdv_, _ƙung, _prže, ćaja,
   {{0x7ae4467e,0x6aad467f,0x9c7c84c4,0x60c39040}},	//   _akit, _slaf, koče, cinm,
   {{0x7eb100e8,0x442ebc35,0x9c7c9911,0xf77281a8}},	//   _håpe, _vef_, joče, _جاء_,
   {{0x1d0a9a3b,0x7af61803,0xa2a180d4,0xe5c68c6c}},	//   _деди_, _chyt, कॉप्, _осло,
   {{0xa3088117,0x26c4acf5,0x25de0074,0xa91d82d4}},	//   _کرتے_, mimo_, _कुली_, _trže,
   {{0x3946956b,0x7ae44680,0x1bd49bd8,0xd838a50d}},	//   iros_, _ekit, _поля, _foče_,
   {{0x9c7c8353,0xa2bf80d4,0x248d001c,0x7d0700f3}},	//   goče, लोड्, _đem_, _rijs,
   {{0x26c4c681,0x2d82026c,0x83fc9351,0x44332243}},	//   nimo_, _brke_, jeđi, wax_,
   {{0x44331ce1,0x2fdf009a,0x60c3abcf,0x6722026c}},	// [3090] tax_, ług_, yinm, _čoje,
   {{0xb4d92f7b,0x3f81026f,0x7afd0bcb,0x26c4b495}},	//   ावे_, _trhu_, lmst, himo_,
   {{0x38ab8022,0x44334682,0x26c48110,0x39469d4e}},	//   _børn_, rax_, kimo_, eros_,
   {{0x26c481e2,0xd6270013,0x2d8200d2,0xd9f3016f}},	//   jimo_, _تعدي, _frke_, _घरात_,
   {{0x39468333,0x2d82017f,0xe1ff0019,0xb5fd8115}},	//   gros_, _grke_, deók_, rešk,
   {{0x7cf04683,0x99d4803d,0x7b670997,0xe1f081a8}},	//   pära, ختما, _отбе, جسم_,
   {{0x60c384b9,0x83fc8088,0xc8788380,0x5b1416dd}},	//   rinm, beđi, _dağ_, _амст,
   {{0x3946840e,0xee398abe,0xfe719e44,0x3ea94684}},	//   bros_, чни_, ادث_, nkat_,
   {{0x26cdc685,0x443107d9,0x98ef000f,0x3a3f8359}},	//   rneo_, _kez_, छताछ_, _idup_,
   {{0xb5fd86f7,0x7ae4202d,0x16010592,0xd01180f7}},	//   neši, _skit, लेयर_, _إلا_,
   {{0x26c4c686,0x3ea94687,0xc2c600f7,0x3b0900b9}},	//   bimo_, kkat_, فيدي, _biaq_,
   {{0x7cf000f2,0x6d4d4688,0xeab20250,0x614617c8}},	//   järn, kuaa, اعد_, нема,
   {{0x8c458c24,0xb5fdbe45,0x7e6d0162,0xc878807e}},	//   _зеле, keši, deap, _yağ_,
   {{0xb5fd920e,0x26fa01c4,0x7e7b88dc,0xb4d9341c}},	//   ješi, ्द्र_, ldup, ावो_,
   {{0xb4bd835a,0x7ea30006,0x46f61cf4,0x645c8722}},	//   ीची_, _lõpu, ечат, òrie,
   {{0x3ea94689,0x7eaa026f,0x291f81bc,0xcf9280be}},	//   gkat_, _výpo, _otua_, נטן_,
   {{0xac8607a1,0x61e980d5,0x291f8282,0x3486002d}},	// [30a0] нгал, _nyel, _ntua_, нгаг,
   {{0x23d635d9,0x44310038,0xb4ea058c,0x26c4912e}},	//   нцер, _cez_, मते_, zimo_,
   {{0x7b090182,0x443135c3,0x291fc68a,0x61e9c68b}},	//   _üstü, _dez_, _atua_, _ayel,
   {{0x39469313,0x6d5bc68c,0xe8d90028,0xa50a024b}},	//   tros_, ktua, _trợ_, _нема_,
   {{0x26c4c68d,0x83fc8052,0x44310073,0xf53981ac}},	//   vimo_, ređi, _fez_, jsť_,
   {{0x39468fba,0x672d9601,0x20070722,0xa5bb468e}},	//   rros_, ćajn, _únic_, _teór,
   {{0xcb67468f,0x29124690,0x2d804691,0x25fc109b}},	//   _паре_, _luya_, lvie_, लेरी_,
   {{0x38b4016d,0x6d5b8168,0x6e3626e9,0x2d800037}},	//   _färg_, ftua, nayb, ovie_,
   {{0x26c4c692,0x7ae2aeac,0x2d8039cb,0x6d5bc693}},	//   rimo_, moot, nvie_, gtua,
   {{0x2240103b,0x387a01ac,0x7ae2c694,0xd5e2819d}},	//   _adik_, _napr_, loot, _anọ,
   {{0x79843a1d,0x26c49c49,0xe7e00e70,0xd00f80f7}},	//   _ariw, pimo_, _खुला_, _الم_,
   {{0x7ae2c695,0x291204bb,0x9e739f33,0x79840286}},	//   noot, _buya_, _مهمت, _briw,
   {{0x64a6a5a4,0xf2d38158,0x24588554,0x29120876}},	//   _пада, רער_, _жаль_, _cuya_,
   {{0x79840c0b,0x26c208ae,0x6b8388ae,0x2ed9036d}},	//   _driw, _amko_, _frng, भक्त,
   {{0xe7db0a16,0x644328f4,0x79840c2e,0x7e6d0087}},	//   _मुखप, ónim, _eriw, teap,
   {{0x44314696,0x6d4d07b8,0x63a51e51,0x3cfe8037}},	//   _sez_, tuaa, vyhn, lmtv_,
   {{0x25fc035a,0x628d0010,0x443101ca,0xdce4009a}},	// [30b0] लेली_, _inao, _pez_, zwią,
   {{0x26c208ae,0x3ea94697,0x2f150106,0x6d4d0299}},	//   _emko_, skat_, _tåg_, ruaa,
   {{0x443110dd,0x6e362f15,0x92598009,0x61e980b9}},	//   _vez_, bayb, дает_, _syel,
   {{0x61e981e0,0x44314698,0x3ea903ed,0x9f961101}},	//   _pyel, _wez_, qkat_, _סדרה_,
   {{0x44314699,0x628d469a,0x644a12ca,0x38b40338}},	//   _tez_, _mnao, ófic, _färd_,
   {{0xf771845b,0xf745bd2f,0xfaff0168,0x6d5b81c0}},	//   لاب_, веко, hmë_, vtua,
   {{0x6a159a88,0xd7fb8162,0x7e7985ee,0xe2d980d7}},	//   _амбу, чуд_, _pawp, _قارچ_,
   {{0xfaff020f,0x629f02a3,0x6d5bc69b,0xa3e60072}},	//   jmë_, _noqo, ttua, _पडत_,
   {{0xc21284de,0x7cf008dc,0x7e7b839c,0x7003019d}},	//   _כהן_, kärl, rdup, ọchu,
   {{0xb4bdaf7b,0x628d469c,0x27e08162,0xb4cb8072}},	//   ीचे_, _anao, şina_, रचे_,
   {{0x6d5bc69d,0x629f02a3,0xf4120039,0x2120025b}},	//   stua, _boqo, יפי_, _stih_,
   {{0x68e38a40,0x6d5bc69e,0x2912469f,0x83fc9351}},	//   lond, ptua, _puya_, jeđu,
   {{0x6e298359,0x645c8722,0x6a3a81c6,0x7cf00338}},	//   mbeb, òric, וגרפ, färl,
   {{0xdca28572,0x2eedc6a0,0x64a2b4d5,0x661d46a1}},	//   _ваши, llef_, _ваша, _afsk,
   {{0xafe611d2,0x291204b9,0x20cd0267,0x7ec789c4}},	//   товл, _wuya_, džid_, _gèpè,
   {{0x661b9599,0x68e3c6a2,0xfe431b56,0x291246a3}},	//   ncuk, hond, инсо, _tuya_,
   {{0x9c7c9fd8,0x6d49c6a4,0xec7a02a4,0x657b026c}},	// [30c0] loča, nrea, мпа_, _šuhr,
   {{0x6d49aab6,0x31370051,0xa3d59344,0x293704de}},	//   irea, _שנים_, _सखा_, _שאין_,
   {{0x6d49c6a5,0xaac60105,0x4ac60074,0x38b4016d}},	//   hrea, _लगाक, _लगाव, _värd_,
   {{0x23270073,0xdcfb8bcf,0x0a678195,0xc4c40264}},	//   тоци_, dvuč, врши_, ্তেজ,
   {{0x90cb011b,0x7ae29328,0x75431431,0x6d498390}},	//   _vvрv, root, _княз, jrea,
   {{0x68e3c6a6,0x91bb0039,0x6f0b8706,0x48d080ab}},	//   gond, ומני, _aigc, িত্র,
   {{0xb8ea8bb8,0x7bc7c0a1,0x2a7d81c0,0x547b01c6}},	//   _लग_, újul, bdwb_, _קטלו,
   {{0x9c7c805c,0x6d49a0d0,0xb7db03c8,0x63a346a7}},	//   doča, frea, וקצי, änne,
   {{0xa91dc6a8,0x6ee581ac,0x44208300,0x09068196}},	//   _trža, tóbr, _ƙi_, _апан,
   {{0x8ffa9125,0x21269083,0x68e3914e,0xd838a50d}},	//   _قرار_, mpoh_, cond, _foča_,
   {{0xda3507ac,0x6d49c6a9,0x9c7c8353,0x7cf0016d}},	//   лены, area, goča, värl,
   {{0xa91d803a,0x8aa70012,0x2eed8242,0x02a71c56}},	//   _mržn, трод, clef_, тром,
   {{0x61f6009a,0x6d498051,0xfaff00f1,0x290c8300}},	//   _czyl, crea, rmë_, _kida_,
   {{0x929d809a,0x290c86c0,0x7522ad27,0xfaff0168}},	//   _piłk, _jida_, _itoz, smë_,
   {{0x290cc6aa,0xb4de8076,0xcfa4002e,0x40340198}},	//   _mida_, थकी_, ашти, ресс,
   {{0x2f188117,0xa3e6000f,0x68e3c6ab,0x628d022e}},	//   _még_, _पड़_, zond, _unao,
   {{0x83fc805c,0xdcfb8289,0x68e3c6ac,0x261903b7}},	// [30d0] ređu, zvuč, yond, युगी_,
   {{0x6adba8d7,0xb5fd8eef,0x61ed46ad,0x5f95154f}},	//   यक्र, mešt, _iyal, _биот,
   {{0x68e38a0f,0xddc40110,0x6aa0913b,0x6d49c6ae}},	//   vond, reiš, _bomf, zrea,
   {{0x68e380c9,0x7b644107,0x6e95069c,0x61ed46af}},	//   wond, ртфе, _симу, _kyal,
   {{0x68e3c6b0,0x38b402af,0x290c95d0,0xb5fd943c}},	//   tond, _wäre_, _bida_, nešt,
   {{0x6d49b96b,0x290c81b4,0x61ed46b1,0xfc4781d6}},	//   vrea, _cida_, _myal, číky_,
   {{0x533446b2,0xf094012a,0x290cc6b3,0xdce4009a}},	//   _вест, ינס_, _dida_, jwię,
   {{0x68e3c6b4,0x7cf008e5,0xf770803d,0xe579a041}},	//   sond, järj, تاه_, ези_,
   {{0x68e383d3,0xb5fd82fd,0x61ed46b5,0x6e29c6b6}},	//   pond, ješt, _nyal, rbeb,
   {{0x290cb154,0x68e3829b,0x9c7cc6b7,0x38ab83ba}},	//   _gida_, qond, toča, _mørk_,
   {{0x7afb8c9e,0x61ed46b8,0x752281bc,0x2d8681e8}},	//   _khut, _ayal, _etoz, _eroe_,
   {{0x7e7d46b9,0x9c7c8353,0x290c8668,0xe29a2f0a}},	//   _nasp, roča, _zida_, хам_,
   {{0xc95601bb,0x38c8003d,0x9c7cc6ba,0x78a1a20d}},	//   ытны, ناسی_, močn, _kolv,
   {{0x9c7cc6bb,0x3eada2ea,0xdddd009a,0x438580f7}},	//   ločn, lket_, _obsł, _ملتق,
   {{0xaa7b0125,0x7ae9c6bc,0x2b180fd5,0x61ed46bd}},	//   glýs, _oket, _बंधु_, _eyal,
   {{0x9c7c826f,0x7e7d46be,0x7ea30074,0x7ae9819d}},	//   nočn, _casp, _sõpr, _nket,
   {{0x61ed1ef0,0x0d860196,0x7e7d46bf,0x95860fe6}},	// [30e0] _gyal, ылан, _dasp, ылае,
   {{0x7cf046c0,0xddc6027f,0x2718007a,0xa91d8bda}},	//   märk, _takž, _učno_, _pržn,
   {{0x39400a38,0x3ead93e1,0x7afba350,0x290cc6c1}},	//   _hvis_, kket_, _bhut, _rida_,
   {{0xe9da8895,0x290c92cf,0x7afbc6c2,0xbae5835f}},	//   нке_, _sida_, _chut, ацій,
   {{0xc1e78987,0x290c8661,0x10a682a4,0x5a33804a}},	//   льше_, _pida_, лидн, сніт,
   {{0xa91d8805,0x7ae9c6c3,0x3eadb5fe,0x7d1b02df}},	//   _tržn, _eket, eket_, _éusa,
   {{0x69dc809a,0x657980b9,0x7d0e01b4,0x3b0d8609}},	//   _śred, _aswh, _iibs, _fieq_,
   {{0x443a46c4,0xdd908591,0xd6d78fe6,0xe8d9019d}},	//   lap_, قوب_, лты_, _irụ_,
   {{0xbcfb00f7,0x45d484bd,0xb5fb0032,0x290c821e}},	//   _spéi, ропс, _abáj, _tida_,
   {{0x443a46c5,0xb5fd8eef,0x5b26976e,0x78a1bd58}},	//   nap_, vešt, льма, _golv,
   {{0x394046c6,0x61ed00dd,0xdfcf80f7,0xdeefa4bd}},	//   _avis_, _syal, _فيك_, _гы_,
   {{0x3eadc6c7,0x7d0e02a6,0x7eb581d6,0x63a8a9e3}},	//   cket_, _libs, _pápe, rydn,
   {{0xf4868110,0x61ed05ee,0x7d0e0706,0x7522c6c8}},	//   _буйн, _qyal, _oibs, _utoz,
   {{0x6b9c8022,0xed578051,0x443a07d5,0x26c68069}},	//   ørgs, _עבור_, jap_, _hmoo_,
   {{0x443a14ff,0x8c1b8039,0xb8dd016f,0x69c046c9}},	//   dap_, _אווי, _आत_, úmer,
   {{0x4ea446ca,0x7d0e0362,0x7c3ac6cb,0xaa7b008b}},	//   бруа, _aibs, latr, rlýs,
   {{0x7e7d1c89,0xe8d9082e,0x443a2fde,0x26c681bc}},	// [30f0] _vasp, _arụ_, fap_, _mmoo_,
   {{0x443a46cc,0xaa7b0125,0x7e7d0b17,0x25a946cd}},	//   gap_, plýs, _wasp, ryal_,
   {{0x25a91b83,0xd3710624,0x7afb81e4,0x7c3a847f}},	//   syal_, تها_, _phut, iatr,
   {{0xf53f04b8,0x78a1c6ce,0x8f9a010f,0x7c3ac6cf}},	//   _två_, _solv, _סירי, hatr,
   {{0x6e2d46d0,0x210f92ee,0x78a1b381,0x7c3ac6d1}},	//   mbab, ादेश_, _polv, katr,
   {{0x443a0886,0x7c3a805c,0x07a58698,0x6e2d46d2}},	//   cap_, jatr, иалн, lbab,
   {{0x78a1c6d3,0x9c7c8038,0xc4d20039,0x7afbc6d4}},	//   _volv, točn, _וגם_, _thut,
   {{0xd838826c,0xa3b20035,0x7545a4dc,0x6f0f0197}},	//   _fočo_, टनर_, аниз, _jicc,
   {{0x9c7c905e,0x6d4d46d5,0x38b4016d,0x6f0f0b57}},	//   ročn, nraa, _lära_, _micc,
   {{0x3eadaa40,0x7eaa026f,0x99d491cc,0x2a7f8282}},	//   sket_, _výpi, _اتفا, _haub_,
   {{0x38b400f2,0xf79984c1,0x2a7f822c,0x394001a1}},	//   _nära_, _جناب_, _kaub_, _svis_,
   {{0x6f0f46d6,0x6d4d2411,0x7cf03cac,0x8b0881d0}},	//   _nicc, kraa, tärk, mořá,
   {{0xfeb88416,0x2a7f822c,0x690b02a6,0xed598087}},	//   _حالت_, _maub_, _eżem, _рол_,
   {{0x6e3bc6d7,0x6d4d10b0,0x2a7f8282,0x75298548}},	//   laub, draa, _laub_, mpez,
   {{0xac7483f8,0x443a07d9,0x6f0f2414,0x6d4d0079}},	//   _دانش, vap_, _bicc, eraa,
   {{0xddc60063,0x6e2d02b8,0x6f0f46d8,0x7a0c00eb}},	//   _takż, gbab, _cicc, _pētī,
   {{0x443a1cc9,0x6f0f46d9,0x6d4d3a9c,0x395f8282}},	// [3100] tap_, _dicc, graa, _nqus_,
   {{0x7cef8aa2,0xe3b200f7,0x8c4604db,0x25fc0035}},	//   føri, يرا_, реже, लेगी_,
   {{0x443a2963,0x798980a4,0x6f0f46da,0x6e2d46db}},	//   rap_, _arew, _ficc, bbab,
   {{0x443a352f,0x63a300f2,0x2a7f822c,0x6d4d0f1a}},	//   sap_, änna, _caub_, braa,
   {{0x3940c6dc,0x6f043ece,0x7989a374,0x2a7f8122}},	//   éis_, mmic, _crew, _daub_,
   {{0x6ab6031d,0x6f040229,0x7989809a,0xe8d9001c}},	//   _llyf, lmic, _drew, _trụ_,
   {{0xd6dac6dd,0xbb4346de,0x7c3ab0d2,0xd90d87d2}},	//   кти_, _мерк, vatr, ریم_,
   {{0x443846df,0xb4de81a2,0x6f040229,0x38698503}},	//   _her_, थक्_, nmic, đara_,
   {{0x44380db7,0xdd909f54,0xe51c005e,0x6280c6e0}},	//   _ker_, سود_, _भूमि_, _iamo,
   {{0x4438003a,0x6280c6e1,0x628282b5,0x2a7f81c5}},	//   _jer_, _hamo, ldoo, _zaub_,
   {{0x6f04003a,0x4438179a,0x7c3ac6e2,0x6280c6e3}},	//   kmic, _mer_, ratr, _kamo,
   {{0xf2c70f16,0x62808fe2,0x443846e4,0x20cd0110}},	//   рсон, _jamo, _ler_, džia_,
   {{0x443846e5,0xdd8f8013,0x6f0404a8,0x6f0f0098}},	//   _oer_, _يوم_, dmic, _ricc,
   {{0x443804b8,0x3d1a01ce,0x6d4d038e,0x6f0f047f}},	//   _ner_, _बढ़े_, vraa, _sicc,
   {{0x6f0f0698,0xd8388d11,0x040480ab,0x13a980d7}},	//   _picc, _meč_, _শ্রী_, _منوی_,
   {{0x6280c6e6,0x5eb42c18,0x6d4d271e,0x443846e7}},	//   _namo, ойст, traa, _aer_,
   {{0x443846e8,0x6d40c6e9,0x628282a3,0x6e2d0ad4}},	// [3110] _ber_, nsma, ddoo, rbab,
   {{0x7c388efd,0x6d4d46ea,0x443846eb,0x645c00ee}},	//   _jevr, rraa, _cer_, _ccri,
   {{0x443846ec,0xdd86850c,0x2a7f90af,0x6d4d37cc}},	//   _der_, _کو_, _paub_, sraa,
   {{0x6e951ecd,0x6d4d00c9,0xe69516a5,0x645c00e7}},	//   _الحا, praa, _الحد, _ecri,
   {{0x443846ed,0xdced02a5,0x7eb5826f,0xd8388289}},	//   _fer_, svađ, _nápa, _beč_,
   {{0x443846ee,0x6e22c6ef,0x2d8b01a1,0x7ceb0380}},	//   _ger_, _afob, _irce_, rürs,
   {{0x2a7f81c5,0x6d42c6f0,0x6d46c6f1,0x2fde83a8}},	//   _taub_, _avoa, škal, _cxtg_,
   {{0x44211f8b,0x4438011e,0x6280c6f2,0x4177803d}},	//   lch_, _zer_, _gamo, _پارس,
   {{0x443802bb,0x9c7c8353,0x6d40a36b,0x7c38837a}},	//   _yer_, močj, gsma, _bevr,
   {{0x7aed46f3,0x442146f4,0x6aa40362,0x67d59be4}},	//   _akat, nch_, _soif, _лозу,
   {{0x442146f5,0x7c38c6f6,0xa3d73b6b,0x6280b55d}},	//   ich_, _devr, ापि_, _yamo,
   {{0xfbd20039,0x62808118,0x75299e75,0xf8a91101}},	//   לתי_, _xamo, ppez, _אש_,
   {{0x7c38c6f7,0xd46989a5,0x6b8a9699,0xf8db8035}},	//   _fevr, _биле_, _erfg, _बदाय,
   {{0x7c3880c9,0x7cf01bf3,0x7aed46f8,0xe8f7002e}},	//   _gevr, päri, _ekat, йля_,
   {{0xf412804c,0x78a5012b,0x7eb5803e,0x2d8b46f9}},	//   _צפה_, _dohv, _zápa, _arce_,
   {{0x645c46fa,0x443846fb,0x64472240,0x628281b4}},	//   _scri, _ser_, _adji, xdoo,
   {{0x443846fc,0xbea315e3,0x6280c6fd,0xa3cb8105}},	// [3120] _per_, чатк, _ramo, _रेत_,
   {{0x9992000d,0xc5f283c8,0x7cf00338,0x4423018e}},	//   _když_, לדן_, härv, _cfj_,
   {{0x443810dd,0x6280c6fe,0x7f860013,0xd838b3fc}},	//   _ver_, _pamo, _الجن, _reč_,
   {{0x44380352,0x93bc802e,0xd25980e8,0x442146ff}},	//   _wer_, mbăt, иці_, ach_,
   {{0x44384700,0x6282b1e9,0x6280c701,0x673b005c}},	//   _ter_, rdoo, _vamo, ćuje,
   {{0xdb1a8065,0x3ea7002e,0xd7fa8193,0x52a50540}},	//   szté, _într_, луй_, _ऑक्स,
   {{0xd838a588,0x65644702,0xf1bf0065,0x20c980f7}},	//   _več_, ltih, zzá_, جبني_,
   {{0x6d40c703,0x7c3893ff,0x62828df6,0xc6f882ee}},	//   tsma, _sevr, qdoo, јних_,
   {{0x94868087,0x6d40c704,0x656419b3,0x20cd01a1}},	//   бынд, usma, ntih, džin_,
   {{0x7aed4705,0x9c7c8353,0x38b9b868,0xb866815b}},	//   _skat, močk, _père_, _دارو,
   {{0x95f5064a,0xaca40133,0xd2510f24,0x6d564706}},	//   _आर्ट_, _adịr, وند_, huya,
   {{0x38af02bb,0x6d564707,0x7c3e2f2c,0xddcd0087}},	//   _türk_, kuya, hapr, neaţ,
   {{0x44214708,0x9c830db7,0x7c3883b2,0x65642a58}},	//   ych_, ščit, _tevr, jtih,
   {{0x7cfd80e7,0xc0c84709,0x9a298129,0x6d5602d5}},	//   tère, бусе_, _mươi_, duya,
   {{0x443ec70a,0xaab8901b,0xbcfb02be,0x38af20e8}},	//   mat_, _आतंक, _opér, _jüri_,
   {{0x442120af,0xd2510117,0x38ab8aa2,0x7aed470b}},	//   wch_, _کچھ_, _hørt_, _ukat,
   {{0x4421388d,0x69da1d7e,0xf77804b7,0x38ab806a}},	// [3130] tch_, şter, ħħa_, _kørt_,
   {{0x3f8c80ad,0x645aad75,0x4421470c,0x798d470d}},	//   _ordu_, ngti, uch_, _iraw,
   {{0x4421470e,0x443e8087,0xbcfb08f9,0xcfad8264}},	//   rch_, iat_, _spés, _কেনন,
   {{0x443ec70f,0x442121c9,0xe5700065,0x2d8b017f}},	//   hat_, sch_, بطہ_, _trce_,
   {{0x443ec710,0x7c3e01f6,0x9967c711,0x5d330019}},	//   kat_, bapr, стел, _رہائ,
   {{0x443ec712,0x3f8c80d2,0x02c6016f,0x493c03c8}},	//   jat_, _brdu_, _लग्न, נגוו,
   {{0x443ec713,0xf5228133,0x291308dc,0xf3f323df}},	//   dat_, _rịọr, _mixa_, _رأس_,
   {{0x92b788ca,0x2249061b,0x9c7c826f,0x645ac714}},	//   _احسا, _ndak_, bočk, egti,
   {{0x99d48013,0x212907d5,0x798d0069,0x2d8b801b}},	//   _فتكا, _ntah_, _nraw, íce_,
   {{0x443ec715,0xe4c5835f,0x20cd0110,0x7cef804a}},	//   gat_, ійни, džio_, jørt,
   {{0x798d4716,0x224900b9,0x7cf00198,0xf9891101}},	//   _araw, _bdak_, märt, _שר_,
   {{0xef0e8d13,0xae0908fd,0x798d4717,0x65643d09}},	//   _ім_, वधान_, _braw, ytih,
   {{0x443e8859,0xe5a597c8,0x672d82a5,0x8c4595b7}},	//   bat_, _фили, ćaju, _деле,
   {{0x443eaa71,0x248300dd,0xbf0204c5,0x798d4718}},	//   cat_, _najm_, लग्न_, _draw,
   {{0xfaa6104b,0xa91d931b,0x3f8c016b,0x7c3e4719}},	//   _мако, _drži, ídu_, vapr,
   {{0x765bc71a,0x2ca783b2,0x93bc8087,0x7c3e008e}},	//   nguy, _hond_, rbăt, wapr,
   {{0x27e087d9,0x798d471b,0x2913471c,0x6296471d}},	// [3140] ğini_, _graw, _fixa_, _inyo,
   {{0x33f60e8e,0x27e0c71e,0x629601c0,0x62864079}},	//   очес, şini_, _hnyo, ldko,
   {{0x2ca7ad33,0x7eb5803e,0x656404e8,0x7c3e471f}},	//   _mond_, _nápo, stih, rapr,
   {{0x443ec720,0x7ebc8065,0x62864721,0x7c3e4722}},	//   zat_, _képe, ndko, sapr,
   {{0x6284156b,0x443ec51e,0xe894812f,0x88e6aaf7}},	//   _maio, yat_, заль, ожде,
   {{0x443e881a,0x5fcf0035,0x628412f5,0x11398084}},	//   xat_, _हेडल, _laio, сяцы_,
   {{0x443ec723,0x6d4438a9,0x62960870,0x9949809a}},	//   vat_, lsia, _onyo, góły_,
   {{0x7c3c4724,0xa3d705b3,0x9a29801c,0x7cf48722}},	//   _herr, ापर_, _tươi_, màri,
   {{0x443ec725,0x7c3c0364,0x9c7c8db7,0x41278256}},	//   tat_, _kerr, loči, _мото_,
   {{0x0caaa00d,0x443ec726,0x62964727,0x3b5486d2}},	//   ртии_, uat_, _anyo, пкор,
   {{0x7c3c4728,0x6d4403ac,0x7cf4809f,0x62844729}},	//   _merr, hsia, nàri, _baio,
   {{0x798d472a,0x672dacf6,0x6b83006a,0x7c3c472b}},	//   _praw, ćajt, ængi, _lerr,
   {{0x443e8595,0xf1c5016f,0xaca4019d,0xd251003d}},	//   pat_, _लेखन, _adọr, ونگ_,
   {{0x443ec72c,0x7ebc80e7,0x843880f7,0x9c7c8796}},	//   qat_, _dépe, _اكثر_, koči,
   {{0x224909da,0x9c7c807a,0x6d461f48,0xa8140073}},	//   _tdak_, joči, _avka, ддрш,
   {{0x798d472d,0x5694460d,0x7eb5826f,0x7cf48722}},	//   _traw, маст, _nápl, dàri,
   {{0x7c3c472e,0x443cc72f,0xa91d803a,0x7ebc8019}},	// [3150] _berr, _kev_, _trži, _gépe,
   {{0x7c3c4730,0x2d894731,0x449811e9,0x7d1d87e0}},	//   _cerr, rvae_, овую_, íssi,
   {{0x9c7c8353,0x7eaa026f,0x395901ec,0x443cc732}},	//   goči, _výpr, luss_, _mev_,
   {{0xb77a093f,0x0f7a0158,0x7cf00004,0x877a03c8}},	//   _פארש, _פארב, färs, _פארי,
   {{0x7c3c4733,0xc692093f,0x6b8e022b,0x24830088}},	//   _ferr, _נאך_, _erbg, _tajm_,
   {{0x443c8282,0x7c3c01e1,0x63a300e8,0x3f8103ed}},	//   _nev_, _gerr, ønns, _kshu_,
   {{0x2ca7c734,0xda3597ae,0x78a8817f,0xe7398009}},	//   _rond_, _невы, _dodv, щей_,
   {{0x7d1d4735,0x7c3c0102,0x7640badc,0x7c25297a}},	//   _kuss, _zerr, gamy, lchr,
   {{0xee3681e2,0x62844736,0x7cf00198,0x7d1d1f9f}},	//   чны_, _raio, märr, _juss,
   {{0x443c81e9,0x7d1d4737,0x6aa980f3,0x7c3c4738}},	//   _cev_, _muss, _hoef, _xerr,
   {{0x7d1d12bb,0x2ca78a0f,0x62840037,0x6f028834}},	//   _luss, _vond_, _paio, _fhoc,
   {{0x6d440114,0x443c8609,0x2ca7998b,0x6f028362}},	//   ysia, _eev_, _wond_, _ghoc,
   {{0x361a812a,0x3495a183,0x443cc739,0x5ec300ab}},	//   _הונד, _надр, _fev_, ্কাই,
   {{0x3e4c8110,0x7e6f00c3,0x3ebf808e,0xe51f06ae}},	//   rėtų_, _abcp, lhut_, _बढ़ि_,
   {{0x6441c73a,0x7d1d473b,0xdfd200f7,0xc7a60098}},	//   mali, _auss, رير_, чивк,
   {{0x7c3c1ed6,0x7d1d473c,0x7d150029,0x6d440006}},	//   _serr, _buss, _aizs, tsia,
   {{0x7c3c473d,0x6d44473e,0x6e3d473f,0x6e2405e4}},	// [3160] _perr, usia, _desb, rcib,
   {{0x6abbc740,0x7cf4809f,0x6e24383e,0x443c856c}},	//   _aluf, tàri, scib, _xev_,
   {{0xd838805c,0x6e3d010c,0x6d440ca9,0x3ebfc67a}},	//   _uoči_, _fesb, ssia, khut_,
   {{0x9c7c824a,0x6441c0cc,0xe80f946d,0xdddba365}},	//   roči, hali, ाधना_, zduš,
   {{0x6441843c,0x7c3c05d8,0x290a004f,0x26d201b4}},	//   kali, _terr, omba_, miyo_,
   {{0x6441c741,0x69c28613,0x26d24742,0x92cc80ab}},	//   jali, rzoe, liyo_, রকে_,
   {{0x6abb9045,0xf0930039,0xa3cba120,0xdddb807a}},	//   _fluf, תנו_, _रेल_, vduš,
   {{0x6d558063,0x443cc743,0x69cd94d5,0x3ebf8359}},	//   ązan, _sev_, _देवी, ghut_,
   {{0x6441c744,0x443c822c,0x76408a03,0x25a00118}},	//   fali, _pev_, ramy, nxil_,
   {{0x6441c745,0x26d23c6e,0x645e033e,0x31bb8039}},	//   gali, hiyo_, ngpi, _הזמנ,
   {{0x443c8069,0x61e412ca,0x81aa00ab,0x6f1e016a}},	//   _vev_, _axil, _গেল_, _nupc,
   {{0xed5aa87b,0x201a03a8,0x6441956e,0x26d20079}},	//   _год_, _agpi_, aali, jiyo_,
   {{0x6441c746,0x26d24747,0x443cc748,0x6e3d4749}},	//   bali, diyo_, _tev_, _resb,
   {{0x64a381e2,0xa3ac0af7,0x39590dba,0x6e3d474a}},	//   _пача, गहा_, russ_, _sesb,
   {{0x7d1d474b,0x6e3d008e,0x7f94474c,0x2d824264}},	//   _suss, _pesb, нарх, _aske_,
   {{0xc6f9102a,0x26c00122,0x0ccd80ab,0x67278061}},	//   інах_, ghio_, রকৃত, _éjje,
   {{0x3d1706a7,0xd83880c3,0x1ddc820e,0x7c25474d}},	// [3170] _भूखे_, _hoču_, मपित, tchr,
   {{0xad9b0e1b,0x4427474e,0xc1bc0039,0x3f8101c0}},	//   _azúc, ùn_, _למחש, _tshu_,
   {{0x23790b76,0x09aa80c8,0x7d150019,0x2d8206c0}},	//   تماد_, _খেলা, _vizs, _eske_,
   {{0x7d1d2468,0x7c25474f,0x6441c750,0x26c04751}},	//   _tuss, schr, zali, chio_,
   {{0x6441c752,0x6f1e00d2,0x0ef9064a,0x69348956}},	//   yali, _zupc, ंतीस_, енчу,
   {{0x7e62c753,0x64418085,0xb9260032,0xf4840098}},	//   _acop, xali, _aawọ_, _пусн,
   {{0x238c801b,0x66e58a13,0xb5fb046d,0x6aa9989f}},	//   _něj_, мока, _gbár, _toef,
   {{0x2bd30074,0x3949016a,0x7e6d0118,0x44278299}},	//   _धेया, _ovas_, nfap, _sfn_,
   {{0x26c381e2,0x224dc754,0x6f09872a,0x442580b9}},	//   ėjo_, _idek_, rmec, tcl_,
   {{0x26d2005d,0x38b40f02,0x3a3f998b,0xa91d936f}},	//   ziyo_, _värk_, _heup_, _držt,
   {{0x3b0a1ad3,0x68e48174,0x394902f1,0x61f60198}},	//   жено_, éide, _avas_, _syyl,
   {{0xe29a4755,0x80d00540,0x216a0009,0x291f804f}},	//   цам_, डोने, оими_, _kuua_,
   {{0x68ee05ee,0xf652825f,0x44279914,0x7e7bab8c}},	//   tobd, _יצא_, _tfn_, meup,
   {{0x31568158,0xd838826c,0x6441c756,0x6ada9a4d}},	//   וישן_, _foču_, qali, _भद्र,
   {{0x26c0031d,0x7ebcbb9b,0xdce401b9,0x291f82f1}},	//   thio_, _hépa, stiċ, _luua_,
   {{0x61f60009,0x212d8326,0x61e40cdb,0x224d9abb}},	//   _tyyl, _oteh_, _txil, _ndek_,
   {{0xf1bf1db7,0x26d24757,0x6d468e63,0x6569c758}},	// [3180] lcán_, riyo_, škav, nteh,
   {{0x3157093f,0x24878247,0x26d24759,0x9c7ca6b5}},	//   _קיין_, _janm_, siyo_, boču,
   {{0x24878247,0x224001e0,0x212dc75a,0x9a86a8ff}},	//   _manm_, _keik_, _ateh_, дулл,
   {{0xe1fa8604,0x212003ac,0xa3d48054,0x38af01ec}},	//   оге_, _kuih_, _सेफ_, _fürs_,
   {{0x397a9e44,0x2d8200ce,0x29058362,0x69c6358b}},	//   تصاد_, _uske_, _bhla_, nzke,
   {{0x7e62c75b,0x3a26c0fc,0x224024f1,0x212000ee}},	//   _scop, scop_, _leik_, _muih_,
   {{0x63831957,0x3946a379,0xdb8324dd,0x212009c4}},	//   _игра, ssos_, _игри, _luih_,
   {{0x4444475c,0xf8bb0e70,0x81c400c8,0x2f178009}},	//   la_, _उत्प, _এখন_, мощь_,
   {{0x7866c75d,0x4444011e,0x248783ec,0x6d4f8b80}},	//   _оказ, oa_, _banm_, šcan,
   {{0x4444475e,0x7ebc83d3,0x09038162,0x00000000}},	//   na_, _dépa, _апун, --,
   {{0x44440c39,0x79841ec4,0x403380e8,0xb86584c1}},	//   ia_, _asiw, _реєс, _سالو,
   {{0x4444475f,0x63a34760,0x21202c30,0x6d5b820d}},	//   ha_, änni, _buih_, buua,
   {{0x44444349,0x24878247,0xf1bf0e1b,0xf5b6815b}},	//   ka_, _fanm_, acán_, _تصاد,
   {{0xfbcf89d7,0x690b0372,0xfd4f0129,0x6602c761}},	//   اتی_, _ażer, _triế, _izok,
   {{0xc5888104,0xd7f801a0,0x2f01b2c9,0x86020176}},	//   _hồ_, дут_, lóga_, _dakٍ_,
   {{0x4444002e,0x3869811f,0x442a4762,0x76440326}},	//   ea_, đari_, _afb_, gaiy,
   {{0x44444763,0x09d90a49,0x39492755,0xfd1f38ef}},	// [3190] fa_, _সরকা, _uvas_, _quì_,
   {{0x80b383db,0xc58880ff,0x599601c6,0x9c7c81d6}},	//   _अवधे, _mồ_, _נכתב_, poču,
   {{0x70db86a7,0xc58880ff,0x32558d9e,0x442a4764}},	//   _बदौल, _lồ_, евер, _dfb_,
   {{0x7d188bfa,0x44444765,0x527c03de,0x6f060362}},	//   _livs, aa_, ַנוא, _ghkc,
   {{0x7c2aac59,0x5e5600be,0x6f0d04b9,0x442a1abb}},	//   _offr, _אירע_, mmac, _ffb_,
   {{0x6f0d4766,0xf8bf03c9,0x7ebc80e7,0xd1b8806b}},	//   lmac, mpés_, _répa, باما_,
   {{0x64453151,0x6602c767,0x7ebc80e7,0x7ceb4768}},	//   mahi, _azok, _sépa, kürz,
   {{0x7c2ac769,0xc58880ff,0xf4298198,0x291f82f1}},	//   _affr, _bồ_, kkää_, _tuua_,
   {{0x7d1881dd,0xa3d48424,0x9875ba7d,0x2240476a}},	//   _bivs, _सेब_, _плац, _reik_,
   {{0x644545eb,0x6569b12f,0x6f0d45ff,0x31348087}},	//   nahi, rteh, hmac, _рефр,
   {{0xeb998785,0x6569c76b,0x6f0d476c,0xccf20039}},	//   чин_, steh, kmac, רכי_,
   {{0x644528b8,0x87b680be,0x6aad0087,0x1a66015b}},	//   hahi, _אלעס_, _coaf, ریخی_,
   {{0xed4ea46a,0x463a893f,0x64451066,0xa3d48074}},	//   _що_, _זענע, kahi, _सेठ_,
   {{0x444416cb,0xdb1a8065,0x73e58698,0xfc3189a7}},	//   xa_, sztá, _полз, _صحت_,
   {{0x6d49c76d,0x6445476e,0x910311c7,0x224000b9}},	//   lsea, dahi, упре, _teik_,
   {{0x6443007b,0x98a00369,0x2d800035,0x6721ae5c}},	//   ðnin, _otić_, twie_, _mulj,
   {{0x6d49c76f,0x672181b9,0x7eb5ad84,0x76442050}},	// [31a0] nsea, _lulj, _cápi, raiy,
   {{0x6d498ad0,0x9f864770,0x44444771,0x26df80d2}},	//   isea, _згод, ua_, hnuo_,
   {{0x7c249010,0x26df805c,0x929d809a,0x6e460af2}},	//   _şirk, knuo_, _chło, _пенз,
   {{0x44444772,0xe60780f7,0xaa7b026f,0x7c3b0115}},	//   sa_, _مش_, mnýc, _đure,
   {{0x64454773,0xaa7b026f,0xd6d080d5,0xda6580f7}},	//   bahi, lnýc, یقت_, ضاني,
   {{0x10a38a94,0x44444774,0x98a39e4e,0x6d4981e4}},	//   личн, qa_, личе, dsea,
   {{0xaa7b026f,0x6602900b,0x7eb5826f,0x291a008e}},	//   nnýc, _szok, _zápi, _mipa_,
   {{0x6721c775,0x26df80ce,0x7d1b4776,0x6f199670}},	//   _dulj, gnuo_, _èusc, _ciwc,
   {{0x6d49c777,0x91e38081,0x301a81a8,0x66db062c}},	//   gsea, _боте, _فتاة_, läkä,
   {{0x291a077f,0xa2a3064a,0x7ae44778,0x224682d5}},	//   _nipa_, गाभ्, _ajit, laok_,
   {{0xf3898104,0xaa7b026f,0x31e280ab,0x6f0d10ae}},	//   _cả_, jnýc, _বরিশ, ymac,
   {{0xaa7b0efc,0x6d498362,0x34dd109b,0xad2681a8}},	//   dnýc, bsea, _मद्द, _كرتو,
   {{0x6721826c,0x644546d0,0x291a0115,0x6d498427}},	//   _zulj, yahi, _bipa_, csea,
   {{0x7eb58510,0x26f90935,0xb4af1d9a,0x212b802a}},	//   _rápi, ंत्र_, _ओके_, _éche_,
   {{0x64453855,0x6f0d4779,0x291a477a,0xbddb010c}},	//   vahi, tmac, _dipa_, _ndèr,
   {{0x7ae40b18,0x6445477b,0x7cf487f1,0xabfb81c6}},	//   _gjit, wahi, càrr, _מהור,
   {{0x6445477c,0x7c3b0267,0x988381d6,0x75228084}},	// [31b0] tahi, _đurb, víľu_, _juoz,
   {{0x7afd477d,0xaa7b0a21,0x6f0d0d35,0x98650065}},	//   llst, bnýc, smac, _جیسے_,
   {{0xc4d380be,0xf09f80ff,0x764b0019,0xd6d10f24}},	//   נגע_, _đà_, ógys, _نقد_,
   {{0x6445477e,0x291a0279,0x59d2809a,0xbd05826b}},	//   sahi, _zipa_, _देहर, _akẹ́,
   {{0x67218364,0x6445477f,0x41b325ef,0xc2c481a8}},	//   _sulj, pahi, ुनिस, ديني,
   {{0xdb2304c0,0x3ea94780,0x9dd60039,0x7afd3d7f}},	//   _موسی, ljat_, _יורק_, hlst,
   {{0x656d4781,0x26df8503,0x07a58c07,0x9be401e5}},	//   ltah, tnuo_, тайн, _бітк,
   {{0x7ebc82be,0xcf248154,0x3ea94782,0xf1d29094}},	//   _dépo, دروي, njat_, _देवन,
   {{0xceb40f60,0x391593bd,0x6e29c783,0x26df8289}},	//   טיק_, _амар, rceb, rnuo_,
   {{0x6d49c784,0x26df812b,0x7af608f8,0x7afd09e5}},	//   rsea, snuo_, _skyt, elst,
   {{0xa3ba01ce,0x6d49c785,0x3ea90267,0x3fdc00ab}},	//   आईए_, ssea, kjat_, _ধর্ষ,
   {{0x291a0699,0xaa7b0a21,0x3ea902a6,0x6d5f005d}},	//   _sipa_, vnýc, jjat_, kuqa,
   {{0x6d46803a,0xcb128158,0x20d600e8,0x656d35a3}},	//   škar, ילט_, вівс, jtah,
   {{0xaa7b0efc,0xf389801c,0x7afd2580,0x20188580}},	//   tnýc, _tả_, alst, _úric_,
   {{0x46f600e8,0x7eb816dc,0x10a306e9,0xddca0035}},	//   вчат, _hípi, ширн, łoży,
   {{0xcf928158,0xaa7b026f,0x321f801c,0x20cd0084}},	//   סטן_, rnýc, _nguy_, džiu_,
   {{0x6443c786,0x61fbc787,0xaa7b026f,0x656d2afd}},	// [31c0] _keni, _nyul, snýc, gtah,
   {{0x64439e92,0xaa7b016b,0xfaf901a9,0x66db062c}},	//   _jeni, pnýc, stīt_, täkä,
   {{0x394d87a3,0x61e99a1c,0x7eb82d84,0x213f810c}},	//   _aves_, _axel, _lípi, _awuh_,
   {{0x60c1c788,0x7ebc83d3,0x6443b139,0x79828035}},	//   _allm, _répo, _leni, twow,
   {{0x80b38075,0x7ebc82be,0x200580b9,0x3eab016b}},	//   _अवशे, _dépl, _azli_, žitá_,
   {{0x7982809a,0xed59816b,0x6443c789,0x2126808e}},	//   rwow, drž_, _neni, rqoh_,
   {{0x61e9c78a,0x7ee69d7b,0xf6e68ff7,0x213f88f9}},	//   _exel, кцие, кцин, _ewuh_,
   {{0x2d86a0e6,0x7e64478b,0xd6d784d9,0x7bc8816b}},	//   _psoe_, ngip, кты_, vzdu,
   {{0x6443c78c,0x7ae281f6,0x2d9206c0,0x61fb8061}},	//   _beni, mnot, nvye_, _gyul,
   {{0xd90e826a,0xe7eda776,0x64438942,0x7ae2c78d}},	//   _بیت_, _चुका_, _ceni, lnot,
   {{0x7d1c478e,0x34b70039,0x6443c78f,0x9f4f061c}},	//   _mirs, דפים_, _deni, ünüz_,
   {{0x7ae2c790,0x4fd98158,0x41e705e9,0x394d8c1a}},	//   nnot, _אַנד, віга, _yves_,
   {{0x394d06e3,0xb3568416,0x7afd016d,0xdd9287d2}},	//   ées_, ریکا_, rlst, _خوش_,
   {{0x79964791,0x61e200c3,0x26c24792,0x00000000}},	//   _dryw, _žolc, _alko_, --,
   {{0x6448c793,0x251b898a,0x92950a42,0x442ec794}},	//   madi, _קווא, _байц, _iff_,
   {{0x6443c795,0x7d1c0782,0xaf34003d,0x7c2e4796}},	//   _zeni, _airs, شرفت, _afbr,
   {{0x7ae28775,0x6443884a,0x3ea94797,0xe8d90133}},	// [31d0] dnot, _yeni, rjat_, _asụ_,
   {{0xfaff020f,0x656d0f68,0x6443c798,0x3e530028}},	//   llë_, rtah, _xeni, ệt_,
   {{0xa2b486bf,0x656d45eb,0x38b4016d,0x5a35867c}},	//   _आवश्, stah, _värt_, гнет,
   {{0x941580be,0x628f4799,0x7ae2c79a,0x2bc200bc}},	//   אַנד_, ndco, gnot, वैधा,
   {{0x7d1c0051,0x442e8051,0x69cd93ba,0xaca301bc}},	//   _firs, _off_, _देखी, _atụb,
   {{0x6448c79b,0x7c341663,0xdce981b9,0x7ae28198}},	//   jadi, _верх, rteċ, anot,
   {{0x3d06800f,0x6448c79c,0xccf201c6,0x8af98085}},	//   _सीधे_, dadi, _לכך_, _atəş,
   {{0x6e2d479d,0x2a6901c0,0xb5fd80eb,0x7cfd823e}},	//   ncab, _ncab_, egša, mèri,
   {{0x6448c79e,0x6d4d479f,0x4035ae8c,0x6f1d079a}},	//   fadi, nsaa, _безс, _misc,
   {{0x6448c7a0,0x60c180f7,0x6f1d028e,0x64438168}},	//   gadi, _ullm, _lisc, _qeni,
   {{0x7a6a0758,0x6443c7a1,0x7c958077,0x68f5026c}},	//   нинг_, _veni, نشگا, dozd,
   {{0x79960063,0x64438352,0x6d4d2645,0x68ed8013}},	//   _pryw, _weni, ksaa, éadf,
   {{0x6443b09b,0x645c9313,0x6448c7a2,0x442c89c4}},	//   _teni, óric, badi, bcd_,
   {{0x6f1d0013,0x6448c7a3,0x6d4d47a4,0x644383ba}},	//   _aisc, cadi, dsaa, _ueni,
   {{0x1fb501ae,0x2cb8c7a5,0x7d1c0118,0xd36e81a8}},	//   астр, örde_, _rirs, _فهو_,
   {{0x63bc8aa2,0x292500f7,0x7c3b0da8,0x6d4d067f}},	//   ørne, úpaí_, _đura, fsaa,
   {{0xceb28bea,0xed5700a9,0x7d1c0077,0xe5a347a6}},	// [31e0] זין_, лот_, _pirs, бити,
   {{0x888610f8,0x6f1d47a7,0x03a62302,0x7ff600f7}},	//   _слож, _eisc, лизо, _مسجا,
   {{0x7d1c0bb6,0xfaf900eb,0xad9b0e1b,0x7ae2c7a8}},	//   _virs, brīd_, _ayúd, tnot,
   {{0x6d5b820f,0x6e2d1ad0,0xbea60a08,0x80a201ab}},	//   krua, ccab, _самк, खावे,
   {{0x7ae2c7a9,0x7d1c47aa,0x2d8402be,0x6448bc69}},	//   rnot, _tirs, _ème_, yadi,
   {{0x7ae2c7ab,0xb6058088,0x2cb102d4,0x6448857b}},	//   snot, _mišč, _gozd_, xadi,
   {{0x6448b386,0x9cd704de,0xe3a78829,0x442c8122}},	//   vadi, _עולה_, _ار_, vcd_,
   {{0x6448c7ac,0x442e8da8,0x6e3b97ea,0x798611ee}},	//   wadi, _sff_, gbub, kwkw,
   {{0xceb3025f,0x6d5bc7ad,0x442cc7ae,0xbddb0176}},	//   מיה_, grua, tcd_, _neèl,
   {{0xddcb8087,0x752600ee,0x3374c7af,0x3a098fd3}},	//   ţişt, _mukz, агор, _شکنی_,
   {{0x6448c7b0,0x7eb5a769,0x4f5a92c8,0x5fa8ac17}},	//   radi, _cáps, _سجاد_, _कपिल,
   {{0x6448c7b1,0x291ec7b2,0x6d4d0079,0x764631f3}},	//   sadi, _hita_, ysaa, _neky,
   {{0x291ec7b3,0x6f1d01e8,0x6448bb3a,0xa3d482f1}},	//   _kita_, _risc, padi, _सेर_,
   {{0x6f1d47b4,0x1be40540,0x291ec7b5,0x644881b4}},	//   _sisc, कपाल_, _jita_, qadi,
   {{0x291e854e,0x764601eb,0x40340009,0x248e80ee}},	//   _mita_, _beky, сесс, _iafm_,
   {{0x9635432c,0xf1a729e4,0x291ec7b6,0x6d4d2bcc}},	//   рнац, _брон, _lita_, tsaa,
   {{0x2d580c4f,0xf8ae004e,0x272ac7b7,0xe9058129}},	// [31f0] лить_, سکی_, _lùn_, _lượ,
   {{0x6d4d47b8,0x6e2d0333,0x7cfd809f,0x0f35003d}},	//   rsaa, scab, tèri, _نکرد,
   {{0x6d4d47b9,0xd25192dc,0x6f1d36ae,0xbc070a0e}},	//   ssaa, قنا_, _tisc, учай,
   {{0x6e22aff2,0x6f1d00f7,0x291ec7ba,0x0ce1a594}},	//   _ngob, _uisc, _aita_, _पद्म,
   {{0xa0698638,0x1869845d,0x68458071,0xe0458767}},	//   вала_, вали_, анла, анли,
   {{0x2f55a358,0x272a9b5b,0x2d990511,0x7eb5816b}},	//   атис, _bùn_, _irse_, _nápr,
   {{0x256f2e76,0x291ec7bb,0x628281ed,0x6d4285ee}},	//   lül_, _dita_, beoo, _awoa,
   {{0xca488307,0x443108ae,0x6d5bc7bc,0x2d990b80}},	//   _ملفه_, _hfz_, trua, _krse_,
   {{0x7afbb6a5,0x291ec7bd,0x644747be,0xa2c28f12}},	//   _ikut, _fita_, _keji, लसर्,
   {{0x6d5ba7ed,0x6447000d,0x291ec7bf,0xeb998eef}},	//   rrua, _jeji, _gita_, вио_,
   {{0x644747c0,0x645c8187,0xb6058115,0x7ae98163}},	//   _meji, ória, _sišč, _kjet,
   {{0x2d8b0267,0x64470b95,0x60c500dd,0xb605807a}},	//   _osce_, _leji, _alhm, _pišč,
   {{0xddc2800d,0x7afb8010,0x2611ac4c,0x7ae980f1}},	//   _zbož, _mkut, देशी_, _mjet,
   {{0x7ae982fd,0xe8f72902,0x6ac28778,0x3eadc7c1}},	//   _ljet, иля_, _शत्र, ljet_,
   {{0x7afbc7c2,0xb8de0f8d,0x290400eb,0x2d8b0037}},	//   _okut, _आव_, ēma_, _asce_,
   {{0x5de6098d,0xc6c31d38,0x3eadb038,0x068603a7}},	//   ажба, ойск, njet_, јган,
   {{0x1c461a03,0xa4460d0e,0x256f47c3,0x4ad80019}},	// [3200] инам, инад, gül_, _لاکھ_,
   {{0x7ae9c7c4,0xf1c20824,0x3eadc7c5,0x389a03de}},	//   _ajet, rišč_, hjet_, _ייִנ,
   {{0x0c790196,0xdddb8289,0x2d8b047f,0x63a30106}},	//   ысты_, jduž, _esce_, ännp,
   {{0x291ec7c6,0x2bda016f,0x3ebfc7c7,0x78a186c4}},	//   _sita_, _येणा, jkut_, _anlv,
   {{0x27f70bca,0x7ae982fd,0x3ead82ce,0x3f9a2f56}},	//   _مفید_, _djet, djet_, _hrpu_,
   {{0x64550063,0x60dc47c8,0xd8f780e8,0x7afb8c6a}},	//   _gdzi, nirm, анії_, _ekut,
   {{0x291ec7c9,0x3cf50072,0x65640198,0x7ae983ed}},	//   _vita_, ्तरे_, luih, _fjet,
   {{0x7ae984b1,0x12c100c8,0x3f988125,0x3ead80f1}},	//   _gjet, _উদ্দ, _árum_, gjet_,
   {{0x291ec7ca,0x2bda016f,0xd04a8085,0xe4a6c7cb}},	//   _tita_, _येता, zifə, арно,
   {{0xd49a8847,0x291e8087,0x27ed350a,0x26c900fc}},	//   три_, _uita_, şeni_, zhao_,
   {{0x60dc0850,0x256f0019,0x26c00037,0x92952cab}},	//   dirm, zül_, kkio_, банц,
   {{0x63bac7cc,0x81c301a9,0xd5e2846d,0x5693804a}},	//   rytn, ņēmi, _gbo̟, _маєт,
   {{0x60dc47cd,0x20b4000f,0xd534826a,0xfce69c9b}},	//   firm, ुसंध, _افتخ, _кодо,
   {{0x26c681c0,0x60dc47ce,0x256f0019,0x7c3b0904}},	//   _hloo_, girm, vül_, _đuro,
   {{0xb5e880c8,0x23278b30,0xab278fbb,0x644747cf}},	//   _পরিচ, _који_, _која_, _reji,
   {{0x256f0019,0x3a2480b9,0xa2d6064a,0x61ed011b}},	//   tül_, _ngmp_, मोद्, _txal,
   {{0x64470699,0x60dc47d0,0xdddb8754,0x44230144}},	// [3210] _peji, birm, zduž, _pgj_,
   {{0x7afb8a7a,0x7ae9911b,0x256f0019,0x60dc47d1}},	//   _skut, _sjet, rül_, cirm,
   {{0x443e82af,0x9f5e80f1,0x68f88b67,0x644747d2}},	//   ibt_, _dytë_, dovd, _veji,
   {{0x21290590,0xb69b00e7,0x29034619,0x66e881d0}},	//   _kuah_, _chât, llja_, děko,
   {{0x7ae9c7d3,0x3ead911b,0x644705a4,0x764d47d4}},	//   _vjet, vjet_, _teji, maay,
   {{0xe8f88160,0x6455009a,0xaa7b016b,0x764d47d5}},	//   алі_, _udzi, dným, laay,
   {{0x7ae988cf,0x3ead80f1,0x02a79273,0x212900ee}},	//   _tjet, tjet_, _крам, _luah_,
   {{0x7afb91e8,0x764d1a2b,0x7ae9beeb,0x7980819d}},	//   _ukut, naay, _ujet, _ịweg,
   {{0x6eba0076,0x3eadc7d6,0x3ebfc7d7,0x332001b4}},	//   _एकसु, rjet_, rkut_, _riix_,
   {{0x3eadc7d8,0x764d0079,0x212109da,0x26c0011b}},	//   sjet_, haay, _nihh_, zkio_,
   {{0x798d1629,0x80ab14d5,0xaca30133,0x764d132f}},	//   _asaw, ञाने, _adịc, kaay,
   {{0x212914ec,0xaa7b016b,0xe1ff016a,0x799b810c}},	//   _buah_, bným, rgón_, _kruw,
   {{0xed599182,0x764d47d9,0x60dc47da,0x443e80f2}},	//   _сол_, daay, tirm, bbt_,
   {{0x6c3589d7,0x2d8902f7,0xdce401a1,0x7af9c7db}},	//   _افغا, dwae_, mtić, howt,
   {{0x5b358b76,0xbea60d69,0xe29a47dc,0x60dc47dd}},	//   _اعتر, бавк, _бай_, rirm,
   {{0xc2460652,0x2a6d822c,0x9f5e8168,0x2bc60697}},	//   _уник, _nceb_, _sytë_, लनसा,
   {{0x6da347de,0x29030ee1,0xe8df9d3c,0x60dc0637}},	// [3220] пита, blja_, _awọn_, pirm,
   {{0x308600f7,0x07fa003d,0x387a018e,0x0ffa01a8}},	//   _الدف, _مرجع_, _ubpr_, _معجب_,
   {{0xe29ac7df,0x799bc7e0,0xa2e6a7ee,0x202901d6}},	//   лаж_, _aruw, божд, átiť_,
   {{0x673b0bcf,0xdce40115,0x764d01b4,0x799bc7e1}},	//   ćujt, ktić, caay, _bruw,
   {{0x6728ac14,0xf1d28321,0x6f0447e2,0xdce40bda}},	//   _sudj, _देखन, mlic, jtić,
   {{0x6f0447e3,0x672886cb,0xaa7b016b,0x628647e4}},	//   llic, _pudj, vným, heko,
   {{0x68f884b7,0x35d086a7,0x38cb8180,0x6f04383e}},	//   rovd, _तेज़, دانی_, olic,
   {{0x1dd9823c,0x62863636,0x2bb50076,0x6f0402af}},	//   _बेहत, jeko, ंहरा, nlic,
   {{0x645c8073,0x62862dfe,0x6f0447e5,0x7c29026c}},	//   ório, deko, ilic, _đerz,
   {{0x67288065,0x6f0402af,0x21290359,0x6aa40114}},	//   _tudj, hlic, _ruah_, _anif,
   {{0x6f0447e6,0x23658bcf,0x764d47e7,0x443ec7e8}},	//   klic, gulj_, yaay, rbt_,
   {{0x6286044e,0x21293d11,0x212102f7,0xd5a48180}},	//   geko, _puah_, _sihh_, _ولای,
   {{0x6f0447e9,0x290300d2,0xc05b00e8,0x7ae38511}},	//   dlic, tlja_, лів_, énti,
   {{0x764d0ec8,0xf6178039,0x6f0447ea,0x66e50084}},	//   waay, _החדש_, elic, mėki,
   {{0x6f0447eb,0x628647ec,0x764d25d5,0x2129008e}},	//   flic, beko, taay, _wuah_,
   {{0x6f0447e9,0x798d47ed,0x36d4223c,0x29030699}},	//   glic, _tsaw, поср, slja_,
   {{0x29030503,0xdced1c17,0x798d26b4,0x764d3e6e}},	// [3230] plja_, stač, _usaw, raay,
   {{0x764d02ec,0xddd00162,0x66029075,0x00000000}},	//   saay, ţeşt, _myok, --,
   {{0x7c2d8214,0xdce08289,0x660283f7,0x764d033e}},	//   _şark, jumč, _lyok, paay,
   {{0x799bc7ee,0x26d90192,0x99998056,0x764d0df6}},	//   _pruw, _umso_, икет_, qaay,
   {{0x6458935a,0x6602925c,0xd825c7ef,0x6025841c}},	//   _odvi, _nyok, одли, одла,
   {{0x47598021,0x10a281f3,0x98a28323,0x628647f0}},	//   ария_, дишн, дише, zeko,
   {{0xe7398009,0x6602c7f1,0x7e699384,0xdddb81a1}},	//   шей_, _ayok, tgep, deuš,
   {{0x2ee9031d,0x64589527,0x6602c7f2,0x62860cdb}},	//   nnaf_, _advi, _byok, xeko,
   {{0x628647f3,0x644ab805,0x7e69c7f4,0xb88380e1}},	//   veko, _befi, rgep, _príč,
   {{0x7aed47f5,0x7cfdc7f6,0xcd2881a8,0x753bc7f7}},	//   _ajat, vèrs, حسين_, rpuz,
   {{0x62861711,0xdce4003b,0x6f0447f8,0x64988196}},	//   teko, stić, ylic, стыр_,
   {{0x67228144,0x2485c7f9,0x644a8032,0x6d4f8118}},	//   _gioj, selm_, _eefi, ácas,
   {{0xe56ea5f5,0x644a802a,0x412a042f,0x7aed0168}},	//   _юз_, _fefi, рого_, _djat,
   {{0x8afd0d38,0x644ac7fa,0x186a0dc7,0x52b68fea}},	//   stęp, _gefi, јави_, _अक्स,
   {{0x6f040352,0x6441c7fb,0x68e480f7,0x93bc8087}},	//   tlic, mbli, éidi, scăr,
   {{0x7aed020f,0xee3a1289,0xf4128039,0x752382af}},	//   _gjat, рна_, _קפה_, _hinz,
   {{0x6f04474f,0x764b8065,0x5d6a2361,0x6441c7fc}},	// [3240] rlic, _megy, ризм_, obli,
   {{0x764b8065,0x44278057,0x81c200ab,0x6441989c}},	//   _legy, _jgn_, ্পদ_, nbli,
   {{0x6f0447fd,0x68fc04fe,0x61fb04b7,0x93460558}},	//   plic, mord, żult, інде,
   {{0xf1db946d,0xa206b19d,0x7523c7fe,0xe5a624dd}},	//   _मेहन, опед, _linz, _дими,
   {{0x6722957a,0x68fc01ed,0x9c7cc7ff,0x4427c800}},	//   _rioj, oord, liče, _ogn_,
   {{0x257404b8,0x68fc4801,0x764b82f7,0x4427c802}},	//   mäl_, nord, _aegy, _ngn_,
   {{0x9c7c803a,0x764b8a38,0x67228388,0x660280b9}},	//   niče, _begy, _pioj, _syok,
   {{0x35b4938c,0x752b810c,0x1ef781a8,0x68fc3c2a}},	//   збир, _bugz, يعية_, hord,
   {{0x65762da9,0xd04e0201,0x0caa9a1f,0x94aa9ad3}},	//   ntyh, sibə, атни_, атна_,
   {{0xf06390ef,0x7ebcc803,0x7523c804,0x2cb80370}},	//   _окуп, _répu, _cinz, _jord_,
   {{0x44278483,0x9c7c8067,0x7aed4805,0x2cb81b59}},	//   _dgn_, jiče, _pjat, _mord_,
   {{0xf3ec0a49,0x75238352,0x04fc80c8,0x050a80ab}},	//   _করার_, _einz, ীদের_, রদের_,
   {{0x6441c806,0xead2877f,0x2574016d,0x2d968294}},	//   bbli, _rẹ̀_, jäl_, _фрес,
   {{0x64588022,0x2cb846fb,0x2bca800f,0x644a80c3}},	//   _udvi, _nord_, ानदा, _uefi,
   {{0xd6db4807,0x7aed0aa8,0xcb6782ee,0x00000000}},	//   ата_, _tjat, _даје_, --,
   {{0xa5351091,0x4427890d,0x25740338,0x7e7d09c4}},	//   знач, _zgn_, fäl_, _qbsp,
   {{0x2cb84808,0x38c900d7,0xdb17066f,0x06cd0264}},	// [3250] _bord_, _هادی_, ńców, রচলি,
   {{0x7afd4809,0x68fc480a,0x3f9eb58a,0x44278118}},	//   lost, cord, _ortu_, _xgn_,
   {{0xd0f80441,0x2d82480b,0xfe700019,0xfbab01e5}},	//   ंकरण_, _epke_, عدہ_, штай_,
   {{0x6ffa01c6,0x25bf8326,0x6e960061,0x3eb415d8}},	//   _להתפ, yyul_, _فلپا, ľatá_,
   {{0x64418114,0x3f9eba6d,0x2cb8480c,0x764b83f7}},	//   ybli, _artu_, _ford_, _regy,
   {{0xe0d8835f,0xfbca89c2,0x55ba0039,0x752b890d}},	//   ові_, ानाम, _המשו, _rugz,
   {{0x3eb9480d,0x602283c7,0x7ebc8019,0x3f9e811f}},	//   _kost_, ндша, _néps, _crtu_,
   {{0x7e6d480e,0x0ea98364,0x7523950f,0x64418176}},	//   ngap, ский_, _sinz, wbli,
   {{0x3eb90051,0x68fc07d9,0x95558013,0x7ebc8ece}},	//   _most_, yord, أخبا, _répt,
   {{0xe73380f7,0x7ebc85e4,0x2b478114,0x6441c80f}},	//   _قصص_, _sépt, _pwnc_, ubli,
   {{0x6441bb94,0x7afd4810,0xe29a1510,0x68fc00c9}},	//   rbli, fost, бан_, vord,
   {{0x7afd4811,0x2907c812,0x9c7cc813,0x212d80ee}},	//   gost, llna_, viče, _kueh_,
   {{0x442780dd,0x261183eb,0x224dc814,0x75239ac7}},	//   _tgn_, देखी_, _meek_, _tinz,
   {{0x97428067,0x659a812a,0x2574016d,0x27318091}},	//   šćen, _לינק, väl_, _kán_,
   {{0x3f5701cd,0x07a3140b,0x3eb94815,0x273180e1}},	//   għu_, нарн, _bost_, _ján_,
   {{0xcf92893f,0x7afd4816,0x7e6d25ba,0x63bc8338}},	//   עטן_, cost, ggap, ärne,
   {{0x05664817,0x68fc4818,0x27319ccf,0x38b402af}},	// [3260] яван, pord, _lán_, _märz_,
   {{0x629610c1,0x7e6d02c4,0x9c7c82d4,0x2731827d}},	//   _hayo, agap, piče, _oán_,
   {{0x3eb94819,0x6296481a,0xc61d00ab,0x7bc1810c}},	//   _fost_, _kayo, ধুলা_, nylu,
   {{0x2fc50bc5,0x2cb80039,0xc7b303c8,0x212d8144}},	//   ølge_, _word_, _טבת_, _bueh_,
   {{0xd24f83f8,0xe8948c5c,0x7644481b,0x673a80b9}},	//   انه_, даль, mbiy, _sttj,
   {{0x27318104,0x7afd481c,0x20058cf0,0x6296481d}},	//   _bán_, zost, _byli_, _layo,
   {{0xd6da8987,0x764402a3,0x2731801c,0x6d5d81a8}},	//   йти_, obiy, _cán_, ásan,
   {{0x44440352,0x7c3b0d11,0x98788353,0x442a1705}},	//   lb_, _đuri, _išči_, _hgb_,
   {{0x644e481e,0x7afd481f,0x444410af,0x6d564820}},	//   _kebi, vost, ob_, nsya,
   {{0x7ae2c821,0x44444822,0x3d068424,0xdb1b0019}},	//   liot, nb_, _सीखे_, sztü,
   {{0x44440cd8,0x2731c823,0x62961ed0,0x6d56010b}},	//   ib_, _gán_, _bayo, hsya,
   {{0x644e048f,0xddc400eb,0x6d564824,0x629601e0}},	//   _lebi, maiņ, ksya, _cayo,
   {{0x64a6b1b3,0x6296033e,0xdca6824f,0x0e9b8039}},	//   _нада, _dayo, _нади, _לשאל,
   {{0x760b8158,0x644e4825,0x442a4826,0xf8be83eb}},	//   _פּאַ, _nebi, _ngb_, ्सिय,
   {{0x3eb90051,0x62808353,0x44444827,0x78bac828}},	//   _post_, _obmo, db_, _motv,
   {{0x44444829,0x629602b8,0x442a02af,0x65640bbd}},	//   eb_, _gayo, _agb_, frih,
   {{0xdb1b247d,0x7e6d406f,0xa2aa0e00,0x672601b9}},	// [3270] sztó, rgap, टार्, _dikj,
   {{0x66060aa2,0xb03527ee,0x66ca04e8,0x290701a8}},	//   _dykk, _юнош, _výka, _óna_,
   {{0x7644482a,0xa3e28540,0x62961c83,0x316c0035}},	//   bbiy, _नेम_, _yayo, ądze_,
   {{0x4444146a,0x2731c82b,0x66ca026f,0x645c09c4}},	//   ab_, _rán_, _týka, _edri,
   {{0x4444482c,0x27318091,0x442a482d,0x9c7c8110}},	//   bb_, _sán_, _fgb_, anči,
   {{0x644e105d,0x224d8039,0x2731816b,0xb5fb026b}},	//   _gebi, _week_, _pán_, _adág,
   {{0x7ebcbb9b,0xb90586a7,0x690d802a,0x644505e7}},	//   _répr, _पग_, búen, mbhi,
   {{0x3eb9808b,0x7ae2c82e,0x442a482f,0x78a8c830}},	//   ðst_, ciot, _zgb_, _endv,
   {{0x62964831,0x78278154,0x802782e3,0x628bc832}},	//   _rayo, _فعال, _فرام, mego,
   {{0x2731c833,0x628b88ff,0x62960637,0x6299c834}},	//   _tán_, lego, _sayo, ldwo,
   {{0xb4cd8076,0x62964835,0x764401b4,0x7527090d}},	//   _रती_, _payo, ybiy, _mijz,
   {{0x628bc836,0xbe15845b,0x91e6425e,0x63a31c70}},	//   nego, _قواع, доме, änny,
   {{0x6f098c0b,0xdc0a1995,0xed4e9c57,0x6f1bc837}},	//   mlec, _वर्ड_, _шо_, mmuc,
   {{0x7ae2c838,0x628b83a8,0x6f09c839,0x6606054f}},	//   ziot, hego, llec, _rykk,
   {{0xa3dd483a,0x6296483b,0x660600e8,0x628b810c}},	//   _तेल_, _tayo, _sykk, kego,
   {{0x68e3c83c,0x444430c9,0x9c7c805c,0x628bae94}},	//   hind, wb_, miča, jego,
   {{0x7644483d,0x75270a0f,0x764f009a,0x644e483e}},	// [3280] rbiy, _bijz, _decy, _pebi,
   {{0x444401e9,0x6d56483f,0x6f0982af,0x6aa99670}},	//   ub_, rsya, hlec, _anef,
   {{0x9c7c803a,0x6f09b377,0x764f0118,0x6d5600dd}},	//   niča, klec, _fecy, ssya,
   {{0x66064840,0xb4db0032,0x628bbb11,0x6d560122}},	//   _tykk, _atàd, gego, psya,
   {{0x68e3c841,0x78baa9c7,0x7ae2c842,0x644e4843}},	//   find, _potv, riot, _tebi,
   {{0x68e3859f,0x7ae38511,0x6f09c844,0x6f02c845}},	//   gind, éntr, elec, _skoc,
   {{0x628ba5e1,0xad9b0019,0xdfd080f7,0x2a7d822c}},	//   bego, _nyúj, طية_, bfwb_,
   {{0x628b8267,0x26d2008e,0x6abb9a25,0x656d81d6}},	//   cego, nhyo_, _gouf, _ťaha,
   {{0x68e3c846,0x2246afec,0x24984847,0x3f8581a1}},	//   bind, mbok_, _karm_, _eplu_,
   {{0xa2da88d4,0x68e3c848,0x78a8b842,0x9c7c812b}},	//   पोर्, cind, _undv, fiča,
   {{0x6f09840e,0x7d0880f2,0x9c7c812b,0x24980118}},	//   blec, rlds, giča, _marm_,
   {{0x7c2d8214,0x24980502,0x2246c849,0x6d40a6be}},	//   _şart, _larm_, nbok_, ppma,
   {{0x2bde8beb,0xace981f9,0x471bb7b6,0xbddb026b}},	//   _फेरा, _کرنل_, _וואג, _leèr,
   {{0x9c7c803a,0x660f81ec,0x7b76a452,0x212b81e8}},	//   biča, ücke, _قطعا, _èche_,
   {{0xa3dd0e18,0x0cca864a,0x764f0428,0x22469388}},	//   _तें_, िसीम, _pecy, kbok_,
   {{0x68e3c84a,0x290a0144,0x929d8035,0xbbca9d6a}},	//   zind, alba_, _okła, ानीक,
   {{0xa3e285b3,0x68e3c84b,0x9d152f02,0x22469f48}},	// [3290] _नेत_, yind, едач, dbok_,
   {{0x6abba2a2,0x68e3c84c,0x628b8c2e,0xee3f01d6}},	//   _souf, xind, wego, _iným_,
   {{0xdce9805c,0x64450c41,0x6f09c84d,0x3a3c8135}},	//   steć, rbhi, ylec, _ịgụ_,
   {{0x75270a0f,0x68e3c84e,0x9c13019d,0x6fae000d}},	//   _wijz, wind, _bọro, ीहरू,
   {{0x9c7c8024,0x6299c84f,0xbbcaac17,0xcad80039}},	//   ziča, rdwo, ानुक, וואת_,
   {{0x26c94850,0x3cf886a7,0x7b0382f1,0x6d5d8174}},	//   lkao_, ँवों_, tõus, ásam,
   {{0x68e3c851,0x656d03ac,0x6abbc852,0xfe7181a8}},	//   rind, luah, _touf, هدة_,
   {{0x68e3c853,0xf53f0f96,0x273500f2,0x9c7c8503}},	//   sind, _tråd_, _mån_, viča,
   {{0x68e3c854,0x6f09c855,0x27350370,0x9980009a}},	//   pind, rlec, _lån_, _dziś_,
   {{0x9c7c803a,0x9742803a,0xc4d20158,0x213f82f7}},	//   tiča, šćan, ָגט_, _ituh_,
   {{0xe29a227b,0x273500f2,0x320902a3,0x28ac8aed}},	//   пан_, _nån_, _ayay_, चारि,
   {{0xe29a1597,0xd0550085,0x63bc816d,0xdce40214}},	//   чам_, mizə, ärna, ktiğ,
   {{0x9c7cc856,0xa3e600c2,0xfd5081bc,0x213f8609}},	//   mičn, _बेन_, _medị, _jtuh_,
   {{0x9c7c80ce,0x657b8c93,0x213f83e4,0x00000000}},	//   piča, mtuh, _mtuh_, --,
   {{0x9cd68051,0x657bb6c3,0x8cac866f,0x394d8176}},	//   _רוצה_, ltuh, जारो, _lwes_,
   {{0x7bda8051,0x66ca0efc,0x225f923c,0x2201019d}},	//   _מקצו, _výko, _nduk_, ụsịl,
   {{0x657bc857,0x7c3b0085,0x25798247,0x290580b9}},	// [32a0] ntuh, _şura, nèl_, _okla_,
   {{0x7ae64858,0x225f8763,0x33f6046e,0xfa1580ab}},	//   likt, _aduk_, нчес, িশাল_,
   {{0x929d809a,0x213f8573,0x24980370,0x69c64859}},	//   _skła, _atuh_, _varm_, lyke,
   {{0x213f808e,0x26c900d2,0x657b977c,0x9c7c8824}},	//   _btuh_, ckao_, ktuh, jičn,
   {{0x28ac85e8,0x9c7c8b24,0x27f200eb,0x76560041}},	//   चालि, dičn, šanā_, mayy,
   {{0x26cf90dd,0xd90d80d5,0x02cc13e5,0x257986c0}},	//   _algo_, قیق_, ासुन, dèl_,
   {{0x56948607,0x9c7c8824,0xb9250133,0x929d8035}},	//   вайт, fičn, _akpụ_, _wkła,
   {{0xd6d78009,0x39400e35,0xdd908250,0xc7b304de}},	//   еть_, _otis_, لوب_, רבה_,
   {{0x3940022c,0x929d809a,0x88869a1f,0xe0dabb78}},	//   _ntis_, _ukła, _плаж, _ева_,
   {{0x6284485a,0x20128085,0x2a60485b,0x20d402f1}},	//   _abio, əyin_, _adib_, _jäid_,
   {{0xdeef93cd,0x9c7c803a,0x394006c0,0x76560041}},	//   _бы_, bičn, _atis_, kayy,
   {{0xe8d901bc,0x7ec68036,0x27350106,0x28a482f1}},	//   _mpụ_, _dépê, _rån_, _गोति,
   {{0x2735016d,0x765605a3,0x66ca016b,0x248c808e}},	//   _sån_, dayy, _výkl, pedm_,
   {{0x2ec90e70,0x2a600201,0x7d018706,0x628402c4}},	//   रस्त, _edib_, cols, _ebio,
   {{0xb909035a,0xf53f13c2,0x394002f7,0x4394c85c}},	//   _मग_, _stå_, _etis_, _райс,
   {{0x56943606,0xf1c68028,0x752a9087,0xdce40214}},	//   ласт, _đánh_, _hifz, ttiğ,
   {{0xb81680ab,0x6aad0010,0xe8d90133,0x6d44228a}},	// [32b0] াশিত_, _inaf, _apụ_, gpia,
   {{0x629d485d,0x473502de,0x9c7c8805,0x26c90503}},	//   ldso, _инос, zičn, skao_,
   {{0x290300f6,0x37e580ab,0x76560326,0x26c900fe}},	//   moja_, _পুনর, bayy, pkao_,
   {{0xd6db0160,0x25798205,0x7b2c0214,0x29032f20}},	//   _хто_, yèl_, _ağus, loja_,
   {{0x9c7c9408,0x7bc50859,0x6f0d485e,0xb0ac80d4}},	//   vičn, syhu, mlac, चांग,
   {{0x25798247,0x2903485f,0x9c7c9b39,0xd0098012}},	//   vèl_, noja_, dičo, меле_,
   {{0x9c7c8ee1,0x6aad00c9,0x628f00b9,0x6f0d0635}},	//   tičn, _onaf, keco, olac,
   {{0x2579c860,0x225f86cb,0x6f0d4861,0x442e8366}},	//   tèl_, _uduk_, nlac, _agf_,
   {{0x9c7c84c4,0x213fbfa5,0x29034862,0x7ae61faf}},	//   ričn, _utuh_, koja_, vikt,
   {{0x6f0d35fa,0x657b80dd,0x6aad4863,0xa3e282f1}},	//   hlac, rtuh, _anaf, _नेह_,
   {{0x657bc864,0x765600a4,0x7ae64865,0xe7b59459}},	//   stuh, yayy, tikt, _جماد,
   {{0x2d4f0063,0x6e3d0267,0x6448826c,0x6f0d00e1}},	//   kże_, _nfsb, abdi, jlac,
   {{0x7d01809a,0x69d9c866,0x7649c0a5,0x443c8163}},	//   pols, nzwe, mbey, _ffv_,
   {{0x7ae60448,0x290346b7,0x442e81ec,0x61432c65}},	//   sikt, goja_, _ggf_, рера,
   {{0x66e62791,0x225202c4,0x6d440114,0xd0072772}},	//   вова, _teyk_, wpia, вере_,
   {{0x6e3b8ad4,0x6f0d4867,0x246400eb,0xe3b2026a}},	//   ncub, glac, zīmē_, یرا_,
   {{0x7ae44868,0xed570003,0xf65280be,0x765600a4}},	// [32c0] _imit, кот_, יצן_, rayy,
   {{0x672b820f,0x6f0d1a2f,0xa3c88105,0x315700be}},	//   _ligj, alac, लैक_, _שיין_,
   {{0x6f0d4869,0x7989c86a,0x6d5bc86b,0xd8388668}},	//   blac, _apew, hsua, _jače_,
   {{0x6146b6de,0x765600dd,0xd0418085,0x6d440a0e}},	//   веда, qayy, _illə, ppia,
   {{0xd91089d7,0x6d5b81c0,0x7ae4038a,0x64488df6}},	//   میر_, jsua, _mmit, ybdi,
   {{0x0443486c,0x8c43486d,0x65699831,0x9c7c9e51}},	//   _верн, _вере, dreh, vičo,
   {{0x66d10106,0xc60700ab,0xdce0826c,0x20d402f1}},	//   _håka, লেদা_, lumć, _käib_,
   {{0xe81a0105,0x25a99f66,0x0cca9905,0x68e7090d}},	//   _धरना_, _šala_, िस्म, zijd,
   {{0x6569c86e,0x80d300c8,0x628f486f,0x672b8168}},	//   greh, _সদস্, veco, _digj,
   {{0x3946a602,0xe4a6916b,0x7ae44870,0x6282c7a4}},	//   mpos_, трио, _amit, lfoo,
   {{0x290306ee,0xdced025b,0xd4978d15,0x3946989e}},	//   voja_, stać, тры_, lpos_,
   {{0x290e8114,0x7e989f33,0x68e701ed,0xdce41f66}},	//   llfa_, _سنتر_, wijd, drič,
   {{0x6f0d0052,0x29034871,0x68e700f3,0x4cba80ab}},	//   vlac, toja_, tijd, ইসবু,
   {{0x7ae44872,0x394682ba,0x5ba687b6,0xd3a68087}},	//   _emit, ipos_, _ариз, _арип,
   {{0x4fc40190,0xc7c412b2,0x29034873,0x68e700f3}},	//   аста, асти, roja_, rijd,
   {{0x6aad004f,0x8f9b83de,0x29034874,0x212c8168}},	//   _unaf, וילי, soja_, _lidh_,
   {{0x6f0d198f,0x1be8064a,0xa6154875,0xa5bb22ef}},	// [32d0] rlac, _टेबल_, умач, _agór,
   {{0xdce41024,0x26058424,0x03c731a9,0xe7e38074}},	//   brič, _हँसी_, ксем, _कइला_,
   {{0x64574876,0x6f0d21d9,0x273880ff,0xed46804e}},	//   raxi, plac, _nén_, _گپ_,
   {{0x69d982af,0xe8e1001c,0x6d5d4877,0x212c8229}},	//   tzwe, _đột_, _tvsa, _aidh_,
   {{0x212c8014,0x9985987e,0x3946baab,0xda788c4f}},	//   _bidh_, التو, gpos_, тях_,
   {{0x92e380ab,0x212cc878,0x69d99cd9,0x2738c879}},	//   নকে_, _cidh_, rzwe, _bén_,
   {{0xe81e8e18,0x27388013,0x66e5802e,0x660b80ee}},	//   येला_, _cén_, лока, _sygk,
   {{0xdd91880b,0x3869880a,0x645540b9,0x6d5bc87a}},	//   موع_, şar_, _hezi, tsua,
   {{0x6e3bc87b,0x273881ed,0x25a68115,0x28a48c2d}},	//   rcub, _eén_, _crol_, _गोवि,
   {{0x6e3bac70,0x7b2c88c5,0x6f04002a,0x9c7caa06}},	//   scub, _uğur, zoic, ličj,
   {{0xa3d60f12,0xd0118f99,0x6d5bc87c,0x2738c87d}},	//   िनय_, _الا_, ssua, _gén_,
   {{0x6455487e,0xd94601f3,0x6569c87f,0x216a035f}},	//   _lezi, леми, preh, ними_,
   {{0x60c198c5,0x3eaf80b9,0xdbc982f1,0x7d0503ed}},	//   _kolm, _ingt_, _rõõm, kohs,
   {{0x64554880,0x273888f9,0x66d10711,0x8d5a8039}},	//   _nezi, _yén_, _råka, _טכני,
   {{0xf456810f,0x657d008e,0x66d10aa2,0x2d994881}},	//   _עיקר_, _aqsh, _såka, _asse_,
   {{0x66e301a1,0xdb041a25,0x94428061,0x7ae4113b}},	//   боса, _orné, _پھین, _umit,
   {{0x64554882,0x6f044883,0x25a601a8,0x3dc90122}},	// [32e0] _bezi, roic, íol_, gyaw_,
   {{0xdce40805,0x779402e3,0x6ea401ab,0x85038a74}},	//   prič, _پیرا, _चोरु, रकिट_,
   {{0x2d9900a9,0xe7e3835a,0x332db086,0x645510e8}},	//   _esse_, _केला_, _biex_, _dezi,
   {{0xa3c88105,0x394682c4,0x44314884,0x2d860187}},	//   लैट_, tpos_, _egz_, çoes_,
   {{0x9f060065,0xaca401bc,0xaa5795a9,0x63a705ee}},	//   _لوگو, _atụs, الها_, _erjn,
   {{0x64554885,0x307a00be,0xb42601ad,0x7e62c886}},	//   _gezi, גאַנ, _معزو, _sdop,
   {{0x26c24887,0xbf0f835a,0x3946c888,0x3eaf82f7}},	//   _koko_, ातून_, spos_, _bngt_,
   {{0x3ea008cf,0x2738c889,0x25a69d64,0x64550234}},	//   ndit_, _vén_, _prol_, _zezi,
   {{0x2d80488a,0xb8ea80ab,0x7ebc8019,0x26c2488b}},	//   ntie_, _লগ_, _képz, _moko_,
   {{0x60c18503,0x26c2488c,0x859700be,0x9c7c98a6}},	//   _golm, _loko_, נדיג_, mičk,
   {{0x9c7ca1d1,0xa92385b9,0x8cd90035,0xee868084}},	//   ličk, ížen, फोटो, _было,
   {{0xbda68154,0x57fb8039,0x26c2021e,0xdc3c8517}},	//   _محتو, _אלבו, _noko_, mšči,
   {{0x9c7c82a5,0x7bdab380,0xb5fb0091,0x6d42804f}},	//   ničk, sztu, _adán, _utoa,
   {{0x3aeb06c4,0x316002d6,0xa2a6864a,0x22403516}},	//   _bòpè_, _dviz_, _घोस्, _efik_,
   {{0x6455488d,0x26c200a4,0x9c7c805c,0xdc3c8353}},	//   _rezi, _boko_, hičk, nšči,
   {{0x6455488e,0x26c201f4,0xdc3c9502,0x00000000}},	//   _sezi, _coko_, išči, --,
   {{0xa3dd023c,0x26c2026b,0xdc552369,0x6455488f}},	// [32f0] _तेज_, _doko_, ивањ, _pezi,
   {{0xf53f1918,0x9c7c803e,0x2bb884e5,0x443ec890}},	//   _från_, dičk, इमपा, nct_,
   {{0x5a35938c,0x92598364,0x2d804891,0x31600267}},	//   анет, вает_, atie_, _zviz_,
   {{0x9c7c8024,0x64550234,0xf991853d,0x60c1c892}},	//   fičk, _wezi, قبت_, _solm,
   {{0x2d804893,0x629f4894,0x50b800d5,0x64554895}},	//   ctie_, _maqo, _شدید_, _tezi,
   {{0xb4c38a61,0x645ac896,0xe05780d5,0x3eaf836e}},	//   _एके_, jati, ایات_, _sngt_,
   {{0x44253917,0xa3dd016f,0x60c1c897,0x645ab00a}},	//   _àl_, _तेच_, _volm, dati,
   {{0x8c0a80c8,0x9c7c9807,0x660f016d,0x0565c898}},	//   রধান_, bičk, _kyck, авин,
   {{0x645a80b4,0x63418029,0x057680f7,0x798d0069}},	//   fati, _mēne, لمية_, _npaw,
   {{0x660f1918,0x3b858b79,0xc48293cd,0x7aebc899}},	//   _myck, алог, ольк, ligt,
   {{0x660f00f2,0x2907c89a,0x764d489b,0x629f3869}},	//   _lyck, mona_, kbay, _baqo,
   {{0x2907c89c,0xceb40201,0x443e85ae,0xf770806b}},	//   lona_, rmək_, act_, _رام_,
   {{0x660f016d,0x656d03ac,0x26c2489d,0xa91d8084}},	//   _nyck, jrah, _roko_, _apži,
   {{0x645a87cc,0x03a58cde,0x2907a010,0x6d4980a0}},	//   cati, _вико, nona_, mpea,
   {{0x9c7c8289,0xd8388024,0xb21b013c,0x26c206c0}},	//   zičk, _jača_, lfæl, _poko_,
   {{0xe51980a5,0x2907c89e,0x799bc89f,0x764d132b}},	//   _नीति_, hona_, _osuw, gbay,
   {{0x3ea048a0,0x7aebc8a1,0x656d48a2,0x6d49c8a3}},	// [3300] rdit_, digt, grah, npea,
   {{0x2d8048a4,0x9c7ca1f8,0x2907c8a5,0xb4c3908a}},	//   rtie_, vičk, jona_, _एको_,
   {{0xa7fc8182,0x26c2278b,0x2d8028c3,0x3dbd80c8}},	//   _adın, _toko_, stie_, েছিল,
   {{0x9c7c8025,0x656d0726,0x645ab672,0x2d8048a6}},	//   tičk, brah, zati, ptie_,
   {{0x69268087,0xaca40133,0xa3e60006,0x672401b9}},	//   амда, _agụr, _बेर_, mmij,
   {{0x273c2278,0x9c7c803b,0x290787e2,0x645ac8a7}},	//   _kín_, ričk, gona_, xati,
   {{0x645ac8a8,0xe0b703de,0x0306064a,0x9c7cc8a9}},	//   vati, ילסט_, रवाह_, sičk,
   {{0x645ac8aa,0x273c0125,0xf102001b,0xd8388088}},	//   wati, _mín_, लकुद_, _dača_,
   {{0x2907c4a5,0x01cb00ab,0x38658314,0x25b0852a}},	//   bona_, _লেনদ, _fdlr_, जमेण,
   {{0x2907b3d2,0x273c0118,0x67240267,0xdc3c82d4}},	//   cona_, _oín_, hmij, pšči,
   {{0x645ac8ab,0x764d0c27,0x50b5c8ac,0xb4d68beb}},	//   rati, ybay, _усту, _सती_,
   {{0x645a9de9,0x6d46003a,0x672439e9,0x629f0609}},	//   sati, _otka, jmij, _qaqo,
   {{0xc05b0cde,0x79828063,0x2c06816f,0x645ac8ad}},	//   ків_, ntow, _सुरू_, pati,
   {{0x645ac8ae,0x386d02af,0xa3d63841,0x660f0106}},	//   qati, ßer_, िना_, _ryck,
   {{0x386d07d9,0x251b812a,0x6d462585,0x64588029}},	//   ğer_, _שווא, _atka, _ievi,
   {{0x656d48af,0x7982809a,0xd6d80c0e,0x6458c8b0}},	//   trah, ktow, ату_, _hevi,
   {{0x764d0965,0x2907c8b1,0x798d005d,0x84470481}},	// [3310] rbay, yona_, _upaw, لخال,
   {{0x40950013,0xb89500f7,0x6458c8b2,0x67240079}},	//   _الدر, _الدع, _jevi, amij,
   {{0x64588267,0x290795a4,0xd00800a9,0x656d48b3}},	//   _mevi, vona_, _веќе_, srah,
   {{0x660f04b8,0x23670353,0x290c809c,0x69cb8106}},	//   _tyck, šnjo_, _akda_, tyge,
   {{0x7aebc8b4,0x7d08c8b5,0x6aa0c8b6,0x1869971c}},	//   rigt, kods, _damf, гали_,
   {{0x6458c8b7,0x66d8026f,0x7aebc8b8,0x7642826b}},	//   _nevi, _víke, sigt, _afoy,
   {{0x2907c8b9,0x6aa080fc,0x79828035,0x7aebc8ba}},	//   rona_, _famf, atow, pigt,
   {{0x20d40364,0x2907c8bb,0x66d584be,0x77f8025f}},	//   _näin_, sona_, _báka, ימוד_,
   {{0x7ae9c8bc,0x6458c8bd,0x2738801c,0x799bc8be}},	//   _imet, _bevi, _lĩnh_, _usuw,
   {{0x2ba58341,0x6aa0c8bf,0x66d13032,0x25ff0424}},	//   _pēc_, _zamf, _såkl, _रखनी_,
   {{0x7ae98353,0x1fe58264,0xfaa600e5,0xe217824c}},	//   _kmet, _পুরস, бано, _तरुण_,
   {{0x6d5d8118,0x7afb85ee,0x6aa08580,0x6d49c8c0}},	//   ásas, _jjut, _xamf, ppea,
   {{0x4545806b,0x64a5aa13,0x7ae98135,0x68e8831d}},	//   _انتق, _гала, _mmet, _ymdd,
   {{0x7afb811f,0x05b8826a,0x6458c8c1,0x6ac48054}},	//   _ljut, _خدمت_, _gevi, _वक्र,
   {{0x66d58a56,0xb8f00996,0x7b33802e,0x96db801b}},	//   _záka, _शव_, _căut, _बताउ,
   {{0x3ebf8867,0x9c7c81e2,0x7afbc8c2,0x6458913b}},	//   njut_, viči, _njut, _zevi,
   {{0xe61a102f,0x67240a0f,0x998600f7,0xb5fb01d0}},	// [3320] уда_, rmij, _الخو, _udál,
   {{0x7afbc8c3,0x7ae9c8c4,0x6724120e,0x6aa0c8c5}},	//   _ajut, _amet, smij, _samf,
   {{0x7ae98037,0x1d1683de,0xa09b0538,0x2fd00493}},	//   _bmet, צקער_, _גייט, ângă_,
   {{0x76598355,0xdbd0027f,0x9c7c943c,0x290a48c6}},	//   _newy, _užív, riči, loba_,
   {{0xe3a78986,0x78a180eb,0x6d460687,0x798280fc}},	//   _کر_, _balv, _utka, utow,
   {{0x7ae9c8c7,0xa3d50076,0x79828063,0x26c0012b}},	//   _emet, ाईश_, rtow, ljio_,
   {{0x6458c8c8,0x645e48c9,0xf0930039,0x7982c8ca}},	//   _revi, mapi, פנה_, stow,
   {{0x6458a353,0x645e48cb,0x26c0012b,0x26d2008e}},	//   _sevi, lapi, njio_, nkyo_,
   {{0x7cd88bba,0x7ae3838e,0x645882f7,0x7d08c8cc}},	//   имир_, ënte, _pevi, tods,
   {{0x78a1a393,0x645e1868,0x290a1c19,0xd49a9593}},	//   _galv, napi, joba_, ури_,
   {{0x387e80f6,0xa6869c45,0x241897ae,0xdee68e49}},	//   _ictr_, _глед, роны_, _ложи,
   {{0x3f9e803a,0x645e0077,0x6443807b,0x7659867f}},	//   _istu_, hapi, _efni, _gewy,
   {{0x645e27bb,0x290a0267,0x612018b6,0xa6a987c3}},	//   kapi, foba_, köld, _خالق_,
   {{0x64a38d70,0x27388104,0x290a0365,0x7e7d026c}},	//   _нача, _cũng_, goba_, _scsp,
   {{0x368b0071,0x645e3d65,0x673ac8cd,0x273880ff}},	//   лсан_, dapi, _jutj, _dũng_,
   {{0xccf8800d,0x2bac04c5,0x2738801c,0xfbdf00ab}},	//   lně_, घटना, _vĩnh_, _বুঝত,
   {{0x634501e2,0x60c51d37,0x628d48ce,0x673a8168}},	// [3330] _mėne, _tohm, _ibao, _lutj,
   {{0x645e0447,0x7aef48cf,0x290a48d0,0x69cf1916}},	//   gapi, lict, coba_, myce,
   {{0x439448d1,0x3ea248d2,0x16350198,0x9e350196}},	//   захс, _fakt_, _меня, _менч,
   {{0x78a1a9da,0x7aef109b,0xd0488085,0x6f09802a}},	//   _salv, nict, _ildə, xoec,
   {{0x78a18364,0x645e2610,0x1a68815b,0xccf881d0}},	//   _palv, bapi, صیلی_, kně_,
   {{0x661d0029,0xd90f80d5,0xccf8801b,0x6d4d08e5}},	//   _izsk, ریا_, jně_, mpaa,
   {{0xccf8800d,0x2eed85f8,0x78a18399,0x25a948d3}},	//   dně_, tief_, _valv, lval_,
   {{0x7ae9c8d4,0x7afb803b,0xee399a1f,0x290a48d5}},	//   _umet, _ujut, шни_, zoba_,
   {{0x7aef0bd9,0x2eed85f8,0x78a1c8d6,0x25a90cfa}},	//   dict, rief_, _talv, nval_,
   {{0x33658c8e,0x2eed8a0f,0x2a6920d5,0x6f0496f2}},	//   овог, sief_, _adab_, čica,
   {{0x39491a6e,0x2ca30065,0x66d8007b,0xf53f0711}},	//   _atas_, _majd_, _líka, _bråk_,
   {{0xc5d58d13,0xeb968009,0xc04903c8,0x6441c8d7}},	//   _міль, цию_, _יז_, scli,
   {{0x290a48d8,0x80b500ab,0x3ea2016d,0xccf8801b}},	//   toba_, ুসন্, _rakt_, bně_,
   {{0x26d948d9,0x6efe81a9,0xccf881d0,0xceb4011c}},	//   _also_, mība, cně_, hmət_,
   {{0x6efe80eb,0x61200dfa,0x3ea248da,0x7ce90085}},	//   lība, völd, _pakt_, _görə,
   {{0x7e7bc8db,0xa3e283b6,0x290a48dc,0x645e004f}},	//   ngup, _नेट_, soba_, wapi,
   {{0x0566035f,0x6efe80eb,0x6d4d3097,0xceb40085}},	// [3340] юван, nība, gpaa, dmət_,
   {{0x6aa403ae,0xa3d527cf,0xdb210198,0x7b3418ad}},	//   _haif, ाईं_, ätök, _găur,
   {{0xeb9a48dd,0x3ea220e5,0x398448de,0x6aa41325}},	//   рие_, _takt_, lös_, _kaif,
   {{0x66dcc2b2,0x645e0d58,0x094aa7d4,0x914a97c8}},	//   _kéke, sapi, ачки_, ачка_,
   {{0x673ac8df,0x645e0ed0,0xccf8801b,0x39842a3a}},	//   _sutj, papi, yně_, nös_,
   {{0x6aa400a4,0x83fc812b,0x6efe80eb,0xb50386b7}},	//   _laif, lađe, dība, रकोप_,
   {{0xd6dac8e0,0xccf8800d,0x444400ee,0xcb670012}},	//   ити_, vně_, mc_, _маре_,
   {{0x83fc803a,0x764448e1,0x444448e2,0x758a891c}},	//   nađe, nciy, lc_, асов_,
   {{0x01638951,0x645c0590,0xccf8800d,0x444447b7}},	//   _окто, _keri, tně_, oc_,
   {{0x444448e3,0x645c48e4,0x394981df,0x673a83ed}},	//   nc_, _jeri, íase_, _tutj,
   {{0x444448e5,0x443848e6,0xccf8801b,0x2018807b}},	//   ic_, _mgr_, rně_, _ári_,
   {{0xccf8801b,0x65643abf,0x6aa42cc4,0xe8e100ff}},	//   sně_, ksih, _caif, _đốt_,
   {{0x66d58775,0x7e608590,0x64a69e58,0x6efe8029}},	//   _záko, mamp, _мада, cība,
   {{0x645c48e7,0x9c7c82a5,0x7ce90085,0x69cf0362}},	//   _neri, tiču, _törə, ryce,
   {{0x7ce048e8,0x6aa40300,0x40341290,0xceb40085}},	//   _körf, _faif, дерс, ymət_,
   {{0x7e60c8e9,0x66d5803e,0x83fc8067,0x645c48ea}},	//   namp, _nákl, gađe, _aeri,
   {{0x645c48eb,0x25a948ec,0x656448ed,0x444448ee}},	// [3350] _beri, uval_, gsih, fc_,
   {{0x645c0859,0x25a937cc,0x200101c0,0x2bae8697}},	//   _ceri, rval_, _txhi_, टिपा,
   {{0x6d4d3a9c,0x6efe80eb,0x443848ef,0x6b850122}},	//   spaa, zība, _dgr_, uthg,
   {{0x444448f0,0xb5fd8353,0x6d4d0009,0x76440041}},	//   ac_, laše, ppaa, cciy,
   {{0x27ff0459,0x661d0029,0x7aed48f1,0x78a548f2}},	//   ğunu_, _uzsk, _mmat, _kahv,
   {{0x645c48f3,0x4438016d,0x8505015b,0xb5fb00f7}},	//   _geri, _ggr_, _روزن, _ndái,
   {{0x765d0247,0x644548f4,0x6722a8bd,0xd343015b}},	//   _kesy, mchi, _bhoj, _آفری,
   {{0x644548f5,0x645c48f6,0x6efe80eb,0x7e60a3a8}},	//   lchi, _zeri, tība, gamp,
   {{0x645c0459,0x765d48f7,0x80cc052a,0x75351a1a}},	//   _yeri, _mesy, _सकले, _kizz,
   {{0x66d58a56,0xdced003e,0x75350609,0x6aa448f8}},	//   _zákl, krač, _jizz, _saif,
   {{0x7ce000f2,0x644548f9,0x6efe8029,0xd378812b}},	//   _förf, ichi, sība, guć_,
   {{0xf8bd80ab,0x6efe81a9,0x7aed0118,0xdced007a}},	//   _অতিথ, lībn, _cmat, drač,
   {{0x171a8158,0x14a6816f,0x83fc8289,0x6729c8fa}},	//   _פונע, _कोकण, vađe, mmej,
   {{0x7aed011e,0x753548fb,0x17fa00f7,0xdca5a6c8}},	//   _emat, _nizz, مرأة_, _хаки,
   {{0x6aa448fc,0x753d48fd,0x61e2c8fe,0x3f87812b}},	//   _taif, _ausz, zzol, ntnu_,
   {{0xee3a48ff,0xaad00076,0x3b070698,0x443801e4}},	//   сна_, _हकिक, _нещо_, _sgr_,
   {{0x83fc803a,0x44384900,0xa3de001b,0x765d0176}},	// [3360] rađe, _pgr_, दैन_, _desy,
   {{0x65640057,0x44444901,0x6445056c,0x3f87825b}},	//   rsih, uc_, gchi, ktnu_,
   {{0x4444476f,0x75354902,0x6f0d062f,0x645c3560}},	//   rc_, _dizz, boac, _veri,
   {{0xd7bb004c,0x78a50289,0x44444808,0xdce40024}},	//   _הצטר, _zahv, sc_, krić,
   {{0x60c88690,0x645c1342,0xdce4026c,0x7e60c903}},	//   _podm, _teri, jrić, vamp,
   {{0x64450698,0xdce402a5,0x9c13019d,0xb5fb046d}},	//   cchi, drić, _bọdo, _adáw,
   {{0x7e60c904,0xb8f4857a,0x61e28019,0x6d4b8110}},	//   tamp, _हक_, szol, _atga,
   {{0xb8d3aaf8,0x6f04992c,0x35b4807f,0x7535038a}},	//   _जो_, čico, дбир, _zizz,
   {{0x7e608886,0xa06ac905,0x186a98a3,0x60229b9c}},	//   ramp, _газа_, _гази_, _bímí,
   {{0x7aed0025,0x7e60b745,0x656fc906,0xb4d6809a}},	//   _smat, samp, ácha, ससे_,
   {{0xa3be05b3,0x78a50006,0x7e609890,0x7b370b67}},	//   ेहि_, _rahv, pamp, _ućut,
   {{0x7ce00106,0x66028102,0xd7ef81a8,0xdced02d4}},	//   _förg, _txok, _حكم_, vrač,
   {{0xf2d38158,0xf1be8076,0x7ce0016d,0xaca40032}},	//   גער_, ्हिन, _körd, _awọs,
   {{0x2367012b,0x3d148740,0x765d4907,0x6299809a}},	//   šnji_, _नीचे_, _sesy, zewo,
   {{0xbebb020f,0x78a508e5,0x7ce00884,0xb5fd9809}},	//   _dhën, _vahv, _mörd, raše,
   {{0x59be8e18,0xabfb8051,0x7ce000f2,0x7aed4908}},	//   ्हार, _להור, _lörd, _umat,
   {{0xdd940084,0x65940254,0x644501c6,0x78a520e8}},	// [3370] наты, нату, tchi, _tahv,
   {{0x81e600ab,0xdced026c,0x3ea680e4,0xa11501a8}},	//   _বুক_, prač, _laot_, _زوجت,
   {{0x62998e35,0x7afd05e6,0x75350197,0x64454909}},	//   tewo, onst, _vizz, rchi,
   {{0x753d490a,0x7afd0e5d,0x6445490b,0x386ca8bd}},	//   _tusz, nnst, schi, _addr_,
   {{0x6299c90c,0x7afd490d,0x6445490e,0x7535111d}},	//   rewo, inst, pchi, _tizz,
   {{0x66d8007b,0x7afd3279,0x008a00be,0xdce40390}},	//   _líkl, hnst, ַרפֿ, vrić,
   {{0xb4fb03eb,0x7ce007c0,0xdb240061,0x917a027d}},	//   ्वीप_, _dörd, őség, _mất_,
   {{0x24bf00c8,0xdd918872,0x3f87825b,0x26cb442e}},	//   _ইতিহ, نوع_, rtnu_, _joco_,
   {{0x7ce02a9c,0x3f87c90f,0x29010267,0xfce591d0}},	//   _förd, stnu_, _ojha_, допо,
   {{0xd13183f8,0x7afd4910,0x26cb4911,0x6729c615}},	//   _شما_, enst, _loco_, smej,
   {{0xf77092dc,0x31694912,0xb7d58c2a,0x00000000}},	//   _مان_, _avaz_, _تقاب, --,
   {{0xbebb020f,0xc8690051,0x2901008e,0x25a9811f}},	//   _shën, _כן_, _ajha_, _šalu_,
   {{0xdce2807a,0x3ea90106,0x6d4b80e8,0x7ce001ec}},	//   _zvoč, ddat_, _utga, _höre,
   {{0x225f8613,0x7afd2d24,0xda2081ab,0xbddb0176}},	//   _leuk_, anst, _बरसत_, _efèk,
   {{0x25ad82f1,0xaa7b06d4,0x00000000,0x00000000}},	//   lvel_, uhýc, --, --,
   {{0x2ca7bbad,0x394d826c,0xef1a0221,0x4ae206ab}},	//   _hand_, _otes_, іма_, _पतिव,
   {{0xbebb00f1,0x394d8069,0x090623d9,0x2ca7c913}},	// [3380] _thën, _ntes_, _опин, _kand_,
   {{0x2ee04914,0x3ea601a9,0x62840176,0x66dc88f9}},	//   shif_, žot_, _hcio, _méka,
   {{0x39402468,0x2ca7813c,0x4f260d69,0x66dc801b}},	//   _huis_, _mand_, _одоб, _léka,
   {{0x2ca7c915,0x26cb0279,0x83fc8301,0x2d9f81bc}},	//   _land_, _goco_, nađa, kwue_,
   {{0x6143c916,0xd00f0416,0xa1588009,0x394001b0}},	//   веча, _ملی_, чалу_, _juis_,
   {{0x83fc812b,0x39404917,0xd83881a1,0x2a602c34}},	//   hađa, _muis_, _kači_, _leib_,
   {{0xd838a8d2,0xb906856b,0xdb02016b,0x394dc918}},	//   _jači_, _पत_, zvlá, _etes_,
   {{0x2ca781b0,0x7e642362,0x225f8cdb,0x356a862c}},	//   _aand_, naip, _geuk_, орон_,
   {{0x25a01705,0x2ca79ab5,0x20d08362,0x66dc810c}},	//   nwil_, _band_, _bàit_, _céka,
   {{0x7ce00004,0x2ca78012,0x29188019,0x38cb8065}},	//   _före, _cand_, _óra_, _والی_,
   {{0x7ce04919,0x7e6440ff,0xb5fb04e8,0x917a0129}},	//   _göre, kaip, _udáv, _rất_,
   {{0x83fc803a,0xf9e700ab,0x7e6406df,0xeb9100be}},	//   gađa, _গুগল_, jaip, אָך_,
   {{0x51844709,0xaca40032,0x2ca7ac22,0xc984002e}},	//   кура, _afọr, _fand_, кури,
   {{0x6e22c91a,0x3940491b,0xa8030214,0x26cb491c}},	//   _izob, _duis_, _çıkm, _soco_,
   {{0x26cb491d,0x83fc8024,0xb5fd812b,0x3ea90cfa}},	//   _poco_, bađa, maša, tdat_,
   {{0xb5fd992c,0x2ca781ed,0x5694031a,0x628401a8}},	//   laša, _zand_, каст, _gcio,
   {{0x78baa539,0x3ea9491e,0xd83881a1,0x7ae289c4}},	// [3390] _ontv, rdat_, _dači_, dhot,
   {{0x2edb946d,0x78a8b99c,0xdb0401ec,0x651501ad}},	//   _बत्त, _nadv, _ernä, روائ,
   {{0x68f502bb,0x3a759a21,0x26cb4612,0x394d8580}},	//   mizd, елер, _toco_, _stes_,
   {{0x7ce0016d,0x2911491f,0x7ae2808e,0x628f01e8}},	//   _röre, loza_, ghot, nfco,
   {{0x644ac920,0x672d80e1,0x7ce0048d,0x99158a4c}},	//   _offi, ňajk, _söre, нькі,
   {{0x68f503bf,0x8d5a02f6,0x2911154e,0x66dcc787}},	//   nizd, _מכשי, noza_, _réka,
   {{0x3861034a,0x7ce004b8,0x2ca78252,0x225f90e4}},	//   _mehr_, _förb, _rand_, _teuk_,
   {{0xfaff08cf,0xf838004c,0x644ac921,0x7ae2c922}},	//   jnë_, ונות_, _affi, chot,
   {{0x29112acc,0x91ee00d4,0x2ca781ed,0x6f0282a6}},	//   koza_, _चेंज_, _pand_, _djoc,
   {{0x23670025,0x62844923,0x25adc924,0x7ce04925}},	//   šnju_, _scio, rvel_, _töre,
   {{0x394003d3,0x2ca7c926,0x6abbc927,0xa3d50701}},	//   _suis_, _vand_, _knuf, ाईट_,
   {{0x394002be,0x629d2c5b,0x644ac928,0x660f81ec}},	//   _puis_, geso, _effi, ücks,
   {{0xa4d5835f,0x394003a7,0x3989c929,0x672d026c}},	//   _поді, _quis_, nús_, dmaj,
   {{0x628b016d,0x2911492a,0x83fcad16,0xdca2c060}},	//   _ögon, goza_, sađa, _баши,
   {{0x629d492b,0x39899e18,0x6d4f492c,0xfd64019d}},	//   beso, hús_, _atca, barị,
   {{0x629d492d,0x394001b0,0x6f1bc92e,0x62840b80}},	//   ceso, _tuis_, nluc, _ucio,
   {{0x7e6416da,0xe6e0000f,0x29111eda,0xb5fb01a8}},	// [33a0] raip, _नतीज, boza_, _reác,
   {{0x25a0492f,0x6d4400b9,0x6f1bc930,0xdc3c81f4}},	//   rwil_, rqia, hluc, ršći,
   {{0x7ae2c931,0xd83885a2,0x7e644932,0x27218c83}},	//   thot, _tači_, paip, zóna_,
   {{0xbee992c6,0xc7b3025f,0xca26afc0,0x69c28cdb}},	//   टफोन_, _עבר_, нфли, txoe,
   {{0xc69300be,0x6f1b8041,0x7ae2c933,0xb21b3f7e}},	//   _גאר_, dluc, rhot, lfær,
   {{0x6aa900c8,0x97a69b06,0x7ae2a65a,0x644300e1}},	//   গাযো, ерил, shot, ľnic,
   {{0x7a368a0b,0x64434934,0x7ae28c92,0x629d00f1}},	//   _bütü, žnic, phot, yeso,
   {{0x29112d0f,0x20d08706,0x7f4181b4,0x2389128a}},	//   zoza_, _càir_, _dulq, žují_,
   {{0x94868162,0x569b0051,0x8cc4064a,0x3989c0a2}},	//   нынд, ליקצ, रापो, cús_,
   {{0xdce40024,0x629d22d7,0x672d01a1,0xa5bb136f}},	//   ksič, weso, zmaj, _ozón,
   {{0xb5fdc935,0x291100ce,0x6f02816d,0x629d4936}},	//   raša, voza_, _tjoc, teso,
   {{0x38610352,0xb5fd8024,0x62828365,0x15eb8074}},	//   _sehr_, mašn, ngoo, _जेकर_,
   {{0xb5fd8699,0xaca4819d,0x29110435,0x25a0847f}},	//   lašn, _arụz, toza_, _èil_,
   {{0x644a81c1,0x52dd824c,0xddc984e8,0xba3b0901}},	//   _uffi, _मत्स, dceň, deïe,
   {{0xd6db0328,0x629d4937,0x672d4938,0x61204939}},	//   пта_, peso, tmaj, möll,
   {{0xf5e70d8e,0x629d03ed,0x61200198,0x6d428c93}},	//   нізм, qeso, löll, _kuoa,
   {{0x672d493a,0x68f516f2,0xb5fb0091,0x386100ee}},	// [33b0] rmaj, pizd, _adár, _tehr_,
   {{0xb5fd811f,0x6abb9e12,0x6aa9808e,0x672d493b}},	//   kašn, _snuf, _saef, smaj,
   {{0xb5fd8025,0xdcfb8289,0xd2518250,0xf09201c6}},	//   jašn, stuć, لنا_, _דני_,
   {{0x7e62825b,0xb5fd803b,0xf41380be,0xd838811f}},	//   _neop, dašn, אפע_, _jaču_,
   {{0x6120493c,0x6f1b8a58,0x6d4f0061,0x5eef8035}},	//   köll, vluc, _utca, इफस्_,
   {{0x2d99493d,0x26c902a5,0x7f41c93e,0x66d5808b}},	//   _ipse_, ljao_, _pulq, _jákv,
   {{0x39899ee8,0x7e628279,0x66e58652,0xbea58081}},	//   sús_, _beop, кока, вайк,
   {{0x26c90052,0x6569a5b5,0x5334c93f,0x66dc89c4}},	//   njao_, tseh, _бест, _déko,
   {{0xe8d904be,0x0609ac65,0x7e628162,0xd3788035}},	//   _awọ_, ьник_, _deop, erć_,
   {{0x6f1b8307,0x8cc40beb,0x656981ec,0xdbde808b}},	//   sluc, रायो, rseh, tíða,
   {{0x3b0a35d9,0x2d99008e,0x65699831,0xd83881a1}},	//   дено_, _lpse_, sseh, _baču_,
   {{0x63b50699,0xdce9805c,0x7e629412,0xf4120039}},	//   _mrzn, kreć, _geop, שפט_,
   {{0xe7308277,0x4e7880f7,0x26c90b67,0x7ce48706}},	//   _اصل_, _أحمد_, djao_, _bòrd,
   {{0x3eada3dd,0x8c4281a1,0x6d404940,0xa3e11795}},	//   ldet_, _кеше, _émai, धना_,
   {{0xb90a05b3,0x2d994941,0x26cfc942,0x6282c0ac}},	//   _मत_, _apse_, _kogo_, ygoo,
   {{0x3ead8d1a,0xf7728158,0x26cf80a9,0x7e62ae26}},	//   ndet_, יקל_, _jogo_, _xeop,
   {{0x26cf817f,0xb21b03ba,0x3eadc943,0x66d103ba}},	// [33c0] _mogo_, lgæn, idet_, _påkr,
   {{0xe8f7012f,0xb97b04de,0x3ead8198,0x317b007c}},	//   _аль_, _קניי, hdet_, _קרימ,
   {{0x316d82be,0x64a32f0a,0x18770039,0x2d8d8198}},	//   _avez_, раха, _בעיר_, htee_,
   {{0x68e1816d,0x3ead813c,0x29058267,0x26cf82d4}},	//   _alld, jdet_, _ajla_, _nogo_,
   {{0x64430110,0x62829bbe,0x3eadc944,0x66dc89c4}},	//   žnia, rgoo, ddet_, _dékl,
   {{0x224d88b3,0xc9530039,0x7ce0016d,0x3ea04945}},	//   _efek_, סמו_, _föra, leit_,
   {{0x7e62c946,0x7ce0016d,0x26cfc947,0x7416003d}},	//   _peop, _göra, _bogo_, _شورا,
   {{0x81e800c8,0xeb0d90be,0x753c026c,0x3ea00a2a}},	//   _যখন_, िकृत_, _hirz, neit_,
   {{0x66d5803e,0xd946a6c5,0x80c28fb8,0x26cfa0c5}},	//   _náku, _рези, लादे, _dogo_,
   {{0x3ea04948,0x9b588003,0x70d10665,0x224000b9}},	//   heit_, ниот_, _सकेल, _agik_,
   {{0x3ea002af,0x83fcb69f,0x753c4949,0x26cf8317}},	//   keit_, rađo, _mirz, _fogo_,
   {{0xb4df1c9d,0x26cfc94a,0x50f28054,0xbe8581a8}},	//   _तत्_, _gogo_, _अगुआ_, _مجهو,
   {{0x3944a393,0xdb218065,0x7e7d8207,0x316d00e7}},	//   _jums_, ítés, óspe, éez_,
   {{0x3944a393,0xab650f4f,0x104b0198,0x629602ec}},	//   _mums_, ngüí, ьями_, _ebyo,
   {{0x09cb00c8,0xd8388029,0xb5fb002a,0x601827ee}},	//   _লেখা, _taču_, _adáp, воря_,
   {{0x26cf84c3,0xdce08110,0x7ce0494b,0xdce980fe}},	//   _xogo_, tumė, _röra, treć,
   {{0x1df82252,0x9f34021e,0x753c494c,0xa5f8494d}},	// [33d0] веты_, реті, _birz, вету_,
   {{0x09be80c2,0xfd62819d,0x798d0197,0x6aad0299}},	//   ्हैय, _setị, _iqaw, _haaf,
   {{0xdce9803a,0x29030024,0x3ea002af,0x66d5816b}},	//   sreć, mnja_, beit_, _záku,
   {{0x2d800c6e,0x6aad00ee,0xeb0d8072,0x7b188118}},	//   buie_, _jaaf, िकेत_, díus,
   {{0xadf0035a,0x6aad494e,0x644e026c,0x667a01c6}},	//   _घेऊन_, _maaf, _ffbi, _אטרק,
   {{0x66d80125,0x89dc0039,0x9b45045b,0x7ce005ec}},	//   _ríki, וחדי, _منسو, _hörn,
   {{0x7ce00065,0x26cfb1fc,0x61200106,0xd34700d7}},	//   _körn, _pogo_, följ, _شیشه_,
   {{0xbb840013,0x2903494f,0x63b80366,0x6aad4950}},	//   _خلفي, hnja_, ævne, _naaf,
   {{0x3ead88f8,0x656d10c1,0x798d01c0,0x673d4951}},	//   rdet_, nsah, _nqaw, _misj,
   {{0x3ea002af,0x645e8074,0x66d8008b,0x68e1c952}},	//   zeit_, _õpil, _víki, _ulld,
   {{0xa5bb0019,0x9f558af2,0x2d8dab3b,0x6aad4953}},	//   _szól, _свеч, stee_, _baaf,
   {{0xa5bb0065,0x6aad0079,0x799b819d,0x645aa6e9}},	//   _gyóg, _caaf, _kpuw, abti,
   {{0x69d9bbf0,0x765b80b4,0x6dc492c8,0x661d006f}},	//   nywe, mbuy, _نزول, _nysk,
   {{0x3ea002af,0xd9430012,0x290300c3,0x657b8c53}},	//   weit_, сери, gnja_, mruh,
   {{0x3ea02539,0x66e60785,0x1cb8b06f,0xdee62d01}},	//   teit_, гова, _جانب_, гови,
   {{0xeabe80ab,0x7e55116b,0x2d804954,0xceb40085}},	//   _আত্ম, итуц, tuie_, lməz_,
   {{0x2bcb85e8,0x29034955,0x7ae44956,0x3ea04957}},	// [33e0] ाहका, bnja_, _ilit, reit_,
   {{0x661d009a,0xe61722f7,0x2903017f,0x3f9a008e}},	//   _dysk, уду_, cnja_, _tppu_,
   {{0x7ce0016d,0x2b4f8087,0x656d009c,0x753c00eb}},	//   _förn, _încă_, asah, _virz,
   {{0x62864958,0x55e6197d,0x6aad0079,0x656d3e3b}},	//   ngko, _бомб, _xaaf, bsah,
   {{0xf5488104,0xceb303c8,0x4427826c,0x7ae4491b}},	//   _mục_, _פיש_, _lzn_, _mlit,
   {{0x6f040e3f,0xf548801c,0x7b188118,0x386a00c3}},	//   lnic, _lục_, tíus, nabr_,
   {{0xfbc78624,0x6f0415db,0x248a01e0,0x7ae44959}},	//   _ات_, onic, _icbm_, _olit,
   {{0x6f04495a,0x6d46495b,0x290302a5,0xa3c98327}},	//   nnic, _kuka, znja_, ोहन_,
   {{0xa206ace0,0x1a069501,0x44278201,0x6f042dba}},	//   _спад, _спам, _azn_, inic,
   {{0x6d46495c,0x7ae4320a,0x6f04495d,0x764d495e}},	//   _muka, _alit, hnic, zcay,
   {{0xd4979006,0x2903173d,0x7ae4495f,0x6d460e5a}},	//   уры_, vnja_, _blit, _luka,
   {{0x291a0870,0xf548801c,0xb5fb0019,0x51870652}},	//   _akpa_, _cục_, _beál, луга,
   {{0x6f0429c7,0xf5488028,0x90d580ff,0x7ce48362}},	//   dnic, _dục_, _mìn, _còrc,
   {{0x661d4960,0x6f04383e,0x6aad4961,0x28c79a42}},	//   _rysk, enic, _waaf, लायि,
   {{0x7ae44962,0xc4f7807c,0x661d0711,0x6f0401e0}},	//   _flit, _תמוז_, _sysk, fnic,
   {{0x6d464963,0x656d1400,0x29030da8,0xdce40b80}},	//   _buka, tsah, snja_, driđ,
   {{0x764d059c,0x29034964,0x6d460ad4,0x644f809a}},	// [33f0] rcay, pnja_, _cuka, ście,
   {{0x6d464965,0x764d20d5,0x656d0057,0x661d4966}},	//   _duka, scay, rsah, _vysk,
   {{0x6d464967,0xfff900d5,0x569501e2,0x6e9521f2}},	//   _euka, _شکست_, _кант, _кину,
   {{0xdced0024,0x661d1c6d,0x7ce00106,0x98b30087}},	//   krać, _tysk, _föro, _fixă_,
   {{0xe1358084,0x213e803c,0xaca3019d,0x09d880ab}},	//   анды, _bith_, _agục, _দেবা,
   {{0x6ae210c5,0x2618959a,0x02e20128,0xd366c968}},	//   _पत्र, _पड़ी_, _पत्न, _وه_,
   {{0x3f830397,0x6d460041,0x3f91011b,0x6b818118}},	//   nuju_, _zuka, ntzu_, xulg,
   {{0x6b81841c,0x6d460214,0x2d9580a1,0xfe458073}},	//   vulg, _yuka, арос, шнио,
   {{0x386a1072,0x608780f7,0xdced0088,0x51878a3d}},	//   yabr_, _مشاك, grać, _љуба,
   {{0x3f8302a5,0x81cb00ab,0xb5fb03b0,0xb4658a13}},	//   kuju_, লনা_, _reál, школ,
   {{0x3f83003a,0x78a38a10,0x9b060b5f,0x02c60225}},	//   juju_, menv, изод, айно,
   {{0xdced2997,0x3f830052,0x4e198009,0x63b880ce}},	//   brać, duju_, _июля_, _drvn,
   {{0xd9463290,0x62864969,0x41a702a9,0x78c48061}},	//   реги, rgko, авян_, _átvé,
   {{0x6d462e0a,0x6f040063,0xcc898077,0x412a11d2}},	//   _ruka, wnic, _شنبه_, того_,
   {{0x46f62cd1,0xf5488028,0x3f8301dd,0x52760c24}},	//   ачат, _tục_, guju_, _купу,
   {{0xb5fd9809,0xfd4c801c,0x29d800e1,0xdb0ec96a}},	//   jašk, _nhiễ, eľať_, _orbá,

   {{0xe7371b56,0x7ce000f2,0xb4662fd6,0xee3a1c60}},	// [3400] рет_, _förl, икал, тна_,
   {{0x6f0410d1,0x6d460503,0x3eafc96b,0x25bf496c}},	//   snic, _vuka, _lagt_, _šulc_,
   {{0x3f830052,0x307b0039,0xf1b9826c,0x213e80f7}},	//   cuju_, _באינ, _arš_, _rith_,
   {{0x29183ed7,0xeb968158,0x213e8a2a,0x68fc080a}},	//   lora_, ידער_, _sith_, lird,
   {{0x332d82a3,0x80c29d41,0x26cd80d2,0x7ce0496d}},	//   _dhex_, लाले, djeo_, _hörm,
   {{0xdced0024,0x78a3c96e,0x6aa28174,0x307a03de}},	//   vrać, genv, seof, דאַנ,
   {{0xe3a783f8,0xa3ba0006,0x96f88056,0x7ee6b2f0}},	//   _بر_, _अछि_, лект_, ицие,
   {{0x213e873a,0x2918496f,0x68fc0285,0xd6d78198}},	//   _with_, hora_, hird, иты_,
   {{0x3f830025,0x29182cdb,0x68fc007e,0xaa7b04e8}},	//   zuju_, kora_, kird, hkýc,
   {{0x63b8800d,0x29184358,0x14c9036d,0x7bda9c43}},	//   _prvn, jora_, रायण, tytu,
   {{0x26c20364,0x68fc07c0,0x66e683bd,0xa113853d}},	//   _onko_, dird, _кожа, _بولت,
   {{0x83fc8024,0xdced02a5,0x3f830b67,0x32674970}},	//   nađi, prać, vuju_, штов,
   {{0xbddb4971,0xf8da86a7,0xe4e680e8,0x7d1c04e8}},	//   _agèn, _बकाय, _війн, _okrs,
   {{0x3f831cdf,0x26c206c0,0x68fc4972,0x3a20076d}},	//   tuju_, _anko_, gird, _dyip_,
   {{0xbb849ecd,0x438480f7,0x2ee9031d,0x533514f6}},	//   _العي, _العق, thaf_, _лект,
   {{0x2fcd003a,0x643b8833,0x2d920901,0x3f911fe7}},	//   ćeg_, _בעונ, ftye_, rtzu_,
   {{0x7afd4973,0x29184974,0x3f830052,0x2d84c975}},	// [3410] mist, bora_, suju_, nume_,
   {{0x29184976,0x7ce000f2,0x3f830024,0xfd100290}},	//   cora_, _förm, puju_, وجل_,
   {{0xaa7b0a56,0x69dd1da3,0x7ce002bb,0x3949022c}},	//   ckýc, lyse, _görm, _huas_,
   {{0x7b1d05e4,0x39494977,0x2d84c978,0x83fc8042}},	//   céut, _kuas_, kume_, gađi,
   {{0x2d84c979,0x78a38d35,0xf1a7c97a,0x26cd826c}},	//   jume_, tenv, ррен, vjeo_,
   {{0x3eafc97b,0x39490069,0x31580039,0xac191a11}},	//   _sagt_, _muas_, סיון_, _богу_,
   {{0x7afd497c,0x3949497d,0x3a8787ac,0x48788d13}},	//   kist, _luas_, _вызв, рсія_,
   {{0x7afd497e,0x78a3907f,0xb5fd8067,0xf1b9826c}},	//   jist, senv, laši, _trš_,
   {{0x7afd2ddd,0x39490014,0x25a90948,0x2d84c97f}},	//   dist, _nuas_, nwal_, gume_,
   {{0x50db8128,0x7e6d30f1,0xb5fd833b,0x7afd0a52}},	//   _भविष, haap, naši, eist,
   {{0x291802a5,0x7ce004b8,0x7e6d4980,0xa3d70076}},	//   vora_, _börj, kaap, िहि_,
   {{0x394909ca,0xc049007c,0x2ee68122,0x7b1d0118}},	//   _buas_, _טז_, _glof_, déus,
   {{0x3949244b,0x2d84802a,0x68fc03bf,0xb5fd8390}},	//   _cuas_, cume_, tird, kaši,
   {{0x6443003a,0x6d5b8812,0x39494981,0x25a94982}},	//   žnij, mpua, _duas_, dwal_,
   {{0x7afd4983,0x29184984,0x2ca5a90e,0x5eaa80c8}},	//   bist, rora_, meld_, কারে,
   {{0xe9ff801c,0x70160f97,0xf54880ff,0x6306003d}},	//   _ngắn_, _दुःख_, _mụn_, _دوبل,
   {{0xf50a11b3,0xaa7b03fb,0xb5fd812b,0x70b7801b}},	// [3420] гнал_, skýc, faši, _आफूल,
   {{0x77ca14d6,0xad9b0118,0xb5fd817f,0xee374970}},	//   _блог_, _axús, gaši, сну_,
   {{0x493b0051,0x7b1d0511,0x3ea601a4,0xaf0a006b}},	//   _תגיו, péut, _линг, _مقدم_,
   {{0x7ce0225f,0x6d5b8359,0x2907c985,0x2ca5c986}},	//   _körk, kpua, enna_, held_,
   {{0x2ca5c987,0x83fc805c,0x67244988,0xb5fd9351}},	//   keld_, rađi, mlij, baši,
   {{0x7afd4989,0x7ce00ffd,0xceb40085,0x836a003d}},	//   zist, _mörk, ldə_, _مصرف_,
   {{0x2249807d,0x442a010c,0x8f34c98a,0x7986498b}},	//   žaka_, _uzb_, оекц, hukw,
   {{0xceb402bf,0x7afd498c,0x29078307,0x2d84c98d}},	//   ndə_, xist, anna_, tume_,
   {{0x67242ce9,0xceb30039,0x2ca581ec,0x6d5b809c}},	//   ilij, ליה_, feld_, gpua,
   {{0x3949498e,0x7afd498f,0x2d849c49,0x2ca59f8f}},	//   _ruas_, wist, rume_, geld_,
   {{0xa3e805b3,0x39494990,0x2a690006,0xceb40201}},	//   यनि_, _suas_, _peab_, kdə_,
   {{0x394901e9,0x67240253,0x798606bb,0x2d801142}},	//   _puas_, jlij, fukw, krie_,
   {{0x3949022c,0x672400d2,0x656f80f7,0x7e6d4792}},	//   _quas_, dlij, ácht, vaap,
   {{0x7afd4991,0x394901c0,0x1c0802f1,0x69dd0901}},	//   sist, _vuas_, वपाल_, ryse,
   {{0x7afd446f,0x64430805,0x7d1ac992,0x6e22808e}},	//   pist, žnik, mots, _hyob,
   {{0x39494993,0x7ce000f2,0x3f7302a5,0xaae708ca}},	//   _tuas_, _förk, rću_, _دستو,
   {{0xb5fd8289,0x2907c994,0x7ce009ce,0xf8ae053d}},	// [3430] taši, ynna_, _görk, رکی_,
   {{0xfaff037a,0x5c750071,0x9c470fbf,0xf99001a8}},	//   lië_, ілет, схал, _أبي_,
   {{0x67244995,0x2d804996,0x28c781a2,0x7e6d4997}},	//   blij, arie_, लासि, paap,
   {{0x2d80002e,0x291eb138,0x63ae00dd,0xfaff06a8}},	//   brie_, _akta_, _dsbn, nië_,
   {{0xdd86a779,0x6e22c998,0x9fa2807b,0x7d1ac999}},	//   _تو_, _nyob, _síða_, kots,
   {{0xb4d78076,0x7bc5807b,0xa3b6000f,0x6eea01ac}},	//   _सवे_, _áhug, जिश_, _výbe,
   {{0xdb0b0207,0x2ca5c1e6,0xe3b31f31,0x60dc007c}},	//   _esfé, veld_, _عرس_, רקונ,
   {{0xba7784c0,0x2ca5bd05,0xe5798d69,0xa3b60768}},	//   _داست, weld_, ази_, जिर_,
   {{0x7ae987d9,0x7afbc99a,0x2ca5c99b,0xfaff074c}},	//   _ilet, _imut, teld_, dië_,
   {{0x6d5ba0d5,0xceb40085,0x67240140,0xdced09d1}},	//   rpua, zdə_, zlij, ksač,
   {{0x2ca590f4,0x7ae9c99c,0xeb9995fc,0x130a0009}},	//   reld_, _klet, шин_, иной_,
   {{0x628b9d53,0xdb1c82be,0x3f87c99d,0x7afb8372}},	//   nggo, _arrê, munu_, _jmut,
   {{0x7ce000f2,0x7d1ac913,0x3f87880a,0xec6e8ea2}},	//   _förh, bots, lunu_, _оп_,
   {{0x6d59c99e,0x7ae9c99f,0x64470168,0x7ae2c9a0}},	//   _itwa, _llet, _ngji, zkot,
   {{0xb9020076,0x48e1ae04,0x7ae9837b,0x672449a1}},	//   _दव_, _कवनो_, _olet, tlij,
   {{0x6d43c9a2,0xbebb020f,0x6f0985ef,0x6d4ba5d3}},	//   _hina, _shër, nnec, _kuga,
   {{0x6d43c9a3,0x67240613,0x6d4bc9a4,0xceb40086}},	// [3440] _kina, rlij, _juga, rdə_,
   {{0x67240582,0x6d4bc9a5,0x2d8049a6,0x6d43c9a7}},	//   slij, _muga, rrie_, _jina,
   {{0x6d4bc9a8,0x6d43c9a9,0x672400d2,0xa09b00be}},	//   _luga, _mina, plij, _דייט,
   {{0xe29aa5c4,0xdcfba43e,0xd2509baf,0x6d43c9aa}},	//   рад_, druč, رنت_, _lina,
   {{0x6d43811e,0xdb218019,0x6f1b801b,0x6d4bc9ab}},	//   _oina, ítás, douc, _nuga,
   {{0x7ae9c9ac,0x6d43c9ad,0xfbc99a22,0x3a2d8da8}},	//   _elet, _nina, िमाम, _dzep_,
   {{0x6d59bd92,0x6d4bc9ae,0x7ae992ed,0xd90d87d2}},	//   _atwa, _auga, _flet, دیل_,
   {{0x6d4bae8b,0x7c2e49af,0x6d43c9b0,0x644700f1}},	//   _buga, _izbr, _aina, _zgji,
   {{0x6d4bc9b1,0x29008187,0x6d4380f8,0xe4a6948d}},	//   _cuga, éias_, _bina, орно,
   {{0x6d4b84a7,0x6d43c9b2,0x332681b9,0xb5fd81a1}},	//   _duga, _cina, llox_, jašu,
   {{0x6d598352,0x2e4e81bc,0x6d4bc9b3,0x7d1ac9b4}},	//   _etwa, _dọrọ_, _euga, rots,
   {{0x2eed9a1c,0x6d43ac9f,0x7c2e008e,0x6f1b8036}},	//   chef_, _eina, _mzbr, couc,
   {{0xc6499e09,0xfaff0cfa,0x6d4b8978,0x2e4e81bc}},	//   _اجمل_, rië_, _guga, _fọrọ_,
   {{0x6d438bf2,0xfaff49b5,0x3a2482c4,0x7c2e04e8}},	//   _gina, sië_, _mymp_, _ozbr,
   {{0x291c8087,0x466b0323,0x6d4bc9b6,0x7c238428}},	//   iova_, ирам_, _zuga, _gynr,
   {{0x291cc9b7,0x6d43b059,0xa3c9aaf8,0x6d4bc9b8}},	//   hova_, _zina, ोहर_, _yuga,
   {{0x61200065,0x83fc803a,0xdd940110,0x344b0878}},	// [3450] tölt, rađu, маты, ачен_,
   {{0xb5fd8052,0x7ae98bc5,0x61320366,0x6f008041}},	//   mašt, _slet, gæld, himc,
   {{0xf092004c,0xb5fd8025,0x141900f7,0x2249008e}},	//   _אני_, lašt, حياة_, _kgak_,
   {{0x9948015b,0x224900ee,0x26c6819d,0x79828035}},	//   _دلیل_, _jgak_, _nnoo_, frow,
   {{0x386c8267,0x6f00817f,0xdce98088,0x7982c9b9}},	//   _bedr_, dimc, zređ, grow,
   {{0x6d4bc9ba,0x3ea949bb,0x463a03c8,0xe4a401a1}},	//   _ruga, leat_, _לערע, _орсо,
   {{0x6d43c9bc,0xf77180f7,0x98a280e8,0x2721816b}},	//   _rina, ءات_, хище, zónu_,
   {{0x6d43c9bd,0xdce98eef,0x7afb8578,0x2249015d}},	//   _sina, vređ, _umut, _ngak_,
   {{0x6f09c9be,0x6d43ba93,0x291c8067,0xddcb80eb}},	//   rnec, _pina, bova_, _iegū,
   {{0xa3df0b3b,0x22490867,0x6f1bc9bf,0x291cc9c0}},	//   _तथा_, _agak_, souc, cova_,
   {{0x6d43c9c1,0x6f00803a,0x644f809a,0x2a6d8069}},	//   _vina, bimc, ścio, _keeb_,
   {{0x26d9062f,0x6d4bc9c2,0x6d43c9c3,0x2121008e}},	//   _noso_, _tuga, _wina, _akhh_,
   {{0x6d4392e8,0x2a6d81c0,0x6d59c9c4,0xdc3c80eb}},	//   _tina, _meeb_, _utwa, kšķi,
   {{0xdce990d3,0xd47980be,0x2a6d8cd8,0xe8e100ff}},	//   pređ, _האַל, _leeb_, _đợt_,
   {{0xa3cc890a,0xb5fdb351,0x26d949c5,0xe0161513}},	//   रमण_, rašu, _boso_, _दुखद_,
   {{0x9c7c83fb,0x3f51801c,0x2a6d8069,0xc7b280be}},	//   nkčn, _máu_, _neeb_, עבן_,
   {{0x0d860071,0x6da3079e,0x25adc9c6,0x272191a9}},	// [3460] ялан, нита, nwel_, lóns_,
   {{0xe52311c7,0x6ab60915,0x5fbd8651,0x39458687}},	//   едуп, _hayf, ्माल, _nils_,
   {{0x6132013c,0xeb9a1f0d,0x68e13635,0x6ecc001b}},	//   ræld, сие_, ölde, हादु,
   {{0x2a6d81e9,0x3ea90609,0x3f8a0bb1,0x79828035}},	//   _ceeb_, ceat_, mubu_, trow,
   {{0x6ab62651,0x7d01c9c7,0x25ad80f3,0x3f9849c8}},	//   _mayf, kils, jwel_, ltru_,
   {{0x394d87e2,0xd90d89a7,0xdb07807b,0xed5713d1}},	//   _dues_, لیق_, _brjó, _хор_,
   {{0x3f980193,0x2a6d8069,0x7c2e2fbe,0xb5fd811f}},	//   ntru_, _feeb_, _uzbr, zašt,
   {{0x291cc9c9,0xc7b30039,0x7d1e016d,0x7982809a}},	//   sova_, תבה_, lops, prow,
   {{0x291c8503,0x3945c9ca,0x6f009040,0x2167c9cb}},	//   pova_, _fils_, rimc, _нити_,
   {{0x3f8a49cc,0xb5fd80fe,0x61e28176,0x27218118}},	//   kubu_, vašt, myol, fóns_,
   {{0x7ce004b8,0x61e283f7,0x2a6d81c5,0xf8b3807c}},	//   _förv, lyol, _yeeb_, _רשע_,
   {{0x2a6d81e9,0xdb0e8980,0xb5fd8669,0x6b888366}},	//   _xeeb_, _arbú, tašt, rudg,
   {{0x61e2c9cd,0x7d01c9ce,0xa3b328bf,0x26d91abb}},	//   nyol, bils, _जैन_, _roso_,
   {{0x26d949cf,0x7d578039,0xa63b8039,0xb5fd943c}},	//   _soso_, _ציוד_, _הגדר, rašt,
   {{0xb8f5000f,0x7d1e0573,0x26d90573,0x2721802a}},	//   _सच_, dops, _poso_, cóns_,
   {{0xdb1583a8,0xb5fd9351,0xf7700061,0xd6d804dd}},	//   _orzá, pašt, طاف_, пту_,
   {{0xceb40201,0xf6500064,0x7aed49d0,0x26d901df}},	// [3470] vlət_, ائف_, _ilat, _voso_,
   {{0x6eea026f,0x3ea949d1,0x2a6d822c,0x394d8036}},	//   _výba, seat_, _seeb_, _rues_,
   {{0x2a6d81c0,0x3ea949d2,0xa7740162,0x0edc80c2}},	//   _peeb_, peat_, _плэч, _बवंड,
   {{0x394d85b4,0x60c88006,0x628f005d,0x2a6dc9d3}},	//   _pues_, _andm, ngco, _qeeb_,
   {{0x272187f4,0x6f0d49d4,0x3f51c9d5,0x394dc9d6}},	//   zóns_, mnac, _sáu_, _ques_,
   {{0xa3cc83bb,0xa3be800d,0x394d82be,0x47598b33}},	//   रमा_, ीमा_, _vues_, ория_,
   {{0x2a6dc9d7,0xceb40085,0x7d01c9d8,0x25ad8197}},	//   _teeb_, mlər_, vils, wwel_,
   {{0x6d471067,0x6458813c,0xceb40085,0x443100b9}},	//   _hija, _afvi, llər_, _izz_,
   {{0x6d4f002e,0x6d4749d9,0xa2d109c2,0x7d019277}},	//   _juca, _kija, धान्, tils,
   {{0x7aed49da,0x6ab60179,0x7ce02459,0x6d4f0079}},	//   _alat, _sayf, _föru, _muca,
   {{0x6d4f49db,0x7ce00019,0x2d848dd7,0xa3b6009a}},	//   _luca, _törv, arme_, जिए_,
   {{0x7aed49dc,0x6d5d47ba,0x272181df,0x7d01c9dd}},	//   _clat, _otsa, róns_, sils,
   {{0x2360805c,0xe8160076,0x80b4809a,0xceb40201}},	//   _čije_, _दुजा_, _इसमे, klər_,
   {{0x7aed49de,0x6d4749df,0xdcfb80eb,0x6729c9e0}},	//   _elat, _nija, bruā, llej,
   {{0xd9431172,0x6d5d1d76,0x61434675,0x7aed49e1}},	//   тери, _atsa, тера, _flat,
   {{0x6d4f49e2,0x6f0d49e3,0xdced00c3,0xbfc3047f}},	//   _buca, gnac, drađ, ъбск,
   {{0x29034679,0xcb130051,0x44278355,0x3f9849e4}},	// [3480] bija_, _שלח_, _hyn_, stru_,
   {{0x3e6c0104,0x7aed49e5,0x6d4f49e6,0x6f0d34cb}},	//   ết_, _zlat, _duca, anac,
   {{0xdced003a,0x6d4749e7,0x7d1e2dcf,0x6d4f03cd}},	//   građ, _dija, rops, _euca,
   {{0x44279d5d,0x673b809a,0x60dac9e8,0x7d1e49e9}},	//   _myn_, jmuj, _sotm, sops,
   {{0x6fc08076,0x6d4749ea,0xceb40201,0x4427b204}},	//   विभू, _fija, blər_, _lyn_,
   {{0x6f0403e4,0xdced0503,0x764b8c2e,0xd25982d6}},	//   liic, brađ, _aggy, _efņ_,
   {{0x672985a4,0xb8d69278,0x62880110,0x4427c9eb}},	//   flej, _जस_, ėdoj, _nyn_,
   {{0xd6d08013,0x6d4f0388,0x6729807a,0x3f808110}},	//   اقة_, _yuca, glej, čiu_,
   {{0xa3b61a4d,0x7ce000f2,0x9f4549ec,0x6459009a}},	//   जिक_, _fört, álé_, świe,
   {{0x6f0d009a,0x764b8365,0x290304b7,0x2cb801a1}},	//   znac, _eggy, xija_, _jard_,
   {{0x4427831d,0x6ef1013c,0x7ce012d2,0x2cb8022b}},	//   _cyn_, _håbe, _hörs, _mard_,
   {{0x44278114,0x2d4d017f,0x29033b39,0x8c3c8214}},	//   _dyn_, _užeg_, wija_, neği,
   {{0xf2d3893f,0x7aed012b,0xdced011f,0xceb4011c}},	//   דער_, _vlat, zrađ, ylər_,
   {{0xa6db008b,0x4427c9ed,0x6d4f26a3,0x6ef10646}},	//   _viðm, _fyn_, _ruca, _måbe,
   {{0x6d47298e,0xd6db1928,0x7aed003d,0x4427c9ee}},	//   _rija, ота_, _tlat, _gyn_,
   {{0x6d4f003b,0x6d4749ef,0x2cb80cfa,0x2cacc9f0}},	//   _puca, _sija, _aard_, ledd_,
   {{0x2cac831d,0xceb40085,0x9df9098d,0x50670081}},	// [3490] oedd_, tlər_, чнат_, _отна,
   {{0x6f0d49f1,0x973c8d26,0x2cb8062d,0x2cac8114}},	//   snac, _općo, _card_, nedd_,
   {{0xceb40086,0x6d4749f2,0x6720911b,0x673b8035}},	//   rlər_, _vija, komj, ymuj,
   {{0x7ce049f3,0x521580e5,0x2cac831d,0x6d4739d2}},	//   _börs, ндет, hedd_, _wija,
   {{0x865a0051,0xa9698258,0x2169a345,0xb65a007c}},	//   _מדרי, чила_, чили_, _מדרש,
   {{0x798bc9f4,0xa3be82f1,0x2cb849f5,0x3eb949f6}},	//   rugw, ँटा_, _gard_, _hast_,
   {{0xddc600eb,0x3eb949f7,0x67298074,0xf1b9816b}},	//   _iekš, _kast_, tlej, _myši_,
   {{0x7ce049f8,0x8c3c87d9,0xb4db0722,0xe9ff8129}},	//   _förs, ceği, _guàr, _ngần_,
   {{0x7ce049f9,0x99678221,0x7cf2013c,0xe8d9082e}},	//   _tört, _італ, _færd, _atọ_,
   {{0x67bb8060,0x644e8289,0xdb0b49fa,0x0d828e11}},	//   _واضح_, žbin, _erfü, ыльн,
   {{0xab2a1c9b,0xc2090039,0x7ced80f7,0x6729c9fb}},	//   зона_, _פה_, _cúra, plej,
   {{0x7af98059,0xbebb0168,0xf41203de,0x2a7f8197}},	//   _çatı, _skën, רפט_, _jdub_,
   {{0x3eadc9fc,0xaca38135,0xc33284de,0x4427c9fd}},	//   meet_, _arụk, טוט_, _wyn_,
   {{0xdce98279,0x3eadabcb,0x7cf2006a,0x80bf8264}},	//   dseć, leet_, _kære, ্সক্,
   {{0x07a300c4,0x6ee302f1,0x8fa317c8,0x3eb949fe}},	//   ларн, _lõbu, ларе, _bast_,
   {{0x3ead8364,0x6eea003e,0x224d82d5,0x26dda11d}},	//   neet_, _výbo, _ngek_, _jowo_,
   {{0x7cf20bc5,0x395f8282,0x629600b4,0x6f0449ff}},	// [34a0] _lære, _ntus_, _icyo, riic,
   {{0x050000ab,0xdd8f12dc,0x6f040362,0x26ddca00}},	//   ্ত্র_, صوم_, siic, _lowo_,
   {{0x3eb94a01,0x66e61f91,0x3ead956e,0xaca401bc}},	//   _fast_, _зона, keet_, _nzụr,
   {{0x69c44a02,0x3eb94a03,0x60de4a04,0x3ead8198}},	//   _krie, _gast_, _hopm, jeet_,
   {{0x2cb84a05,0x6726021e,0x7ce0016d,0xe8948c5c}},	//   _tard_, _ikkj, _dörr, валь,
   {{0x65643abf,0x7cf20aa2,0x6ef1006a,0x290e8333}},	//   mpih, _bære, _våbe, unfa_,
   {{0x7ce000f2,0x25a68696,0x09d880ab,0x7cf2013c}},	//   _förr, _spol_, _দেখা, _værd,
   {{0x8f9b0451,0x61e601e2,0x539b0039,0x26dd8b99}},	//   ליצי, kykl, _מילו, _cowo_,
   {{0x55068a41,0x10a6a39a,0x3f8780d2,0xdce28bcf}},	//   ечна, _пиан, arnu_, _svođ,
   {{0x5597093f,0xfd4d019d,0xdb1581ec,0x7e7688ae}},	//   עדיע_, _aghị, _erzä, _šapć,
   {{0xccf30051,0x2cac8514,0x644e01bc,0xe1ff808b}},	//   רכת_, redd_, _mgbi, _þór_,
   {{0x2cac8514,0xa6db007b,0x39524a06,0xf1bf03f2}},	//   sedd_, _viðk, _buys_, tvá_,
   {{0xfce697f9,0x2b4935d5,0x3eb93038,0x645c0aa8}},	//   _подо, _viac_, _rast_, _ofri,
   {{0x313515b7,0x7521823e,0x3eb90a53,0x2c86826b}},	//   тегр, colz, _sast_, _dídà_,
   {{0x6280803a,0xdce28024,0x78baba79,0x3ea02e17}},	//   _odmo, _uvođ, _matv, ffit_,
   {{0x645c4a07,0x69c40051,0x644e4a08,0x6d4aa8b8}},	//   _afri, _frie, _agbi, _hifa,
   {{0x6d4aca09,0x65640bb1,0x7d250019,0x644e0609}},	// [34b0] _kifa, gpih, نفرن, _bgbi,
   {{0x645aca0a,0x29014a0b,0x3f8eca0c,0x6d4aca0d}},	//   ncti, _umha_, kufu_, _jifa,
   {{0xa6db007b,0x6d4a804f,0x3eb93344,0x7cf203ba}},	//   _liði, _mifa, _tast_, _bærb,
   {{0x6abd2b33,0xf6790158,0x7c2a8aff,0x877a007c}},	//   ndsf, _קאָמ, _myfr, _קארי,
   {{0x645c031d,0x442b80ff,0x6abd206b,0x7c2a8428}},	//   _ffri, ́c_, idsf, _lyfr,
   {{0x672d4a0e,0x3ead867f,0x6d4aca0f,0x91e28dac}},	//   llaj, weet_, _nifa, роше,
   {{0x3ead88e5,0x8aa781e2,0x6fb280f7,0x61e60402}},	//   teet_, _прад, لموا, zykl,
   {{0x78a4803a,0x7cf20257,0x645a802e,0x672d4a10}},	//   điva, _være, ecti, nlaj,
   {{0x23608067,0x6d4aca11,0x7ce04a12,0x78ba8088}},	//   _čija_, _bifa, _körp, _fatv,
   {{0x2d838805,0x82348013,0x78baca13,0x7bc3826c}},	//   čje_, _إرفا, _gatv, _prnu,
   {{0x7c2a8355,0xc6e7835f,0x6abb8352,0x6d4aca14}},	//   _cyfr, _підп, _kauf, _difa,
   {{0x69c44a15,0x2907ca16,0x29110098,0xe1ff4a17}},	//   _prie, lina_, enza_, rbón_,
   {{0x6d4aac3a,0x399b83a7,0x2d8d876b,0x95e98019}},	//   _fifa, nês_, quee_, _تباہ_,
   {{0x69c42539,0x6abb90f6,0x2d89067f,0x6d4a8a03}},	//   _vrie, _lauf, drae_, _gifa,
   {{0x7c2a831d,0x61e60b73,0xf0928039,0x81d780ab}},	//   _gyfr, sykl, ינם_, ানি_,
   {{0x2907ca18,0x29114a19,0xe1f21381,0x672d3b08}},	//   hina_, anza_, _نسخ_, glaj,
   {{0x2907ca1a,0x60de4a1b,0x657bca1c,0x7afd03ed}},	// [34c0] kina_, _topm, nsuh, ërte,
   {{0x81d780c8,0x7ce4809f,0x25b2079f,0x656409ca}},	//   ানা_, _fòru, rwyl_, rpih,
   {{0x2907803a,0x672d4a1d,0x644f809a,0x1fbd8035}},	//   dina_, blaj, ściw, ्मोड,
   {{0x66e61511,0x672d06a5,0xe1ff0019,0x2d891b65}},	//   _рома, claj, kból_, brae_,
   {{0x78baab47,0x6459009a,0x2907ca1e,0x7ce0016d}},	//   _patv, świa, fina_, _förp,
   {{0x28d54a1f,0x97a69541,0x645c4a20,0xa3b34a21}},	//   दायि, врил, _ufri, _जैव_,
   {{0xdfd080f7,0x6abb9c9f,0x8b26a351,0x28c781a2}},	//   صية_, _fauf, _адве, लाजि,
   {{0xa3d584e5,0x1ae3b4fd,0x3f8eca22,0x399b8187}},	//   समन_, _косм, rufu_, bês_,
   {{0x2907c134,0x399b8073,0x81e700ab,0x3f8e8b3f}},	//   bina_, cês_, _যেন_, sufu_,
   {{0x799d01c0,0xf212819d,0x6abb866f,0xfd4e0135}},	//   vtsw, bọrọ, _zauf, wekọ,
   {{0x6d4a8010,0xd251003d,0x69c2874c,0x7ae081f6}},	//   _vifa, ینگ_, lvoe, _komt,
   {{0xb69b0087,0x7ce48580,0x6d4a818f,0x69dd87b6}},	//   _amân, _aòrt, _wifa, _àsec,
   {{0x69c2910f,0x6abd04e1,0x394cca23,0x7ae3841c}},	//   nvoe, rdsf, _kids_, ênti,
   {{0x55778158,0x7ae0a4f4,0x2d89067f,0xf548827d}},	//   _יעדן_, _lomt, vrae_, _cụt_,
   {{0x799d01c0,0xa6db007b,0xa3cc86a7,0x7ce48a2a}},	//   stsw, _miðv, _रपट_, _dòrt,
   {{0x6609007b,0x394ca0b4,0x2d894a24,0xd5b69a42}},	//   _þekk, _lids_, trae_, _अनाज,
   {{0x672d4a25,0x06c500ab,0x2907a2e8,0xd49b1775}},	// [34d0] rlaj, _একদি, yina_, дре_,
   {{0x290787f4,0x2d89002a,0x7d08826c,0x2c7c01d0}},	//   xina_, rrae_, nids, vádí_,
   {{0xa3d584e5,0xd251990c,0x6ef5a2d9,0xa3b302f1}},	//   समय_, منا_, _hábe, _जैश_,
   {{0x7ae087fa,0x2907ca26,0x7d088392,0xaad606a7}},	//   _comt, wina_, hids, धायक,
   {{0x4aa51d2a,0xdcef0201,0xf99f0247,0xdb0e8118}},	//   ग्यव, şdır, ntè_, _arbó,
   {{0x3ea6ca27,0x6e2b8428,0x6934b941,0xdb1c8580}},	//   _abot_, _rygb, анчу, _errà,
   {{0x6abb8433,0x3f588187,0x65628915,0x3f91007e}},	//   _tauf, _céu_, _atoh, nuzu_,
   {{0x2907ca28,0xf8380051,0xf99f0247,0x3f588722}},	//   sina_, כנות_, ktè_, _déu_,
   {{0x7bc181c0,0x61320366,0xfec50264,0x2b4dab8c}},	//   wvlu, fæll, _একাধ, _iiec_,
   {{0xee368110,0x394cca29,0x2907b2f5,0x7cf2008b}},	//   ыны_, _gids_, qina_, _kæra,
   {{0xe29a2fc0,0xd1208074,0xfc0580e2,0xe1ff0061}},	//   нан_, मकरण_, упно, sból_,
   {{0x68e1ca2a,0x2249856f,0xdb1583a8,0x65628168}},	//   _hold, žaku_, _arzú, _ftoh,
   {{0x68e1ca2b,0x6f09809a,0x26cfca2c,0xdbe700ab}},	//   _kold, miec, _ingo_, _গেমস_,
   {{0x6f0980eb,0x68e1826c,0xf1b98267,0x293580be}},	//   liec, _jold, _msš_, טאָן_,
   {{0x68e1ca2d,0x4424819f,0xa6db01fa,0x3f910102}},	//   _mold, _پروف, _liðu, guzu_,
   {{0xb8eb000f,0x6f09ca2e,0x6ee30006,0x2b9c001b}},	//   _रो_, niec, _sõbr, víc_,
   {{0xa6db0125,0x7bc7003d,0xa2d14a2f,0x80b38424}},	// [34e0] _niðu, _arju, धार्, ंजाइ,
   {{0x69ba8035,0x7ae0ca30,0x69094a31,0x59c7914f}},	//   _एनबी, _somt, lžen, लिनर,
   {{0x389b093f,0xb09b012a,0xa2d8024c,0xdb1c8825}},	//   _איינ, _אייר, याप्, _arrá,
   {{0x290a4a32,0x69c285f8,0x7cf68087,0x3cf00072}},	//   liba_, tvoe, _târg, _इतके_,
   {{0x28130077,0xc05a835f,0x2b9c03fb,0x68e1ca33}},	//   _نویس, ній_, síc_, _bold,
   {{0x69c2838e,0x26cfca34,0x29058362,0x3eb202c4}},	//   rvoe, _ango_, _cmla_, leyt_,
   {{0x7ae0ca35,0x6d5dca36,0x7d08aa92,0x6d418916}},	//   _tomt, ísan, vids, dmla,
   {{0x6d4e4a37,0x2d829d1c,0x66090267,0x3dc6ca38}},	//   _hiba, škem_, _žeki, _prow_,
   {{0x6d4e34d8,0xa2d804c5,0x7d088082,0x5896803d}},	//   _kiba, यान्, tids, _مجاز,
   {{0xdce981ac,0x8f76835f,0x6d4e4a39,0x68e1c9f6}},	//   ateľ, _буді, _jiba, _gold,
   {{0x6f09ca3a,0x7d088b81,0x290a4a3b,0x6d4e4a3c}},	//   biec, rids, diba_, _miba,
   {{0x6d4e4a3d,0x973c82fd,0xa2ca81ab,0x68e1ca3e}},	//   _liba, _opći, _सोम्, _zold,
   {{0x7d08ca3f,0x68e18059,0x26c0031d,0xf1c784e5}},	//   pids, _yold, ddio_, लियन,
   {{0x25a0013c,0x7faa8201,0x5d8380f7,0x68e18118}},	//   dtil_, _təqd, _الول, _xold,
   {{0xe44fa6c2,0xd7f80364,0xf99f4a40,0x7c2e0502}},	//   _عضو_, гут_, stè_, _nybr,
   {{0x6d4e130c,0xa4ff000c,0x3f9101f4,0x636081bc}},	//   _aiba, ोच्च_, ruzu_, _ịnwa,
   {{0x6d4e457f,0xdd950071,0x2d9200b4,0x443809ed}},	// [34f0] _biba, разы, guye_, _azr_,
   {{0x2d874a41,0x290a0661,0x6d4e4a42,0x753c0035}},	//   čne_, ciba_, _ciba, _chrz,
   {{0x6d4e4a43,0x68e183a8,0x32558110,0xaa55a7d4}},	//   _diba, _rold, авер, авеш,
   {{0xd6db4a44,0x2d923818,0x6d4e0102,0x65950110}},	//   _что_, buye_, _eiba, _каму,
   {{0x68e1c37d,0x25a04a45,0x2b4d80ff,0x442eca46}},	//   _pold, ctil_, _viec_, _lyf_,
   {{0x6d4e4a47,0x6f09809a,0x68e1a0d8,0xa6db007b}},	//   _giba, wiec, _qold, _viðu,
   {{0x68e1bddd,0x6f098029,0xe3e480c8,0x46f5ca48}},	//   _vold, tiec, _ফেসব, ичит,
   {{0x290a4a49,0x9585a265,0x6d4e44a5,0x9a1281bc}},	//   ziba_, алие, _ziba, pọpụ,
   {{0x68e19a7e,0xe57697ae,0x19598a14,0x3ebfca4a}},	//   _told, азы_, _разы_, rdut_,
   {{0x6f098114,0xb3a98214,0x6d4e0118,0xdce981d6}},	//   siec, _çıkı, _xiba, steľ,
   {{0xd0119e7b,0x6f098029,0x6d41ca4b,0xfd5e01bc}},	//   _بلا_, piec, rmla, _bayọ,
   {{0xb6c98117,0x69c9ca4c,0x690901d0,0x1f5a81c6}},	//   _جائے_, _kree, užen, _סדנא,
   {{0x290a4a4d,0x69c9808e,0x956795a6,0x7f570036}},	//   tiba_, _jree, _съед, _auxq,
   {{0x7e7b8867,0x8c45ca4e,0x672481dd,0x2ca780ff}},	//   laup, _келе, čije, _ubnd_,
   {{0x61eb807b,0x6aa9ca4f,0x37e34a50,0x2f1a8ec3}},	//   hygl, _obef, оорг, līga_,
   {{0xe8df8028,0x09e60e97,0x539a84de,0x26c0487c}},	//   _muốn_, _воин, _סיפו, udio_,
   {{0xed570003,0x6d5bca51,0x9f454a52,0x69c981c0}},	// [3500] иот_, nqua, álá_, _nree,
   {{0x6909003e,0x7ae41bf3,0x25a03ca5,0xb97b02f6}},	//   nžel, _hoit, rtil_, _שניי,
   {{0x25a04a53,0x7e7b862c,0x1d19035f,0xeb9a2c18}},	//   stil_, kaup, ують_, тие_,
   {{0x7c2e03cb,0xfaa690fc,0x7ae40009,0x82a68110}},	//   _vybr, радо, _joit, радж,
   {{0x7ae407f4,0x44260063,0x41b695a4,0x7c2e009a}},	//   _moit, ło_, рсет, _wybr,
   {{0x7ae4062f,0x6f16481c,0xa3d5801b,0xb11480ab}},	//   _loit, lnyc, समा_, িত্ব_,
   {{0xe8df801c,0xc60e8a27,0xd00f80a0,0xa2c181d0}},	//   _cuốn_, ाप्य_, وله_, _रोक्,
   {{0x6f164a54,0x7ae44a55,0x7e7bca56,0x69c9b60b}},	//   nnyc, _noit, gaup, _free,
   {{0x2d804a57,0x69c9ca58,0x1dc9066b,0x50b6804a}},	//   nsie_, _gree, रियत, _всеу,
   {{0x44f491d5,0x7af60110,0x3f5c0118,0x2d804918}},	//   спос, _alyt, _oíu_, isie_,
   {{0x7ae400e7,0xdeef81e2,0x3f5c4a59,0x443893c2}},	//   _boit, _ды_, _níu_, år_,
   {{0xe5a69c74,0x7ae40068,0x6da6ca5a,0x2d80079f}},	//   _види, _coit, _вида, ksie_,
   {{0x6f160dee,0x2d8000e1,0x2369816b,0x4efb83c8}},	//   dnyc, jsie_, _čaje_, _בלאג,
   {{0xddcf0162,0xa6db01fa,0x6abf022b,0x00000000}},	//   _lecţ, _niðr, _waqf, --,
   {{0x7af612f1,0xc7c41285,0x7c388024,0x9a872cd1}},	//   _flyt, ости, _uzvr, _купл,
   {{0x27219c32,0x7ae40cdb,0xa2d8001b,0xddc998ad}},	//   fóny_, _goit, याण्, nceş,
   {{0x7cf21277,0x635398ad,0x2d8005ee,0xa2ca81d0}},	// [3510] _værn, _dănu, gsie_, _सोध्,
   {{0x629b8098,0x04670ea6,0xeb1f99eb,0x6aa98037}},	//   _scuo, ртам, यक्त_, _sbef,
   {{0x6f16009a,0x61368087,0xd6d100f7,0x2d8d80b9}},	//   bnyc, tâln, _فقد_, zree_,
   {{0x69c9ca5b,0xa6db0125,0x7528809a,0xd64e819d}},	//   _pree, _viðs, hodz, _kọdụ_,
   {{0xa2d80aed,0xe1ff3ac6,0x68e50364,0x7cf23f7e}},	//   यात्, nzó_, _kohd, _kærl,
   {{0x69c980c9,0x6f0d4a5c,0xb4e5816f,0x68e50198}},	//   _vree, liac, _नवे_, _johd,
   {{0x6fd70540,0xa3bb000d,0x68e500ee,0x7e7b96b5}},	//   डमिं, _अनि_, _mohd, taup,
   {{0x6f0d4a5d,0x2d8d81b0,0x6d450c5e,0x38180039}},	//   niac, tree_, lmha, יקום_,
   {{0x6b5e8029,0x6ef5816a,0x9f4e004a,0xd64e819d}},	//   _rīga, _cába, _åfå_, _nọdụ_,
   {{0x6f1621f3,0x6d45008c,0x7ae44a5e,0x6d5bb1f1}},	//   znyc, nmha, _soit, rqua,
   {{0x69090110,0x6d5bca5f,0x7ae43b79,0x65699024}},	//   ržel, squa, _poit, speh,
   {{0x60c1ca60,0xd64e8133,0xdce080eb,0x65958048}},	//   _halm, _bọdụ_, rpmā, _гаду,
   {{0x7ae44a61,0x60c1ca62,0x333f81cd,0xe2970009}},	//   _voit, _kalm, _mhux_, щая_,
   {{0x60c19abb,0xd466835f,0x6f16009a,0xeb999cd5}},	//   _jalm, _лише_, wnyc, _бик_,
   {{0xbb858307,0x60c1ca63,0x6ef5803e,0x6d59ca64}},	//   _البي, _malm, _zába, _huwa,
   {{0x09bd8a49,0x6d59a7ae,0xd64e819d,0x2d80000b}},	//   _আপনা, _kuwa, _fọdụ_, tsie_,
   {{0xac8601e5,0xe73715d1,0x0dca01e5,0x7faa8201}},	// [3520] йгал, сет_, ылай_, _məqa,
   {{0x2d801e11,0x6d59ca65,0xddcf0087,0x5c564a66}},	//   rsie_, _muwa, _secţ, стаф,
   {{0x2d804a67,0xb5fd81e2,0x8ca9886a,0x6d59b303}},	//   ssie_, rašy, ज्यो, _luwa,
   {{0x6f0d11b9,0x64554a68,0x2d804221,0xe5a601ae}},	//   ciac, _egzi, psie_, _лими,
   {{0x26c2003a,0x2b400083,0x6d59ca69,0x4a9b03c8}},	//   _iako_, _mhic_, _nuwa, רינג,
   {{0xa50a0381,0x86370039,0x6eea016b,0x26c24a6a}},	//   _сега_, _לרכב_, _výbu, _hako_,
   {{0x60c1acf6,0x6ef58510,0x68e10ede,0x6d59ca6b}},	//   _dalm, _sába, öldi, _auwa,
   {{0x26c24a6c,0x6d59ca6d,0xe8df801c,0xe807816f}},	//   _jako_, _buwa, _buồn_, _वेळा_,
   {{0x26c2001d,0x2dda81a8,0x6d59b017,0xa2c1a177}},	//   _mako_, ابعة_, _cuwa, _रोट्,
   {{0x6d59ca6e,0x2d8a875f,0x60c181b4,0x6f0d4a6f}},	//   _duwa, čbe_, _galm, ziac,
   {{0x63a582af,0x7cf20b40,0x7528998a,0x7afd0168}},	//   _ähnl, _nærm, rodz, ërto,
   {{0x7cf20bc5,0x26c24a70,0x083b80be,0x6d5980fc}},	//   _særl, _nako_, _געבל, _fuwa,
   {{0x7982809a,0x2d4d0279,0x1562819d,0x26c380eb}},	//   nsow, _džej_, _fọọa, ējot_,
   {{0x19580791,0xa2d5816f,0x2ee681b0,0x26c205ee}},	//   сары_, णाऱ्, _hoof_, _aako_,
   {{0x6e3c82bf,0x6d59ca71,0x26c204bb,0x78b54a72}},	//   ərba, _zuwa, _bako_, rezv,
   {{0x877b83c8,0x290e83e4,0xdce080eb,0xceb981d0}},	//   טאלי, hifa_, ksmī, toři_,
   {{0x28b98321,0x26c24a73,0x690909d1,0x26c701d0}},	// [3530] _इसलि, _dako_, nžek, ěno_,
   {{0x6f0d0038,0x6d451769,0x89dc01c6,0x2ee68a53}},	//   siac, umha, _תחזי, _loof_,
   {{0x6d454a74,0x2d4d00d2,0x6f0d36af,0x26c24a75}},	//   rmha, _užem_, piac, _fako_,
   {{0x539b8039,0x6d450c41,0xf2d400be,0x81bd8264}},	//   ריאו, smha, ּעס_, ইমস_,
   {{0xb2bc00be,0x994801f9,0x6aad300e,0x6f1d0bfd}},	//   טמאר, _خلیل_, _mbaf, _ijsc,
   {{0x6d59ca76,0x656d4a77,0x60c18085,0x26c24a78}},	//   _ruwa, mpah, _qalm, _zako_,
   {{0x60c1ca79,0x26c2022e,0x6d59ca7a,0x43943f61}},	//   _valm, _yako_, _suwa, _нарс,
   {{0x0565916b,0xa3ae0006,0x46e98162,0x7d0a8362}},	//   овин, _कहत_, рдин_, _amfs,
   {{0x60c1ca7b,0x4add00c2,0xa2d8024c,0x656d4a7c}},	//   _talm, यानव, यास्, npah,
   {{0x3b859383,0x6aad4a7d,0x5ba99541,0x672481a1}},	//   олог, _abaf, аком_, čija,
   {{0x28158013,0x656d0573,0x443c81a1,0x69cd0915}},	//   _بواس, hpah, _czv_, _arae,
   {{0x6d59ca7e,0x4acf9199,0x63a50c5e,0x69cd1aad}},	//   _tuwa, _सोमव, ithn, _brae,
   {{0xabd78065,0x26c2011b,0x9f4c01d0,0x6ef58061}},	//   _گزشت, _rako_, ádí_, _hábo,
   {{0x26c24a7f,0x672f009a,0x2d4d0088,0x69cd1ef2}},	//   _sako_, _akcj, _džek_, _drae,
   {{0xc447803d,0x3ea93a0a,0x7ce00061,0x69cd4a80}},	//   _دیدن_, ffat_, _törz, _erae,
   {{0x7afd0352,0x6aad11d3,0x9f590061,0x1b180264}},	//   chst, _gbaf, ázás_, _ধীরে_,
   {{0x23608025,0x69cd4a81,0x26c20042,0x6da30012}},	// [3540] _čiji_, _grae, _vako_, мита,
   {{0x26c2022e,0x62898091,0xe5774a82,0xa2d80b99}},	//   _wako_, _adeo, юзу_, याव्,
   {{0x6ef5826f,0x6efc80e7,0xdee6309a,0x66e6116b}},	//   _nábo, _hébe, _дони, _дона,
   {{0x3f984a83,0x49ca91b3,0xa25b01d6,0x7982b3e0}},	//   muru_, илен_, jdôl, tsow,
   {{0xdce28503,0x3f980458,0x63a500f7,0x290e93a9}},	//   _stoč, luru_, athn, tifa_,
   {{0xc5f30051,0xf7729baf,0x7cf2013c,0x6ef5ca84}},	//   _חדש_, واع_, _mærk, _bábo,
   {{0x290eca85,0x4aca3497,0xa3ae02f1,0xaadd03eb}},	//   rifa_, ियाव, _कहि_, यामक,
   {{0x78ad812b,0x27e08024,0xe297a7ba,0x290eca86}},	//   đava, ćin_, _мас_, sifa_,
   {{0x26c281ac,0x3f983c86,0x7cf2286c,0xe0daa4dc}},	//   ľko_, huru_, _nærk, _ква_,
   {{0xa3ae0d38,0x3f984a87,0x69c08065,0x26c2877b}},	//   _कहा_, kuru_, _isme, žko_,
   {{0x7e644a88,0x3ce7826c,0xdce2812b,0x3f982b1c}},	//   kcip, _donv_, _utoč, juru_,
   {{0x69cd4a89,0xeb07035f,0x6efc83c9,0x7ae2808e}},	//   _prae, ічно, _bébe, njot,
   {{0x9e65803d,0xad5a8198,0x6ef5936f,0xddc3802e}},	//   _رانن, _трех_, _zábo, _обци,
   {{0x3f98449b,0x6efc84c3,0x443ca1d1,0x69cd0a53}},	//   furu_, _débe, _tzv_, _vrae,
   {{0x3f983976,0x443cb7bc,0x290c82d5,0xb90312c6}},	//   guru_, _uzv_, _mmda_, _नच_,
   {{0x69c08904,0x69cd297a,0xd6d84a8a,0x37bc80ab}},	//   _osme, _trae, оту_, _অপার,
   {{0xa2d80b84,0x2d848101,0x61e48198,0x31690326}},	// [3550] यार्, nsme_, äill, _utaz_,
   {{0x3f984a8b,0x2d84ca8c,0x656d00dd,0x8883003d}},	//   buru_, isme_, rpah, _زیرن,
   {{0xa3cd9d6a,0x69c0ca8d,0x29112403,0x656d4a8e}},	//   रिय_, _asme, miza_, spah,
   {{0x0cb785b3,0x629d02e8,0x63a5031d,0x2d8480eb}},	//   _अस्म, ngso, rthn, ksme_,
   {{0x7e7d0341,0x68e8ca8f,0x2d8486d4,0x1a9c03de}},	//   _iesp, _bodd, jsme_, שידע,
   {{0x29114a90,0x91bc0039,0x68e891fe,0x7cf204d6}},	//   niza_, ימדי, _codd, _nærh,
   {{0x200321d5,0x69c0ca91,0x6d5d1d79,0x68e8ca92}},	//   nzji_, _esme, _husa, _dodd,
   {{0x2d9592c0,0x6d5d4a93,0x7e7d4a94,0x6b830511}},	//   прос, _kusa, _jesp, ángu,
   {{0x3f984a95,0x291130a8,0x6d55313e,0xfaff00f1}},	//   zuru_, kiza_, _kiza, dhë_,
   {{0x6d5d4a96,0x7afb8125,0x7e7d0247,0x29110c53}},	//   _musa, _hlut, _lesp, jiza_,
   {{0xca291dfa,0x6d5d4a97,0x2d84ca98,0x7ae9abcb}},	//   _עם_, _lusa, asme_, _koet,
   {{0xf770b25e,0x6d5d247a,0xdb04006a,0x25608176}},	//   _شام_, _ousa, _opnå, _fòl_,
   {{0x7ae98613,0x29114a99,0x7cf30214,0x7d1a81c0}},	//   _moet, fiza_, _kırı, bnts,
   {{0x7cf2013c,0x3f984a9a,0x29114a9b,0x6d554a9c}},	//   _værk, turu_, giza_, _niza,
   {{0x7afbbc96,0x79998748,0x6d5d4a9d,0xd9b88bb8}},	//   _olut, huww, _ausa, _इन्ट,
   {{0x05661269,0xdee334fd,0x3f984a9e,0x66e30615}},	//   зван, носи, ruru_, носа,
   {{0x6d554a9f,0x7e7d0927,0x291144a5,0x60c54aa0}},	// [3560] _biza, _desp, biza_, _fahm,
   {{0x3f984aa1,0xdd8f0f99,0x6d5d4aa2,0x7afbcaa3}},	//   puru_, اول_, _dusa, _alut,
   {{0x46bd816f,0x7ae9caa4,0x68e88114,0x7afb81ec}},	//   ्याह, _boet, _rodd, _blut,
   {{0x7e7d16a1,0xe29acaa5,0x68e8caa6,0x6d5d4aa7}},	//   _gesp, сад_, _sodd, _fusa,
   {{0x6d5d4aa8,0x6d552e9c,0x63828019,0x7ae28009}},	//   _gusa, _fiza, _kíná, rjot,
   {{0x7f42820f,0x7bce0a20,0x6d55011e,0x7e7d009a}},	//   _shoq, _trbu, _giza, _zesp,
   {{0x7afbcaa9,0x6d5d0352,0xd0108013,0x7cf22ca9}},	//   _flut, _zusa, ضلة_, _næri,
   {{0x67248042,0x799980ee,0x6d550ab4,0xe2f88019}},	//   čijo, buww, _ziza, _بورڈ_,
   {{0x69c084c4,0x66044aaa,0x3cfe951e,0x6d5d0079}},	//   _usme, nzik, thtv_, _xusa,
   {{0x7ae9caab,0x6d439997,0x636181bc,0x7d1a82f9}},	//   _zoet, _chna, _ịnap, unts,
   {{0xfaff020f,0xa2950221,0x256086c0,0x92954aac}},	//   thë_, мані, _wòl_, манц,
   {{0x23be001b,0xf7730019,0x7d1a81c0,0x29110314}},	//   _můj_, ہار_, snts, wiza_,
   {{0xdd8f845b,0x236082a5,0x7ced80f7,0x2911315e}},	//   _مون_, _čiju_, _cúrs, tiza_,
   {{0x6d5d0f43,0xfaff00f1,0x0cc700ab,0x7bdc8074}},	//   _rusa, shë_, _শক্ত, ärus,
   {{0x29113003,0x6d5d0590,0x6d554aad,0x443a8028}},	//   riza_, _susa, _riza, _áp_,
   {{0x6d5d0859,0xb8f41516,0x70b9a135,0x29110316}},	//   _pusa, _सो_, _इस्ल, siza_,
   {{0xdce98a56,0x7e7d12d0,0x6d55262c,0x5d552789}},	// [3570] zpeč, _vesp, _piza, дкат,
   {{0x7afbcaae,0xe94500d5,0x7ae9caaf,0x672d0c93}},	//   _slut, _تربی, _soet, soaj,
   {{0x7afbcab0,0xccf380be,0xe8d901bc,0x7e7d4ab1}},	//   _plut, עכע_, _juọ_, _tesp,
   {{0x6d550c5a,0xa3cd90c5,0xa3ae000f,0x6d5d11b5}},	//   _wiza, रित_, _कहर_, _tusa,
   {{0xdd868117,0x7ae985f8,0xa2a50bb3,0x6d5d4ab2}},	//   _جو_, _voet, _कान्, _uusa,
   {{0x25a94ab3,0xf770003d,0xc2448d8e,0xbcfb1727}},	//   mtal_, _جای_, хнік, _quéd,
   {{0x7ae981b7,0x25a9213c,0x7afb89c4,0x7cf698ad}},	//   _toet, ltal_, _tlut, _cârm,
   {{0x26c90010,0xdb1900e1,0x25a94ab4,0x628d01a8}},	//   ndao_, _prvý, otal_, _ndao,
   {{0x25a94ab5,0x7cf305e0,0x917a027d,0x387e8c0b}},	//   ntal_, _tırı, _mật_, _fetr_,
   {{0xab659982,0x2a690176,0x7ce482d6,0x628d0493}},	//   мвол, _afab_, _kòry, _adao,
   {{0xccf2012a,0x6ef8385e,0x1c459ff8,0xd7c186ae}},	//   דכי_, _bíbl, ьном, _शनिच,
   {{0x395f82f1,0x52b801a2,0xc87882d0,0x769681cc}},	//   _kuus_, इजेस, _doğu_, rüyü,
   {{0x64a5cab6,0xb4bd081f,0xa06a0196,0x5fc5cab7}},	//   _жала, _आसू_, жага_, विकल,
   {{0xa3ae0006,0xdb190580,0xdcfb80c3,0x7cf22474}},	//   _कहल_, _esvà, pruđ, _hærv,
   {{0x07a306c8,0xe8d9019d,0x2d8f0216,0x225f026c}},	//   карн, _guọ_, ágen_, žuka_,
   {{0x6604011b,0x6ef80144,0x25a9090d,0x98bf822b}},	//   tzik, _víbo, ftal_, _ftuħ_,
   {{0x395f84df,0x28de06ae,0xe1ff0511,0xccc63811}},	// [3580] _nuus_, मादि, lcón_, мбай,
   {{0xf53f108c,0x66044ab8,0x6ef595d8,0x69c44ab9}},	//   _spår_, rzik, _bábk, _isie,
   {{0xe1ff3e2e,0xf365021e,0x78bc0cab,0x69c402a6}},	//   ncón_, етін, merv, _hsie,
   {{0x31604aba,0x78bc4abb,0xa2d4081f,0x7cf20e51}},	//   _kuiz_, lerv, _बोम्, _nærv,
   {{0x7bda086f,0x7afd00f1,0x387e801b,0x31600187}},	//   _štud, ërti, _petr_, _juiz_,
   {{0xa2a5001b,0x316000b9,0x2f1a80eb,0x69c44abc}},	//   _काभ्, _muiz_, mīgi_, _msie,
   {{0xb9068105,0x6b632c39,0x64a34abd,0x3ead926c}},	//   _बच_, _акса, _шара, ffet_,
   {{0x78a9003a,0x3ea03b06,0x8c43425e,0x758a8009}},	//   đevi, ngit_, _ресе, осов_,
   {{0x44384abe,0xb8f480ab,0x2f1a80eb,0x78bc4abf}},	//   _hyr_, _হক_, nīgi_, kerv,
   {{0x62808020,0x6efc82be,0xb143802e,0x690904e8}},	//   _hemo, _déba, _анул, nžet,
   {{0x78bc01eb,0x38cb80d5,0xaad002f1,0x7cedcac0}},	//   derv, _باقی_, _तोहक, _púrr,
   {{0x60c8cac1,0x44384ac2,0xed5a95be,0x25a904e8}},	//   _hadm, _myr_, _дод_, ytal_,
   {{0xe707826a,0x5ea38065,0x645c4ac3,0x5573902a}},	//   _تسلی, _شمول, _ogri, _агіт,
   {{0x672d812b,0x645c2c04,0xa3de000d,0x25a9016d}},	//   čaje, _ngri, तमा_, vtal_,
   {{0x403419b8,0x69094ac4,0xdb190118,0xd5c880ff}},	//   верс, džet, _esvá, _hề_,
   {{0x6d588019,0x25a94ac5,0x3ea015d4,0xd5c88129}},	//   _hiva, ttal_, ggit_, _kề_,
   {{0x7cff879f,0x60da80c9,0x7cf24ac6,0x9f340163}},	// [3590] _wêre, _ontm, _læru, теті,
   {{0x44384ac7,0x3f9c82ec,0x7aed4ac8,0x3d940758}},	//   _byr_, kuvu_, _hoat, тифр,
   {{0x62809e12,0x6722cac9,0xd5c88129,0x44381a25}},	//   _bemo, _ojoj, _lề_, _cyr_,
   {{0x6d58caca,0x44381da3,0xbcfb00e7,0xdced0279}},	//   _liva, _dyr_, _québ, mpač,
   {{0x7aed01e0,0xa069cacb,0x31600118,0x7d088084}},	//   _moat, пала_, _xuiz_, _kūrė,
   {{0x628082c4,0x7aed4acc,0x44384acd,0x60c8bf6f}},	//   _eemo, _loat, _fyr_, _cadm,
   {{0x6ef58acf,0x6d47026c,0x2d4d0088,0x6efccace}},	//   _hábi, _ihja, _džet_, _séba,
   {{0x6280837a,0x6d58cacf,0xa3cd84c5,0x60c88118}},	//   _gemo, _aiva, रिस_, _eadm,
   {{0x79a4b312,0x6d58cad0,0x2d894ad1,0x6abd0261}},	//   _архе, _biva, nsae_, desf,
   {{0x620183bf,0x3eadcad2,0x6d58cad3,0x6b650084}},	//   ızlı, sfet_, _civa, _jėgo,
   {{0x7c958077,0x290300f1,0x78bc0be7,0x6ef58187}},	//   وشگا, dhja_, verv, _lábi,
   {{0xe1ff157a,0x6d58c6f0,0x2e4e819d,0x78bc4ad4}},	//   rcón_, _eiva, _kọlọ_, werv,
   {{0x6d470009,0x6d588901,0x99d60019,0x2bb18074}},	//   _ohja, _fiva, رتحا, _जहवा,
   {{0xa3c12418,0x64a5c3e8,0x6ef580f7,0x6d58cad5}},	//   ्टा_, _чака, _sábh, _giva,
   {{0x657d0032,0x0ea686a7,0x656f0c0b,0xfc648081}},	//   _awsh, क्कड, _atch, _ръчн,
   {{0xdbd718c5,0x6443cad6,0xc4c60077,0x7aed4ad7}},	//   _määr, _izni, کترو, _goat,
   {{0x628600a4,0x443e202e,0x6280cad8,0x44384ad9}},	// [35a0] mako, _št_, _remo, _syr_,
   {{0x6280859c,0x62864ada,0x2ebd816f,0x2f1a80eb}},	//   _semo, lako, ्युत, rīgi_,
   {{0x62808057,0x6ef580f7,0x60c8812b,0xbcfb041c}},	//   _pemo, _tábh, _radm, _suéc,
   {{0x869a0364,0x22288077,0xed5a1faa,0xe3631b4d}},	//   _этот_, وزشی_, _ном_, укци,
   {{0x62809e31,0x60c889c4,0x395a4adb,0x260fab28}},	//   _vemo, _padm, _kips_, _तेली_,
   {{0x7faa8085,0xc0e38c4f,0x62864adc,0xb86680d7}},	//   _həqi, лочк, hako, راتو,
   {{0x8c430c8e,0x6280cadd,0x443e0019,0xddcd0289}},	//   _бере, _temo, _át_, mbaš,
   {{0xd5e28032,0x6d58cade,0xa6aa81a8,0x03d701c6}},	//   _afó, _siva, سابق_, _אולם_,
   {{0x6d588669,0x644380ee,0x7ced9e31,0x7aed0162}},	//   _piva, _azni, _púrp, _roat,
   {{0xd5c88142,0x81e600ab,0x81b380ab,0xc42a9bd8}},	//   _về_, পনা_, টিশ_, зюме_,
   {{0x7aed0c6e,0x6d58cadf,0xa2d58072,0x6abd039c}},	//   _poat, _viva, णाच्, tesf,
   {{0x81b380c8,0x78a5026f,0x6aa2cae0,0x62864ae1}},	//   টির_, _schv, ngof, gako,
   {{0x6f0401e4,0x6d58cae2,0xdc12a353,0xee3ac792}},	//   dhic, _tiva, rşım, _энд_,
   {{0x395a3ec8,0xa3cd9a8f,0x248587f1,0x7cf2006a}},	//   _cips_, रिश_, calm_, _mærs,
   {{0x7aed0c6e,0x628639d8,0xa2d80c78,0xddcd026c}},	//   _toat, bako, याख्, dbaš,
   {{0x290300f1,0x6f04342a,0x643b8039,0xdc3b84de}},	//   shja_, ghic, _מעונ, _מעור,
   {{0xdd940196,0x65943811,0x3d941a07,0x7faa8085}},	// [35b0] латы, лату, литр, _dəqi,
   {{0xac272e87,0xbcfb026b,0xa3e20035,0x2f1a81a9}},	//   нфек, _atér, _गपशप_, mīgu_,
   {{0x2d890609,0x29014ae3,0x80a49107,0x6efc83a8}},	//   ssae_, _ilha_, च्छे, _nébo,
   {{0x91bf81ce,0x9e150112,0x6f044ae4,0x59bf909b}},	//   _एनआई, _адмі, chic, _एनआर,
   {{0x3f8c826c,0x2b490c41,0xdb1c8019,0x2d8b01a1}},	//   _avdu_, _mhac_, _arró, _uvce_,
   {{0x62864ae5,0x6e398428,0xdbd725ac,0x395a07f1}},	//   zako, _rywb, _päär, _xips_,
   {{0x62864ae6,0x7cf23ea6,0x6efc89c4,0xafe58084}},	//   yako, _vært, _cébo, тойл,
   {{0xdbd7043d,0x7cf20125,0x25b900b9,0x2b4900ff}},	//   _väär, _færs, _kpsl_, _nhac_,
   {{0xe7f38f21,0xdb1c80ab,0x290103a7,0x26cb4ae7}},	//   _अथवा_, _erró, _olha_, _maco_,
   {{0x6b5e80eb,0x673b8968,0x6286019e,0xd9559190}},	//   _līgu, sluj, wako, _شناخ,
   {{0xe29a12a0,0x62864ae8,0xaadd0aed,0xdce42cf6}},	//   ман_, tako, यांक, spić,
   {{0x6443803e,0x46128180,0x2b494ae9,0x26cb4aea}},	//   _vzni, اویر, _chac_, _naco_,
   {{0xed4eacb8,0x62863581,0x28de0327,0x2485caeb}},	//   _во_, rako, मालि, palm_,
   {{0x62864aec,0x7c878878,0xf487a109,0xdd92004e}},	//   sako, _чуде, _чудн, یوز_,
   {{0x6f0414f2,0xdb02002a,0xe73a0572,0x25ada306}},	//   thic, atlá, дев_, ltel_,
   {{0x3ebf81ec,0x7cf201fa,0x07a30073,0x7b119e51}},	//   neut_, _nærr, јатн, sťuj,
   {{0x6609829b,0xe8120768,0x7bd54aed,0x68470118}},	// [35c0] nzek, _डेरा_, _arzu, _pédí,
   {{0x67248fda,0x6f044aee,0xbcfb0036,0xdbe48091}},	//   čiji, shic, _stér, _bèèr,
   {{0x29184aef,0xe0fb03c8,0x261883eb,0x6ef84af0}},	//   mira_, _חליל, _बेनी_, _líbi,
   {{0x69d608cf,0x29180c56,0xe6bd816f,0xdb1c8722}},	//   _krye, lira_, ्योज, _arrò,
   {{0x4aaa0076,0xe894a380,0x62844af1,0xa2a504c5}},	//   _कानव, галь, _meio, _कास्,
   {{0x29184af2,0x66098029,0x81b380c8,0x69c2874c}},	//   nira_, dzek, টিং_, rwoe,
   {{0x0fe08a49,0x7cf215f8,0x38cb87d2,0xebe3006d}},	//   বন্ধ, _færr, بانی_, _корп,
   {{0x6d5c4af3,0x29184af4,0xa3c10128,0x69d62928}},	//   _hira, hira_, ्टर_, _orye,
   {{0x29184af5,0x6f030012,0xf1aa8077,0x28e2809a}},	//   kira_, _înce, _تازه_, पादि,
   {{0x6d5c4af6,0x672d8052,0x29181b61,0x64434af7}},	//   _jira, čaja, jira_, żnie,
   {{0x29184af8,0x3ebfcaf9,0xdc9b007c,0x69d62e08}},	//   dira_, beut_, וייל, _arye,
   {{0x29180548,0x6d5c4afa,0x65628198,0x200a0140}},	//   eira_, _lira, _tuoh, dzbi_,
   {{0xc3338051,0x65948087,0x25adb673,0x69d607f1}},	//   שור_, _салу, ctel_, _crye,
   {{0x29184afb,0xa2a51da7,0x26cb04f0,0x853000fc}},	//   gira_, _काव्, _saco_, buɗi,
   {{0x19580110,0x6f02cafc,0x26cb1ee8,0x5433815b}},	//   тары_, _kloc, _paco_, _پرور,
   {{0x25a01301,0x6d5c010a,0x6ef58207,0x69d6028c}},	//   fuil_, _aira, _fábu, _frye,
   {{0x29184afd,0x2f1a81a9,0x2369877b,0x69d64afe}},	// [35d0] bira_, līgs_, _čaji_, _grye,
   {{0x29184aff,0x6f02c99f,0x7afd44eb,0x6d5c01b4}},	//   cira_, _lloc, lkst, _cira,
   {{0xa2d8053e,0x6d5c4b00,0x2bd5809a,0x2d4d0668}},	//   याच्, _dira, धिया, _džep_,
   {{0x7afd4b01,0x26c0041c,0x6d5c4b02,0xbddb010c}},	//   nkst, ceio_, _eira, _nyèg,
   {{0x6d5c4b03,0x442a0118,0x99158d8e,0x7bd5009a}},	//   _fira, _exb_, лькі, _wrzu,
   {{0x6d5c146f,0x7c3c0125,0xa5da00be,0x6f028087}},	//   _gira, _fyrr, _אַלי, _aloc,
   {{0x6f02abe8,0x6e3d031d,0x7c3c0114,0x46aa001b}},	//   _bloc, _hysb, _gyrr, ङ्कह,
   {{0x660980ad,0x25adcb04,0x29184b05,0x7e6d0867}},	//   tzek, ttel_, zira_, ncap,
   {{0x6d4a8013,0x29180e4d,0x25ad8e61,0x6d5c0079}},	//   _bhfa, yira_, utel_, _yira,
   {{0x6609cb06,0x2ed0000f,0x25ad92af,0x291801df}},	//   rzek, _हफ्त, rtel_, xira_,
   {{0x25adcb07,0x66098019,0x7e6d008e,0x29079a2c}},	//   stel_, szek, kcap, mhna_,
   {{0x7f5d0609,0x6f02cb08,0x29182cc9,0xaca3819d}},	//   _nisq, _gloc, wira_, _krịk,
   {{0xa2a5085d,0xe4c8815b,0x7e6d0299,0x62844434}},	//   _कार्, ربین_, dcap, _veio,
   {{0x361a8158,0x6f028052,0xa2d4090f,0xef19a3b3}},	//   _אונד, _zloc, _बोर्, liż_,
   {{0x29184b09,0x7f5d4b0a,0x60260098,0x6d5c4b0b}},	//   rira_, _bisq, удва, _rira,
   {{0xbcfb4b0c,0xef1981b9,0x6ef5841c,0x7faa811c}},	//   _quén, niż_, _tábu, _təqv,
   {{0x29184b0d,0xb90a00c8,0x2569cb0e,0x7f5d4b0f}},	// [35e0] pira_, _মত_, _júl_, _disq,
   {{0xb5fb0118,0x6d5c4b10,0x26c00187,0xee374aa5}},	//   _afás, _qira, seio_, уну_,
   {{0x6d5c4b11,0x9f5800f1,0x290781e4,0x656983ed}},	//   _vira, nyrë_, dhna_, hqeh,
   {{0x6d5c2c06,0x7e6d01e8,0x7cf68162,0x5c3683de}},	//   _wira, ccap, _hârt, ארען_,
   {{0x6d5c4b12,0x25a00661,0x427b00be,0x98a7cb13}},	//   _tira, quil_, גאנג, zoną_,
   {{0x6724003a,0xa3e3800d,0xbebb00f1,0xa3d692ee}},	//   lnij, नमा_, _njëj, सिम_,
   {{0xc5f18a49,0x6f02aadc,0xa2a52177,0x6d4781cd}},	//   _জেলা_, _ploc, _काल्, ċjal,
   {{0x6d4a80f1,0x672401cd,0x6566005d,0xa6f48162}},	//   _shfa, nnij, _kukh, рзиш,
   {{0x94868162,0xe9da835f,0xb226aee8,0x443c854f}},	//   лынд, _яка_, _смал, _syv_,
   {{0x38c8819f,0x65664b14,0x2907801b,0x6724026c}},	//   _جاری_, _mukh, chna_, hnij,
   {{0xdb020bd7,0x5ea68019,0x6f028369,0x4c9b00be}},	//   ktlä, _ممال, _tloc, עשטע,
   {{0x67240025,0xe45700be,0x8aff0041,0x2f1a80eb}},	//   jnij, טייט_, _buƙa, rīgs_,
   {{0x7f5d02be,0x92580198,0x0eab00c2,0xb69b0493}},	//   _risq, лают_, _छाबड, _blân,
   {{0xbcfb0144,0x98a78084,0xbebb03ed,0xbd029517}},	//   _cuél, poną_, _gjëj, _šéfr,
   {{0x395e910f,0xffe4104b,0x7e6d0580,0x7d1acb15}},	//   _mits_, бютн, tcap, mits,
   {{0x7d1acb16,0xc8780059,0xeafb003d,0x2bc8016f}},	//   lits, ığa_, _سرعت_, रबना,
   {{0xd49b023a,0x7e6d10e1,0x2d8f0019,0xb5fb0091}},	// [35f0] ере_, rcap, ége_, _afár,
   {{0x7d1acb17,0x65664b18,0x395e823e,0x3f9c8699}},	//   nits, _dukh, _nits_, krvu_,
   {{0x67244b19,0x7faa8201,0x9c4701b5,0x1cb815a9}},	//   bnij, _məqs, ухал, طالب_,
   {{0x67240052,0x7e62cb1a,0x7d1acb1b,0x2d8d857b}},	//   cnij, _ngop, hits, ysee_,
   {{0xdd0107d9,0xef1984b7,0x7cdb00eb,0xd49b0073}},	//   ştır, viż_, _pārē, _прв_,
   {{0x69c9807a,0x7e6280e5,0x395e81a9,0x6ce7426b}},	//   _vsee, _agop, _cits_, _сіме,
   {{0x80ad2af8,0x7d1acb1c,0x395e9b0d,0xbebb0168}},	//   _जाने, dits, _dits_, _njëk,
   {{0xb8fccb1d,0x4975cb1e,0x69c990af,0x2d8d8c04}},	//   _तो_, _влас, _tsee, tsee_,
   {{0x7bd88006,0x660d24e1,0x09b88277,0x628bcb1f}},	//   _arvu, nzak, _مطلع_, mago,
   {{0x7d1acb20,0x5f958098,0x2d8d8c4d,0x7b164b21}},	//   gits, _вижт, rsee_, ršum,
   {{0xd8748060,0x04458c8e,0x2905cb22,0x3b0a0ae7}},	//   _طالب, ренн, _illa_, вено_,
   {{0x60c38179,0x628bcb23,0x216a0b88,0x25698019}},	//   lenm, nago, кими_, _túl_,
   {{0xfce5cb24,0x6ef59313,0x67240025,0x7bcacb25}},	//   _воло, _fábr, vnij, _esfu,
   {{0x81b800c8,0x26cf9143,0x393601e5,0x660d4b26}},	//   ছিল_, _hago_, рэмс, dzak,
   {{0x67240025,0xb8ee0c2d,0x628ba2ce,0x26cfcb27}},	//   tnij, _रस_, kago, _kago_,
   {{0x6f0980a9,0x26cfcb28,0x2caa008e,0x6ef5816b}},	//   nhec, _jago_, _scbd_, _zábr,
   {{0x29058181,0x6724012b,0xa3cd8ebf,0x6da611f3}},	// [3600] _olla_, rnij, रिक_, риза,
   {{0x67240025,0xb4c2053e,0x80ad45d2,0x6d41831d}},	//   snij, ्ये_, _जाये, nlla,
   {{0x24878f23,0x6d41cb29,0x6cd31a3e,0x389b03c8}},	//   _menm_, illa, تقلا, _ביינ,
   {{0x2905cb2a,0x628bcb2b,0x7d1acb2c,0xe29acb2d}},	//   _alla_, gago, zits, тад_,
   {{0x395e82e6,0x6f030087,0x7d1a8ab4,0x28e28bc2}},	//   _pits_, _înca, yits, पालि,
   {{0x3f9cb6b7,0xaca3819d,0x89da826a,0x26cf8091}},	//   trvu_, _brọk, _یوزر_, _aago_,
   {{0xb8cec5d2,0x7b240052,0x26cf82b8,0x628bcb2e}},	//   _का_, rđuj, _bago_, bago,
   {{0xd6d7ca44,0x2905cb2f,0x6d41cb30,0xa8570039}},	//   ать_, _ella_, ella, סיקה_,
   {{0x26cf811e,0x10a6835f,0x7d1acb31,0xc0e69b56}},	//   _dago_, _визн, tits, _коак,
   {{0x6208807e,0x60c3cb32,0x6296038a,0xdb0209c4}},	//   ırlı, cenm, _adyo, lulè,
   {{0x7d1acb33,0x80c50f12,0x26cf83a8,0x660d4b34}},	//   rits, ाजसे, _fago_, zzak,
   {{0x6d41cb35,0x291ccb36,0x7d1acb37,0x26cfcb38}},	//   alla, liva_, sits, _gago_,
   {{0x7bda0bcf,0x26c4cb39,0xb5fb0032,0x8b57807c}},	//   _štul, memo_, _agán, ייטס_,
   {{0xb4c2000d,0x29050125,0x291ccb3a,0x7cf68087}},	//   ्यो_, óla_, niva_, _vârs,
   {{0xb4c201d0,0x9b9488ca,0x26cf8091,0xdb0b006a}},	//   ्यै_, _البت, _yago_, _opfø,
   {{0x27ed003b,0x660d011e,0x2fcd009a,0x6d4e260b}},	//   ćen_, tzak, łego_, _ahba,
   {{0x60c3b99e,0x798404b9,0x224902d0,0x291ccb3b}},	// [3610] yenm, _gwiw, _uzak_, kiva_,
   {{0x61fd21aa,0x660d4b3c,0x6efc8eba,0xe1ff009a}},	//   mysl, rzak, _débi, wców_,
   {{0x660d0019,0x60c3cb3d,0x26188074,0x9f3505a8}},	//   szak, venm, _बेसी_, _гені,
   {{0xf21c000f,0xaefb0706,0x6e32128a,0xf21281bc}},	//   _पेड़_, _diùc, _žebř, rọnọ,
   {{0x6d41cb3e,0x60c3cb3f,0x26cfcb40,0xa9c78087}},	//   ylla, tenm, _rago_, рсек,
   {{0x628bacda,0x3169083a,0x291c8037,0x7c280088}},	//   sago, _muaz_, giva_, _ždre,
   {{0x26cfa018,0x260f823c,0x628bcb41,0xa2d8816f}},	//   _pago_, _तेजी_, pago, _नोव्,
   {{0x3ea91904,0x53348328,0x3eb9808b,0x0d858ba8}},	//   ngat_, _дест, ýst_, блин,
   {{0x20c78364,0x291ccb42,0xc33280be,0x98c79630}},	//   _всег, biva_, _זון_, _всел,
   {{0xdb1c83d3,0xa5da00be,0x6aad01a1,0x6f098144}},	//   _aprè, אַטי, _acaf, shec,
   {{0x63a50057,0x2bda009a,0x26cfcb43,0x673d02f1}},	//   nuhn, णिया, _tago_, _oksj,
   {{0x26c490d3,0xc86900be,0x442e81e0,0x6d41c9e8}},	//   cemo_, _טן_, _dxf_, slla,
   {{0xdb024b44,0x6abb81bc,0x61fd0196,0x248782d6}},	//   nulé, _mbuf, gysl, _tenm_,
   {{0xcd768039,0x673d00e8,0xa9670f9c,0xed4480e8}},	//   _העסק_, _aksj, сира_, _дніп,
   {{0xa3cd85b3,0xd0072006,0x69cd0cdb,0x6abbbe3e}},	//   रिओ_, бере_, _esae, _obuf,
   {{0x291c82a5,0x98a7809a,0x3ea94b45,0x753c14df}},	//   ziva_, ronę_, ggat_, _skrz,
   {{0xc27b0039,0x10a600e8,0x98a62626,0xaefb0a2a}},	// [3620] _גרפי, _липн, _липе, _siùc,
   {{0x26c4cb46,0x6abbcb47,0x7af601e0,0x88ca0c4f}},	//   zemo_, _abuf, _hoyt, _слов_,
   {{0xcfea03f8,0x63a50867,0x26c480b4,0x25b20123}},	//   _صفحه_, guhn, yemo_, styl_,
   {{0xfaa6a0e4,0x69db8625,0xddc981d6,0x7ae40609}},	//   садо, _brue, dbež, _jnit,
   {{0xdce28052,0xd946902f,0x61469df3,0xd91a89c7}},	//   _suoč, беди, беда, льк_,
   {{0x63a532bb,0x26c4a8ba,0x6abbaa34,0x291a00b9}},	//   buhn, wemo_, _ebuf, _jmpa_,
   {{0x291cbc9e,0x7ae40091,0x26c48314,0xa3bc03ca}},	//   riva_, _onit, temo_, _अहि_,
   {{0xa3d6946d,0xc6f8a4c1,0xe8d900ff,0x69db888a}},	//   सिस_, рних_, _tuệ_, _frue,
   {{0x26c4cb48,0x249800b9,0x69dbcb49,0x291ccb4a}},	//   remo_, _kdrm_, _grue, piva_,
   {{0x6aad383e,0x26c4cb4b,0x7d1e02d5,0xbf0500a5}},	//   _scaf, semo_, nips, _रत्न_,
   {{0xb5fb0118,0x25a00d8b,0x261885fc,0xdb1ccb4c}},	//   _agál, hril_, _बेरी_, _apré,
   {{0xa3cd86a7,0x291a4b4d,0x69cd0118,0x7ae40362}},	//   रिज_, _ampa_, _psae, _cnit,
   {{0x4aaa0c78,0x7d1e4b4e,0x2d9fcb4f,0xaaaa0744}},	//   _कारव, kips, crue_, _कारक,
   {{0x7ae42f3a,0x25a04b50,0x2d92067f,0xf1270c5c}},	//   _enit, dril_, dsye_, сьмо,
   {{0x28de1a4d,0x24b78039,0x76428681,0x236a010c}},	//   माजि, _ההון_, _hyoy, _nubj_,
   {{0x69c0838e,0x3ea90087,0xf99f03ec,0x764283f7}},	//   _opme, ugat_, prè_, _kyoy,
   {{0x7bdc473f,0xd0d50098,0xddc99024,0x44f50bba}},	// [3630] _arru, _допъ, zbež, опас,
   {{0x04671bbf,0x8c671e0b,0x63a50b20,0x753a8f3e}},	//   стам, стад, tuhn, notz,
   {{0x69c08029,0x7f444b51,0xbc4b0150,0x645a4b52}},	//   _apme, bliq, учае_, _útil,
   {{0x69db85b4,0xa294835f,0x63a5010b,0x672d9be7}},	//   _prue, заці, ruhn, čajk,
   {{0x6f0d061f,0x63a509ca,0xe1ff439d,0x7bdc0102}},	//   mhac, suhn, nyó_, _erru,
   {{0x28ad0743,0xf7718250,0x63a500c3,0x6f0d07b6}},	//   ञ्चि, واب_, puhn, lhac,
   {{0x7762cb53,0x764284b9,0x628f21e6,0x37868081}},	//   _biox, _ayoy, kaco, общо_,
   {{0x6d454b54,0x2d95ac18,0x69db8257,0x6abb9d8b}},	//   llha, орос, _true, _ubuf,
   {{0x29034b55,0xd629cb56,0xdd8e80a0,0x76428db1}},	//   kkja_, ропе_, نوي_, _cyoy,
   {{0x26d980e1,0x7af64b57,0x753a811b,0xdb059d5b}},	//   ôsob_, _soyt, gotz, sthä,
   {{0x02c61194,0x25a000b9,0xddc28035,0x7642cb58}},	//   ойно, zril_, _czoł, _eyoy,
   {{0x7bda00cd,0x6b9c8661,0x628f4b59,0x25a0113b}},	//   _štuk, árga, gaco, yril_,
   {{0x6f0d4b5a,0xa96a047f,0x2d4d1f79,0x3204016b}},	//   dhac, рига_, _džez_, ámy_,
   {{0x6efc82be,0x6729cb5b,0xb4e80327,0x320c066f}},	//   _débu, lnej, _मचे_, ądy_,
   {{0x656bcb5c,0xd9430012,0xbf0511bc,0x6b650110}},	//   _hugh, фери, रसून_, _mėgs,
   {{0x7ae43bf6,0x6f0d0870,0x656b8c53,0x6729cb5d}},	//   _unit, ghac, _kugh, nnej,
   {{0x6563cb5e,0x2498293f,0x80a50019,0x20110037}},	// [3640] _kinh, _pdrm_, _کمپن, azzi_,
   {{0x25a046da,0x6563cb5f,0x6443b6d4,0xdca30adb}},	//   rril_, _jinh, _kyni, дафи,
   {{0x6563cb60,0x7d1e25e0,0x7f444b61,0x656bcb62}},	//   _minh, rips, pliq, _lugh,
   {{0xe9daaae3,0x6563c539,0x6f0d4b63,0x6729cb64}},	//   ике_, _linh, chac, jnej,
   {{0x68f70201,0x7762802a,0x6d450114,0x752895d8}},	//   _yoxd, _riox, blha, yndz,
   {{0x628f21fa,0x1d0a24b6,0xf8068009,0x224d8b67}},	//   zaco, _теги_, жчин, _dzek_,
   {{0xe3a78416,0x224d8019,0xeb971b4d,0x28b20f3d}},	//   _تر_, _ezek_, _мир_, _जानि,
   {{0x644e0ee1,0x656bcb65,0x63b303c1,0xe1faa5f5}},	//   _izbi, _bugh, žení, _кгб_,
   {{0x6563ac8c,0x62829151,0x64439428,0x3cf80589}},	//   _binh, mboo, _ayni, _korv_,
   {{0xa3d685e8,0x2b46823e,0x32d700ff,0x656bcb66}},	//   सिल_, lloc_, _ủy_, _dugh,
   {{0x6563c6e6,0x64438114,0x6729875f,0x628f4b67}},	//   _dinh, _cyni, bnej, taco,
   {{0x6563cb68,0x672981ac,0x644381e6,0x753a8102}},	//   _einh, cnej, _dyni, sotz,
   {{0x628f0a7a,0x7d1c026c,0x753acb69,0x6563cb6a}},	//   raco, _omrs, potz, _finh,
   {{0x644e0025,0x65639acd,0x628f24df,0x6282cb6b}},	//   _ozbi, _ginh, saco, hboo,
   {{0x6f0d125b,0x6282cb6c,0x20051dc5,0x60c74b6d}},	//   thac, kboo, áli_, rejm,
   {{0x442d003a,0xe7f280cf,0x443100ee,0x29034b6e}},	//   _će_, _अपना_, _rxz_, skja_,
   {{0x200527da,0x6d45112e,0x63a884ef,0x644e00fc}},	// [3650] šli_, tlha, ludn, _azbi,
   {{0x6729a840,0x7c280bcf,0x62829447,0x6563cb6f}},	//   znej, _ždra, eboo, _xinh,
   {{0x63a8807a,0x62829e12,0xa2a5152c,0x290eab8c}},	//   nudn, fboo, _काञ्, dhfa_,
   {{0x6282cb70,0x672901a1,0xddcd4b71,0x7d1c05ee}},	//   gboo, čejs, mbaž, _emrs,
   {{0x6729a1f6,0x63a8cb72,0x28b2064a,0xed5b0180}},	//   vnej, hudn, _जामि, _نشست_,
   {{0x656bcb73,0xb17c04de,0x98aa01d0,0x69dd8118}},	//   _rugh, סטור, době_, _ásem,
   {{0xa2ac035a,0x6729cb74,0xe8d9019d,0x3d00016f}},	//   _झाल्, tnej, _gwụ_, _शकते_,
   {{0x0d859dba,0x656ba881,0x63a8a6e9,0x2b46a161}},	//   плин, _pugh, dudn, cloc_,
   {{0x6443c66c,0x67298165,0x65638187,0xb3648081}},	//   _syni, rnej, _pinh, _църк,
   {{0x6729a02e,0xe6168e11,0x656bcb75,0x2b400af8}},	//   snej, яды_, _vugh, _skic_,
   {{0x6563cb76,0x6f1d00f3,0x628d0362,0xbb460254}},	//   _vinh, _omsc, _beao, зенк,
   {{0x6443850f,0x7d0acb77,0x798994ee,0x691006ae}},	//   _vyni, _elfs, _kwew, _käeg,
   {{0x55e581a1,0x25a913b8,0x6563c539,0x64438063}},	//   _холб, jual_, _tinh, _wyni,
   {{0x3eadcb78,0x63a8c36b,0x25a94b79,0x4dda81c6}},	//   lget_, budn, dual_, _לחנו,
   {{0x6f040668,0x3ce899a1,0x6282cb7a,0xbebb0168}},	//   tkic, जारे_, yboo, _njës,
   {{0x3eadb9d2,0x7d1c011f,0x628281e0,0xdce60da8}},	//   nget_, _smrs, xboo, _vukč,
   {{0x6f0400d2,0x316d8388,0xf6510019,0x7989838a}},	// [3660] rkic, _nuez_, ہئے_, _nwew,
   {{0x6f044b7b,0x6282c762,0x600a0791,0xd88400d7}},	//   skic, wboo, _гном_, _تهدی,
   {{0xc9530039,0x798982e9,0x5fe04b7c,0xe0fb025f}},	//   _רמת_, _awew, _पछिल, _הליל,
   {{0xcfc380c8,0x25a90748,0x798983f7,0xe2979541}},	//   ্মান, bual_, _bwew, зац_,
   {{0xd9469c39,0x3eadcb7d,0x6282cb7e,0x237f005c}},	//   педи, dget_, rboo, _čuje_,
   {{0x673b4b7f,0x2d804b80,0x69c403a8,0x7bc3cb81}},	//   čuje, mpie_, _mpie, _opnu,
   {{0x6282a338,0x2b4681e0,0xab648192,0x2ca7016a}},	//   pboo, ploc_, grüß, ónde_,
   {{0x3ead8f06,0x3da69033,0x69c40dee,0xb2268012}},	//   gget_, проб, _opie, _ембл,
   {{0xa0a68084,0x96349ff8,0x5d549182,0x316d83c9}},	//   _наад, ьниц, мкит, _guez_,
   {{0xcb98835f,0x63a8822b,0x48d70264,0xa61701c6}},	//   ової_, tudn, _সক্র, פקיד_,
   {{0xa9f7000d,0x5335151c,0x6efc8036,0x68e88366}},	//   ुन्छ_, дент, _débr, _indd,
   {{0x63a8850a,0x68facb82,0x61e09502,0xcb0b1e42}},	//   rudn, _hotd, _krml, сход_,
   {{0x76460009,0xaefb0229,0xc6938e82,0xa6b40264}},	//   _nyky, _diùl, _נאס_, ুযায়,
   {{0xa3df0935,0xbebb00f1,0xd90f0077,0x61e080c3}},	//   तिम_, _njër, اید_, _mrml,
   {{0xc7c40db6,0x4fc40a9f,0xdb1ccb83,0x1cbb84de}},	//   нсти, нста, _aprí, _המוע,
   {{0x6d48cb84,0x25a94b85,0xdb1c81a8,0x64430035}},	//   llda, tual_, _bprí, żnik,
   {{0xa63400e8,0x69dd8187,0xf1b118a9,0xe3b8807e}},	// [3670] енті, _àsex, _जमिन, ltı_,
   {{0x4d980a41,0x64c7052a,0x291e8db1,0x68fa8799}},	//   якую_, रजेश, _nmta_, _notd,
   {{0x28b21e4b,0xe3b883bf,0x3ead8106,0x25a94b86}},	//   _जाति, ntı_, yget_, sual_,
   {{0xf1b1000f,0x290ccb87,0x6f1d0192,0xa3d481a2}},	//   _जमान, _alda_, _umsc, _हनन_,
   {{0xeab081a8,0x672d0822,0x964725f5,0xa9f981d0}},	//   اعم_, mnaj, _хэнд, ्नेछ_,
   {{0xd0450201,0xe3b88457,0xbebb00f1,0x3e7c01d0}},	//   _sahə, ktı_, _gjër, rátů_,
   {{0xb8d5acfc,0xdfce80f7,0x656f4b88,0x60d70df6}},	//   _झा_, ليو_, _huch, _maxm,
   {{0x656f4b89,0x6d5a8640,0xe5799e0b,0xfbd20039}},	//   _kuch, emta, ози_, _בתל_,
   {{0x51878098,0x3eadc2fa,0x61e0812b,0x7ae9cb8a}},	//   _хуба, rget_, _grml, _inet,
   {{0x656f1220,0x69dd0353,0x7afb838e,0x2f23826b}},	//   _much, dvse, _hout, _bègè_,
   {{0x656f4b8b,0x69c44b8c,0x7afb8247,0xfaa60993}},	//   _luch, _spie, _kout, мано,
   {{0x6d48cb8d,0x6f03002e,0x7afb8009,0x656f4b8e}},	//   alda, _înch, _jout, _ouch,
   {{0x657d01e9,0x60d70085,0x68e88114,0xd706804a}},	//   _ntsh, _baxm, _yndd, _інше_,
   {{0x6606804a,0xdce280e1,0xbcfb0144,0xa3c2170c}},	//   økke, _zvoľ, _mués, ्बम_,
   {{0x7ae9811b,0x1867164f,0xdb1c80e1,0xa067030d}},	//   _onet, дари_, _sprí, дара_,
   {{0x656f4b8f,0x7afbcb90,0x69c01238,0x7ae985ee}},	//   _buch, _nout, çmes, _nnet,
   {{0x656f247e,0x2bd580c2,0xf7430993,0x60d700f5}},	// [3680] _cuch, धिका, тето, _faxm,
   {{0x656f0a7a,0x7ae98217,0x2d80002f,0x80bf8035}},	//   _duch, _anet, rpie_, ल्मे,
   {{0x7afbaeef,0x6d4380b9,0x628601c0,0x8e86266e}},	//   _bout, _mkna, obko, _огне,
   {{0x2bf68158,0xe51dac5d,0x7afbcb91,0x4e0d8441}},	//   ומען_, योति_, _cout, िनाई_,
   {{0x7afbcb92,0xfe420065,0xc69304de,0xb17b013c}},	//   _dout, _شکری, _באר_, rvåg,
   {{0x60c180b9,0x7ae9cb93,0xe3b8811c,0xbebb03ed}},	//   _cblm, _enet, ytı_, _ujër,
   {{0x7afbcb94,0xd01080f7,0x3320002a,0xe3b88085}},	//   _fout, طلة_, _omix_, xtı_,
   {{0x6d43cb95,0x7afbaaa5,0x7ae9cb96,0xd75781a8}},	//   _akna, _gout, _gnet, وجيا_,
   {{0x66044b97,0x68facb98,0xa3b089c8,0x3494b548}},	//   nyik, _totd, टून_, напр,
   {{0x672d0289,0x7afb8247,0xe3b88214,0xbcfb0661}},	//   znaj, _zout, ttı_, _huér,
   {{0x7afbcb99,0x2be10697,0x60d701b4,0x48eb80c2}},	//   _yout, फिया, _raxm, चारो_,
   {{0xe3af817e,0x38638019,0xdd8f803d,0xe3b8807e}},	//   گری_, _újra_, _چون_, rtı_,
   {{0x6ef5803e,0x672d807a,0xdd8f8a47,0x6abd007b}},	//   _náby, čajt, _نون_, rfsf,
   {{0xe3af80d5,0x656f0491,0xe3b882d0,0x61e48198}},	//   دری_, _ruch, ptı_, äily,
   {{0x656f4b9a,0xb88201ac,0x628608dc,0xc7b80a41}},	//   _such, _číta, bbko, мёт_,
   {{0xdcc70f21,0xa3db82f1,0x63a5016b,0x656701e9}},	//   रज्ञ, ठिर_, vrhn, _sijh,
   {{0xa3d69299,0x672d3937,0x7afbcb9b,0x5d554660}},	// [3690] सिक_, rnaj, _rout, екат,
   {{0x7afbcb9c,0x88c4009a,0x2fd303a8,0xdb020658}},	//   _sout, ęści, _tsxg_, mulá,
   {{0x7afbcb9d,0xfe700117,0x5695151b,0x656f4b9e}},	//   _pout, ادہ_, _пант, _wuch,
   {{0x224910fe,0x656f4b9f,0xd6d98035,0x3f8301b9}},	//   _kyak_, _tuch, koła_, mpju_,
   {{0xe66425f5,0x7bda0088,0x7ae9807a,0x2fc580b9}},	//   _атро, _štut, _vnet, _splg_,
   {{0x23690282,0xc9849da6,0xe8f88d13,0xe9d886cf}},	//   _liaj_, туци, млі_, ькі_,
   {{0x7afba2a7,0x26d94ba0,0xf7458293,0xbcfb0144}},	//   _tout, _kaso_, неко, _fuér,
   {{0x236901c5,0x26d90102,0x7ae9b131,0xdb024ba1}},	//   _niaj_, _jaso_, _unet, kulá,
   {{0x2d998065,0x26d94ba2,0x2d8b82be,0x2bd18a27}},	//   ése_, _maso_, èce_, _तनहा,
   {{0xf8078364,0xdb022825,0x26d94ba3,0x00000000}},	//   _очен, dulá, _laso_, --,
   {{0x8b2600af,0x8cc11199,0x798d3ad5,0x224902d0}},	//   едне, र्यो, _awaw, _ayak_,
   {{0x28b20576,0x236901c5,0x26d936ef,0x798d25d3}},	//   _जाहि, _ciaj_, _naso_, _bwaw,
   {{0xdca59383,0x64a59958,0xdb020f09,0xf1e283b6}},	//   _зали, _зала, gulá, पियन,
   {{0x2618823c,0x80bb000c,0x656fc906,0x22494ba4}},	//   _बेटी_, श्ले, íchu, _dyak_,
   {{0x26d94ba5,0x67244ba6,0x79828035,0x3e750133}},	//   _baso_, tiij, zpow, _ụta_,
   {{0x6d419aa7,0xdb1c826f,0xdcba0768,0xfe7981d0}},	//   lola, _oprá, ैज्ञ, nců_,
   {{0xe5a30aac,0x6da31a3b,0xdce381a1,0xada302df}},	// [36a0] лити, лита, _linč, латл,
   {{0x6d41cba7,0xaac1000d,0x02c103b6,0x8aff09ab}},	//   nola, ष्ठक, ष्ठभ, _duƙu,
   {{0x26d91c9f,0x660438e0,0x6616009a,0x25ad8216}},	//   _faso_, syik, szyk, huel_,
   {{0x6d41cba8,0xbcfb31cf,0x67240079,0xe29280f7}},	//   hola, _quér, qiij, اذا_,
   {{0x6d41c12e,0x61e20253,0x68fe4ba9,0xdced04b7}},	//   kola, _šolj, _kopd, ssaġ,
   {{0x6b51816d,0x6d418573,0x63ba90cc,0x2a6d826b}},	//   råga, jola, yttn, _egeb_,
   {{0x6d41cbaa,0xfaa681e2,0xdce38140,0x7cf68162}},	//   dola, _паво, _cinč, _târz,
   {{0x61e410ab,0x6e2d8b80,0xb1839c32,0xdce38b80}},	//   _oril, _žaba, šťan, _dinč,
   {{0x25adcbab,0x6d41adea,0xe2a6807b,0x6d5e1867}},	//   guel_, fola, æðum_, ompa,
   {{0x6d41cbac,0xe9d780e8,0x6b9c06ec,0x798d0a03}},	//   gola, _яку_, _kvrg, _rwaw,
   {{0x66e6aa04,0xdb1c800d,0x22490239,0xf8b39101}},	//   _пожа, _zprá, _syak_, _תשע_,
   {{0x201800b9,0x61e44bad,0x60dacbae,0xdb024baf}},	//   dzri_, _bril, _hatm, tulá,
   {{0x6d41cbb0,0x23694bb1,0x69068125,0xc3338039}},	//   bola, _viaj_, _aðei, רור_,
   {{0x6d41b7cf,0xa3c2123a,0xd0488085,0x2eeb0036}},	//   cola, ्बा_, _sadə, _sncf_,
   {{0x26d9040e,0x23690282,0x61e4037b,0xb4ac9834}},	//   _paso_, _tiaj_, _eril, गली_,
   {{0xdb0203b0,0xd6d80cf9,0xf7700019,0x61e42dc2}},	//   pulá, нту_, صاف_, _fril,
   {{0x6722822e,0x7aed4bb2,0xe573080b,0xe4a71b35}},	// [36b0] _mmoj, _inat, اطر_, ерео,
   {{0x6fe085b3,0xaab12cfc,0x63a8cbb3,0x81d68264}},	//   पटां, _झाँक, ordn, িমা_,
   {{0xdb1c8a56,0x26d94bb4,0x7aed007b,0x6b9aae99}},	//   _sprá, _taso_, _knat, nstg,
   {{0x6d41cbb5,0x66fb01ab,0x8aff00fc,0xa5a18035}},	//   zola, _एकटक_, _tuƙu, _खिलौ,
   {{0x7aed4bb6,0xe4a72369,0xdce3850b,0x25ad8036}},	//   _mnat, _прво, _sinč, xuel_,
   {{0x7f4d03e7,0xeafe0cf0,0x4438008e,0x60dacbb7}},	//   llaq, _उक्त_, _fxr_, _catm,
   {{0x6d41cbb8,0xe7399577,0x644ab032,0xaab106a7}},	//   vola, мек_, _nyfi, _झांक,
   {{0x25adcbb9,0xdce39fe9,0x64554bba,0x6d41cbbb}},	//   tuel_, _vinč, _izzi, wola,
   {{0x6d41cbbc,0x6f09810b,0x60dacbbd,0x200980eb}},	//   tola, rkec, _fatm, ņai_,
   {{0x7aed4bbe,0x270e159a,0x25ad957a,0x25a9020d}},	//   _anat, _सत्र_, ruel_, iral_,
   {{0x63a880d2,0x644a8114,0x25a900e1,0x6d588609}},	//   grdn, _cyfi, hral_, _dhva,
   {{0x6d41cbbf,0x74c10075,0x25a90b17,0x68fe02c4}},	//   sola, र्तृ, kral_, _sopd,
   {{0x6d41cbc0,0x25adc4df,0x1c1e035a,0x63a8808e}},	//   pola, quel_, _येईल_, ardn,
   {{0x7e7d4bc1,0x6d4181b4,0xe5a2954f,0xddc28115}},	//   _afsp, qola, _тиши, _ugoš,
   {{0x21670b9c,0xa9671878,0x764b8114,0x673b0390}},	//   тири_, тира_, _hygy, čujn,
   {{0x61e44bc2,0x69c9815f,0x7c2e8333,0x84648081}},	//   _tril, _opee, úbre, _съче,
   {{0x61e4002e,0x69c981c0,0x6b9c0289,0x0e664bc3}},	// [36c0] _uril, _npee, _svrg, ткан,
   {{0x7aed003a,0x2576237b,0xd9100117,0xc00617c8}},	//   _znat, _væl_, _ایس_, _апок,
   {{0xeb974bc4,0xa3df2967,0x7d03016d,0x6b51816d}},	//   вих_, तिष_, önsa, rågn,
   {{0x130a8190,0x60daa353,0xfaa68779,0x2aeb114f}},	//   ьней_, _satm, тадо, टाएँ_,
   {{0xceb30158,0xdb020bc5,0x827700be,0x161a064a}},	//   _דיר_, pulæ, דענע_, _नेचर_,
   {{0x92ce00ab,0x6b588531,0x8cc104c5,0x6722882c}},	//   রায়_, díge, र्दो, _smoj,
   {{0xdbcc007b,0xd00f80f7,0xc01000ff,0x2d9d82d6}},	//   _góða, يله_, _đuổi_, _avwe_,
   {{0x6d58803a,0xa3df2e04,0xceb40085,0x63a880fe}},	//   _shva, तिर_, ciət_, vrdn,
   {{0x32469ad3,0x94868162,0x60da9238,0x2127827d}},	//   _реаг, кынд, _tatm, binh_,
   {{0x6ad292ee,0xb4ac8d14,0x44f4813a,0x61e2829a}},	//   _ससुर, गले_, упос, mvol,
   {{0xe9ff8028,0x61e2cbc5,0x92954bc6,0xdb023d7f}},	//   _thảo_, lvol, ланц, kulä,
   {{0xdb9b010f,0x6722822e,0xf6268ab2,0x7e7bcbc7}},	//   וסטר, _umoj, _идео, ccup,
   {{0xf2d3893f,0x61e2907f,0x69dd81fa,0xceb381c6}},	//   בער_, nvol, _áset, _כיף_,
   {{0x6d58803b,0x25a90085,0xa8a4017c,0x3494cbc8}},	//   _uhva, vral_, ирск, _сакр,
   {{0xe7e5adb8,0x7f4d02a6,0x40350073,0xe8940110}},	//   किया_, tlaq, уевс, рась,
   {{0x7aed4bc9,0xb7db83c8,0x6d474bca,0x7528afbe}},	//   _unat, וקלי, _skja, lidz,
   {{0x273701cd,0x2d8f02be,0xe6640878,0x7e55004a}},	// [36d0] għna_, ège_, атфо, уває,
   {{0x58d50009,0x61e28696,0x2ba99869,0x7528a828}},	//   _соот, dvol, _किमा, nidz,
   {{0x69c9cbcb,0xdd86804e,0x7a0a81a9,0x2127827d}},	//   _spee, _گو_, _lētā, vinh_,
   {{0x25a94bcc,0x7b3c812b,0x6b518106,0x6f160ebf}},	//   pral_, jčud, rågo, chyc,
   {{0xdd86a003,0xf1bf4bcd,0x28c0000f,0x8d8744f1}},	//   _دو_, ntá_, श्वि, _шунд,
   {{0x6f0d4bce,0x26c685ee,0xb4ac8072,0xadc38032}},	//   lkac, _aboo_, गलो_, _gbẹk,
   {{0xf7718872,0x6d4515e6,0x64554bcf,0x29014bd0}},	//   حات_, moha, _uzzi, _moha_,
   {{0x6d4529d1,0xa3c22c4c,0xdb0580f7,0x6f0d4bd1}},	//   loha, ्बर_, rthó, nkac,
   {{0x752880dd,0x62998077,0x645c808b,0x7bca8a03}},	//   fidz, mawo, ýrin, _apfu,
   {{0x6299cbd2,0x7c2805f3,0x6b58cbd3,0x63730372}},	//   lawo, _ždri, ríge, _aħni,
   {{0xc2091101,0x6f0d0326,0xf1bf02df,0x5edb8264}},	//   _צה_, kkac, etá_, ভাবে,
   {{0xa77a80be,0x26c68133,0x6299cbd4,0x2f11826b}},	//   _טרעפ, _gboo_, nawo, _fága_,
   {{0xed4ec807,0xa3d381fe,0x6d454bd5,0x6729cb13}},	//   _го_, _सैर_, koha, miej,
   {{0x6d454bd6,0x3ea200dd,0x67298110,0x75288267}},	//   joha, _sdkt_, liej, cidz,
   {{0x37c380c8,0xab2a0009,0x26dd80a4,0x6d45059e}},	//   ্মকর, _пока_, _kawo_, doha,
   {{0x6729a9d9,0x236d809a,0x26dd84b9,0x26df8084}},	//   niej, _niej_, _jawo_, nduo_,
   {{0x25bf8012,0x6609af99,0xdce38029,0xe7370364}},	// [36e0] ntul_, nyek, _zinā, ует_,
   {{0x62960637,0xa3c7a39d,0x798402d5,0x25bf8162}},	//   _heyo, _उहा_, _itiw, itul_,
   {{0xdb024760,0x6e2d8bcf,0x6729866f,0xb17b0338}},	//   pulä, _žabl, kiej, nvån,
   {{0xf8c00a27,0x26ddcbd7,0xa3e4adb8,0x6f0d4bd8}},	//   श्रय, _nawo_, नित_, ckac,
   {{0x6d454bd9,0xf1268ca0,0x25bfb11a,0xe81c8035}},	//   boha, лько, jtul_, _भेजा_,
   {{0x61e2b5cd,0x26d2005d,0xbebd8110,0x6d450034}},	//   rvol, leyo_, siūl, coha,
   {{0x3d0783bb,0x61e294f9,0xa3df0743,0x6d5c4bda}},	//   ाउने_, svol, तिः_, _ihra,
   {{0x26d24bdb,0x61e29384,0x758aa7ee,0x75288035}},	//   neyo_, pvol, нсов_, widz,
   {{0x9d149bd8,0x26dd9d15,0xa0b68a47,0x1634cbdc}},	//   идич, _dawo_, _محاص, репя,
   {{0x88bc801b,0x6aa4046d,0x26d202c4,0x02039a4e}},	//   _změn, _adif, heyo_, _узун,
   {{0x9b5900a9,0xef868615,0x61d4ac17,0x25bf8162}},	//   киот_, _слеп, _धनुष, atul_,
   {{0xa3a9800f,0x667680f7,0x6609cbdd,0x29014bde}},	//   गंज_, _إدار, byek, _soha_,
   {{0x25bf802e,0x6d5c2ded,0x6d4504a7,0xf2d38158}},	//   ctul_, _ohra, yoha, זער_,
   {{0x6aa41883,0x60de4bdf,0x863781c6,0x26ddcbe0}},	//   _edif, _capm, _גאדג_, _zawo_,
   {{0x6d4503a7,0xf1bf1c32,0x7984019d,0x19580009}},	//   voha, stá_, _etiw, уары_,
   {{0x6458cbe1,0x2ba980a5,0x656e0c41,0x6b564be2}},	//   _izvi, _किता, _aibh, pága,
   {{0x6f0d4be3,0x6d454be4,0x291800f7,0x6d5c0c5e}},	// [36f0] rkac, toha, bhra_, _bhra,
   {{0xb0b20063,0x6d5c0219,0x67298084,0x29184be5}},	//   _जाएग, _chra, ziej, chra_,
   {{0x62960010,0x6299cbe6,0x644e0122,0x3a75a523}},	//   _yeyo, tawo, _cybi, алер,
   {{0x98a9805c,0x6f028079,0x6d454690,0x656e0219}},	//   đač_, _nooc, soha, _eibh,
   {{0x60de07d9,0x62999410,0x6d5c032f,0xf99f06c0}},	//   _yapm, rawo, _fhra, nsè_,
   {{0x6d5c0c41,0x26ddcbe7,0xbebb03ed,0x656e4be8}},	//   _ghra, _sawo_, _njëz, _gibh,
   {{0xfe718307,0xdb1ca38a,0xb8cd86ae,0x6299cbe9}},	//   يدة_, _språ, _कय_, pawo,
   {{0x88bc81d0,0x6609810c,0x661b811b,0xaefb0706}},	//   _uměn, tyek, tzuk, _dhùg,
   {{0x62964bea,0x7afd01a1,0x67298196,0xa8a798a3}},	//   _reyo, djst, riej, _брек,
   {{0x25bf802e,0x62964beb,0x661b9bcc,0x656e022c}},	//   rtul_, _seyo, rzuk, _xibh,
   {{0x25bf8012,0x661b8063,0x5ea780ab,0x26dd9341}},	//   stul_, szuk, ক্ষে, _tawo_,
   {{0x25bf8012,0x3947cbec,0xda6628b4,0xb17b016d}},	//   ptul_, lons_, ивни, rvån,
   {{0x82d6812a,0x80df00ab,0xbbd10651,0xaefb0706}},	//   בורג_, মান্, सबुक, _liùs,
   {{0x3947cbed,0x26d201f6,0x66068009,0x25ad80e1}},	//   nons_, weyo_, äkke, mrel_,
   {{0x6f02cbee,0x7d0380f7,0x5f064bef,0xdfd200f7}},	//   _yooc, _ions, азва, غير_,
   {{0x1e8647de,0x06860470,0x6d5c4bf0,0x61e98493}},	//   рлам, рган, _shra, _orel,
   {{0x7d03cbf1,0x78bb005c,0xa5260a8e,0xa1560098}},	// [3700] _kons, đuvr, амад, _външ,
   {{0x64a64bf2,0x26d24bf3,0xdca60374,0x3947cbf4}},	//   ража, seyo_, ражи, jons_,
   {{0x61e98333,0xe29a81e2,0x7d0390b6,0x93469374}},	//   _arel, вае_, _mons, анже,
   {{0xf99f06c0,0xdee602ee,0x66e61509,0x7d03cbf5}},	//   zyèm_, _томи, _тома, _lons,
   {{0x644e0063,0x6d5c0224,0x3947cbf6,0xd90d826a}},	//   _wybi, _thra, fons_, کیل_,
   {{0x97a6a8a7,0x6d5c3b68,0x656e01e4,0x25a007c0}},	//   арил, _uhra, _uibh, msil_,
   {{0xf0930051,0x64a302cb,0xdfd08013,0x03a30dbd}},	//   חנו_, _фаса, سية_, _миро,
   {{0x61e98a35,0xbb438012,0xa3e48bbc,0x3ec3af84}},	//   _frel, _деск, निस_, осьб,
   {{0xc6f79006,0x61e9cbf7,0xe0daa14a,0x394787f1}},	//   рных_, _grel, _ива_, bons_,
   {{0xdceb8087,0x7ae2b58b,0x8fa69bf5,0x81cc0264}},	//   _rugă, ldot, _важе, রটা_,
   {{0x25a00201,0x2f150106,0xa3df0035,0x69c2cbf8}},	//   hsil_, _låga_, तिए_, ltoe,
   {{0x7ae2b756,0x25a04bf9,0x98a301a9,0xaefb0706}},	//   ndot, ksil_, dijā_, _liùr,
   {{0x7d03c639,0x69c2cbfa,0xdd8e8019,0x273a8ec3}},	//   _fons, ntoe, _کوڈ_, cīna_,
   {{0x29c28028,0x7ae28198,0x2d050072,0x7d03cbfb}},	//   _mưa_, hdot, _शकेल_, _gons,
   {{0x753d8065,0x6458be30,0x69c28009,0x61e24bfc}},	//   észe, _uzvi, htoe, _šolt,
   {{0x6d48cbfd,0x25a00609,0xa3c21513,0x7d03cbfe}},	//   loda, fsil_, ्बई_, _zons,
   {{0x629d4bff,0x394780e7,0x7ae2ae31,0x7bdc4c00}},	// [3710] maso, yons_, ddot, _asru,
   {{0x44f40705,0xa8a71290,0x3947c9d6,0x30a718c6}},	//   опус, _трик, xons_, _трив,
   {{0x61e982a5,0x98a300eb,0x394780e7,0x9cd78039}},	//   _srel, cijā_, vons_, שובה_,
   {{0xfaff020f,0x629d02c4,0x06ac80c8,0x2ba9923a}},	//   një_, naso, ক্তি, _किसा,
   {{0xa2bc28d7,0x24984c01,0x672d0010,0x3947cc02}},	//   ष्ट्, _ferm_, miaj, tons_,
   {{0x629d4c03,0x61e98da8,0x660d260d,0x88bc801b}},	//   haso, _vrel, myak, _uměl,
   {{0x3947cc04,0x6d48cc05,0xb8ff931d,0x660d2b81}},	//   rons_, doda, _तस_, lyak,
   {{0x4975860a,0x7d03cc06,0xf83804de,0x28a70b04}},	//   _глас, _sons, ינות_, कृति,
   {{0x660d480e,0xa3df0aad,0x7d03cc07,0x629d4c08}},	//   nyak, तिक_, _pons, daso,
   {{0x6d48803a,0x7bc181ec,0x660d02d5,0x7ae0b8b6}},	//   goda, ttlu, iyak, _zamt,
   {{0xe29a031f,0x0445a187,0x94078085,0x660d00b4}},	//   лан_, сенн, _yenə_, hyak,
   {{0x2905cc09,0xa3e8000f,0x2d8521f6,0xf1bb800f}},	//   _hola_, बित_, _člen_, _ईमान,
   {{0xfce5895a,0x6d48cc0a,0x68e1cc0b,0x7bc1cc0c}},	//   _голо, boda, _kald, stlu,
   {{0x7d1ac74f,0x61e20353,0x68e380f1,0x0fda0e11}},	//   chts, _šols, ndnd, льбы_,
   {{0x8cca03db,0x09d4873c,0x2905cc0d,0xb4b3816f}},	//   स्फो, _धन्य, _mola_, टली_,
   {{0x290580e4,0x629d0511,0x98a300eb,0x6b5d00e7}},	//   _lola_, caso, rijā_, tége,
   {{0x660d2acb,0x60d5026c,0x7c248326,0x7ae08366}},	// [3720] gyak, bezm, _ƙirg, _ramt,
   {{0x2ed485e8,0x25a04c0e,0x7ae0cc0f,0x2905811e}},	//   _दस्त, rsil_, _samt, _nola_,
   {{0x6b5d0117,0x7ae08052,0x940c8201,0x4adc0074}},	//   sége, _pamt, fadə_, _बसाव,
   {{0x1db78540,0xb21b008b,0x734980e8,0x2b5f80ff}},	//   _आमंत, mbær, ачів_, _chuc_,
   {{0x68e1cc10,0x2905a3bd,0xd9108416,0x59f884fa}},	//   _bald, _bola_, ویر_, реля_,
   {{0x69c29e12,0xd9438198,0xa80282d0,0x7ae0cc11}},	//   rtoe, печи, şıml, _wamt,
   {{0x6d48a1f8,0x69c29eb6,0x2905cc12,0x629d22eb}},	//   voda, stoe, _dola_, yaso,
   {{0xdc3700be,0x69c289ff,0x6d48cc13,0x6f060af8}},	//   _האלט_, ptoe, woda, _jokc,
   {{0x6b58cc14,0x68e1cc15,0x6d48cc16,0x6282aeb6}},	//   lígo, _fald, toda, mcoo,
   {{0x68e1cc17,0x28c480d4,0x629d4c18,0xa3bc001b}},	//   _gald, ल्शि, waso, _आमा_,
   {{0x6d48ad38,0x629d3925,0x8cca0035,0x2458cc19}},	//   roda, taso, स्यो, рань_,
   {{0x2ba98996,0x23a9800f,0x23600282,0x660d00a4}},	//   _किरा, _किरद, _chij_, yyak,
   {{0x629d071e,0x2905caed,0x6d488b24,0x63ab009a}},	//   raso, _yola_, poda, ągni,
   {{0x672d009a,0x463b80be,0x629d0102,0x47d200ab}},	//   wiaj, _געדע, saso, হিনী,
   {{0xaac89d2a,0x629d4c1a,0x4ac88ebf,0x5f940012}},	//   रभाक, paso, रभाव, зист,
   {{0x6d4e1953,0x660d4787,0x6b5d0061,0xec3781c6}},	//   _akba, tyak, ségb, _לאור_,
   {{0x645c435e,0xe8d90870,0x23668699,0x246e811c}},	// [3730] _azri, _atụ_, dmoj_, ləm_,
   {{0xe29f007b,0xe6c00668,0x61ed4c1b,0x660d4c1c}},	//   lað_, čišć, _iral, ryak,
   {{0x2905bcc4,0x8cca80d4,0x660d04bf,0x3e6f8214}},	//   _rola_, त्यो, syak, _kötü_,
   {{0x61ed0289,0xe29f0125,0x325590f8,0xd6db4c1d}},	//   _kral, nað_, овер, _сто_,
   {{0x290581df,0x28c0023c,0x7c873941,0x99d780f7}},	//   _pola_, श्कि, _губе, إتصا,
   {{0x6440009a,0x68e19b44,0xa969818b,0x21699509}},	//   _śmie, _qald, шила_, шили_,
   {{0x68e1cc1e,0xe29f007b,0x2905cc1f,0xdbf1801b}},	//   _vald, kað_, _vola_, _přít,
   {{0x68e1cc20,0x0d8585c2,0x7bc54c21,0x777ab2be}},	//   _wald, олин, mthu, _dutx,
   {{0x68e180ad,0x7bc53c76,0xe5768e11,0x645c00b9}},	//   _tald, lthu, озы_, _zzri,
   {{0xb4b3b841,0x7989cc22,0xdb1c83ba,0x62844c23}},	//   टले_, _itew, _sprø, _sfio,
   {{0x61ed4c24,0x7bc54c25,0x777a811e,0x394080f7}},	//   _aral, nthu, _gutx, éise_,
   {{0x61ed141f,0xbfb492c8,0xd2508065,0x44211a25}},	//   _bral, _رحمت, _آنے_, izh_,
   {{0x4e78845b,0x64a5c098,0xdca597c8,0x61ed0362}},	//   _احمد_, _дала, _дали, _cral,
   {{0xd56787f2,0xdc698087,0xe3b18742,0x7bc50687}},	//   _утеп, _калд_, _قرب_, kthu,
   {{0xe7ec8e18,0xa06a3b34,0x186a14b8,0x61ed4c26}},	//   झिया_, рава_, рави_, _eral,
   {{0x61ed4c27,0x6aa98c53,0x7c2d8300,0x81d08264}},	//   _fral, _ndef, _ƙirƙ, ষিত_,
   {{0x61ed25eb,0x7ae44c28,0xd7f8002e,0x44210dc1}},	// [3740] _gral, _iait, ţă_, ezh_,
   {{0x7ae44c29,0x2716a770,0x6aa9826b,0x7d070b80}},	//   _hait, _तत्र_, _adef, _cojs,
   {{0x7ae44c2a,0x7af60f91,0x8b2680e8,0x6f0602f7}},	//   _kait, _knyt, одже, _tokc,
   {{0x7ae40102,0x741301a8,0xfaff0168,0xa80282d0}},	//   _jait, بوما, hmën_, şıkl,
   {{0x7ae44c2b,0x69c60065,0x6aa9831d,0x6282cc2c}},	//   _mait, ntke, _ddef, rcoo,
   {{0x7ae44a5e,0x3ea04c2d,0xed570d0e,0x6282cc2e}},	//   _lait, lait_, _моя_, scoo,
   {{0xea0100ff,0x6b5d43d6,0xfbc34c2f,0xd7fa8c6e}},	//   _đậu_, héga, _обро, рул_,
   {{0x7ae44c30,0x3ea04c31,0xd838882c,0xc6f8a4c1}},	//   _nait, nait_, _neče_, сних_,
   {{0xe29f007b,0xaf079a43,0xb17b004a,0xb0ca1c6f}},	//   vað_, تقيم_, rvåk, िभाग,
   {{0x61ed00f1,0x38c887d2,0xdb218019,0x7af60039}},	//   _rral, _داری_, ütör, _anyt,
   {{0x7ae44c32,0xe29f0125,0x06ac80ab,0x98a30084}},	//   _bait, tað_, ক্ষি, niją_,
   {{0x06658077,0x246e8201,0x61ed4c33,0x7ae40cac}},	//   _کامپ, rəm_, _pral, _cait,
   {{0x7ae44c34,0x3ea04c35,0xe29f007b,0x41e42f8d}},	//   _dait, dait_, rað_, міра,
   {{0x7bc50428,0xe29f008b,0x25a68299,0x752a913b}},	//   ythu, sað_, _ivol_, _umfz,
   {{0xbbc903bb,0x7d070353,0xe29f008b,0xa2db816f}},	//   _रहेक, _rojs, pað_, _नसल्,
   {{0x61ed377e,0x7ae44c36,0x06ac80ab,0xd6ac80ab}},	//   _tral, _gait, ক্রি, ক্রয,
   {{0x690b0722,0xaded81af,0xdb02016b,0x61ed4c37}},	// [3750] _qües, जियन_, nulý, _ural,
   {{0x929d809a,0x7ae40102,0x7bc54c38,0xa2c10894}},	//   _poło, _zait, tthu, _वाड्,
   {{0x7ae4035a,0x3ea04c39,0xb4ab009a,0x7d0704ef}},	//   _yait, bait_, _गयी_, _vojs,
   {{0x6abd1da3,0x442103e7,0x61290858,0x7d070035}},	//   ngsf, rzh_, džli, _wojs,
   {{0x237f02a5,0x68e50009,0x7bc509ff,0xa3e1941b}},	//   _čuju_, _kahd, sthu, _नैन_,
   {{0x673b003a,0x290302f7,0x68e54c3a,0x92d70264}},	//   čuju, njja_, _jahd, সায়_,
   {{0xa2959af1,0x68e54c3b,0x98a301e2,0x657d08dc}},	//   _наві, _mahd, ciją_, _hush,
   {{0x657d4c3c,0xdfce803d,0x753a8102,0x7b3c81a1}},	//   _kush, ايي_, entz, nčul,
   {{0x64469010,0xd838b351,0x80dc00d4,0x7ae44c3d}},	//   şkil, _reče_, _फसले, _rait,
   {{0x7ae44c3e,0x58bb9dd2,0x6e200074,0x68e54c3f}},	//   _sait, _خارج_, _ümbe, _nahd,
   {{0x6d890038,0xd838850b,0x7ae43174,0xfaff0168}},	//   _hľad, _peče_, _pait, rmën_,
   {{0x65750326,0x96b8caa5,0x62810035,0x2fc78122}},	//   _lizh, _душу_, ślon, mtng_,
   {{0xd83890d3,0x3ea04c40,0x213100dd,0x2bd218a9}},	//   _veče_, vait_, fizh_, _सहभा,
   {{0x645d8086,0xeb18864a,0xdd920065,0xeb08943e}},	//   əsin, _दत्त_, ہور_, _वक्त_,
   {{0x7ae44c41,0x2fd3002a,0x442184e1,0x3ea04c42}},	//   _tait, _cpxg_, _åh_, tait_,
   {{0x657d2a3f,0x673b98c2,0x77698144,0x0d860bda}},	//   _bush, nnuj, nmex, злан,
   {{0x3ea0174b,0xf1da809a,0xfe434c43,0x68e54c44}},	// [3760] rait_, _मैंन, енто, _fahd,
   {{0x657d4c45,0x3ea04c46,0xd5af0591,0x6b56041c}},	//   _dush, sait_, افل_, dági,
   {{0x3c21811b,0x3ea04c47,0xa3e48fea,0xa87b0039}},	//   _eгvv_, pait_, निए_, _לאיר,
   {{0x657d4c48,0x98a30110,0x2b81cc49,0x63be80e8}},	//   _fush, riją_, _móc_, _åpne,
   {{0xceb3093f,0x657d4c4a,0x673b817f,0xd6c380ab}},	//   _איר_, _gush, dnuj, ্যায,
   {{0x28c00778,0x6455026f,0x2d8281d0,0xf53f0338}},	//   श्चि, _fyzi, íkem_, _tvåa_,
   {{0x04430ca0,0xbbda801b,0x2b818129,0x48fe8327}},	//   _зерн, _बनेक, _nóc_, लाबो_,
   {{0x1ae39198,0x543b0039,0x671c0eed,0x657d00fc}},	//   _посм, _העלא, नसिक_, _yush,
   {{0x4343997d,0x6e242daf,0x657d0df6,0xbb438103}},	//   _четв, nzib, _xush, _четк,
   {{0x47d480ab,0x2b818129,0x6b518338,0x6e2405ee}},	//   থিবী, _bóc_, bågs, izib,
   {{0xdbf1801b,0x2b8180ff,0x69c0023e,0x4ae08072}},	//   _přát, _cóc_, àmen, _नसाव,
   {{0x1dac4c4b,0x60c4973d,0xf6e580e8,0x6aa2804f}},	//   _चिंत, đimu, _оцін, naof,
   {{0x6abd03a6,0x6f044c4c,0x872581a8,0x9f47010c}},	//   rgsf, djic, _تعلم, _éné_,
   {{0xb4ab009a,0x61ed8201,0xb4e6000d,0x67d51775}},	//   _गये_, çilə, भयो_, могу,
   {{0x3d000a16,0x2b81801c,0xd7f84652,0xb9054c4d}},	//   राने_, _góc_, пут_, _नस_,
   {{0x443f003a,0x63ba858b,0x7d0acc4e,0x68e5022b}},	//   _ću_, mutn, _hofs, _wahd,
   {{0xa3e49a4d,0x1bea8ee6,0xa2a20105,0x6aa28187}},	// [3770] निक_, टिवल_, _ख़त्, daof,
   {{0x04670676,0xf1b20035,0xe61f0114,0x798d4c4f}},	//   птем, _जितन, _ffôn_, _itaw,
   {{0x69100006,0xedd9801b,0x1e188697,0x23810196}},	//   _päev, _भन्छ, धनुष_, _vėjo_,
   {{0x657d4c50,0x6b560187,0xdb058168,0x6f164c51}},	//   _tush, tági, mshë, ckyc,
   {{0xdb1c8019,0x63ba816b,0x672083ed,0xbebd8196}},	//   _apró, hutn, dhmj, kiūr,
   {{0x63ba8057,0xdb1b0009,0xe4e400e8,0xe9d88a18}},	//   kutn, lttä, _пісн, які_,
   {{0x1bd44c52,0x20548098,0xdb058168,0x62860106}},	//   _поря, нтър, nshë, ycko,
   {{0x63ba80dd,0xe61995a6,0x629f1cd8,0xdb1b0198}},	//   dutn, жди_, _neqo, nttä,
   {{0x798d146a,0x2b81cc53,0x98a78087,0x7769cc54}},	//   _ntaw, _sóc_, gină_, rmex,
   {{0xee369842,0x3d000105,0xe6c4876c,0xdb058168}},	//   ьны_, राये_, češć, kshë,
   {{0x3c65835f,0x2d540006,0x798d4c55,0xdb058168}},	//   ьког, päev_, _ataw, jshë,
   {{0x57278250,0x799b81bc,0x2b818129,0x3dc94c56}},	//   _عراق, _kwuw, _vóc_, ktaw_,
   {{0x3d0027af,0x80c4801b,0xdb058168,0x98a78162}},	//   रामे_, _रामे, eshë, cină_,
   {{0x63ba8f68,0x2b818028,0x3ebf8722,0xdb058168}},	//   butn, _tóc_, lgut_, fshë,
   {{0x63ba80b9,0x06e080ab,0x798d2f4a,0xa3dc27af}},	//   cutn, ভারি, _etaw, _तैं_,
   {{0x3ebfcc57,0xdbd90073,0x2c0a801b,0x7b060118}},	//   ngut_, nçõe, ाहरू_, _lóuz,
   {{0xf50a22e9,0xd8389c89,0xdbd9247a,0xaefb00ff}},	// [3780] онал_, _meča_, içõe, _thùn,
   {{0xb4b8009a,0x61e44c58,0x3ce7cc59,0x6f1601d6}},	//   छले_, _isil, _janv_, skyc,
   {{0x6f660073,0x0aea8049,0xb6a38129,0x799b85e7}},	//   _овоз, ждей_, _phầ, _awuw,
   {{0x60dc4c5a,0x7c650277,0xdb1c8176,0xddcb4c5b}},	//   lerm, رالل, _aprò, žišk,
   {{0xa2c100d4,0xb5fb016b,0xdb1c8035,0x2baa06a7}},	//   _वास्, _vzác, _spró, _चटका,
   {{0xa91d8289,0x26c01ab6,0x7d030106,0x98a78162}},	//   _nužd, lgio_, önst, vină_,
   {{0x38cb89d7,0xd83880d2,0x799b8c2e,0x4425ae49}},	//   تانی_, _beča_, _ewuw, jzl_,
   {{0x60dc4c5c,0x61e42328,0xef91803d,0x69100074}},	//   herm, _osil, ایند, _käes,
   {{0x60dc1e9a,0x75d480f7,0x8c3c8085,0x29184c5d}},	//   kerm, ريدا, dağa, kkra_,
   {{0x6b5d03d3,0x2fdf0063,0x63ba8ad4,0xdbd90187}},	//   tégo, ługi_, tutn, açõe,
   {{0xdb1b025d,0x61e44c5e,0xccf8801b,0x798d009a}},	//   yttä, _asil, dmět_, _staw,
   {{0x68e8cc5f,0x290c805c,0x79808b15,0x63ba8359}},	//   _hadd, _hoda_, _kumw, rutn,
   {{0x60dc1d03,0xff278077,0x63ba8025,0x68e8cc60}},	//   ferm, _تبلی, sutn, _kadd,
   {{0xfc2f83f8,0x7980bd92,0x660f8884,0xdb0580f1}},	//   احی_, _mumw, äcke, tshë,
   {{0x68e882bb,0x61e44c61,0xba3b4c62,0x63ba80b9}},	//   _madd, _esil, caïn, qutn,
   {{0x26c00021,0x6d5acc63,0x8ccaa2f9,0xc3280013}},	//   ggio_, llta, त्रो, _يكون_,
   {{0x798d4c64,0x64588364,0xc61200c8,0x68fa838e}},	// [3790] _utaw, _hyvi, _সেবা_, _ontd,
   {{0x290c80dd,0x2918016d,0x68e88365,0x6d5a85ee}},	//   _noda_, ckra_, _nadd, nlta,
   {{0x3dc94af7,0xa7751cf8,0xa3e4c1d0,0x60c50176}},	//   staw_, _плоч, निट_, _ichm,
   {{0x160e83db,0xae0e8d86,0xbebb0168,0x290c8362}},	//   िहार_, िहान_, _emër, _aoda_,
   {{0x68e8a695,0x290ccc65,0x3f813a00,0xf1a7980b}},	//   _badd, _boda_, _huhu_, френ,
   {{0x41b2009a,0x290c88d8,0x3f810074,0xd838979d}},	//   _जिसस, _coda_, _kuhu_, _seča_,
   {{0xa91d817f,0x78a38338,0xa92781a9,0x25a94c66}},	//   _ružd, ranv, _režī, lsal_,
   {{0x6d5acc67,0x78a38365,0x68fa81ec,0x59b18beb}},	//   elta, sanv, _entd, ुंदर,
   {{0x7afbcc68,0x290ccc69,0xb9b58875,0x98a30084}},	//   _inut, _foda_, _سماع, siję_,
   {{0x290ccc6a,0x68e8985b,0x7afb816b,0x7ae98198}},	//   _goda_, _gadd, _hnut, _haet,
   {{0x60dc0f82,0xc4d200be,0x3f81054e,0x29c981ca}},	//   verm, נגט_, _nuhu_, lúa_,
   {{0x78a1cc6b,0x6d5a8046,0x61e401e0,0x60c54c6c}},	//   _helv, alta, _psil, _achm,
   {{0xa2c1000c,0x68e8cc6d,0x29c982ba,0x60dc4c6e}},	//   _वार्, _yadd, núa_, term,
   {{0x7ae980f7,0x291e1f04,0x3f8100fc,0x8c4581cf}},	//   _laet, óta_, _buhu_, _пеле,
   {{0x9d1a80be,0x46f60678,0x69cb8f67,0x7c8488ed}},	//   _מוסט, нчат, htge, _руче,
   {{0xdee34c6f,0xe45680be,0x60dc4c70,0x7c2d8041}},	//   лоси, _איצט_, serm, _ƙarf,
   {{0xea010104,0x26c02167,0xc69280be,0x69c981c0}},	// [37a0] _đầu_, rgio_, טאן_, _nqee,
   {{0x7afb99fb,0x79808314,0x7d7a83de,0xafe61a88}},	//   _anut, _rumw, פרעג, _зоол,
   {{0x389b0158,0x68e8cc71,0x69c980b9,0x6aa09b7c}},	//   _מיינ, _radd, _aqee, _pemf,
   {{0x6d554c72,0x7ae9cc73,0x612201ac,0xfe6788ca}},	//   _ekza, _caet, _dôle, _مد_,
   {{0xa3e50105,0xb17b04e1,0x7ae98114,0x6d5a8106}},	//   _बैठ_, lvår, _daet, ylta,
   {{0x68e8a85b,0x672404bf,0x1c0f83b7,0x2ca581fa}},	//   _qadd, lhij, ाहाल_, jald_,
   {{0xa2c101b6,0xb90895bc,0x4ac6016f,0x78a184fe}},	//   _वाल्, _बस_, _वाढव, _delv,
   {{0x68e8cc74,0x8b668077,0x7ae9cc75,0x7659831d}},	//   _wadd, _سازم, _gaet, _bywy,
   {{0x290c9313,0xa84a80d5,0x78a18019,0x2ca58370}},	//   _toda_, _کلام_, _felv, fald_,
   {{0x3c2500ad,0x2d824c76,0x3ea49722,0xb17b016d}},	//   _vзvv_, _muke_, samt_, kvår,
   {{0x7d0e4c77,0x92954c78,0xe57103de,0xa2950a4c}},	//   _mobs, канц, יַט_, кані,
   {{0xa4fd000c,0x60c502af,0x6458816b,0x33204c79}},	//   _उच्च_, _schm, _vyvi, _clix_,
   {{0x3f811e92,0x2ca581ec,0x6e3b00e1,0xd2440087}},	//   _suhu_, bald_, _ľubo, гэри,
   {{0x63be04e8,0xd5b990ac,0x7d0e0609,0x39860c0b}},	//   kupn, _ісі_, _nobs, _dôs_,
   {{0x67d41541,0xdfd80098,0x332007f1,0x6b588118}},	//   лору, нът_, _flix_, lígu,
   {{0x63be0057,0x2d824c7a,0x61e2cc7b,0x25a94c7c}},	//   dupn, _buke_, kwol, tsal_,
   {{0x2d820267,0x25a91b7d,0xe7e28035,0x5d552639}},	// [37b0] _cuke_, usal_, _कैसा_, вкат,
   {{0x2edd80d4,0x2d824c7d,0x7d1a82f1,0x7ae9cc7e}},	//   _मस्त, _duke_, nkts, _saet,
   {{0x25a94c7f,0x236901c0,0x7ae9cc80,0x78a182f1}},	//   ssal_, _khaj_, _paet, _relv,
   {{0x78a1ab1e,0x67240a0f,0x29c985e4,0x25a9001b}},	//   _selv, chij, túa_, psal_,
   {{0xdd86881b,0x66640098,0x5f0490a1,0xe5c730b4}},	//   _خو_, _бърз, वान्_, _ясно,
   {{0x69cb84eb,0x78a70669,0x88bc81d0,0xccf881d0}},	//   rtge, najv, _směr, změr_,
   {{0x69cbcc81,0x7c288390,0x7ae9cc82,0x63be008e}},	//   stge, jzdr, _taet, cupn,
   {{0xf77185ff,0x256600e7,0x26c6bdb4,0xadc40032}},	//   جات_, rôle_, _ccoo_, _akẹr,
   {{0x49758e9f,0x62849c89,0x9fb6001b,0x99d4bdf2}},	//   _алас, žioc, vřít_, _متلا,
   {{0xe9759a43,0x2f11cc83,0x61e482d0,0x26c68037}},	//   _شهاد, _págs_, çile, _ecoo_,
   {{0xa91d8067,0x8c459e58,0xecc6086a,0xa8028380}},	//   _tužb, тене, र्टफ, şırl,
   {{0x76598114,0x6f0f01e8,0x23690242,0xf1bf016a}},	//   _tywy, _nocc, _chaj_, rzán_,
   {{0xb5fb0061,0x6aa600b9,0xf1bf041c,0x0b4301b5}},	//   _szán, rakf, guá_, рнян,
   {{0x2d82003a,0x6fd88424,0x6f09a72d,0x9e6483a9}},	//   _ruke_, _महमू, ljec, _свід,
   {{0x2d8203c3,0xea010028,0x10a3395b,0x6f0f0081}},	//   _suke_, _đấu_, рисн, _bocc,
   {{0x2d82020d,0x6f0f4c84,0x22160a41,0x66040102}},	//   _puke_, _cocc, _афор, txik,
   {{0x67244c85,0x6da60258,0x6f0f0081,0xb17b0106}},	// [37c0] rhij, тиза, _docc, rvår,
   {{0x6b83cc86,0x672402a0,0x63be05b9,0xe6c91351}},	//   _kung, shij, tupn, čašć,
   {{0x6d41cc87,0x6b83cc88,0x68fe00e5,0x7c290326}},	//   inla, _jung, _inpd, _ƙera,
   {{0x6b83b37f,0x64414c89,0x63be017f,0x6f0f047f}},	//   _mung, _žlic, rupn, _gocc,
   {{0x9c7c827f,0x6f09a1fa,0xaca3819d,0x6b83c617}},	//   leče, djec, _apọk, _lung,
   {{0x61e28114,0x6f0f01e8,0x6aa42257,0x7b3c8088}},	//   rwol, _zocc, _leif, jčuv,
   {{0x03a3219f,0x6a86a5ab,0x6b83cc8a,0xb4de4c8b}},	//   _висо, _алба, _nung, ढ़ी_,
   {{0x6d5e4c8c,0x2ca3311a,0x04431505,0x2fda00b9}},	//   llpa, _zejd_, _тесн, _mppg_,
   {{0x91e399a7,0x5d54a639,0x3eb981a8,0x6b83ab8c}},	//   _коте, лкит, ósta_, _aung,
   {{0xe29a0028,0x660f816d,0xa8028085,0xfe7f023e}},	//   _đưa_, äcka, şıql, _raïm_,
   {{0x9c7c920e,0x6b83cc8d,0x6b5d4c8e,0x6f09cc8f}},	//   ječe, _cung, légi, bjec,
   {{0x6b83cc90,0x61f60aa2,0xddcfcc91,0x7984010c}},	//   _dung, _bryl, žešk, _buiw,
   {{0x6f0f0081,0x645c4c92,0x6aa44c93,0x7def8061}},	//   _rocc, _lyri, _deif, rősö,
   {{0x6f0f4c94,0x7984067f,0x2f150687,0x61f60286}},	//   _socc, _duiw, _lågt_, _dryl,
   {{0xf7730bbe,0x28d20778,0x6b83cc95,0x236901c5}},	//   لار_, द्धि, _gung, _thaj_,
   {{0x5eb40ada,0x6280808e,0x27fe0106,0x2007023e}},	//   ийст, _ngmo, åtna_, _ànim_,
   {{0x657c076d,0x79840041,0x7aed02c4,0x645c2353}},	// [37d0] _birh, _guiw, _iaat, _ayri,
   {{0x7aed4c96,0x672280f1,0x6b83b2a0,0x98a79c43}},	//   _haat, _lloj, _yung, binę_,
   {{0x6f0f0081,0xb227007b,0x7aed4c97,0x6b8388f1}},	//   _tocc, _fræð, _kaat, _xung,
   {{0x7c248326,0x3f570866,0x27f9928a,0xb22701fa}},	//   _ƙirj, rçus_, _čsn_, _græð,
   {{0x7aed1694,0x3ea94c98,0x6f09b11a,0x69cf49d6}},	//   _maat, maat_, vjec, ntce,
   {{0x645c1ca8,0xeb9308ca,0x7aed4c99,0x1bf4823c}},	//   _fyri, _نظر_, _laat, ेमाल_,
   {{0x6f09b275,0x98a28009,0xb8dbb41c,0x3d00114f}},	//   tjec, щище, _अय_, रारे_,
   {{0x765d0364,0x6b83cc9a,0x7aed4c9b,0xa91d95db}},	//   _kysy, _rung, _naat, _duža,
   {{0x6aa44c9c,0xdce38bda,0x8cca04c5,0xaefb01e4}},	//   _reif, _sinđ, स्को, _chùi,
   {{0x6b8383f8,0x61e9cc9d,0x6f0982ce,0x6e29851c}},	//   _pung, _isel, sjec, rzeb,
   {{0xb5fb0065,0x7aed0365,0x6722cc9e,0xfaa6198e}},	//   _szál, _baat, _floj, лано,
   {{0x7aed44bb,0x15f59e7b,0x61f6016d,0x6b589ee8}},	//   _caat, _مستح, _pryl, lígr,
   {{0x9c7ccc9f,0x3f858b20,0x6b83ac2e,0x3ea94ca0}},	//   veče, _hulu_, _wung, daat_,
   {{0x6b83cca1,0x25adba17,0x64a5cca2,0x92df80ab}},	//   _tung, msel_, _сака, তায়_,
   {{0xc815035f,0x25adcca3,0x3ea94ca4,0x3f859c89}},	//   аєть, lsel_, faat_, _julu_,
   {{0x7bc1cca5,0xa3b89344,0x61e9cca6,0x3f858b99}},	//   mulu, _चित_, _osel, _mulu_,
   {{0x7bc1cca7,0x201e4ca8,0x765d0355,0x645c4ca9}},	// [37e0] lulu, šti_, _cysy, _syri,
   {{0xb4de0b9f,0x319b012a,0x7aed254d,0xb19b03c8}},	//   ढ़े_, _רבינ, _zaat, _רייכ,
   {{0xf5368158,0x9c7cccaa,0x7bc1ccab,0x69db85a4}},	//   נטער_, peče, nulu, _apue,
   {{0x25adccac,0x3ea94cad,0x645c3be2,0x6b5d434b}},	//   ksel_, caat_, _vyri, tégi,
   {{0x7bc1ccae,0x99d380f7,0x657c02c4,0x765d0114}},	//   hulu, متوا, _tirh, _gysy,
   {{0x7bc1beee,0x645c01e2,0x3f85b859,0xdce380eb}},	//   kulu, _tyri, _bulu_, _minē,
   {{0x7bc1ccaf,0xd54709b5,0xd90d803d,0x61e9ccb0}},	//   julu, _спре_, بیل_, _esel,
   {{0x3f858393,0x7bc1ccb1,0xc6f8a025,0x60c8849c}},	//   _dulu_, dulu, тних_, _wcdm,
   {{0x25ad84fe,0xd33581e2,0xe1faa5f5,0x7ae2ccb2}},	//   gsel_, _тэры, _яга_, meot,
   {{0x7aed32c7,0xa91d811f,0x80d601c4,0x7bc1ccb3}},	//   _saat, _tuža, म्मे, fulu,
   {{0x7bc1ccb4,0x7aed4cb5,0xa3bb80d4,0x3f85ccb6}},	//   gulu, _paat, इंग_, _gulu_,
   {{0xb5fb0117,0x23a58076,0x7aed02a3,0x317e811e}},	//   _szám, _खबरद, _qaat, _hitz_,
   {{0x7aed24da,0xa5968698,0x3f85c57e,0x3ea90a53}},	//   _vaat, _срещ, _zulu_, vaat_,
   {{0x7bc1b785,0xa2c103dd,0x6d58807a,0x7aed4cb7}},	//   bulu, _वाक्, _ukva, _waat,
   {{0x7aed4cb8,0x7bc1ccb9,0x3ea928d4,0x753aad08}},	//   _taat, culu, taat_, mitz,
   {{0x753a8813,0xa91d8499,0xcb69003d,0x765d0009}},	//   litz, _nužn, _جمعه_, _pysy,
   {{0x3ea94cba,0x7bdc4cbb,0xdb1e80e7,0x7ae2aa6a}},	// [37f0] raat_, _apru, cupé, deot,
   {{0x753a87e2,0x3ea94cbc,0xd7f88087,0x628f0088}},	//   nitz, saat_, _oră_, lcco,
   {{0x765d009a,0x61e98fd6,0xb97a01c6,0x04671246}},	//   _wysy, _ssel, _שנתי, утам,
   {{0x92eb80f7,0x753a8102,0x3ea905ee,0x7f440722}},	//   عراق_, hitz, qaat_, cniq,
   {{0xa91d803a,0x7bc1ccbd,0x6f0d4cbe,0x753a8102}},	//   _dužn, zulu, mjac, kitz,
   {{0xf77f07d9,0x6f0d003a,0xe8f885a8,0x7a2a8061}},	//   _hiç_, ljac, ллі_, _söté,
   {{0x753a8102,0xd70595a6,0x6b5d0036,0x7bc18162}},	//   ditz, изки, légu, xulu,
   {{0x6d573fe4,0x6f0d4aff,0xd34389a7,0x25adccbf}},	//   loxa, njac, _افری, tsel_,
   {{0xd7068009,0x6e2d4cc0,0x2bdd8035,0xb5fb0061}},	//   рные_, nzab, _फैजा, _száj,
   {{0x7bc1ccc1,0x25adccc2,0x753a811b,0x6d4508b6}},	//   tulu, rsel_, gitz, nnha,
   {{0x30848013,0x237f8176,0xe29a079e,0xa2cc800d}},	//   _المف, _kiuj_, кан_, _हाम्,
   {{0x68e3ccc3,0x7bc1ccc4,0x6f0d02a5,0x290148b5}},	//   lend, rulu, jjac, _anha_,
   {{0x7bc1ccc5,0xfe9a8051,0x6f0d10d3,0x753accc6}},	//   sulu, _סיסמ, djac, bitz,
   {{0x82768158,0x68e3ccc7,0x6d454cc8,0xa91d80e1}},	//   יערע_, nend, jnha, _mužo,
   {{0x2bb10063,0xa3e51990,0x68fc86a5,0x8fa6096f}},	//   jąc_, _बैल_, _órde, рабе,
   {{0x68e3ccc9,0x273f0009,0xd91009a7,0x6fd8bd25}},	//   hend, vänä_, _کیس_, _महसू,

   {{0x661bb134,0xa91d805c,0x29130118,0x63a38114}},	// [3800] nyuk, _ružn, _foxa_, _hwnn,
   {{0x33f61ba8,0x26cb0098,0x68e3ae2b,0xf1bf0061}},	//   ичес, _ecco_, jend, zzák_,
   {{0x68e3ccca,0xa3bb8540,0x225f808e,0x2ca7cccb}},	//   dend, इंट_, _ayuk_, _mend_,
   {{0x753a811e,0x28d2000c,0x6f0d009a,0x48ee001b}},	//   zitz, द्रि, cjac, इएको_,
   {{0x2bd20c78,0x272a801c,0xdb020338,0x273f062c}},	//   _सहका, _hùng_, mslä, sänä_,
   {{0x39584ccc,0x68e3cccd,0xc05a80e8,0x8b962c60}},	//   nors_, gend, кій_, _врач,
   {{0xa91d8024,0x8c430b88,0xf8b30039,0x443e4cce}},	//   _tužn, _дере, קשה_, _ät_,
   {{0x9c7c93ee,0x6d5c007a,0xd838826c,0x395800e7}},	//   ječa, _hkra, _ječi_, hors_,
   {{0x60ea8ae7,0x753aad08,0x39584ccf,0x2a6001c0}},	//   _имам_, titz, kors_, _nyib_,
   {{0x395802e6,0xd8388279,0x6443009a,0x63a385ee}},	//   jors_, _leči_, źnie, _bwnn,
   {{0x39580813,0x753accd0,0x6e2d0d3d,0xb0aa0035}},	//   dors_, ritz, zzab, करनग,
   {{0x753a9919,0xd6d9809a,0xee3a8bda,0x48fe801b}},	//   sitz, koły_, _ине_, लाको_,
   {{0x78a88065,0xf5948013,0x6d5c105e,0x39584cd1}},	//   _kedv, _التج, _okra, fors_,
   {{0x78a8803b,0xf77f00f1,0x272a8129,0x6fca852a}},	//   _jedv, _siç_, _bùng_, संपू,
   {{0x272a8104,0x4ea70073,0xaad781d0,0x4ad78107}},	//   _cùng_, ираа, ण्डक, ण्डव,
   {{0x68e3ccd2,0x272a8104,0x6d5c4cd3,0x6c7b812a}},	//   zend, _dùng_, _akra, _באופ,
   {{0x68e3ccd4,0xdceb0696,0x2913002a,0x8cc200dc}},	// [3810] yend, šičk, _toxa_, _लाखो,
   {{0x29014cd5,0x61ed4cd6,0xa91d81ac,0x6e2d4cd7}},	//   _unha_, _isal, _ružo, rzab,
   {{0x68e3ccd8,0x6d454cd9,0x6d570358,0x236d81c0}},	//   vend, rnha, roxa, _phej_,
   {{0x68e3ccda,0x28c9816f,0x1fcc80ab,0x2b591717}},	//   wend, _राहि, লবাস, nosc_,
   {{0xe91980e8,0xaefb051e,0x61ed0372,0x3be8029a}},	//   лоді_, _dhùt, _jsal, _eşq_,
   {{0xf1bf1986,0x6f02ccdb,0x61ed4cdc,0x98a2a4dd}},	//   irá_, _anoc, _msal, пише,
   {{0xe7398a41,0x2ca7ccdd,0x63be011f,0xf1bf4315}},	//   лек_, _rend_, crpn, hrá_,
   {{0x61ed01c2,0x7bc54cde,0x2ca78039,0xf1bf007b}},	//   _osal, muhu, _send_, krá_,
   {{0x612b0065,0x68e3a8eb,0x7bc50886,0x9c7c8353}},	//   _küld, pend, luhu, veča,
   {{0x6aa98586,0xb8fc80c8,0xf1bf4cdf,0x0d829439}},	//   _heef, _তো_, drá_, яльн,
   {{0x61ed4ce0,0x2ca7cce1,0x39584ce2,0x661b8859}},	//   _asal, _vend_, vors_, syuk,
   {{0x6f02cce3,0x61fbcce4,0x7981a6e9,0x2c4100fc}},	//   _gnoc, _krul, _hilw, _mɗd_,
   {{0x61ed0065,0xd838979d,0x7bc507fe,0x9c7c8024}},	//   _csal, _reči_, huhu, reča,
   {{0x6aa9838e,0x9c7ccce5,0x7bc54ce6,0xfd48819d}},	//   _leef, seča, kuhu, _memọ,
   {{0x9c7c800d,0x7981abf7,0xf1bf1fd3,0x7d03cce7}},	//   lečn, _milw, ará_, _inns,
   {{0xf1bf4ce8,0x1e86161a,0xdc3984b7,0x272a801c}},	//   brá_, слам, _aħħa, _vùng_,
   {{0x9c7c803e,0x7ae60214,0xa3ca016f,0x2fdf0162}},	// [3820] nečn, mekt, ळून_, ăuga_,
   {{0x25bf9eea,0x272a801c,0x23db8ebf,0x69c6005d}},	//   irul_, _tùng_, _बहाद, muke,
   {{0x69c64ce9,0x6aa9ccea,0x25bf836e,0x61fbcceb}},	//   luke, _beef, hrul_, _arul,
   {{0x61fbccec,0xaefb0a2a,0x78a8ac15,0x6b5d1a25}},	//   _brul, _dhùs, _sedv, légr,
   {{0x9c7c94ce,0x28c9af52,0x3ea04aba,0x7ae6011e}},	//   ječn, _राशि, mbit_, iekt,
   {{0x25bf8abf,0x28db000c,0x9c7c816b,0x6d5c1d80}},	//   drul_, म्पि, dečn, _ukra,
   {{0xdfd080f7,0x93bc8087,0x64a302ac,0x6ab780ab}},	//   ذية_, nzăt, _хаса, _ইউরো,
   {{0x6aa98a0f,0x6d8908ae,0xa3ab8fea,0x7d03998f}},	//   _geef, _džaf, गठन_, _anns,
   {{0xc6f791e9,0xa63b00be,0xa91d812b,0x79819ad9}},	//   сных_, ָגיר, _mužj, _filw,
   {{0xb606812b,0x73d8b229,0xdce38084,0x69c64ced}},	//   vršć, адор_, _minė, duke,
   {{0x7ae642a4,0x628581d0,0x3ea02a0f,0x3ead82c4}},	//   fekt, ěhov, kbit_, baet_,
   {{0x09bf00ab,0x3f8200d7,0x8e8681a8,0x25bfccc1}},	//   েবসা, _niku_, _الإه, brul_,
   {{0xc3338051,0x25bf8162,0x9418011c,0xd75781a8}},	//   פוש_, crul_, _verə_, _النت_,
   {{0xa2d901fe,0xecc7009a,0x3f820032,0xdcfc0b67}},	//   _फॉर्, _लाइफ, _aiku_, _birč,
   {{0x0d3b804c,0x7d1509a4,0x77640118,0xd6db19ae}},	//   _תגוב, _rozs, flix, лта_,
   {{0xf7700250,0x61ed00a4,0x7ae60214,0x3f8200b9}},	//   فاق_, _tsal, cekt, _ciku_,
   {{0xe66711c7,0xb505000f,0x61ed4cee,0x9c8700f7}},	// [3830] ство, रालय_, _usal, مشاه,
   {{0x7bc5022e,0x6d48a405,0x25e08006,0xdcfc01a1}},	//   tuhu, nnda, _कहनी_, _firč,
   {{0x25bf80ee,0xaefb0229,0x6d48ccef,0xadea86ae}},	//   zrul_, _dhùr, inda, _जैसन_,
   {{0x61fb8bfd,0x6d5accf0,0x7bc54cf1,0x7981ccf2}},	//   _prul, hota, ruhu, _silw,
   {{0x6d5accf3,0xd838b69f,0x7bc51ec7,0x2179c792}},	//   kota, _meču_, suhu, айды_,
   {{0x2d990364,0x68e70067,0x92e500c8,0x65940a42}},	//   _itse_, nejd, নায়_, _хару,
   {{0x7ae64cf4,0xb9260135,0x6d5accf5,0xdfce80f7}},	//   yekt, _agwọ_, dota, نيو_,
   {{0xf3898104,0x6d48ccf6,0xef19a19f,0x9c7c800d}},	//   _bản_, enda, рми_, tečn,
   {{0x6b8a8352,0x2d8b04a8,0x6d48807b,0xf38980ff}},	//   _aufg, _juce_, fnda, _cản_,
   {{0x6d5accf7,0x9c7ca1f6,0x45198997,0xc58880ff}},	//   gota, rečn, рция_, _tồn_,
   {{0x5fdd91be,0x9c7c84c4,0x637180f2,0x2d8b4cf8}},	//   _महिल, sečn, gång, _luce_,
   {{0x6d48ccf9,0x2fc78077,0x69c6288c,0x2d9902f1}},	//   anda, mung_, tuke, _otse_,
   {{0x6d5accfa,0x2fc7ccfb,0x2d990069,0x6b5d02be}},	//   bota, lung_, _ntse_, tégr,
   {{0x2d83003a,0xe7dd81ab,0x3f8200f6,0xf99284de}},	//   _nije_, _महाप, _siku_, ורך_,
   {{0x2fc7ccfc,0x3cee835a,0x33294cfd,0x3f82026c}},	//   nung_, _असते_, _flax_, _piku_,
   {{0x7f49cb4f,0xf389801c,0x6d4b2e90,0x28db04c5}},	//   nneq, _hảo_, égan, म्बि,
   {{0x68e70022,0xf09f8104,0x2fc7ccfe,0xe7e9800f}},	// [3840] bejd, _đàn_, hung_, झौता_,
   {{0x2fc78854,0x61e48059,0x2d8b2072,0xf53f0106}},	//   kung_, çilm, _duce_, _svår_,
   {{0x98788038,0x2fc7a0d5,0x13ea0087,0x2d834cff}},	//   _páči_, jung_, рмей_, _dije_,
   {{0x672d4d00,0xe1fa9634,0xc7b3007c,0x6d5acd01}},	//   chaj, иге_, _קבר_, zota,
   {{0xe8949a97,0x6d488125,0x2b4d826c,0x6f0614a2}},	//   паль, ynda, _djec_, _inkc,
   {{0x6b8434b0,0xf8aa0105,0x2fc781ec,0x2d830176}},	//   _liig, करिय, fung_, _gije_,
   {{0xb8f2aaef,0xf3898104,0x6d5acd02,0xf72a80d6}},	//   _वा_, _sản_, vota, иций_,
   {{0x68e7009a,0x67244d03,0x4b34803d,0x6d5acd04}},	//   zejd, nkij, _عکاس, wota,
   {{0xf3898104,0xf7730039,0x6d5acd05,0x1ee8803d}},	//   _bảo_, וקה_, tota, لوژی_,
   {{0x61300004,0x6d48cd06,0xd83881a1,0x23668168}},	//   _hälf, unda, _seču_, lloj_,
   {{0x6d5a92bf,0x67244d07,0x6d48cd08,0xd7ef80f7}},	//   rota, kkij, rnda, _لكل_,
   {{0x51871454,0x78baa651,0x6d5acd09,0x67242a0a}},	//   жува, _hdtv, sota, jkij,
   {{0x6d5acd0a,0x3f8c84b9,0x9f4c80f7,0xb5fb046d}},	//   pota, _hudu_, _ordú_, _ayán,
   {{0x3f8ccd0b,0x6d5a8079,0x0e8e819d,0x2d8b01d0}},	//   _kudu_, qota, _gịrị_, _ruce_,
   {{0x28d28076,0x69c2cd0c,0x637192f1,0x29050850}},	//   _सानि, hroe, låne, ıla_,
   {{0x6d4e026c,0x7d18cd0d,0x2bc9016f,0x2d834d0e}},	//   _ajba, _hovs, ांसा, _sije_,
   {{0x672d4d0f,0x7bc8973c,0x2fc781ec,0x80cd8035}},	// [3850] rhaj, ludu, zung_, सलमे,
   {{0x672d022e,0x2d8b02a5,0xf09f8028,0x850512c6}},	//   shaj, _vuce_, _đào_, राइट_,
   {{0x80c48778,0x3eb98110,0x2d8b00a4,0xd25100d7}},	//   _राजे, ųsti_, _wuce_, _زنگ_,
   {{0x7d18cd10,0xdceb9e03,0xa4a5826b,0x6724026c}},	//   _lovs, _čiči, _afọ̀, ckij,
   {{0x69c280c9,0x2fc7cd11,0x7bc880b8,0x2b4d8168}},	//   groe, wung_, hudu, _vjec_,
   {{0x2fc7cd12,0x3f8cadcf,0xa91db7bc,0x7d18976d}},	//   tung_, _budu_, _kuži, _novs,
   {{0x6371816d,0xe8d900ff,0x2fc781ec,0xa91d80c3}},	//   tånd, _quỹ_, uung_, _juži,
   {{0x2fc7cd13,0x7bc8cd14,0x3f8ca11d,0xc61200ab}},	//   rung_, dudu, _dudu_, _সেটা_,
   {{0x2fc7cd15,0x6b840006,0x2d9980f1,0x3d000072}},	//   sung_, _riig, ëse_, राचे_,
   {{0x2fc78886,0xee368084,0xc588801c,0x799bcd16}},	//   pung_, яны_, _gồm_, _ituw,
   {{0x3f8c8041,0x798d0c53,0x7bc8cd17,0x46cb001b}},	//   _gudu_, _auaw, gudu, िलाह,
   {{0x09e6091d,0x26dd8578,0x1becc1d0,0x612f805f}},	//   помн, _ubwo_, _जनरल_, _bølg,
   {{0xb0d2ba6a,0x6d890038,0xa2d394d5,0x6ed091be}},	//   _सामग, _zľav, _डान्, _धातु,
   {{0x867a8051,0xfe708077,0xa91d856f,0x14c7016f}},	//   _פרסו, _شدن_, _buži, _लागण,
   {{0xab99987e,0x67244d18,0x7bc881cc,0xed5981a1}},	//   _اختر_, tkij, cudu, juži_,
   {{0x6d41cd19,0x612f86be,0xa91d8025,0x753c0668}},	//   lila, _følg, _duži, _smrz,
   {{0x67244d1a,0x9c7c911b,0x5bdb9a4d,0x6443008b}},	// [3860] rkij, ječj, _बहुव, únin,
   {{0x6d41be03,0x61e404be,0x6abbcc22,0x4d630073}},	//   nila, _ipil, _aduf, екув,
   {{0x711b0158,0xa7fc8059,0x3d0c86a7,0x28d283a4}},	//   _הויפ, _ayın, ़ाते_, _साबि,
   {{0x6d41c8e9,0x6d890253,0xeb9680be,0x61e400b9}},	//   hila, _džab, לדער_, _kpil,
   {{0x291a4d1b,0x6d41cd1c,0x61300106,0xc33301c6}},	//   _kopa_, kila, _välf, עוד_,
   {{0x25a0481e,0x612b0006,0x291a0009,0x27fe80b9}},	//   mpil_, _küla, _jopa_, _prtn_,
   {{0xc44809d7,0xfaa692a0,0x3d090075,0xd7fa802e}},	//   _بیان_, _наво, सारे_, сул_,
   {{0xf3898104,0x96eacbc4,0x69c286a8,0x61300106}},	//   _cảm_, ська_, proe, _fälg,
   {{0x7d18a840,0x4ac60072,0x3f8ccd1d,0x6f19cd1e}},	//   _povs, _वाजव, _wudu_, _dowc,
   {{0x6aad4d1f,0x7bc88886,0x3f8c89ab,0x63bc84e8}},	//   _seaf, tudu, _tudu_, árno,
   {{0x1e86ac87,0x6db5817b,0x61e44d20,0xd12f8872}},	//   _елем, _aşağ, _apil, _حمل_,
   {{0xa91dcd21,0x9c7c81d0,0x212c8362,0x61e40f35}},	//   _ruži, lečk, _hldh_, _bpil,
   {{0x637f00eb,0xc3338039,0xa91d8110,0xd7098054}},	//   _jūni, תור_, _suži, वारथ_,
   {{0x6b9c00d2,0x6d5e012b,0xa91d80c3,0x256f02f1}},	//   _otrg, jopa, _puži, küla_,
   {{0x6d5e4d22,0xd1488028,0xf99f06c0,0xaac6016f}},	//   dopa, yễn_, spè_, _वाचक,
   {{0x8f9b810f,0xf09f80ff,0x798d05ee,0x6491007a}},	//   מילי, _đàm_, _tuaw, zžič,
   {{0xbf1d053e,0x78838019,0x9f5e8168,0x320002d6}},	// [3870] _नवीन_, _kívü, _artë_, _griy_,
   {{0xf9940451,0xa91d803b,0x9c7ccd23,0x612f806a}},	//   _ארץ_, _tuži, ječk, _køle,
   {{0x44274d24,0x25a00420,0x799b8cab,0xa02206ae}},	//   án_, apil_, _stuw, ööta,
   {{0x394300eb,0xaabf0f0a,0x99990035,0xceeb01f9}},	//   lijs_, ्लिक, mysł_, _اردن_,
   {{0x6d41cd25,0x6d5e4d26,0xa2c006f0,0x442100b9}},	//   yila, bopa, _वयस्, syh_,
   {{0x6d41cd27,0x5d8500d5,0x394300eb,0x61300f02}},	//   xila, _زلزل, nijs_, _välg,
   {{0x81e300ab,0x213e8168,0x6e2002f1,0xe7398b7d}},	//   নটি_, _dmth_, _ümbr, жей_,
   {{0x6604cd28,0x28d281a2,0x6fcf816f,0x6d41cd29}},	//   _šika, _साथि, संबं, wila,
   {{0x2731cd2a,0x3f868176,0x80ce064a,0x0609804a}},	//   _láng_, _diou_, _ताले, інок_,
   {{0x7af60201,0x7aeb81ec,0x69cb8f8e,0x81e30264}},	//   _sayt, legt, muge, নটা_,
   {{0x61e433b7,0x291a00ab,0x7af64d2b,0xa3a8816f}},	//   _spil, _ropa_, _payt, खील_,
   {{0x7af6011c,0x291a4bd3,0xf1d18aad,0x2d8b85e4}},	//   _qayt, _sopa_, _समान, íces_,
   {{0x6d41cd2c,0xdb1b0364,0x69d9a476,0x69cb9eea}},	//   pila, yttö, ntwe, nuge,
   {{0x61e488c5,0x612f8b40,0xafe61bc6,0x6d418438}},	//   çili, _føle, могл, qila,
   {{0xb8f6053e,0xe0d200d7,0x67030133,0x2d8f81c6}},	//   _हा_, _یزد_, _ọkai, _huge_,
   {{0xa91d8503,0x2731801c,0xf4128039,0xdbc60074}},	//   _gužv, _dáng_, _יפו_, _köög,
   {{0xb5fb0019,0x2d8f8036,0x6db5811c,0x0d860071}},	// [3880] _szár, _juge_, _uşağ, длан,
   {{0x3eafcd2d,0xc8ca003d,0x28d286ab,0x4176003d}},	//   _legt_, _بودن_, _साधि, _تابس,
   {{0x6d5e4d2e,0x613004b8,0x5fe23841,0x9c7cadad}},	//   ropa, _väld, _पहिल, večk,
   {{0x69d9aebd,0xfbc58beb,0x2bc5861e,0x4a469b8a}},	//   ftwe, _विनम, _विना, мнев,
   {{0xceb31e1f,0x63760c58,0x3cee816f,0x6d5e4d2f}},	//   _שיש_, mánd, _असले_, popa,
   {{0x332d86cb,0xfbc61ff8,0xcf9a84ae,0x7bc30144}},	//   _elex_, _обго, оји_, ánuc,
   {{0x399404b8,0x9c7c826f,0x3d119862,0x2d8f91e6}},	//   _läs_, rečk, ताने_, _auge_,
   {{0xc5888028,0x63760511,0x2d8f89ab,0x2d87a88c}},	//   _hồi_, nánd, _buge_, _aine_,
   {{0x2d878012,0x6e24018c,0xc62000ab,0x9c7ccca8}},	//   _bine_, nyib, _নেতা_, meči,
   {{0x2d87cd30,0x9c7c8353,0x2d8f805c,0x2b40009f}},	//   _cine_, leči, _duge_, _amic_,
   {{0x2d8786be,0x69c04d31,0xa3a88006,0xd6cfb8fc}},	//   _dine_, ámen, खीं_, _ит_,
   {{0x2d878943,0x3d050063,0x7d1c02be,0x80da8aed}},	//   _eine_, _होने_, _lors, प्रे,
   {{0x2d878653,0x27318028,0x7d1c00c9,0x660f816d}},	//   _fine_, _sáng_, _oors, äckt,
   {{0x7d1c0cde,0x3eaf8a0f,0x6602cd32,0x2d8784b9}},	//   _nors, _zegt_, _irok, _gine_,
   {{0x39434d33,0xc58880ff,0x69cb81ec,0xdfd80081}},	//   rijs_, _nồi_, zuge, мът_,
   {{0x9c7c82fd,0x63760511,0x15f282f1,0x2d87cd34}},	//   ječi, gánd, _अनार_, _zine_,
   {{0x171b8158,0x2d878214,0xe78433e5,0xbf1f0105}},	// [3890] קומע, _yine_, туро, _यकीन_,
   {{0x7d1c1137,0x2bc58c46,0xad9b0118,0xc58880ff}},	//   _cors, _विमा, _crúa, _bồi_,
   {{0xe3b89014,0xe1ff0216,0x6376016a,0x7c2d8041}},	//   nsı_, lvó_, bánd, _ƙari,
   {{0x32559bbf,0x637605e4,0x0f2700e8,0x66028102}},	//   нвер, cánd, _цьом, _orok,
   {{0x7d1c15f8,0x2bc58dbc,0x7aebcd35,0xdddd009a}},	//   _fors, _विभा, regt, _wysł,
   {{0x69cbcd36,0x7d1c4d37,0x70c9835a,0x69d98a10}},	//   ruge, _gors, रलेल, rtwe,
   {{0x6d45009c,0x6602cd38,0x3d0506a7,0x69cbcd39}},	//   miha, _arok, _होये_, suge,
   {{0x6d45028a,0xf7718829,0x2d87cd3a,0x69c60f06}},	//   liha, دات_, _sine_, yrke,
   {{0x2a6901c5,0x78b508ae,0xf1a78a4c,0x79888372}},	//   _nyab_, kazv, _іран, _fidw,
   {{0x6f1d4d3b,0x6e9f864a,0x28df0540,0x6d454d3c}},	//   _losc, _ग्रु, _पॉलि, niha,
   {{0x2d87cd3d,0x934601bb,0x6b898019,0x69b20074}},	//   _vine_, енне, _kieg, _अबही,
   {{0x65959a18,0x6602805f,0xdd958190,0x637603a8}},	//   _заду, _frok, _зады, xánd,
   {{0xed4ecd3e,0x6b89cd3f,0x2d87cd40,0x6d454d41}},	//   _бо_, _mieg, _tine_, kiha,
   {{0x6b89cd42,0x412a00e8,0x2bd003eb,0x2eed874c}},	//   _lieg, чого_, _हमला, leef_,
   {{0xdee6239f,0x637602ba,0xd466cd43,0xd0074d44}},	//   нови, tánd, _пише_, нере_,
   {{0xc5888104,0x6729cd45,0x6f1d4d46,0x6b89cd47}},	//   _rồi_, nkej, _cosc, _nieg,
   {{0xee3a1506,0xdcf40024,0x7ae40a6d,0x6d4504be}},	// [38a0] чна_, šačk, _ibit, fiha,
   {{0x7d1c0079,0xa91d826f,0x63760511,0x98a78110}},	//   _qors, _mužs, sánd, minė_,
   {{0x7d1c0352,0x20c9853f,0x6f1d4d48,0x798880dd}},	//   _vors, _राजध, _fosc, _ridw,
   {{0x28d28f85,0xeb92893f,0x6b89cd49,0x7f440079}},	//   _साहि, אָס_, _cieg, qiiq,
   {{0x7d1c1da3,0x6b89a510,0x6376256c,0xf38a001c}},	//   _tors, _dieg, cáne, _cải_,
   {{0x6604816b,0x41d1864a,0x4425cd4a,0xf38a0129}},	//   _šiko, _समरस, kyl_, _dải_,
   {{0x50b78013,0xfc1a2105,0x2d998118,0x7ae448a8}},	//   ردود_, _عقرب_, ísen_, _obit,
   {{0x26d2033e,0x20d29199,0x3d0e01ab,0x28d2861e}},	//   ngyo_, _सावध, ठावे_, _सावि,
   {{0xdb0227c5,0x020680e8,0x2d8a166a,0x657e0866}},	//   mplè, _язан, _kibe_, omph,
   {{0x44258c0b,0x7ae44d4b,0xe7b10035,0x645d8085}},	//   fyl_, _abit, _जबलप, əsiz,
   {{0x290c83c3,0xd5c28f12,0x61f604fe,0x63ae008e}},	//   _inda_, _शिवज, _asyl, _jwbn,
   {{0x291ecd4c,0xb605826c,0xf09f801c,0xbacf00ab}},	//   _hota_, _bošč, _đài_, িজ্ঞ,
   {{0x291e8500,0xe5a387b6,0x6d4501d4,0x8c2400ab}},	//   _kota_, _бичи, yiha, _যেমন_,
   {{0x656180a9,0x2d8a32ca,0x7ae402ec,0x291ecd4d}},	//   colh, _nibe_, _ebit, _jota_,
   {{0xb4be8576,0xf2b000ab,0x291ecd4e,0x6f1d00e1}},	//   ेली_, _কারণ, _mota_, _posc,
   {{0x63763b65,0x628d0b67,0x6d451fbb,0x63788118}},	//   táne, _ugao, wiha, nínd,
   {{0x290c803a,0x6d454217,0x273500f2,0x6b89816a}},	// [38b0] _onda_, tiha, _lång_, _rieg,
   {{0x7afd2053,0x637604e8,0x7aef4d4f,0x6b89cd50}},	//   ldst, ráne, lect, _sieg,
   {{0x98c4025d,0x6d454689,0x6b89cd51,0x63baae2b}},	//   _ссыл, riha, _pieg, nstn,
   {{0x290c8852,0x6d450859,0x6b8981b9,0xe8d90129}},	//   _anda_, siha, _qieg, _tuỳ_,
   {{0x69dd4d52,0x7aef0012,0x291ecd53,0x6b8980eb}},	//   ntse, iect, _bota_, _vieg,
   {{0xa069bf21,0xe61f001c,0x290c808e,0xf38a00ff}},	//   мала_, _ngôi_, _cnda_, _vải_,
   {{0x6b89b086,0x2bc586a7,0x629687d9,0x63ba875f}},	//   _tieg, _विधा, ıyor, jstn,
   {{0x3d054d54,0x290ccd55,0xf38a0028,0x06098a13}},	//   _होते_, _enda_, _tải_, дник_,
   {{0xb4be800f,0x67298057,0x69dd4d56,0xceb403c8}},	//   ेलू_, rkej, jtse, ניץ_,
   {{0x7afbcd57,0x69db913b,0x3f8b005c,0xdb024d58}},	//   _haut, _ique, _licu_, mplé,
   {{0x273500f2,0x7aef0806,0x7afbcd59,0x7afd00f3}},	//   _gång_, fect, _kaut, fdst,
   {{0x7afbb96c,0x3947cd5a,0x98a781e2,0x3dc900ee}},	//   _jaut, lins_, tinė_, kraw_,
   {{0x7afbcd5b,0x69cf017f,0x2f188061,0x656182df}},	//   _maut, guce, _négy_, polh,
   {{0x6606813c,0x3dc94d5c,0x7afbcd5d,0x39479ed6}},	//   ække, draw_, _laut, nins_,
   {{0xa067246b,0x69dd0613,0x18674d5e,0x6378cd5f}},	//   вара_, atse, вари_, líne,
   {{0xed59803b,0xc6c31056,0xcf9280be,0x69cf4d60}},	//   drži_, ийск, שטן_, buce,
   {{0x3dc93cc0,0x2d8a4d61,0x1e863941,0x3f8b248e}},	// [38c0] graw_, _pibe_, тлам, _dicu_,
   {{0x61ed81b9,0x3947cd62,0xad9b4d63,0x657e4b6b}},	//   ħall, jins_, _trún, umph,
   {{0x69db938d,0x7afbcd64,0xf1bf3240,0x3ea94d65}},	//   _aque, _baut, nyán_, bbat_,
   {{0x291e809f,0x776d01df,0x7afbb672,0xf1bf0144}},	//   _sota_, clax, _caut, iyán_,
   {{0x7fe203a4,0x291ecd66,0x2b4681a8,0x8c9605a8}},	//   _पहुँ, _pota_, rioc_, _арбі,
   {{0xdca33631,0x64a30f04,0xb5fb0032,0x7afb89c4}},	//   _вари, _вара, _ayáw, _eaut,
   {{0x154330fe,0x7aef1220,0x291eaeab,0x7afb80e7}},	//   _терм, yect, _vota_, _faut,
   {{0x7aef4d67,0x7afbcd68,0x8a069c60,0x394783ac}},	//   xect, _gaut, _избе, ains_,
   {{0x291ebde1,0xae0503b7,0xe0da8fbb,0x7aef01e0}},	//   _tota_, रियन_, _ова_, vect,
   {{0x2176975e,0xb4be8f85,0x69cf02a5,0x39478cf8}},	//   _рубр, ेले_, vuce, cins_,
   {{0x7aef4d4f,0x3cfa009a,0x2005acf6,0x33200980}},	//   tect, _उसने_, _grli_, _boix_,
   {{0x69cf00e7,0x63bacd69,0x65c681e5,0x46a68081}},	//   tuce, rstn, _абда, _радв,
   {{0x7aef0918,0x61e980b9,0x6130039c,0x9c7c82d4}},	//   rect, _xpel, _säla, veču,
   {{0x69dd05e1,0x273513c2,0xdc558061,0x7bde1de0}},	//   rtse, _måne_, ئریک, ktpu,
   {{0x6d488c52,0x5ea400ab,0x7aef0cf7,0x69dd4d6a}},	//   mida, _ওয়ে, pect, stse,
   {{0x6d4887a3,0x3ea907d5,0x6376001b,0x3947cd6b}},	//   lida, ubat_, ránc, zins_,
   {{0xb0d29cfa,0x3ea9229a,0x7afbcd6c,0x3f930079}},	// [38d0] _सांग, rbat_, _raut, _wuxu_,
   {{0x6d489313,0x3947a651,0x7afbcd6d,0x63763b0f}},	//   nida, xins_, _saut, mána,
   {{0x61e9ac5c,0x7afbb0b2,0x63764d6e,0xc3160264}},	//   _spel, _paut, lána, াসরি_,
   {{0xfaff00f1,0x6d48cd6f,0xe3b000f7,0xc2c480f7}},	//   ndë_, hida, ترك_, ليمي,
   {{0x3947cd70,0xa2d601fe,0x6b8d0bb1,0xe9df4d71}},	//   tins_, _भास्, _miag, ntú_,
   {{0xf1d58a61,0x30758009,0x7afbafe3,0xa805002a}},	//   डंबन, луйс, _waut, coñé,
   {{0x7afbcd72,0x3947cd73,0xf7458fc8,0xdcfc298e}},	//   _taut, rins_, леко, _sirć,
   {{0x3947cd74,0x6b8d1083,0xdb0200e7,0xe1f3803d}},	//   sins_, _niag, pplé, _پسر_,
   {{0x6d48b72a,0x90e78eca,0x2121008e,0xa194a639}},	//   fida, _لسان, _oohh_, _вауч,
   {{0xee36979e,0x5ba980e2,0x63764d75,0xdb1c8176}},	//   унь_, нком_, dána, _avrè,
   {{0x6b951e86,0x6b8d4d76,0x672d4d77,0x20058037}},	//   _juzg, _biag, kkaj, _urli_,
   {{0x257982be,0x6b954d78,0x11d6102a,0x672d0115}},	//   dèle_, _muzg, лігр, jkaj,
   {{0xfce5818b,0x2bc58a3a,0xaad1800f,0x9f5e383f}},	//   _боло, _विवा, _हाईक, ítí_,
   {{0x6d488510,0x6f1b8052,0xb602801b,0x399993f8}},	//   cida, ljuc, čátk, _mès_,
   {{0x74d89008,0x3999cd79,0x3d1706af,0x69cb8192}},	//   _मातृ, _lès_, नाने_, hrge,
   {{0x3d118e18,0x6d890fda,0x69c4800f,0x6b8d0bb1}},	//   तावे_, _džam, _रिली, _giag,
   {{0xa3b603b7,0x6e298393,0xc69280be,0x80b300ab}},	// [38e0] चीन_, nyeb, מאן_, _জার্,
   {{0xdff38935,0xc8d28670,0xfd9e8135,0xe6d0928a}},	//   _आनंद_, _साइट, _jụọ_, _सञ्ज,
   {{0xa3bb80dc,0x6ab60059,0x6f1b817f,0xfd9e8135}},	//   ेंट_, _keyf, kjuc, _mụọ_,
   {{0x2ca70a0b,0x6d48cd7a,0xe73a0364,0xe29aa6ab}},	//   ında_, zida, _чем_, хад_,
   {{0x82d70158,0xb17b0bfa,0x59f8cd7b,0x6d48cd7c}},	//   רונג_, ståe, теля_, yida,
   {{0x399982be,0x6ab6007b,0x660400b4,0x7ae2a11c}},	//   _dès_, _leyf, mvik, sfot,
   {{0xe3a7896c,0x6d489313,0xd90d8bca,0x6604075e}},	//   _در_, vida, ظیم_, lvik,
   {{0xb8cb809a,0x3999cd7d,0xcfe780f7,0x2cba0122}},	//   _क्_, _fès_, افيه_, lapd_,
   {{0x10a68d31,0x66044227,0x6b8d0014,0xa534b0ed}},	//   _бизн, nvik, _riag, инич,
   {{0x46a483dd,0x6b8d4d7e,0x23692051,0x2bc58c2d}},	//   _ग्रह, _siag, _skaj_, _विशा,
   {{0x2056a5c4,0x6d488511,0x40938307,0xd6c491fb}},	//   _стар, rida, _المر, _نمای,
   {{0x6d48cd7f,0x80d70b86,0x2bc581a2,0x27ec82f7}},	//   sida, _बाहे, _विरा, _ipdn_,
   {{0x7c3a8065,0x6d48cd80,0xfe728065,0x96b985e9}},	//   sztr, pida, _ادا_, _руху_,
   {{0x98a78024,0x660414a2,0x63764084,0x68fe0722}},	//   čići_, dvik, rána, _capd,
   {{0x629d0117,0xb8fd0bb8,0x09d18b84,0x67228282}},	//   pcso, _डा_, _सम्य, _kooj,
   {{0x67228079,0x613016d2,0x637d09c4,0x96f82109}},	//   _jooj, _häll, déng, лест_,
   {{0x6b82811f,0x613000f2,0x799600fc,0x672d4d81}},	// [38f0] dmog, _käll, _guyw, rkaj,
   {{0x672d4d82,0x627c0051,0x61300406,0x45d40470}},	//   skaj, _אנחנ, _jäll, софс,
   {{0xa9260029,0x5b27814c,0x53a400f7,0xbc070110}},	//   _dažā, льда, مملك, ычай,
   {{0x2d8ecd83,0x637887e0,0x61ed01bc,0xade58074}},	//   _life_, vínc, _kpal, _कहलन_,
   {{0x99d78013,0xd5af0117,0x6d4b01df,0x7aff02a6}},	//   اتصا, _رہا_, égas, _maqt,
   {{0x2cf3835a,0x34941b62,0xa4f3816f,0x637d0333}},	//   _असेल_, _гарр, _असेच_, lénd,
   {{0xad9b10ab,0x60de86c0,0xfd9e8870,0x25a902c4}},	//   _orúk, òpma, _rụọ_, lpal_,
   {{0x6d588699,0x637d157a,0xcf2581a8,0x260906af}},	//   _ajva, nénd, شرعي, सिपी_,
   {{0xed5998a0,0xef1684d9,0x3d11801b,0xfd9e8133}},	//   кои_, рмы_, ताले_, _pụọ_,
   {{0x61fb9f3c,0xd1678098,0xed4580e8,0x63789e4f}},	//   _isul, _съби, рноп, mína,
   {{0x768b8201,0x61ed4d84,0xf77081f9,0xad9b1434}},	//   _böyü, _apal, _کال_, _brúk,
   {{0xe2860139,0x60c501a8,0x6b6607b6,0x273b846d}},	//   илни, _adhm, ркма, _dànù_,
   {{0x7ae98f5d,0x61300b2f,0x998081ac,0x7bc33878}},	//   _mbet, _fäll, šiť_, ánuj,
   {{0x613004b8,0xdca59317,0x25bf89ca,0x64a59269}},	//   _gäll, _таки, msul_, _така,
   {{0xa06a05d3,0x80d7090f,0x186a0767,0x7ae9b99c}},	//   тава_, _बारे, тави_, _obet,
   {{0xb6a602bc,0x660400e8,0x7d1cc94b,0x63762ac8}},	//   риал, tvik, örsv, máno,
   {{0x7dc60077,0x25bf802e,0x63760019,0x66030012}},	// [3900] شقان, nsul_, láno, опта,
   {{0x3f8f8503,0x66044d85,0x3ead8214,0x127b00be}},	//   _ligu_, rvik, hbet_, _באפע,
   {{0xc5f2a885,0x3cdd8996,0xf5368158,0x66044d86}},	//   _अन्य_, _खाने_, סטער_, svik,
   {{0x25bf8074,0x637d43d6,0x78bc4d87,0x79a69c56}},	//   ksul_, cénd, larv, арке,
   {{0x6b82ad0e,0x6722cd88,0x63a94d89,0x23bc0032}},	//   rmog, _rooj, _čene, _bájá_,
   {{0x637d3db4,0x67228074,0x78bc1be8,0x31678267}},	//   méne, _sooj, narv, gonz_,
   {{0xd7fa8c6e,0x61fbcd8a,0x3f8f8326,0x02b60072}},	//   тул_, _esul, _bigu_, _अजून,
   {{0x3ea04d8b,0x6130016d,0xab278323,0x61348362}},	//   ncit_, _säll, _коса_, _dàla,
   {{0xb5fb0019,0x66e286ce,0x3f8f811b,0x3dcd8176}},	//   _száz, क्षक_, _digu_, grew_,
   {{0x96a68540,0xdce182d4,0x61e2cd8c,0x612b4d8d}},	//   _ट्रॉ, bolč, mtol, _tüli,
   {{0x61ed4d8e,0xa41480c8,0x3ead8ecb,0x6d890267}},	//   _spal, ান্য_, bbet_, _džah,
   {{0x61ed162a,0x27f80114,0x61e28c53,0x3dc002d5}},	//   _ppal, dwrn_, otol, ksiw_,
   {{0x61e2cd8f,0x61300364,0x9da78098,0x2d968e0b}},	//   ntol, _täll, _къща_, _трес,
   {{0x7523cd90,0x7aff0079,0x2703001c,0x3cdd83db}},	//   _gonz, _waqt, _ổn_, _खाये_,
   {{0x637d01df,0xd6db10f8,0xb5fb0019,0xd48f9d28}},	//   ténd, кта_, _nyár, _фр_,
   {{0x75238144,0x6130156e,0x6568cd91,0x3f8f008b}},	//   _zonz, _jälj, lodh, ögu_,
   {{0xdb02016d,0x442c955c,0x637d4d92,0x78bc3eeb}},	// [3910] tslö, lyd_, rénd, barv,
   {{0x25a9036e,0x78bc4d93,0x929d8035,0xb912819d}},	//   rpal_, carv, _małe, renụ_,
   {{0x443ecd94,0x49140054,0xdb020338,0x656f8866}},	//   nzt_, दारो_, rslö, îchi,
   {{0x2731826f,0x63760019,0x69ce001b,0x25a90061}},	//   _ráno_, jánl, _तिमी, ppal_,
   {{0x877a004c,0x290102e7,0x10a58abe,0xfaff0168}},	//   _תארי, _kaha_, билн, llës_,
   {{0x63a4803e,0x29034d95,0xb34784b7,0x3eb90aa2}},	//   _činn, ndja_, _saħħ, _hest_,
   {{0x29013832,0xb5fb0019,0x01380039,0x2d990c86}},	//   _maha_, _gyár, שרות_, _huse_,
   {{0x3eb90610,0x81e680c8,0x6378826f,0x25a680ee}},	//   _jest_, _বছর_, pína, _btol_,
   {{0xf2d28159,0x6e2d4d96,0x3eb9120b,0x61fb8573}},	//   _מען_, nyab, _mest_, _usul,
   {{0xf9908872,0x442c8355,0x68f54d97,0x25bf802e}},	//   _قبل_, fyd_, jezd, rsul_,
   {{0x442ccd98,0x237f81c0,0x3cfa009a,0x2d914d99}},	//   gyd_, _khuj_, _उससे_, _mize_,
   {{0xe6958013,0x25bf94e4,0x637601ac,0x05c70072}},	//   _الإد, psul_, ráno, _लिंब,
   {{0x8e8580f7,0x78bc3d47,0x29014d9a,0x6568cd9b}},	//   _الشه, tarv, _baha_, bodh,
   {{0x7d1c80f2,0x753acd9c,0xa0a30081,0x63762ac8}},	//   örst, chtz, зард, páno,
   {{0x29010b06,0x3eb94d9d,0xd9430e8e,0x236dcd9e}},	//   _daha_, _best_, чери, _okej_,
   {{0xdd9200f7,0x637d0061,0xdceb8372,0x78bc28be}},	//   كور_, téne, _bugħ, sarv,
   {{0x61300364,0x3bc38201,0x2d910c12,0x29010362}},	// [3920] _jälk, lıq_, _bize_, _faha_,
   {{0x3eb90006,0x3ea04d9f,0x2d9101d6,0x29010db1}},	//   _eest_, scit_, _cize_, _gaha_,
   {{0x41760986,0xdd8f0b76,0x3eb94da0,0x69c401ac}},	//   _پاکس, روم_, _fest_, _hvie,
   {{0x2cb84da1,0x61e2a234,0x69c40110,0x2ca10046}},	//   _werd_, ttol, _kvie, achd_,
   {{0x237f81c0,0x2d9102d6,0x6130062c,0x7c3e0061}},	//   _dhuj_, _fize_, _nälk, szpr,
   {{0x613004b8,0x6f041e26,0x7bc1cda2,0xada325f5}},	//   _sälj, ldic, kslu, _харл,
   {{0xb9008d38,0x61e2cda3,0x443e2fdb,0xa7fc880a}},	//   _था_, stol, _åt_, _ayır,
   {{0x6f040c6b,0x29033804,0x6378816b,0x3f84808e}},	//   ndic, zdja_, míno, ummu_,
   {{0x61304da4,0x442c8355,0x612b13f4,0xa80583a8}},	//   _välj, wyd_, _kült, _poñí,
   {{0x443e834a,0x442c879f,0x69cf0699,0xccfa8eef}},	//   tzt_, tyd_, vrce, ући_,
   {{0x29014da5,0x68f51024,0x351b00be,0x78ba80eb}},	//   _raha_, vezd, אוינ, _ietv,
   {{0x2901003d,0x442ccda6,0x443e81ec,0x6aa2b83e}},	//   _saha_, ryd_, rzt_, ncof,
   {{0x667692dc,0x443eb380,0x4f6580f7,0x69cf4da7}},	//   _ادار, szt_, _بالف, urce,
   {{0x3eb90006,0x69c42e75,0x70d3016f,0x2d9912ec}},	//   _sest_, _dvie, तलेल, _ruse_,
   {{0x403423b2,0x3cddcda8,0xdbf1001b,0x29034da9}},	//   перс, _खाते_, _příj, rdja_,
   {{0x2d914daa,0x6e2d4dab,0x2d994dac,0x6d5c4dad}},	//   _size_, tyab, _puse_, _ajra,
   {{0x29010074,0x3eb94dae,0x69c005e4,0x7aed4daf}},	// [3930] _taha_, _vest_, ámet, _ibat,
   {{0x78bacdb0,0xdb1b00f7,0x6f028834,0x3eb90039}},	//   _netv, istí, _laoc, _west_,
   {{0x6e95153d,0x69c41a35,0x6e2d0359,0x3eb94db1}},	//   _мину, _zvie, syab, _test_,
   {{0x6f02817f,0x2d91018f,0x98a78110,0xd2518829}},	//   _naoc, _wize_, tinį_, ونا_,
   {{0x6d4a8082,0x7aed4db2,0x4cd080ab,0x200cc2d8}},	//   _omfa, _mbat, ত্যু, _ardi_,
   {{0x527c00be,0x612b4db3,0x7bc1875e,0x98a78084}},	//   אנדא, _gült, yslu, rinį_,
   {{0x7aed4db4,0xe809873c,0x69a01094,0xb8f18072}},	//   _obat, विधा_, _गंभी, _वय_,
   {{0x3eb987ca,0x6d4a83c3,0xf83804de,0x3d17131d}},	//   úst_, _amfa, מנות_, नावे_,
   {{0x78bab865,0x673bcdb5,0x200c9c24,0xa3cb8075}},	//   _fetv, rhuj, _erdi_, _लिह_,
   {{0x28e0890a,0x7aed1eda,0x613000f2,0xe8098540}},	//   _नायि, _abat, _välk, विदा_,
   {{0x69c444da,0xe8559459,0xc4d201c6,0x09be8264}},	//   _svie, _بناد, וגי_, _উৎপা,
   {{0xf8a9004c,0x7bc1cdb6,0x3f9a012b,0x28dc000d}},	//   _יש_, rslu, _rupu_, _बाहि,
   {{0x2bc5a8d7,0x7bc1a48a,0x3ebfcdb7,0x4adea8bf}},	//   _विका, sslu, maut_, फ्टव,
   {{0xb17b00f2,0x3f9a4db8,0x7aed0dde,0x7bc1888b}},	//   stån, _pupu_, _ebat, pslu,
   {{0x273c0013,0x2d9f82be,0x6609cdb9,0xa2e60081}},	//   _líne_, lque_, lvek, _дойд,
   {{0x7d03cdba,0x637d3862,0x6f040362,0x7aed01bc}},	//   _hans, rénc, udic, _gbat,
   {{0x7d03cdbb,0x2d9fcdbc,0xa526035f,0x69c400e1}},	// [3940] _kans, nque_, омад, _uvie,
   {{0x2bed823c,0x3f9a0870,0x29040029,0x2d9f9f1a}},	//   _जहां_, _tupu_, ēmas_, ique_,
   {{0x7d03cdbd,0x320d80b9,0x273889c4,0x3ebf8035}},	//   _mans, _arey_, _léna_, kaut_,
   {{0x7d03cdbe,0x78ba979d,0xfa2580ab,0x320d802a}},	//   _lans, _setv, _মেইল_, _brey_,
   {{0x394e82be,0xe8facdbf,0x3d050074,0x7d0388dc}},	//   tifs_, илд_, _होके_, _oans,
   {{0x69c2879f,0x97a68a95,0x7d03871f,0x26c00081}},	//   rsoe, орил, _nans, laio_,
   {{0xdfd08307,0x256f0065,0x3d17000f,0xe80d0327}},	//   رية_, rült_, नारे_, हिया_,
   {{0xa2d601ab,0x7d03bd43,0x03679d27,0x644180b9}},	//   _भाग्, _aans, _диск_, dzli,
   {{0x7d03cdc0,0x9989811a,0x260006f0,0xdb1e8118}},	//   _bans, šaš_, रिटी_, supó,
   {{0x2bd12c4c,0x7aed2414,0x200c807a,0x6b9c4dc1}},	//   _हिमा, _sbat, _trdi_, _kurg,
   {{0x7d03cdc2,0x3ebf81ec,0x66e6cca2,0x6f028289}},	//   _dans, baut_, _можа, _taoc,
   {{0x6b9c4dc3,0xe3af826a,0x3b068609,0x2d9f8144}},	//   _murg, کری_, ndoq_, bque_,
   {{0xed5ac094,0xda7b4dc4,0x637d2bc6,0x7ae080b9}},	//   _код_, рян_, géna, _mcmt,
   {{0x6d4acdc5,0x7d03a2ea,0xa3b5864a,0x41d280d4}},	//   _umfa, _gans, _चौक_, _सिनस,
   {{0x2731801c,0x28dc143e,0x69c00118,0x2f190198}},	//   _bánh_, _बारि, ámer, бовь_,
   {{0x4c3b8051,0x7aed4dc6,0x2fcd0668,0x2731801c}},	//   _כתוב, _ubat, čeg_, _cánh_,
   {{0x7d03cdc7,0xd49b4dc8,0x6d5acdc9,0x3d0f816f}},	// [3950] _yans, аре_, onta, _थोडे_,
   {{0x6d5acdca,0xdfdb0021,0x63a48025,0xe6b788fd}},	//   nnta, _към_, _činj, _इज्ज,
   {{0xa2f5835f,0x6d5acdcb,0x6b9c4dcc,0x92dd0264}},	//   зпеч, inta, _curg, ড়ী_,
   {{0xdd9525f5,0x6b9c4dcd,0x659518d1,0x20014dce}},	//   _намы, _durg, _наму, _ishi_,
   {{0x6d581351,0xe9d885a8,0x863503de,0x7e7d0ec3}},	//   čvar, жкі_, _זאָג_, _uzsp,
   {{0x6d5a81c0,0x3f894dcf,0x5ef301bc,0x63764a84}},	//   jnta, lmau_, _ịhọọ, tánk,
   {{0x6b9c16ea,0xc95403c8,0x7d03cdd0,0x6abb8192}},	//   _gurg, ומס_, _rans, _teuf,
   {{0x63761389,0x61300a92,0xef19a206,0x7bc54dd1}},	//   ránk, _väli, сми_, mshu,
   {{0x7d038983,0x3ebf80e3,0x28dc0107,0x30a79fb5}},	//   _pans, raut_, _बालि, _древ,
   {{0x80d701fe,0x644182af,0x69d9c40b,0x63764dd2}},	//   _बागे, tzli, muwe, pánk,
   {{0x7d03821e,0xc4d200be,0x69d9cdd3,0x2d9f8806}},	//   _vans, עגט_, luwe, sque_,
   {{0x2d999313,0x6d5acdd4,0x2905cdd5,0x6441a906}},	//   íses_, anta, _hala_, rzli,
   {{0x2905cdd6,0x7d03cdd7,0x20010326,0x7bc50cd5}},	//   _kala_, _tans, _ashi_, hshu,
   {{0x2907cdd8,0x7d038b40,0x2731801c,0x29fd81ac}},	//   ndna_, _uans, _sánh_, _mňa_,
   {{0x29058b5d,0xb9250135,0x69d983e9,0x26c04dd9}},	//   _mala_, _hapụ_, huwe, taio_,
   {{0x29058079,0x660f0267,0x69d9cdda,0x7bc50bbd}},	//   _lala_, _brck, kuwe, dshu,
   {{0x26c00098,0x9ad301bc,0x0e6306f9,0x96630dff}},	// [3960] raio_, _dịde, ектн, екте,
   {{0x649a20a3,0x69d9cddb,0x26c00ba3,0x69c64ddc}},	//   стар_, duwe, saio_, mske,
   {{0x69c64ddd,0x389b0158,0xc2f100ab,0xa3b60fd5}},	//   lske, _ליינ, য়ারি_, चीं_,
   {{0x23a1809a,0x290799ea,0x637881d0,0xe3c90216}},	//   _mój_, edna_, mínk, _soñé_,
   {{0x2905cdde,0x2d9d84df,0x637602ba,0x660f04a8}},	//   _bala_, _nuwe_, gáni, _grck,
   {{0x6b9c4ddf,0x6f060ad4,0x29fd81ac,0x6d891c9a}},	//   _turg, _hakc, _dňa_, _džas,
   {{0x6d4e4de0,0xb4ca0bf5,0xad9b2a8f,0x7c650060}},	//   _imba, ोली_, _frús, _قافل,
   {{0x91e68f04,0x67244de1,0x29079498,0xceb40085}},	//   _нобе, njij, adna_, nbə_,
   {{0xb0dc11bc,0x20dc09c8,0x637602ba,0x2905cde2}},	//   _बांग, _बांध, cáni, _fala_,
   {{0x6d5acde3,0x613dae07,0x69c64de4,0x612f83ba}},	//   unta, _pèle, dske, _sølv,
   {{0x44444de5,0x3cdd8127,0xd6cf854c,0xa438902a}},	//   nz_, _खारे_, _пт_, ізму_,
   {{0x44444de6,0x6b844de7,0x66e38a74,0xdee68d0e}},	//   iz_, _chig, _गायक_, _ходи,
   {{0x6b8402c1,0x6d4e1b7c,0x6e9380f7,0x95868037}},	//   _dhig, _omba, _كلما, _елде,
   {{0x2bc58894,0x92dd00ab,0x6602cde8,0x25f20074}},	//   _विचा, ড়ে_, _isok, ुबनी_,
   {{0xc86402df,0x63a901a1,0xa4270264,0x776d0118}},	//   етти, _čeno, _মধ্য_, toax,
   {{0x6d4e211f,0x44441a1b,0x7bdacde9,0x3f9e80a4}},	//   _amba, dz_, mutu, _mutu_,
   {{0x7bda81c2,0x44444dea,0x3f890428,0x69c60061}},	// [3970] lutu, ez_, rmau_, cske,
   {{0x7bc5164d,0x2bd106a7,0x660f01f4,0x6b8400fc}},	//   tshu, _हिदा, _vrck, _zhig,
   {{0x25f90063,0x9f5e85a4,0x629a001b,0xe57012c5}},	//   _उनकी_, _esté_, ětov, اطق_,
   {{0x63760333,0x6d4e4ccd,0x6602811b,0x69d9aa5a}},	//   táni, _emba, _osok, tuwe,
   {{0x2905cdeb,0x3f9e8052,0x44440102,0x7bdacdec}},	//   _pala_, _autu_, az_, hutu,
   {{0x63764ded,0x6d4e00dd,0x3f9e989e,0x2905cdee}},	//   ráni, _gmba, _butu_, _qala_,
   {{0x4444009a,0x660d2174,0x7bda87b8,0x64e20072}},	//   cz_, lvak, jutu, _पातळ,
   {{0x2905c9a3,0x05a9835f,0xee398fe7,0x44330748}},	//   _wala_, овий_, жни_, myx_,
   {{0x6d890a20,0x29058e20,0x05b9803d,0xa3df816f}},	//   _užas, _tala_, زگشت_, धून_,
   {{0x6b8403c3,0xb4d7b841,0x7bda854e,0x69c62577}},	//   _shig, िले_, futu, vske,
   {{0xa3d49094,0x7d070b48,0x637d016b,0x25740106}},	//   िंग_, _majs, rénn, mält_,
   {{0x60c3cdef,0x7d070390,0x09e200ab,0x929d809a}},	//   lanm, _lajs, যবসা, _mało,
   {{0xe56e8698,0x612f83ba,0x3f9e8bcf,0x25fd0ad5}},	//   _аз_, _følt, _zutu_, _रैली_,
   {{0x69c60d5b,0x7bdabf29,0x6f098c57,0x673d4df0}},	//   rske, butu, ldec, _alsj,
   {{0x6d41cdf1,0x6b8401e4,0x6f060ad4,0xafe325f2}},	//   mhla, _thig, _pakc, корл,
   {{0x672b88b3,0x6f09a448,0x629b801c,0x69c64df2}},	//   _jogj, ndec, _nguo, pske,
   {{0x09e200c8,0x63a4803b,0x6f064df3,0xfb87004e}},	// [3980] যবহা, _čini, _vakc, _تدوی,
   {{0x44440ad9,0x6378cdf4,0x6d41805d,0x25740106}},	//   tz_, míni, nhla, jält_,
   {{0xd91b0158,0x68fc09ca,0xf7464df5,0x711b00be}},	//   _וויל, merd, _жено, _וויפ,
   {{0x44441013,0x68fc29ed,0x3cfa0063,0x6ea506a7}},	//   rz_, lerd, _उसके_, _कलयु,
   {{0x44442a8e,0xd9469e25,0x6d41810b,0x636803bf}},	//   sz_, меди, khla, mınd,
   {{0x3f9e82a5,0x6d4e4df6,0x636802bb,0xb4d7800d}},	//   _putu_, _umba, lınd, िलो_,
   {{0xd0108d4a,0x613000f2,0x2b0e101c,0x6d41a17a}},	//   الب_, _häls, ियाँ_, dhla,
   {{0x636802bb,0x7bda84a2,0x6d8900d2,0x68fc4df7}},	//   nınd, vutu, _užar, herd,
   {{0x10a68364,0x2d984df8,0x68fc4df9,0x60c389ab}},	//   _жизн, _kire_, kerd, banm,
   {{0x6d41aab6,0x7bdacdfa,0x3f9ecdfb,0x25740106}},	//   ghla, tutu, _tutu_, mäls_,
   {{0x68fc4dfc,0x2d984dfd,0x44388298,0x660d3e30}},	//   derd, _mire_, ár_, zvak,
   {{0x2d984dfe,0x7c4481dd,0x291a01df,0x2bd1123a}},	//   _lire_, _đurđ, _anpa_, _हिसा,
   {{0xd3790025,0x7bda8006,0x636803bf,0x6d418c49}},	//   juće_, sutu, dınd, bhla,
   {{0x6d4184ac,0x7bdac4f8,0xd3790024,0x26c4cdff}},	//   chla, putu, duće_, lamo_,
   {{0xa3cb8610,0x636805c5,0x4fc40678,0x273c0125}},	//   _लिए_, fınd, кста, _sína_,
   {{0x26c4ce00,0x2d982360,0x60c3ce01,0x3995026b}},	//   namo_, _aire_, zanm, _bùsì_,
   {{0xd379003a,0x68fc1c53,0xa3dc016f,0x8af78085}},	// [3990] guće_, berd, णूस_, şəkk,
   {{0x69dd4e02,0x660d0336,0x2d984e03,0x273c026f}},	//   muse, rvak, _cire_, _vína_,
   {{0x2d984e04,0x8af9a2f1,0x69dd4e05,0x61303750}},	//   _dire_, знес_, luse, _vält,
   {{0x26c4ce06,0x490703bb,0xf38a001c,0x6d41816b}},	//   jamo_, िएको_, _bảy_, zhla,
   {{0xfe088104,0x26c4ce07,0x69dd4e08,0xad9b00f7}},	//   _nữ_, damo_, nuse, _grúp,
   {{0x63764e09,0xd122146d,0xde1600be,0x3ea94e0a}},	//   lánt, मायण_, _אַלץ_, lcat_,
   {{0xb9078006,0x69dd1da3,0x60c3ce0b,0x6f0981ec}},	//   _भा_, huse, ranm, tdec,
   {{0x3ea94e0c,0x69dd373a,0xdb1b1bd7,0x7afd0c6b}},	//   ncat_, kuse, nstä, jest,
   {{0x7afd4e0d,0x29d58c3b,0x3f990115,0x68e50229}},	//   dest, _سياس, _misu_, _ochd,
   {{0x69dd0744,0x9a8483c7,0xfe08801c,0x06828071}},	//   duse, _русл, _dữ_, ыгын,
   {{0x116a84c0,0x26c4ce0e,0x973c826c,0xdb1b0106}},	//   _علمی_, bamo_, _suće, kstä,
   {{0x3f990025,0x60c1810a,0xf4120158,0x26c4aff4}},	//   _nisu_, _helm, אפט_, camo_,
   {{0x68fc4e0f,0x60c1ce10,0x69dd0006,0xf38a001c}},	//   terd, _kelm, guse, _xảy_,
   {{0xf1b28051,0x6e20009f,0xfc31987e,0xb606807b}},	//   רסם_, _àmbi, _محب_, sráð,
   {{0x63681010,0x3f9900dd,0x60c1ce11,0x2d980036}},	//   tınd, _bisu_, _melm, _rire_,
   {{0x28dc0665,0x6d5e01e0,0xb5fb06a5,0x68fc4e12}},	//   _बाकि, wnpa, _exám, serd,
   {{0x63680afe,0x6996007f,0xcf92812a,0x3dc92651}},	// [39a0] rınd, _прох, רטן_, gsaw_,
   {{0x63680a0b,0xec098104,0x59c98105,0x26c4bd01}},	//   sınd, _kế_, _रिजर, zamo_,
   {{0x491d0076,0xf5368158,0x2d9806c0,0xd3791be7}},	//   मारो_, עטער_, _vire_, suće_,
   {{0x3ea94e13,0x20570158,0x661b4e14,0x442602a5}},	//   ccat_, _טייל_, _šuke, ćo_,
   {{0x2d878352,0x20058587,0x635c8353,0x798e0c53}},	//   _ohne_, _asli_, nčni, ombw,
   {{0x3f868358,0x7afd4e15,0xdb1b01a3,0x26c48dc5}},	//   _shou_, zest, mstå, wamo_,
   {{0x26c4c6d0,0x22468019,0x333faf6a,0x3f86822c}},	//   tamo_, szok_, _flux_, _phou_,
   {{0x7afd062f,0x60c18074,0x62840037,0x752e0609}},	//   xest, _eelm, _ozio, _hobz,
   {{0x26c4ce16,0xbb4381bb,0xdb1b0f96,0x6e242da4}},	//   ramo_, _сетк, nstå, nxib,
   {{0xa3cb8b85,0x60c18214,0x7ae2ce17,0x7afd4e18}},	//   _लिख_, _gelm, lgot, west,
   {{0x2b400eef,0x62840098,0x7bde4e19,0x7afd0888}},	//   _blic_, _azio, nupu, test,
   {{0x69dd0665,0x7ae2ce1a,0xec0980ff,0xdbc702f1}},	//   tuse, ngot, _dế_, _tööv,
   {{0x7afd4e1b,0x7bde0ad4,0xdb1b0106,0x799a8737}},	//   rest, hupu, vstä, _kitw,
   {{0x7afd4e1c,0x69dd4e1d,0xa4d4835f,0x7bde4e1e}},	//   sest, ruse, _рокі, kupu,
   {{0x62840870,0xd7f84e1f,0x69dd4e20,0xdb1b12d2}},	//   _ezio, нут_, suse, tstä,
   {{0x799ace21,0x26c24337,0x7d0ace22,0x69dd4e23}},	//   _litw, _ceko_, _hafs, puse,
   {{0x3ea94e24,0x3f99396c,0xdb1b0b2f,0x7d0a80f1}},	// [39b0] rcat_, _visu_, rstä, _kafs,
   {{0xceeb0077,0xdb1b1f4d,0x3ea94725,0xfd61001c}},	//   _کردن_, sstä, scat_, _huyế,
   {{0x9f478a21,0x3f990034,0x60c74e25,0xec0980ff}},	//   stné_, _tisu_, majm, _xế_,
   {{0xd6db025d,0x7ae28587,0x60c1ce26,0x5b2499bb}},	//   _это_, ggot, _selm, льча,
   {{0x799ace27,0x6f1d3f19,0x3984016d,0xd7f88087}},	//   _bitw, _insc, lösa_, _apă_,
   {{0x7d0ace28,0x98b40289,0x26c20669,0x3cfe8267}},	//   _nafs, čeći_, _zeko_, jetv_,
   {{0xe81400d4,0x60c183cb,0x48e90035,0xb8140f0a}},	//   डिया_, _velm, _जानो_, डियम_,
   {{0x27e700f2,0x43948198,0xa2cdbb6b,0x78b885ee}},	//   _ännu_, _басс, दृश्, abvv,
   {{0x7b648dc8,0xd7068009,0x60c1ce29,0x644881ac}},	//   _стре, тные_, _telm, ezdi,
   {{0x29cd0038,0x2bd80b9f,0x6f0d47e5,0xdb058192}},	//   dľa_, _डिमा, hdac, sphä,
   {{0xcb6a0463,0x6f1d4e2a,0x69cb8c4d,0xd11e8dd2}},	//   дане_, _onsc, lsge, पारण_,
   {{0x69d986a8,0xdd0200c3,0x3cddb41c,0x63680850}},	//   orwe, _čuči, _खाके_, dınc,
   {{0xad9b4e2b,0x799a80b4,0xee2e91b3,0xe809a5ef}},	//   _asúm, _yitw, _тн_, विका_,
   {{0x4999025d,0x23d11094,0xec098104,0x6f1d02af}},	//   ется_, _हिंद, _tế_, _ansc,
   {{0xdb0810ab,0x929d809a,0x8c428a0e,0x69d981ec}},	//   ólóh, _całk, _веще, hrwe,
   {{0x973c8499,0xd36f00f7,0x6729ce2c,0xdb1b108c}},	//   _kuća, _وهو_, njej, tstå,
   {{0xb6a30087,0xdca61810,0x63a3888b,0x7f440168}},	// [39c0] риул, вази, _hunn, rhiq,
   {{0x63a39682,0xdb1b0bfa,0x1dd4835a,0x7bde4e2d}},	//   _kunn, rstå, _दिसत, tupu,
   {{0x7c960ef5,0x40d90158,0x7f4402be,0xd7ca0077}},	//   трац, _אַרײ, phiq, _توجه_,
   {{0x6b89ce2e,0x799ace2f,0xdb1b0186,0x673b8b67}},	//   _cheg, _sitw, pstå, jkuj,
   {{0x7bde4e30,0xcb13010f,0x6fbe80c8,0x8b6592dc}},	//   supu, ילא_, _ইমেই, دالم,
   {{0x49738160,0x7bde42af,0x6d4501ec,0x27fa008e}},	//   аліс, pupu, chha, _kppn_,
   {{0x7af6016b,0x6b9b9d3f,0xa87a00be,0x237d822c}},	//   _obyt, _fiug, ואַר, blwj_,
   {{0x6b9b8698,0x657e151e,0x60c701dd,0x799a80b4}},	//   _giug, llph, zajm, _witw,
   {{0xe9a68698,0xd379005c,0x660400e4,0x25f4801b}},	//   _разп, juća_, nwik, ्बधी_,
   {{0x973cc775,0xd3791487,0x799a837a,0x205689b1}},	//   _duća, duća_, _uitw, _итер,
   {{0x291e82a3,0x63a38014,0x637d03c9,0xbd06826b}},	//   _inta_, _cunn, léni, _abéò,
   {{0x290ca4db,0xfd610028,0x63a3ce31,0x99ae00ab}},	//   _hada_, _quyế, _dunn, _কয়েক,
   {{0x7d0ace32,0xd379005c,0x63a3808e,0x6d86808b}},	//   _tafs, guća_, _eunn, rðab,
   {{0x672f4635,0x63a3ce33,0xf8b48665,0x290cce34}},	//   _socj, _funn, ुरिय, _jada_,
   {{0x63a3ce35,0x290cce36,0xfd610028,0x63789ee8}},	//   _gunn, _mada_, _tuyế, níns,
   {{0xd6d8232d,0xf1a71810,0x6f0d495a,0x2a6901c0}},	//   кту_, _ирон, udac, _txab_,
   {{0x6f0d4e37,0xc299035f,0x69c003a7,0x291ea1ba}},	// [39d0] rdac, _яких_, âmet, _onta_,
   {{0x290ca602,0xf8b70af3,0x7af613e2,0x63a39bcc}},	//   _nada_, _अभिय, _zbyt, _yunn,
   {{0x403533fa,0x290e8114,0x69c08609,0x63680380}},	//   _сенс, ddfa_, _awme, lına,
   {{0x41c400d5,0x291ece38,0x6f0084e8,0x2d9c9357}},	//   _حقیق, _anta_, jemc, _live_,
   {{0x290ccd4e,0x1959876a,0x637d4e39,0x66f603c8}},	//   _bada_, нады_, géni, _גמרא_,
   {{0x69cbce3a,0xc4bd80ab,0x60c50197,0x61ed0197}},	//   rsge, _ইঞ্জ, _jehm, _mqal,
   {{0x6d550059,0x60c54e3b,0xf7f581ad,0xd379026c}},	//   _imza, _mehm, استد, zuća_,
   {{0x53348f5a,0x61ed05e7,0x80dc00c8,0xaf0580bf}},	//   _кест, _oqal, ম্প্, упил,
   {{0x290cce3c,0x63a38e20,0x637d256c,0x6729ce3d}},	//   _fada_, _sunn, céni, rjej,
   {{0x290c8341,0x9f5e87e2,0x60c502af,0xc9878e97}},	//   _gada_, _està_, _nehm, _руби,
   {{0x6f0ba938,0x7f42ce3e,0x61ed4e3f,0x637884e8}},	//   _tagc, _floq, _aqal, cíns,
   {{0xc654803d,0x63a3ce40,0x27350338,0x3f4706ae}},	//   افیک, _vunn, _måns_, _jõud_,
   {{0x973c803b,0xf77092dc,0x290cce41,0x7bda89ff}},	//   _kućn, _بال_, _yada_, artu,
   {{0x06e3959a,0xa11609a7,0x2d9c8039,0x63a3ce42}},	//   _गाँव_, دوست, _give_, _tunn,
   {{0xd3793275,0x7d01ae3d,0x18670ae7,0x6d438037}},	//   suća_, mels, гари_, _ilna,
   {{0x290c003a,0x7af6003e,0x66044e43,0x7c3c8bc5}},	//   žda_, _ubyt, twik, ørre,
   {{0x60c54e44,0x637d01df,0x558a096f,0x33200197}},	// [39e0] _fehm, xéni, ебам_, _inix_,
   {{0x27350186,0x66040077,0x090606e6,0x64648110}},	//   _sånt_, rwik, _спон, štiš,
   {{0x06e3959a,0xdd8f00f7,0x48e9016f,0x9f5e4e45}},	//   _गांव_, أول_, _जातो_, ító_,
   {{0x290c803b,0xb7db010f,0xbda600d5,0x7d01804a}},	//   _sada_, _אקטי, _محسو, hels,
   {{0x290c9dda,0x7d018082,0x799e4e46,0x6b460032}},	//   _pada_, kels, _kipw, _kógb,
   {{0x64a331dd,0x290c9a83,0x7d01ce47,0x637d0866}},	//   _гара, _qada_, jels, réni,
   {{0x2d9c8205,0x8c461510,0x7d018f06,0x290cce48}},	//   _rive_, _севе, dels, _vada_,
   {{0x290c82a3,0x7d0e4e49,0x4734a265,0xa81780d7}},	//   _wada_, _habs, рнис, اتور_,
   {{0xa3e68996,0xd2669e58,0x2611864a,0x660d826c}},	//   यून_, _скай, तिषी_, _šakr,
   {{0x7d01920b,0x291ec3c8,0x6378ce4a,0x5d54a29c}},	//   gels, _unta_, píns, ркот,
   {{0x9f5e9313,0x2498816d,0x443a0901,0xaca48135}},	//   _está_, ärm_, nyp_, _ntụz,
   {{0x6d43ce4b,0x929524f5,0xdb1b1277,0xe9f90129}},	//   _elna, ианц, nstø, _ngả_,
   {{0x60c504a2,0x2d9c83a7,0x7d019c7e,0x61e28110}},	//   _pehm, _tive_, bels, nuol,
   {{0xdd8f92dc,0x7d01ce4c,0x973c811f,0x61ef14cf}},	//   _فون_, cels, _kućo, rtcl,
   {{0x273c001c,0x3f9d8041,0x6d488c41,0x6d5ac24d}},	//   _kính_, _yiwu_, mhda, mita,
   {{0x61e2ce4d,0x7d0e02c4,0x8c1b9101,0xaefb026b}},	//   kuol, _aabs, _טווי, _ijùk,
   {{0x5d554098,0x613d8247,0x80ca80ab,0x6e9901a1}},	// [39f0] акат, _sèlm, _রান্, твар_,
   {{0x6d5a85d8,0x7d0e0079,0x7ae9ce4e,0x273c00ff}},	//   nita, _cabs, _scet, _lính_,
   {{0x61fbce4f,0x6d5a8267,0x02d08072,0x63ad81a1}},	//   _spul, iita, हणून, _čank,
   {{0x6d5ace50,0xb17b016d,0x52158991,0x7d01ce51}},	//   hita, fråg, идет, zels,
   {{0x6d5ace52,0x7d01ce53,0x36de86a7,0x90c58110}},	//   kita, yels, _गाड़ी_, абле,
   {{0xdb04020f,0x26c98a20,0x6d5a9cc1,0x29110b80}},	//   _punë, _žao_, jita, ndza_,
   {{0x7d018370,0xb17b0082,0x9f47800d,0xe73181a8}},	//   vels, mråd, stní_, قصة_,
   {{0x25a6808e,0xadc404be,0x7d01ce54,0xb17b006f}},	//   _buol_, _amẹr, wels, lråd,
   {{0x6d5ace55,0x7d01ce56,0x6f0f4e57,0x3f838029}},	//   fita, tels, _macc, ēju_,
   {{0x6d5ace58,0x6d48ce59,0x6f0f4e5a,0x7d0e0079}},	//   gita, ghda, _lacc, _xabs,
   {{0x7d018370,0x6b8d4e5b,0x69dd044e,0xd469b39a}},	//   rels, _bhag, erse, тине_,
   {{0x7d0181eb,0x6b8d1c5d,0xa3ab85fc,0x672d0365}},	//   sels, _chag, _कंठ_, jjaj,
   {{0xf770ce5c,0x672d20f1,0x6b8d02a3,0x9f048065}},	//   _عام_, djaj, _dhag, _دونو,
   {{0x6d5ace5d,0x6d488782,0xd379005c,0x290324a1}},	//   cita, chda, vrće_, geja_,
   {{0x63a70353,0x1fb50221,0xd47980be,0x7d0e4e5e}},	//   _nujn, йстр, _באַל, _rabs,
   {{0x6f0f4e5f,0x6b8d01bc,0x273c046d,0x7d0e4e60}},	//   _cacc, _ghag, _kíni_, _sabs,
   {{0xee372373,0x4b7b00be,0x2a7f81c0,0x7b0800eb}},	// [3a00] ант_, _באקו, _nyub_, āstī,
   {{0xf53f13c2,0x7d0e02a3,0x14c8003d,0x443a4e61}},	//   _står_, _qabs, اهای_, typ_,
   {{0x6f0f0098,0x6c4a04c1,0x2a7f8642,0x6289810c}},	//   _facc, خلاف_, _ayub_, _azeo,
   {{0x55e60328,0x6d5ace62,0x3945ce63,0xa3e6835a}},	//   _комб, zita, _alls_, यंत_,
   {{0x7d0e01c5,0x637d4e64,0xdb1b0aa2,0x6d5aac1d}},	//   _tabs, mént, rstø, yita,
   {{0x6d5ace65,0x6f040352,0x6f0f00df,0xb4cf852a}},	//   xita, leic, _zacc, षणो_,
   {{0x6d5aa0a2,0xed5724dc,0x2a7f89c4,0xf1d286a7}},	//   vita, _тор_, _eyub_, _सिकन,
   {{0x6d5ace66,0xdefa8084,0x61e293cd,0x3945809f}},	//   wita, тык_, puol, _ells_,
   {{0x6d5ace67,0x6b8d0355,0x2366807d,0x48e6a34e}},	//   tita, _rhag, mnoj_, _возв,
   {{0x23668025,0x69dd0052,0x6b8d4e68,0x236901dd}},	//   lnoj_, vrse, _shag, _sjaj_,
   {{0x273c0104,0x6d5a8908,0xc8b581e5,0x29034e69}},	//   _tính_, rita, _ысты, veja_,
   {{0x6b82ce6a,0x63a0ce6b,0x6d5ace6c,0x69c40372}},	//   nlog, _jimn, sita, _bwie,
   {{0x6f0f2c36,0x29034ab9,0x69dd4e6d,0x05b4806b}},	//   _racc, teja_, urse, _امتح,
   {{0xd5fb8051,0x5ba6828b,0x6f0f4e6e,0x69c42b30}},	//   _ספור, _криз, _sacc, _dwie,
   {{0x6f0f0081,0x6b8d008c,0x6d5880b4,0x60c8a2b7}},	//   _pacc, _thag, _imva, _medm,
   {{0x236680d2,0x63a7173d,0x29034e6f,0xddc4009a}},	//   jnoj_, _rujn, seja_, dził,
   {{0x23668025,0x672d4e70,0x212100ff,0xb17b04e1}},	// [3a10] dnoj_, rjaj, _tnhh_, tråd,
   {{0x64410074,0x6f0f04b9,0x764d1037,0x63a0ce71}},	//   _ülik, _wacc, rzay, _aimn,
   {{0x6f0f4e72,0x69c44e73,0x6b828114,0xb17b006f}},	//   _tacc, _zwie, flog, rråd,
   {{0x2366826c,0x637d0511,0xa3e603b7,0xb17b0f91}},	//   gnoj_, cént, पढ़_, sråd,
   {{0x636802bb,0x6280831d,0x6d589406,0x63a0811a}},	//   dınl, _cymo, _omva, _dimn,
   {{0xdb0780f2,0x2bac801b,0x6280ce74,0x2aadce75}},	//   _stjä, _něco_, _dymo, _bóbó_,
   {{0xe9df00f7,0xb90c0133,0x2366812b,0x60c882d5}},	//   hrú_, _achụ_, bnoj_, _dedm,
   {{0x75350117,0x236682a5,0x6b828980,0x7d0500b9}},	//   _hozz, cnoj_, clog, lehs,
   {{0x7afbce76,0x6d86807b,0x7f4980f1,0x6d470301}},	//   _ibut, rðan, rheq, _klja,
   {{0x63a08e04,0x6f0402af,0x6722ce77,0x39458722}},	//   _zimn, zeic, _enoj, _ulls_,
   {{0x69c44e78,0x753500df,0xeb9a4e79,0x6d4701f4}},	//   _swie, _mozz, лио_, _mlja,
   {{0x67228805,0x63a081df,0xa3c914d5,0x7aed01a1}},	//   _gnoj, _ximn, लीय_, _ccat,
   {{0x3da7ce7a,0x3ebf9e92,0xb5a7a6c5,0xd77480f7}},	//   _треб, mbut_, _трей, _بالع,
   {{0x4e7a8158,0x2366812b,0x75354e7b,0x6722883d}},	//   _גאנצ, znoj_, _nozz, _znoj,
   {{0x637d0c15,0x7afbce7c,0x6f0400eb,0xa78604a3}},	//   tént, _obut, teic, مشرو,
   {{0x69c44e7d,0x6d4716ea,0x6b6b009a,0x27ea806a}},	//   _twie, _alja, lęgn, _åbne_,
   {{0x6f04034a,0x23668025,0x6609ce7e,0xe61a0190}},	// [3a20] reic, vnoj_, nwek, ыда_,
   {{0x6d41ce7f,0x4cd980c8,0x637d01df,0x753501e8}},	//   nkla, ব্রু, sént, _cozz,
   {{0x2366803a,0x636807d9,0x63a0808e,0xa5dd0035}},	//   tnoj_, yınl, _pimn, _पिथौ,
   {{0xf0930039,0x6609ce80,0x60c8a9c7,0x63680085}},	//   _מנת_, kwek, _sedm, xınl,
   {{0xceb3093f,0x26c04685,0x23668025,0x6b82ce81}},	//   _מיר_, mbio_, rnoj_, rlog,
   {{0x2366803b,0x7afbce82,0x75354e83,0xa7b8ce84}},	//   snoj_, _ebut, _gozz, алку_,
   {{0x6c360288,0x6d5e4e85,0x63a0ce86,0x6d4185b9}},	//   _افزا, mipa, _timn, dkla,
   {{0x6d5e04d2,0x62808114,0x61e63989,0x543b00be}},	//   lipa, _tymo, kukl, _געלא,
   {{0x61e610f5,0x160e03db,0xfa6a8162,0x3f4706ae}},	//   jukl, सिटर_, _саак_, _jõua_,
   {{0x3ebf8bb1,0x61e64e87,0xf8ac83db,0x9ad301bc}},	//   abut_, dukl, _चलिय, _tịke,
   {{0xdefa8364,0x308680f7,0x9f47826f,0xa3ab8105}},	//   _был_, _الاف, stná_, _कूद_,
   {{0xdc9b0158,0x6d5e4e88,0x2be00dd2,0x973c992c}},	//   טייל, hipa, _पटना, _mućk,
   {{0x6d5e4e89,0x6e968013,0x44274e8a,0x98ac90a1}},	//   kipa, _الشا, ̣n_, _चलाए,
   {{0x6d41ce8b,0x067b8158,0x6d5e4e8c,0xe3af82e3}},	//   ckla, _ענגל, jipa, بری_,
   {{0x6d5e4e8d,0xa89905a8,0x75350b91,0x657ace8e}},	//   dipa, ркву_, _rozz, moth,
   {{0x3ceb4e8f,0x6d4700d2,0x7eb90098,0x657ace90}},	//   _चाहे_, _slja, ргас_, loth,
   {{0x171b8158,0x6d47003b,0xf1b9807d,0xa535067c}},	// [3a30] נומע, _plja, _krše_, онач,
   {{0x657a8bef,0x3ebf8359,0x628d1e03,0x98c70a0e}},	//   noth, zbut_, _izao, _усил,
   {{0x443ece91,0x26c00081,0xfbd0003d,0x293800be}},	//   nyt_, bbio_, فتن_, _לאזן_,
   {{0x291301df,0xd9ed0f12,0xe2f98558,0x6d41a21f}},	//   _haxa_, _जमात_, реді_, zkla,
   {{0x6d41a36b,0x75354e92,0x2b4900c3,0x657a81f6}},	//   ykla, _tozz, _mlac_, koth,
   {{0x7ff40077,0xa5bb007b,0x6d47042b,0x59dc0441}},	//   _بسیا, _próf, _ulja, _बिसर,
   {{0x6d41b032,0xcfb480ab,0x661d192c,0x6d86808b}},	//   vkla, _টিউন, _hrsk, rðal,
   {{0x7afb8578,0x59c6800d,0x29130118,0x26cb01a1}},	//   _ubut, रीहर, _laxa_, _jeco_,
   {{0x161c000f,0xee3687ac,0x3ebfce93,0x26cb0118}},	//   नियर_, жны_, rbut_, _meco_,
   {{0x61e6011f,0xd3790024,0x661d00cd,0x26c00289}},	//   vukl, vrća_, _mrsk, zbio_,
   {{0xdb1b0789,0xf6d580e8,0xd847ce94,0x2b490c0b}},	//   sstý, _діля, _ухап, _blac_,
   {{0xa3e105e8,0xf7708013,0x6e24cbfc,0x61e64e95}},	//   _दिन_, _كان_, _šibe, tukl,
   {{0xa3c9016f,0x6d41ce96,0x29130be9,0xdb1e83ba}},	//   लीत_, pkla, _baxa_, rspø,
   {{0x443e9122,0x2907ce97,0x31af080a,0x07a60226}},	//   byt_, nena_, _düz_, жавн,
   {{0xa0a34e98,0x61e64e99,0x475a2417,0xe73a4e9a}},	//   дард, sukl, арая_, аев_,
   {{0x661d0db7,0x77698557,0x2907ce9b,0xb3470187}},	//   _brsk, nnex, hena_, ruçõ,
   {{0x2907ce9c,0x80ca80ab,0xdb040216,0x2913011b}},	// [3a40] kena_, _রাস্, _juní, _faxa_,
   {{0x2d85ce9d,0x661d0289,0x63a40074,0xf1b901d0}},	//   nlle_, _drsk, _hiin, íše_,
   {{0x6d5e16a7,0x63a4348c,0x273c007b,0x2d85bf19}},	//   ripa, _kiin, _sínu_, ille_,
   {{0x6d5e435e,0x64990c51,0x7f4d0144,0x31af061c}},	//   sipa, стур_, chaq, _yüz_,
   {{0x63a44e9e,0x67264e9f,0xdb00cea0,0x657a81f6}},	//   _miin, _inkj, _jimé, yoth,
   {{0x61438009,0x63a418c2,0x2bda8035,0xceb4011c}},	//   меча, _liin, _भिला, lcə_,
   {{0xaada01fe,0xb4e601ce,0x98be8087,0xa7fc811c}},	//   _भयंक, फली_, _altă_, _axır,
   {{0x44208a56,0x63a44ea1,0x963494d6,0x973c805c}},	//   _či_, _niin, зниц, _kući,
   {{0x550691e9,0xdb1b02af,0x628400b9,0xcd069033}},	//   очна, rstü, _nyio, очни,
   {{0x63764ea2,0xdd908872,0x443ecea3,0x2b491a34}},	//   mány, عود_, tyt_, _slac_,
   {{0xd6cfcea4,0xf1b982a5,0x2b494ea5,0xad1b00be}},	//   _от_, _vrše_, _plac_, בויר,
   {{0x74ba85e8,0x8cba8ebf,0x443ea183,0x657acea6}},	//   _श्रृ, _श्रो, ryt_, soth,
   {{0xf2d39bb3,0xd37900fe,0x63a4438f,0xfd0f8077}},	//   וער_, nući_, _diin, رجی_,
   {{0x26cb06ea,0x443ecea7,0x6602b2e1,0x63b880ff}},	//   _seco_, pyt_, _ipok, _ttvn,
   {{0x63a40012,0xb4d6800c,0xa1578039,0x7d08cea8}},	//   _fiin, िणी_, קבלה_, meds,
   {{0x29130962,0x3cfd000d,0x2907cea9,0x661d01dd}},	//   _waxa_, र्ने_, zena_, _prsk,
   {{0xd3790025,0x29132d6d,0x2907ceaa,0xdb00ceab}},	// [3a50] jući_, _taxa_, yena_, _gimé,
   {{0xd379003a,0x290792f5,0x7d0881a3,0x201eceac}},	//   dući_, xena_, neds, _orti_,
   {{0x61e287f1,0x76408428,0x4ab99273,0xd7a98035}},	//   erol, hymy, буля_, _चूंच,
   {{0x7d088022,0x6d5c4aba,0xa3ccab28,0x80ca80ab}},	//   heds, _emra, शीय_, _রাষ্,
   {{0xd3790052,0x201e96b2,0x776980ee,0xdb00816a}},	//   gući_, _arti_, vnex, _ximé,
   {{0xe817b497,0x2b9200e1,0x201e808e,0x7d088140}},	//   थिला_, máce_, _brti_, jeds,
   {{0x2907853e,0x25e30b9f,0x236d816d,0x6d450234}},	//   rena_, टंकी_, _tjej_, mkha,
   {{0x81aa80c8,0x27e7cead,0x3f5701b9,0x15ef06ae}},	//   _খবর_, runn_, għux_, _चमार_,
   {{0x2907ceae,0x201e8ad4,0x7769822b,0x2d85823e}},	//   pena_, _erti_, rnex, tlle_,
   {{0x63a40df8,0x2d85a202,0x6d454eaf,0x613d8580}},	//   _siin, ulle_, nkha, _cèlt,
   {{0x2d85862f,0xa3e68b9f,0xdb00ceb0,0x6602bf3e}},	//   rlle_, यूल_, _simé, _epok,
   {{0x2d8581df,0xd8748591,0x69c9ceb1,0x660d0234}},	//   slle_, _غالب, _kwee, kwak,
   {{0x7d08ceb2,0x63a44eb3,0x4a430081,0x69c985ee}},	//   beds, _viin, еняв, _jwee,
   {{0x25bfaeb0,0xfbd180f7,0xd1320019,0xc7b88140}},	//   mpul_, _كتب_, رمز_, _hrđa_,
   {{0x6561ceb4,0x6023002d,0xd8233b7d,0x3d0f0035}},	//   milh, ндра, ндри, ड़ने_,
   {{0xcc3a8158,0x0eaa0a8e,0x6aa9ceb5,0x38650174}},	//   _לעצט, скай_, _ngef, úlra_,
   {{0xe7371172,0x6d5c00b9,0xa5bb0032,0xc7b88088}},	// [3a60] чет_, _pmra, _arób, _mrđa_,
   {{0xd379005c,0x65618187,0x98ac8084,0x63760061}},	//   vući_, nilh, _kodą_, vány,
   {{0x31570159,0x4915170c,0xe7eb000f,0x6441831d}},	//   _זיין_, _फोटो_, जूदा_, nyli,
   {{0x7d088063,0x290a4eb6,0x6da6045e,0x6e2003a8}},	//   zeds, leba_, _нима, _ámbo,
   {{0x26d24eb7,0x6d450326,0x6f098df6,0xe5a61c60}},	//   mayo_, bkha, deec, _хиги,
   {{0x61e29220,0xe4da1125,0x26d24eb8,0x6d5c0d1b}},	//   rrol, _دوست_, layo_, _umra,
   {{0x6561ceb9,0x28bf0d14,0xd9d9001b,0x7d0884d6}},	//   dilh, ्रति, _भट्ट, veds,
   {{0x26d24eba,0x61e28754,0x657e4ebb,0x64a30110}},	//   nayo_, prol, loph, _часа,
   {{0x91e38468,0x7538a840,0xeb979577,0xbebb0cab}},	//   _поте, _povz, _хит_, _poëz,
   {{0x290a4912,0xb3e006a7,0x2c000074,0x73d89ae2}},	//   jeba_, _पटाख, _ईहां_, одор_,
   {{0x7d08cebc,0x76408364,0x26d24ebd,0x69c981ed}},	//   reds, symy, kayo_, _zwee,
   {{0x657e234c,0xc7b384de,0x6d4b01a9,0x394c8174}},	//   hoph, _טבע_, īgai, _hlds_,
   {{0x7afdaac0,0x63ae11fe,0x6602b936,0xf1b989d1}},	//   _öste, _lubn, _upok, _krša_,
   {{0x6d4a808e,0x3f823524,0xad9b0333,0xada38073}},	//   _ulfa, _akku_, _apún, _зачл,
   {{0xd6db163f,0x7d150353,0x34fb81c6,0x657e4ebe}},	//   йта_, _razs, _ההוד, doph,
   {{0x29184ebf,0x35d18105,0x26d22674,0x8f340791}},	//   adra_, _दौड़, gayo_, несц,
   {{0xaac32263,0x4ac32418,0xae1f8054,0x6d45237d}},	// [3a70] _व्यक, _व्यव, बियन_, tkha,
   {{0xa5bb247d,0xd49b1bc0,0x660d48dc,0x290a0644}},	//   _prób, бре_, rwak, ceba_,
   {{0x26d200f6,0x660d0726,0x6d4534ed,0xa5bb3f85}},	//   bayo_, swak, rkha, _bróc,
   {{0x1ddd809a,0x6d454ec0,0xf1b98267,0x7fd604de}},	//   _मिलत, skha, _arša_, _קורס_,
   {{0xbef88b9f,0xdb020106,0x657e0234,0x63760118}},	//   ्जैन_, pplö, boph, ránx,
   {{0xf8bf024c,0x3f890114,0x657e01f6,0x2bac81d0}},	//   ्रिय, llau_, coph, _těch_,
   {{0x656183a7,0xe0d09a3e,0x3f890114,0x7bdc8061}},	//   vilh, ازه_, olau_, árul,
   {{0x39841bd7,0x290a009a,0x69c9c47e,0x321f801c}},	//   löst_, zeba_, _twee, _truy_,
   {{0x50bf000f,0xa8a78dae,0x1ddd816f,0xd3791487}},	//   ्राष, _ерек, _मिळत, nuću_,
   {{0x61e4cec1,0x25bfcec2,0x26d2005d,0x7afd1384}},	//   áile, rpul_, zayo_, efst,
   {{0x63ae4ec3,0xeb9a002e,0x6561ceb9,0x26d24ec4}},	//   _xubn, жин_, rilh, yayo_,
   {{0x657e1cb9,0x8c1a0039,0x3cfd016f,0x2901198f}},	//   zoph, קורי, र्ते_, _abha_,
   {{0xd379012b,0xa3b2800f,0x7e6902d4,0xe5e680d7}},	//   juću_, _झूठ_, _žepn, _قزوی,
   {{0x59e0816f,0x26d24ec5,0x200580b9,0x2242004a}},	//   _निसर, wayo_, _kpli_, rykk_,
   {{0x26d24446,0x290a4ec6,0x29184ec7,0xb4e98576}},	//   tayo_, reba_, rdra_, यली_,
   {{0x60c11010,0x26cf8063,0x7bc18197,0x63ae0140}},	//   ılma, _jego_, mplu, _rubn,
   {{0xd1ba0b76,0x6b8402a0,0x26d20924,0x3a200077}},	// [3a80] _بابا_, _ikig, rayo_, _urip_,
   {{0x26d2005d,0x3eb9007b,0x61eb8558,0xf507002e}},	//   sayo_, _efst_, dugl, мнул_,
   {{0xe73a0381,0x657e4ec8,0xa3c9016f,0x7bc1cec9}},	//   _ден_, roph, लील_, nplu,
   {{0x26cf803a,0x27e50038,0x728a95a6,0x394c8216}},	//   _nego_, álne_, обег_, _slds_,
   {{0x75490117,0x61eb80fe,0x2bac81d0,0x6b8403e4}},	//   ászó, gugl, _věci_, _mkig,
   {{0xe894a011,0xa5bb0035,0x7bc18299,0x5183b0af}},	//   наль, _wróc, kplu, куща,
   {{0x9f4301d0,0x26cfceca,0xb90680c2,0x59e08107}},	//   zují_, _bego_, _भय_, _निवर,
   {{0x44443228,0x8e1485c2,0x48de052a,0x1e1495a4}},	//   my_, едиц, कृतो_, емия,
   {{0x753c0063,0x6a8397ae,0xe9d78d5f,0x3ea28106}},	//   _korz, _алта, _окт_, äkt_,
   {{0x4a578039,0x69c289ff,0x9f4301d0,0x6b840f45}},	//   _חשמל_, mpoe, vují_, _akig,
   {{0x44440f66,0xdb00cecb,0x973c8369,0xdb1b0198}},	//   ny_, _limí, _suću, istö,
   {{0xf6d68bca,0xa3e10e5b,0x3a26026c,0x26cf80c3}},	//   _آزاد, _दिस_, _šopa_, _gego_,
   {{0x44440775,0x51874ecc,0xc33382f6,0x527b80be}},	//   hy_, дува, דור_, ַנלא,
   {{0x44440a56,0x6e22948e,0x753c00ee,0x6b8402ec}},	//   ky_, _irob, _norz, _ekig,
   {{0x80d380c8,0x6e22816b,0x1fa70e63,0x140d0327}},	//   _সাম্, _hrob, драг, _सनेह_,
   {{0x2bd80996,0x5f941c64,0x9f580247,0xf7700124}},	//   _डिजा, вист, ntrè_, لاق_,
   {{0x44440079,0x2005001b,0xd2520019,0x88bc81d0}},	// [3a90] ey_, ůli_, _منٹ_, _vněj,
   {{0x30150c8e,0x7d1ac830,0x6d48cecd,0x44443228}},	//   _здор, ndts, nkda, fy_,
   {{0x44444ece,0xa3c90b9f,0xd3791be7,0x36d50009}},	//   gy_, लीं_, suću_, _понр,
   {{0x309a0051,0x6d4e4ecf,0x9f4780e1,0x16350081}},	//   _משתמ, _elba, stnú_, _земя,
   {{0x753c4ed0,0x26cf92f5,0x7d18816d,0x44444ed1}},	//   _forz, _rego_, _oavs, ay_,
   {{0x44440f4c,0x6f0d0c64,0x61eb811f,0x41e080d4}},	//   by_, leac, rugl, _निरस,
   {{0x62868bc5,0x4444137c,0x61eb8042,0x673d01a1}},	//   _økon, cy_, sugl, _kosj,
   {{0x6f0d2ab6,0xee398dd3,0x6e228114,0xac942f84}},	//   neac, зни_, _brob, _расш,
   {{0xe1f0826a,0x68138201,0x6abb81bc,0x6e228115}},	//   _نسل_, _mədə, _ifuf, _crob,
   {{0xe00f0c69,0x3159990c,0x29cd4ed2,0x6f0d0ad0}},	//   ाबाद_, _علاج_, dža_, heac,
   {{0x26cf8d38,0x63a981cd,0x62898683,0x636802d0}},	//   _tego_, _kien, _hyeo, kınt,
   {{0x91e60256,0xf092807c,0x79854ed3,0x81d700ab}},	//   номе, _גנב_, _akhw, _সহজ_,
   {{0x6f0d154c,0x63a9ced4,0x69d9ced5,0xdc3b881d}},	//   deac, _mien, nswe, _išče,
   {{0x63a9ced6,0x6289ced7,0x6f1bc776,0x7bc193ac}},	//   _lien, _myeo, lduc, pplu,
   {{0x6e228063,0xf1dc0996,0x6f0d00f7,0x6b464ed8}},	//   _zrob, _बिकन, feac, _lógi,
   {{0x44440a56,0x63a9ced9,0x6f0d4b8b,0xd252045b}},	//   vy_, _nien, geac, _منع_,
   {{0x44440d38,0x2b00213e,0x9f584eda,0x69cd0114}},	// [3aa0] wy_, ष्णु_, ntré_, _gwae,
   {{0xa3e386a7,0x60d53f85,0x98a582d6,0x69d989ff}},	//   _फटा_, cazm, _anlč_, dswe,
   {{0xdb1b4edb,0x63a9cedc,0xdd8f187e,0x44444edd}},	//   rstö, _bien, حول_, uy_,
   {{0x444414e3,0x63a991b9,0x291a022e,0xa5bb016a}},	//   ry_, _cien, _hapa_, _irón,
   {{0x63a98f29,0x4444096a,0x05d48072,0xdcfc01a9}},	//   _dien, sy_, _धबधब, _ekrā,
   {{0x4444185c,0xa5bb007b,0x63a9bfa2,0xdb040073}},	//   py_, _krón, _eien, _funç,
   {{0x2d980352,0x69c2a06b,0x63a98687,0x69d98a53}},	//   _ihre_, spoe, _fien, aswe,
   {{0x291a4ede,0xa84780f7,0xdb0b00e8,0x7d18cedf}},	//   _lapa_, عليم_, _utfø, _savs,
   {{0x3cfd0540,0x6289810c,0x6b82cee0,0x52cc81d0}},	//   र्वे_, _gyeo, moog, ारीस,
   {{0x291a4ee1,0x6b828006,0x63a98102,0x672bcee2}},	//   _napa_, loog, _zien, _engj,
   {{0xd498835f,0x6d48cee3,0x22468019,0x6f19cee4}},	//   ької_, rkda, lyok_, _fawc,
   {{0x6e2287e2,0x6f02cee5,0x63a981c0,0x290ecee6}},	//   _trob, _uboc, _xien, lefa_,
   {{0x291a1083,0x7d188214,0x6e2281ac,0x22468019}},	//   _bapa_, _tavs, _urob, nyok_,
   {{0xa3e10740,0x291a4ee7,0x290e8c0b,0x6b82b08e}},	//   _दिल_, _capa_, nefa_, hoog,
   {{0x673d030b,0x6f0d0af9,0x1cb7812a,0xa5bb02ba}},	//   _posj, teac, _אלול_, _crón,
   {{0x68138201,0x2d8c816d,0x6b82cee8,0x7bdac2cd}},	//   _qədə, llde_, joog, mstu,
   {{0x6f0d1523,0x62350dca,0xf1a71fee,0x63a9cee9}},	// [3ab0] reac, _репу, _прон, _rien,
   {{0x6f0d2ab6,0x62898708,0x4ea403c7,0x442302f7}},	//   seac, _ryeo, урса, _prj_,
   {{0x63a9ceea,0x9cd78051,0x41b7000f,0x2d9e8fb0}},	//   _pien, גובה_, _इंडस, imte_,
   {{0x7bdaceeb,0x69d9ceec,0xeab08154,0xdb07ceed}},	//   istu, tswe, معه_, _bujá,
   {{0x63a9ceee,0xdb078125,0x22468065,0x213e8051}},	//   _vien, _stjó, gyok_, _both_,
   {{0xceb40086,0x7bdaceef,0xfbd30154,0x26c94ef0}},	//   ndən_, kstu, _متر_, lbao_,
   {{0x63a9cef1,0xe7399687,0x69c087d9,0xac940196}},	//   _tien, дей_, _etme, _барш,
   {{0x2d8c8cfa,0x61e4bda0,0x7bc501f6,0x2246808e}},	//   elde_, šila, mphu, byok_,
   {{0xb11580b3,0x81bb80ab,0xceb40085,0x7bdacef2}},	//   _имаш, _আটক_, kdən_, estu,
   {{0x637d0065,0xdb0e8511,0x7bda867f,0x6b460789}},	//   mény, _rubé, fstu, _jógv,
   {{0x9f58261c,0x7bdacef3,0x316780b9,0x15f3064a}},	//   stré_, gstu, minz_, इंडर_,
   {{0x291a33ae,0x069980f7,0x2d8ccef4,0x61fd3da6}},	//   _sapa_, _قناة_, alde_, ftsl,
   {{0x291a428d,0x20d600e8,0xe297433f,0xceb4011c}},	//   _papa_, ківс, каю_, fdən_,
   {{0x6e200da1,0x3f8d894d,0xf8d19a42,0x6d478338}},	//   _ámbi, lleu_, हरिय, öjad,
   {{0x4879217c,0x5d7a83de,0x61fd1c2b,0xb8ea03ca}},	//   естя_, _קאצק, atsl, _ऊभ_,
   {{0x27e501ac,0xa3e68beb,0xe8030697,0x1fe380ab}},	//   álna_, _पित_, _लहरा_, _মহাস,
   {{0x8fa31285,0x291a4ef5,0x07a310f8,0xdcfa80eb}},	// [3ac0] рате, _tapa_, ратн, lotā,
   {{0x64458006,0x63ae81a8,0xf29701c6,0x9f4302df}},	//   _ühis, _úiné, _בכפר_, rujá_,
   {{0x6b82cef6,0x66e60dca,0x213ecef7,0xdcfa81a9}},	//   toog, _иона, _roth_, notā,
   {{0xf7460d0e,0xa5bb0035,0xb4ae86a7,0x41e68a4c}},	//   _ремо, _król, _कल्_, віка,
   {{0x6d8681fa,0x637d0061,0x333f8036,0x6b82cef8}},	//   iðar, gény, _doux_, roog,
   {{0x7bc50640,0x7bdacef9,0xf80680e8,0xdcfa81a9}},	//   bphu, ystu, вчин, kotā,
   {{0xb50206bf,0x9d1b00be,0x351b0039,0xdfd080f7}},	//   र्णय_, _קולט, _קולנ, حيب_,
   {{0x2d8786c0,0xe7e38105,0x290ecefa,0xceb40085}},	//   _akne_, _गिरा_, sefa_, zdən_,
   {{0x7d1c4efb,0x7bdabf33,0x68ed8019,0x69c08163}},	//   _kars, wstu, ándé, _utme,
   {{0xfe6f9301,0xf1dc0fea,0x7bdaae7f,0xdcfe00fe}},	//   تدى_, _बिजन, tstu, kopč,
   {{0xc0a980f7,0x2d9eb5cd,0xa5bb0032,0xa0a68081}},	//   _كامل_, rmte_, _aról, _ражд,
   {{0xe50203eb,0x7bdacefc,0xd5e2058c,0x7d1c0f06}},	//   र्ति_, rstu, _पिंज, _lars,
   {{0x290428d2,0x7d1c011b,0x9b581ceb,0xa3e6b064}},	//   đman_, _oars, тият_, यूज_,
   {{0x70bf0aed,0x6d86807b,0x61ef0503,0x7d1c4efd}},	//   ्रेल, rðas, rucl, _nars,
   {{0xceb40201,0xd37b0fe7,0x224d1f2a,0xdfd80098}},	//   rdən_, _очи_, šek_, кът_,
   {{0xd4378039,0x34cb27fb,0x6568cefe,0x3eaf128d}},	//   _ירוק_, िर्द, lidh, øgt_,
   {{0x333fceff,0x26c90bcf,0xe3b8811c,0x680a811c}},	// [3ad0] _roux_, rbao_, lqı_, _hədd,
   {{0x7d1c4f00,0xbebb020f,0x2b8e803e,0x637d0019}},	//   _cars, _anët, lých_, vény,
   {{0x7d1c4f01,0x29114f02,0x6ca704bd,0x2ca70bd7}},	//   _dars, meza_, траж, änd_,
   {{0x2b8e8775,0x2911247b,0x7d1c0706,0xd4980a95}},	//   ných_, leza_, _ears, тру_,
   {{0x7d1c4f03,0x63ad4f04,0xe1ff1355,0x64488114}},	//   _fars, _mian, ntó_, hydi,
   {{0x29114f05,0x7d1c4f06,0xd5fa0051,0x98c602a5}},	//   neza_, _gars, _אפשר, čući_,
   {{0x2b8e8ed7,0xccf20051,0x6142a7ee,0x3f84c1b5}},	//   kých_, _לכם_, сеща, fomu_,
   {{0xe61994b7,0x63ad4f07,0x4429976d,0x29113190}},	//   еди_, _nian, _ča_, heza_,
   {{0x29111b97,0x2b8e816b,0x69dd00f3,0x6b9bcf08}},	//   keza_, dých_, jsse, _ihug,
   {{0x6f1d4f09,0xdcfa8029,0x80ca873c,0x28ac800d}},	//   _lasc, totā, _स्पे, _चलचि,
   {{0x63ad0098,0x63b502a5,0x69dd45bd,0x3f8480b8}},	//   _bian, _juzn, esse, bomu_,
   {{0x6f1d4f0a,0xc7b28039,0x63ad4f0b,0x3f84cf0c}},	//   _nasc, _הבא_, _cian, comu_,
   {{0x63ad1ade,0x6d868125,0xee2e8193,0x65688010}},	//   _dian, rðar, _ун_, bidh,
   {{0x29113190,0xaca38135,0x660b80b9,0xe00f064a}},	//   geza_, _atụk, _ipgk, ाबंद_,
   {{0xdee6134e,0x63ad4f0d,0x2d85cf0e,0x66e64f0f}},	//   лови, _fian, mole_, лова,
   {{0x63ad37cd,0xd6d98035,0x80ca8c2d,0x2f55279e}},	//   _gian, nał_, _स्ने, атус,
   {{0x7d1c014c,0x29114f10,0x7ae40289,0xceb284de}},	// [3ae0] _pars, beza_, _idit, מין_,
   {{0xdca63012,0x4427cf11,0x7d1c0be9,0x6b9bcf12}},	//   гази, _krn_, _qars, _ahug,
   {{0x6f1d29da,0x69c40372,0x2d858037,0xd6d9866f}},	//   _fasc, _htie, iole_, kał_,
   {{0x7d1c4f13,0x2d858234,0x63b5007d,0x6b9b80f7}},	//   _wars, hole_, _duzn, _chug,
   {{0x673b8efd,0x298a8ae7,0x61469957,0x7d1c4f14}},	//   djuj, нско_, леда, _tars,
   {{0xc27b00be,0xb605807a,0x6b89819d,0x2d85cd39}},	//   ערסי, _mašč, _ekeg, jole_,
   {{0xa3e1090a,0x9f479b39,0x2d85cf15,0x7ae44f16}},	//   _दिए_, stný_, dole_, _odit,
   {{0x20d88110,0xdb1900e1,0x7ae4300e,0x29110b5e}},	//   džių_, _otvá, _ndit, zeza_,
   {{0x2b8e8ed7,0x70f684e3,0x80d380c8,0x63ad4f17}},	//   vých_, _مسائ, _সার্, _rian,
   {{0x7ae44f18,0x2d85cf19,0x551406a7,0x7bde00b9}},	//   _adit, gole_, ड़िए_, ospu,
   {{0x261405e8,0x6568cf1a,0x291100fa,0x2b8e803e}},	//   नौती_, ridh, veza_, tých_,
   {{0x291122f6,0x291ecf1b,0xb6058754,0xd4978196}},	//   weza_, _hata_, _bašč, ыры_,
   {{0x291eb2a4,0x29114f1c,0x2b8e803e,0x645a8065}},	//   _kata_, teza_, rých_, szti,
   {{0x2d85cf1d,0xd379011f,0x6e93880b,0xe1ff2908}},	//   cole_, vrću_, _الها, rtó_,
   {{0x29110fb7,0x291ecf1e,0x69c44f1f,0xe1ff4f20}},	//   reza_, _mata_, _etie, stó_,
   {{0x2f1802c7,0x7bde0aa2,0x291ecf21,0xe1ff01ca}},	//   лось_, dspu, _lata_, ptó_,
   {{0x291124c2,0xdb0e8144,0x59e090a1,0x63b500fe}},	// [3af0] peza_, _cubí, _निगर, _suzn,
   {{0x6b9bb5bd,0x291ecf22,0x63a281e2,0x6f1d01ec}},	//   _shug, _nata_, emon, _wasc,
   {{0xb6058db7,0xc1740039,0x6f1d4f23,0x3a2902c4}},	//   _zašč, _לחץ_, _tasc, _hrap_,
   {{0xfbd00077,0xd2518013,0xf2960091,0x3a29000b}},	//   ستم_, ينا_, _abẹ́_, _krap_,
   {{0x291eb68b,0xf1b98904,0xe704026a,0xa3c91094}},	//   _bata_, _krši_, _اسپی, लीज_,
   {{0xd6d98063,0x98ba0029,0x63b50503,0xa069c060}},	//   wał_, _kopā_, _tuzn, кала_,
   {{0x6b9b8c64,0x2d858098,0x291ecf24,0x2f55cf25}},	//   _thug, vole_, _data_, итис,
   {{0x5ba48436,0x6b460118,0x2d85cf26,0xddc98035}},	//   _груз, _lógr, wole_, cześ,
   {{0x291ecf27,0x00e5803d,0x4427c8ec,0xdb0e8118}},	//   _fata_, _نتای, _srn_, _xubí,
   {{0x0565c120,0x291ecf28,0xd6d9809a,0xb6058289}},	//   рвон, _gata_, sał_, _rašč,
   {{0x2815803d,0x66160035,0xeb9a1073,0x3a294f29}},	//   _خواس, zwyk, кио_, _arap_,
   {{0xe81b800f,0x291e80a4,0x34b20816,0x25ee8072}},	//   _भैया_, _zata_, _जल्द, _आमची_,
   {{0xed4ea6b9,0x291ecf2a,0x26cd816a,0x4427808e}},	//   _до_, _yata_, mbeo_, _wrn_,
   {{0x64a58f04,0x44278390,0xa5bb0035,0xdb158168}},	//   _кала, _trn_, _trój, _buzë,
   {{0x6d4391cd,0xa0a628b4,0x4427cf2b,0x7bc380dd}},	//   _iona, равд, _urn_, _utnu,
   {{0x6e248754,0x3ebfbdd4,0x6d438102,0x70d1800d}},	//   _šibi, ncut_, _hona, हरुल,
   {{0x05664f2c,0x6b460013,0x6d43cf2d,0x6f041ad0}},	// [3b00] аван, _fógr, _kona, rfic,
   {{0x6e24016a,0x6f044f2e,0x7bde4f2f,0xa3e1066f}},	//   rvib, sfic, tspu, _दिख_,
   {{0xe5020054,0x60dc4f30,0xaaba03a4,0x161c8105}},	//   र्षि_, marm, _इलाक, _बैनर_,
   {{0x291e803a,0x60dc4f31,0x7bde4f32,0xdb0e8118}},	//   _sata_, larm, rspu, _tubí,
   {{0x70d1800d,0xf8da00c2,0x320204e8,0xda63a489}},	//   हरूल, _बजाय, ntky_, овци,
   {{0x63a2cf33,0x26c04f34,0x60dc007b,0x3f920683}},	//   smon, lcio_, narm, llyu_,
   {{0xd01081a8,0xb8deb41c,0xa8a38081,0x201a8037}},	//   سلة_, _इल_, орък, ìpi_,
   {{0x26c0100a,0x291e83c3,0x6d438ad0,0x9c828efc}},	//   ncio_, _wata_, _aona, _účin,
   {{0x291e81bf,0x6d43cf35,0x60dc4f36,0x26c04f37}},	//   _tata_, _bona, karm, icio_,
   {{0x6d438cac,0x5d5481f3,0x60dc4f38,0x2b92016b}},	//   _cona, скот, jarm, lách_,
   {{0x60dc4f39,0x34b70039,0x3320009f,0x69c04f3a}},	//   darm, יפים_, _baix_, ímen,
   {{0x2b920626,0x680a8201,0x6d438118,0x3d060f0a}},	//   nách_, _tədb, _eona, स्ते_,
   {{0x60dc4f3b,0x6d43cf3c,0x4cd580ab,0xee948019}},	//   farm, _fona, _দারু, _اداک,
   {{0x6d43cf3d,0xc98700b3,0x224b016d,0x2b92016b}},	//   _gona, руми, ryck_, hách_,
   {{0xf1b98024,0x2b92026f,0x32021e51,0x656f8866}},	//   _vrši_, kách_, atky_, èche,
   {{0x442d2588,0x6d43cf3e,0xf77301ad,0x9f4301d6}},	//   _če_, _zona, زاز_, lujú_,
   {{0x61e48796,0x236906c0,0x442a4f3f,0x60dc13c4}},	// [3b10] šilj, _imaj_, _arb_, barm,
   {{0xa2c9800d,0x60dc4f40,0x7afb8087,0x443a0216}},	//   हुन्, carm, _scut, fxp_,
   {{0xdcf8801b,0x92d900ab,0x320db76b,0xf1cf90be}},	//   _skvě, ালী_, _spey_, _सौजन,
   {{0x26c00098,0x442a00ee,0x2121008e,0x9f4300e1}},	//   ccio_, _drb_, _hahh_, hujú_,
   {{0x442a4f41,0x6d5ac347,0x3ebf82d0,0x6b8d0c53}},	//   _erb_, khta, vcut_, _mkag,
   {{0xe8f8804a,0xdcfc066f,0x2bd90180,0xf4350012}},	//   илі_, _okrę, _مارک_, _легэ,
   {{0x44254f42,0x442a00d2,0x3f6984ae,0x26d94f43}},	//   _él_, _grb_, лико_, _keso_,
   {{0xef198993,0x21210a84,0x7c25807b,0x7afb8b80}},	//   уми_, _lahh_, _áhri, _ucut,
   {{0xd4d98112,0x60dc4f44,0x80dd00ab,0x9f584f45}},	//   льні_, yarm, _বান্, ntrá_,
   {{0x3ebf93df,0x6b8d4ae1,0x6d438085,0x987800d2}},	//   scut_, _akag, _qona, _ušća_,
   {{0xb8958013,0x40958013,0x6d43cf46,0x60dc4f47}},	//   _الاع, _الار, _vona, varm,
   {{0x60dc4f48,0x2121368b,0xa3ea0107,0x63b880fe}},	//   warm, _aahh_, _मिस_, _duvn,
   {{0x6d43cf49,0x5ea580ab,0x7c2a8192,0x998001f4}},	//   _tona, _গ্রে, _erfr, _ariš_,
   {{0x6d5a9301,0x3202016b,0x2c57811c,0x9f4301d6}},	//   chta, rtky_, hədə_, cujú_,
   {{0x26d94f4a,0x3202026f,0x212100dd,0x2c578085}},	//   _beso_, stky_, _dahh_, kədə_,
   {{0x394580e4,0xdb1c84e8,0xdb028a53,0x2efd8901}},	//   _lols_, _otrá, rmoë, _jcwf_,
   {{0x644300f2,0x442a2b0d,0x2b921c32,0xf7430073}},	// [3b20] änin, _srb_, vách_, чето,
   {{0x23690503,0x26c04f4b,0x61e4113b,0xd9100061}},	//   _zmaj_, scio_, _ivil, _تیس_,
   {{0xdb1ca391,0x61e40a38,0x2b92026f,0xe2caa109}},	//   _atrá, _hvil, tách_, глед_,
   {{0xd0488085,0xe73a4f4c,0xf1b9842b,0x9f4300e1}},	//   _gedə, _сем_, _buš_, zujú_,
   {{0x672439e9,0x21210101,0x2b92016b,0xaeff8264}},	//   mdij, _yahh_, rách_, ্যাণ_,
   {{0x39459ed6,0x6f1600b9,0x64a61cae,0x3ce781a1}},	//   _cols_, leyc, _гага, _ndnv_,
   {{0xa3f28a49,0x629b819d,0x3dc6b7f7,0x3d1402f1}},	//   _জন্য_, _ezuo, _stow_, ड़ीं_,
   {{0xb8ef97ba,0x26d9002a,0xf1b98140,0xc7b301c6}},	//   _व्_, _xeso_, _fuš_, הבה_,
   {{0x66040d66,0xa5bb00f7,0x03a381cf,0x50d680d7}},	//   ntik, _prói, _хито, _هزار,
   {{0xb9968013,0xa3b98f12,0x67240072,0x39459b32}},	//   _الطب, _अंश_, hdij, _gols_,
   {{0x69b2000f,0x61e43098,0x66040009,0x974300ce}},	//   _इंजी, _avil, htik, šćiv,
   {{0x6d5acf4d,0x6724026c,0x75e1819d,0x04638190}},	//   shta, jdij, _ịzer, ятым,
   {{0x26d9047f,0x4e968c2b,0xc6968019,0x539b83de}},	//   _reso_, _اشار, _اشاع, טיטו,
   {{0x92d900ab,0x7c3eb800,0x6023128a,0x69b0064a}},	//   ালে_, _àpro, jímá, ंदगी,
   {{0x26d92f32,0xf4848077,0xc8cf864a,0x67228326}},	//   _peso_, _باشی, _स्फट, _kaoj,
   {{0xd6d80ca0,0xe7f08744,0x6b8d1d4c,0x764d4f4e}},	//   йту_, _घटना_, _ukag, tyay,
   {{0xf77005ff,0x66040bb1,0x93bc8162,0x518701e5}},	// [3b30] راف_, gtik, zvăl, _гуна,
   {{0x2b921c32,0x61e29388,0x764d4f4f,0x201ecf50}},	//   váci_, dsol, ryay, _osti_,
   {{0xdb1c9385,0xd2510416,0xf99404de,0x61e287cd}},	//   _strá, _رنگ_, _מרץ_, esol,
   {{0x394587fa,0xdb19016d,0x66040122,0x59d00b84}},	//   _sols_, _utvä, btik, तीकर,
   {{0x4cde8a49,0x6d588065,0x2c578201,0x61458ada}},	//   _মানু, _olva, rədə_, жела,
   {{0x60da8118,0x6e2d990f,0x2c57811c,0x2b92136f}},	//   _cetm, _šabo, sədə_, ráci_,
   {{0x394587fc,0xf9908154,0xddd6009a,0x5edd8264}},	//   _vols_, ربه_, czył, _যাবে,
   {{0x6d58cf51,0x6d474f52,0xf1b9bf13,0x290c84b7}},	//   _alva, _hoja, _tuš_, _ebda_,
   {{0x201eba2d,0x9f5c801b,0x80caa7fb,0x60dacf53}},	//   _esti_, ctví_, _स्वे, _fetm,
   {{0x6b8bc189,0xe5699630,0x80d380ab,0x60da8085}},	//   logg, риод_, _সাক্, _getm,
   {{0xca291a15,0x61e40098,0x6d474f54,0x66044f55}},	//   _שם_, _svil, _moja, ztik,
   {{0x6d474f56,0x672281c0,0x6d588f7c,0x6b8b867f}},	//   _loja, _gaoj, _elva, nogg,
   {{0x84e5a150,0xfce5964c,0x8d74a452,0x67244f57}},	//   _долж, _доло, _کانا, vdij,
   {{0xa3ea101b,0x412a11d2,0x0d84b941,0x28cf863a}},	//   _मिल_, шого_, _елін, _स्मि,
   {{0x1b0f00ab,0x96c7082e,0x75238c53,0x06ae8264}},	//   িয়ে_, _ụfọd, _ianz, ছুদি,
   {{0x66044f58,0x7ae98578,0x752380b4,0x61e40370}},	//   ttik, _ndet, _hanz, _tvil,
   {{0x6d47025b,0xee3a067c,0x7523cf59,0x92e900a0}},	// [3b40] _boja, шна_, _kanz, _طريق_,
   {{0x3a2017ea,0x90c308b0,0x3d140035,0xb17b0106}},	//   _isip_, _обье, ड़ें_, lsån,
   {{0x7523cf5a,0x032695b5,0x29182151,0xf74629b3}},	//   _manz, жден, mera_, _дено,
   {{0x29184f5b,0x7523840e,0x60da87e2,0xeb978009}},	//   lera_, _lanz, _setm, оих_,
   {{0xada601a1,0x3a2d81a1,0x6d471e9f,0x6a1692c5}},	//   _мамл, _crep_, _foja, تبار,
   {{0x7ae9cf5c,0x61e2b734,0xdb0b016d,0x6d470390}},	//   _edet, rsol, _utfö, _goja,
   {{0x29184f5d,0x6f09cf5e,0xd83a8048,0x60da80f1}},	//   iera_, ffec, рэл_, _vetm,
   {{0x29184f5f,0x9c7c90d1,0x7523cf60,0xdb1ca401}},	//   hera_, nače, _aanz, _stræ,
   {{0x29184f61,0x7523cf62,0x63bc15d0,0x3a2dcf63}},	//   kera_, _banz, _hurn, _grep_,
   {{0x7523cf64,0x70b9035a,0xa06a8098,0x98a68878}},	//   _canz, _आलेल, _каза_, _дизе,
   {{0x63bc4f65,0x7523ca24,0x3a20008e,0x201ecf66}},	//   _jurn, _danz, _asip_, _usti_,
   {{0x63bc1ce9,0x25eb00d4,0xa5bb009a,0x9c7c811a}},	//   _murn, _चिली_, _krót, jače,
   {{0xa2bc050a,0x320682c4,0x2ee00140,0xe57a8087}},	//   _एलर्, ntoy_, daif_, _кзд_,
   {{0x29183d92,0x752382af,0xd5af8558,0x3d140035}},	//   gera_, _ganz, _іс_, ड़ों_,
   {{0xd6db1c74,0xa89914bc,0x20992f84,0x36d54f67}},	//   ита_, скву_, сквы_, зобр,
   {{0x27ed04c4,0x7523822e,0x2d8ccf68,0x6d474f69}},	//   čen_, _zanz, lode_, _soja,
   {{0x29184f6a,0x7c2e4f6b,0x752383c3,0xe4cb019f}},	// [3b50] bera_, _arbr, _yanz, لبان_,
   {{0x80f501bb,0xa5bb03a8,0x2d8c929d,0xd7fb0012}},	//   _эпох, _asóc, node_, _кум_,
   {{0x5b159289,0x9c7c8024,0x290106cb,0xf8b1003d}},	//   змет, bače, _icha_, _سکس_,
   {{0x501a004c,0x3a2d82e6,0x2d8c8b48,0xe3b83941}},	//   _פורו, _prep_, hode_, ібі_,
   {{0x6d4701a1,0x2d8c9a47,0x7f3a025f,0x6b8b8a53}},	//   _toja, kode_, _הערו, rogg,
   {{0x6b8bcf6c,0x6d5e0192,0xe8b927ec,0x63bc15df}},	//   sogg, chpa, _आलोच, _furn,
   {{0x63bc4f6d,0xb4d736cf,0x6b8b847f,0xa5bb09aa}},	//   _gurn, सरी_, pogg, _erót,
   {{0xd00e8013,0x636883bd,0x29184f6e,0x7523cf6f}},	//   الي_, _друг_, zera_, _sanz,
   {{0x28cf9a8f,0x236d8ad4,0x29014f70,0x63bc4f71}},	//   _स्थि, _imej_, _ocha_, _zurn,
   {{0x9c7c80fe,0x290143d1,0x6f09bdc8,0x29184f72}},	//   zače, _ncha_, sfec, xera_,
   {{0x7523cf73,0xb97a80be,0xccf200be,0x317a80be}},	//   _vanz, _פרעז, עכט_, _פרעמ,
   {{0x29014f74,0xe50b00c2,0x29184f75,0x28cf8327}},	//   _acha_, स्ति_, wera_, _स्ति,
   {{0x7523cf76,0xd2520019,0x442ea633,0xb6ba8e82}},	//   _tanz, رنس_, _erf_, _הצני,
   {{0x27f80039,0x7afd06a8,0x75238c53,0x442e8493}},	//   turn_, agst, _uanz, _frf_,
   {{0x29184f77,0x2007bb19,0x2f5601a1,0x8fa64f78}},	//   rera_, ntni_, птас, заве,
   {{0xb8f30076,0x63ba2755,0x29014f79,0x9f5803ed}},	//   _ह्_, _étni, _echa_, murë_,
   {{0x63bc4f7a,0x2ee000f7,0x9c7c812b,0x26dd81bc}},	// [3b60] _surn, raif_, rače, _mewo_,
   {{0x63bc2240,0x20078968,0x6284008e,0x33248282}},	//   _purn, ktni_, _ixio, _samx_,
   {{0xa3dec50b,0x3f8d8118,0xd25280d7,0x61e60687}},	//   दीप_, koeu_, کنش_, lskl,
   {{0x2d8c8052,0xeb9a8009,0xa5bb4f7b,0xaefb026b}},	//   zode_, щие_, _prót, _alùf,
   {{0x61e60338,0x63a41e73,0x60de008e,0x61ed807a}},	//   nskl, _mhin, _kepm, šaln,
   {{0xe8949663,0xdb1c8004,0xf8be4f7c,0x3206cf7d}},	//   маль, _strä, ्डिय, rtoy_,
   {{0x2d8c803b,0x55f880c8,0x64a6227b,0xada31290}},	//   vode_, _অনেক_, _хава, _чарл,
   {{0x9634a7d4,0x442e826c,0x6449061c,0x63a4027d}},	//   дниц, _rrf_, çmiş, _nhin,
   {{0xa3de8b9f,0xbb3b8039,0x80dd00ab,0x798e02a0}},	//   दीन_, _פעמי, _বাস্, kobw,
   {{0x7c86908d,0x61e60b81,0x63a44f7e,0x442e82df}},	//   зуме, dskl, _ahin, _prf_,
   {{0x9c7ccf7f,0x63a44f80,0xb4bcb192,0xbae100ab}},	//   dačc, _bhin, _अली_, _ভাবছ,
   {{0x63a44f81,0x29014f82,0x7ae2804f,0xaca3819d}},	//   _chin, _scha_, naot, _gwọk,
   {{0x63a402a3,0xb7e0800c,0xdb0400ff,0x60cb8061}},	//   _dhin, _गौतम_, _khiê, _élmé,
   {{0x6e22acde,0x63b60748,0x442e82df,0x6d4a2c02}},	//   _isob, _eiyn, _trf_, öfal,
   {{0xd90f0077,0xd5a5803d,0x7d1acf83,0x442e80b9}},	//   نیک_, _تلوی, mets, _urf_,
   {{0x63a40ad7,0x95d90081,0x6d5c4f84,0xa2de0072}},	//   _ghin, ждат_, _alra, परण्,
   {{0x59b722d5,0xf1d780c8,0x7aed011e,0x6d4acf85}},	// [3b70] _इंटर, _সম্ভ, _idat, _kofa,
   {{0xdb040028,0xb4d736cf,0xb4c9016f,0x29014f86}},	//   _nhiê, सरे_, ैरे_, _ucha_,
   {{0xa5bb008b,0x8c190c3b,0x9cd781c6,0xdb1ccf87}},	//   _prós, تيار_, פואה_, _kurè,
   {{0x7d1aa61b,0x27e500e1,0xfaff0168,0x63a403ed}},	//   hets, álnu_, ngë_, _xhin,
   {{0x7d1ab131,0x539c0039,0x6f0d4f88,0x6e22bd92}},	//   kets, זיאו, mfac, _nsob,
   {{0x7d1a82fd,0xdb04001c,0x6f028118,0x67260fbc}},	//   jets, _chiê, _acoc, _zakj,
   {{0x29c287ca,0x7aed255e,0xdb1c8082,0x28de8105}},	//   _eða_, _odat, _strå, _नजरि,
   {{0x6f0d0352,0x80380039,0x3eb98aa2,0x20079b46}},	//   nfac, לנוע_, øst_, rtni_,
   {{0x2007b2b7,0x63a44f89,0x61e48013,0x6adc00ab}},	//   stni_, _rhin, áilt, _ভালো,
   {{0x7aed4f8a,0x7d1a82a0,0xa2c99d41,0x6d4acf8b}},	//   _adat, gets, हुर्, _cofa,
   {{0x68e3cf8c,0x63a44f8d,0xceb40085,0x69cd4f8e}},	//   mand, _phin, ndər_, _atae,
   {{0x68e3b560,0x61e980e8,0xe29a4f8f,0xdb0a81d6}},	//   land, _kvel, жам_, _šnúr,
   {{0x7d1a84b8,0x27e0a43e,0xa3b9a594,0x7aed031d}},	//   bets, ćine_, _अंक_, _ddat,
   {{0x25ee000f,0x63a43ece,0x6d4a831d,0xb4d70441}},	//   ेंसी_, _whin, _gofa, सरो_,
   {{0x63a40051,0x6609cf90,0x672601ed,0x7aed0372}},	//   _thin, ltek, _pakj, _fdat,
   {{0x7e7b494f,0x61e9cf91,0x6729cf92,0xe82080c2}},	//   _župa, _ovel, ndej, _मनसा_,
   {{0xdd9207bd,0x80dd00c8,0x6609cf93,0x68e385d1}},	// [3b80] نور_, _বার্, ntek, kand,
   {{0x68e3cf94,0x443101dd,0x442300b9,0xa5bb0511}},	//   jand, _brz_, _bsj_, _prór,
   {{0x68e3cf95,0x6726437d,0x6f0d0122,0x61e98e5a}},	//   dand, _takj, bfac, _avel,
   {{0x9c7c803a,0x6729cf96,0xaefb0362,0x65c64f97}},	//   nača, jdej, _clùd, _обма,
   {{0xa3de023c,0x68e3cf98,0xdb040028,0x61e98088}},	//   _दौर_, fand, _phiê, _cvel,
   {{0x68e3cf99,0x6da622be,0x6f0281e8,0x7ae29b9c}},	//   gand, _цига, _scoc, saot,
   {{0x9c7c8267,0xa3b9970c,0xd5ad0019,0x443100e5}},	//   kača, _अंग_, _اہل_, _grz_,
   {{0x9c7c803b,0xdca30ab2,0x6d4a9277,0x61e94f9a}},	//   jača, _раси, _sofa, šeli,
   {{0xf8cf8aed,0xdb040028,0x6609bbf7,0x9c7c856f}},	//   _स्वय, _thiê, gtek, dača,
   {{0x7afd91bf,0x657e01a8,0x7ae08106,0x7bdc010c}},	//   _östr, nnph, _hemt, _kwru,
   {{0x291ccf9b,0x7d1acf9c,0x69c0cf9d,0xfa1300ab}},	//   meva_, rets, _hume, িয়াল_,
   {{0xee3a93cd,0x69c09167,0x291cc291,0x7d1a932e}},	//   _мне_, _kume, leva_, sets,
   {{0xf2d38158,0x69c0cf9e,0x6d4a822e,0x5eac80ab}},	//   כער_, _jume, _tofa, _ট্রে,
   {{0x69c0cf9f,0x291ccfa0,0xdb1c82be,0xceb40085}},	//   _mume, neva_, _duré, ydər_,
   {{0x69c0cfa1,0x9c7c9123,0xa5bb0032,0xa3ea064a}},	//   _lume, bača, _aróp, _मिग_,
   {{0x7ae0cfa2,0xb4d7016f,0x4423008e,0xaefb026b}},	//   _nemt, सर्_, _rsj_, _amùr,
   {{0x68e3cfa3,0x69c0a9da,0xdb008511,0xf1a70088}},	// [3b90] yand, _nume, _limó, _орон,
   {{0x291ca43e,0x15f3035a,0xd49b2772,0x6e2d3cc0}},	//   jeva_, ेंबर_, оре_, rvab,
   {{0x7527020f,0x291ccfa4,0xf48500d5,0x66098102}},	//   _vajz, deva_, رائی, ztek,
   {{0x68e3badc,0x69c0930e,0x395ecfa5,0x3d0e9f5b}},	//   wand, _bume, _alts_, त्ते_,
   {{0x68e3cfa6,0xdb1c802a,0xe5c40198,0xeb9200be}},	//   tand, _xuré, _ассо, אָג_,
   {{0xa0a5a1a7,0x25b84fa7,0x7c3a042b,0xe8e000ff}},	//   налд, _girl_, _štre, _kiều_,
   {{0x7ae08e23,0x1fb58d69,0xdb008118,0x442300b9}},	//   _femt, нсир, _cimó, _usj_,
   {{0x69c0bfbc,0x491b800d,0x9f582bc6,0xa295902a}},	//   _fume, _यसको_, turé_, _забі,
   {{0x68e39c5d,0x61e9cfa8,0x69c0cfa9,0x6729cfaa}},	//   pand, _uvel, _gume, rdej,
   {{0x6609cfab,0x291cc194,0x7bc800e7,0x61fd4fac}},	//   rtek, ceva_, _éduc, dusl,
   {{0x6609cfad,0xeb9a0056,0x9f580036,0x9c7c81a1}},	//   stek, зин_, suré_, tača,
   {{0x68e18e20,0x6609bd90,0xdb1ccfae,0xd6d9866f}},	//   _held, ptek, _puré, ykły_,
   {{0x7e7b4faf,0x68e1c2f7,0x632200ab,0x61fd02f1}},	//   _župn, _keld, যালয়_, gusl,
   {{0x9c7c84e8,0xdb190087,0x68e1a72d,0xade302f1}},	//   mačn, _cuvâ, _jeld, गठनन_,
   {{0x9c7ccfb0,0x0396017a,0x68e1977a,0xfbc6800d}},	//   lačn, _прия, _meld, _रूपम,
   {{0x28d00ebf,0xa5bb0073,0x20050722,0x291c80d2}},	//   _त्रि, _próp, àlia_, zeva_,
   {{0x61ed8d11,0x9c7c803a,0xc7b2812a,0x7ae64fb1}},	// [3ba0] šalj, načn, רבן_, makt,
   {{0x2cbc004a,0x6aa40234,0x26cb0037,0x7ae0cfb2}},	//   øvd_, _izif, _efco_, _semt,
   {{0x69c0cfb3,0x66e60b9c,0xdee61b4d,0x291ccfb4}},	//   _sume, _пона, _пони, veva_,
   {{0x9c7c826f,0xb4bc864a,0xaca401bc,0xe1ff002a}},	//   kačn, _अल्_, _nrụr, izón_,
   {{0x291ccfb5,0x68e1cfb6,0xdb00957a,0x395e808e}},	//   teva_, _beld, _simó, _plts_,
   {{0x6b841487,0x6fc78214,0xaca40135,0x68e18661}},	//   _ljig, _sıca, _arụr, _celd,
   {{0x64a34fb7,0xdca31e0b,0x7ae64fb8,0x291ca47b}},	//   _бара, _бари, kakt, reva_,
   {{0x69c0b3ac,0x4444022b,0x6d4e4fb9,0x59dd801b}},	//   _tume, mx_, _hoba, नीहर,
   {{0x291ccfba,0x9c7ca1f6,0x44444fbb,0x68e1cfbc}},	//   peva_, gačn, lx_, _feld,
   {{0x68e1cfbd,0xdb00a68b,0xc0aa9459,0x6d4e4fbe}},	//   _geld, _timó, _فاضل_, _joba,
   {{0x7ae64fbf,0x6d4e4fc0,0x236000f3,0x44444fc1}},	//   fakt, _moba, _blij_, nx_,
   {{0x4444258a,0x61fd2dd4,0x5fb40424,0x68e1cfc2}},	//   ix_, tusl, ंगफल, _zeld,
   {{0xf99f06c0,0xc33384de,0xe1ff0118,0x3f800035}},	//   stèm_, אור_, azón_, dniu_,
   {{0x7d1e02a5,0x2b840457,0x6d4e4fc3,0x6b840135}},	//   jeps, rıca_, _noba, _ejig,
   {{0x7d1e4fc4,0x6aa40c6a,0x97a7446e,0xa0c401a8}},	//   deps, _ezif, ерал, ايفو,
   {{0x5f94038b,0x7ae64fc5,0x7c9b810f,0x4444022b}},	//   гист, cakt, _משוג, dx_,
   {{0x6d4e2d7c,0x444419ea,0x80e18264,0x2b9c928a}},	// [3bb0] _boba, ex_, _নাস্, mích_,
   {{0x6d5acfc6,0x44444fc7,0x6b9d29b8,0x61ed4fc8}},	//   nkta, fx_, llsg, _ival,
   {{0x9c7c826f,0xa5bb002a,0x5f0c00d4,0xdbdb9727}},	//   začn, _isóm, _डॉक्_, _yáñe,
   {{0x2b9c800d,0x68e70019,0x68e1cfc9,0x29032c9f}},	//   ních_, lajd, _seld, lgja_,
   {{0x22588009,0xaa58cfca,0xe1ff01ca,0x68e181a9}},	//   ницы_, ницу_, nuó_, _peld,
   {{0x865a0bea,0x29031805,0x6d4e4fcb,0x7ae64c72}},	//   _חדשי, ngja_, _goba, zakt,
   {{0xe8e00028,0x68e18357,0x660d4fcc,0x7ae6004a}},	//   _hiểu_, _veld, ltak, yakt,
   {{0x6d4e0063,0xee398139,0x672d4fcd,0xe8e00028}},	//   _zoba, дни_, ndaj, _kiểu_,
   {{0x27e08025,0x0d858e8e,0x338488d5,0x68e1cfce}},	//   ćina_, клин, _сурв, _teld,
   {{0xb2749c64,0x9c7c803e,0x41b584c0,0x7ae60057}},	//   _слуш, račn, _شمار, wakt,
   {{0x80ca904f,0x61ed4fcf,0x63bb804f,0x9c7c80e1}},	//   _स्टे, _aval, _kiun, sačn,
   {{0x9c7c8968,0x2cb00085,0xe1ff2db0,0x628c8035}},	//   pačn, ündə_, rzón_, żnoś,
   {{0x2d8701ac,0x63bba8b5,0x63660118,0x63a98428}},	//   čnej_, _miun, _lóng, _mhen,
   {{0x7ae64fd0,0x29032c9f,0xdb0b4fd1,0x673d0197}},	//   sakt, ggja_, _bufó, _ansj,
   {{0x66e619bb,0xdee64b1e,0x6d4e4fd2,0xc0e311b3}},	//   кова, кови, _roba, роск,
   {{0x2b9c83cb,0x660d4fd3,0xe8e00028,0xd5c302f1}},	//   cích_, ftak, _biểu_, _वंशज,
   {{0x6d4e4fd4,0x660d1d4d,0x672b80f1,0x7bc3cfd5}},	// [3bc0] _poba, gtak, _magj, _hunu,
   {{0x63a9a0d1,0x44444fd6,0x7bc38010,0x7ae40e20}},	//   _ahen, tx_, _kunu, _heit,
   {{0x444406e3,0x61ed0052,0x660d3e3d,0x272192c7}},	//   ux_, _zval, atak, _मसूर_,
   {{0x7bc3cfd7,0x44444fd8,0x63a9cfd9,0x7d1e4fda}},	//   _munu, rx_, _chen, seps,
   {{0x7ae44fdb,0xa96aae78,0x63bb81fb,0x63a9cfdc}},	//   _meit, мида_, _diun, _dhen,
   {{0x7ae44fdd,0x7e69cfde,0x2b9c81d0,0x442784e8}},	//   _leit, dzep, zích_, _osn_,
   {{0x8c43028e,0xebe32b83,0x7bc3cfdf,0x2d98026c}},	//   _кере, _восп, _nunu, _ikre_,
   {{0x63bbcfe0,0x6f044fe1,0x59dd8740,0x03a686a1}},	//   _giun, ngic, _नौकर, _рибо,
   {{0xf7730051,0xdb1ccfe2,0x9c7c826f,0x692680a9}},	//   יקה_, _jurí, tačo, _имаа,
   {{0x7bc3cfe3,0x63a9cfe4,0x6b82882c,0x73d882fb}},	//   _bunu, _zhen, lnog, ндор_,
   {{0x7ae4034a,0x6d5acfe5,0x68e72d16,0xaf06cfe6}},	//   _beit, rkta, vajd, _апел,
   {{0x3f8081e2,0x7ae40083,0x16dc016f,0x7bc3cfe7}},	//   čius_, _ceit, बरोब, _dunu,
   {{0x3ea08013,0x7ae41c2a,0x7c3e826c,0x2b9c81a8}},	//   _áit_, _deit, _šprd, rích_,
   {{0x3cfe0c87,0x66008057,0x28c6940d,0x6b828428}},	//   _लागे_, mumk, रुचि, hnog,
   {{0x7ae44fe8,0x7bc38397,0x4fc40391,0x212c820f}},	//   _feit, _gunu, иста, _madh_,
   {{0x2d9eafd1,0x3d0e816f,0x61ed943c,0x2d9802c4}},	//   llte_, त्रे_, šali, _akre_,
   {{0x636605a4,0x6b82805c,0x61ed4fe9,0x63bb8081}},	// [3bd0] _dónd, dnog, _uval, _riun,
   {{0x7c3a025b,0x63a9cfea,0x7ae40352,0x63bb827e}},	//   _štra, _shen, _zeit, _siun,
   {{0x2d9e8ad0,0x6b82831d,0xd49b44f1,0x660d4e6c}},	//   ilte_, fnog, фра_, stak,
   {{0x7ae4062f,0x4ea701e2,0xe8e00028,0x2d9e81ec}},	//   _xeit, _арга, _tiểu_, hlte_,
   {{0x63bb8010,0x2ee90359,0xad9b0118,0x2175b306}},	//   _viun, maaf_, _opúx, лукр,
   {{0x776284c3,0x02a3019d,0x2ee943de,0x3f868242}},	//   _alox, _arịọ, laaf_, _ajou_,
   {{0xd4980190,0x68e50965,0x101581a8,0x212c8a2a}},	//   _арт_, _mehd, ابتد, _dadh_,
   {{0x68e50009,0x7bc3cfeb,0xd10580dc,0x212c8219}},	//   _lehd, _runu, _रावण_, _eadh_,
   {{0xa3e7101b,0xdb1c84c3,0x7bc3cfec,0x799500b4}},	//   _मौत_, _xurí, _sunu, kozw,
   {{0x7ae44fed,0x7762cfee,0x7bc3cfef,0x2ee94ff0}},	//   _seit, _elox, _punu, haaf_,
   {{0x7ae44c80,0x7bc3828d,0x3b0a177f,0x672b8061}},	//   _peit, _qunu, нено_, _tagj,
   {{0x67209351,0xa2aa904f,0x63760115,0xe61180d7}},	//   cemj, जेक्, ršno, _هشت_,
   {{0x7ae40125,0x68e5026c,0x06b180ab,0x69c4426a}},	//   _veit, _behd, _ট্রি, _quie,
   {{0x7ae438e1,0x7bc3cff1,0xfce58dc9,0xdb19006a}},	//   _weit, _tunu, _соко, _nuvæ,
   {{0xb4df8576,0x7ae4031d,0x4427a26a,0x63660118}},	//   तरी_, _teit, _usn_, _pónd,
   {{0xfbd28051,0x80d41053,0x6e3b0bcf,0x26cd9f10}},	//   _פתח_, _ब्रे, _šuba, nceo_,
   {{0x22460179,0x36674ff2,0x6b82812b,0x0d861a51}},	// [3be0] _çok_, гато_, vnog, глан,
   {{0x0446220b,0x6e2409ca,0x8c461f8c,0x636607f1}},	//   лезн, rwib, лезе, _dóne,
   {{0x98a8000d,0xf8a8000d,0x6b828140,0x212c851e}},	//   _गरिए, _गरिय, tnog, _radh_,
   {{0xe51381c4,0x25e80540,0xdb1ccff3,0x7c3ecff4}},	//   त्ति_, _चौथी_, _turí, _ápre,
   {{0x320201ac,0x5b7b00be,0xf1bf2825,0x2d9e821e}},	//   nuky_, ערנא, lvár_, ylte_,
   {{0x6b8282ce,0xa5bb002a,0x75218019,0x31348c4f}},	//   snog, _apóf, jelz, рекр,
   {{0xfaff00f1,0x8d63260c,0x27e081a1,0x6720a1a9}},	//   dhën_, _увре, ćino_, temj,
   {{0x442a056c,0x9f549156,0x998d8087,0x17548081}},	//   _isb_, рвич, _preţ_, рвия,
   {{0x28cf8540,0x6ce6a183,0x998900e1,0xe4e6c26b}},	//   _स्कि, ліне, _hrať_, лінн,
   {{0x98ba0176,0x752194cf,0xf1bf4ff5,0xf28bb7b6}},	//   _anpč_, gelz, kvár_, _אָבֿ,
   {{0x9c7c803b,0x9f5806a5,0x2cb8816d,0xe7b4015c}},	//   mačk, ntró_, ärd_, ंगाप,
   {{0x78a8a43e,0x3d140f97,0x442a4ff6,0xda350009}},	//   _izdv, न्ते_, _msb_, аемы,
   {{0xed5a8544,0xa77b80be,0x442a01e0,0x629e8035}},	//   _под_, _אראפ, _lsb_, ępow,
   {{0x9c7c803b,0x44384ff7,0xceb383c8,0x442a0558}},	//   načk, _orr_, _פיס_, _osb_,
   {{0xe3b00416,0x657acff8,0x65688c5e,0x442a4ff9}},	//   تری_, mith, mhdh, _nsb_,
   {{0x657acffa,0xf40a00ab,0x7c2acffb,0x9c7ca1d1}},	//   lith, রবার_, _isfr, hačk,
   {{0x68e519e3,0x63ad4ffc,0x442a079f,0x557506e6}},	// [3bf0] _tehd, _ihan, _asb_, агат,
   {{0x9c7c82a5,0x63760353,0x046701a1,0x657acffd}},	//   jačk, jšnj, лтем, nith,
   {{0x2ca70e23,0x9c7c826f,0x63ad4ffe,0x752e0326}},	//   ånd_, dačk, _khan, _dabz,
   {{0xd4984aa5,0x20030b20,0x442a4fff,0xbe050065}},	//   уру_, muji_, _dsb_, _پوسٹ,
   {{0x63ad5000,0x81c780eb,0x442a008b,0x657ad001}},	//   _mhan, klēš, _esb_, kith,
   {{0x657a80f1,0x9c7cd002,0x63ad5003,0x645a84f6}},	//   jith, gačk, _lhan, kyti,
   {{0x5ba78767,0x63ad5004,0x657ad005,0x315804de}},	//   _браз, _ohan, dith, ריון_,
   {{0x63ad0028,0x7bd5011e,0x61fd2384,0x657a8428}},	//   _nhan, _itzu, krsl, eith,
   {{0x9c7cd006,0x9f4c5007,0x7bc75008,0xa3e78540}},	//   bačk, édé_, _huju, मीन_,
   {{0x7bc740f5,0xb4dfb9a1,0x8d5589e0,0x63ad02a0}},	//   _kuju, तरे_, ртич, _ahan,
   {{0xcb6a0021,0x64a59908,0xe8e00028,0x7bc7059c}},	//   ване_, рана, _hiệu_, _juju,
   {{0x63ad388d,0x661d49e9,0xfaff00f1,0x7bc75009}},	//   _chan, _opsk, shën_, _muju,
   {{0x63ad500a,0x6db2809a,0x7bc7500b,0x657a81f6}},	//   _dhan, _płat, _luju, bith,
   {{0x2907d00c,0x657ad00d,0x63ad0114,0x3202016b}},	//   ngna_, cith, _ehan, ruky_,
   {{0xb8ce2336,0x661d0df1,0xe8e00028,0x6b9b8c56}},	//   _और_, _apsk, _liệu_, _okug,
   {{0x63ad3503,0x2b40500e,0x7aeba642,0x6b9bd00f}},	//   _ghan, _unic_, jagt, _nkug,

   {{0x539b0039,0x7aeb81b0,0xc4e60198,0x7bd507f1}},	// [3c00] _ביקו, dagt, ижай, _atzu,
   {{0x63ad2407,0x845a5010,0x7bc75011,0x752e5012}},	//   _zhan, крет_, _buju, _qabz,
   {{0x9c7c812b,0xb4d60063,0x0c261e58,0xf0aa17ae}},	//   vačk, _सभी_, рмен, _школ_,
   {{0x657a805d,0x9f58023e,0x6d5e06ae,0x61e44e90}},	//   zith, rtró_, skpa, _kwil,
   {{0x2d828019,0x9f581e54,0x657a8234,0x9c7c936f}},	//   ékek_, stró_, yith, tačk,
   {{0x442a5013,0x61e40010,0xe8e000ff,0xdb1c9820}},	//   _tsb_, _mwil, _diệu_, _durá,
   {{0x9c7c803b,0x6b5f00f1,0x68ead014,0x44381929}},	//   račk, _dëgj, rafd, _urr_,
   {{0x7aeb8079,0x2ca71fd1,0x03d70039,0xd1388035}},	//   cagt, ünde_, _כולם_, _skąd_,
   {{0x9c7cd015,0x63ad031d,0x657a8174,0x70f69e09}},	//   mači, _rhan, tith, _نسائ,
   {{0x9c7cd016,0xa9068077,0x7bc084a7,0x21a68162}},	//   lači, _خبرن, _himu, _тизм,
   {{0x657a8013,0x7bc0d017,0x4438d018,0x63a280e5}},	//   rith, _kimu, ír_, olon,
   {{0x68e8d019,0x657ad01a,0x9c7c93b3,0x64410118}},	//   _hedd, sith, nači, _álie,
   {{0x645ad01b,0x7bc0d01c,0xda780071,0x27e9812b}},	//   syti, _mimu, аяр_, ćane_,
   {{0x7af6009a,0x63a28234,0x63ad501d,0x7e6d007a}},	//   _edyt, hlon, _whan, vzap,
   {{0x68e8bef0,0x63a28289,0x63ad501e,0x6db28063}},	//   _medd, klon, _than, _włas,
   {{0x7bc7501f,0x501b8051,0x9c7c811f,0x68e888f3}},	//   _ruju, כולו, jači, _ledd,
   {{0x7a1a80eb,0xba0180ab,0x63a2d020,0x68e88114}},	// [3c10] nātā, _এন্ড_, dlon, _oedd,
   {{0x7bc70748,0x6b9bd021,0x68e88365,0x3cec826c}},	//   _puju, _skug, _nedd, nadv_,
   {{0x63660065,0x6b89882c,0x7bc0acf7,0x5c070081}},	//   _hóna, _pjeg, _bimu, ряза,
   {{0x9c7c8025,0x41c4003d,0x63a2c89b,0xbd05846d}},	//   gači, _دقیق, glon, _adẹ́,
   {{0x19598110,0x7bc75022,0x7bc0ca43,0xab5da3b3}},	//   лады_, _wuju, _dimu, _niże,
   {{0x7bc7028a,0x63a2d023,0x98ac83bf,0x6366016a}},	//   _tuju, alon, _aldı_, _móna,
   {{0x63a2866b,0x7aeb97ea,0x680a8085,0x7bce957a}},	//   blon, pagt, _sədr, íbul,
   {{0xbb858013,0x438580f7,0x9b94a2b1,0x6b9bb022}},	//   _الري, _الرق, _дисц, _ukug,
   {{0x68e88114,0x290c8326,0x163981a8,0xa7628081}},	//   _fedd, _fcda_, اسبة_, якъд,
   {{0x4d65afd6,0x3a2d808e,0x6d5503ec,0x7c3e8988}},	//   сков, _isep_, _joza, _špra,
   {{0x69c9808e,0xd05c0085,0xaefb026b,0x3f58841c}},	//   _huee, barə, _alùm, _céus_,
   {{0x69c1d024,0x6d41007b,0x291a00ee,0x60c55025}},	//   _hile, _ólaf, _sbpa_, _aghm,
   {{0xe1ff1355,0x69c1d026,0x636600f7,0x3f9d8135}},	//   gró_, _kile, _cóna, _ikwu_,
   {{0x2bcf8894,0xe50303bb,0x7ae9a49f,0x6d5500eb}},	//   _संपा, _लागि_, _leet, _noza,
   {{0x6d43b117,0x05748277,0x201e253a,0x98a612ea}},	//   _inna, _باند, ïti_, сиве,
   {{0x6f09a75b,0x69c1d027,0xa3e781a2,0xe1ff5028}},	//   ngec, _lile, मीण_, bró_,
   {{0xee3a2628,0x69c18083,0x6e29d029,0x6b998079}},	// [3c20] ына_, _oile, nweb, dowg,
   {{0x7bc09219,0x66040cfa,0xd05c0085,0xa3de9521}},	//   _simu, ruik, zarə, दीक_,
   {{0x68e8805f,0x63a2809c,0xd5c8801c,0x3a2d81bf}},	//   _redd, tlon, _nền_, _asep_,
   {{0x387a8201,0x69c1d02a,0xaca38133,0x68e8d02b}},	//   _üzrə_, _aile, _atịk, _sedd,
   {{0x7ae9aaaa,0x9c7cb799,0x6d550118,0x63a2d02c}},	//   _deet, rači, _foza, rlon,
   {{0xdd9215e4,0x6d55502d,0xe6e08054,0x69c1d02e}},	//   _روز_, _goza, नर्ज, _cile,
   {{0x7bc0878a,0x69c18b23,0x2c1c00c2,0x657e0234}},	//   _timu, _dile, _नहिं_, miph,
   {{0x6d43ab2e,0x69c18046,0x2d9a502f,0x7ae9d030}},	//   _anna, _eile, lope_, _geet,
   {{0xa5bb0510,0x2cea8987,0x6d551a1a,0x68ee00b9}},	//   _próx, льно_, _yoza, kabd,
   {{0x8e5700be,0x3f9d8870,0x657e005d,0x68ee00b9}},	//   צייג_, _ekwu_, niph, jabd,
   {{0xfaff020f,0xaf0a89d7,0x80a692c8,0xa5bb12ca}},	//   shëm_, _مقام_, _امان, _isót,
   {{0x6d43b95f,0x69c1b05e,0xe1ff5031,0x657e5032}},	//   _enna, _zile, tró_, hiph,
   {{0xc7978065,0x5e5a9459,0xbc67804e,0x363680f7}},	//   _اپنا_, _حجاج_, لمین_, _دراس,
   {{0x69c1d033,0xfbcf9e5c,0xe1ff5034,0x7bdad035}},	//   _xile, بتی_, rró_, pptu,
   {{0x6d555036,0xdbe283a8,0x115b80be,0x2bcf852a}},	//   _roza, _téñe, נדלע, _संया,
   {{0x28d92594,0x443f0669,0x442ed037,0x9f051ca3}},	//   _ब्रि, _ču_, _isf_, تورو,
   {{0x67d18029,0x7ae9d038,0xa2a0483a,0x443ca514}},	// [3c30] _māja, _reet, _गुप्, _hrv_,
   {{0x7bcad039,0x7ae9d03a,0x443ca9b4,0x6eff026b}},	//   _kufu, _seet, _krv_, _bàbà,
   {{0x6d55003b,0x69c1d03b,0x7ae98650,0xa5bb0333}},	//   _voza, _rile, _peet, _apóc,
   {{0x2564016d,0x1dc883eb,0x7aef503c,0x7bcabd92}},	//   _höll_, रदात, nact, _mufu,
   {{0x2bcf83b7,0x6d5509ab,0x7c2e503d,0x7ae982f1}},	//   _संभा, _toza, _esbr, _veet,
   {{0x7ae9c4a6,0x6b8d017f,0x657e503e,0xdb0d003d}},	//   _weet, _ljag, ciph, _dhaé,
   {{0xb4e50f12,0x02fb3a6a,0x69c1d03f,0xa2a018a9}},	//   नरी_, ्लाह_, _vile, _गुन्,
   {{0xf7718250,0x3f890355,0x27e501ac,0x23cf86b7}},	//   بات_, nnau_, álny_, _संबद,
   {{0x14da9880,0x7aef5040,0x442e8358,0x645c8bc5}},	//   _म्हण, dact, _asf_, ørin,
   {{0x6b8d5041,0x2bb99664,0xe579981f,0x442e8388}},	//   _ajag, ेदवा, рзо_, _bsf_,
   {{0x3a202218,0x443c82f7,0xa34a1a1f,0x1b4a0ae7}},	//   _spip_, _crv_, азна_, азни_,
   {{0xeaba01e8,0x2007d042,0xe51900bc,0x920d8744}},	//   ийн_, muni_, न्ति_, _समाज_,
   {{0x3dd901c0,0x2007d043,0xe7968019,0x657e0234}},	//   _ntsw_, luni_, _بالک, yiph,
   {{0x6f1d02af,0x6aad5044,0xfd52019d,0x200c023e}},	//   _absc, _dzaf, _dajụ, àdio_,
   {{0x2007d045,0x2918054f,0x7bcad046,0x68ee5047}},	//   nuni_, rfra_, _gufu, rabd,
   {{0x3f891670,0xa3de82f1,0xa3cd0327,0x2087004a}},	//   gnau_, दीओ_, रदन_, ійти_,
   {{0x27e08025,0xbea35048,0xee373eb9,0x2007a5d2}},	// [3c40] ćini_, датк, онт_, huni_,
   {{0x6f1d5049,0x2007d04a,0x645e504b,0x443c80b9}},	//   _ebsc, kuni_, typi, _yrv_,
   {{0x2007d04c,0x657e2dc8,0x2127826c,0x7ac69ed5}},	//   juni_, riph, denh_, осле,
   {{0xeb9aaf0c,0x8cda00d4,0xe73a0009,0x3e7002be}},	//   шие_, _प्रो, _тем_, _côté_,
   {{0x094a9445,0xee371663,0x27ed0024,0x914aad01}},	//   ички_, _дня_, ćene_, ичка_,
   {{0xaca391d3,0x661603ba,0x2007d04d,0x7aef0087}},	//   _atọk, mtyk, funi_, zact,
   {{0x64a30a42,0xdca30cec,0x2007d04e,0xdb0f026f}},	//   _жара, _жари, guni_, ždéh,
   {{0x3b078ae7,0x7bca818e,0x7bde0198,0x29008162}},	//   _месо_, _rufu, mppu, şia_,
   {{0xc7b31a15,0x799c0578,0x27e9805c,0xed8acc43}},	//   ובה_, korw, ćana_, исок_,
   {{0x661601e2,0x2007822e,0xdb0d00e7,0x067b007c}},	//   ityk, buni_, _chaî, ינפל,
   {{0x20078098,0x3f89031d,0x2369504f,0x6aad0035}},	//   cuni_, ynau_, _plaj_, _szaf,
   {{0x926b3ce9,0x66165050,0x6aa40a03,0x443c9502}},	//   арга_, ktyk, _byif, _vrv_,
   {{0x81d300ab,0x64480118,0x799c5051,0x236900c3}},	//   হীন_, _ádif, forw, _vlaj_,
   {{0x7aef5052,0x7bcad053,0x7c3e802a,0x69dd0e20}},	//   sact, _tufu, _ápro, rpse,
   {{0xd5c88028,0x752881ac,0xd24e004e,0x443c8980}},	//   _mềm_, medz, نچی_, _urv_,
   {{0x2bcf89a3,0x27fe1e51,0x69dd5054,0xa857825f}},	//   _संता, átna_, ppse, חילה_,
   {{0x20078245,0x66f42187,0xef19ab30,0x3f890428}},	// [3c50] zuni_, ьпту, niża_, rnau_,
   {{0x6d589487,0x2007d055,0x8c6701a8,0x7d1a8192}},	//   _jova, yuni_, يطان, nfts,
   {{0x6d58a651,0x7aed010b,0x256980e1,0x49b800d7}},	//   _mova, _keat, _júla_, _بايد_,
   {{0xa2a00697,0x6d58d056,0x7ae28637,0x20079ffb}},	//   _गुड्, _lova, gbot, vuni_,
   {{0x69c55057,0x6145980f,0xd9458256,0x7aed5058}},	//   _kihe, зела, зели, _meat,
   {{0x6d5890ac,0x2007d059,0x4129813a,0xaca381bc}},	//   _nova, tuni_, соко_, _stọk,
   {{0x77a5862f,0xfbc68beb,0x6d47505a,0x2bc6816f}},	//   lóxi, _रंगम, _inja, _रंगा,
   {{0xdb1cd05b,0x6f0d505c,0xd343815b,0x6e2281a8}},	//   _strö, ngac, _تفری, _bpob,
   {{0xc3329a6a,0x6b9d002a,0x6d470088,0x70a8125f}},	//   _און_, dosg, _knja, _गर्ल,
   {{0x7ac4821e,0x4423008e,0x61e98caa,0xceb981d0}},	//   _істе, _kpj_, _iwel, neři_,
   {{0x04458c8e,0x75351917,0x6d58a628,0x442303ac}},	//   ченн, _mazz, _dova, _jpj_,
   {{0x61e9d05d,0x69c50364,0x7aed04bc,0x6616505e}},	//   _kwel, _aihe, _ceat, ytyk,
   {{0x799c505f,0x442300dd,0x99890503,0x69c53bbb}},	//   torw, _lpj_, _draž_, _bihe,
   {{0x6d5880cd,0x753504b7,0xb227007b,0x61e9874b}},	//   _gova, _nazz, _svæð, _mwel,
   {{0x2564016d,0x7aed0051,0x69c525d2,0x44310b67}},	//   _följ_, _feat, _dihe, _nsz_,
   {{0x6d470034,0x6f1ba498,0xdfcf00f7,0x7aed0427}},	//   _anja, nfuc, طيك_, _geat,
   {{0x75355060,0x69c50609,0x77a581df,0x26c2a4bc}},	// [3c60] _bazz, _fihe, góxi, žkov_,
   {{0xaa3b0039,0x75350081,0x66161c7b,0x2d8100b4}},	//   _פתיח, _cazz, rtyk, gihe_,
   {{0xa0a6002e,0x6616324b,0x69dbd061,0xdd8f00f7}},	//   _ханд, styk, _atue, دول_,
   {{0x7f4a1381,0x6d470a40,0xe3c9801c,0x69c54191}},	//   _الحق_, _enja, _nằm_, _zihe,
   {{0x7ae2d062,0x20185063,0xf8dd800d,0x200a5064}},	//   rbot, ltri_, नुभय, lubi_,
   {{0xdb15d065,0x753525c0,0x6d470669,0x66043090}},	//   _buzó, _gazz, _gnja, mrik,
   {{0x61e9d066,0x20185067,0x6d58a7be,0xd83a81e5}},	//   _ewel, ntri_, _rova, сэл_,
   {{0x95d88009,0x753504b9,0x6d58a986,0x6a86d068}},	//   одит_, _zazz, _sova, _елба,
   {{0x3a3fd069,0x7bce0812,0x61e98355,0x7aed506a}},	//   _grup_, _hubu, _gwel, _reat,
   {{0x7bce2133,0x6b82d06b,0x7bcd8088,0x644827c4}},	//   _kubu, liog, _čaur, _àdis,
   {{0x75288029,0x6366007b,0xd5b88029,0x43950d5f}},	//   redz, _tónl, rmā_, данс,
   {{0x98ac8029,0x6604506c,0xd5b880eb,0x2240506d}},	//   _gadā_, krik, smā_, _brik_,
   {{0x27e085f5,0x6d58a007,0x7bce506e,0x212a026c}},	//   ćinu_, _tova, _lubu, febh_,
   {{0x6604180a,0xdb0981a8,0x35b38d8e,0xdb0d1627}},	//   drik, _mheá, _збір, _ciaò,
   {{0x7aed506f,0x753512bb,0x36d51bcb,0x7bce3f72}},	//   _teat, _razz, добр, _nubu,
   {{0x27ff2ee4,0x2d9ed070,0x97a40162,0x26c2816b}},	//   čun_, lote_, ерул, žkou_,
   {{0x6f0d34ef,0x75350081,0x6d4700dd,0x224000b9}},	// [3c70] rgac, _pazz, _pnja, _grik_,
   {{0x2d9ed071,0x442300b9,0x2fc6cb66,0xdb1c816a}},	//   note_, _ppj_, _liog_, _gurú,
   {{0x69db8aa2,0x2d8cd072,0x200a00e5,0x7bce25f1}},	//   _stue, inde_, cubi_, _cubu,
   {{0x2bcfbf53,0x23cf800c,0x7bce5073,0x75355030}},	//   _संसा, _संसद, _dubu, _wazz,
   {{0xb90a0104,0xe1f881e5,0x75351347,0xcf560039}},	//   _nghệ_, згі_, _tazz, _חברת_,
   {{0x09e200ab,0x2d8c81ed,0x2d9eb883,0x98a59f2f}},	//   _বিমা, jnde_, jote_, миле,
   {{0xb4ab816f,0x27e98503,0x7bce2d58,0x2d9e8a41}},	//   _खरे_, ćano_, _gubu, dote_,
   {{0x2d8cd074,0x23668052,0x6d5c8bd7,0x53348012}},	//   ende_, ckoj_, öran, _пест,
   {{0x09e20a49,0xee368110,0x88c500ab,0x61fb005c}},	//   _বিভা, дны_, ্রিক, šulj,
   {{0x2d9ed075,0xe81e009a,0x9e6481a8,0xdce70824}},	//   gote_, _पहला_, عاين, _oljč,
   {{0x2fc68362,0x7983912e,0x61fc81a9,0xe3c9827d}},	//   _fiog_, minw, _ārli, _tằm_,
   {{0x2d8c87b3,0x09e20264,0xc8e65076,0x7983d077}},	//   ande_, _বিবা, कर्म_, linw,
   {{0x0caa000c,0xf77088ca,0x2bcfa594,0x2d9ea2c7}},	//   _कर्म, _حال_, _संवा, bote_,
   {{0xd5bb86b5,0x2d9ed078,0x2018329d,0xdb0d002a}},	//   _усе_, cote_, ttri_, _diañ,
   {{0x07a6069b,0x236d8f4c,0x2b495079,0x8fa6507a}},	//   давн, _olej_, _fnac_, даве,
   {{0x6604507b,0x290402bb,0x22401299,0x7bce507c}},	//   trik, şma_, _trik_, _rubu,
   {{0x63a4507d,0x7bce45d8,0x27ed003a,0xdcfa8029}},	// [3c80] _ikin, _subu, ćena_, litā,
   {{0x5983176e,0x6604507e,0xdd8f0290,0xab5d8609}},	//   _альб, rrik, لوق_, _biżo,
   {{0x660412a5,0x3a2480b9,0x2366811f,0xdcfa81a9}},	//   srik, _spmp_, tkoj_, nitā,
   {{0x491a03bb,0x2ca7d07f,0x61e9002e,0x2d9e8c53}},	//   म्रो_, _mynd_, ţele, zote_,
   {{0x236d81c0,0x23668168,0x63a40c93,0x2d9e80f8}},	//   _dlej_, rkoj_, _mkin, yote_,
   {{0x7bce40fa,0x2366803b,0x6b828110,0x7c3a15f2}},	//   _tubu, skoj_, siog, _štru,
   {{0xa3ae03b7,0x7bdc5080,0x2d9ec306,0x65631a49}},	//   कता_, _utru, vote_, önhe,
   {{0x96348785,0xc6f8cbc4,0x6d5c3110,0x2d9e804f}},	//   ениц, чних_, _hora, wote_,
   {{0x7e643437,0x2d9ed081,0xdb040f35,0x00000000}},	//   nyip, tote_, _fhiú, --,
   {{0x63a45082,0xa3cf959a,0xb4e881fe,0x6d5c435e}},	//   _akin, _वंश_, बरे_, _jora,
   {{0x7bda02be,0xb4de809a,0xcfa98019,0x69c88df6}},	//   _étud, _तभी_, _کالم_, _iide,
   {{0x63b6031d,0x6d5c5083,0x69c68c1c,0xa5bb5084}},	//   _chyn, _lora, ादकी, _apól,
   {{0x69c8d085,0x63a40122,0x61e2d086,0xfaff03ed}},	//   _kide, _dkin, npol, dhët_,
   {{0x3f84afa6,0x63a45087,0x6d5c5088,0x69c8d089}},	//   limu_, _ekin, _nora, _jide,
   {{0x58d40729,0xb8d7035a,0x69c8d08a,0x6d4ac0eb}},	//   тост, _जर_, _mide, _infa,
   {{0x69c8d08b,0x7538d08c,0x65ab164a,0xab5d81b9}},	//   _lide, _havz, rühm, _riżo,
   {{0x6d5c1f71,0x69c88cb5,0xa3e711bc,0x443e81a3}},	// [3c90] _bora, _oide, _मौज_, lvt_,
   {{0x3f84822e,0x69c8d08d,0xbddb0362,0xb91281bc}},	//   himu_, _nide, _crèa, ranụ_,
   {{0x236d8bda,0x3f84d08e,0x7538d08f,0x68f50380}},	//   _plej_, kimu_, _mavz, mazd,
   {{0x14df03b7,0xdb041a2c,0x6d5c01a8,0x61e2c018}},	//   _प्रण, _shiú, _eora, fpol,
   {{0x6d5c5090,0x69c880ad,0xdb1602be,0xb4bb852a}},	//   _fora, _bide, écéd, _अण्_,
   {{0x6d5c5091,0x61ed2a5a,0x7538a1f6,0x6722846d}},	//   _gora, _mwal, _navz, _aboj,
   {{0x69c8b4a2,0x61e2bf6f,0x10a2940b,0x7642948e}},	//   _dide, apol, лишн, _aroy,
   {{0x6d4ad092,0x69c8d093,0xdcfa80eb,0x7642d094}},	//   _anfa, _eide, vitā, _broy,
   {{0x69c89c8f,0x2ca7a0e5,0x63b6031d,0x7642d095}},	//   _fide, _synd_, _rhyn, _croy,
   {{0x69c8d096,0x68f5198a,0x128a80d5,0x6d5c40ac}},	//   _gide, jazd, _عملی_, _xora,
   {{0x809f0996,0x61ed5097,0x98148124,0xa2c204c5}},	//   _खुले, _awal, _لبنا, रेन्,
   {{0x7bc98d00,0x6d4ad098,0xe29a2d7a,0xdcfa80eb}},	//   _jieu, _enfa, зам_, ritā,
   {{0x7bc982be,0xfbcf864a,0x7f4b81f6,0x7642d099}},	//   _mieu, _सूरम, _ingq, _groy,
   {{0x7bc9d09a,0xdcfa80eb,0x200781e8,0x68f50061}},	//   _lieu, pitā, orni_, gazd,
   {{0x2d85d09b,0x7f5d02ba,0x61ed0c2e,0x61e2807a}},	//   mile_, _bosq, _ewal, zpol,
   {{0x7bc98586,0xe29a0021,0x2d85d09c,0x6d5c509d}},	//   _nieu, _най_, lile_, _sora,
   {{0x6d5c509e,0x661b885c,0xdd920154,0x61ed509f}},	// [3ca0] _pora, ntuk, هور_, _gwal,
   {{0xa3b4023c,0x2d85d0a0,0x6d5c02a3,0x661bade5}},	//   _जीत_, nile_, _qora, ituk,
   {{0x6aba8076,0x6d5c50a1,0xdcfa802e,0xaacb8ee6}},	//   ेश्र, _vora, lită, िशंक,
   {{0x69c8d0a2,0xeb97d0a3,0x2d85805d,0x673b809a}},	//   _side, них_, hile_, jduj,
   {{0x6d5c4e59,0x2d85829b,0x69c8d0a4,0x57be03eb}},	//   _tora, kile_, _pide, ्दीह,
   {{0x1ae700c8,0x61e4802e,0x61e2d0a5,0x61fb04f0}},	//   _কাছে_, ţilo, rpol, áuli,
   {{0x2d85d0a6,0x7dc90110,0x443e50a7,0xc7c69f0d}},	//   dile_, _užsa, _ét_, нсии,
   {{0xfaa6d0a8,0x7642d0a9,0x7c3e8019,0x35e687a1}},	//   _забо, _proy, _ápri, нцов,
   {{0x3f848542,0xf652990c,0x69c8904a,0x2d85d0aa}},	//   rimu_, ائع_, _tide, file_,
   {{0x3f84bbf8,0x63a291c9,0x2d85c0ec,0x4427808e}},	//   simu_, loon, gile_, _bpn_,
   {{0x64438052,0x4c948db3,0xddcd2cf6,0x68f5026c}},	//   _crni, тинс, izaš, vazd,
   {{0x6722d0ab,0x442780dd,0x63a282ec,0x6443cc91}},	//   _uboj, _dpn_, noon, _drni,
   {{0x2d85b1de,0x4427cd61,0x6366002a,0x2a668282}},	//   bile_, _epn_, _xóni, nyob_,
   {{0x2d85d0ac,0x63a2d0ad,0x6d4ad0ae,0x4aa5104f}},	//   cile_, hoon, _unfa, _गुणव,
   {{0xd3a745c8,0x27ed003a,0x395e82be,0xb8e91c58}},	//   _прип, ćeno_, _mots_, _ऋण_,
   {{0x25a102af,0x63a2d0af,0x61ed50b0,0xbddb010c}},	//   wohl_, joon, _twal, _drèn,
   {{0x7bc9c000,0xfaff00f1,0x63a2aa24,0xdcfa8162}},	// [3cb0] _rieu, shës_, doon, cită,
   {{0x200eb11a,0x7bc9d0b1,0x673b8b80,0xd2519190}},	//   kufi_, _sieu, zduj, ینا_,
   {{0x63a298f0,0x61fb84e1,0x661b8102,0x442750b2}},	//   foon, _svul, ztuk, ïn_,
   {{0x2d85d0b3,0x63a2d0b4,0x200782d4,0xdb160176}},	//   zile_, goon, vrni_, _chyè,
   {{0x239600eb,0x7bc980e7,0x61e080b9,0xe9d88084}},	//   nāja_, _vieu, _ctml, екі_,
   {{0x395ed0b5,0x79870314,0x2f3f019d,0x2d85d0b6}},	//   _cots_, nijw, _ọghi_, xile_,
   {{0xdd94053b,0x200e80b4,0x2795d068,0x0138025f}},	//   _сары, gufi_, кшир, גרות_,
   {{0x661bd0b7,0x6366016a,0xc01c80ff,0x20078168}},	//   ttuk, _tóni, _hước_, rrni_,
   {{0xe3b0845b,0x2d85d0b8,0x29014beb,0x2b4dd0b9}},	//   _طرف_, tile_, _odha_, _inec_,
   {{0x4d659af1,0x661bd0ba,0x89348077,0x1c45afe1}},	//   тков, rtuk, _معما, вном,
   {{0x2d85d0bb,0x661b8bc4,0xeb9a50bc,0x3d1906af}},	//   rile_, stuk, дин_, _पाने_,
   {{0x2d85d0bd,0x0056812a,0x6443807a,0xdcfa8493}},	//   sile_, _בשעת_, _vrni, tită,
   {{0xeaf20105,0x3f7a80be,0x3b000168,0xdcfc4f66}},	//   _अजीत_, _קאנס, _vdiq_, _smrč,
   {{0xc01c8104,0xdcfa8087,0x6443d0be,0x4427d0bf}},	//   _nước_, rită, _trni, _tpn_,
   {{0x10a63f4b,0x98a6245d,0x63a2b6f2,0x6443d0c0}},	//   тивн, тиве, yoon, _urni,
   {{0xd00f0b76,0x20050c4e,0x57be001b,0x20044a41}},	//   تلف_, ália_, ्देह, čmi_,
   {{0x7c24803b,0x6b8450c1,0xc01c8028,0x9663269c}},	// [3cc0] _ćiri, _imig, _bước_, акте,
   {{0x63a2c5ed,0x6d8b00eb,0x5bcaa0c0,0xc01c80ff}},	//   woon, kļau, िद्व, _cước_,
   {{0x63a2d0c2,0x6ea2146d,0x5f060a13,0x80c780ab}},	//   toon, _कुरु, _изна, রুত্,
   {{0x91e69a1f,0x395ebd7d,0x67d181a9,0x26cf80d7}},	//   воде, _sots_, _gāji, _nggo_,
   {{0x395e809f,0x63a2d0c3,0x2fc03f01,0x2564007b}},	//   _pots_, roon, mmig_, _sölu_,
   {{0xfce350c4,0x63a2d0c5,0x6609d0c6,0xc27b01c6}},	//   _воро, soon, drek, ורני,
   {{0x395e8722,0x63a2d0c7,0x6d4e50c8,0x6609d0c9}},	//   _vots_, poon, _inba, erek,
   {{0xf093078d,0x442a50ca,0x753c50cb,0x65b001ec}},	//   ינו_, _ipb_, _harz, zähl,
   {{0x395e8813,0x753c0f89,0x6609d0cc,0x443800ee}},	//   _tots_, _karz, grek, _hsr_,
   {{0x6b84436a,0xc01c8129,0xb5fd928a,0x26cf9407}},	//   _amig, _xước_, myšl, _eggo_,
   {{0x753c1d03,0x6ab2acfc,0x6609811e,0x2175d0cd}},	//   _marz, _जरुर, arek, _сутр,
   {{0x443831fc,0x23960029,0x66099e12,0x65b001ec}},	//   _msr_, tāja_, brek, wähl,
   {{0x51874ecc,0x80c780c8,0x2d8f0019,0xed5a8081}},	//   вува, রুদ্, égek_, _оод_,
   {{0x6b8450ce,0x753c009a,0x443808ae,0xaefb026b}},	//   _emig, _narz, _osr_, _alùp,
   {{0x97a70009,0x843880f7,0xa3b450cf,0xd7f8002e}},	//   врал, _أكبر_, _जीव_, кут_,
   {{0x6ab2901b,0x6d4e50d0,0x24b800ab,0x63660dfe}},	//   _जरूर, _anba, জশাহ, _bónu,
   {{0x27e9812b,0x68f88858,0x7c3a0b80,0xc7c80198}},	// [3cd0] ćani_, kavd, _štrp, тыре_,
   {{0x1c099a42,0x6935028e,0xdcb10129,0xf4d10264}},	//   _विमल_, _сноу, _ở_, ির্ব,
   {{0x9f5806a5,0xdce88110,0x7bcd0110,0x6acb83b6}},	//   guró_, sidė, _kiau, िश्र,
   {{0x6d4e50d1,0x201111b7,0x09cb816f,0x212580dd}},	//   _enba, muzi_, ाद्य, _sblh_,
   {{0x2011491f,0x3f894662,0x753c50d2,0xd83882d6}},	//   luzi_, miau_, _farz, _asč_,
   {{0x3f8950d3,0x7c388052,0xdb1cd0d4,0x6f02d0d5}},	//   liau_, _osvr, _zurü, _adoc,
   {{0xb8dbba68,0xc954010f,0x201121bb,0x2576006a}},	//   _घर_, ימס_, nuzi_, _sælg_,
   {{0xee399a1f,0x3f89031d,0x753c009a,0xb4c10105}},	//   ени_, niau_, _zarz, ुशी_,
   {{0xdb1c8e14,0x673d2727,0x09dd80ab,0x63a9d0d6}},	//   _euró, _masj, _ঠিকা, _iken,
   {{0x6609d0d7,0x6f02819d,0x7bd524d4,0x2576006a}},	//   rrek, _edoc, _kuzu, _vælg_,
   {{0x9f0591cc,0x78548416,0x7bd50c9e,0x63bb801c}},	//   _موضو, _نیوز_, _juzu, _khun,
   {{0x91e60d9e,0x7bd550d8,0x36d580a9,0x673d035f}},	//   ломе, _muzu, _содр, _nasj,
   {{0x7bcd00dd,0x660586c8,0x2ed900ab,0x3f890114}},	//   _diau, _спла, তরাষ, diau_,
   {{0x201102ec,0xbddb00e7,0x644702d0,0xe4e7804a}},	//   fuzi_, _crèm, _orji, _рідн,
   {{0x5f060698,0x2011114c,0x63a9d0d9,0x6aad14ee}},	//   лзва, guzi_, _oken, _eyaf,
   {{0x3f890a8e,0x63a9862b,0xe73750da,0x63bb801c}},	//   giau_, _nken, лес_, _nhun,
   {{0x6443013c,0x753c42ee,0x7e69a11a,0x200a0267}},	// [3ce0] ænin, _parz, nyep, srbi_,
   {{0x2018832b,0x61e40247,0x63a9d0db,0x491b00d4}},	//   _årig_, _itil, _aken, _बायो_,
   {{0x711b093f,0x63bb8c5e,0x3f8950dc,0x753c14af}},	//   _אויפ, _bhun, biau_, _varz,
   {{0x63bbd0dd,0x7bd50102,0x3f8950de,0xe29a81e2}},	//   _chun, _duzu, ciau_, нае_,
   {{0x25a5d0df,0xa68304cf,0x63bbd0e0,0x753c50e1}},	//   koll_, _гляд, _dhun, _tarz,
   {{0x64a650e2,0x63a98caa,0x673d02ce,0x7af650e3}},	//   _бага, _eken, _zasj, _leyt,
   {{0xebe320c2,0x629c8063,0x63a61142,0x68f887fd}},	//   _госп, _środ, kokn, ravd,
   {{0xb4c0000f,0x7c9300f7,0x61e450e4,0x7af650e3}},	//   ँधी_, _الفص, _otil, _neyt,
   {{0xa2cb88af,0x44440ecb,0xa5bb00f7,0xe297ca4e}},	//   _तृप्, lv_, _spói, _бат_,
   {{0x444401e9,0xa3d30063,0x71d78039,0x7bcd0110}},	//   ov_, _हूँ_, _עובד_, _siau,
   {{0x61e450e5,0x4ac70076,0x7c2902ee,0x6aad20d5}},	//   _atil, रेनव, _ćerk, _syaf,
   {{0x444450e6,0x7bc286c0,0xaca40133,0x63a980b9}},	//   iv_, nmou, _arịr, _xken,
   {{0xc3338051,0x388e8086,0x25a58106,0x69d60144}},	//   זור_, _hər_, boll_, _cuye,
   {{0x7bc2acbd,0x3f890114,0x518419bb,0x61e90162}},	//   hmou, wiau_, буса, ţelo,
   {{0x21310176,0x776282a3,0xa3d3009a,0x444450e7}},	//   rezh_, _koox, _हूं_, jv_,
   {{0x63a63437,0x201100b4,0x7bd5265a,0x61e450e8}},	//   cokn, ruzi_, _ruzu, _ftil,
   {{0x444401c5,0x8cf51628,0x3f8950e9,0xc9874543}},	// [3cf0] ev_, изац, riau_, _буни,
   {{0x63bbd0ea,0x63a9d0eb,0x3f8950ec,0x213ed0ed}},	//   _shun, _sken, siau_, _nath_,
   {{0x3d1c8441,0xe1ff0019,0xd6d100f7,0x3f891adf}},	//   _माने_, lsó_, _وقد_, piau_,
   {{0xb5190e18,0x2249013c,0x25b280d4,0x6d5850ee}},	//   न्जय_, _krak_, ुगुण, övar,
   {{0x444401e9,0xe9ff801c,0xe1ff50ef,0xfaa5acab}},	//   av_, _trận_, nsó_, јало,
   {{0x2249011f,0x3f86d0f0,0x213ea0ee,0xa593004e}},	//   _mrak_, _amou_, _cath_, _اگرچ,
   {{0x25a5bc87,0x213e8090,0x705281a8,0xe73991b1}},	//   voll_, _dath_, قنوا, вей_,
   {{0x63a9a049,0x163981a8,0x63bb9aca,0x6f658081}},	//   _uken, نسخة_, _uhun, рвиз,
   {{0x660d50f1,0x442150f2,0x7af61c08,0x213e8114}},	//   nrak, lth_, _reyt, _fath_,
   {{0x45859cf2,0x6b8bd0f3,0x27058028,0x79c88875}},	//   ргов, ligg, ồn_, _موقف_,
   {{0x61e42fac,0x47358dea,0x22490859,0xf1c8001b}},	//   _stil, _внес, _arak_, ntář_,
   {{0x442150f4,0x224930dd,0x1ee7803d,0x660d01a9}},	//   ith_, _brak_, _صوتی_, krak,
   {{0xeb970b33,0x25a5d0f5,0x27e9992c,0x7ae91f88}},	//   рия_, poll_, ćanu_, ñeta,
   {{0xa2c21a4d,0xa5098767,0xfce58eef,0x69c381a8}},	//   रेष्, _река_, _токо, nmne,
   {{0x69c3d0f6,0x9d1a807c,0x660d50f7,0x2c7b846d}},	//   imne, _יוסט, erak, _dádé_,
   {{0x4421360b,0x6840801b,0x69d600ff,0x22490197}},	//   dth_, ládá, _tuye, _frak_,
   {{0x442120af,0x444410af,0xa2c22e2e,0x7de50250}},	// [3d00] eth_, wv_, रेश्, مسلم,
   {{0xe57723e1,0xab5d81b9,0x79fb04de,0x444450f8}},	//   азу_, _miżu, _שליח, tv_,
   {{0x68fc50f9,0x44440069,0x2abb077f,0x2249393a}},	//   mard, uv_, _tàbí_, _zrak_,
   {{0x779411fb,0x68fc0459,0x444450fa,0x69c387d8}},	//   _ایرا, lard, rv_, emne,
   {{0x80ad80c8,0x2d87810c,0x69c382f7,0x1603001b}},	//   টেম্, _omne_, fmne, _लिएर_,
   {{0x99f580e8,0x291850fb,0x333f8036,0x213e808e}},	//   сяці, ngra_, _eaux_, _qath_,
   {{0xa967824b,0xd83a8087,0x333fcb4f,0x21678eef}},	//   рија_, тэл_, _faux_, рији_,
   {{0x68fc50fc,0xb9178135,0x93168180,0xab5d8035}},	//   hard, _kedụ_, _خورش, _biżu,
   {{0x68fc50fd,0xba29830f,0x27ed003b,0xae0c0540}},	//   kard, _مسلم_, ćeni_, िंटन_,
   {{0x68fc025b,0x656380a9,0x5d668c9d,0x2d8780ee}},	//   jard, _conh, ртиз, _cmne_,
   {{0x2cb88e23,0xe2f900e8,0x3cf80122,0x10a680e8}},	//   ård_, лені_, _merv_, _тижн,
   {{0x2d878bc5,0x80ad80ab,0x68f750fe,0xbb940198}},	//   _emne_, _চলচ্, _sexd, жающ,
   {{0x52141ff8,0x3636803d,0x68fc50ff,0x491b0074}},	//   одят, _خراس, fard, _बादो_,
   {{0xac1885e9,0x44215100,0x7c2e3f7d,0x68fc5101}},	//   _боку_, yth_, _opbr, gard,
   {{0x2bd04a2f,0xb4d2816f,0x657a80f7,0xb868024b}},	//   _संचा, वशी_, mhth, ајте_,
   {{0x2d8cd102,0x8b6700d5,0x291800f7,0x36d5292d}},	//   lide_, _خاتم, agra_, соар,
   {{0x7afd25ac,0x7bd880f2,0xdef80196,0x63ad5103}},	// [3d10] mast, _huvu, рыс_, _ikan,
   {{0x7afd5104,0x7bd8d105,0xdcf907bd,0x2d8cd106}},	//   last, _kuvu, افات_, nide_,
   {{0x65ab02af,0x9f35102a,0x63ad0365,0x95c82432}},	//   führ, _лені, _kkan, рута_,
   {{0x7afd5107,0x44212eff,0xe4578158,0xa3b4835f}},	//   nast, rth_, ייבט_, обхі,
   {{0x07560039,0x6b8bd108,0x7bd88009,0x2d8cd109}},	//   _הסרט_, rigg, _luvu, kide_,
   {{0x7afd2083,0x443c8082,0x463a0158,0xab5d84b7}},	//   hast, _osv_, _געשע, _riżu,
   {{0x6602d10a,0x63ad510b,0x333f80e7,0x7e6d489b}},	//   _avok, _okan, _taux_, lyap,
   {{0x65638073,0x09e680ab,0x7afd2421,0x69dc875f}},	//   _sonh, _নিরা, jast, _črev,
   {{0x7afd510c,0x9f5e510d,0x6b89d10e,0x2d8cd10f}},	//   dast, été_, _imeg, fide_,
   {{0x8d5585c2,0x2d8c8870,0x63ad5110,0x657ad111}},	//   стич, gide_, _akan, ghth,
   {{0xbb460009,0x64a5980f,0x6d41d112,0xcb6a38a6}},	//   бенк, сана, rdla, гане_,
   {{0x7afd0558,0x3d1c8424,0xe45600be,0x316581ec}},	//   gast, _माथे_, צירט_, _holz_,
   {{0x644a91f8,0x2d8c811e,0x139a80be,0x6b898135}},	//   _erfi, bide_, רברע, _mmeg,
   {{0x2d8cd113,0x63ad5114,0x3f8dd115,0x657ad116}},	//   cide_, _ekan, lieu_, chth,
   {{0x2b400046,0xe1f2003d,0x3d1c950e,0x660282d4}},	//   _taic_, _کسب_, _माते_, _zvok,
   {{0xea5a0fbb,0x316581de,0x68fc5117,0x43930992}},	//   _број_, _lolz_, sard, _најс,
   {{0x09e200ab,0x7ae45118,0xa3b4341c,0x6ea2001b}},	// [3d20] _বিকা, _ifit, _जीए_, _कुखु,
   {{0x6b9bd119,0x442ecb69,0x32023fdf,0x6b89b943}},	//   _ajug, _ypf_, msky_, _ameg,
   {{0xa5bb0207,0xd8d70158,0x0c260785,0xa06a01a1}},	//   _após, _לויט_, смен, _сана_,
   {{0xeafa8b53,0x8afd801b,0x798e02ec,0xdce381d0}},	//   ارات_, _pořa, libw, _plně,
   {{0x3202511a,0xa96a902f,0x6b9b8118,0x65ab01ec}},	//   nsky_, лида_, _djug, rühr,
   {{0x6b898135,0x2d8f0019,0x7c330e15,0x6b9b819d}},	//   _emeg, éget_, ñerí, _ejug,
   {{0x764b8114,0x7afd1a7b,0x2d8cd11b,0x6602b543}},	//   _argy, yast, vide_, _svok,
   {{0x442e8a5a,0x2d8cd11c,0x7bd88435,0xbddb09c4}},	//   _rpf_, wide_, _ruvu, _crèw,
   {{0x7afd10a6,0x2d8c8074,0x657ace71,0xda63a639}},	//   vast, tide_, thth, _евти,
   {{0x867b004c,0x7afd1a9c,0x716580f7,0x442ebd09}},	//   טרפו, wast, _والك, _ppf_,
   {{0xdeef814c,0x2d8cd11d,0x672082f1,0x6e2400b9}},	//   _ны_, ride_, _यापक_, htib,
   {{0x6e24511e,0x2d8cb00a,0x4c9b00be,0x3f8d823e}},	//   ktib, side_, רשטע, cieu_,
   {{0x2d8cd11f,0xe5a68e97,0x3d190327,0x256f02d0}},	//   pide_, _лиди, _पाले_, _yılı_,
   {{0x7bd8d120,0x7ae40789,0x7afd35b2,0x443cd121}},	//   _tuvu, _efit, sast, _tsv_,
   {{0x7dc901e2,0xe8140076,0x442e8980,0x38c30036}},	//   _užsi, तूला_, _upf_, déré_,
   {{0x2d8a5122,0x63ad0dc5,0x44ce8085,0x7e6d02d0}},	//   _ambe_, _ukan, mə_, tyap,
   {{0x320f0065,0x61f6031d,0x44ce8085,0x6e24076d}},	// [3d30] _így_, _gwyl, lə_, gtib,
   {{0x67d50110,0x7d1ad123,0x69dc8074,0x6b898084}},	//   _sąju, ngts, _पढ़ी, _smeg,
   {{0x44ce8086,0xe43503f8,0xa2cbbb82,0x7f440df6}},	//   nə_, تفاد, तेन्, bdiq,
   {{0x291ed124,0xdfc681a8,0xe3b902d0,0x8c1b9101}},	//   _acta_, _زي_, ktım_, רואי,
   {{0x27ed012b,0x38c35125,0x2d8f0019,0x2bb880f7}},	//   ćenu_, béré_, éges_, حالة_,
   {{0x6ea20f85,0x3cfe88ae,0x98be861c,0xbddb0036}},	//   _कुटु, jatv_, _altı_, _brèv,
   {{0x6d555126,0x29f6809a,0x212c82c4,0xdb060c83}},	//   _inza, ała_, _dbdh_, soké,
   {{0x44ce8201,0x798e0c56,0x06098951,0x6b89d127}},	//   də_, zibw, аник_, _umeg,
   {{0x63ab803b,0x332db673,0x96b985e9,0x200500ce}},	//   mogn, _ibex_, шуку_, šlih_,
   {{0x6d4503f8,0x7afb8352,0x63ab9137,0x3202136f}},	//   ndha, _heut, logn, vsky_,
   {{0x61e98d11,0x7afba0d5,0x69c1a4f4,0xbddb0036}},	//   _htel, _keut, _ihle, _grèv,
   {{0x7c255128,0x61f60114,0x6d5c8106,0x224d8176}},	//   ithr, _pwyl, örar, _krek_,
   {{0x3204003e,0x798e02ec,0xbb3a83de,0x7afbd129}},	//   émy_, tibw, בערי, _meut,
   {{0x7afb82af,0x32021f1c,0x6729822b,0x2effd12a}},	//   _leut, rsky_, lfej, lauf_,
   {{0x6d450428,0x7ae404b7,0x798e512b,0xafe302c0}},	//   ddha, _tfit, ribw, досл,
   {{0x6d43d12c,0x6f1b859c,0x6e24512d,0x46ea0c9b}},	//   _hana, nguc, ttib, рдан_,
   {{0x056623e1,0x61462a96,0x20d601e2,0x69c1d12e}},	// [3d40] ован, _депа, _мінс, _ohle,
   {{0x6d43d12f,0x6e245130,0xa5bb4084,0x3f8b026c}},	//   _jana, rtib, _spór, _emcu_,
   {{0x224dd131,0x3a3f810c,0x0b468a0e,0x7afbd132}},	//   _arek_, _asup_, жнен, _beut,
   {{0xab2a941e,0x6d43d133,0xfe678c3b,0x20185134}},	//   рода_, _lana, _قد_, muri_,
   {{0x20185135,0x7afbc9f6,0x7c250083,0x6d4501b4}},	//   luri_, _deut, athr, bdha,
   {{0x6d43d136,0x69c1d137,0x44ce8201,0xbddb009f}},	//   _nana, _chle, yə_, _prèv,
   {{0x657e0013,0x20185138,0x29f6809a,0x61e98009}},	//   mhph, nuri_, sła_, _etel,
   {{0x6d4382a3,0x69c7120e,0x44ce8201,0x3860826c}},	//   _aana, zmje, və_, ćir_,
   {{0x20185139,0x7bdc513a,0x6604513b,0x224d8168}},	//   huri_, _huru, nsik, _grek_,
   {{0x7bdc513c,0x2018513d,0x637f020f,0xa2a38bb8}},	//   _kuru, kuri_, _këng, _छुट्,
   {{0x6d438025,0x9cdb0158,0x7bdc513e,0x224039e3}},	//   _dana, יקיפ, _juru, _asik_,
   {{0xc5f980c8,0x2018513f,0x7bdc5140,0x883b8039}},	//   _আমরা_, duri_, _muru, _כתבו,
   {{0x6d43d141,0x7bdc0458,0x6d450079,0x4e969459}},	//   _fana, _luru, ydha, _بشار,
   {{0x6d43d142,0x7c255143,0x2735001c,0x20185144}},	//   _gana, ythr, _ấn_, furi_,
   {{0xf77312dc,0x20185145,0xe9ff801c,0x69c700f1}},	//   وار_, guri_, _trần_, rmje,
   {{0x69c71351,0x20030035,0xa5bb0032,0x3a2682df}},	//   smje, rsji_, _apóp, ktop_,
   {{0x6b8d5146,0x6d43be35,0x0ec501fe,0x66045147}},	// [3d50] _imag, _yana, लेंड, gsik,
   {{0x7bdc1caa,0x6d43d148,0x20185149,0x09e200ab}},	//   _buru, _xana, buri_, _বিচা,
   {{0x20180012,0x6d45514a,0x7afbd14b,0x63abd14c}},	//   curi_, rdha, _peut, togn,
   {{0x7bdc514d,0x23960029,0x7c25514e,0x224dd14f}},	//   _duru, tāji_, rthr, _prek_,
   {{0x644e5150,0x63abd151,0x69c1c158,0x65b02eac}},	//   _erbi, rogn, _phle, täht,
   {{0x63ab8098,0x7bdc5152,0xd24e9dd2,0x7c253aab}},	//   sogn, _furu, انو_, pthr,
   {{0x6d43d153,0xdcfc02a5,0xd0f8010f,0x637f00f1}},	//   _rana, _smrć, חמות_, _kënd,
   {{0x61e9a2e7,0x3a3f82c4,0x32191122,0x1606970c}},	//   _ttel, _tsup_, kusy_, _शिखर_,
   {{0x6d43d154,0x20185155,0x7bdc5156,0x2eff82af}},	//   _pana, zuri_, _zuru, rauf_,
   {{0x0d828e86,0x6b8d500f,0x76498364,0x2eff83ac}},	//   ельн, _amag, rvey, sauf_,
   {{0x6d43cca0,0x3d1c800f,0xc17281c6,0x20185157}},	//   _vana, _मारे_, _רחב_, xuri_,
   {{0x6d43aa30,0xeb9a1401,0x20185158,0xddcd0503}},	//   _wana, сим_, vuri_, jzaž,
   {{0x6d43d159,0x20184507,0xbebb00f1,0x34b803eb}},	//   _tana, wuri_, _mbës, _अर्द,
   {{0x2018515a,0xdce3a1f6,0x6b8d515b,0x6d4388ce}},	//   turi_, _konč, _emag, _uana,
   {{0xdfd200f7,0x3945d15c,0x645cb31b,0xaca401bc}},	//   فيس_, _mals_, ärit, _kpụr,
   {{0x660442e5,0x2018515d,0xab6600e8,0x32190690}},	//   tsik, ruri_, _хвил, busy_,
   {{0x644e0d11,0xfbd30051,0x2018515e,0x22400bb1}},	// [3d60] _srbi, _אתה_, suri_, _usik_,
   {{0xf1bf4084,0x2018515f,0x6b8d1840,0x7bdc5160}},	//   ltán_, puri_, _zmag, _puru,
   {{0x7bdc4511,0x65b001ec,0x7bd65161,0x6bd606e2}},	//   _quru, fähr, _kiyu, ستار,
   {{0x7bdc3895,0x8fa62702,0x7bd600fc,0x6282890d}},	//   _vuru, _хаме, _jiyu, tzoo,
   {{0x7d01d162,0x7bdc5163,0x7c3b0b67,0x7bd64aa0}},	//   kals, _wuru, _ćure, _miyu,
   {{0x7bdc1922,0x40348a7c,0x239600eb,0x7d01d164}},	//   _turu, декс, māju_, jals,
   {{0x072085e8,0x64a3219f,0x3a26d165,0xdca3321a}},	//   _यादव_, _зара, stop_, _зари,
   {{0x5ea580c8,0x23278abe,0xdce389d1,0x4c9b01c6}},	//   খেছে, _носи_, _donč, _הבלו,
   {{0xc6f787ac,0x6f008300,0x2cba826c,0x3945d166}},	//   чных_, ramc, _špd_, _fals_,
   {{0x6b8d5167,0x998680d5,0xc243a380,0x7bd60300}},	//   _smag, _علاو, _янук, _aiyu,
   {{0x7bd63ced,0xb60381a9,0xe6b92418,0x00000000}},	//   _biyu, ēšam, _आर्ज, --,
   {{0x7bc45168,0x18778039,0x7d018074,0xbebb0168}},	//   _chiu, _מעבר_, aals, _mbër,
   {{0x7d018029,0x637f020f,0x2aab1194,0x602a8085}},	//   bals, _rënd, стно_, _məmm,
   {{0x5e578051,0xd90f0416,0x82778158,0x7c3781df}},	//   _מידע_, دید_, לעכע_, ñarí,
   {{0x68fe11ee,0x2c82846d,0xdb1b80f7,0x6d58879a}},	//   _depd, _dédé_, _shuí, _inva,
   {{0x637f00f1,0xa8578039,0x6b8d5169,0x753a9919}},	//   _qënd, הילה_, _umag, letz,
   {{0x63af0f4c,0x9d5500d5,0x9f8a002a,0x2fc9067f}},	// [3d70] mocn, وچست, _añón_, rmag_,
   {{0x61ed516a,0xdb0bbad6,0x65b001ec,0x2fc9516b}},	//   _ital, mogé, währ, smag_,
   {{0x2903516c,0x6b9d0d35,0xbddb3643,0x637f0168}},	//   maja_, onsg, _près, _tënd,
   {{0xf99f516d,0x290caf6d,0x6b9d1897,0x3d1910f7}},	//   près_, _adda_, nnsg, _पाके_,
   {{0xd945ac60,0x2d998065,0xdce38353,0x6145932a}},	//   дели, ések_, _sonč, дела,
   {{0x99678009,0xbddb00e7,0xeab080f7,0xa2c200d4}},	//   ятел, _frèr, دعم_, रेट्,
   {{0x7d01d16e,0x753a8102,0x3945d16f,0x61ed0420}},	//   vals, detz, _vals_, _ltal,
   {{0x29035170,0x69d71d64,0x6d588247,0x290cd171}},	//   haja_, _lixe, _anva, _edda_,
   {{0x6d470d8b,0xa3d10105,0x3945d172,0x66158035}},	//   _kaja, वगन_, _tals_, ązko,
   {{0x6d4750a9,0x29035173,0x7bc45174,0xdce3aa06}},	//   _jaja, jaja_, _shiu, _tonč,
   {{0x6d475175,0x61ed5176,0x6fbf035a,0x03a625d9}},	//   _maja, _atal, ्षां, дино,
   {{0x6d58d177,0x6d470247,0x69d70722,0x61fb819d}},	//   _enva, _laja, _aixe, _kwul,
   {{0xa5098af2,0x753a8102,0x69d75178,0xf1bf3554}},	//   _дела_, betz, _bixe, rtán_,
   {{0x6d47003b,0xdb0b80f2,0x290329a8,0x69df01b4}},	//   _naja, llgä, gaja_, _duqe,
   {{0x2bd909a3,0x69d701df,0xdee60ba8,0x66e60847}},	//   _बंगा, _dixe, доби, доба,
   {{0xe29a239a,0x23960029,0x6443c38c,0x61fb9e8b}},	//   _май_, tāju_, _isni, _owul,
   {{0x6d470733,0x6e29d179,0x290301ca,0x75464aa5}},	// [3d80] _baja, nteb, baja_, мназ,
   {{0x7ae9d17a,0x29030025,0x6d47517b,0xf1e18816}},	//   _afet, caja_, _caja, _पढ़न,
   {{0x53e5035f,0x6d4704c4,0x395a047f,0x6ad6816f}},	//   еціа, _daja, _inps_, धश्र,
   {{0x661bd17c,0xeb979bc6,0x6443d17d,0x6e29d17e}},	//   kuuk, мих_, _msni, kteb,
   {{0x6f0401e4,0x6d488514,0x09e387c4,0x6286517f}},	//   maic, ydda, вочн, nzko,
   {{0xc6930158,0x6443803b,0x6d470397,0x7ae98073}},	//   _יאר_, _osni, _gaja, _efet,
   {{0x61fbd180,0x7ae9d181,0x6e29d182,0x443e0242}},	//   _ewul, _ffet, eteb, _èt_,
   {{0x6f040014,0x6d473888,0x8b958a18,0xdb1b8362}},	//   naic, _zaja, _зруч, _ghuà,
   {{0x753a8102,0x6e2985b1,0x6d47019e,0x66165183}},	//   tetz, gteb, _yaja, nryk,
   {{0x2366812b,0x62862201,0x6f0401e4,0x28a982a8}},	//   ljoj_, dzko, haic, _चुकि,
   {{0x29030796,0x6f0404b9,0x6d4893b0,0x753a8102}},	//   vaja_, kaic, rdda, retz,
   {{0x753a8352,0x23668052,0x93bd002e,0x69d70609}},	//   setz, njoj_, ptăm, _sixe,
   {{0x290314c7,0x61e0a659,0x69d75184,0xf8e28441}},	//   taja_, _juml, _pixe, _पलाय,
   {{0x66165185,0x6d58b408,0x61e0d186,0x2d9307b6}},	//   dryk, _unva, _muml, xixe_,
   {{0x6d475187,0x69d704c3,0xdb0b80f2,0x80d080ab}},	//   _raja, _vixe, llgå, _স্ত্,
   {{0x6d475188,0x316cd189,0x36d5518a,0x69dd8037}},	//   _saja, _lodz_, еобр, _èseg,
   {{0x6d47167a,0x61ed518b,0x672d518c,0x69d70118}},	// [3d90] _paja, _utal, rfaj, _tixe,
   {{0x2d9eb5a7,0x20050065,0x33248362,0xd5bb05a8}},	//   nnte_, ális_, _acmx_, іса_,
   {{0x6d47518d,0x2d9ed18e,0x5b159354,0x79953e9d}},	//   _vaja, inte_, емет, mizw,
   {{0x6d472727,0x79952767,0x6f04518f,0x2d9e8192}},	//   _waja, lizw, caic, hnte_,
   {{0x34bb8441,0x6d473d5d,0x6fc58388,0xa3c20c2d}},	//   _उर्द, _taja, nóce, ्गत_,
   {{0x34955190,0x6025a844,0xc10581a8,0x645a15d8}},	//   _загр, едка, روبي, _štie,
   {{0xa3af2177,0xb4bd98b8,0x7d0500dd,0x25a62218}},	//   कवा_, _आरे_, mahs, éole_,
   {{0x2d9eaf32,0x6e29afc7,0x661b8c56,0x2fc68706}},	//   ente_, tteb, tuuk, _chog_,
   {{0xee368b71,0xeab38872,0xf6519e09,0x9f510019}},	//   ены_, _شعر_, ائب_, lszó_,
   {{0x661bd191,0x316c809a,0xdb06016b,0x29014d81}},	//   ruuk, _godz_, doká, _neha_,
   {{0x6e29d192,0x5fdb03eb,0x3eb90aa2,0xf1bf05bf}},	//   steb, _मंगल, _lyst_, rtál_,
   {{0x2b490580,0xf1bf0f09,0x2fd90362,0x22521407}},	//   _caac_, stál_, _nisg_, _pryk_,
   {{0x55599e58,0x29014ec9,0x59c4864a,0x2b4902ed}},	//   _надя_, _beha_, _लीडर, _daac_,
   {{0x23960029,0x79955193,0x6609912e,0xdca585fa}},	//   tājs_, gizw, msek, _пали,
   {{0x2f5626c8,0xa0a30d46,0x62862dd7,0xa06a03bc}},	//   нтас, гард, szko, чава_,
   {{0x66160bc5,0x2252006a,0xdce700e1,0x613381cc}},	//   tryk, _tryk_, _dojč, lılı,
   {{0x6f040046,0x539b0051,0x63a45194,0xe61a5195}},	// [3da0] raic, _מיקו, _ijin, яда_,
   {{0x6f040046,0xbd4600f7,0x6133861c,0x66098198}},	//   saic, عناي, nılı, isek,
   {{0x6b829532,0x6f040c41,0x660980ee,0x61e0d196}},	//   thog, paic, hsek, _suml,
   {{0x237f802e,0xc0530039,0x637f00f1,0x25fb0424}},	//   _cluj_, _עזר_, _këna, _लौकी_,
   {{0x63a4022e,0x7d051f71,0x6b828fb0,0x69ce4e46}},	//   _mjin, bahs, rhog, ombe,
   {{0xe894976e,0x602a8201,0x26ddd197,0xe29f008b}},	//   каль, _həmi, _agwo_, naða_,
   {{0xc30b00c8,0xe5a305c2,0x69ce5198,0x2d9e83ba}},	//   ষ্টি_, _сири, imbe, vnte_,
   {{0x9634c2a1,0x189780f7,0x2fc681c0,0x63a45199}},	//   вниц, عضوة_, _qhog_, _njin,
   {{0x79950ab4,0x940a8085,0xe72f9f33,0x929d8035}},	//   yizw, əmək_, صصي_, _pełe,
   {{0x44380072,0x63a4519a,0xdb060c83,0x2d9e8037}},	//   _kpr_, _ajin, voká, unte_,
   {{0x98be8087,0xbddb0176,0x2cb8bea6,0x4438010c}},	//   _dată_, _asèl, ærd_, _jpr_,
   {{0x69da84a6,0x443801bf,0x1e868c9d,0x290100ee}},	//   _hite, _mpr_, _плем, _seha_,
   {{0x69dad19b,0xdb0f0e1b,0x29010748,0x2018011b}},	//   _kite, nocé, _peha_, erri_,
   {{0x613383bf,0x6f02d19c,0x6594a5f5,0x38c6826b}},	//   cılı, _heoc, _шалу, _gírí_,
   {{0x69dab5e7,0xd8380048,0x3ebf0503,0x79953294}},	//   _mite, нэт_, _šut_, rizw,
   {{0x6d4a831d,0x602a8201,0x63a400f1,0x6d5c519d}},	//   _hafa, _cəmi, _gjin, _anra,
   {{0x6d4ab640,0x29010006,0xc8f50098,0x4438519e}},	// [3db0] _kafa, _teha_, _изпъ, _apr_,
   {{0x6d4a930c,0x443800dd,0x69dad19f,0x656e0c41}},	//   _jafa, _bpr_, _nite, _cobh,
   {{0x6d4ad1a0,0x7d0551a1,0x628e00ce,0x764651a2}},	//   _mafa, rahs, ćnoš, _esky,
   {{0x3f670364,0x61338182,0x6d4ad1a3,0x443851a4}},	//   _чтоб, zılı, _lafa, _dpr_,
   {{0x69dad1a5,0x6133880a,0xaa458198,0x3ebf00e1}},	//   _bite, yılı, телл, _áut_,
   {{0x69dad1a6,0x6d4ab2bf,0x3d1c8d14,0x61338201}},	//   _cite, _nafa, _मागे_, xılı,
   {{0x69da8458,0xdb0b8c15,0x5ba785e9,0xead18264}},	//   _dite, logí, _зраз, াডেম,
   {{0x70de1a42,0x69dad1a7,0x7f4d1953,0x6609ca80}},	//   _मल्ल, _eite, ndaq, tsek,
   {{0x0ea9835f,0x6f02d1a8,0x613385c5,0x69dad1a9}},	//   ький_, _deoc, tılı, _fite,
   {{0x6609d1aa,0x7aed120f,0x63b626fa,0x6d4ad1ab}},	//   rsek, _afat, _skyn, _cafa,
   {{0x2907b281,0x64a58e0b,0x61338182,0xdca5ac60}},	//   mana_, тана, rılı, тани,
   {{0x2907d1ac,0xe29a0972,0x69dad1ad,0x91e60811}},	//   lana_, дам_, _zite, коме,
   {{0x69c88364,0x6d4ad1ae,0x61338457,0x4a430081}},	//   _yhde, _fafa, pılı, аняв,
   {{0x657ad1af,0x6d4ad1b0,0x2907cccd,0xc1740041}},	//   ckth, _gafa, nana_, _kuɗi_,
   {{0x20182833,0xbbe880f7,0x7aed0428,0x290797c9}},	//   urri_, _كريم_, _ffat, iana_,
   {{0x2907b2a8,0x6d4ad1b1,0x6d218105,0x7d03d1b2}},	//   hana_, _zafa, _माँग_, _hens,
   {{0x2907d1b3,0x7d038314,0x645500a4,0x443851b4}},	// [3dc0] kana_, _kens, _arzi, _spr_,
   {{0x2907d1b5,0x6455003a,0x7d03888a,0x2d85d1b6}},	//   jana_, _brzi, _jens, nhle_,
   {{0x7d03d1b7,0x2907ced3,0x69dad1b8,0x602a8201}},	//   _mens, dana_, _rite, _təmi,
   {{0x69dad1b9,0x7981831d,0x7bc981e4,0x59bc000d}},	//   _site, _allw, _cheu, ोगकर,
   {{0x6d21823c,0x61e403d3,0xdb158019,0x69dad1ba}},	//   _मांग_, _juil, óbál, _pite,
   {{0x644f8341,0x2abd0b4c,0x61e451bb,0x25fb00c2}},	//   ācij, lábú_, _muil, _लौटी_,
   {{0x69dad1bc,0x26c08110,0xeb9a95fe,0x7bc98014}},	//   _vite, _šio_, _жив_, _fheu,
   {{0x78ba8a56,0x672451bd,0xf1bf0019,0x69dad1be}},	//   _vytv, ngij, tták_, _wite,
   {{0x7d03d1bf,0x2907d1c0,0xe3b907d9,0x09e68a7f}},	//   _bens, bana_, ktır_, _розн,
   {{0x69da85f8,0x7aed002e,0x6d4ac636,0x444401b4}},	//   _uite, _sfat, _qafa, ow_,
   {{0x351b00be,0xfe6f815b,0x657a80f1,0xf4868729}},	//   ווינ, مدی_, rkth, тупн,
   {{0x63a2d1c1,0x6d4ad1c2,0x44440b99,0x61e424e3}},	//   nnon, _wafa, iw_, _buil,
   {{0x81be00c8,0x61e41536,0x6d4ad1c3,0x7d0381ec}},	//   েদন_, _cuil, _tafa, _fens,
   {{0xf2d3893f,0x657d80f1,0x61e40046,0x7d03a474}},	//   יער_, ësht, _duil, _gens,
   {{0xb33b0073,0x394c928d,0x6fc59727,0xf4849e5c}},	//   ança, _mads_, lóca, _حاشی,
   {{0x7d08d1c4,0x7aed51c5,0x61e40219,0x3dca05ee}},	//   lads, _ufat, _fuil, _ahbw_,
   {{0x6ed60076,0x2907d1c6,0x6e20badb,0xdfd80098}},	// [3dd0] _मृदु, yana_, numb, тър_,
   {{0x7d088448,0x2907d1c7,0x2713001c,0xbbcb800c}},	//   nads, xana_, ện_, िष्क,
   {{0x6e20b845,0x98ba01d0,0x83198061,0x9f41010c}},	//   humb, _mapě_, فقار_, _luhé_,
   {{0x29078ef9,0x6e20b15e,0x3d1c835a,0x2613816f}},	//   wana_, kumb, _माझे_, _दिली_,
   {{0x2907d1c8,0x6e20a4d4,0x471a0039,0xee870198}},	//   tana_, jumb, _אורג, _рыно,
   {{0x64473490,0x660d51c9,0x6e20d1ca,0x9aa481a8}},	//   _tsji, msak, dumb, جمهو,
   {{0x2907d1cb,0x7d03d1cc,0x01380039,0x7bc9d1cd}},	//   rana_, _rens, דרות_, _theu,
   {{0x2907cec5,0x2f548364,0x6e209d45,0x3ea0ab0d}},	//   sana_, атьс, fumb, _žita_,
   {{0x44211e92,0x2907b8d6,0x6e2088a7,0x645c9f48}},	//   luh_, pana_, gumb, årin,
   {{0x4d65d1ce,0x61e42dae,0x394c81a9,0x89348290}},	//   уков, _ruil, _gads_, _نعما,
   {{0x44210393,0x7d0381eb,0xa3c7800f,0x290580eb}},	//   nuh_, _vens, _उठा_, _iela_,
   {{0x290584b8,0x660d51cf,0x7d03d1d0,0x4fa480e8}},	//   _hela_, ksak, _wens, _києв,
   {{0x22490117,0x61e451d1,0x2d8b82be,0x2d8314f1}},	//   _csak_, _quil, èces_, _olje_,
   {{0x44210587,0x2905b8d6,0x660d51d2,0x61e41699}},	//   kuh_, _jela_, dsak, _vuil,
   {{0x6d41d1d3,0xa6db0125,0x2905d1d4,0x44210057}},	//   mela, _maðu, _mela_, juh_,
   {{0x6d41d1d5,0x61e40ad0,0x44210587,0x8a960077}},	//   lela, _tuil, duh_, _مشخص,
   {{0x6724044a,0x1fa747a6,0x660d2974,0x6b8451d6}},	// [3de0] rgij, укти_, gsak, _ilig,
   {{0x2905bf54,0x85064787,0x5bdc8ebf,0x76440db1}},	//   _nela_, اوان, यद्व, rwiy,
   {{0x44440586,0x44210812,0x290a51d7,0x660d10e1}},	//   uw_, guh_, maba_, asak,
   {{0xd9cc8576,0x290a253c,0x09e696be,0x501b0039}},	//   ाष्ट, laba_, годн, _אוטו,
   {{0x6d41d1d8,0x63a2d1d9,0x69de2660,0x2fc00f06}},	//   kela, rnon, _kipe, mlig_,
   {{0xfce30e86,0x44210812,0x2905d1da,0x661bc9f7}},	//   _горо, buh_, _cela_, druk,
   {{0x2905d1db,0x6d41d1dc,0x442100dd,0x290a51dd}},	//   _dela_, dela, cuh_, iaba_,
   {{0x6d4e51de,0xa3e7823c,0x2fc00f91,0xa8570039}},	//   _haba, _बढ़_, nlig_, ריקה_,
   {{0x6d4e51df,0x6d41d1e0,0x290a2246,0x7d088b81}},	//   _kaba, fela, kaba_, tads,
   {{0x6b8451e1,0x01d79a05,0x6d4e0b50,0x26190105}},	//   _alig, _موقع_, _jaba, यूटी_,
   {{0x6d4e51e2,0x290a51e3,0x6e2093b2,0xc445803d}},	//   _maba, daba_, sumb, لیون_,
   {{0x6d4e3809,0x7d0882ee,0x661bd1e4,0x2fc014a2}},	//   _laba, sads, bruk, jlig_,
   {{0x6d41b86a,0x2fc01eb4,0x6b8401e4,0x2905cb47}},	//   bela, dlig_, _dlig, _yela_,
   {{0x29050307,0x6b8451e5,0x69de003a,0x22491e29}},	//   úla_, _elig, _cipe, _vsak_,
   {{0x69de0458,0x4cd280ab,0x97a72345,0x645a0115}},	//   _dipe, _দ্রু, грал, _štin,
   {{0x2fc00f06,0x6f06008e,0x6b8401f4,0x5f9436ac}},	//   glig_, _cekc, _glig, бист,
   {{0xdb0f3b65,0x6458826c,0x4421003d,0x98a503bf}},	// [3df0] nocí, _hrvi, wuh_, ılı_,
   {{0x290a0207,0x6d4e23e3,0x4421059c,0x313551e6}},	//   caba_, _caba, tuh_, _теор,
   {{0x6add8e18,0x6d4e51e7,0x2905810b,0x7bcd01c5}},	//   यश्र, _daba, _rela_, _khau,
   {{0x4421059c,0x6d41d1e8,0x64588668,0x8f470cf9}},	//   ruh_, zela, _mrvi, _сход,
   {{0x290580a9,0x44211e92,0x7bdf009f,0x6d418234}},	//   _pela_, suh_, _miqu, yela,
   {{0x6d4e51e9,0x2d8300ce,0x6d418ece,0x442151ea}},	//   _gaba, _ulje_, xela, puh_,
   {{0x6602990b,0xddcb8110,0x2905d1eb,0xa3e48740}},	//   _awok, žiūr, _vela_, _भूल_,
   {{0x6d4e51ec,0xee39838d,0x291b8201,0x290a51ed}},	//   _zaba, вни_, şqa_, zaba_,
   {{0x6d41b2bb,0x6d4e51ee,0x2905d1ef,0x6458d1f0}},	//   tela, _yaba, _tela_, _arvi,
   {{0x6d4e51f1,0x290a51f2,0x80bb016f,0x6b9651f3}},	//   _xaba, xaba_, _शुभे, _smyg,
   {{0x30a788cc,0x69de51f4,0x63a9835f,0x7bdf0187}},	//   _срав, _ripe, _kjen, _biqu,
   {{0xe72e99b9,0x7bcd03d3,0x6d41d1f5,0xeb9a1935}},	//   _ќе_, _chau, sela, тим_,
   {{0x63a9d1f6,0x2fc00e23,0x7bcd51f7,0x7bdf0333}},	//   _mjen, vlig_, _dhau, _diqu,
   {{0x6f063931,0x7d07000d,0x7bdf03a8,0x63a98140}},	//   _sekc, _nejs, _eiqu, _ljen,
   {{0x63bbd1f8,0x7bdf51f9,0x9c13819d,0x2fc051fa}},	//   _okun, _fiqu, _kọmu, tlig_,
   {{0x6d4e51fb,0x63a9d1fc,0x290a0c6f,0x63bbd1fd}},	//   _saba, _njen, saba_, _nkun,
   {{0x7ae40578,0x2fc00f91,0x290a51fe,0xaa460b88}},	// [3e00] _igit, rlig_, paba_, _тепл,
   {{0x6d4e3a33,0x63a9add5,0x929d809a,0x63bb86a0}},	//   _qaba, _ajen, _pełn, _akun,
   {{0x2d9a51ff,0x6d4e0006,0x7d075200,0x2fc05201}},	//   ripe_, _vaba, _dejs, plig_,
   {{0xfbc39056,0x6d4e2cf2,0x63a982ce,0x2d9a0247}},	//   обхо, _waba, _cjen, sipe_,
   {{0x7ae4803e,0x7d070067,0x2d9a5202,0x425481a8}},	//   žito, _fejs, pipe_, إنتر,
   {{0x63a9813c,0x2d9a00f1,0x93bd0087,0x799c020c}},	//   _ejen, qipe_, ntăr, nirw,
   {{0x64a30084,0x50668071,0xdc670071,0x76598114}},	//   _дара, ртла, _кард_, _arwy,
   {{0x63a9d203,0x7ae45204,0x799c00b4,0x394301a9}},	//   _gjen, _ngit, hirw, zejs_,
   {{0xd0fb1513,0x7bcd022c,0x799c020c,0xe9da87b6}},	//   ्रमण_, _rhau, kirw, _ака_,
   {{0x7bdf5205,0x7bcd5206,0x76598114,0x637f0168}},	//   _siqu, _shau, _drwy, _gënj,
   {{0xdeef96fe,0xfe1887e6,0x2ec30770,0x409680d6}},	//   _мы_, _दिवस_, _शर्त, _трат,
   {{0x7bcd022c,0x63a981b9,0x645882d4,0x06ea8a27}},	//   _qhau, _xjen, _vrvi, _ऑलिव_,
   {{0xc3338039,0x7bdf009f,0x7762d207,0x7985022c}},	//   חור_, _viqu, _inox, _plhw,
   {{0x7ae400ad,0x799c020c,0x3f891670,0x7bdf0580}},	//   _egit, girw, whau_, _wiqu,
   {{0x7d075208,0x7bcd10af,0x3f890355,0x7bdf26f6}},	//   _rejs, _thau, thau_, _tiqu,
   {{0x386d28d2,0xb8cf00c2,0x04db81c6,0x93bd0493}},	//   ćer_, _कश_, _בקול, drăg,
   {{0x6b8704c0,0x3f890114,0xfaff0168,0x799c2c1d}},	// [3e10] _مشکل, rhau_, mbë_, birw,
   {{0x63a9811f,0x6b9d033e,0x7bc283a8,0x78ad87c0}},	//   _sjen, lisg, elou, şavi,
   {{0x70550c48,0x63a98668,0xaab802e3,0x637f0168}},	//   _انجا, _pjen, _مدیر_, _nënk,
   {{0x2d9802d0,0x6b9d5209,0x6e24383e,0xdce380c3}},	//   _emre_, nisg, buib, _tonć,
   {{0x63a9a217,0x6f0d0079,0x4ec180ab,0x7f3a00be}},	//   _vjen, maac, _উল্ল, _גערו,
   {{0x5d850250,0x7762b8f8,0x3f868580,0x6b9d0bb1}},	//   _السل, _anox, _alou_, hisg,
   {{0x63a98a38,0x3f86867f,0x7bc2d20a,0xb4c28778}},	//   _tjen, _blou_, blou, ्धो_,
   {{0x6d452c30,0x7bc2d20b,0x63bba73c,0x63a9d20c}},	//   leha, clou, _ukun, _ujen,
   {{0x799c00b4,0x332d816a,0x3f9900c3,0xf1bf0061}},	//   yirw, _icex_, _mmsu_, ntás_,
   {{0x51748013,0x41749ecd,0x27178028,0x6d45520d}},	//   _والأ, _والس, ển_, neha,
   {{0x61f6520e,0x3b0a140b,0x61e98020,0xe7c703eb}},	//   _styl, лено_, _huel, लताप,
   {{0x61e98010,0x80d080ab,0x3fc9803d,0x03a60a0e}},	//   _kuel, _স্ক্, _صدای_, симо,
   {{0xeb972092,0xf668803d,0x61e1d20f,0x799c0f8e}},	//   сия_, _نحوه_, _kill, tirw,
   {{0x645a1123,0x61e9d210,0x61e1d211,0x9f580388}},	//   _štim, _muel, _jill, mpré_,
   {{0x63b98d38,0xdca2867c,0x61e1938e,0x64a2b6de}},	//   kown, _наши, _mill, _наша,
   {{0x4425d212,0x61e19da3,0x93bd0087,0x799c260d}},	//   mul_, _lill, stăr, sirw,
   {{0x44258c6e,0x0d86196f,0x63b9d213,0x06ca01e5}},	// [3e20] lul_, блан, down, угай_,
   {{0xd9100416,0x6d45105d,0xbddb0032,0x4425d214}},	//   _زیر_, geha, _apèb, oul_,
   {{0x4425d215,0x98a78084,0xdb0f1727,0x224d8176}},	//   nul_, menė_, locá, _asek_,
   {{0x61e1d216,0x6f0d02ed,0xf1bf5217,0x61e9811b}},	//   _aill, caac, stát_, _buel,
   {{0x44258006,0x61e1d218,0x61e98e1b,0x20058609}},	//   hul_, _bill, _cuel, _awli_,
   {{0x61e980ad,0x4425ce52,0x61e19581,0x76498079}},	//   _duel, kul_, _cill, dwey,
   {{0x6c860013,0x61e1d219,0x01338013,0x4425a449}},	//   _الأم, _dill, سعود, jul_,
   {{0xf1bf01ac,0x63b9809a,0x644e0079,0x645c424d}},	//   ntár_, cown, _isbi, _irri,
   {{0x61e1cc7d,0x35f7803d,0xb4c286ab,0x7c3b00fe}},	//   _fill, یرید_, ्ध्_, _ćuri,
   {{0x61e1d21a,0x4425b4c5,0x61ef80e7,0x644e026c}},	//   _gill, ful_, _écla, _ksbi,
   {{0xb5fb0510,0x4425d21b,0x22400077,0x61e98102}},	//   _gráf, gul_, _apik_, _zuel,
   {{0x29c98511,0xe29f007b,0x290ed21c,0x60db80be}},	//   núan_, laði_, lafa_, _עקאנ,
   {{0x61e1d21d,0x6b9d051e,0xfaff03ed,0x6d45521e}},	//   _yill, risg, rbë_, yeha,
   {{0x4425d21f,0x645c011e,0x61e18079,0x644e08ae}},	//   bul_, _orri, _xill, _osbi,
   {{0x65750a56,0x44258012,0x6f0d328e,0x644e0267}},	//   _rozh, cul_, taac, _nsbi,
   {{0x2d9ed220,0x53a40251,0x27e200fc,0x290ed221}},	//   lite_, _најб, _cikn_, hafa_,
   {{0x645c5222,0x55751677,0x6d455223,0x6f0d01b4}},	// [3e30] _arri, огат, teha, raac,
   {{0xae1e009a,0xf1bf0e06,0x2d8700e1,0x994d0084}},	//   यंजन_, rtás_, óne_, ržų_,
   {{0x6d455224,0x61e985b4,0x58d5059d,0xe29f01fa}},	//   reha, _suel, _фонт, daði_,
   {{0x61e1c712,0x2d9ed225,0x6d451ade,0x53c917a3}},	//   _sill, hite_, seha, रतिश,
   {{0x2d9e8a8e,0x4425d226,0x2bb18063,0x764982a3}},	//   kite_, zul_, jące_, xwey,
   {{0x61e99099,0x61e19ac7,0x2d9e8805,0x4425c068}},	//   _vuel, _qill, jite_, yul_,
   {{0x39530101,0x4425b0f2,0x7dc69434,0x69dd81e8}},	//   _maxs_, xul_, rðsl, _èsem,
   {{0xe6199b8b,0x533493b4,0x4425d227,0x63ad2869}},	//   ади_, _нест, vul_, _njan,
   {{0x61e1d228,0x2d9e8578,0x69c380e1,0x44259ce9}},	//   _till, fite_, plne, wul_,
   {{0x4425d229,0x2d9e80a9,0x161e000f,0xb5fb0510}},	//   tul_, gite_, यूटर_, _tráf,
   {{0x5baa168a,0x61fd21c2,0x92e500ab,0xb5fb522a}},	//   иком_, epsl, _পড়ে_, _frág,
   {{0x44258c6e,0x3c31826f,0x394788f8,0xc169007c}},	//   rul_, ráv_, lens_, _בח_,
   {{0x4425ccc1,0x2d9ed22b,0x63ad522c,0x0cc645d2}},	//   sul_, bite_, _djan, _वर्म,
   {{0x6b89c6d9,0x4425d22d,0x39478082,0x80d080ab}},	//   _lleg, pul_, nens_, _স্ট্,
   {{0x765d00f1,0x6b9b82ec,0xaf9a1aed,0x6b89d22e}},	//   _arsy, _omug, атах_, _oleg,
   {{0x82a600e8,0x290e8242,0x6b898133,0xfbc30081}},	//   _майж, zafa_, _nleg, _общо,
   {{0x1dc501fe,0xb6a62c18,0x7ae4826f,0x2240008e}},	// [3e40] वतंत, циал, žitk, _upik_,
   {{0x6b89d22f,0x6b9ba13a,0x644e0267,0x26c20084}},	//   _aleg, _amug, _psbi, _vyko_,
   {{0x3947990e,0x66e6218a,0x2db680be,0x29c98511}},	//   dens_, _мона, קלען_, túan_,
   {{0x3947913b,0x89360019,0xd62a0eef,0xdce18ec3}},	//   eens_, _اٹھا, _коме_, eklī,
   {{0x290ec593,0x28f8854c,0x3947d230,0x5f0301e2}},	//   tafa_, бель_, fens_, _ізра,
   {{0x3947d231,0x753c003b,0xd01a95b7,0x201a841c}},	//   gens_, _ubrz, афи_, ápio_,
   {{0xcc2480ab,0x645c0102,0xda0b8105,0xe29f008b}},	//   _বন্ধ_, _urri, सीबत_, raði_,
   {{0x2d9ed232,0xfc4683fb,0x93fb02f6,0x290ed233}},	//   wite_, šíku_, _כללי, safa_,
   {{0xe29a80a9,0x7d188216,0x21a682bc,0xdcfa81d0}},	//   _таа_, _pdvs, _диам, chtě,
   {{0x3947d234,0x66090214,0x63ad004a,0x2bb1866f}},	//   cens_, _çeke, _sjan, rące_,
   {{0xa3e4800f,0x63ad5235,0x7d0a807b,0x290c80b9}},	//   _भूख_, _pjan, _vefs, _ieda_,
   {{0x3f8dd236,0x78ad84e8,0x291a0db1,0xf746ac65}},	//   cheu_, ťový, _adpa_, _федо,
   {{0x7fd78159,0x7d0ab865,0xcb138039,0x753d8019}},	//   _וואס_, _tefs, ולר_, ősza,
   {{0x290cd237,0x27fa00dd,0x15f1064a,0xad9b026b}},	//   _jeda_, _btpn_, _अंबर_, _ewúj,
   {{0x6d48829e,0xdfd50198,0xcf9b04ae,0x69d8a06b}},	//   meda, зовы, аја_, imve,
   {{0x491703bb,0x290cd238,0x7c2881bf,0x442105b9}},	//   _भएको_, _leda_, mudr, vrh_,
   {{0x3f848b99,0x394780e7,0x645a81a3,0xd6db0956}},	// [3e50] ikmu_, yens_, lvti, ртв_,
   {{0x63bd0052,0x6d48d239,0x6b89d23a,0x32090901}},	//   losn, neda, _sleg, _iway_,
   {{0x3947d23b,0x6b89d23c,0x29111ad6,0xd5b8102a}},	//   vens_, _pleg, maza_, ісу_,
   {{0x61ed0590,0x291100fa,0x69c7523d,0x6d488074}},	//   _kual, laza_, llje, heda,
   {{0x290cd23e,0x6d48d23f,0x61ed0057,0x645e8988}},	//   _beda_, keda, _jual, _špil,
   {{0x6d488025,0x88df00c8,0x29110ca3,0xaca3019d}},	//   jeda, _ব্যক, naza_, _apục,
   {{0x764285b4,0x290cd240,0x3947920b,0x764d0234}},	//   _apoy, _deda_, rens_, lway,
   {{0x6b9b8578,0x6d555241,0x39479da3,0x29113219}},	//   _umug, _haza, sens_, haza_,
   {{0x6d555242,0x29115243,0x3947800b,0xd7068009}},	//   _kaza, kaza_, pens_, чные_,
   {{0x61fb9904,0x69c70499,0xb998a252,0x9f420168}},	//   _itul, jlje, _двух_, _pikë_,
   {{0x6d555244,0x1b0e80ab,0x3209282f,0x29110300}},	//   _maza, _হাতে_, _away_, daza_,
   {{0x61ed0c41,0x320902d6,0x29110087,0x09b4064a}},	//   _bual, _bway_, eaza_, ंक्य,
   {{0x61ed5245,0xed598767,0x69c180b9,0x69c7026c}},	//   _cual, _гол_, _kkle, flje,
   {{0x6d555246,0x61ed5247,0x6e298264,0x29112999}},	//   _naza, _dual, mueb, gaza_,
   {{0x61e50609,0x32091029,0x7ae982f9,0xfaff03ed}},	//   _dihl, _eway_, _oget, gjës_,
   {{0x7ae9b2af,0x7ae481ac,0x09a8a123,0x61fba54d}},	//   _nget, žiti, _औद्य, _otul,
   {{0x69c70ee1,0x6fc58073,0x61ed5248,0x29111eda}},	// [3e60] blje, góci, _gual, baza_,
   {{0x2a605249,0x6d55524a,0x637f0168,0x69c7026c}},	//   _irib_, _caza, _dënu, clje,
   {{0x981607bd,0x61fbb4f9,0x644380b9,0x6d55524b}},	//   _عبدا, _atul, _jpni, _daza,
   {{0x261c823c,0x290c8665,0x225f821e,0x764d0365}},	//   _मिली_, _seda_, _bruk_, bway,
   {{0x6f043c4f,0x1154b2de,0x6d4881f8,0x3b0d81b4}},	//   mbic, дклю, yeda, _deeq_,
   {{0x225f8b3c,0x6443d24c,0x6d5520a8,0xb5fb007b}},	//   _druk_, _opni, _gaza, _fráb,
   {{0x8c43524d,0x6d48d24e,0xd90d8077,0xf7729ec9}},	//   _пере, veda, شین_, فاظ_,
   {{0x69c1d24f,0x6d555250,0x29110314,0x7c288687}},	//   _ekle, _zaza, zaza_, vudr,
   {{0x6d554851,0x290cd251,0x6d48d252,0x6578822c}},	//   _yaza, _teda_, teda, _povh,
   {{0x63a2d253,0x61eb00e7,0x290c89c4,0xb33b041c}},	//   lion, _égli, _ueda_, diça,
   {{0xfe6f8bca,0x61ed5254,0xdb06026f,0xab5b02d0}},	//   ندی_, _sual, soký, slüm,
   {{0x63a2d255,0x2911322c,0x764d5256,0x637f00f1}},	//   nion, waza_, yway, _nënt,
   {{0x61ed2b2d,0x63bd5257,0x6d48a8c5,0x6282c7d9}},	//   _qual, rosn, peda, nyoo,
   {{0x63a2d258,0xbddb2321,0x2a600176,0x26c6d259}},	//   hion, _apèn, _drib_, _iyoo_,
   {{0x2911525a,0x6d55525b,0x63a2d25c,0x27e68176}},	//   raza_, _raza, kion, _kion_,
   {{0x69c7243e,0x15f1023c,0x764d525d,0xf7730f24}},	//   slje, _अंदर_, tway, راز_,
   {{0x63a282f7,0x6d55525e,0x2911525f,0x672d04b9}},	// [3e70] dion, _paza, paza_, rgaj,
   {{0x6d550201,0x7d1c0267,0xb5fb016a,0x26c701a9}},	//   _qaza, _cdrs, _arác, āno_,
   {{0x6b8d01eb,0x645e8024,0x80c280ab,0x61fbd260}},	//   _klag, _špij, ষেত্, _stul,
   {{0x69c1d261,0x6d552de9,0xf65f006a,0x6e24117d}},	//   _skle, _waza, _træ_, brib,
   {{0x6e245262,0x6d5520c5,0x26c681c0,0x2fc903fc}},	//   crib, _taza, _nyoo_, mlag_,
   {{0xd90f8117,0x2fc95263,0x6b8d023e,0xbd4501a8}},	//   ایا_, llag_, _llag, _تنسي,
   {{0x23690025,0x63a2809a,0x645a0042,0x6b8d5264}},	//   _onaj_, bion, _štiv, _olag,
   {{0x225fd265,0x7e64811f,0x6b8d01bc,0x69c18035}},	//   _truk_, _šipa, _nlag, _wkle,
   {{0xe3b0819f,0x6f0f379d,0x645cb3b7,0x673b9320}},	//   _صرف_, _mecc, ærin, rfuj,
   {{0x6b8d5266,0x6f0f12d0,0x6e2985a4,0x2fc901ec}},	//   _alag, _lecc, rueb, hlag_,
   {{0x637f0168,0x27e69009,0x1b4a091e,0x753d8061}},	//   _nëns, _fion_, озни_, őszo,
   {{0xfaa601e5,0x6b8d0362,0x15ed064a,0x7bda80e5}},	//   дамо, _clag, जदार_, _ètut,
   {{0x6e29907c,0x7ae482d4,0xe2972b97,0x6e24029a}},	//   queb, žitv, дая_, xrib,
   {{0x63a2d267,0x6f1d3722,0xb33b03a7,0x27e68102}},	//   zion, _adsc, riça, _zion_,
   {{0x50b51b56,0x6f0f5268,0x14d19130,0x91e31c56}},	//   есту, _becc, _हरिण, торе,
   {{0x63a2a0e6,0x201e0289,0x6f0f2ed2,0x2905008b}},	//   xion, štio_, _cecc, ðlar_,
   {{0x6f045269,0x26c681e9,0x2a60010c,0x7bc42b8c}},	// [3e80] rbic, _xyoo_, _urib_, _ikiu,
   {{0x236902a5,0x6f04526a,0x63a2809a,0x6282804f}},	//   _znaj_, sbic, wion, vyoo,
   {{0x63a286f3,0xb5fb016b,0x5f06069b,0x2fc9526b}},	//   tion, _prác, _озна, blag_,
   {{0x6e24526c,0x7d0e341b,0x27f70efc,0x7d0501a8}},	//   prib, _webs, žené_, abhs,
   {{0xd0418085,0xb5fb01d0,0x25be8216,0x6fc5841c}},	//   _izlə, _vrác, yotl_, nócu,
   {{0x2fc000f7,0x6f0f01e8,0x14b70072,0x6d48016b}},	//   loig_, _zecc, _अडचण, ímač,
   {{0x03a689b8,0xb5fb526d,0xa3c3073c,0xa2a51370}},	//   _живо, _trác, ्तम_, _चेन्,
   {{0x97a38d15,0xab5b1238,0x2269928a,0x44259502}},	//   крыл, rlük, átký_, drl_,
   {{0x7ae9025b,0x03a38087,0x91a6819d,0x6b8d0362}},	//   žetk, _рито, gwọ_, _rlag,
   {{0x6b8d48bd,0xe16695a9,0x7bc40c53,0xe123997d}},	//   _slag, _تدري, _akiu, _амфи,
   {{0x6b8d526e,0xe046804a,0x291e9ec7,0x308687c3}},	//   _plag, _інди, _idta_, _تلاف,
   {{0x0a6b066a,0xa3c0ba68,0xdcf504e8,0x76460123}},	//   орги_, ुति_, _rozč, _opky,
   {{0xfe7281bd,0x61e8977c,0xed5a8e8e,0x6b8d0805}},	//   _جدا_, _kidl, _мод_, _vlag,
   {{0x6f0f1883,0x7dcf8aa2,0x02a30135,0x7bc405ee}},	//   _secc, løsn, _nrụọ, _ekiu,
   {{0x61e8ca20,0x6f0f526f,0x656a80f7,0xdc3e8ec3}},	//   _midl, _pecc, _infh, rģēt,
   {{0x7e6292f1,0x6d58d270,0x6b8d003a,0x442cd271}},	//   _krop, _hava, _ulag, mud_,
   {{0x442cd272,0x6d58d273,0x4ad30076,0x2fc904fe}},	// [3e90] lud_, _kava, _सरिव, rlag_,
   {{0x2fc9190e,0xca48003d,0x6d5ad274,0x36d40087}},	//   slag_, _کلیه_, ndta, тоур,
   {{0x442cd275,0x2fc95276,0x6d58804f,0x3c388061}},	//   nud_, plag_, _mava, név_,
   {{0xad9b0dfa,0x61e88362,0x61fb0162,0x291e8e06}},	//   _stúd, _aidl, ţulu, _adta_,
   {{0x657c005f,0x645a003a,0x61e881b9,0xa2a5239d}},	//   _forh, _štit, _bidl, _चेम्,
   {{0x442cd277,0x6d5887dd,0x7dd00106,0xdb1d0106}},	//   kud_, _nava, läsn, llsä,
   {{0xb8f79344,0x442cb745,0x61e88915,0x7e628091}},	//   _सर_, jud_, _didl, _arop,
   {{0x7aed5278,0xa4d4035f,0x442cd279,0xa2f90540}},	//   _ngat, _росі, dud_, ंडोज_,
   {{0x6d58d27a,0xe4e30b75,0x6e2d016a,0xaad3cb7c}},	//   _bava, _कृति_, nuab, _तरिक,
   {{0x6d58d27b,0x7aed527c,0x777d0282,0xc8fb064a}},	//   _cava, _agat, _losx, ्रोम_,
   {{0x6d58d27d,0x44258362,0x442cd27e,0x2907807a}},	//   _dava, url_, gud_, mbna_,
   {{0x69c53b9c,0x2d8ed27f,0x64470197,0x7853829a}},	//   _akhe, _elfe_, _mpji, _nəvə,
   {{0xbe878b76,0x6d5880e5,0x7e62d280,0x776b8234}},	//   _تجاو, _fava, _grop, _ingx,
   {{0x442ca0e5,0x6d58d281,0x201e025b,0x442582d4}},	//   bud_, _gava, štim_, prl_,
   {{0x1beb09a3,0x25a580f5,0x18674898,0xa0670eef}},	//   _जंगल_, mill_, нари_, нара_,
   {{0x6d58984c,0x3f890867,0x9f468081,0x7bc4004f}},	//   _zava, gkau_, _cioè_, _ukiu,
   {{0xcf9280be,0x6e3bd282,0x63a609da,0x6d58d283}},	// [3ea0] אטן_, ntub, mikn, _yava,
   {{0x63a634a0,0x25a5d284,0x090629e4,0x7dc6053d}},	//   likn, nill_, _япон, رقان,
   {{0x03269dbc,0x657c02af,0x399b00be,0x61e8839c}},	//   еден, _vorh, _זייד, _ridl,
   {{0xb5fb0019,0x61e8d285,0x63a6026f,0x6e3b8a32}},	//   _irán, _sidl, nikn, ktub,
   {{0x6f630364,0x25a5807b,0x71a68e11,0xf1bf0511}},	//   _связ, kill_, надз, irán_,
   {{0x64a6232d,0xdca61507,0xf1bf00f7,0x442cd286}},	//   _зага, _заги, hrán_, yud_,
   {{0xb0da92c6,0x442c8085,0x63a65287,0xfdbe0035}},	//   येंग, xud_, kikn, ्तीफ,
   {{0xdb1d02be,0x395a0074,0x9fb8016b,0x6d58d288}},	//   posé, _laps_, _očí_, _sava,
   {{0x6d58d289,0x61e886be,0xf1bf05a4,0x569481e5}},	//   _pava, _tidl, drán_, тапт,
   {{0x442c8778,0x40968fbb,0x721b84de,0x628621f3}},	//   tud_, _прет, _מומח, dyko,
   {{0x46ea80a9,0x6fc58e15,0xf1bf0333,0x63a6528a}},	//   _еден_, tóct, frán_, fikn,
   {{0x442c99fa,0xaca4019d,0xf1bf528b,0x63a600ee}},	//   rud_, _apịr, grán_, gikn,
   {{0x6d58a03f,0x7e62d28c,0x32191d88,0x442cd28d}},	//   _tava, _urop, ussy_, sud_,
   {{0xf2d3893f,0xa02482af,0xdee38012,0x442cd28e}},	//   טער_, _größ, _сочи, pud_,
   {{0xda1d05b3,0xc4f7893f,0x8d5b8039,0xf1bf016a}},	//   _भटकत_, _אזוי_, _זכוי, brán_,
   {{0x0aeb0f99,0x7aed528f,0x6e2d5290,0x317e8c00}},	//   _عربي_, _ugat, tuab, _lotz_,
   {{0x28a7881f,0x66041400,0x9f4680e5,0x8aa40a41}},	// [3eb0] _केनि, gpik, _cioé_, _брэд,
   {{0x2249003a,0xb5fb5291,0x3f895192,0x64550061}},	//   _ipak_, _frán, skau_, _pszi,
   {{0x6f1602bf,0xdcf8803a,0x26e200c8,0x645a0353}},	//   bayc, _novč, গুলো_, _štir,
   {{0xa3c3123a,0xae218592,0x28c4809a,0x20010234}},	//   ्ति_, _मिलन_, _लुधि, _ithi_,
   {{0xe1f890ac,0x6e3babf6,0xdb082610,0x2fd90101}},	//   егі_, xtub, élék, _ihsg_,
   {{0x6145be32,0x25a5007b,0x63a600b9,0x7dcb02f1}},	//   тека, _öll_, zikn, küsi,
   {{0xa3c32418,0x62861bc3,0x25a5d292,0x29135293}},	//   ्ता_, zyko, vill_, _mexa_,
   {{0x9ff300c8,0xf7719e09,0xfe458073,0x6d8d8144}},	//   _জবাব_, شاب_, внио, _cúan,
   {{0xe80d81ce,0x63a6005c,0x25a5a578,0x99558087}},	//   _सबका_, vikn, till_, _икац,
   {{0x6e3b9600,0x2913008e,0xb46580e8,0x62864f9a}},	//   rtub, _nexa_, вкол, vyko,
   {{0x63a6085c,0x6e3b913c,0x20010282,0x22495294}},	//   tikn, stub, _nthi_, _apak_,
   {{0x6286185c,0x395a5295,0x03a63023,0x661d0140}},	//   tyko, _saps_, тимо, _ovsk,
   {{0xeb9709b4,0xed4ed296,0x63a6010b,0x25a5d297}},	//   тия_, _ко_, rikn, pill_,
   {{0x412a035f,0x2fcdcf90,0x63a63437,0x7d1cd298}},	//   ього_, lleg_, sikn, órst,
   {{0x6f09826f,0x661d0186,0xed52003d,0x21210144}},	//   obec, _avsk, یپر_, _ddhh_,
   {{0x2fcd8eb9,0x810d886a,0x62662af7,0xe4e480e8}},	//   nleg_, हरुख_, _авиа, _січн,
   {{0x69c399e3,0x63a43d8e,0xee3a0c5c,0xb8c919a1}},	// [3ec0] kone, _imin, ьна_, _खे_,
   {{0x66040072,0x69c3835f,0xb5fb001c,0x6d41d299}},	//   rpik, jone, _trán, nfla,
   {{0x6604529a,0x69c3d29b,0xad9b026b,0x741315a9}},	//   spik, done, _awús, لولا,
   {{0x69ce05ec,0x09ca970c,0xb5fb001b,0x661baeac}},	//   llbe, ित्य, _král, ksuk,
   {{0x69c39da3,0x27e0529c,0xaefb0362,0x2fcd821e}},	//   fone, mmin_, _cnùu, dleg_,
   {{0x2918529d,0xf5030198,0x2fc68687,0x39908362}},	//   nara_, _взро, _skog_, _bàsa_,
   {{0xa3d201ab,0x6da30f2e,0x6d5c04bc,0x656e0046}},	//   वता_, _тира, _iara, _inbh,
   {{0x27e013f2,0x368a87b6,0x588381e5,0x661b808e}},	//   nmin_, дсон_, рыша, fsuk,
   {{0x6d5c368b,0x29183376,0x6e299123,0x69c3c4a5}},	//   _kara, kara_, greb, bone,
   {{0x63a4529e,0x2918529f,0x69c3d2a0,0xe7ed864a}},	//   _amin, jara_, cone, _चूका_,
   {{0x92af150b,0x27e020a7,0x6d5c4617,0x7c3e52a1}},	//   _করে_, kmin_, _mara, ntpr,
   {{0x6d5c52a2,0x2913062f,0x224900b9,0x6e29a01d}},	//   _lara, _sexa_, _ppak_, breb,
   {{0x27e052a3,0x291852a4,0x6fc59e31,0x6722d2a5}},	//   dmin_, fara_, pócr, _idoj,
   {{0x291852a6,0x63a40d6a,0x660290ab,0x7dc6808b}},	//   gara_, _emin, _itok, rðss,
   {{0x28f802c7,0x25ab80e7,0x291301df,0xdb1b80ff}},	//   тесь_, ècle_, _vexa_, _khuô,
   {{0x69c3d2a7,0x6d5c02b8,0xe4e30770,0x63a4009a}},	//   zone, _aara, _कृषि_, _gmin,
   {{0x291852a8,0x645a075f,0x6ff180eb,0x69c3d2a9}},	// [3ed0] bara_, _štip, _vāci, yone,
   {{0x29180763,0x63a452aa,0x660902d0,0x5c070ba7}},	//   cara_, _zmin, _çekm, вяда,
   {{0x6d5c52ab,0x80a2835a,0x6ec9800d,0x2001005d}},	//   _dara, _केले, _हुनु, _uthi_,
   {{0x6602bac3,0x69c385f8,0xff0443e8,0x6d5c2630}},	//   _otok, wone, _вярн, _eara,
   {{0x6d5c05a3,0x69da88ae,0xa3ab224b,0x1308804a}},	//   _fara, _bhte, _गगन_, тній_,
   {{0x6d5c4e6c,0x6e299f18,0xdb0600f1,0xdb1d0019}},	//   _gara, vreb, tikë, dosí,
   {{0x6602d2ac,0x2fcdd2ad,0x14c7003d,0x7c3e090d}},	//   _atok, tleg_, _شهری_, ctpr,
   {{0x6e29ca41,0x291852ae,0xdb060168,0xdb1b80ff}},	//   treb, zara_, rikë, _chuô,
   {{0x6d5c52af,0x291852b0,0x2fcd821e,0x7f5d52b1}},	//   _yara, yara_, rleg_, _masq,
   {{0x6e29d2b2,0x6d5c0be9,0x63a452b3,0x27e052b4}},	//   rreb, _xara, _smin, zmin_,
   {{0x29182e02,0x6d418e51,0x51848a42,0xb4b10035}},	//   vara_, rfla, _тута, _ओशो_,
   {{0x291847b5,0xb5fb3ad6,0x7f5d07f1,0xe81d00c2}},	//   wara_, _arám, _nasq, _फिजा_,
   {{0x291852b5,0x6d4715f2,0x69da825d,0x9d4581e5}},	//   tara_, _obja, _yhte, _белд,
   {{0xed5681cf,0xf65281c6,0x21f980d7,0xf1a6914f}},	//   _бош_, _לצד_, _mèh_, कोपन,
   {{0x291852b6,0xb5fb52b7,0xf99f0247,0x7c3e29b8}},	//   rara_, _drám, nsèy_, xtpr,
   {{0x291852b8,0x2bbb18b8,0x6d4752b9,0x63a42f15}},	//   sara_, _उदया, _abja, _umin,
   {{0x7bc6185b,0x29c98388,0x0e660110,0xb5fb0174}},	// [3ee0] moku, núas_, ыкан, _frám,
   {{0x6d5c52ba,0x1a9b0158,0x3c3c496a,0x7bc98176}},	//   _qara, _נייע, tív_, _akeu,
   {{0x6d5c52bb,0xef198063,0x31570158,0x7f5d002a}},	//   _vara, każ_, _גיין_, _fasq,
   {{0x69da88cf,0x6d5c52bc,0x44262007,0x7bc60234}},	//   _shte, _wara, čo_, noku,
   {{0x6d5c52bd,0xef19809a,0x7bdb8079,0x69650fd3}},	//   _tara, daż_, _dhuu, _صدیق,
   {{0x1db801fe,0xdd920481,0x6d5c52be,0x443eac9f}},	//   _आदित, _اوس_, _uara, ytt_,
   {{0x7bc652bf,0x6b8092f1,0x3f8252c0,0x443e03e7}},	//   koku, _tomg, _koku_, _ët_,
   {{0x3f820364,0x201e82f7,0xf09301c6,0x2d838198}},	//   _joku_, _vvti_, מנו_, öjen_,
   {{0xaab88f12,0x09368bbe,0xa91c80e1,0x01368199}},	//   _अशिक, _مراج, _voľb, _معاد,
   {{0xa2a50beb,0xd6570039,0x7981d2c1,0x3b0052c2}},	//   _चेष्, ניית_, _golw, _afiq_,
   {{0x3a200118,0x94d4bf21,0x7e640100,0xdb1b827d}},	//   _avip_, ронц, hvip, _thuô,
   {{0xdb09820f,0xd4978c6e,0x3f8209b6,0x7dcb0965}},	//   _vjeç, урь_, _noku_, lüst,
   {{0x6602beda,0x7f5d07f1,0x395e86ab,0x00000000}},	//   _utok, _rasq, _kats_, --,
   {{0xdcfc1024,0xad9b0032,0x365b81c6,0xba00819d}},	//   _borč, _atún, _נכונ, _ọọ_,
   {{0x6ab0d2c3,0x7f5d52c4,0x7d150061,0x43950110}},	//   जपुर, _pasq, _rezs, _вайс,
   {{0x7d1ad2c5,0x29c98125,0x998681d0,0x395ed2c6}},	//   lats, núar_, spoň_, _lats_,
   {{0xb5fb02ba,0xaaa48023,0x61f61f5a,0x3f8252c7}},	// [3ef0] _trám, _खेलक, _guyl, _doku_,
   {{0x442c81d8,0x7d1ad2c8,0x7bc98a53,0x7bdbd2c9}},	//   ord_, nats, _skeu, _shuu,
   {{0x320480b9,0xd5b81ac8,0x7f5d0722,0xdcfc011a}},	//   _atmy_, уст_, _tasq, _gorč,
   {{0x7d1ad2ca,0xfaff00f1,0xc8ff80d4,0x2a69522c}},	//   hats, ncë_, ॉर्म_, _krab_,
   {{0x6f0d0483,0x7d1ad2cb,0xee8717ae,0x7981a45f}},	//   mbac, kats, _сыно, _polw,
   {{0x7d1abe5b,0x7bc620fd,0xef19809a,0xe1f080d7}},	//   jats, zoku, waż_, سسه_,
   {{0x7bc64349,0x7981837a,0x7d1ad2cc,0x6f0d51af}},	//   yoku, _volw, dats, obac,
   {{0x2d8300a9,0x82f880f7,0x443352cd,0x6f0d52ce}},	//   _hoje_, _مركز_, mux_, nbac,
   {{0x2d830025,0xe61687ac,0x442c9afa,0x399400f2}},	//   _koje_, ады_, erd_, _läsa_,
   {{0x7d1ad2cf,0x6f0d52d0,0x2b5f81c0,0x1c458b73}},	//   gats, hbac, _hauc_, аном,
   {{0x04458c8e,0x5f748077,0x69c70390,0xeb9a1e17}},	//   шенн, _گالر, doje, вин_,
   {{0x6266007f,0x2d8352d1,0x6e2d52d2,0x2b490286}},	//   авма, _loje_, krab, _cbac_,
   {{0x3f8209a4,0x7d1ad2d3,0x442cd2d4,0x6f1bd2d5}},	//   _roku_, bats, ard_, mauc,
   {{0x6f1bd2d6,0x69c70824,0xdcfe00eb,0x48dc800d}},	//   lauc, goje, āvīg, गेको_,
   {{0xdca292b2,0x6f0d52d7,0x0cb000c8,0x7bc6022e}},	//   _маши, fbac, _কর্ত, poku,
   {{0xa3c32ba6,0xcc3a80be,0x6441888b,0x4433022b}},	//   ्तः_, _סעפט, mtli, dux_,
   {{0x2d83003a,0x443300e7,0x644181ec,0x24f6002e}},	// [3f00] _boje_, eux_, ltli, ачер,
   {{0xf21380ab,0x69c70144,0xf507002e,0xd24f00d7}},	//   _সমূহ_, coje, инул_, _کنی_,
   {{0x6441c95f,0x3f8252d8,0x224dd2d9,0x6f0d0041}},	//   ntli, _toku_, _apek_, bbac,
   {{0x7d1ad2da,0x21258359,0x395e92f1,0xdb0b8187}},	//   zats, _adlh_, _sats_, ligê,
   {{0x395e8df1,0x443352db,0x236001c0,0x644183e3}},	//   _pats_, aux_, _maij_, htli,
   {{0x6441d2dc,0x2360022c,0x44330197,0xa50752dd}},	//   ktli, _laij_, bux_, _вера_,
   {{0x7d1ad006,0x224da3a8,0x7dcb4db3,0xdb1d0061}},	//   vats, _epek_, rüst, őzés,
   {{0xf1bf0298,0x236001c0,0x7d1ad2de,0x7dcb0074}},	//   nuár_, _naij_, wats, süst,
   {{0xd6d78987,0x7d1ad2df,0xb3558019,0x69c701f8}},	//   ить_, tats, _دینا_, yoje,
   {{0x64418456,0xddc2809a,0x71ea826a,0x6f0d012b}},	//   ftli, _społ, _شفاف_, zbac,
   {{0x7d1ac2dd,0x442c80f3,0x1b190009,0x291c96dc}},	//   rats, urd_, лжны_, mava_,
   {{0x291cd2e0,0x7d1ad2e1,0x236001e9,0x6f1b91b9}},	//   lava_, sats, _caij_, cauc,
   {{0x6b8452e2,0x9f420364,0x48fd800d,0x69c704a9}},	//   _doig, _mikä_, रुको_, toje,
   {{0x660907d9,0x6e2d52e3,0x63ab98f1,0x98a5811c}},	//   _çeki, vrab, zign, _zalı_,
   {{0x6b96108c,0x97a752e4,0x69c70e3f,0x628b809a}},	//   _flyg, арал, roje, zygo,
   {{0x6e2d02e8,0xcf980b30,0x291cd2e5,0xa3d20d72}},	//   trab, ају_, hava_, वतः_,
   {{0x69c70ac1,0x63abd2e6,0x645c003d,0x7bcd1400}},	// [3f10] poje, vign, _asri, _ikau,
   {{0x6e2d52e7,0x6f0d1d5b,0x44330197,0xf1bf0061}},	//   rrab, sbac, tux_, dság_,
   {{0x224dd2e8,0x63abd2e9,0x6b840216,0x201e01d0}},	//   _spek_, tign, _yoig, átit_,
   {{0x6e2d52ea,0xdea1003d,0x2360022c,0x4433318c}},	//   prab, _فیزی, _xaij_, rux_,
   {{0xd6db52eb,0x644e026c,0xeab095a9,0x63ab85ed}},	//   _што_, _epbi, وعه_, rign,
   {{0x9f420364,0x27ef8051,0x98a582d0,0x7d189b4e}},	//   _eikä_, _sign_, _salı_, _nevs,
   {{0x04950013,0x7c950013,0x6f1ba7a6,0x6c850f99}},	//   _الأح, _الأص, tauc, _الزم,
   {{0x7bcd01e9,0x5ba48b88,0x28b80039,0x63688615}},	//   _nkau, _друз, יפוש_, _круг_,
   {{0x6f1bd2ec,0x2294a312,0xceb981d0,0xb5fb0174}},	//   rauc, _дитя, kaře_, _brái,
   {{0x291cd2ed,0x7bcd52ee,0x6609d2ef,0x6f1bd2f0}},	//   cava_, _akau, rpek, sauc,
   {{0x30a7a32d,0x6b8452f1,0x200581b9,0x34c50035}},	//   _трав, _poig, _utli_, _वडोद,
   {{0x69de020f,0x6441d2f2,0xf989010f,0x442152f3}},	//   _shpe, rtli, _אר_, ish_,
   {{0x63a9d2f4,0xeab20065,0x66058a13,0xad9b04be}},	//   _mmen, سٹس_, _упла, _atúm,
   {{0x637f020f,0x63bbd2f5,0x442352f6,0x63a9d2f7}},	//   _mëny, _ljun, _ovj_, _lmen,
   {{0xb9001cfa,0x63a9d2f8,0xdcfc0029,0x442100f1}},	//   _तर_, _omen, _norā, jsh_,
   {{0xd00f12dc,0x291ca800,0x07a3220b,0xe3b90380}},	//   علق_, zava_, пасн, lsın_,
   {{0xa3bd0105,0xdd8f004e,0xea0080ff,0xdee3229c}},	// [3f20] _आदत_, کول_, _đắm_, зоти,
   {{0x63bbd2f9,0x201e303b,0x291c87d0,0x627b03de}},	//   _ajun, átis_, xava_, _ענינ,
   {{0x291cc11c,0x261986a7,0xbddb06c4,0x130a802e}},	//   vava_, _मौसी_, _apès, гней_,
   {{0xf3f980c8,0x201e0110,0xe29a8ba7,0x63a9d2fa}},	//   _আবার_, štis_, лае_, _cmen,
   {{0x291a0978,0x63bbd2fb,0xe3b901cc,0xc6b28264}},	//   _kepa_, _djun, ksın_, _চর্চ,
   {{0x63a9d2fc,0x55e32d94,0x6f0281e8,0x399400e1}},	//   _emen, _нояб, _sfoc, _mäso_,
   {{0xf1bf0019,0x6e228419,0xe04a803d,0xc8668081}},	//   sság_, _svob, اشته_, стли,
   {{0x444452fd,0xbb438009,0x291a04c4,0x3f9202f7}},	//   mt_, _неск, _lepa_, nkyu_,
   {{0xa3d5823c,0x76444014,0xf66a803d,0x877b03de}},	//   हतर_, ntiy, احبه_, ראפי,
   {{0x63a98038,0x7bcd52fe,0x7bdf00f1,0x44443bad}},	//   _zmen, _skau, _shqu, ot_,
   {{0xe6d50a74,0x2ed5000d,0x69ca8b80,0x769e826b}},	//   _दर्ज, _दर्त, mofe, _bàyé,
   {{0x44443f19,0xc7f78039,0x69cad2ff,0x7d1e5300}},	//   it_, _הזאת_, lofe, haps,
   {{0x44445301,0xb5fb5302,0x7d1e22bb,0x2aab0eef}},	//   ht_, _trái, kaps, утно_,
   {{0x44445303,0x398f02f1,0x442152c9,0x69cad304}},	//   kt_, _küsi_, ysh_, nofe,
   {{0x44445305,0x291a4824,0x6f0d8087,0x251b8e82}},	//   jt_, _depa_, _încâ, _גווא,
   {{0xa3bd00a5,0x398b983d,0xd5b881a9,0x69cad306}},	//   _आदि_, _høst_, lnā_, hofe,
   {{0xa3cc8076,0x63af3351,0x88bc801b,0xaa592f4f}},	// [3f30] रकन_, micn, _sděl, _типу_,
   {{0xa3dd05b3,0x44445307,0x63af0025,0x63a9ce94}},	//   _तीत_, ft_, licn, _smen,
   {{0x444442a4,0x490f000d,0xa91c80e1,0xc8a79995}},	//   gt_, _त्यो_, _poľn, _केंट,
   {{0x63af007d,0x2d980267,0x93bd0087,0x291a0118}},	//   nicn, _elre_, crăt, _zepa_,
   {{0x44441645,0x7f3a0158,0xa91c81ac,0x60c481cc}},	//   at_, _דערו, _voľn, şiml,
   {{0xa9699dba,0x2903009a,0x444449f6,0x69cac913}},	//   рика_, ncja_, bt_, gofe,
   {{0x44445308,0x88bc801b,0x63bb81a1,0x93e981a8}},	//   ct_, _uděl, _tjun, _نفسك_,
   {{0x6d5723be,0xdfd18013,0x63bb8e60,0x63a9d309}},	//   lexa, بيع_, _ujun, _umen,
   {{0x7bcb803a,0x64450014,0x2903009a,0x660d530a}},	//   mogu, lthi, kcja_, npak,
   {{0x7bcbd30b,0xdb0bd30c,0x225f88f9,0x6d5703cd}},	//   logu, digé, _isuk_, nexa,
   {{0x6445530d,0xe3ba0009,0x7e648279,0x32092354}},	//   nthi, ибо_, _šipt, _atay_,
   {{0x3ce10d38,0x61fb98c5,0x6445530e,0x7e6b826c}},	//   _करने_, _kuul, ithi, _trgp,
   {{0x61fb8074,0xb69b0087,0x6445389c,0x63bd0144}},	//   _juul, _sfân, hthi, érna,
   {{0x64453213,0x225f8359,0x4444043c,0x660d2b36}},	//   kthi, _msuk_, yt_, dpak,
   {{0x61fbd30f,0x63af0289,0x7bcb8074,0x6d575310}},	//   _luul, bicn, kogu, dexa,
   {{0x673b84e8,0x44441c6d,0x6575274a,0x6563d311}},	//   nguj, vt_, _anzh, _hanh,
   {{0x660d1066,0x7bcbd312,0x2a6d822c,0x44445313}},	// [3f40] gpak, dogu, _nreb_, wt_,
   {{0x44445314,0x76445315,0xd910026a,0x656389ab}},	//   tt_, rtiy, _سیر_, _janh,
   {{0x44445316,0x39585317,0x76445318,0xe45a1ada}},	//   ut_, mers_, stiy, рже_,
   {{0x395801eb,0x2905d319,0xa3d4800f,0xa91c80e1}},	//   lers_, _afla_, _सीख_, _poľo,
   {{0x6f040b80,0x7dd00106,0x2a6002a6,0xdd1c936f}},	//   mcic, fäst, _jsib_, váži,
   {{0xb5fb0a56,0x3958531a,0x082ad31b,0x63af00fe}},	//   _práv, ners_, ации_, zicn,
   {{0x69cad31c,0x7bcb8032,0x444401b9,0xcf9a84ae}},	//   rofe, bogu, qt_, ији_,
   {{0x7d1c1591,0x656380c9,0x261101ce,0x39580039}},	//   _hers, _aanh, दीकी_, hers_,
   {{0x7d1c531d,0x65638073,0x61fb82a3,0x63af0b67}},	//   _kers, _banh, _guul, vicn,
   {{0x2d988063,0x48e6cc2f,0xb5fb026f,0x3958022b}},	//   óre_, _дозв, _tráv, jers_,
   {{0x2cfb0451,0x63af00d2,0x39581527,0x7d1c531e}},	//   יליא, ticn, ders_, _mers,
   {{0xb5fb003e,0xddc28029,0x236680f1,0x6f0401dd}},	//   _krát, _droš, ndoj_, jcic,
   {{0x7988829b,0xf1bf03fb,0x2d87d31f,0x7d1c2580}},	//   _kodw, krát_, _fone_, _oers,
   {{0x39584e81,0x656380a9,0x63af02a5,0x628f5320}},	//   gers_, _ganh, sicn, ryco,
   {{0x63af00d2,0x3494a8ff,0x37ab24dc,0x6ca38081}},	//   picn, _хайр, атан_, _оръж,
   {{0x6720911b,0x22468461,0x660d2895,0x644501c0}},	//   namj, ktok_, tpak, vthi,
   {{0x7d1c0fc7,0x63ad5321,0x2b59002e,0x59ca8743}},	// [3f50] _bers, _iman, mesc_, ाकार,
   {{0x660d5322,0x7d1c422b,0x93bd0087,0x79888114}},	//   rpak, _cers, crăr, _nodw,
   {{0x437596d9,0x6d575323,0x7d1c0b0b,0x61fbd324}},	//   зулт, rexa, _ders, _suul,
   {{0x7d1c2539,0x64455325,0x6d575326,0x2b59002e}},	//   _eers, rthi, sexa, nesc_,
   {{0x7d1c4ac7,0x27e95327,0x644503e9,0x63ad5328}},	//   _fers, mman_, sthi, _mman,
   {{0x27e95329,0xa3dd146d,0x7d1c532a,0x8dfa0039}},	//   lman_, _तीस_, _gers, _להשת,
   {{0x63ad532b,0x7857817e,0x765908c5,0xb5fb002a}},	//   _oman, تیاز_, şayı, _usáb,
   {{0x27e9532c,0x3958532d,0x2a6d8e72,0x61fbd32e}},	//   nman_, zers_, _treb_, _tuul,
   {{0x28d2101b,0xb5fb532f,0x2d87a7e1,0x65638420}},	//   _दुनि, _grát, _pone_, _panh,
   {{0x63ad4289,0xddc2883d,0x27e90c9e,0x6f1d5330}},	//   _aman, _proš, hman_, _lesc,
   {{0xb5fb003e,0x65638364,0x27e9133b,0x1b2000ab}},	//   _krás, _vanh, kman_, _ভাবে_,
   {{0x27e906c0,0x6f1d5331,0xdb0605bf,0x39580bbf}},	//   jman_, _nesc, fiká, wers_,
   {{0x27e95332,0xa3cc9344,0x39583780,0x386100dd}},	//   dman_, रकत_, ters_, _ashr_,
   {{0x2d9ed333,0x63ad5334,0xf1bf5335,0x64a58539}},	//   chte_, _eman, drás_, _нала,
   {{0x6f1d26b1,0xddc2b738,0x22468019,0x2b590087}},	//   _besc, _uroš, ztok_, besc_,
   {{0x39585336,0x27e939a3,0xab9a0077,0x2fcd8b3c}},	//   sers_, gman_, _دختر_, noeg_,
   {{0x6f1d2b56,0x59cb800c,0x6e243b8f,0x41cb8c78}},	// [3f60] _desc, िवार, usib, िवास,
   {{0x7d1c00f1,0x6b9b9d16,0x63ad0353,0x27e95337}},	//   _qers, _alug, _zman, aman_,
   {{0x7d1c0faf,0x1b0d80c8,0x3ce1016f,0xa3c3016f}},	//   _vers, _হয়ে_, _करणे_, ्तच_,
   {{0x6f1d1736,0x8c4907d9,0x7d1c009a,0xb5fb5338}},	//   _gesc, daşı, _wers, _prát,
   {{0x7d1c045c,0x236681f4,0xb5fb016a,0x7988809a}},	//   _ters, rdoj_, _drás, _podw,
   {{0xb5fb0a21,0x47360077,0x6f1d00d2,0x69ce148c}},	//   _vrát, _برگز, _zesc, nobe,
   {{0x6b9b8189,0x34a70652,0x2d8a0118,0xdb060c83}},	//   _flug, _евро_, _iobe_, ziká,
   {{0x3ce10d38,0xc91804e5,0xb5fb5339,0x69ce533a}},	//   _करते_, थरुम_, _trát, hobe,
   {{0xfaa39092,0xed588038,0x2d9ed33b,0x443a533c}},	//   _зато, teľ_, thte_, lup_,
   {{0x63ad003b,0xf64f8064,0x27e906c0,0xd9c6064a}},	//   _sman, ائي_, zman_, लकोट,
   {{0x27e944bd,0x69ce1b49,0x2b590087,0xdcfc0035}},	//   yman_, dobe, tesc_, _gorą,
   {{0x2d9e88cf,0x69d8bc54,0x291e8106,0xa3e286a7}},	//   shte_, llve, _heta_, _नीम_,
   {{0x2b59002e,0x27e906c0,0x291ed33d,0x2707801c}},	//   resc_, vman_, _keta_, _ống_,
   {{0x7e62d084,0x23de823c,0x2b59002e,0x291e80f1}},	//   _isop, _फीसद, sesc_, _jeta_,
   {{0x291ec6a0,0xa3be805e,0xa3cc800d,0xdfd50d15}},	//   _meta_, ीका_, रका_, довы,
   {{0x291ed33e,0x6d5ad33f,0x443a14ff,0x63ad5340}},	//   _leta_, leta, dup_, _uman,
   {{0xd6db0b88,0x9f4c81ac,0x6f1d3ed7,0x27e935b2}},	// [3f70] ств_, _budú_, _vesc, rman_,
   {{0x6d5a80ad,0x27e90242,0x69ce2333,0x7bcf0087}},	//   neta, sman_, cobe, locu,
   {{0x4427128e,0x27e906c0,0x443a0590,0x7d0502af}},	//   én_, pman_, gup_, rchs,
   {{0x6d5ad341,0x27e9395c,0x245e001b,0xfc301dd2}},	//   heta, qman_, _dům_, احل_,
   {{0x6d5a95ee,0xe6670a14,0x6e22012b,0x2fcd81b0}},	//   keta, _этно, šobr, voeg_,
   {{0xac192ae3,0x3f8b0052,0x443a02f7,0x2d8a5342}},	//   _могу_, _hocu_, bup_, _gobe_,
   {{0x6b89a539,0x6d5ad343,0xb9058054,0x291ed344}},	//   _toeg, deta, _नर_, _deta_,
   {{0x69ce5345,0x0609a623,0x389c03c8,0xefc800ff}},	//   zobe, оник_, מיונ, _địch_,
   {{0x200c8201,0x291e881a,0x7e628019,0x2d8a0041}},	//   _etdi_, _feta_, _csop, _yobe_,
   {{0x291e8125,0xa3d5809a,0x1dbf50cf,0x442781a9}},	//   _geta_, हतक_, ्वित, _pvn_,
   {{0xb8089e44,0x65670353,0x69ce0b80,0xf8e183eb}},	//   _فيلم_, _majh, vobe, _फरिय,
   {{0x7e6d026f,0x2d9cd346,0x3f8b025b,0x61c601cb}},	//   kvap, _elve_, _nocu_, लक्ष,
   {{0x6d5ad347,0x65a002af,0x1dbf0bbc,0x61ff0609}},	//   beta, _höhe, ्वात, _cuql,
   {{0x9f5eca44,0x6d5ad348,0x443a5349,0x6455534a}},	//   _että_, ceta, yup_, _opzi,
   {{0x69ce534b,0xa067117e,0xdb008009,0x3f8b00ce}},	//   robe, мара_, _ymmä, _bocu_,
   {{0xe61a534c,0x69ce0b24,0xafe31f34,0x200c01a9}},	//   жда_, sobe, восл, īdi_,
   {{0xa1c61e72,0x60c48214,0x69ce069f,0x64551d70}},	// [3f80] _обид, ğimi, pobe, _apzi,
   {{0xca370039,0xa2ad016f,0x2257003d,0xee3700e8}},	//   _קניה_, ीपर्, _کلید_, ьну_,
   {{0x0b46a183,0x291ed34d,0x07a623b2,0x013500be}},	//   днен, _reta_, _жанн, _אָרט_,
   {{0x6d5ad34e,0x443a534f,0x291ed350,0x3ebf012b}},	//   zeta, rup_, _seta_, _žute_,
   {{0x291e859c,0x6d5ad351,0x2d8a5352,0xd250806b}},	//   _peta_, yeta, _tobe_, انت_,
   {{0x6d5aaf72,0x7afb811b,0x6e3b81b4,0x672400b9}},	//   xeta, _egut, duub, laij,
   {{0x291ed353,0x6d5ad354,0xa3d98740,0xf54e801c}},	//   _veta_, veta, _ठीक_, _bụng_,
   {{0x291e8133,0x6d5ad355,0x3320023e,0x3a268637}},	//   _weta_, weta, _neix_, psop_,
   {{0xf54e8104,0x2b44826c,0xb146802e,0x63a2d356}},	//   _dụng_, _icmc_, _онал, mhon,
   {{0x2a648e72,0x60cd83bf,0xdcfc0bda,0x200c80b9}},	//   _ismb_, şama, _dorć, _ttdi_,
   {{0x6d5a888b,0x75370051,0x53ca02f1,0x7bcf2973}},	//   reta, ואיד_, रवंश, tocu,
   {{0x69c002be,0x6ec9984a,0x6448d357,0x67c181a9}},	//   émen, _हुकु, rtdi, pēja,
   {{0x6d5ad358,0x6448d359,0x7bcf18f6,0x61f7019c}},	//   peta, stdi, rocu, _pixl,
   {{0x7c3ad1ea,0x7bcf52ed,0x246c928a,0x6d439867}},	//   putr, socu, _těm_, _gcna,
   {{0x63a2829b,0x855784de,0xb5fb535a,0x98480081}},	//   khon, _חשוב_, _aráp, мята_,
   {{0x1b1900c8,0x27e6814a,0x7e6d8390,0xab5b02d0}},	//   _থাকে_, _jhon_, _šapi, ylüy,
   {{0x7f4d00f1,0x63a2803d,0x6567022c,0x27e682f7}},	// [3f90] rfaq, dhon, _pajh, _mhon_,
   {{0xd9e306b7,0xaad28105,0xdb0b8216,0x995400e1}},	//   _गठित_, _तड़क, rigí, _päť_,
   {{0x6567022c,0x27e68bb1,0x7c28d35b,0xddc2866f}},	//   _vajh, _ohon_, nsdr, _spoś,
   {{0xa3a98063,0x2b44802a,0xd6d00019,0x63a2d35c}},	//   गों_, _ccmc_, اقے_, ghon,
   {{0x6b8d535d,0xdcf881d0,0xf54e8129,0x7d0ac8c0}},	//   _moag, _pově, _rụng_, _offs,
   {{0xa3e60fd5,0x2b44808e,0x2bb8826c,0x6845bedc}},	//   _बीन_, _ecmc_, dčcu_, енка,
   {{0x27e68014,0x200102f1,0x442a0bfd,0x00000000}},	//   _bhon_, _juhi_, _gvb_, --,
   {{0xd0f80bea,0x7afbd35e,0x9e65a29c,0x2bbb056b}},	//   ומות_, _ugut, евид, _उदगा,
   {{0xa3cc81fe,0xb8d6816f,0xa3be816f,0xea0080ff}},	//   रकर_, _चे_, ीकर_, _đầm_,
   {{0x2121008e,0x4c8586e9,0x89388dca,0x27e68362}},	//   _nehh_, елов, _опус_, _ehon_,
   {{0xe572093f,0x3f158009,0x33200722,0x6e3b82ec}},	//   אַר_, _здес, _peix_, suub,
   {{0xfe71815b,0x27f9535f,0xf1bf0118,0xcf2780d7}},	//   _مدت_, _nisn_, usán_, _آراي,
   {{0x27edd360,0xc33282f6,0x661d01c0,0x998401d0}},	//   mmen_, נוך_, _nwsk, émů_,
   {{0xc2128451,0x6e298234,0x20010420,0x74ca8a27}},	//   רהם_, mseb, _buhi_, _सुकृ,
   {{0xddc40289,0xa3c1d361,0x212102f7,0x9f5e82d6}},	//   jviš, ुवा_, _dehh_, _butè_,
   {{0x27ed8205,0x6f0983ac,0x442a05db,0x2121008e}},	//   nmen_, ncec, _rvb_, _eehh_,
   {{0x290502bb,0xee3a47dc,0x6e29d362,0xdce3a3b0}},	// [3fa0] ılar_, яна_, nseb, _manč,
   {{0x6d41d363,0x27ed8352,0x6e360683,0xdce38289}},	//   ngla, hmen_, rryb, _lanč,
   {{0x236901c0,0xb5fb016a,0x63a2d364,0x273a8380}},	//   _yaaj_, _usán, thon, nünü_,
   {{0x2486003a,0x8c1a8039,0xb5fb016b,0x69dc5365}},	//   ćom_, פוני, _tráp, llre,
   {{0xfeba08ca,0x45240264,0x6e298366,0x27ed8865}},	//   _راحت_, _পাঠক_, jseb, dmen_,
   {{0x63a2d366,0x27e68c41,0x27eda128,0x6e29807a}},	//   shon, _shon_, emen_, dseb,
   {{0x63a2d367,0xfce31383,0xb882001b,0xdce3807a}},	//   phon, _боро, _říjn, _banč,
   {{0x2fc05368,0x6d5e5369,0x69dc44cb,0xdd258084}},	//   nnig_, lepa, hlre, _rūši,
   {{0x7c3e003e,0x2fc0536a,0x7ae421bb,0x67c50084}},	//   lupr, inig_, _nzit, nėja,
   {{0x6d5e536b,0x6d41d36c,0x7bd60c2e,0x7bc40c53}},	//   nepa, ggla, _akyu, _ajiu,
   {{0xd6da8065,0xd4978012,0xb5fb0032,0x27e6d36d}},	//   _کوشش_, еря_, _asál, _thon_,
   {{0x20014677,0x29180661,0x67c50084,0x27e68420}},	//   _ruhi_, ebra_, kėja, _uhon_,
   {{0xdfcf8077,0x4e93804e,0x200146b7,0x7c28804a}},	//   _اين_, _مشور, _suhi_, ssdr,
   {{0x6d5e0654,0x67c50110,0xdb0f0187,0x7c3e536e}},	//   jepa, dėja, micí, kupr,
   {{0xb90905b3,0xbebb08cf,0xdb0f02ba,0x61faaebd}},	//   _बर_, _ndër, licí, _mitl,
   {{0x443eb303,0x987b8158,0x7c3e00fe,0x26020074}},	//   mut_, האלט, dupr, _वंशी_,
   {{0x443ed36f,0x660287ac,0xdb0f5370,0x391512bc}},	// [3fb0] lut_, _juok, nicí, _импр,
   {{0x443e81e0,0x6d5e0ac5,0x66028009,0xad9b046d}},	//   out_, gepa, _muok, _atúr,
   {{0x443e99e3,0xe3be8182,0x66028009,0x656a8239}},	//   nut_, ğına_, _luok, _mafh,
   {{0x04c800f7,0xe3be817b,0xddc40da8,0x6e298114}},	//   روني_, şına_, rviš, yseb,
   {{0x443ed371,0x21699541,0xa96994d6,0x61fad372}},	//   hut_, дили_, дила_, _bitl,
   {{0x443eb897,0x2369812b,0xd8380db7,0x6d5e5373}},	//   kut_, žaj_, šče_, cepa,
   {{0xdce3aa6b,0x443ea645,0x6d5501c0,0x27ed8dc6}},	//   _panč, jut_, _ibza, tmen_,
   {{0x3f893932,0x3994016d,0x776d5374,0x6d4181c0}},	//   njau_, _häst_, ndax, wgla,
   {{0x764d2bca,0x6f0986cb,0x6458a585,0x3ea95375}},	//   ntay, rcec, _apvi, nzat_,
   {{0x6e29845c,0xa8a78191,0x30a796d4,0x61fa82d5}},	//   rseb, _прек, _прев, _gitl,
   {{0x443ed376,0x03a62623,0x6e29d377,0xdce3d378}},	//   gut_, вино, sseb, _bonġ,
   {{0x399400f2,0x6d41d379,0x09da016f,0x7e6d80d2}},	//   _läst_, sgla, णत्य, _šapu,
   {{0xa2d503ca,0x3ea90168,0x6d5e10fa,0x98b00140}},	//   _युद्, jzat_, yepa, _čađe_,
   {{0x784a8085,0x39940106,0x67c50084,0xdb0604e8}},	//   _səvi, _näst_, vėja, nikú,
   {{0x443e8012,0x67228072,0x3f8f8074,0x64a59ff9}},	//   cut_, _yeoj, _kogu_, _шака,
   {{0x3ebf01dd,0x212780ff,0xa0670073,0x764d537a}},	//   _žuta_, hanh_, њата_, ftay,
   {{0x3f8f803a,0x6d5e1959,0x399400f2,0x7523d37b}},	// [3fc0] _mogu_, tepa, _bäst_, _kenz,
   {{0xdb0b8298,0x2fcd0805,0xa3e60105,0xa80601cf}},	//   vigá, čega_, _बीत_, _изол,
   {{0xdd100038,0x81d800ab,0x2fc00122,0x499b1101}},	//   _týžd, িষদ_, pnig_, _חשיב,
   {{0xeb97bd00,0x3f8f8a20,0x7523c1e5,0x78a30085}},	//   ких_, _nogu_, _lenz, _ünva,
   {{0x443e8c3a,0x7c3e3200,0x425480a0,0x67228144}},	//   zut_, supr, انتر, _reoj,
   {{0x657c0355,0x66028364,0x7f958510,0x7f4400e7}},	//   _unrh, _ruok, _máqu, lgiq,
   {{0x9346867c,0x3f8f811f,0xa3c44069,0x61fad37c}},	//   _инве, _bogu_, ्वा_, _vitl,
   {{0x443ed37d,0x2d8e8390,0x61fa9e12,0xf76f81a8}},	//   vut_, _sofe_, _witl, قاً_,
   {{0x443ea240,0xa3c1881f,0x3f8f811b,0x9f590176}},	//   wut_, ुवर_, _dogu_, _disè_,
   {{0x66028364,0x61fa838e,0x7bc28362,0xb5fb026b}},	//   _vuok, _uitl, lnou, _asáj,
   {{0x3ea9537e,0x35678087,0x7e6d86ec,0xd7ef8615}},	//   zzat_, трын_, _šapt, _ву_,
   {{0x443e8dab,0x040d801c,0x316c826c,0x752381ed}},	//   rut_, _hưởn, _hadz_, _eenz,
   {{0x443ed37f,0xe5c6bd2f,0x161b82f1,0x3f8f008b}},	//   sut_, _иско, पीआर_, ögum_,
   {{0x656a806a,0x7bc281d0,0x7523d380,0x3f8f83ed}},	//   _uafh, hnou, _genz, _zogu_,
   {{0x9f350221,0xd48fd381,0x59f8002e,0x76408c2e}},	//   леві, _тр_, теря_, lumy,
   {{0x3ea92a81,0xb8db2cfc,0x764d5382,0x752381f6}},	//   tzat_, _आइ_, ttay, _zenz,
   {{0x8bb40b76,0x7c2e068f,0x5d551071,0x7bc281d0}},	// [3fd0] _خصوص, _avbr, лкат, dnou,
   {{0x3ea92175,0x26058ad5,0x6b9d14ab,0x764d3a59}},	//   rzat_, _हंसी_, lksg, rtay,
   {{0x764d43c2,0xdce380eb,0x29010135,0x39940106}},	//   stay, _kanā, _igha_, _väst_,
   {{0x6b9d08df,0xed510065,0x9f4c8144,0x2013011b}},	//   nksg, _گھر_, _mudó_, _itxi_,
   {{0xdb1d2755,0x6b9d01ed,0xf9900fd3,0x6f0d5383}},	//   losó, iksg, _طبی_, mcac,
   {{0x75288029,0x644a0722,0xa5bb009a,0xca7682e3}},	//   jadz, àfic, _dwóc, اموش_,
   {{0x7523d384,0x65a0011c,0x442c890d,0x6e2d290a}},	//   _renz, _köhn, jsd_, lsab,
   {{0x7523d385,0x6d451100,0x69d55386,0x2d915387}},	//   _senz, lgha, hoze, _hoze_,
   {{0xaab79299,0x69d55388,0x2d9106c0,0x4ab78778}},	//   _अधिक, koze, _koze_, _अधिव,
   {{0x6d451904,0x63b9d389,0x4585a5d9,0x6e2d441d}},	//   ngha, liwn, угов, isab,
   {{0x2d9102a5,0x481587eb,0xfbb78c78,0x201301c0}},	//   _moze_, _смес, _आगाम, _ntxi_,
   {{0x7523ace6,0xe72e8b30,0x2901082e,0x29cd01ac}},	//   _wenz, _ће_, _agha_, hľad_,
   {{0x69c382be,0x539a8158,0x6f1bd38a,0x2005809c}},	//   onne, גירו, mbuc, _huli_,
   {{0x957c8063,0x8c45b44f,0x186a0098,0x20059f73}},	//   gląd, _беке, наги_, _kuli_,
   {{0x69c38c64,0x65618073,0xc4be00ab,0xdb1d002a}},	//   inne, melh, _অর্জ, gosó,
   {{0x6f0d538b,0x2005d38c,0x6f1b82af,0xad9b01d6}},	//   gcac, _muli_, nbuc, _stúp,
   {{0x63a4538d,0x6e2d043b,0x2005d38e,0x69d5538f}},	// [3fe0] _ilin, gsab, _luli_, boze,
   {{0x51660607,0x63a4026f,0x7bc2d390,0xc9663470}},	//   _своб, _hlin, wnou, _свой,
   {{0x6441885c,0x26cb0748,0x200580d7,0xdce700e1}},	//   nuli, _exco_, _nuli_, _fajč,
   {{0xa22a9194,0x69c3d391,0x7c2e8e15,0x201840cf}},	//   ежда_, enne, ábri, mpri_,
   {{0xd00f04c0,0x75840077,0x2125826c,0x6441d392}},	//   _ولی_, _پیام, _belh_, huli,
   {{0x27e05393,0x6441b539,0x20058c56,0xe8948364}},	//   llin_, kuli, _buli_, иаль,
   {{0x6441bb7b,0x63a45394,0x66060406,0x27e05395}},	//   juli, _olin, _hukk, olin_,
   {{0x66065396,0x75288063,0x963485c2,0xa0678003}},	//   _kukk, wadz, аниц, ѓања_,
   {{0x2bb18063,0x040d8028,0x244e026f,0x752886cb}},	//   jący_, _tưởn, lým_, tadz,
   {{0x63a44cb4,0xa3b086b7,0x65618a34,0xdb0f2d84}},	//   _alin, टोर_, gelh, dicá,
   {{0x244e0775,0x66063f51,0x7528809a,0x2005d397}},	//   ným_, _lukk, radz, _guli_,
   {{0x656e1a2f,0xdb0f0c52,0x69d5254d,0x6726007a}},	//   _labh, ficá, woze, _nekj,
   {{0xe7f8097d,0x244e016b,0x69d5011b,0x6606331b}},	//   ंगना_, hým_, toze, _nukk,
   {{0x63a45398,0x6441baa0,0x645c5399,0xf2d38158}},	//   _elin, buli, _opri, מער_,
   {{0x6f0d0362,0x6441bdf9,0x69d5539a,0xb97b8158}},	//   tcac, culi, roze, ענלי,
   {{0x2a6901c5,0x2d8c8106,0x7ddd83ec,0x3f150071}},	//   _tsab_, ljde_, vèsi, рдас,
   {{0xa3c403b7,0x2d91539b,0x645c33b0,0x2a691341}},	// [3ff0] ्वर_, _poze_, _apri, _usab_,
   {{0xd8380db7,0x6e2d539c,0x656e0cac,0x2d9ebede}},	//   šča_, rsab, _cabh, nkte_,
   {{0x6e2d539d,0x2d9100d2,0x2dd800f7,0x6d45539e}},	//   ssab, _voze_, ابقة_, rgha,
   {{0xae048670,0xb767539f,0x61fe05b0,0x16049094}},	//   रदान_, _стой, _zipl, रदार_,
   {{0x2005856a,0x3ce1009a,0xfdf68105,0x6441d3a0}},	//   _suli_, _करके_, ीदास_, zuli,
   {{0x656e0ad0,0x2005d3a1,0xe2968ae7,0x6f02d3a2}},	//   _gabh, _puli_, раш_, _agoc,
   {{0xa0a581e5,0x18a58196,0x6561c233,0x10a595a1}},	//   райд, райм, velh, рийн,
   {{0xe3b092dc,0xddc9d3a3,0x6e3b816b,0x7f759033}},	//   _فرق_, dveš, trub, рукц,
   {{0xdb06020f,0x442301c5,0x6f1b8865,0x64418c56}},	//   shkë, _hwj_, rbuc, wuli,
   {{0x7ae9d3a4,0x2005c7b9,0xdcf88029,0x4423022c}},	//   _izet, _tuli_, _novē, _kwj_,
   {{0x63a453a5,0x656189e9,0x61fe01e0,0x397a80be}},	//   _plin, relh, _ripl, _שטענ,
   {{0xe29a0471,0xddc28110,0x6441d3a6,0x765d53a7}},	//   вам_, _grož, ruli, _opsy,
   {{0x7ff48277,0x44230069,0x6561d3a8,0x63a4110f}},	//   _اسلا, _lwj_, pelh, _vlin,
   {{0x6441d3a9,0x2d9eaa9c,0x1a9a8158,0x463a80be}},	//   puli, ckte_, דישע, _יענע,
   {{0x66062707,0xa3d597a3,0xd70600b3,0x656e032f}},	//   _sukk, सका_, изви, _rabh,
   {{0x244e0ed7,0x63a453aa,0x656e53ab,0x201853ac}},	//   vým_, _ulin, _sabh, rpri_,

   {{0x28db0076,0x201806c0,0x27f253ad,0xb69b0087}},	// [4000] _मुठि, spri_, rmyn_, _sfâr,
   {{0x637b0009,0x244e026f,0x1a9b03c8,0x7bdbb9b9}},	//   _tänä, tým_, _סייע, _akuu,
   {{0x31570158,0xdd8f190c,0x44230069,0xb46653ae}},	//   _דיין_, بول_, _cwj_, ркел,
   {{0xa3b0809a,0x244e05b9,0x3d160d14,0x3ce60006}},	//   टों_, rým_, _प्रे_, _करीं_,
   {{0x656e003c,0x2d9e854f,0x98a301a9,0x752708b2}},	//   _tabh, ykte_, majā_, _fejz,
   {{0xfe088028,0x4423022c,0xb33b00f1,0x76440010}},	//   _nữa_, _fwj_, thçk, muiy,
   {{0x97a6802e,0x58868196,0xdb0401ed,0xf1a9803d}},	//   ирил, рыла, _clië, دانه_,
   {{0x444453af,0x776407e2,0x6e228247,0x9f420198}},	//   mu_, neix, _pwob, _eikö_,
   {{0x444453b0,0xfe0880ff,0xfaa3d3b1,0xb5fb046d}},	//   lu_, _bữa_, _дато, _aráy,
   {{0x444453b2,0x44230069,0x3d168072,0x9f970580}},	//   ou_, _ywj_, पुढे_, nçò_,
   {{0xb5fb003e,0x2d9ec277,0xa3c402f7,0x31630bda}},	//   _práz, rkte_, ्वं_, vejz_,
   {{0xa3cc800c,0x444453b3,0x9ffa81a8,0x69d8b74e}},	//   रकट_, iu_, _شراء_, love,
   {{0x77640722,0x6fb381a8,0x7e798114,0x387a0db1}},	//   deix, _بمنا, _grwp, _arpr_,
   {{0x6b5c006a,0x14b789a7,0xa5bb026b,0x1cba81a8}},	//   _pågæ, ادیث_, _awón, _لاعب_,
   {{0xa3d69278,0x351b83de,0x06d88264,0x69d88493}},	//   हवा_, _יוגנ, দেশি, iove,
   {{0x77640722,0x442301c0,0x34fb8039,0x3cfb8039}},	//   geix, _rwj_, _בהוד, _בלונ,
   {{0x444453b4,0x69d8d3b5,0x63bd53b6,0x7c3e1254}},	// [4010] eu_, kove, misn, erpr,
   {{0x6d489341,0x44443b2d,0x7bdbb57c,0x443ed3b7}},	//   ngda, fu_, _skuu, ort_,
   {{0x44441a83,0x54553312,0x69d8b06b,0x4423022c}},	//   gu_, свет, dove, _qwj_,
   {{0x443e954c,0xb4e71130,0x63bd53b8,0x69c70353}},	//   irt_, _परी_, nisn, lnje,
   {{0x444453b9,0x443e8352,0x4df68d86,0x752729e7}},	//   au_, hrt_, ँगाई_, _tejz,
   {{0xdca68307,0x6ab78076,0x32090358,0x69d89b46}},	//   _فى_, _अधीर, _muay_, gove,
   {{0x01380039,0x7d038118,0x260c86a7,0x6d488122}},	//   ברות_, _rgns, _डूबी_, dgda,
   {{0x63bd47c7,0xfe08801c,0xfaff0168,0x1bd480e8}},	//   jisn, _sữa_, ndës_, _дося,
   {{0x443ed3ba,0x7ae985f5,0x63bd0052,0x3ead80d2}},	//   ert_, _uzet, disn, uzet_,
   {{0xcda983f8,0x69c702a5,0x51848adb,0x4c698256}},	//   اهده_, jnje, _муха, гион_,
   {{0x69c7135a,0x644542af,0x672d53bb,0x232a1a6d}},	//   dnje, nuhi, kaaj, лони_,
   {{0xe0d08277,0x63bd53bc,0x06b8803d,0x672d33fd}},	//   _غزل_, gisn, انیک_, jaaj,
   {{0x443ece37,0xed59997d,0x444453bd,0xb5fb002a}},	//   art_, _бол_, zu_, _fráx,
   {{0x444453be,0x69c71b46,0x32090122,0x644513fa}},	//   yu_, gnje, _duay_, kuhi,
   {{0x3ce60d38,0x77641209,0x63bd53bf,0x68e9001b}},	//   _करें_, teix, bisn, ředn,
   {{0x81cd80c8,0x81bf80c8,0xaf0653c0,0x2451826f}},	//   রতি_, ীতি_, спал, mám_,
   {{0x444453c1,0x7764009f,0x2451816b,0x823612c8}},	// [4020] wu_, reix, lám_, _اربا,
   {{0xaadb82f1,0x67c181a9,0x69c700fe,0x6b9601b4}},	//   _बड़क, mēju, cnje, _hoyg,
   {{0x6445009c,0x7ae08106,0x69de0870,0x67c181a9}},	//   guhi, _symt, _ikpe, lēju,
   {{0x7f8601a8,0x7e698ca2,0x661b82d5,0x9f5d8032}},	//   _الحن, kwep, kpuk, _fiwé_,
   {{0x44444b47,0x6d48a651,0x290582d5,0xca568073}},	//   su_, ygda, _bgla_, стењ,
   {{0x443ed3c2,0x20020010,0x63bd026c,0x2451a620}},	//   yrt_, _hiki_, zisn, kám_,
   {{0x24778104,0x69d8d3c3,0xfaff020f,0x20020365}},	//   _năm_, rove, ndër_, _kiki_,
   {{0x24518e93,0xa6148750,0x69d8d3c4,0xfaa6a345}},	//   dám_, омич, sove, _лабо,
   {{0x69d89734,0xa3d58540,0x2a60022c,0xddc281a1}},	//   pove, सकर_, _npib_, _asoš,
   {{0x6b8402a3,0x68e1813c,0x7afd826f,0xddc400eb}},	//   _anig, _fyld, _ústa, stiņ,
   {{0x63bd53c5,0x443ea919,0x68e18aa2,0x6d5c53c6}},	//   tisn, urt_, _gyld, _mbra,
   {{0x63a2d3c7,0x9f4003d3,0x200253c8,0x69de008e}},	//   nkon, blié_, _niki_, _akpe,
   {{0x63bd0e78,0x32090028,0x69c701dd,0x51873b98}},	//   risn, _quay_, tnje, бува,
   {{0x6b8453c9,0x200200a4,0x63bd3797,0x24518c83}},	//   _enig, _aiki_, sisn, bám_,
   {{0x63a2cd07,0x97a723b2,0x681180eb,0x63bd53ca}},	//   kkon, брал, _kāda, pisn,
   {{0x6d5c53cb,0x02a70765,0xaada0f12,0x200200a4}},	//   _abra, _гром, _युवक, _ciki_,
   {{0x69c70369,0x6d5c008e,0x67c50110,0xdb0d0214}},	// [4030] pnje, _bbra, nėji, _amaç,
   {{0x7aed00ad,0x644553cc,0x672d29cd,0xec0980ff}},	//   _izat, tuhi, saaj, _mến_,
   {{0x672d0280,0x247780ff,0x6d5c0362,0x5f950012}},	//   paaj, _xăm_, _dbra, _динт,
   {{0x63a2acbf,0x6d5c53cd,0x644553ce,0x67c50110}},	//   gkon, _ebra, ruhi, kėji,
   {{0xe1f1803d,0x24518019,0xeb908eca,0x64452fda}},	//   وست_, zám_, عظم_, suhi,
   {{0xe3cf00c8,0x9f420009,0x64452723,0x67c50084}},	//   রতিব, _ehkä_, puhi, dėji,
   {{0xa3d9000f,0x319c00be,0x299c01c6,0x63a2d3cf}},	//   ़का_, רבונ, רסומ, bkon,
   {{0xee398fe7,0x2d98d3d0,0x6d5c070d,0x245185b9}},	//   ани_, ören_, _zbra, vám_,
   {{0xa3e2816f,0xbebb06a8,0x63a9d3d1,0xe293a105}},	//   _नीट_, _beëi, _ilen, _عذر_,
   {{0xdcf500eb,0x29058b67,0x2451826f,0x31348294}},	//   _nozī, _ugla_, tám_, _неур,
   {{0x63a9d3d2,0x7aed0314,0x63bb808e,0xdce381a1}},	//   _klen, _azat, _kmun, _manć,
   {{0xd8d6893f,0xf9890bea,0xe8d68158,0x22408253}},	//   _וועט_, _בר_, _ווער_, šike_,
   {{0x200253d3,0x79970122,0xddcd026c,0x63a9d3d4}},	//   _riki_, _boxw, zvaš, _mlen,
   {{0xd3780d38,0x63a9d3d5,0x64a581e2,0xdca58ff7}},	//   ść_, _llen, _мала, _мали,
   {{0x929d8063,0x63a28a21,0x200253d6,0x63a9d3d7}},	//   _ogło, ykon, _piki_, _olen,
   {{0x6b84031d,0xa2d5223e,0xec0980ff,0x9f4680ff}},	//   _unig, _युक्, _yến_, _khoá_,
   {{0x672bd3d8,0xe617017a,0x44278355,0x6603a88c}},	// [4040] _megj, жду_, _hwn_, _kink,
   {{0x200217fe,0x672bbb05,0x6603a04b,0x63bbd3d9}},	//   _wiki_, _legj, _jink, _amun,
   {{0x6603d3da,0x130a9d7b,0xb5fb04e8,0x63a9d3db}},	//   _mink, аней_, _spác, _blen,
   {{0x6603d3dc,0x6441832f,0x69dc53dd,0x65a008dc}},	//   _link, irli, lore, _möhi,
   {{0x63a2d3de,0xadeb10c5,0x644181ec,0x442780ee}},	//   rkon, _जीवन_, hrli, _lwn_,
   {{0x63a2d3df,0x660382a3,0x44278039,0x6d5c07c6}},	//   skon, _nink, _own_, _ubra,
   {{0x672bd3e0,0x6286905e,0xe5710158,0xbfaa9d20}},	//   _begj, _škod, _אַן_, итие_,
   {{0x2d9853e1,0xdfd08013,0x69dc53e2,0x3ebf012b}},	//   _hore_, عية_, hore, _žuti_,
   {{0x69dc0578,0x2d9853e3,0x7ae453e4,0x64418faf}},	//   kore, _kore_, _nyit, erli,
   {{0x929d8063,0x69dc00ab,0xdd9aa4dd,0x161f1199}},	//   _zgło, jore, рши_, मीटर_,
   {{0x2d9853e5,0x7ae4351d,0x6603d3e6,0xdb1d02be}},	//   _more_, _ayit, _dink, lisé,
   {{0x6603cb68,0x2d980295,0xb4ea8441,0x212c83ed}},	//   _eink, _lore_, _मरी_, _hedh_,
   {{0x6603811b,0xdb1d2593,0x64419384,0xdceb01f4}},	//   _fink, nisé, arli, _čiča,
   {{0xa184027e,0x200c84b9,0xbf9b03a7,0x66038084}},	//   мысл, _kudi_, _ciên, _gink,
   {{0x200c90e1,0x6568d3e7,0xa3bc816f,0x69cad3e8}},	//   _judi_, medh, ेचा_, infe,
   {{0x64488393,0x31678192,0x6603d3e9,0x656880f1}},	//   mudi, zenz_, _zink, ledh,
   {{0x69dc53ea,0x1ab40364,0x7bdd53eb,0x59bc800c}},	// [4050] bore, _объя, mosu, ्चार,
   {{0xd90489a7,0x386100b9,0xb5fb0032,0x2d9837cd}},	//   _لی_, _tphr_, _asár, _core_,
   {{0x2d9853ec,0x63a9b59f,0xdb008580,0x3319ca82}},	//   _dore_, _plen, _almà, біля_,
   {{0x98a30035,0x656880d7,0xdcee1f1c,0x00000000}},	//   gają_, hedh, _gabč, --,
   {{0x672bd3ed,0x7e7d2a9c,0x2d980b56,0x65689e5c}},	//   _regj, _ursp, _fore_, kedh,
   {{0x2d9802a5,0x6568820f,0x672b8125,0xa9698cae}},	//   _gore_, jedh, _segj, сика_,
   {{0x7e62d3ee,0x660381e2,0x6c54239f,0x3f99003a}},	//   _apop, _rink, _окру, _kosu_,
   {{0x69dc011f,0x63bbd3ef,0x2d9802a5,0x6603d3f0}},	//   zore, _umun, _zore_, _sink,
   {{0xdd918bca,0x69dc53f1,0xdb1d0661,0x65688c53}},	//   فوظ_, yore, cisé, fedh,
   {{0xc05b8cde,0x3f990e80,0x41b5845b,0x6568c787}},	//   _від_, _losu_, _عمار, gedh,
   {{0xbf9b0028,0x657553f2,0x6603d3f3,0xb0db016f}},	//   _riên, _mazh, _vink, _मुलग,
   {{0x6603cda1,0x7bdd53f4,0x320d80b9,0x3f9953f5}},	//   _wink, gosu, _kuey_, _nosu_,
   {{0x6603d3f6,0x213100dd,0x7bcbd3f7,0x6448d3f8}},	//   _tink, fazh_, ingu, audi,
   {{0x200c8a46,0xceb280be,0x7769cd9b,0x67e58661}},	//   _yudi_, _איד_, leex, dóji,
   {{0x03a61c74,0x69dc53f9,0x2d87d3fa,0xe7f8016f}},	//   _нико, rore, _inne_, ंगला_,
   {{0x3f8604c3,0x4c3a8039,0xdb1d0019,0xf43a8039}},	//   ñou_, _התקב, yisé, _התקש,
   {{0x69dc494f,0x7e6d00e4,0xa3d90035,0x00000000}},	// [4060] pore, gwap, ़कर_, --,
   {{0xc27b0f60,0xf27b012a,0x67c50084,0x3f8f007b}},	//   _פריי, _פריש, dėju, ögur_,
   {{0x2d98021e,0x399b03c8,0x999b0039,0x319b01c6}},	//   _vore_, _הייד, _הביט, _הבינ,
   {{0x200cd3fb,0x7bcb9217,0xdb1d332e,0x320d8661}},	//   _rudi_, gngu, tisé, _buey_,
   {{0x200c89a6,0x2d9853fc,0x6286b351,0x98a30035}},	//   _sudi_, _tore_, _škob, rają_,
   {{0xdb1d28d6,0x7bcbd3fd,0x672453fe,0xceb303de}},	//   risé, angu, lbij, _טיר_,
   {{0x64489613,0x7e62d3ff,0xb4eaa120,0x7bdd410a}},	//   xudi, _spop, _मरे_, yosu,
   {{0x442a02f7,0x27e200ee,0x69ca8115,0x200c8088}},	//   _iwb_, _jkkn_, snfe, _vudi_,
   {{0x7bdd005c,0x442a41a9,0x35f48767,0x6568d400}},	//   vosu, _hwb_, мпир, tedh,
   {{0x200ca588,0x64489883,0x44443bad,0x644300eb}},	//   _tudi_, tudi, or_, šnie,
   {{0x92e900c8,0xb0db12c7,0x6568ae9c,0xaac0816f}},	//   _বলে_, _मुंग, redh, _शेतक,
   {{0x444446ff,0x2d87d401,0x6448d402,0x68e9001b}},	//   ir_, _enne_, rudi, ředk,
   {{0x518746dd,0x444411e6,0x6448d403,0x3f990087}},	//   пува, hr_, sudi, _rosu_,
   {{0x3f995404,0x76445405,0xddcd009a,0x628081a1}},	//   _sosu_, driy, ztał, _mrmo,
   {{0xaf12819d,0x557783c8,0x444415f6,0x971a019d}},	//   _fụtụ, _מעגן_, jr_, _ọdụd,
   {{0x5f940676,0x94738013,0x213100f1,0x6280d406}},	//   нист, _أدوا, sazh_, _ormo,
   {{0x63ad5407,0x443800e7,0x7bc2d408,0x442a5409}},	// [4070] _ilan, _avr_, diou, _awb_,
   {{0x63ad01f6,0x645704b7,0x4444540a,0x7e6d0cda}},	//   _hlan, ttxi, fr_, rwap,
   {{0x63ad540b,0x6575020f,0x442a25b8,0xf9920039}},	//   _klan, _vazh, _cwb_, _סרט_,
   {{0x7988d40c,0xff2509d7,0x320581d6,0x61e183ed}},	//   _andw, _تبدی, _sily_, _skll,
   {{0x27e901e4,0xd25ba22c,0x1ee7004e,0x63ad540d}},	//   mlan_, сце_, _روسی_, _mlan,
   {{0x27e9540e,0x63ad540f,0xddcd0063,0x44445410}},	//   llan_, _llan, stał, br_,
   {{0x442a00fc,0x3205816b,0x7bcbd411,0x27e95412}},	//   _gwb_, _vily_, pngu, olan_,
   {{0xe6199b8b,0x22408390,0x27e916fb,0x79888365}},	//   оди_, šika_, nlan_, _endw,
   {{0x66070613,0x6d4a1727,0xc2c481a8,0x27e932b3}},	//   _kijk, ófag, _كيفي, ilan_,
   {{0x63ad5413,0x67240025,0x27e95414,0xd838007a}},	//   _alan, zbij, hlan_, šči_,
   {{0x442a10af,0x27e95415,0x69c3a808,0x673d15db}},	//   _xwb_, klan_, mine, _odsj,
   {{0x66070a0f,0xfc3f8efc,0x63ad5416,0x547a0039}},	//   _lijk, čí_, _clan, קטרו,
   {{0xeb970656,0x69c38c64,0x5f058048,0x6b8980dd}},	//   фия_, oine, _ўзла, _mneg,
   {{0x63ad5417,0xdcee0029,0x76445418,0x6b9b8e35}},	//   _elan, _labā, vriy, _loug,
   {{0x63ad04ce,0x661d2b47,0xc0e32bd4,0x672400f3}},	//   _flan, _atsk, ворк, tbij,
   {{0x6d4300ab,0xa3e60fcc,0x69c3d419,0x7644541a}},	//   ónan, _बीच_, hine, triy,
   {{0x69c3d41b,0x44443a08,0x6724541c,0x442a0282}},	// [4080] kine, wr_, rbij, _swb_,
   {{0x272c0104,0x27e9541d,0x44440a89,0x6ec204e5}},	//   ến_, alan_, tr_, _रेणु,
   {{0x4444541e,0x27e931bb,0xbc6a003d,0x442a01c0}},	//   ur_, blan_, تمان_, _qwb_,
   {{0x4444541f,0x76445420,0x27e901e4,0x29183734}},	//   rr_, priy, clan_, lcra_,
   {{0x7bc2d421,0x6b89808e,0x799a809a,0x27e05422}},	//   riou, _dneg, _potw, moin_,
   {{0x442a01e9,0x7bc2b2e3,0x644305e4,0x6b8993fe}},	//   _twb_, siou, ánic, _eneg,
   {{0xa3de2c17,0x660f5423,0xb4cc8740,0xec16003d}},	//   तका_, _zuck, _रखे_, _آورد,
   {{0x660701ed,0x6d5e09ff,0x27e007c5,0x69c3d424}},	//   _zijk, lfpa, noin_, aine,
   {{0xaf128135,0x6ac80e70,0xb5fb4a84,0x056aacab}},	//   _bụrụ, रपोर, _opál, ојни_,
   {{0x27e94ab8,0x68e901d0,0xdc3e016b,0x69ce090d}},	//   zlan_, ředi, _líče, jnbe,
   {{0x69dd81a8,0x27e95425,0x27e0062c,0x98a78493}},	//   _ísea, ylan_, koin_, rană_,
   {{0x69ce38bc,0xe717803d,0x61ead426,0xf0b780be}},	//   enbe, _قيمت_, llfl, _קלאר_,
   {{0x27e92c5c,0x672f01a1,0x5ede02f1,0x63ad01d6}},	//   vlan_, _recj, _कुल्_, _vlan,
   {{0xa4d4835f,0x44215427,0x63ad3abf,0x660f5428}},	//   _полі, yph_, _wlan, _ruck,
   {{0x2eed0024,0x27e90065,0xdb0b81df,0x660700f3}},	//   _šef_, tlan_, tigü, _rijk,
   {{0x69c3d429,0x63ad386a,0x2fc48609,0x660f542a}},	//   zine, _ulan, nimg_, _puck,
   {{0x2458d42b,0x35f50171,0x69c3cfc8,0x3ea4d42c}},	// [4090] lém_, епар, yine, nymt_,
   {{0x2d9c809f,0x6b898968,0xdce70035,0x660f0b80}},	//   _jove_, _sneg, _zaję, _vuck,
   {{0x27e901eb,0x645a8364,0x61e514ec,0xb4cc9344}},	//   plan_, ntti, _ikhl, _रखो_,
   {{0x2d9cd42d,0x660700f3,0x290c8420,0x645a8198}},	//   _love_, _wijk, _agda_, itti,
   {{0x201ea3b5,0x661d0b64,0xdcef8267,0x645a890d}},	//   _atti_, _utsk, _čeča, htti,
   {{0x68e88355,0x2458801b,0x69c38362,0x7bc08365}},	//   _bydd, kém_, uine, _emmu,
   {{0x3d1a053e,0xe739a1e2,0x64740198,0x201e8580}},	//   मुळे_, пей_, _игру, _ctti_,
   {{0x69c3afac,0x68e8831d,0xb4ab03b7,0x80be816f}},	//   sine, _dydd, गनी_, _वेळे,
   {{0x92ea00c8,0x645a8656,0x201e8214,0xb906d42e}},	//   _গল্প_, etti, _etti_, _यु_,
   {{0x68e8831d,0x2fcd831d,0x69c3d42f,0xdb0b816a}},	//   _fydd, sneg_, qine, pigó,
   {{0x64a58196,0x657881c0,0x69c1d430,0xdca59fb5}},	//   хана, _davh, _imle, хани,
   {{0xe3b2045a,0x7f848013,0x61e55431,0xdb04247a}},	//   ارد_, _للمن, _akhl, _aliá,
   {{0x645ad432,0x27e00198,0xda0f81cb,0x3ce60072}},	//   atti, voin_, ादित_, _जुने_,
   {{0xe9df008b,0x2018d433,0x6d435434,0x00000000}},	//   trúa_, _éric_, ónal, --,
   {{0xe3b200f7,0x69ce2e22,0x24588187,0x7bcf01c0}},	//   _مرة_, rnbe, cém_, bncu,
   {{0x2d9c8025,0x201e00eb,0xafe318a2,0xb90802f1}},	//   _zove_, īti_, госл, _बड_,
   {{0x7ae9c1f9,0x764d0388,0x7bc65435,0x0d8624f5}},	// [40a0] _nyet, guay, miku, нлан,
   {{0x7bc63119,0x27e002be,0x3f9d826b,0x2d9c81df}},	//   liku, soin_, _lowu_, _xove_,
   {{0x28df901b,0x31570158,0x0b46885f,0xe8990065}},	//   _पुलि, _איין_, енен, _ہمیں_,
   {{0x7ae98c2e,0x7bc65436,0x68e88b7f,0x224681e0}},	//   _byet, niku, _rydd, trok_,
   {{0x41e686b5,0x2458d437,0x68e897db,0xdb1d041c}},	//   ніка, zém_, _sydd, lisã,
   {{0xd8380353,0x7ae9d438,0x645ad439,0xdb1d29af}},	//   šču_, _dyet, ytti, visí,
   {{0x232a8139,0x7bc6322c,0xab2a813a,0x7ae99896}},	//   _нови_, kiku, _нова_, _eyet,
   {{0x2d9cd43a,0x6284263a,0x2458801b,0x224686a4}},	//   _sove_, _orio, vém_, prok_,
   {{0x7bc6543b,0x2d9c807a,0x765b8ce9,0x68e88114}},	//   diku, _pove_, gtuy, _wydd,
   {{0x2458d43c,0x98a78035,0x2ca58366,0x2b400db1}},	//   tém_, waną_, fyld_, _adic_,
   {{0x7bc6543d,0x6284543e,0x3a20543f,0x7792881b}},	//   fiku, _ario, _atip_, _میثا,
   {{0x62840224,0x2458d42b,0x7bc65440,0x645ad441}},	//   _brio, rém_, giku, rtti,
   {{0x62842630,0x27e6d442,0x645a8bbd,0x69da01d0}},	//   _crio, _ikon_, stti, čten,
   {{0x2244026f,0xddd98176,0x6578804a,0x049481a8}},	//   ámka_, _apwņ, _uavh, _للتح,
   {{0x62845443,0x28db12ee,0x7bc65444,0x2fc202f7}},	//   _erio, _मुखि, biku, _bmkg_,
   {{0x62845445,0x8d7700d7,0x17f801a8,0xddc405b2}},	//   _frio, کارا, فرقة_, ttiş,
   {{0x62845446,0x6b8d0079,0xe61300f7,0x78a10106}},	// [40b0] _grio, _inag, اشر_, älvb,
   {{0x6448d447,0x7c3ad448,0x201e023e,0xddc98b80}},	//   ordi, ostr, ític_, zvež,
   {{0x69c70668,0xdb1d03a7,0x7ae99c65,0x776d0118}},	//   mije, cisã, _syet, peax,
   {{0x69c75449,0x7ae9820f,0x53e1016f,0x7c3aa97a}},	//   lije, _pyet, नविश, istr,
   {{0xbf360051,0xdb0f07a3,0xfe088028,0x853c8084}},	//   _בארץ_, licó, _hữu_, rkėj,
   {{0x69c70025,0x7c3ad44a,0x27e6a651,0x64488699}},	//   nije, kstr, _akon_, krdi,
   {{0x7c3ad44b,0xa3e1052a,0x7ae982e6,0xbddb0176}},	//   jstr, थवा_, _wyet, _avèg,
   {{0x7c3ad44c,0x7c251106,0xa5bb0061,0xc6240264}},	//   dstr, mphr, _utób, _পিতা_,
   {{0x200b002e,0x7bc6544d,0x2a690282,0x69c7544e}},	//   _mici_, viku, _npab_, kije,
   {{0x0d829663,0x6b8d544f,0x200b0289,0x69c18c54}},	//   альн, _anag, _lici_, _umle,
   {{0x69c723c3,0x7c3aae3d,0x40358790,0x6448817f}},	//   dije, gstr, _реес, grdi,
   {{0x200b0012,0xdb1d0073,0x62845450,0x61e3d451}},	//   _nici_, visã, _prio, lonl,
   {{0x7bc60d7a,0x27ffd452,0x64489384,0xe29716fe}},	//   riku, mmun_, ardi, вая_,
   {{0x27edbfea,0x200b2ab0,0xa06a1597,0x69c70503}},	//   llen_, _aici_, мага_, gije,
   {{0xddd6003e,0x200b3500,0x29cd0858,0x6e3ba37b}},	//   jvyš, _bici_, džad_, lsub,
   {{0x62845453,0x6f1b810b,0x4425d454,0x6a86002e}},	//   _trio, ncuc, mpl_, _алиа,
   {{0x69c7003a,0x200b0b9a,0x27edd455,0x62841041}},	// [40c0] bije, _dici_, ilen_, _urio,
   {{0x27ed8352,0x69c7003a,0x75d300f7,0xca370039}},	//   hlen_, cije, ليقا, _שניה_,
   {{0x27ed813c,0x27ff80dd,0x61e3d456,0x44258176}},	//   klen_, kmun_, donl, npl_,
   {{0x61ee5457,0x27edd458,0xdb0f023e,0x8fa63edc}},	//   llbl, jlen_, licò, _раме,
   {{0x7c3ad459,0x63a984b7,0x86432d4c,0x27edd45a}},	//   zstr, _ċent, _княж, dlen_,
   {{0x27edd45b,0x61e3c336,0x7c3aabed,0x415380e8}},	//   elen_, gonl, ystr, ивіс,
   {{0x2eca83b6,0x660a86cb,0xddc98035,0x27edd45c}},	//   ाप्त, _rifk, steś, flen_,
   {{0x6448805c,0x27edc5b2,0x6729b240,0x65ad8144}},	//   vrdi, glen_, gbej, _búho,
   {{0xb8e988fd,0x6e3b8c27,0x657c545d,0x245c016b}},	//   _ले_, gsub, _karh, lím_,
   {{0x6b8d0025,0x7c3a8d35,0x657e015d,0x64488353}},	//   _snag, tstr, ndph, trdi,
   {{0x245c0a56,0x69c70582,0x63a0d45e,0xaefb026b}},	//   ním_, vije, _komn, _abùl,
   {{0xa3d5a8d7,0xd5b08077,0xd3a71541,0xa73a8f24}},	//   िचय_, _گفت_, троп, _آثار_,
   {{0xfe728bca,0xec0a0104,0x7af60063,0xf77304c0}},	//   _خدا_, _nếu_, _czyt, یار_,
   {{0x63a0d3e9,0x7c3ad45f,0x7bc405ee,0x6e2d9238}},	//   _lomn, pstr, _emiu, _çaba,
   {{0x69c7003a,0x6286c08c,0x245c026f,0x999980e1}},	//   rije, _škol, jím_, _ísť_,
   {{0x245c026f,0x657c013c,0x02a70705,0x63a081f6}},	//   dím_, _aarh, _аром, _nomn,
   {{0x291e80f2,0x69c71351,0x62828a0f,0x61e3861c}},	// [40d0] _ofta_, pije, jvoo, yonl,
   {{0x67298088,0x68ed801b,0xa5bb0032,0xdc4281d0}},	//   zbej, řadi, _awór, _léče,
   {{0x657c209c,0x63a0d460,0x61e3862c,0x62829151}},	//   _darh, _bomn, vonl, evoo,
   {{0x27ff077f,0x6e22d461,0x7a3881bc,0x764982c4}},	//   _òun_, _otob, _ụtar, yrey,
   {{0x63a091ec,0x657c0d8b,0xd945bb78,0x27ed9277}},	//   _domn, _farh, гели, vlen_,
   {{0xec0a0028,0x487994ed,0x245c016b,0x7f428661}},	//   _hết_, есия_, bím_, _adoq,
   {{0xec0a0104,0x61e3d462,0x27ed8065,0x245c027f}},	//   _kết_, ronl, tlen_, cím_,
   {{0x61e38019,0xec0a001c,0x869980a9,0x291ed463}},	//   sonl, _yếu_, етот_, _efta_,
   {{0x67298022,0x7aed0397,0x3ea923db,0x27edd464}},	//   rbej, _nyat, nyat_, rlen_,
   {{0x6e3bd465,0x27edd466,0x6f1b8144,0x764981b4}},	//   rsub, slen_, scuc, rrey,
   {{0x7535139a,0x6e3bd467,0x7aed41fd,0xc10481a8}},	//   _mezz, ssub, _ayat, _نوكي,
   {{0xc209073a,0xddcd003a,0x3ea90455,0x7aed1b25}},	//   _זה_, jvaž, kyat_, _byat,
   {{0xdcf40279,0x29cd08ae,0x7aed00b4,0x290a8118}},	//   _čača, džab_, _cyat, _ºbac_,
   {{0x06e580ab,0x9d55815b,0x3ea95468,0x99d600f7}},	//   _পৃথি, _صنعت, dyat_, اتحا,
   {{0x18675469,0x6443546a,0xa3e38bb8,0xa067546b}},	//   лари_, ánil, नका_, лара_,
   {{0x245c001b,0x645c8722,0x1fb50087,0xaefb026b}},	//   vím_, àrie, асур, _ibùj,
   {{0xa6860084,0x657c136e,0x3ea9546c,0x93fb007c}},	// [40e0] ылад, _parh, gyat_, _אלקי,
   {{0x245c03cb,0x63a0d46d,0x3ea08014,0xaf030087}},	//   tím_, _somn, _àite_, спул,
   {{0xe73a02ac,0x80a880c8,0xa0a616d9,0x63a089b3}},	//   _пен_, _কেন্, _санд, _pomn,
   {{0x65ad81ac,0x644a023e,0x245c546e,0x99990084}},	//   _súhl, àfiq, rím_, busų_,
   {{0x245c0775,0x4423020f,0x657c0a6e,0xa29485e9}},	//   sím_, _etj_, _tarh, ралі,
   {{0x62828b3c,0xfce63ba1,0x91e38198,0x3f8f8234}},	//   rvoo, _бого, боче, _angu_,
   {{0x98a70e78,0x628280bd,0xf1a9803d,0x6e22d46f}},	//   čića_, svoo, خانه_, _stob,
   {{0x6d43d470,0x7c3e20e5,0x3f805471,0x753505ee}},	//   _adna, mspr, ndiu_, _zezz,
   {{0xb5fb2f74,0x7c3e2e3d,0x2487802a,0x36d4983a}},	//   _spái, lspr, _arnm_, ропр,
   {{0x3f8fd472,0x7aed0314,0x660e0372,0xd90ec787}},	//   _engu_, _ryat, _jibk, _عیب_,
   {{0x7aed07d5,0xd7efb4d2,0x6d4301a8,0x628f96f0}},	//   _syat, _гу_, ónai, _àcor,
   {{0x3ea90086,0xce358061,0x2fc9022c,0x317e9fe7}},	//   yyat_, _چونک, xiag_, _hatz_,
   {{0x65949401,0xdcf500eb,0x3a2480b9,0x2fc68122}},	//   _валу, _mazā, _jtmp_, _imog_,
   {{0x7aed08b1,0xa5bb5473,0x7c3e0687,0x7002819d}},	//   _vyat, _atón, kspr, _ọcha,
   {{0xb76701e5,0xd48f88b0,0x351b83c8,0x3ea95474}},	//   лтай, _ур_, _אוונ, wyat_,
   {{0x443ed475,0x7c3e04fe,0x753a811e,0x64435476}},	//   mst_, dspr, latz, ánim,
   {{0x75350098,0x260d0279,0x69cad477,0xe81b85fc}},	// [40f0] _pezz, _džon_, kife, _पूना_,
   {{0x753a8102,0x44235478,0x443ed479,0x64430796}},	//   natz, _ptj_, ost_, šnim,
   {{0x443e8558,0x69cad47a,0xec0a001c,0x3ea90359}},	//   nst_, dife, _tết_, syat_,
   {{0x443ed47b,0x753ab125,0xdb0086c0,0x63af04e8}},	//   ist_, hatz, _komè, nkcn,
   {{0x753a811e,0x672d547c,0x2d8503a7,0x386c8118}},	//   katz, mbaj, _óleo_, _apdr_,
   {{0x644a1313,0x2169b24a,0x443ed47d,0x60258c07}},	//   áfic, тики_, kst_, адка,
   {{0x443ed47e,0xdb1d0125,0x753a8102,0xf77f0214}},	//   jst_, nnsó, datz, _kaç_,
   {{0x07a5d47f,0xc1d20e00,0xf77f0580,0x443e9f0f}},	//   раин, _सद्ग, _jaç_, dst_,
   {{0xee368b71,0x764d5480,0xdcf88353,0x9f5e8019}},	//   аны_, nray, _davč, _autó_,
   {{0x27e08805,0x7bcbd481,0x27338028,0x443ed482}},	//   čina_, ligu, ản_, fst_,
   {{0x443e888a,0xab2a134e,0x764d52c2,0x237f8282}},	//   gst_, кона_, hray, _kauj_,
   {{0x9991012b,0x7bcbd483,0xb4d59990,0x2d98816d}},	//   _čašu_, nigu, _सखी_, örer_,
   {{0x2d910586,0x237f8282,0xdb00d484,0xa2c0001b}},	//   _onze_, _mauj_, _comè, _लेख्,
   {{0x764d002a,0x7bcb833e,0xdb00ca40,0x237f8069}},	//   dray, higu, _domè, _lauj_,
   {{0x64430a20,0x52d1816f,0xaca40133,0x77640197}},	//   šnij, तपुस, _kwụr, tfix,
   {{0x673b8110,0x69cad485,0x788081d0,0x3f800162}},	//   nauj, zife, lává, udiu_,
   {{0x3f8025eb,0x22405486,0xd007163e,0x77b80118}},	// [4100] rdiu_, _uvik_, рете_, _níxe,
   {{0x7c3e0223,0x9d461194,0x77643a16,0x644e802a}},	//   tspr, режд, sfix, ábig,
   {{0x6289d487,0x63a45488,0x14c8003d,0x98a7801b}},	//   _areo, _koin, دهای_, raně_,
   {{0x7c3e105d,0x764d5489,0x753a811e,0x63a4548a}},	//   rspr, bray, zatz, _join,
   {{0x63a403d3,0x6289d48b,0x63b6548c,0x02068009}},	//   _moin, _creo, _mlyn, аздн,
   {{0x443eab33,0x63a4548d,0x77b8002a,0x7c3e213c}},	//   yst_, _loin, _díxe, pspr,
   {{0x64a6130f,0xb9c38013,0x7b96835f,0x8c43548e}},	//   _тава, تقوي, _краї, _мере,
   {{0x22498052,0x237f81c0,0x9634a312,0x27f2548f}},	//   šaka_, _gauj_, бниц, nlyn_,
   {{0x753a80d3,0xa3e397ba,0x62338073,0x443e8428}},	//   tatz, नकर_, _меѓу, wst_,
   {{0xcd069895,0xdb00d490,0x443e8a0f,0x550691c7}},	//   ични, _nomé, tst_, ична,
   {{0x753a80ad,0xdd9781e2,0x443ed491,0x200f86c0}},	//   ratz, ршы_, ust_, _figi_,
   {{0x63a45492,0x443ed493,0x753ad494,0x200fc4f8}},	//   _coin, rst_, satz, _gigi_,
   {{0x443e9722,0x753a8102,0xc6769459,0x63a45495}},	//   sst_, patz, _خطاب, _doin,
   {{0x463b8158,0x261a000f,0xdb00d496,0xf77f0457}},	//   _יעדע, _बढ़ी_, _comé, _saç_,
   {{0xdb00d497,0x63a400f7,0x63b60114,0xdcf50162}},	//   _domé, _foin, _flyn, _mază,
   {{0x63a40039,0x64431809,0x6d5c217a,0x57b412b2}},	//   _goin, šnik, _acra, обст,
   {{0x6b828144,0x2cac831d,0xdb008118,0x237fd498}},	// [4110] ddog, lydd_, _fomé, _rauj_,
   {{0xeb9f0bc5,0x717512c5,0x764d5499,0x2d9e8168}},	//   ljø_, _اهدا, rray, njte_,
   {{0x2ca7002e,0x2cac831d,0x237f8282,0x6fb500d7}},	//   ând_, nydd_, _pauj_, _همدا,
   {{0x77b83dce,0x96c20540,0x6d5c05f7,0x764d09c4}},	//   _píxe, _रेकॉ, _ecra, pray,
   {{0x6b80d49a,0x59bb09a9,0x673b8110,0x60db007e}},	//   _damg, _उतार, vauj, ğumu,
   {{0xc69200be,0x2cac816d,0x75388255,0x27e9549b}},	//   _זאך_, kydd_, _nevz, loan_,
   {{0x7bcb8077,0x673b80eb,0x237f822c,0x7880928a}},	//   pigu, tauj, _tauj_, vává,
   {{0x27e9549c,0x62898013,0x2cac8114,0x63ad82f1}},	//   noan_, _treo, dydd_, öand,
   {{0x63a4061f,0xddc2807a,0xe3b080f7,0x673badab}},	//   _roin, _spoš, _غرف_, rauj,
   {{0x63a4549d,0x2cac8114,0x7afbd49e,0x27e932b3}},	//   _soin, fydd_, _izut, hoan_,
   {{0x63b6003e,0x63a4549f,0x27e9011e,0xec0a001c}},	//   _plyn, _poin, koan_, _bếp_,
   {{0xe29a2c39,0x5f779a3e,0xdb00802a,0x645c823e}},	//   гам_, _خاطر, _somé, ària,
   {{0x6d471502,0x63a40a26,0x7981802f,0x27e9011b}},	//   _odja, _voin, _kalw, doan_,
   {{0xc6928039,0x6d470326,0x6fde81a9,0x2fcd800b}},	//   _מאד_, _ndja, rīce, lieg_,
   {{0x63a40009,0xb4e61344,0x3ead8019,0xddc2807a}},	//   _toin, _पडे_, lyet_, _upoš,
   {{0x27e954a0,0x79818247,0x4427d4a1,0x6441ab2e}},	//   goan_, _lalw, _itn_, msli,
   {{0x244393da,0x3ead8642,0x442781c0,0x8fa31ae7}},	// [4120] lım_, nyet_, _htn_, чате,
   {{0x6b80d4a2,0x8b08009a,0x7bc9a870,0x27f254a3}},	//   _samg, _cięż, _ameu, slyn_,
   {{0x244382bb,0x6441d4a4,0xb4b212e0,0x64a000ce}},	//   nım_, nsli, टने_, _ošiš,
   {{0x69ce54a5,0xec0a0028,0x80c100ab,0x4427d4a6}},	//   libe, _xếp_, _শুক্, _mtn_,
   {{0x7981bfd3,0xdb040362,0x2443a353,0xab658ec3}},	//   _balw, _pliù, hım_, daļā,
   {{0x09e398a0,0x64419247,0x24438214,0x6443a01d}},	//   почн, ksli, kım_, _ovni,
   {{0xe4da1125,0x588681bb,0x3f824560,0x7e64160c}},	//   _صورت_, сыла, _kaku_, ltip,
   {{0x244382bb,0x27e08353,0xf0930039,0x6441a315}},	//   dım_, čino_, לנו_, dsli,
   {{0x2cac8355,0x3f8254a7,0xa3d5ab28,0x26c054a8}},	//   wydd_, _maku_, िचर_, nzio_,
   {{0x3f820886,0x4427800e,0x27e9011b,0x7981ba1a}},	//   _laku_, _btn_, zoan_, _galw,
   {{0x6e2281bc,0x539900e8,0x644184dc,0x69ce0f3e}},	//   _dịọk, авня_, gsli, dibe,
   {{0x5f768875,0x3f8254a9,0x61e12296,0x2cac831d}},	//   _دائر, _naku_, पक्ष, rydd_,
   {{0x7981bb4d,0x644181b0,0x6443913b,0xcb033ef1}},	//   _yalw, asli, _evni, रेंड_,
   {{0x65948c9d,0x3d9482df,0x8b08001b,0x27e909c4}},	//   _факу, _фикр, _stří, woan_,
   {{0x3f8254aa,0x27e954ab,0x442692c5,0x201a421f}},	//   _baku_, toan_, _ارتف, _cupi_,
   {{0x1fa4067c,0xfd5901bc,0x7e7d00b9,0x9f5d8176}},	//   пруг, _febụ, _pssp, _chwè_,
   {{0x680a8063,0x3f82036e,0xdcfc01ac,0x7e6413d2}},	// [4130] _będz, _daku_, _darč, gtip,
   {{0x6d5ad4ac,0x7bcf5348,0x69ce54ad,0xbddb54ae}},	//   ngta, licu, cibe, _evèn,
   {{0x4427038e,0xa3ad0beb,0x6ad1824c,0xb5fb54af}},	//   ën_, _गवा_, तप्र, _spás,
   {{0x7bcf54b0,0x2d9c0106,0x7981d4b1,0x8264003d}},	//   nicu, över_, _salw, _بهین,
   {{0xe299917e,0x2443817b,0x69d8807b,0x3cea86a7}},	//   рал_, zım_, fnve, _घुसे_,
   {{0xa2cd853e,0x7bcf54b2,0x244383bf,0x3f8204b9}},	//   _देण्, hicu, yım_, _zaku_,
   {{0x6e2d157a,0xe1f09a3e,0x2fcd8192,0x7e62912e}},	//   lpab, رسه_, tieg_, _aqop,
   {{0x6d5acba6,0x69ce54b3,0x2d830423,0xce49a7ee}},	//   egta, zibe, _haje_, азие_,
   {{0xe6169006,0x69ce54b4,0x6e2d0144,0x6286d4b5}},	//   оды_, yibe, npab, _škov,
   {{0x644183a6,0x2d83011f,0x244383bf,0x442790e4}},	//   tsli, _jaje_, tım_, _ptn_,
   {{0x87e78153,0x3a290763,0xd469ca48,0x628d1b29}},	//   _люде, _atap_, шине_, _arao,
   {{0x244382bb,0x201a54b6,0x7c2d8da8,0xe6958872}},	//   rım_, _rupi_, _čard, _ولاد,
   {{0x29cd05f5,0x628d0083,0x24438214,0x6441d4b7}},	//   ržan_, _crao, sım_, ssli,
   {{0x63b880eb,0x6441a6be,0x628d0219,0x2d8354b8}},	//   īvni, psli, _drao, _naje_,
   {{0x3a2954b9,0x7bcf023b,0x673f0168,0xdcfc54ba}},	//   _etap_, bicu, faqj, _parč,
   {{0xa3be2a90,0x25fd8076,0x69ce54bb,0xa6db007b}},	//   _इति_, _रीती_, sibe, _meðf,
   {{0xf772812a,0x628d54bc,0x2d8354bd,0xdcfc007a}},	// [4140] וקן_, _grao, _baje_, _varč,
   {{0x6b840074,0x64570b6e,0xdd9207d2,0x26c0047f}},	//   _haig, fuxi, بوط_, rzio_,
   {{0x07a61056,0x7e6454be,0x6b9601e2,0x649a0aac}},	//   _данн, stip, _knyg, штар_,
   {{0x2ca7016d,0x77b8002a,0xcb6ad4bf,0x6d43008b}},	//   ända_, _fíxa, раде_, ónar,
   {{0x7e0301bc,0x00000000,0x00000000,0x00000000}},	//   ọsar, --, --, --,
   {{0x6b84032f,0x2d8308f2,0x7bcf54c0,0x236d8609}},	//   _laig, _gaje_, zicu, _ebej_,
   {{0x2d85d4c1,0x29cd026c,0x628f83a8,0xdb1d0106}},	//   ddle_, džal_, _ácon, mnsö,
   {{0x444454c2,0xca7696fe,0x753c4779,0x6b8454c3}},	//   ms_, _музы, _herz, _naig,
   {{0x764454c4,0x7bcf09c4,0xdb0d54c5,0xdb00816b}},	//   nsiy, vicu, _ilaç, _komí,
   {{0x63a2a42b,0x78a100f2,0x3f829c32,0x442a008e}},	//   ljon, älvk, žku_, _ktb_,
   {{0x6b8454c6,0x3a2900c9,0x753c54c7,0x3d058075}},	//   _baig, _stap_, _merz, हेले_,
   {{0x764454c8,0x63a2d05a,0x6b8454c9,0x628d54ca}},	//   ksiy, njon, _caig, _prao,
   {{0x7bcf4890,0xaac554cb,0x6b8454cc,0x9f49009f}},	//   ricu, _लेखक, _daig, llaç_,
   {{0x444454cd,0x29cd0052,0x7bcf0098,0x442c8122}},	//   ks_, ržao_, sicu, ppd_,
   {{0x44444d33,0x6b840ad0,0x97a7402c,0x2d8354ce}},	//   js_, _faig, орал, _raje_,
   {{0x62808503,0x09b78519,0x628d1997,0x2d8354cf}},	//   _osmo, _अत्य, _trao, _saje_,
   {{0x444454d0,0x753c434d,0x44380114,0xa6db007b}},	// [4150] es_, _berz, _awr_, _meðg,
   {{0x444454d1,0xc05b0a4c,0x6724044a,0xdb008825}},	//   fs_, _кім_, acij, _comí,
   {{0x444454d2,0x753c01ec,0x62808102,0xdb00aa8d}},	//   gs_, _derz, _asmo, _domí,
   {{0x207a0158,0x987a0158,0x2d83507c,0x307a00be}},	//   _פארא, _פארט, _waje_, _פארנ,
   {{0x444454d3,0x79850ad4,0xbf9a04de,0x442a011b}},	//   as_, _kahw, _הירש, _etb_,
   {{0xe7f90076,0x444454d4,0x200954d5,0xd83886c4}},	//   ंतवा_, bs_, lmai_, _bwč_,
   {{0x444454d6,0x6286842b,0x661d0b40,0xc5f20039}},	//   cs_, _škot, _husk, _נדל_,
   {{0xb4d71a42,0x6615011e,0x63a2809a,0x661d54d7}},	//   ापी_, _hizk, cjon, _kusk,
   {{0xe81b8fcc,0x63bbcc58,0xd14b87d2,0x661d54d8}},	//   _पूरा_, _ilun, _نشان_, _jusk,
   {{0x6b8454d9,0x6b9600f2,0x7bcd54da,0x63a9867f}},	//   _saig, _snyg, _amau, _hoen,
   {{0x6b840074,0x752501ec,0x98b800eb,0x20090019}},	//   _paig, ichz, karā_, kmai_,
   {{0x2d8384c4,0x644554db,0x63a98198,0x764401b4}},	//   žje_, ishi, _joen, ysiy,
   {{0xed4e891c,0x7985035a,0x63a981b0,0x64450723}},	//   _по_, _bahw, _moen, hshi,
   {{0x63a284b7,0x7c29001b,0x63bbd4dc,0x764403bf}},	//   zjon, _čern, _llun, vsiy,
   {{0x6d41bee8,0x63bbd4dd,0x6b8454de,0x63a28118}},	//   mala, _olun, _taig, yjon,
   {{0x6d41d4df,0x764454e0,0x444403ab,0x20094328}},	//   lala, tsiy, vs_, gmai_,
   {{0x444454e1,0x6615011e,0xe7370009,0x442a3958}},	// [4160] ws_, _bizk, яет_, _stb_,
   {{0x6d41843c,0x63bbd4e2,0x764454e3,0x44384d1d}},	//   nala, _alun, rsiy, _pwr_,
   {{0x444454e4,0x661d0379,0x753c54e5,0x76440201}},	//   us_, _eusk, _verz, ssiy,
   {{0xdb008012,0x6d41d4e6,0x161b823c,0x661d00a4}},	//   _româ, hala, नदार_, _fusk,
   {{0x444454e7,0x753c54e8,0x27edd4e9,0x63a9a47a}},	//   ss_, _terz, doen_, _doen,
   {{0x63a2d4ea,0x6d418763,0x61ee4b4f,0x63bb80fa}},	//   sjon, jala, nobl, _elun,
   {{0x6d41d4eb,0x2d980106,0x444454ec,0xa5bb026b}},	//   dala, _inre_, qs_, _atów,
   {{0x27ed811e,0xd6d9809a,0x7ae40118,0x6d5e0074}},	//   goen_, wała_, _oxit, lgpa,
   {{0x9f400019,0x7ae40168,0xa5bb0091,0x61ee286c}},	//   llió_, _nxit, _awóy, kobl,
   {{0x6d5e54ed,0xfe6f8829,0x61ee001b,0xf1b980fe}},	//   ngpa, ادي_, jobl, _puše_,
   {{0x7ae403a8,0x443889c4,0x3dbe00ab,0xb4b68105}},	//   _axit, èr_, _আদাল, छने_,
   {{0x79851a83,0x9f5d8032,0x78fb81c6,0xd6d9866f}},	//   _sahw, _diwó_, _פלאפ, sała_,
   {{0x6d41d4ee,0xa3be035a,0xe61f00ff,0x59b0864a}},	//   bala, _इतर_, _trôi_, _जकार,
   {{0x201ed4ef,0x291a00ee,0x644554f0,0xbf9b54f1}},	//   _kuti_, _cgpa_, yshi, _chên,
   {{0x661d54f2,0x7ae43c09,0x213ea651,0x66151142}},	//   _susk, _exit, _meth_, _rizk,
   {{0x657ad4f3,0x201ed4f4,0x213e8014,0x77b803a8}},	//   leth, _muti_, _leth_, _díxo,
   {{0x645aa1d6,0x25aa031d,0x644554f5,0xaefb026b}},	// [4170] luti, _bobl_, wshi, _abùr,
   {{0xd9048288,0x657a8234,0x64450234,0x77b801df}},	//   _می_, neth, tshi, _fíxo,
   {{0xdcfc0029,0x645ad4f6,0x63a9ba1a,0x63bbd4f7}},	//   _parā, nuti, _poen, _plun,
   {{0x6d41d4f8,0x657a805d,0x661d54f9,0x7bdd54fa}},	//   zala, heth, _tusk, nnsu,
   {{0x6d41d4fb,0x213e831d,0x6286d4fc,0x201e9be7}},	//   yala, _beth_, _škor, _auti_,
   {{0x63a985f8,0x644354fd,0x645a9473,0x29cd0267}},	//   _woen, ánis, kuti, džak_,
   {{0x27edcec9,0x6d41d4fe,0x201e8239,0x63a9837a}},	//   toen_, vala, _cuti_, _toen,
   {{0x6d41d4ff,0x645ad500,0x201ed35e,0x224909d1}},	//   wala, duti, _duti_, _ovak_,
   {{0x6d41d501,0x27edcec9,0x3867813c,0x3f869210}},	//   tala, roen_, stnr_, _daou_,
   {{0xe2908bbe,0x27edd502,0x645ad503,0x657ad504}},	//   _حذف_, soen_, futi, geth,
   {{0x645a8e01,0x7af60009,0x9f4b01d0,0xdb008174}},	//   guti, _syyt, _akcí_, _iomá,
   {{0x6d419397,0x333f83d3,0xd6ce80d5,0x60158110}},	//   sala, _jeux_, اقی_, _išmo,
   {{0x6d418e01,0x61ee5505,0x3f89031d,0xe1ff0333}},	//   pala, tobl, ddau_, rtón_,
   {{0x6d41ba0f,0xe1ff0511,0xe61f00e1,0x321f8144}},	//   qala, stón_, _osôb_, _muuy_,
   {{0xc7b8801c,0xdb008118,0x645ad506,0x7e69d507}},	//   _ttđt_, _momá, cuti, ltep,
   {{0xee3a4a82,0x3e6602be,0x9b46003d,0x7af60198}},	//   жна_, tôt_, _کنکو, _tyyt,
   {{0x7dc01f4d,0x2d87d508,0x25aa031d,0xa2cd8d86}},	// [4180] _löse, _kane_, _pobl_, _देल्,
   {{0x3f890355,0xfd12045a,0x27e08805,0x62840870}},	//   adau_, نجا_, čini_, _isio,
   {{0x2d87d509,0x93bd002e,0x3a2d86cb,0xdb1986c0}},	//   _mane_, mpăr, _atep_, viwò,
   {{0x333f82be,0x3e6600e7,0xf6260195,0x201ea6a3}},	//   _ceux_, pôt_, _одмо, _ruti_,
   {{0x333f83d3,0x657ad50a,0x25aa026c,0x213e8114}},	//   _deux_, yeth, _tobl_, _peth_,
   {{0x201e8c27,0x2d87cf8e,0x082a9508,0x3a2000b9}},	//   _puti_, _nane_, оции_, _muip_,
   {{0xdb00827f,0xab2a8d13,0x232a80e8,0x333f8036}},	//   _domá, _мова_, _мови_, _feux_,
   {{0x645ac0f5,0xf76f8124,0x657abc49,0xdb008722}},	//   vuti, لاً_, weth, _tomà,
   {{0x8e149b62,0x6e220013,0x2d87d50b,0xb4b6800d}},	//   ндиц, íobh, _bane_, छन्_,
   {{0x7bc2d50c,0x2d87d50d,0x645ad50e,0x65ad81d6}},	//   lhou, _cane_, tuti, _súhr,
   {{0xd7ef8193,0x62840009,0x333f80e7,0x657ad383}},	//   _ау_, _asio, _yeux_, reth,
   {{0x645ad50f,0x7bc283b2,0xdb042d84,0x657a8234}},	//   ruti, nhou, _aliñ, seth,
   {{0x6d4e0025,0xc33384de,0x7d1c02d4,0x6aa28118}},	//   _odba, כור_, _ogrs, nxof,
   {{0x79889142,0x2d8784b9,0x7d0304e8,0xdb1d03ca}},	//   _jadw, _gane_, ýnsk, lisü,
   {{0x798884b7,0x291880e1,0x7bc29699,0x2006d510}},	//   _madw, _úrad_, khou, _khoi_,
   {{0x80a00540,0x2d87d511,0x98a78503,0x7bc281ed}},	//   _ऑपरे, _zane_, žiću_, jhou,
   {{0x799aa468,0x28cf000d,0x443c8282,0x63ad0087}},	// [4190] _ontw, _हेरि, _hwv_, _ioan,
   {{0x8d771e7b,0x63ad001c,0x443c81c5,0x7bc2b4ec}},	//   بارا, _hoan, _kwv_, ehou,
   {{0x333f82be,0x6005a915,0xdb00d512,0x2d8700e1}},	//   _peux_, lóme, _romá, ľne_,
   {{0x799aa1c9,0x63ad1a01,0x2d875513,0x69d55514}},	//   _antw, _joan, žne_, lize,
   {{0x63ad0bb1,0x600585e4,0x333f82be,0xdb0085b9}},	//   _moan, nóme, _veux_, _pomá,
   {{0x69d55515,0x9f40007b,0xd6d98035,0xf1bf5516}},	//   nize, llið_, wało_, mpás_,
   {{0x6d45471d,0x79888079,0xc7b88115,0x6f028db1}},	//   maha, _dadw, _suđa_, _azoc,
   {{0xde888104,0x6d455517,0x7bc2a218,0x799ad518}},	//   _bị_, laha, chou, _entw,
   {{0x20190b20,0x2d87d519,0xdb0084e8,0x3eb99f04}},	//   _misi_, _pane_, _tomá, ást_,
   {{0x77b59313,0xde88b7a0,0x6d451f36,0x77bc862f}},	//   _máxi, _dị_, naha, _véxa,
   {{0x69c38083,0xf1b98bda,0x6f028caa,0xc5f204de}},	//   mhne, _guša_, _ezoc, רדי_,
   {{0x6d45551a,0xceb40201,0x2d8784b9,0xc7b8811f}},	//   haha, yyə_, _wane_, _tuđa_,
   {{0x6d450ec9,0x63ad551b,0xde88b7a0,0x2d878315}},	//   kaha, _doan, _gị_, _tane_,
   {{0x2019551c,0x443c8282,0x69d5130e,0xbed680be}},	//   _aisi_, _fwv_, gize, _אונז_,
   {{0x6d45551d,0x7dc002af,0xc0e30a42,0x2019551e}},	//   daha, _lösc, горк, _bisi_,
   {{0x67299d4e,0x66188bcf,0x200db880,0x93bd0162}},	//   ncej, _zivk, nmei_, spăr,
   {{0x6d45551f,0x7649d520,0x6284004f,0x60058144}},	// [41a0] faha, nsey, _usio, cóme,
   {{0x6b9bb6a1,0x69d537a8,0x443c822c,0x4d63098d}},	//   _anug, cize, _ywv_, лкув,
   {{0x19b7012a,0x7bc2d521,0x443c8282,0x69c381e4}},	//   _נפטר_, thou, _xwv_, dhne,
   {{0xbea619bb,0xd8d700be,0x79888114,0x753b0088}},	//   _замк, _טויט_, _sadw, _đuze,
   {{0x6d455522,0x7bc28b3c,0x2006831d,0xf1b9aa06}},	//   baha, rhou, _rhoi_, _suša_,
   {{0x6d450b20,0x28f895e3,0x7bc28848,0x69c3d523}},	//   caha, мель_, shou, ghne,
   {{0x27e05524,0xc5ec223e,0x64580187,0x6f028061}},	//   onin_, जकीय_, ávid, _szoc,
   {{0xb4ac0e18,0x2d8a5525,0x27e05526,0x645e32e9}},	//   गही_, _habe_, nnin_, mupi,
   {{0x7bc0d527,0x645e10d8,0x661894bd,0x69c38c5e}},	//   _ilmu, lupi, _pivk, bhne,
   {{0x69c3b27f,0xde888028,0x657e5528,0x62829c2b}},	//   chne, _vị_, neph, mwoo,
   {{0x61fc0713,0xa5bb0d38,0xa6db0125,0x81d600ab}},	//   dlrl, _któr, _meða, িকা_,
   {{0x2d8a5529,0xd5b88029,0x6282d52a,0x205583c7}},	//   _labe_, skā_, owoo, _штур,
   {{0x6d45552b,0x27e0269b,0x628283b2,0x2019552c}},	//   yaha, dnin_, nwoo, _risi_,
   {{0x27e08289,0x20192650,0x7afd8aa2,0x60058333}},	//   činu_, _sisi_, _øste, róme,
   {{0x7bc09010,0xf8073100,0x6d45552d,0x657e1aca}},	//   _olmu, ечан, vaha, deph,
   {{0x77b5cd67,0x6d45552e,0x27e0237b,0x645e552f}},	//   _páxi, waha, gnin_, dupi,
   {{0x2d8a5530,0x20191c3a,0x28c081a2,0x80d1064a}},	// [41b0] _babe_, _visi_, षैति, _डेरे,
   {{0x9ce71f23,0x2019023b,0x78a10106,0xa5bb026b}},	//   нцел, _wisi_, älvs, _atór,
   {{0x6d455531,0x2d8a011b,0x6e22a0a8,0xf99f8129}},	//   raha, _dabe_, _luob, _đè_,
   {{0x628280f3,0x6235d532,0x291e82c4,0x7f4287b6}},	//   fwoo, веду, _agta_, _neoq,
   {{0x628284df,0x6d455533,0x69c38c41,0xaab303b6}},	//   gwoo, paha, thne, ुनिक,
   {{0x2d8a011e,0x98b80084,0xe296964f,0x7e6d5534}},	//   _gabe_, sarą_, таш_, mtap,
   {{0x4425002e,0x69c3826c,0x3f8b5535,0xdcf88196}},	//   _îl_, rhne, _kacu_, _tavę,
   {{0x3f8b00fe,0x2d8a04b9,0x889c00be,0x02d280d4}},	//   _jacu_, _zabe_, לבוי, _देवभ,
   {{0x7e6d5536,0x44314c91,0x200d8087,0x26c9004f}},	//   ntap, _htz_, rmei_, nzao_,
   {{0x442301e9,0xdb008884,0xef1f5537,0x7649d538}},	//   _kuj_, _domä, _saül_, rsey,
   {{0x69c193af,0x27e00672,0x44235539,0x3947b560}},	//   _ille, ynin_, _juj_, mans_,
   {{0x3947d53a,0x4423553b,0x7d1a008b,0x2d9cc2f3}},	//   lans_, _muj_, _útse, _enve_,
   {{0xf4128158,0x44230282,0x7dc00338,0x2e47826b}},	//   יפט_, _luj_, _lösa, _dìfá_,
   {{0x3947d53c,0xaf0480e8,0xdb1b823e,0x65c7826b}},	//   nans_, _спіл, _lluï, _déhù,
   {{0xa06708d5,0xd9430b5b,0x442301c5,0xb21b013c}},	//   кара_, реси, _nuj_, tvær,
   {{0x2d8a0510,0x6d43d53d,0x3f8d8548,0x3f8b180c}},	//   _sabe_, _hena, ndeu_, _cacu_,
   {{0x6d43c963,0x27e0553e,0x321a003e,0x3947d53f}},	// [41c0] _kena, rnin_, _tipy_, kans_,
   {{0xa5bb1ba7,0x6d4384bf,0xb21b128d,0x3947d540}},	//   _stór, _jena, svær, jans_,
   {{0x6d439e92,0x3947d541,0x44235542,0x7afb8915}},	//   _mena, dans_, _cuj_, _ayut,
   {{0x62829afa,0x442301c0,0x657e5543,0x7c238706}},	//   twoo, _duj_, seph, _munr,
   {{0x3947d544,0x02d2800c,0xaad2801b,0x224db63c}},	//   fans_, _देशभ, _देशक, _cvek_,
   {{0x62829337,0x3f9d81bc,0x7afb833e,0x657e036a}},	//   rwoo, _anwu_, _dyut, qeph,
   {{0x64a3181d,0x8c431e58,0x25aed545,0x0443395a}},	//   _кара, _весе, _rofl_, _весн,
   {{0x69c181a3,0xd90d826a,0x77bc8118,0x62962f0f}},	//   _elle, سین_, _véxo, _oryo,
   {{0x6d43d546,0x661c5547,0x83fd0024,0x3947d548}},	//   _bena, _kirk, nuđe, bans_,
   {{0x6d43d549,0x68e9002e,0x661c554a,0x77b8002a}},	//   _cena, şedi, _jirk, _díxi,
   {{0x6d43d0c0,0x23b68006,0x3a24d54b,0x224d8267}},	//   _dena, _अकाद, _hump_, _zvek_,
   {{0xccf30051,0x629609c4,0x3a2480b9,0x69d8afac}},	//   יכת_, _bryo, _kump_, live,
   {{0xdfcf8624,0x7c2382f7,0x83fd190f,0x645d8084}},	//   _بين_, _eunr, juđe, ąsia,
   {{0x6d43d54c,0x7c2384be,0x720500f7,0x661c09e1}},	//   _gena, _funr, اوسم, _nirk,
   {{0x7e60a3a8,0x3f8b06cb,0x2fc20359,0x8a180087}},	//   lump, _pacu_, _blkg_, торс_,
   {{0xa5bb04c3,0x4423554d,0x645a8390,0x3947d54e}},	//   _atóp, _ruj_, mrti, zans_,
   {{0x39478247,0x69d884dc,0x387a0db1,0x2ceb02f1}},	// [41d0] yans_, kive, _eppr_, _जुड़ल_,
   {{0x7e6d3ef3,0x394782e6,0x6b8d554f,0x6d4382a6}},	//   rtap, xans_, _haag, _xena,
   {{0x3947a699,0x7e6d010a,0x6b8d2afd,0x7afb8e6d}},	//   vans_, stap, _kaag, _syut,
   {{0x83fd0668,0xa3cd8035,0x7e6d09c4,0x39478c53}},	//   buđe, षों_, ptap, wans_,
   {{0x6d48d550,0x3947d551,0xb5fd803e,0x7e60b8e0}},	//   kada, tans_, luše, jump,
   {{0x69d886be,0x4423377f,0xe81b83eb,0x6b8d00bd}},	//   give, _tuj_, _पूजा_, _laag,
   {{0x39478205,0x6adf0996,0x2369017f,0x2d815552}},	//   rans_, नपुर, _ocaj_, mehe_,
   {{0x6d43d553,0x3947d554,0x661c21fb,0x236901c5}},	//   _sena, sans_, _zirk, _ncaj_,
   {{0x224d8d11,0xe6198dea,0x3f8dacec,0x6d48d555}},	//   _uvek_, нди_, rdeu_, fada,
   {{0x7dc000f2,0xb5fd935a,0xddcd0035,0xceb200be}},	//   _lösn, kuše, jważ, ציי_,
   {{0x69c7020f,0xddc41c3f,0xa3c006a7,0x6b8d0365}},	//   dhje, ntiš, ंघल_, _baag,
   {{0x4e95806b,0x6d43d556,0xdb1b8722,0x62960e35}},	//   _مشتر, _wena, _lluí, _pryo,
   {{0x6d43b745,0xee2e8934,0x6d48d557,0xe1ff009a}},	//   _tena, _ын_, bada, ntów_,
   {{0x7bc6020f,0x27ffd558,0x2d81111b,0xa5948081}},	//   shku, llun_, jehe_, _връщ,
   {{0xc8b50084,0x6b8d5559,0x057489a7,0x50b51246}},	//   асты, _faag, _خاند, асту,
   {{0xe1ff009a,0x200b001b,0x69d8d55a,0x6b8d11c9}},	//   któw_, _chci_, zive, _gaag,
   {{0x661c1608,0xaf060470,0x764d0ce9,0x69d8d55b}},	// [41e0] _pirk, упал, gsay, yive,
   {{0x5986555c,0xf9921921,0x6b8d3007,0xdca60eef}},	//   _слоб, _طبخ_, _zaag, лази,
   {{0x661c05be,0x27e9d55d,0x3a2481e0,0x29cd02ce}},	//   _virk, čanj_, _sump_, ržat_,
   {{0x661c0352,0x4fa6165d,0x6d488510,0x926a91b3}},	//   _wirk, _симв, zada, ерка_,
   {{0x6d488be9,0xdb1bd55e,0x673b807a,0xbb3b0e82}},	//   yada, _fluí, dbuj, געני,
   {{0x7c29003e,0x7bc4009f,0xaca40135,0x644e026c}},	//   _červ, _lliu, _atụr, _tvbi,
   {{0x3945938d,0xa2db015c,0x6e26020d,0xfd690133}},	//   _dels_, _पेन्, _hukb, hapụ,
   {{0x69d8d55f,0x6005b132,0x6d48d560,0x57b48dc0}},	//   sive, tóma, wada, рбит,
   {{0x6d48d561,0xda040072,0x6b8d01b4,0x2bb98075}},	//   tada, ळतात_, _raag, _आवता,
   {{0x7bc45562,0x80ba00ab,0x6b82d563,0x6b8d5564}},	//   _aliu, _উইন্, leog, _saag,
   {{0x7e60d565,0x6b8d1341,0x6e2602c4,0x7bc45566}},	//   sump, _paag, _lukb, _bliu,
   {{0x764d02b8,0x7e60d567,0x629d802a,0x645acff6}},	//   ysay, pump, _ásoc, rrti,
   {{0x6d48d568,0x59b888fd,0x8f9b810f,0x7bc40706}},	//   pada, _अवार, _רידי, _dliu,
   {{0x6b8d5569,0x6d48d56a,0x645a807a,0x6b8282c4}},	//   _waag, qada, prti, heog,
   {{0x860791cc,0x6b8d02a3,0x4dfb8051,0xdb00840e}},	//   _حقوق_, _taag, _רפוא, _comú,
   {{0x69c700f1,0x764d00a4,0xb5fd85b9,0xdc9b8039}},	//   shje, tsay, ruše, _טיול,
   {{0x2d8ed56b,0xa3ea035a,0x6b82d268,0x141c0039}},	// [41f0] _kafe_, _मदत_, deog, _אוהב,
   {{0x996729e5,0x21671445,0x76428365,0xb8db00ab}},	//   _стил, _стиг, _mwoy, _আই_,
   {{0x80d300c8,0x2d81022e,0x628980b9,0xb6042361}},	//   _দুর্, rehe_, _sseo, сятк,
   {{0x6722a0fd,0x321e8176,0x39459a25,0xa1340019}},	//   _ngoj, _aity_, _sels_, _پریش,
   {{0x394587e2,0x216994d6,0xa969817c,0xfaa5a8fb}},	//   _pels_, вили_, вила_, рало,
   {{0x321ed56c,0x9f5200e7,0xa85589a5,0x98558284}},	//   _city_, voyé_, атиј, атиш,
   {{0xe1ff0063,0x24980118,0x7642d56d,0x394581a1}},	//   stów_, _grrm_, _awoy, _vels_,
   {{0x765bd56e,0x98a58087,0x9b898065,0x656a8229}},	//   truy, _află_, _جنرل_, _acfh,
   {{0x6d47059c,0x673b8216,0xdee59156,0xe3b08591}},	//   _keja, rbuj, ропи, _عرف_,
   {{0x6d470812,0x201d930c,0x7bc800eb,0x7e7d00b9}},	//   _jeja, _wiwi_, ījum, _mpsp,
   {{0xa3ea101c,0x7983d56f,0x9d2200ab,0x7bc40084}},	//   _मदद_, menw, _পড়ুন_, _pliu,
   {{0x6d475570,0x69c55571,0x7e7d3f7d,0x79838114}},	//   _leja, _alhe, _opsp, lenw,
   {{0x9814803f,0x75d58065,0xe5a5c060,0x6286090d}},	//   _ابلا, _پيغا, _вили, uwko,
   {{0x8cb58021,0x6d475572,0xed598779,0x3f8fd573}},	//   _всич, _neja, _рок_, _hagu_,
   {{0x7aed03a7,0x6e260122,0x7e7d01a9,0x59b89d6a}},	//   _exat, _sukb, _apsp, _अवसर,
   {{0xa0670003,0x6d5503d2,0x44278087,0x2fc90637}},	//   јата_, _adza, _iun_, ghag_,
   {{0x442793e1,0x6d475574,0x7983ab36,0x2d8e8300}},	// [4200] _hun_, _beja, kenw, _yafe_,
   {{0x4427d575,0x442000f6,0x399a093f,0x3f8fd576}},	//   _kun_, _hii_, _ייִד, _lagu_,
   {{0x6d475577,0x6b82ad83,0x44205578,0x03269260}},	//   _deja, teog, _kii_, аден,
   {{0x4427d579,0x69dc557a,0x3f8f90b5,0x4420026b}},	//   _mun_, lire, _nagu_, _jii_,
   {{0x4420557b,0x69dc00f7,0x83fd00ce,0x7983d57c}},	//   _mii_, oire, nuđa, fenw,
   {{0xe8549301,0x7983d57d,0x69dc557e,0x4427c396}},	//   منتد, genw, nire, _oun_,
   {{0xfce30c8e,0x25f517a3,0x4427b480,0x3f8f82c4}},	//   _доро, ्तरी_, _nun_, _bagu_,
   {{0x44200665,0x69dc557f,0x443a123c,0xf1b882a6}},	//   _nii_, hire, mpp_, _diġa_,
   {{0x4427d580,0x69dc5581,0x3f8f8359,0x317a826a}},	//   _aun_, kire, _dagu_, _لحاظ_,
   {{0x77bca018,0x4427c2a2,0x44205582,0x69dc5583}},	//   _méxi, _bun_, _aii_, jire,
   {{0x442787f4,0x2fc000c9,0x442010ab,0x77bcab1f}},	//   _cun_, kkig_, _bii_, _léxi,
   {{0x4427d584,0xe73a8dea,0x67228088,0xdcfe01a1}},	//   _dun_, _ред_, _ugoj, jepč,
   {{0x69dc3fe4,0x4427d585,0x9b580098,0x2fc6820d}},	//   fire, _eun_, шият_, _ilog_,
   {{0x69dc5586,0x645e0d2f,0x44278039,0x2fc90122}},	//   gire, krpi, _fun_, whag_,
   {{0x44278046,0x44200012,0x2ee880ab,0xed578dc7}},	//   _gun_, _fii_, _পরিষ, _тој_,
   {{0x6d4714e5,0x3f84d587,0x69dc1dd9,0x44205588}},	//   _seja, nemu_, aire, _gii_,
   {{0x6d471e92,0xd2510013,0x69dc5589,0x61f88289}},	// [4210] _peja, _عند_, bire, kovl,
   {{0x3f84822e,0x442782b8,0x7bdd558a,0x27070a3a}},	//   hemu_, _yun_, lisu, _शरीर_,
   {{0x44270104,0xe4750003,0x4420077f,0x3f84d58b}},	//   ên_, слењ, _yii_, kemu_,
   {{0x442008f1,0x0c242f7e,0x889a02f6,0x7c20d58c}},	//   _xii_, імін, _עברי, _cimr,
   {{0x3f8f8274,0x6d470661,0x3f8486b8,0x79838f67}},	//   _ragu_, _teja, demu_, tenw,
   {{0xb5fd812b,0x2b49381a,0x2fc682d5,0x61f8811f}},	//   kuša, _leac_, _alog_, govl,
   {{0x2fc68213,0x7bdd558d,0xb5fd80eb,0x3a2900dd}},	//   _blog_, kisu, juša, _luap_,
   {{0xdce18029,0x7c2080b9,0x071281bc,0x44278039}},	//   selī, _gimr, _gụkọ, _run_,
   {{0x26cd812b,0x2d910025,0xef198364,0x442010ab}},	//   uzeo_, _kaze_, ыми_, _rii_,
   {{0x44279a6e,0x44205578,0x69dc002a,0x69ca8799}},	//   _pun_, _sii_, xire, chfe,
   {{0x2d9102a0,0x85118035,0x3f8480c3,0x69fa80be}},	//   _maze_, डेंट_, bemu_, _עלעק,
   {{0x44279029,0x7bdd0deb,0x69dc558e,0x671b83eb}},	//   _vun_, gisu, wire, _पृथक_,
   {{0x4420558f,0x44278032,0x3a2902f7,0x69dc448e}},	//   _vii_, _wun_, _cuap_, tire,
   {{0x4427d590,0x77bc862f,0xa06a5591,0x44201532}},	//   _tun_, _réxi, лага_, _wii_,
   {{0x2d85d592,0xa3e7816f,0x69dc5157,0x44205593}},	//   mele_, यचा_, rire, _tii_,
   {{0x2d85d594,0x0b4601a1,0x2cb8816d,0x236d8282}},	//   lele_, _унин, ärde_, _ncej_,
   {{0xb8ff2774,0x2d915595,0xbb3b0158,0x63a45596}},	// [4220] _दे_, _baze_, _געפי, _inin,
   {{0x2d85b3e3,0x99860307,0x3f84c23b,0xa2b8864a}},	//   nele_, _الدو, zemu_, ्नस्,
   {{0x63a42cf6,0x2d911ca2,0xf1b9811f,0x46d9a7af}},	//   _knin, _daze_, _guši_, _बेसह,
   {{0x2d85d597,0xc7b8811f,0x6e2d01b4,0xdcfa8493}},	//   hele_, _tuđi_, bqab, letă,
   {{0x2d85d598,0x7e641b0d,0xaad28816,0x61f8807a}},	//   kele_, quip, _देखक, tovl,
   {{0x2d85d599,0x2fc6d59a,0xcaa580f7,0x2244016b}},	//   jele_, _slog_, تصمي, ámky_,
   {{0x2d85d59b,0x61f8d59c,0x3f84bf29,0xd010830f}},	//   dele_, rovl, temu_, ولت_,
   {{0x63b63e34,0x96348374,0x9a29027d,0x63a40c2e}},	//   _noyn, ониц, _lươn_, _nnin,
   {{0x7bdd0a8d,0xcf930039,0x61f88042,0xa37b03a7}},	//   visu, לטה_, povl, niõe,
   {{0x442a01c5,0x63a4559d,0xf9c4804e,0x7bc282c4}},	//   _kub_, _anin, _بحری, lkou,
   {{0x26c2844a,0x2937893f,0xfe6f8bca,0x3a2909da}},	//   ško_, _האבן_, ودی_, _suap_,
   {{0x2fc68042,0xf1b98289,0xdb0d007b,0x290ca7e9}},	//   _ulog_, _ruši_, _blað, _izda_,
   {{0x442a559e,0x2d85d59f,0x15fa0fea,0xadfa0d5d}},	//   _lub_, bele_, ्तार_, ्तान_,
   {{0xf2d38158,0x2d85d5a0,0x236d009a,0xb5fd826f}},	//   לער_, cele_, żej_, lušn,
   {{0x442a022c,0xeb9f006a,0x443855a1,0xcad2819d}},	//   _nub_, rløb_, _ntr_, dịmị,
   {{0x543b8158,0x7bdd0609,0x628d01a8,0x290c816b}},	//   _געהא, qisu, _tsao, _mzda_,
   {{0x442a55a2,0x6d4ad5a3,0x2d9100d2,0xa37b03a7}},	// [4230] _aub_, _kefa, _paze_, giõe,
   {{0x7c2ad5a4,0x6d4ad5a5,0xfbdf041c,0xcaae8264}},	//   _kufr, _jefa, liê_, কনাফ,
   {{0xb5fd8db7,0xd49b0196,0x7c2a8239,0x62808084}},	//   kušn, ыра_, _jufr, _apmo,
   {{0x442a55a6,0x2d85d5a7,0x69c8d5a8,0xf8a9803d}},	//   _dub_, zele_, _alde, یگاه_,
   {{0x2d85d5a9,0x957c809a,0x27e9335d,0xddc9826c}},	//   yele_, ciąg, mnan_, hteš,
   {{0x867a007c,0xddc281d0,0x957c8035,0x7c388390}},	//   _דרשו, _tvoř, niąd, _otvr,
   {{0x2d85d5aa,0x3dce80ab,0xd90e8019,0x27e902db}},	//   vele_, িচাল, ہیے_, onan_,
   {{0x27e955ab,0xdbf203bb,0x2d85c27a,0x6d58afac}},	//   nnan_, _přís, wele_, _adva,
   {{0x2d85d5ac,0x27e90590,0x6d4ad5ad,0x7c2a81ec}},	//   tele_, inan_, _befa, _aufr,
   {{0x6d4ad5ae,0x6e3b81a9,0xb5fd9809,0x79870314}},	//   _cefa, rpub, krše, jejw,
   {{0x6d4ad5af,0x6e3bd5b0,0x2d85d5b1,0x7bc99afa}},	//   _defa, spub, rele_, _kleu,
   {{0x2d85d5b2,0x645c83a7,0x6d589de0,0xe29a041c}},	//   sele_, ária, _edva, аам_,
   {{0xeb9709b4,0x7bdb826c,0x16090327,0x4a4355b3}},	//   ция_, _mmuu, वतार_, мняв,
   {{0x83fd005c,0x8c4598a0,0x38a0802e,0x6d4ad5b4}},	//   vrđe, _деке, _fără_, _gefa,
   {{0x6d41d5b5,0xab5b08c5,0xd83880ce,0x290c1235}},	//   mbla, mkün, _trče_, åda_,
   {{0x63a455b6,0x442a3f33,0x27e928b0,0x7c29026f}},	//   _unin, _rub_, gnan_, _čerp,
   {{0x3ebf8458,0x7c2a8398,0x6d41851e,0x443800ed}},	// [4240] nyut_, _zufr, obla, _str_,
   {{0x442a01c5,0x7c241572,0x6d4a81df,0x27e955b7}},	//   _pub_, _hiir, _xefa, anan_,
   {{0x7c2409f8,0x442a01c5,0x6e23d5b8,0x7bc980e7}},	//   _kiir, _qub_, _minb, _bleu,
   {{0x2d0a016f,0x130682eb,0x61fc0162,0x395a02c4}},	//   _वरील_, озем, lorl, _hdps_,
   {{0xc7b30bea,0x7c2410ab,0x6d41d5b9,0x27e00a5b}},	//   _חבר_, _miir, kbla, miin_,
   {{0x442a1393,0x1a9b0158,0x4a9b00be,0x61fc55ba}},	//   _tub_, יינע, יינג, norl,
   {{0xa9678fbb,0x7bc9d5bb,0x61edc544,0x6d4a9139}},	//   ција_, _fleu, éala, _refa,
   {{0x6d418e1b,0x6e2bbd54,0x27e055bc,0x7bc994cc}},	//   ebla, _bugb, niin_, _gleu,
   {{0x7c2a8b5a,0x61fc55bd,0x7e7655be,0x4424d5bf}},	//   _sufr, korl, ntyp, _iim_,
   {{0x27e002c1,0xb5fd80fe,0x6d41a86c,0xd5ba9cfb}},	//   hiin_, sušn, gbla, рси_,
   {{0x27e01e6b,0x69a7801b,0x4395151b,0x7c240079}},	//   kiin_, चारी, панс, _biir,
   {{0xb5fd803a,0x6d4a831d,0x6e2390f6,0x3e7450ee}},	//   vrše, _wefa, _einb, kät_,
   {{0x671685e8,0x4424d5c0,0x6d41d5c1,0x7c2455c2}},	//   देशक_, _mim_, bbla, _diir,
   {{0x4424d5c3,0x6d58d5c4,0x35f78077,0xdb008feb}},	//   _lim_, _udva, _ورود_, _homó,
   {{0x7c38803a,0x61fd87ca,0x7e7601e0,0x27e055c5}},	//   _utvr, _ísle, etyp, fiin_,
   {{0x4424c90a,0xc7b8825b,0x395a0197,0xd9c28264}},	//   _nim_, _tuđu_, _edps_, ্চিম,
   {{0x27e955c6,0x443ec494,0x7e7655c7,0x80dc0264}},	// [4250] rnan_, lpt_, gtyp, _মুদ্,
   {{0xd49b0012,0x7bc9837a,0x27e955c8,0x69ce2c22}},	//   ире_, _sleu, snan_, chbe,
   {{0x7bc9d5c9,0xc17201c6,0x98bc81d0,0x27e9306d}},	//   _pleu, _אחי_, ravě_, pnan_,
   {{0x442481c5,0x70fa0039,0x60fa0039,0x78fa0039}},	//   _cim_, _להתח, _להתק, _לפתו,
   {{0x4424d5ca,0x80d38063,0xe29984fa,0xbf3603c8}},	//   _dim_, _भेजे, сал_, _מארץ_,
   {{0x6e2bd5cb,0x76ba0051,0x2249004f,0x3f891a25}},	//   _rugb, _המשפ, _mwak_, leau_,
   {{0x4424d5cc,0x69c39412,0x671f03eb,0x443e81ed}},	//   _fim_, rkne, _मृतक_, jpt_,
   {{0x7bdbd5cd,0x3f890cf8,0xdb0081a8,0x443e80ee}},	//   _umuu, neau_, _comó, dpt_,
   {{0x6005840e,0x645cd5ce,0x61fc0214,0x72058019}},	//   nómi, árin, yorl, _فورم,
   {{0x4424b90a,0xd1b88060,0x7c2437d5,0xb5fda5ea}},	//   _zim_, _والا_, _siir, dršc,
   {{0x7c2401c2,0x442481e9,0x224955cf,0x6d41800b}},	//   _piir, _yim_, _awak_, rbla,
   {{0x6d41d5d0,0x44248069,0x6e2bd5d1,0x395a0088}},	//   sbla, _xim_, _tugb, _sdps_,
   {{0x74c300c8,0x3f8955d2,0x61fc19de,0x2905802a}},	//   ্পিউ, deau_, torl, _hyla_,
   {{0x3e74025d,0x8e0880e8,0xab5b0019,0xf1b9c94f}},	//   vät_, _днів_, lkül, _gušt_,
   {{0x27e00364,0x5502809a,0x61fc55d3,0x77bc81df}},	//   tiin_, _रुपए_, rorl, _téxt,
   {{0x3e7455d4,0x4abdd5d5,0x09b8ba60,0x7e7622c9}},	//   tät_, ्नाव, _अव्य, ttyp,
   {{0x4adb84e5,0x27e055d6,0x2905808e,0xc0768129}},	// [4260] _मेलव, riin_, _lyla_, _bướm_,
   {{0x4424d5d7,0x27e02e79,0x3e741a46,0x1a9b00be}},	//   _sim_, siin_, rät_, _פייע,
   {{0xa3e7816f,0x4424d5d8,0xc32a80f7,0x7e762bdf}},	//   यचं_, _pim_, مكان_, styp,
   {{0x7c2e8187,0x3f891f29,0x7bc655d9,0x27e00df6}},	//   íbri, ceau_, nkku, qiin_,
   {{0x442481e9,0x6d5c8019,0xd0568085,0xf1b0109b}},	//   _vim_, órak, əcək, ञापन,
   {{0x443ed5da,0x2905800d,0x1df78e5b,0x62840267}},	//   ypt_, _byla_, ुतोष_, _mpio,
   {{0x7dcb009a,0x6d5c55db,0xddcd0087,0xdb008035}},	//   yższ, _idra, staţ, _pomó,
   {{0x6d4e0590,0xf09304de,0x394cb7f7,0x672201a9}},	//   _heba, תנה_, _weds_, žoju,
   {{0x6d4e1e92,0x9f5f83a7,0x443e819d,0x69de55dc}},	//   _keba, cluí_, wpt_, _ompe,
   {{0x645c8003,0xddd6009a,0x7c2e55dd,0x60e7807b}},	//   ário, jwyż, _kubr, ármá,
   {{0x443e82af,0x6736009a,0x2249067f,0x9f530061}},	//   upt_, kcyj, _swak_, ődés_,
   {{0x6d4e1600,0x69de0cda,0x7e6455de,0x7c2e010c}},	//   _leba, _ampe, krip, _mubr,
   {{0x3f8955df,0x5fa99664,0xada68ff7,0xd7a98072}},	//   veau_, कारल, _надл, कारच,
   {{0x171b873a,0x6d4e1b87,0xddcd02a5,0x443ed5e0}},	//   _הודע, _neba, ktaš, ppt_,
   {{0x3cdc035a,0x3f890cf8,0x2905008b,0xa3be86ae}},	//   _गेले_, teau_, æla_, ेसा_,
   {{0x69de1a1a,0x6d5c031d,0xb5fd81f4,0x6d4e0f3e}},	//   _empe, _adra, mrša, _aeba,
   {{0x6d4e0dab,0x443cd5e1,0x3f891030,0x7dc002af}},	// [4270] _beba, _htv_, reau_, _lösu,
   {{0x20021ca8,0x3f8902be,0x7c2e0024,0x6d4e0333}},	//   _ekki_, seau_, _bubr, _ceba,
   {{0x7bcd55e2,0x7c2e02ba,0x3f8955e3,0x6d5c0428}},	//   _klau, _cubr, peau_, _ddra,
   {{0x7c2e1123,0xdfc680f7,0x2c750370,0x69c70163}},	//   _dubr, _شي_, råd_, lkje,
   {{0x7e6455e4,0xdb0d0187,0xd6844504,0x443c9d70}},	//   crip, _doaç, _пурп, _ltv_,
   {{0x6d4e4277,0x200955e5,0xb5fd8024,0x6458d5e6}},	//   _geba, llai_, krša, _ovvi,
   {{0x6d453b1c,0x7c2e008e,0xa6db007b,0x443cd5e7}},	//   mbha, _gubr, _veðu, _ntv_,
   {{0x6d5c4a41,0xee398847,0x6d450046,0x6d4e1f8a}},	//   _zdra, они_, lbha, _zeba,
   {{0x442e8943,0x6458d5e8,0xb904a78a,0x6b8bd5e9}},	//   _auf_, _avvi, _पे_, megg,
   {{0xa2b28063,0xf1a497a3,0x6b8b92af,0x6b960214}},	//   _आपत्, _गोपन, legg, _sayg,
   {{0x6284381a,0x7bcd52ff,0x63bb8247,0x61e3d5ea}},	//   _spio, _blau, _koun, minl,
   {{0xe72ed5eb,0xf77083f8,0x7dc000f2,0x63bb8247}},	//   _је_, _ماه_, _höst, _joun,
   {{0xe56ed5ec,0x63a98db7,0x27388028,0x27ff8247}},	//   _из_, _mnen, _ứng_, moun_,
   {{0x443cd5ed,0x7bcd03ac,0x6b8b8081,0x27ed81ec}},	//   _ftv_, _elau, hegg, lnen_,
   {{0x27edc585,0x957c809a,0x63a9cb2c,0xb5fd8699}},	//   onen_, siąc, _onen, hušk,
   {{0x6d4e045c,0x27edd5ee,0x63bba53a,0x7bcd50a1}},	//   _seba, nnen_, _noun, _glau,
   {{0x27edd5ef,0x22160171,0x61e383bf,0xe7df001b}},	// [4280] inen_, _офор, kinl, _नगरप,
   {{0x3f4c0028,0xb5fdaed5,0x27ed82af,0x7e6455f0}},	//   ếu_, dušk, hnen_, rrip,
   {{0x61e3d5f1,0x6441d5f2,0x6d5c81a8,0xeb9aa383}},	//   dinl, npli, órai, жие_,
   {{0x63bb8051,0x27ed8a0f,0xfe79800d,0xab838009}},	//   _coun, jnen_, ktů_, вушк,
   {{0x6d4e02ec,0xddcd01dd,0x27ff8176,0x63a980c3}},	//   _teba, staš, doun_, _dnen,
   {{0x27edd5f3,0x61e3807b,0xc0aa830f,0x7c2e55f4}},	//   enen_, ginl, قابل_, _tubr,
   {{0xdcfc0029,0x63bbd5f5,0xd7a9816f,0xf1b884b7}},	//   _varē, _foun, कांच, _jiġi_,
   {{0xb5fd8067,0x442e9705,0x27ed8e3b,0x443ca800}},	//   vrša, _ruf_, gnen_, _rtv_,
   {{0x2d9855f6,0x7dc0007b,0xf1b884b7,0x442eaa0a}},	//   _kare_, _föst, _liġi_, _suf_,
   {{0x7dc00459,0xaa43802e,0x89169ec9,0x2d9855f7}},	//   _göst, _рефл, _قبائ, _jare_,
   {{0x9cec0a49,0x7bcd55f8,0x2d98489a,0x61fd87ca}},	//   _করুন_, _plau, _mare_, _ísla,
   {{0x2d9855f9,0x443c80ff,0xaec696cf,0x626f09ab}},	//   _lare_, _vtv_, _обел, lɗoɗ,
   {{0x501b80be,0x2d980087,0x83fd0904,0xdcf500eb}},	//   _וואו, _oare_, nuđi, _pazī,
   {{0x7c668f24,0x7bcd00dd,0xc9841505,0x6b8b81ed}},	//   _قابل, _wlau, куси, zegg,
   {{0x2d8cd5fa,0x6e2701ed,0x69c7021e,0x26c48084}},	//   mede_, _rijb, rkje, lymo_,
   {{0x2d8cd5fb,0x2d9855fc,0x69c7035f,0x0cca801b}},	//   lede_, _aare_, skje, ानीम,
   {{0xd904803d,0x63a980dd,0x2d9817af,0x7dcd808b}},	// [4290] _چی_, _rnen, _bare_, _húsa,
   {{0x44290282,0x2d8cd5fd,0xaa88003d,0x2d980039}},	//   _hia_, nede_, _کنیم_, _care_,
   {{0x7dc000f2,0x442955fe,0x6d450083,0x5f05800d}},	//   _röst, _kia_, rbha, _हुन्_,
   {{0xe6670698,0x2d8ca014,0x26c48110,0xb5fd877b}},	//   _отго, hede_, kymo_, tušk,
   {{0x442955ff,0xa2af816f,0x6b8bd600,0x2d980ca9}},	//   _mia_, ंमध्, regg, _fare_,
   {{0x44295601,0x2d985602,0x2d8cd603,0x4095997d}},	//   _lia_, _gare_, jede_, ерит,
   {{0x63bb8247,0x44295604,0x3f995605,0x2d8cd606}},	//   _toun, _oia_, _kasu_, dede_,
   {{0x6441ab0e,0x44295607,0x27edd608,0xb4bd0c87}},	//   vpli, _nia_, unen_, ेनी_,
   {{0x3f990a73,0x2ec98e70,0x27edbede,0x27ffd609}},	//   _masu_, िनेत, rnen_, roun_,
   {{0x7c298e61,0xe93884c0,0xe6168d15,0x2d8cd60a}},	//   _hier, _قسمت_, нды_, gede_,
   {{0x4429560b,0x7c29d60c,0xfe79801b,0xf3e63ba1}},	//   _bia_, _kier, stů_, ежно,
   {{0x4429560d,0x6441890d,0x3f99560e,0xeb9a0a7c}},	//   _cia_, rpli, _nasu_, чим_,
   {{0x44293c4f,0x443110dd,0x2d8cd60f,0x6441d610}},	//   _dia_, _luz_, bede_, spli,
   {{0xf2d2893f,0x2d8cd611,0x3e798247,0x395e00e7}},	//   נעם_, cede_, mèt_, ûts_,
   {{0xf505835f,0x3f9904b9,0xb5fd80eb,0x3e7983ec}},	//   _язко, _basu_, juši, lèt_,
   {{0x44290104,0x2d985612,0x7c29d613,0x35c58105}},	//   _gia_, _sare_, _nier, _लकड़,
   {{0x9cec00c8,0x7dd2013c,0x3e798247,0x6b845614}},	// [42a0] _করেন_, _læse, nèt_, _ibig,
   {{0x44295615,0x22401600,0xf1b884b7,0x2b5f8087}},	//   _zia_, _itik_, _tiġi_, _aduc_,
   {{0x2d980370,0x224d83ac,0x3a3f8122,0x7c29d616}},	//   _vare_, _awek_, _atup_, _bier,
   {{0x7c29d617,0xe9f90104,0x2d985618,0x7e7bd619}},	//   _cier, _trả_, _ware_, ktup,
   {{0x2d98561a,0xb5fd803a,0xa2948d13,0x7c29ae18}},	//   _tare_, vršn, талі, _dier,
   {{0x98a58182,0xcb1300be,0x3f9904b9,0x7644561b}},	//   _adlı_, אלד_, _zasu_, mpiy,
   {{0x3ea03494,0x83fd011f,0x3f9900fc,0x7c298888}},	//   lvit_, suđi, _yasu_, _fier,
   {{0xdfd08013,0x26c48110,0xdb0083a8,0x2d8c820d}},	//   شيخ_, tymo_, _enmá, wede_,
   {{0xe1ff0feb,0xc6f8835f,0x66018370,0x2d8c8808}},	//   drón_, ьних_, folk, tede_,
   {{0x4429561c,0x998902a5,0x6b84561d,0xa3e3432e}},	//   _sia_, _staž_, _abig, फोन_,
   {{0xd7efa623,0x442900f6,0x2d8cd61e,0x22400247}},	//   _бу_, _pia_, rede_, _atik_,
   {{0x4444561f,0x87da8b76,0x2d8cd620,0x07da845b}},	//   ip_, _عباس_, sede_, _عذاب_,
   {{0x660182a3,0x51874ecc,0x3f992cb5,0x2d8cd621}},	//   bolk, нува, _rasu_, pede_,
   {{0x6aa413c2,0x80b503b6,0x6b8423f1,0x7dcd807b}},	//   _drif, _उपदे, _ebig, _húsn,
   {{0x22405622,0x3f995623,0x444450fe,0x44295624}},	//   _etik_, _pasu_, jp_, _tia_,
   {{0x645ad625,0x5f9410f8,0x44295626,0x2614816f}},	//   msti, лист, _uia_, _नीती_,
   {{0xb9081404,0x645c2eef,0x645ad627,0x63ad3eac}},	// [42b0] _मे_, _avri, lsti, _inan,
   {{0x3f9903c3,0x7c29d628,0xf41f0009,0x799a8314}},	//   _wasu_, _sier, lmä_, _natw,
   {{0x7c29a038,0xf1b884b7,0x3a3f942f,0x7e6d00dd}},	//   _pier, _jiġu_, _stup_, suap,
   {{0xeaec8b9f,0x6b9d55d8,0x7c298216,0xf8b61101}},	//   जपूत_, ndsg, _qier, _ספרי_,
   {{0x7c2986ee,0x2bb88013,0xa30f0327,0x645a8229}},	//   _vier, عامة_, _सरोज_, hsti,
   {{0xc0e58381,0x7c29d629,0xf41f0198,0x4431562a}},	//   колк, _wier, hmä_, _tuz_,
   {{0x7c29d62b,0x6601837a,0x645ad62c,0x83fd0669}},	//   _tier, volk, jsti, luđu,
   {{0x6445562d,0xdb238077,0x645a9277,0xf41f01ac}},	//   mphi, _موزی, dsti, jmä_,
   {{0x799a8d92,0x645ad62e,0x603180eb,0x3f8d8a53}},	//   _fatw, esti, _māmi, reeu_,
   {{0x63ad0077,0x3e798247,0x7e7bd62f,0x6b9b80e8}},	//   _anan, rèt_, rtup, _haug,
   {{0x6b9bc1ff,0xe1ff0511,0xcb6a0a42,0x22401791}},	//   _kaug, trón_, мане_, _stik_,
   {{0x6aa4466c,0xa3dc009a,0x798e5630,0x957c8035}},	//   _prif, णों_, webw, wnąt,
   {{0xe1ff3132,0x6ec492c8,0x3cf511be,0xdb1b9a25}},	//   rrón_, _متوق, ्थडे_, _boué,
   {{0xf505838d,0x63ad455b,0x200db42e,0x27e20101}},	//   _изло, _enan, llei_, _smkn_,
   {{0x1c11800f,0x44445631,0xdd921190,0x6e2d8037}},	//   ़ताल_, xp_, یور_, _èabb,
   {{0xa2b2853e,0x3ea0826c,0x6fde81a9,0x63ad0af8}},	//   _आपल्, _šiti_, tūci, _gnan,
   {{0x78a5013c,0x444400ee,0x35a68d86,0xd00702a4}},	// [42c0] _erhv, wp_, _कोड़, тете_,
   {{0x64a616be,0xdca61697,0x08c64f78,0x69d54a03}},	//   каза, кази, _абон, chze,
   {{0x4444388d,0x6b9bd632,0x9f4001a8,0x200dd633}},	//   up_, _baug, iniú_, klei_,
   {{0x3958009f,0xfdbd0540,0x799aaacb,0x9f4000f7}},	//   lars_, ोसॉफ, _satw, hniú_,
   {{0xdaba8077,0xe1ff0019,0x6b9ba67c,0x799a83ec}},	//   بهشت_, król_, _daug, _patw,
   {{0x39584e63,0x4444088b,0x645ad634,0x7e69d635}},	//   nars_, pp_, ysti, drep,
   {{0x645c02ce,0x55e31bf5,0x38c88180,0x7d030192}},	//   _uvri, _торб, عاتی_, ünst,
   {{0x28ba170c,0x2ca70366,0x27f25636,0x6fe7810c}},	//   _उपनि, ænde_, nnyn_, _rècè,
   {{0x7e69998d,0xb2268110,0x4b7b80be,0x645ad637}},	//   grep, _амал, _קאמו, wsti,
   {{0x2246d638,0x645a9c02,0x20e3816f,0x7bc085b0}},	//   mpok_, tsti, _केवळ_, _homu,
   {{0x5fa38076,0x81c900c8,0x1da6835a,0xc8ca803d}},	//   _खोवल, লোড_, _कोणत, _توان_,
   {{0xf74690ca,0x39530a76,0x7bc0c2d8,0x68fa8609}},	//   _редо, _sexs_, _jomu, _ixtd,
   {{0x200484b9,0x6b8f026c,0x7dc48362,0xe737c65d}},	//   momi_, recg, _bòst, _реч_,
   {{0x395803ab,0x3cfd86a7,0x63ad553d,0x2004b799}},	//   gars_, _रुके_, _wnan, lomi_,
   {{0xf80725d9,0xd90f003d,0x98c40198,0xcf9b0073}},	//   вчан, تید_, астл, мја_,
   {{0x2d9cd639,0x63ad02b8,0x2004d63a,0x2618058c}},	//   _have_, _unan, nomi_, _बीबी_,
   {{0xa3b685e8,0x2d9ca847,0x6d57563b,0xb4bd01a2}},	// [42d0] जान_, _kave_, taxa, ेन्_,
   {{0xab5d8063,0x6b9b81e2,0x2d9ea3dd,0x7c2d563c}},	//   _może, _saug, ndte_, _hiar,
   {{0x7c2d004f,0x6594563d,0x6d570be9,0x6b9bafec}},	//   _kiar, раху, raxa, _paug,
   {{0x80dc00c8,0x2d9cd63e,0xdb040317,0x7c2d0704}},	//   _মুক্, _lave_, _uniã, _jiar,
   {{0x7bc0d63f,0x20048612,0x7c2d5640,0x290c807e}},	//   _domu, domi_, _miar, _ayda_,
   {{0x3f86d641,0x2d9cd642,0x27e9360b,0x6b9bd643}},	//   _abou_, _nave_, lian_, _waug,
   {{0xe739b34f,0xdb0084b8,0x7642d644,0x7c2d011b}},	//   ней_, _anmä, _atoy, _oiar,
   {{0x7e69d645,0xccf20bea,0x7c3a02be,0xdb0081ac}},	//   trep, _הכל_, _étra, _pomô,
   {{0x5a348b88,0x200d9781,0x6d5507d5,0x51f982c7}},	//   _внут, rlei_, _keza, _знаю_,
   {{0x442dd646,0xef168196,0xb5fb026f,0x27e91adb}},	//   _hie_, ымы_, _uvád, hian_,
   {{0x27e93135,0x290c8355,0x6d555647,0x7c2d07d5}},	//   kian_, _gyda_, _meza, _biar,
   {{0x27e90812,0x442d81e2,0x7c2d4a7b,0x61e55648}},	//   jian_, _jie_, _ciar, _amhl,
   {{0x27e95649,0x442dd64a,0x6fd58511,0x660500dd}},	//   dian_, _mie_, _cáce, kohk,
   {{0x6d55564b,0x61e50706,0x2d9cd64c,0x69c19473}},	//   _neza, _cmhl, _gave_, _jole,
   {{0x69c1cab9,0x27e9564d,0xa3b6800f,0x660509ca}},	//   _mole, fian_, जाम_, dohk,
   {{0x442d9019,0xb8dc0d38,0x27e93135,0x7c2d0098}},	//   _nie_, _आप_, gian_, _giar,
   {{0x6d552f34,0xe61a05f1,0xa3d7a39d,0x7bc0971c}},	// [42e0] _beza, еда_, िसन_, _romu,
   {{0xb5fd8025,0x7c2d564e,0x2bcc150e,0x6d55564f}},	//   dršk, _ziar, ासका, _ceza,
   {{0x6d555650,0x27e912bf,0xdd5680be,0x2004923c}},	//   _deza, bian_, רבעט_, yomi_,
   {{0x9f060277,0x2d9c0301,0x7c3ed651,0x2ca78dc5}},	//   _موجو, žve_, _épre, _mrnd_,
   {{0x442d96a1,0x69c1d652,0x1603d653,0x6fca0038}},	//   _die_, _bole, रकार_, _rých,
   {{0x442d879f,0x6d555654,0x69ce1080,0x38a382d0}},	//   _eie_, _geza, nkbe, _bır_,
   {{0x69c1d655,0x442d8012,0x7bc0d656,0x799e0122}},	//   _dole, _fie_, _tomu, _mapw,
   {{0x09d111be,0xaa86003e,0x442dd657,0x2d9cd658}},	//   _हत्य, _zvýš, _gie_, _save_,
   {{0x6fca003e,0x7c2d0cb5,0x6e2e453c,0x7c229a27}},	//   _vých, _riar, _kibb, mmor,
   {{0x69c1d659,0x442dd65a,0x7c2d565b,0x2004b22c}},	//   _gole, _zie_, _siar, somi_,
   {{0x6fca01ac,0x442d81bc,0x645e565c,0x2db70e82}},	//   _tých, _yie_, nspi, אלין_,
   {{0x6e2e565d,0x69c1d65e,0xdce383bf,0xdb1b8118}},	//   _libb, _zole, _canı, _gluó,
   {{0x7c2d1eaa,0x644386a4,0xdce39014,0x27e6d65f}},	//   _viar, _etni, _danı, _imon_,
   {{0x69d88125,0xa3ab9990,0x27e95660,0x869b8039}},	//   nhve, _कोन_, wian_, _ניוז,
   {{0x69cc823c,0x248d003a,0x7c2d5661,0xdcfc00eb}},	//   _तकनी, _ćemo_, _tiar, _darī,
   {{0x645e5662,0x69ce1c2b,0x69c007b6,0x00000000}},	//   dspi, akbe, êmer, --,
   {{0x27e93135,0x5d550fbe,0xb5fd803a,0x442d8133}},	// [42f0] rian_, икат, pušt, _rie_,
   {{0x442dd663,0x6d5ad664,0x27e936a5,0x3eb98009}},	//   _sie_, nata, sian_, ästi_,
   {{0xdce382bb,0x27e95665,0xa115003d,0x628e011f}},	//   _yanı, pian_, _خودت, čnoš,
   {{0x6d5ad666,0xd4980071,0x69c1d667,0xdce38085}},	//   hata, ыру_, _sole, _xanı,
   {{0xe299b385,0x6d5ab335,0x69c1d668,0x442dd669}},	//   тал_, kata, _pole, _vie_,
   {{0x442d8df3,0x27e6d66a,0x6e2e1106,0x7c22d66b}},	//   _wie_, _amon_, _gibb, amor,
   {{0x442d95cb,0x69c1d66c,0x7d1c807b,0x7e6d03a6}},	//   _tie_, _vole, ýrsl, lrap,
   {{0x2d931139,0x166585c2,0x28b68f0f,0x225f8115}},	//   lexe_, авим, _अपरि, _tvuk_,
   {{0x6d5abc00,0x7e6d003d,0x78a88084,0x644f817f}},	//   fata, nrap, _erdv, ćcim,
   {{0x0d829a97,0xdce38214,0x2d931f29,0x629b80e4}},	//   ольн, _sanı, nexe_, _isuo,
   {{0x6fd58118,0x7e6d5475,0x67d59f2f,0x6b9f022b}},	//   _cácc, hrap, _кожу, _baqg,
   {{0x6aa9d66d,0xcc760039,0x6d5a82d5,0x7dcdd66e}},	//   _kref, סגרת_, aata, _kúsk,
   {{0x6d5a8a98,0x6b89d66f,0x7bdd0168,0xe72ec543}},	//   bata, _mbeg, ërua, _фе_,
   {{0x6d5a9b0a,0x64a59c56,0x6aa98010,0xb5fd95db}},	//   cata, _вака, _mref, krši,
   {{0xdce38459,0x7c22d670,0x90c31229,0x69ce1c2b}},	//   _tanı, ymor, обре, rkbe,
   {{0x3ead00d2,0x32079c71,0x6ed5850a,0x6aa981e8}},	//   _šeta_, hony_, मैथु, _oref,
   {{0x1b0d00c8,0x2b4d04c3,0x7e6d32d4,0x32078658}},	// [4300] সেবে_, ñece_, grap, kony_,
   {{0x83fd005c,0x2d859f5a,0x998c81a9,0x6b898deb}},	//   vrđi, nfle_, _vidū_, _abeg,
   {{0x6aa99286,0xd838812b,0x3ea98b80,0xc1010129}},	//   _aref, _trči_, _šatl_, _mượt_,
   {{0x6d5ad2da,0xc1010028,0x9f91877f,0x5aca8071}},	//   zata, _lượt_, _náà_, клем_,
   {{0x32078023,0x7e6d2651,0x6e2e342f,0x645e5671}},	//   fony_, crap, _tibb, sspi,
   {{0x20ba2a80,0x6aa98114,0xceb30039,0x64a63941}},	//   _उपाध, _dref, _ויש_, _кага,
   {{0xa3c62885,0x6d5ad672,0x02b4000d,0x61ead673}},	//   _एवं_, vata, ुहुन, rifl,
   {{0x6d5ab2fb,0x61ea9286,0xbfa78198,0x7bd981ec}},	//   wata, sifl, атье_, chwu,
   {{0x6d5ad674,0x44381918,0x3207d675,0xe2979908}},	//   tata, _hur_, bony_, _кат_,
   {{0x44385676,0x63a08687,0x61ed80f7,0x62828a53}},	//   _kur_, _hamn, éalt, mtoo,
   {{0xd49782ff,0x6d5a81bf,0x63a0d677,0x6282929d}},	//   аря_, rata, _kamn, ltoo,
   {{0x44385678,0x6d5ad679,0xc7c78198,0x63a0821e}},	//   _mur_, sata, _выше_, _jamn,
   {{0x6d5a80e4,0x44382023,0x63a081b4,0x3a741afd}},	//   pata, _lur_, _mamn, оляр,
   {{0xa2a78c78,0x4438004c,0x6d5ad67a,0x7e6d047f}},	//   चित्, _our_, qata, vrap,
   {{0x4438034a,0x19581c28,0x6d5880eb,0x2904007e}},	//   _nur_, расы_, _ieva, şman_,
   {{0x7e6d567b,0x63a28019,0x63a0d67c,0x25e29370}},	//   trap, jdon, _namn, टोरी_,
   {{0x44380b65,0x51870791,0xba3d801b,0x6d588074}},	// [4310] _aur_, _куна, _prům, _keva,
   {{0x7e6d567d,0x27058028,0x63a2847f,0x3207d67e}},	//   rrap, ồng_, edon, xony_,
   {{0x4438003c,0xd49b0098,0x3207826b,0x7e6d2337}},	//   _cur_, ъра_, vony_, srap,
   {{0x6d58b0df,0x2d93567f,0x5b2580f7,0x63a083ac}},	//   _leva, sexe_, مفضل, _camn,
   {{0x7cca8201,0xa3ab835a,0x69c55680,0x660883ac}},	//   lərd, _कोण_, _kohe, kodk,
   {{0xceb20159,0x7c38aeef,0x79951c5d,0x81c900ab}},	//   _זיך_, _ouvr, nezw, লোর_,
   {{0x4438061f,0x32078063,0xf09400be,0x6fca016b}},	//   _gur_, rony_, ַנץ_, _výcv,
   {{0x6aa9d681,0x6282d682,0xddcd0805,0x63a2c9d1}},	//   _tref, btoo, ntaž, cdon,
   {{0x4438034a,0x799520fd,0x7dcd807b,0x06098abe}},	//   _zur_, kezw, _húsi, лник_,
   {{0x58878a7f,0x6d5887d9,0x66088353,0x69c52cde}},	//   _выда, _ceva, godk, _nohe,
   {{0x6d58d683,0xc3290451,0xc101001c,0x63a0d684}},	//   _deva, _נו_, _vượt_, _yamn,
   {{0xe9f90028,0x69d703a8,0xeb9f1277,0xd83882d6}},	//   _trẻ_, _alxe, dløs_, _prčv_,
   {{0xed4e91c7,0x69c55685,0x27edaccc,0x87078198}},	//   _но_, _bohe, mien_, _тяже,
   {{0x6d58a468,0x69c507f1,0xd5b18872,0xed599c9b}},	//   _geva, _cohe, _رفع_, _сок_,
   {{0x7dd2013c,0x3f6a1950,0x27ed81ed,0x87db86a7}},	//   _sæso, ливо_, oien_, _बताऊ,
   {{0x6ab78996,0xafe305d3,0x44385686,0xd83880fe}},	//   _आपूर, посл, _rur_, _grču_,
   {{0x44381cb0,0x4420082e,0xef1a0a9f,0x75468019}},	// [4320] _sur_, _ihi_, ума_, _érzé,
   {{0x27edd687,0x63a0d688,0x7cca8085,0x62828069}},	//   hien_, _samn, bərd, vtoo,
   {{0x44200142,0x7dc00065,0xb8ed00c8,0x27edd689}},	//   _khi_, _kösz, _শে_, kien_,
   {{0x27ed8009,0x61ee011c,0x320a0a7a,0x6608b741}},	//   jien_, libl, loby_, zodk,
   {{0x27eda1dd,0x63a28bf9,0x63a0822c,0xdcfc0bcf}},	//   dien_, rdon, _vamn, _obrć,
   {{0x4438568a,0x61ee10cd,0x63a2d68b,0x27ed80f3}},	//   _tur_, nibl, sdon, eien_,
   {{0x44381afa,0x6d58a218,0x6d5e568c,0x62828ebc}},	//   _uur_, _reva, mapa, stoo,
   {{0x6d5e5517,0x27edb85d,0x4420001c,0x44321bca}},	//   lapa, gien_, _nhi_, _niy_,
   {{0x52b403bb,0x6d588eef,0x7c38b8c1,0x7cca8085}},	//   ुहोस, _peva, _suvr, zərd,
   {{0x6d5e568d,0x4420568e,0x61ee568f,0x27ed80f3}},	//   napa, _ahi_, jibl, aien_,
   {{0xab5d8063,0x183683f8,0x27edd690,0x320a0e04}},	//   _możn, _طراح, bien_, doby_,
   {{0x44205691,0x27ed90cd,0x6d5e1c1a,0x4426d692}},	//   _chi_, cien_, hapa, nmo_,
   {{0x6d5e2705,0x4432259e,0x6d58d693,0x44205694}},	//   kapa, _diy_, _teva, _dhi_,
   {{0x6abb00c8,0x61ee5695,0x44200133,0x69dc0739}},	//   উনলো, gibl, _ehi_, ghre,
   {{0x58d42a96,0x84468277,0x6d5e0867,0x2fc69d3e}},	//   порт, _اختل, dapa, _koog_,
   {{0x44200028,0x4426935a,0x36d50ada,0x2fc681b4}},	//   _ghi_, jmo_, ообр, _joog_,
   {{0xddcd1329,0x2fc6d696,0x69dc0c41,0xa3ce016f}},	// [4330] rtaž, _moog_, bhre, _शकत_,
   {{0x69dc5697,0x6d5e0461,0x27edb17a,0x7175003d}},	//   chre, gapa, zien_, _بهدا,
   {{0x2bdd86bf,0x23690353,0x9f350558,0x6d9e84b7}},	//   _मतदा, _kdaj_, _мені, _għaż,
   {{0xedb5901c,0x6d4186a5,0x649e84a8,0x2fc68069}},	//   _अच्छ, zcla, mšić, _noog_,
   {{0x6b8d5698,0x27edd699,0x6d5e21ce,0x7e7900be}},	//   _mbag, vien_, bapa, _דאָז,
   {{0x4426d69a,0x764d569b,0x7f5f4139,0x4a5c0e82}},	//   amo_, mpay, laqq, נדוו,
   {{0x27edb712,0x64ac9487,0xdb0d01df,0x3ea9569c}},	//   tien_, nđić, _moañ, lvat_,
   {{0x2369020f,0x2249059c,0x7a20016d,0x5fa38d86}},	//   _ndaj_, _otak_, möte, _खोखल,
   {{0x27edd69d,0xa3b69c6f,0xee3684d9,0x2fc68952}},	//   rien_, जार_, оны_, _doog_,
   {{0x44200a73,0x27edd69e,0x27080028,0x6b8d1eda}},	//   _shi_, sien_, ởng_, _abag,
   {{0x224954b9,0x6d41d69f,0x44200028,0x27edd6a0}},	//   _atak_, rcla, _phi_, pien_,
   {{0xab2a102f,0x442001c0,0x232a10ca,0x6a8601e5}},	//   иона_, _qhi_, иони_, олма,
   {{0x69dc38ac,0xadfb08fd,0x6d5e4157,0xfdfb073c}},	//   thre, ्वान_, yapa, ्वास_,
   {{0x6aad5670,0xb21b013c,0x7a20225f,0x44268110}},	//   _draf, stæn, köte, zmo_,
   {{0x44200104,0x4426d6a1,0x320a56a2,0x75e90201}},	//   _thi_, ymo_, roby_, _gözə,
   {{0xe7370364,0x6d5e2424,0x6b8d19ab,0x442001e4}},	//   жет_, wapa, _gbag, _uhi_,
   {{0x6e46015b,0x63a456a3,0x61ee06c0,0xe29a1073}},	// [4340] زنام, _iain, pibl, _тап_,
   {{0x63a456a4,0x23690353,0x05660110,0x604301bc}},	//   _hain, _zdaj_, івен, ọmat,
   {{0x63a456a5,0x6d5e56a6,0x3ea90009,0xa3b68f97}},	//   _kain, rapa, avat_, जाल_,
   {{0xddcd0087,0x63a42044,0xead2846d,0x2d8556a7}},	//   tuaţ, _jain, _fẹ́_, _ölen_,
   {{0x6d5e56a8,0x63a456a9,0x1a968875,0x62862e32}},	//   papa, _main, تجاج, ntko,
   {{0x442699c8,0xfce60847,0x63a456aa,0x7d068063}},	//   smo_, _дого, _lain, ększ,
   {{0x6d5c0029,0xa37b0073,0xfd078065,0xd4670009}},	//   _iera, lhõe, _آج_, _мире_,
   {{0x6d5c1705,0xef19809a,0xb4d6073c,0x6286119b}},	//   _hera, leży_, िनी_, ktko,
   {{0x6d5c16a7,0x7e6456ab,0xab5d8063,0x6fdc82be}},	//   _kera, nsip, _możl, _néce,
   {{0x7c3c1c41,0x6b8d0081,0x06cd00ab,0x5c748cec}},	//   _kurr, _sbag, _রেডি, плот,
   {{0x63a456ac,0x6d5c1599,0x29188ede,0x77668098}},	//   _bain, _mera, _ára_, _дълж,
   {{0x63a40ad7,0x7bc283d3,0x6d5c1c2b,0x69c880e8}},	//   _cain, njou, _lera, _hode,
   {{0x63a456ad,0x7c3c011e,0x6fe8809a,0x644856ae}},	//   _dain, _lurr, jści, _édif,
   {{0x6fdc82be,0xaca401bc,0x69c8d6af,0xdb0080e7}},	//   _déce, _atọr, _jode, _camé,
   {{0xe50286b7,0xdb00810c,0x628656b0,0x68e20326}},	//   _रुचि_, _damé, atko, _ƙoda,
   {{0x6d5c56b1,0x6b8d56b2,0x6fd80333,0x63a428bc}},	//   _aera, _ubag, _píca, _gain,
   {{0x6d5c2c0a,0x7c3c00ad,0x2249486e,0x443c81c5}},	// [4350] _bera, _aurr, _utak_, _huv_,
   {{0x63a456b3,0x443c946a,0x7c3c56b4,0x69c8d6b5}},	//   _zain, _kuv_, _burr, _node,
   {{0x6d5c088b,0x7c3c0051,0xd37180f7,0xa3b68a27}},	//   _dera, _curr, فها_, जां_,
   {{0xa3ab8063,0x69dad6b6,0x7c3c00f1,0x7f5f0609}},	//   _कोश_, _alte, _durr, qaqq,
   {{0x443cbf33,0x69c8d6b7,0x7d7712c8,0x29f68035}},	//   _luv_, _bode, _واسط, kład_,
   {{0xe570026a,0xfa780039,0xdb1b8187,0x1a9c00be}},	//   _لطف_, קעות_, _louç, יידע,
   {{0x69c8d6b8,0x443c8282,0xdd1c80e1,0x9878011f}},	//   _dode, _nuv_, yšši, ršće_,
   {{0x62860d38,0x6d4501e4,0x61c805fb,0x69dad6b9}},	//   ytko, lcha, _रक्ष, _elte,
   {{0x69c8d6ba,0x443c822c,0x7f5d56bb,0x6d451e73}},	//   _fode, _auv_, _mesq, ocha,
   {{0x6d5c37c9,0x6d4556bc,0x6fdc82be,0x69c8d6bd}},	//   _xera, ncha, _réce, _gode,
   {{0xcb09073a,0xb21b013c,0x2b408bc8,0x63a456be}},	//   _על_, rtæl, žice_, _pain,
   {{0x29040214,0x6d4535de,0xe29a1988,0x22841f04}},	//   şmak_, hcha, бам_, tök_,
   {{0x98a78182,0x63a456bf,0xeb970750,0x7dd302d0}},	//   manı_, _vain, чия_, _kısı,
   {{0x7dcd8118,0x63a456c0,0x6e35011f,0x7dd2005f}},	//   _cúst, _wain, _nizb, _væsk,
   {{0x228456c1,0x63a456c2,0x6e3d02af,0x7dd30214}},	//   sök_, _tain, _ausb, _mısı,
   {{0x6d5c04bf,0x63a40c41,0x7e6412a5,0xfbdf0187}},	//   _sera, _uain, tsip, chê_,
   {{0x6d5c1e92,0xdb00cd67,0x69cc8105,0x7c242cde}},	// [4360] _pera, _tamé, _तकली, _ihir,
   {{0x443c822c,0x7dcdb367,0x06c580ab,0x80ae80d4}},	//   _yuv_, _gúst, এনপি, ंटमे,
   {{0xc9530451,0x6d5c3139,0x31570158,0x7e6456c3}},	//   _אמת_, _vera, _מיין_, ssip,
   {{0xa3e68d38,0x6d450c64,0x69c88db7,0x7bc982be}},	//   यों_, acha, _sode, _coeu,
   {{0x6d4501c5,0x7bc28009,0x27e056c4,0x6fd581d0}},	//   bcha, rjou, mhin_, _václ,
   {{0x27e03097,0x7c3c541f,0xfd5901bc,0x7c2402c4}},	//   lhin_, _turr, _mgbụ, _lhir,
   {{0x6561d6c5,0x764b9adf,0x7c240286,0x5fe001a2}},	//   dalh, _atgy, _ohir, _नताल,
   {{0xdfd08013,0x27e056c6,0x79988247,0x2d9a56c7}},	//   ئية_, nhin_, sevw, lepe_,
   {{0x69c88364,0x27e00364,0x442482af,0xa3e6d6c8}},	//   _tode, ihin_, _ihm_, योः_,
   {{0x7c2429f3,0x69dad6c9,0x27ff2a06,0x443c8069}},	//   _ahir, _ulte, čuni_, _puv_,
   {{0x395ea468,0x443c810c,0xfd590135,0x3d0681ab}},	//   _iets_, _quv_, _agbụ, _सुखे_,
   {{0x395e8186,0x7dcdd6ca,0xdddb941f,0xddc98162}},	//   _hets_, _súst, rtuš, treţ,
   {{0x6561d6cb,0x6d4556cc,0x7c241a81,0x27e056cd}},	//   balh, ycha, _dhir, dhin_,
   {{0x2d9a56ce,0xa410001b,0x656199b1,0x398f861c}},	//   jepe_, ětší_, calh, cısı_,
   {{0x7f5d56cf,0x69d501ec,0x395ed6d0,0x27e001ec}},	//   _pesq, rkze, _mets_, fhin_,
   {{0x2d8c90f4,0x34fb8039,0x7c24383e,0x27e00acd}},	//   lfde_, _להוד, _ghir, ghin_,
   {{0x6d451a27,0x9f40007b,0xa3b682f1,0x69c38035}},	// [4370] tcha, rnið_, जाई_, yjne,
   {{0x6d4556d1,0x06140009,0xf1d1000d,0x4424b68b}},	//   ucha, едую, _सकिन, _ahm_,
   {{0xf8d1000f,0xd9182187,0x6d4534a1,0x244180ff}},	//   _हथिय, _нью_, rcha, _xóm_,
   {{0x27e006c0,0x6d4556d2,0xf1b88609,0x7a200106}},	//   chin_, scha, _anġ_, möta,
   {{0x398f8214,0x59d10ebf,0xe8108a0d,0x6e3d56d3}},	//   yısı_, _सकार, ावना_, _uusb,
   {{0x644a11b9,0x2d9a002e,0xe7d51c08,0x2d8c81ed}},	//   ífic, cepe_, _yığı, jfde_,
   {{0x395ed6d4,0x656183cd,0xf8928073,0x6e2d8037}},	//   _dets_, valh, вајќ, _èabi,
   {{0x656187fe,0x2a66a022,0x2d8c9384,0x7ddf841c}},	//   walh, bsob_, efde_, _mêse,
   {{0xc91a41d0,0x656180a9,0x395e8722,0x236d807a}},	//   _धर्म_, talh, _fets_, _idej_,
   {{0x7dcdd6d5,0x7c2456d6,0xddc98267,0x27e00168}},	//   _rúss, _shir, freš, zhin_,
   {{0x31630d11,0x6561d6d7,0x398f807e,0x601e8168}},	//   dajz_, ralh, rısı_, sëma,
   {{0x6fd815a0,0x6561c233,0x3078866e,0x2d8c9407}},	//   _cícl, salh, _رحمة_, afde_,
   {{0xe60e8a8e,0xbdf88065,0x656183a7,0x06cd00ab}},	//   _ад_, _کرنا_, palh, _রেসি,
   {{0x75e00065,0xc58e8028,0x2441cd63,0x2fdd8197}},	//   _köze, _hồng_, _tóm_, _hlwg_,
   {{0x27e056d8,0x7c2435cf,0x2fcb07f1,0x236d8af8}},	//   thin_, _thir, _bocg_, _odej_,
   {{0x6fdc88f9,0x442b56d9,0x6144846d,0x26c002f9}},	//   _kéca, cmc_, _kìló, txio_,
   {{0xb4d6001b,0x442488ae,0x27e056da,0x2fcb00e5}},	// [4380] िन्_, _rhm_, rhin_, _docg_,
   {{0x27e056db,0x270c8104,0x44248b99,0x7bc602a5}},	//   shin_, ớng_, _shm_, ljku,
   {{0xe73a0698,0x2d9a4068,0x4424d6dc,0x799c56dd}},	//   _мен_, repe_, _phm_, merw,
   {{0xd36f8013,0x799c56de,0x2d9a56df,0xc58e80ff}},	//   لهم_, lerw, sepe_, _nồng_,
   {{0xa3e30fd5,0xdb040118,0xaaa7001b,0xdb008176}},	//   फोट_, _baié, खिएक, _anmò,
   {{0x799c56e0,0xc3330039,0x9f468192,0x6aa40c93}},	//   nerw, דוד_, _bloß_, _msif,
   {{0x6b840253,0x3ea01384,0xc58e8129,0x2240554f}},	//   _ocig, lwit_, _bồng_, _luik_,
   {{0x6bda803d,0x466a823f,0x3eadb83a,0x7764023e}},	//   _بورس_, ором_, fvet_, naix,
   {{0xcebb8201,0x799c300e,0xe2469a3e,0x9634a626}},	//   _şərh_, kerw, _آخري, нниц,
   {{0x7dcd80c8,0xc6f784d9,0xb21b0125,0x6b840118}},	//   _búsq, ьных_, rtæk, _acig,
   {{0xdb0088f1,0x05770039,0x75e056e1,0x2b490118}},	//   _mamí, וגים_, _közb, _pfac_,
   {{0x69de31f1,0x22402dae,0x9f9c026b,0x444401b4}},	//   _alpe, _buik_, _bíí_, iq_,
   {{0xf7d7810f,0x51873b98,0xfd6500ff,0x753c0035}},	//   _קודש_, мува, _chuỗ, _ogrz,
   {{0xa3ab8df4,0xe7ea85b3,0x20148063,0xddc9976d}},	//   _कोई_, जोरा_, ścią_, preš,
   {{0x6aa40234,0xd6fb0264,0x86379101,0x874c01bc}},	//   _esif, _আরো_, _קרוב_, _ọdịg,
   {{0x5f940e97,0xdc2b003d,0x69de56e2,0x6fa9016f}},	//   кист, _بسته_, _elpe, _चोखं,
   {{0x644e0341,0xee3f0028,0x444404b7,0x799c56e3}},	// [4390] _atbi, _quý_, eq_, berw,
   {{0x645c0114,0x6b9d01ba,0x69d88bfd,0x39472828}},	//   _bwri, lesg, jkve, _üns_,
   {{0x7985010c,0x7764107f,0x61f503bf,0x7bcd011f}},	//   _ichw, baix, mizl, _koau,
   {{0x77644633,0xe8df801c,0x64410036,0x6b9d56e4}},	//   caix, _niềm_, _élim, nesg,
   {{0xdb00a6e2,0x3d0f05b3,0x444401b4,0xc58e80ff}},	//   _famí, _तुरे_, aq_, _rồng_,
   {{0x7ff58986,0x6fd584e8,0x92a9009a,0x27ff0796}},	//   کستا, _zách, _załó, čunu_,
   {{0x5fd305e8,0x44442218,0x2b40811a,0x2618064a}},	//   _सवाल, cq_, žica_, _बीटी_,
   {{0x01380bea,0xe3ca062f,0x799c18e3,0x6d4ac928}},	//   ורות_, _mañá_, zerw, _affa,
   {{0xf390001c,0x63bb9b0a,0xcdf5af84,0xddcd0162}},	//   _bảng_, _inun, ечны, craţ,
   {{0x7bdf56e5,0x644805db,0x2d8138ef,0x63a9d637}},	//   _alqu, _édic, nghe_, _haen,
   {{0x3ead8353,0x63a99eec,0x799c1457,0xf7709abb}},	//   svet_, _kaen, verw, _چاه_,
   {{0xff53845b,0x6d4ad6e6,0x1ac680ab,0x63a992bf}},	//   _شخص_, _effa, _শেয়া, _jaen,
   {{0x799c56e7,0x63a9d6e8,0x45d5a0e2,0x2bc793f5}},	//   terw, _maen, _подс, _रचना,
   {{0x63a98074,0x7bdf24fe,0x25a78144,0x2be203b7}},	//   _laen, _elqu, _uanl_, _पतवा,
   {{0x799c01d3,0xdb00d6e9,0x63bbd6ea,0x98aa080a}},	//   rerw, _ramí, _onun, tabı_,
   {{0x7dd2013c,0x27ff97ee,0x07a30a90,0x799c56eb}},	//   _læst, nnun_, ласн, serw,
   {{0xd7074d44,0x3f8056ec,0xdee32865,0xe810950e}},	// [43a0] енте_, rgiu_, готи, ावता_,
   {{0x7dd21103,0x9f5d819d,0xe61736a2,0xf0a58129}},	//   _næst, _akwü_, еду_, _đàng_,
   {{0x6fd58216,0xeb9a9da6,0x5ec80264,0x9f9503a6}},	//   _tách, зие_, _রেখে, _såå_,
   {{0x6fd5c36a,0x63a99193,0x6565477a,0x444456ed}},	//   _fáci, _caen, aahh, rq_,
   {{0xa3e690c5,0x7985031d,0xdbc70074,0x63a9d099}},	//   योग_, _ychw, _tööl, _daen,
   {{0xa8a691b3,0x644501c0,0x59c3064a,0x7bd98133}},	//   ерик, bqhi, शायर, akwu,
   {{0x6603433f,0x644e00f2,0xde033fe1,0x63a9bc19}},	//   _спра, _utbi, _спри, _faen,
   {{0xb4be142d,0x200047f8,0x69d8d6ee,0x61f500fe}},	//   ेही_, nnii_, skve, zizl,
   {{0x25aa0b67,0xd5b081a8,0x68050196,0x7dd256ef}},	//   _kabl_, لفة_, nėda, _fæst,
   {{0x7cca8086,0x7dd2013c,0x63a9d6f0,0x71eab0f6}},	//   bərl, _gæst, _zaen, _عفاف_,
   {{0x8afd801b,0xe8df80ff,0x67fb0198,0x63a98f84}},	//   _veře, _tiềm_, näjä, _yaen,
   {{0x7985034a,0x6b82d6f1,0xab5d81b9,0x982b8061}},	//   _schw, ngog, _pożi, _فتنہ_,
   {{0x6b9d56f2,0xf39000ff,0x70c901a2,0xdb1b87b6}},	//   resg, _tảng_, रह्ल, _anuê,
   {{0x6d4ad53d,0xdb040aae,0xd5b881a9,0xddcd0084}},	//   _uffa, _anió, rmās_, kraš,
   {{0x2d9ed6f3,0x3161026c,0x9f9c046d,0xc60c81cb}},	//   mete_, _vehz_, _bíà_, सकीय_,
   {{0x2d9ebd3e,0x61f5080a,0xe8df801c,0x656500dd}},	//   lete_, sizl, _hiểm_, wahh,
   {{0x442956f4,0xe8df8028,0xb8c806b7,0x6fd836e5}},	// [43b0] _iha_, _kiểm_, _खै_, _mích,
   {{0x26c7005c,0x63a9d6f5,0x3954001b,0xaa640098}},	//   ćno_, _saen, časí_, _стък,
   {{0xf1bf8028,0x6fd800f7,0x63a9d6f6,0x2d81383e}},	//   _đá_, _oích, _paen, rghe_,
   {{0xe8d6004c,0x2d9ed6f7,0x44290197,0x6fd5a68b}},	//   _יותר_, hete_, _jha_, _táci,
   {{0xfaa592b2,0x44292881,0x63a982f1,0xa3b686a7}},	//   тало, _mha_, _vaen, जाज_,
   {{0x4429003d,0x63a9d6f8,0x4b3800be,0xe9d881e2}},	//   _lha_, _waen, ׂראל_, нкі_,
   {{0x2d9ed6f9,0x442905b0,0x63a9d6fa,0x628bc494}},	//   dete_, _oha_, _taen, stgo,
   {{0x6fdc83d3,0x44292c72,0x7e698074,0x63bbd6fb}},	//   _déco, _nha_, tsep, _unun,
   {{0x6fdc9313,0x2d9ed6fc,0x7c29c0bb,0xdee58fc8}},	//   _técn, fete_, _iher, топи,
   {{0x442956fd,0x7e69c786,0x6fdc8866,0x7c3b8362}},	//   _aha_, rsep, _féco, _hiur,
   {{0x44290782,0x201200a4,0x3ea680eb,0x7c298c53}},	//   _bha_, yoyi_, _esot_, _kher,
   {{0x442956fe,0x3a3a008e,0x443b00b9,0xe73f00ff}},	//   _cha_, _sipp_, _ciq_, _ngõ_,
   {{0x442956ff,0x2d9ed700,0x76428326,0xaca3019d}},	//   _dha_, bete_, _guoy, faịd,
   {{0x2d9e803e,0xdb0086a5,0x7c3b8362,0x2fcfd701}},	//   cete_, _jamá, _liur, _hogg_,
   {{0x7c29d702,0x98b800eb,0xdb00bdf7,0xfce59cfd}},	//   _oher, mbrī_, _mamá, _шоко,
   {{0x64438012,0x44290870,0x20000087,0x65638257}},	//   _iuni, _gha_, unii_, _henh,
   {{0xee3a0676,0xa3d583bb,0x6443d703,0x36670098}},	// [43c0] дна_, ाउन_, _huni, като_,
   {{0x7a7b010f,0x67fb0364,0x2fcf835f,0x7c2980b4}},	//   _קריס, täjä, _logg_, _aher,
   {{0x7c3ba9d9,0x6443ad12,0x6fd80580,0xada32c39}},	//   _biur, _juni, _líci, рахл,
   {{0x7c29d704,0xdb040874,0x6fdcd705,0x6563d706}},	//   _cher, _unió, _réco, _lenh,
   {{0x64438b65,0x69dc0503,0x6fdc82be,0x2d9eb168}},	//   _luni, okre, _décl, yete_,
   {{0x6563d707,0x7c2993d2,0xddcd02d7,0x2d9e01d0}},	//   _nenh, _eher, praš, _úte_,
   {{0x6443d708,0x2ca70366,0xdb0081a8,0x75e002d0}},	//   _nuni, ændt_, _damá, _göza,
   {{0x7c3bd709,0x27e200b9,0xd6daa361,0x7c29d70a}},	//   _giur, _jlkn_, дто_, _gher,
   {{0xfaa3b3e5,0x6563b247,0x7d1d8085,0x644386c1}},	//   _като, _benh, əssi, _auni,
   {{0x4429507c,0x6443d70b,0x7c3bd70c,0xf77f02d0}},	//   _sha_, _buni, _ziur, _ilçe_,
   {{0xd82f8012,0x4429570d,0x7d7b0039,0x6e3c1d69}},	//   _вэ_, _pha_, וניו, _mirb,
   {{0x6443d70e,0x40ab8065,0x65638cfa,0xdb04002a}},	//   _duni, _زخمی_, _eenh, _aniñ,
   {{0xa3c9113d,0x80d000ab,0x44292474,0x6ab60428}},	//   लॉग_, _হেল্, _vha_, _cryf,
   {{0x4429570f,0xaca40133,0xc3338039,0xdb008118}},	//   _wha_, _ahọp, יור_, _xamá,
   {{0x44293e13,0x6568d13a,0x6443d710,0x629a0087}},	//   _tha_, madh, _guni, ătoa,
   {{0x6568803d,0x3f849295,0xaca40870,0xd7c5816f}},	//   ladh, ngmu_, _chọp, वायच,
   {{0x6e3c03bf,0x6ab65711,0x7c29808e,0x6443b46d}},	// [43d0] _birb, _gryf, _rher, _zuni,
   {{0xf41f4a44,0x7c29d712,0x3f730104,0x69dc1230}},	//   llä_, _sher, ệu_, ckre,
   {{0x6e3c01e2,0x63ad5713,0x61f8812b,0xdb1d0074}},	//   _dirb, _kaan, divl, rksõ,
   {{0x2d87009a,0x63ad10b5,0x6568d714,0x6e3c0706}},	//   żne_, _jaan, hadh, _eirb,
   {{0x7c3b809f,0xe3b0803d,0xdb0081d0,0x201900e4}},	//   _viur, ترل_, _pamá, _iksi_,
   {{0x7c298051,0x63ad5715,0x7d1c2c9f,0x6fd59f9e}},	//   _wher, _laan, _fyrs, _láct,
   {{0x7c29804c,0x3da40698,0x2edb801b,0x2610016f}},	//   _ther, _тряб, यन्त, तकरी_,
   {{0x6563d707,0x63ad5716,0xfe79801b,0x6443d717}},	//   _senh, _naan, trů_, _runi,
   {{0x6568822e,0xee398698,0x7e6d5718,0x6443d719}},	//   fadh, нни_, nsap, _suni,
   {{0x6568815b,0x7a248247,0x2b400118,0x6fd8041c}},	//   gadh, pòta, _sgic_, _víci,
   {{0x63ad571a,0x656383a7,0xa3df016f,0x66d9846d}},	//   _baan, _venh, णसं_, _bùkú,
   {{0xf1a90039,0x63ad0079,0x5bde064a,0x628f571b}},	//   _מס_, _caan, मसेव, ftco,
   {{0x656380a9,0x63ad571c,0x65688079,0x92f6102a}},	//   _tenh, _daan, badh, учні,
   {{0x201907c7,0x6443bf19,0x6fd5841c,0x7bdd571d}},	//   _aksi_, _tuni, _vácu, aksu,
   {{0xb21b006a,0xe0d500e8,0x27e20748,0x63ad01b4}},	//   kræf, ають, _plkn_, _faan,
   {{0x63ad571c,0x61f882a5,0x69dc48bd,0xdce701d0}},	//   _gaan, zivl, skre, ůměr,
   {{0x7e6d16fb,0x857a028b,0x628f0bfd,0x25a10192}},	// [43e0] gsap, есет_, ctco, fehl_,
   {{0xe058003d,0x2d85d71e,0x80b38105,0xcf2501a8}},	//   _لیست_, ngle_, ंटाइ, شرقي,
   {{0xb33b0073,0xf8a5819f,0x63ad3d74,0xe5f680be}},	//   meça, _بک_, _yaan, נזער_,
   {{0x80a1009a,0x8afd81d0,0xb5fb01d0,0xa4f40072}},	//   खबरे, _seřa, _svát, _आधीच_,
   {{0x9f4480f1,0x61f8d71f,0x6d5a81b4,0x7e6d0061}},	//   shmë_, tivl, ybta, csap,
   {{0x7e7bd720,0xf12680e8,0x9f52008b,0x6e3c0174}},	//   drup, льйо, ábær_, _uirb,
   {{0x20190009,0x61f8aa06,0xf41f0198,0x7c3a80e5}},	//   _yksi_, rivl, ylä_, _ètro,
   {{0x61d1146d,0xddcb826c,0x9f49008b,0x6568d721}},	//   _सक्ष, _ćiši, nnað_, wadh,
   {{0x7e7b92f1,0x23af0076,0x7bc0d722,0x628f0a2a}},	//   grup, _जोगद, _inmu, xtco,
   {{0x7cca82bf,0x63ad5723,0x211a80f7,0x35f49509}},	//   ləri, _saan, _كتاب_, рпор,
   {{0x63ad02b8,0x4d7b0158,0x6568cd8c,0x7c669e09}},	//   _paan, ערטע, radh, داخل,
   {{0x53350758,0x201f83a7,0x63ad0df6,0xf74694d6}},	//   иент, clui_, _qaan, _седо,
   {{0x656880d7,0x2d980722,0x63ad0848,0x764605ee}},	//   padh, _obre_, _vaan, _nuky,
   {{0x63ad36f5,0x7cca8085,0xe534812f,0x85568019}},	//   _waan, həri, _кель, _حیدر_,
   {{0x63ad5724,0x6fd585e4,0x6fd8009f,0xe919004a}},	//   _taan, _táct, _lícu, тові_,
   {{0x2d980510,0xb8860187,0x69c8048d,0x76460365}},	//   _abre_, _suíç, öder, _buky,
   {{0x311b8bb8,0x7c2d5725,0x35f516fc,0x6fc5816f}},	// [43f0] _पुनः_, _ihar, апар, वातं,
   {{0x6b898098,0x2d8a0197,0x7c2d0706,0x6f1d136f}},	//   _sceg, _ccbe_, _hhar, _vysc,
   {{0x8d7400a0,0x7c2d5726,0x7e6d5727,0x7cca8085}},	//   صالا, _khar, ssap, fəri,
   {{0x43959a11,0x2d985728,0x7c2d5729,0x63a2d72a}},	//   радс, _ebre_, _jhar, geon,
   {{0x27e91a2f,0x7c2d4e59,0xe8df801c,0x75e00019}},	//   mhan_, _mhar, _kiệm_, _közl,
   {{0x291e80f2,0x27e90cf4,0x02a301bc,0xf67a03c8}},	//   _byta_, lhan_, _gwụọ, _באשמ,
   {{0xc0e584fa,0x7c2d0102,0x2258807a,0x7e628032}},	//   ройк, _ohar, _črke_, _awop,
   {{0x27e9572b,0x201f8087,0xccf20496,0x3eb94c4c}},	//   nhan_, ului_, _וכל_, _krst_,
   {{0x442db7a0,0xda788098,0x6fdc8036,0xdce181a9}},	//   _ihe_, _бях_, _méch, dalā,
   {{0xdcf5084a,0x644700f6,0x67fe8029,0x443fd72c}},	//   _hazı, _kuji, dīju, _hiu_,
   {{0x7c2d09c5,0x443fd72d,0x69c1d72e,0xa5098ae7}},	//   _bhar, _kiu_, _inle, тена_,
   {{0x7c2d347d,0x64470010,0x443f872a,0x6d5c9434}},	//   _char, _muji, _jiu_, ðrar,
   {{0xed4ed72f,0x1615146d,0xe9ff8028,0x7c2d3f80}},	//   _мо_, तकार_, _luận_, _dhar,
   {{0xd9e583b7,0xdcf51010,0x2fcd803a,0x442d8073}},	//   कसित_, _lazı, ljeg_, _lhe_,
   {{0xb33b07e0,0x7a2002af,0x7c2d0c49,0x0596803d}},	//   reça, nöti, _fhar, _خانگ,
   {{0x7c2d5730,0x27e91341,0x2fcd8024,0x290c04b7}},	//   _ghar, ghan_, njeg_, ħda_,

   {{0x056612b2,0x8d660009,0x6567311a,0x63a281e0}},	// [4400] иван, ивае, _bejh, veon,
   {{0x75e01010,0x957c809a,0xdb0401df,0x443f8706}},	//   _gözl, wiąz, _gaiá, _aiu_,
   {{0x3eb902af,0x0b46a373,0xb97b0051,0x7663001b}},	//   _erst_, анен, _בניי, _čtyř,
   {{0x442dd731,0x27e95732,0x9f060bca,0x61fc05c5}},	//   _che_, chan_, _نوجو, lirl,
   {{0x442d9674,0x443f809f,0x63a281a8,0x31c68098}},	//   _dhe_, _diu_, reon, искв,
   {{0x27e000a4,0x63a2d733,0xc5690065,0xed574d44}},	//   lkin_, seon, _محفل_, _вор_,
   {{0x443fb570,0x67fe80eb,0xb5fb03f2,0x9965804a}},	//   _fiu_, zīju, _tvár, стіл,
   {{0x27e05734,0xd90d95e4,0x442dd735,0x443fd736}},	//   nkin_, رین_, _ghe_, _giu_,
   {{0x28a68b9f,0x61fc0059,0x41aa82d3,0x27e05737}},	//   _कैरि, kirl, _иван_, ikin_,
   {{0x7c22d738,0x7c2d5739,0xd9439537,0x6447008e}},	//   llor, _shar, _дефи, _yuji,
   {{0xdcf50afe,0x27e0573a,0xc8ca815b,0x61fc34f5}},	//   _yazı, kkin_, _جوان_, dirl,
   {{0x75e00459,0x67fe8029,0x6440a221,0xdb040118}},	//   _sözl, tīju, _jimi, _saiá,
   {{0x64408a0d,0x27e00267,0x61fc573b,0x2909807e}},	//   _mimi, dkin_, firl, şaat_,
   {{0x3d0f01fe,0xd9f8d73c,0x27e00102,0x661c0267}},	//   _तुझे_, ्चित_, ekin_, _nkrk,
   {{0x27e9573d,0x98480021,0x6c848013,0x7c2d573e}},	//   than_, ията_, _العم, _thar,
   {{0x6440d73f,0x7c2d5740,0x27e04689,0x645a90b6}},	//   _nimi, _uhar, gkin_, mpti,
   {{0x3218222f,0x443fd741,0xb33b03a7,0x06cd00ab}},	// [4410] bory_, _riu_, meço, _রেজি,
   {{0x6fdccb0c,0x442d8051,0x27e95742,0x61fc5743}},	//   _déci, _she_, shan_, cirl,
   {{0xf8b10288,0x443f8098,0x33180117,0xe9ff801c}},	//   _عکس_, _piu_, _مزید_, _quận_,
   {{0x1b1080c8,0x98a10028,0x644724a7,0x442d822c}},	//   ়েছে_, _nghĩ_, _vuji, _qhe_,
   {{0x443fa89e,0x6fd805dc,0xfaa78c40,0xe2998087}},	//   _viu_, _víct, ршен, уал_,
   {{0xa2580051,0x64475744,0x22490359,0x27e6c9a9}},	//   סבוק_, _tuji, _muak_, _alon_,
   {{0x442dd745,0x78ba84c3,0x6ce4035f,0x224929cf}},	//   _the_, _crtv, _діте, _luak_,
   {{0x61fc0201,0x32180831,0x6440d746,0x3f895747}},	//   zirl, zory_, _gimi, ngau_,
   {{0xe6199073,0x61fc08c5,0xa159818b,0xfe7181a8}},	//   лди_, yirl, _базу_, أدب_,
   {{0x3f538032,0x27e0011e,0x6440922e,0x3f7780ff}},	//   ṣu_, zkin_, _zimi, ểu_,
   {{0x3ea9010b,0x3218026f,0x6440d748,0x80d700ab}},	//   hwat_, vory_, _yimi, _ডেস্,
   {{0x3ea934c9,0x224929cf,0x98648061,0x644082ed}},	//   kwat_, _buak_, _بیٹے_, _ximi,
   {{0x78ba82a5,0x61fc5749,0x13a8003d,0x224900ee}},	//   _zrtv, tirl, هنگی_, _cuak_,
   {{0x6d43809c,0x6fdc80e7,0x765b95d7,0xdddb81b9}},	//   _ugna, _réci, mpuy, ntuż,
   {{0x27e00009,0x61fc574a,0x25a59c8f,0x6b9ba3f1}},	//   tkin_, rirl, mell_, _obug,
   {{0x25a5d74b,0x3ebf0390,0x61fc099b,0x037a0180}},	//   lell_, _šuta_, sirl, _صحبت_,
   {{0x27e0574c,0x62800065,0x7bc4020d,0x63a63437}},	// [4420] rkin_, ámod, _iniu, mekn,
   {{0x25a5a9be,0x64408ca9,0x6b9b860f,0x628622fe}},	//   nell_, _simi, _abug, muko,
   {{0x6440d74d,0xc7a60785,0x6286574e,0x7bd602d0}},	//   _pimi, _линк, luko, _koyu,
   {{0x25a5d74f,0x28bd83b6,0x6abbd750,0x3ea902d5}},	//   hell_, ्मनि, _bruf, bwat_,
   {{0x7c228be3,0x64409eaa,0x62865751,0x9f91807b}},	//   rlor, _vimi, nuko, _ráð_,
   {{0x27e6990f,0xdb1b8118,0x6b9bc044,0xd46a08ca}},	//   _slon_, _couñ, _ebug, _محرم_,
   {{0x25a5874a,0x628627bb,0x7c22cbad,0x27e68242}},	//   dell_, huko, plor, _plon_,
   {{0xa8570051,0x62865752,0x61ea81e0,0x64408049}},	//   זיקה_, kuko, shfl, _uimi,
   {{0xe9ff8028,0x25a5d753,0x69968544,0x6abb8428}},	//   _quản_, fell_, _грех, _gruf,
   {{0x25a5c99f,0x6b8d5754,0x78bc83a7,0x2d998061}},	//   gell_, _scag, _árvo, ősen_,
   {{0xd4978009,0x7bd603bf,0x25f00ad5,0x1da989c1}},	//   бря_, _boyu, _इतनी_, _कसरत,
   {{0x224903ac,0x62865755,0x7bd63952,0x24190a41}},	//   _puak_, fuko, _coyu, ромы_,
   {{0x25a5d756,0xb33b03a7,0x998c826c,0xa3d0815c}},	//   bell_, reço, _midž_, _वचन_,
   {{0x2d578009,0x25a5d757,0xe6778039,0x07378039}},	//   _лишь_, cell_, _פתוח_, _האדם_,
   {{0x63a6008e,0x6722808e,0x7c3f01e8,0xfc4980ff}},	//   bekn, _hyoj, _èpro, _hận_,
   {{0x63a6008e,0x672285ee,0xf7701f31,0x3ea9293b}},	//   cekn, _kyoj, ّال_, twat_,
   {{0x6aad0010,0x9df91df3,0x34e1001b,0x644ab28e}},	// [4430] _usaf, анат_, पन्द, _hufi,
   {{0xdce70063,0x644ad758,0x99671cd0,0xa2c61c58}},	//   _zdję, _kufi, _утил, ामर्,
   {{0x2127001c,0xfc498129,0x67d50162,0x656ad759}},	//   _ánh_, _lận_, _дону, _mefh,
   {{0x661a811f,0x69d7002a,0x7cca8085,0x644abf27}},	//   hotk, _hoxe, lərs, _mufi,
   {{0x644ab4e6,0xf42a0198,0x661ad75a,0x3abc03de}},	//   _lufi, lvää_, kotk, ָמונ,
   {{0xd4e70d0e,0x5ce717d4,0x51878009,0x25a5823e}},	//   _люби, _люба, суда, xell_,
   {{0x25a5d75b,0x644a8803,0x628624e8,0x661a84e8}},	//   vell_, _nufi, zuko, dotk,
   {{0x20091106,0x6b9b9d8b,0xfc4980ff,0x40328073}},	//   nnai_, _ubug, _bận_, мејс,
   {{0x6458d75c,0x25a5ad2d,0xdce382ee,0xfc49801c}},	//   _atvi, tell_, _venč, _cận_,
   {{0x7bd60059,0x661a812b,0x69d74b53,0x63a609e1}},	//   _soyu, gotk, _noxe, wekn,
   {{0x25a5d75d,0x200902f7,0x66838019,0xddc995d8}},	//   rell_, knai_, _کیخل, prež,
   {{0x25a5be92,0x6286575e,0x7bd60201,0x69c5575f}},	//   sell_, tuko, _qoyu, _anhe,
   {{0x8c1a8bea,0x25a5b01d,0x63a65760,0x2b1703db}},	//   שורי, pell_, rekn, _धुआँ_,
   {{0xfce582da,0x6d47020f,0x27ffd761,0x644a826c}},	//   _моло, _ngja, liun_, _fufi,
   {{0x61430a68,0x6286558a,0xd9431f0d,0xd5b881a9}},	//   дера, suko, дери, klāj_,
   {{0x3ea9826f,0x27ff846d,0x7bc40087,0x69c50f06}},	//   _šaty_, niun_, _uniu, _enhe,
   {{0x44205762,0x7643d763,0x9d2600c8,0x29f6809a}},	// [4440] _iki_, _kiny, _বলেন_, cław_,
   {{0x6fdc957a,0x7643d764,0x7c26203c,0x644a8326}},	//   _héct, _jiny, llkr, _yufi,
   {{0x7643b86a,0xdd7a8158,0x24758029,0xfecf80ab}},	//   _miny, שטעל, nām_, িনিধ,
   {{0x76439fa2,0x661a812b,0x27ffb788,0xeb9a8073}},	//   _liny, zotk, jiun_, рид_,
   {{0x27ff91ee,0x27edd765,0x1fb501e5,0xdc3700be}},	//   diun_, dhen_, _эсэр, קאנט_,
   {{0x7643c5eb,0x247580eb,0x27ed8a48,0x09e3876a}},	//   _niny, kām_, ehen_, мочн,
   {{0x24758341,0x44205766,0xe7868d9e,0xd7c5816f}},	//   jām_, _oki_, оупо, वांच,
   {{0x44205767,0x27ff810c,0x247580eb,0x644ad321}},	//   _nki_, giun_, dām_, _rufi,
   {{0xa3ce00cf,0x09c480ab,0x4426955c,0x7643afa0}},	//   रान_, ্সবা, mlo_, _biny,
   {{0x4426a9da,0x44200065,0x443231bb,0xfc49801c}},	//   llo_, _aki_, _ahy_, _vận_,
   {{0x6fdcd768,0x7643859c,0xa3ae816f,0x4426c194}},	//   _sécu, _diny, _कसा_, olo_,
   {{0x27ed8943,0x4426d769,0x27ff802e,0xfc49801c}},	//   chen_, nlo_, ciun_, _tận_,
   {{0x4420016f,0x4426d76a,0x661ad76b,0x62829336}},	//   _dki_, ilo_, potk, nroo,
   {{0x4426d76c,0x9e658077,0x4420576d,0x247580eb}},	//   hlo_, _راهن, _eki_, bām_,
   {{0x6458835f,0x29f68035,0xd48f8a08,0x6282890d}},	//   _utvi, sław_, _юр_, hroo,
   {{0x35e08b85,0x44268088,0x187b80be,0x3166026c}},	//   _पकड़, jlo_, יטלב, _đoze_,
   {{0x4426d76e,0xdce380eb,0x2009576f,0x2d8c86a8}},	// [4450] dlo_, _ienā, rnai_, ogde_,
   {{0x3135246b,0x27ff9a91,0xdcbb1f2b,0x4426d770}},	//   _непр, ziun_, ище_, elo_,
   {{0x2fc68025,0x44395771,0x321c826f,0x7a201743}},	//   _onog_, oms_, dovy_, rött,
   {{0xf53783de,0x62828901,0x0b588071,0xdb1b87b6}},	//   קטאר_, froo, оршы_, _anuá,
   {{0xa7560039,0x601304b7,0x628286a8,0x2a69008e}},	//   _משרד_, għme, groo, _jwab_,
   {{0xa96680a9,0x4426a27f,0x21668c24,0x7f3a01c6}},	//   пиша_, alo_, пиши_, _לערו,
   {{0x4426d772,0x628291fe,0x764bd773,0x27edd774}},	//   blo_, aroo, _sugy, then_,
   {{0x7643d775,0x75ed8298,0x443914da,0x6282d776}},	//   _siny, _múze, jms_, broo,
   {{0x7643d777,0x27edd778,0xadc4046d,0x27ff8168}},	//   _piny, rhen_, _afẹr, riun_,
   {{0x27ed83c3,0x27ff88b3,0x24758029,0x44390110}},	//   shen_, siun_, tām_, ems_,
   {{0x44200c68,0x236d8282,0x7a2d8118,0x2a69010c}},	//   _pki_, _keej_, cúta, _awab_,
   {{0x3835a252,0x2b4903a8,0x247580eb,0xdce7001b}},	//   _энер, _cgac_, rām_, _nejč,
   {{0x76438870,0x236d81c5,0x67ea007b,0x247581a9}},	//   _tiny, _meej_, _nýja, sām_,
   {{0xceb29bb3,0x236d90af,0x44320039,0x985600e8}},	//   _ניו_, _leej_, _why_, зташ,
   {{0x4426d779,0xdca29056,0x31160076,0x44200b99}},	//   ylo_, _защи, _दुखः_, _tki_,
   {{0x236d81e9,0x6282d77a,0xe0431da6,0x8ca60105}},	//   _neej_, yroo, енси, _टैगो,
   {{0x4426bffc,0x3ead9151,0xe7371ae5,0x2c0b0061}},	// [4460] vlo_, nwet_, зет_, _دعوی_,
   {{0x63b601b4,0xf8bd86ab,0x66019b4e,0xd83882d6}},	//   _hayn, ्माय, nilk, _apčl_,
   {{0x63b607d9,0xddcd0353,0x89db04de,0x61fe252a}},	//   _kayn, braž, _החיי, _impl,
   {{0x62829ebf,0x205703c8,0x4426b926,0x224d80b9}},	//   troo, _מיטל_, ulo_, _buek_,
   {{0x4426957e,0x63b655cd,0x66019eea,0x224d9142}},	//   rlo_, _mayn, kilk, _cuek_,
   {{0x98b80b06,0x44269234,0x6282cef8,0x628690aa}},	//   ları_, slo_, rroo, _åkom,
   {{0xdca31878,0x6601d77b,0x62828123,0x4439577c}},	//   _пари, dilk, sroo, yms_,
   {{0x644e002e,0x6282cacc,0x661e0796,0x6aa40037}},	//   _iubi, proo, lopk, _opif,
   {{0x644e577d,0x61fe009f,0x96349ae2,0x63a089c4}},	//   _hubi, _ompl, мниц, _ibmn,
   {{0x644e0c6f,0xf9c489d7,0x660182f7,0x6726021e}},	//   _kubi, _تحری, gilk, _mykj,
   {{0x69c8d77e,0x236d90af,0xdcfc0214,0x6fdc82be}},	//   _inde, _yeej_, _karı, _décr,
   {{0xb21b013c,0x644e01d3,0x61fe15ad,0x661e042b}},	//   græn, _mubi, _ampl, hopk,
   {{0x4439577f,0xe9ff8028,0x644e5780,0xddcd5781}},	//   rms_, _quần_, _lubi, vraž,
   {{0x44395782,0x69da8364,0x6601b21c,0x22450106}},	//   sms_, _jote, cilk, ölk_,
   {{0xddcd003a,0x644e5783,0x59f85784,0x859b8039}},	//   traž, _nubi, черя_, _השוו,
   {{0xa3ce0778,0xe9ff8028,0x61fe4839,0x22960edd}},	//   राण_, _tuần_, _empl, bæk_,
   {{0x69c8933a,0x35b53ba1,0xe9ff80ff,0x95d927d4}},	// [4470] _onde, мбар, _huấn_, одат_,
   {{0x69dad785,0x644e0f8e,0x236d8282,0x317100b9}},	//   _note, _bubi, _seej_, qazz_,
   {{0x644e3402,0x682583a7,0xdcfc03bf,0x63a0808e}},	//   _cubi, sódi, _barı, _bbmn,
   {{0x236d822c,0x645c0174,0x22459f21,0x3eb2062c}},	//   _qeej_, _dtri, _silk_, äntä_,
   {{0x69dad786,0xa3ce035a,0x69c8d787,0x7ae2d788}},	//   _bote, रात_, _bnde, gyot,
   {{0xed46803d,0x69da9139,0xdea4053d,0xbde5010c}},	//   _لپ_, _cote, _سیمی, _dhèè,
   {{0x644e003a,0x7c844d44,0x6601d789,0x69dad78a}},	//   _gubi, _путе, vilk, _dote,
   {{0x7e7d82b7,0x6d5883b2,0x560000ab,0x7ff5803d}},	//   áspo, _afva, ্তৃক_, بستا,
   {{0x644e31ec,0x6601d78b,0x76470314,0x91d00035}},	//   _zubi, tilk, _kijy, दामै,
   {{0xd7068364,0x63abafa2,0x644e578c,0x628ba2fe}},	//   ьные_, legn, _yubi, mugo,
   {{0xdcfc02bb,0x644802be,0x628bd78d,0x6add809a}},	//   _yarı, _édit, lugo, _मथुर,
   {{0xd91a8159,0x6601d78e,0x68e392fa,0xa3ce0af3}},	//   _וועל, silk, mynd, राध_,
   {{0x629989e5,0x0f568051,0x628b977c,0x68e3808b}},	//   ntwo, _חינם_, nugo, lynd,
   {{0x63b6578f,0x22960366,0xbea2ce94,0xa2b08072}},	//   _wayn, ræk_, _рашк, _आईस्,
   {{0x324326c8,0xa3ce00d4,0x628b82e8,0x80ba0035}},	//   терг, राद_, hugo, ॉमें,
   {{0xdfd200f7,0xc7b98019,0x764f0a5a,0x5d4483de}},	//   خير_, ndő_, _bucy, _אָפּ_,
   {{0x1dc909a3,0x644e0b87,0x386d0a20,0x645c5790}},	// [4480] रांत, _subi, ćera_, _stri,
   {{0xdcfc03bf,0x644e5791,0x7ae28010,0x61fe0087}},	//   _sarı, _pubi, vyot, _umpl,
   {{0x7e760176,0x764702d6,0x7c240c2e,0xb4e81404}},	//   ssyp, _dijy, _kkir, यने_,
   {{0x656e5792,0x63abd793,0xd90d0019,0xdcfc0085}},	//   _webh, gegn, _ایف_, _qarı,
   {{0x19588084,0x656e5794,0x245380ff,0x6684004e}},	//   палы_, _tebh, _lãm_, _سیال,
   {{0x644e2703,0x7ae29315,0x6fb4016f,0x98c69f2c}},	//   _tubi, ryot, _उघडू, дсил,
   {{0x68e3813c,0x7c245795,0x63abbf9d,0x645c5796}},	//   gynd, _okir, begn, _utri,
   {{0xdfd08013,0x628bc98b,0xd7d1016f,0x5fd1016f}},	//   اية_, bugo, हायच, हायल,
   {{0x69dad797,0x6d432b0d,0x25b800ed,0x7c3f0037}},	//   _tote, žnat, _karl_, _èpri,
   {{0x69c8c6df,0x7c243190,0xd49a8012,0x7bc9826f}},	//   _unde, _akir, орм_, _zneu,
   {{0x6448d798,0x442484fb,0x62805799,0x35f780f7}},	//   _édis, _kkm_, ámon, بريد_,
   {{0x4424b07e,0x9f4901a8,0xa2c298b1,0xddc282d4}},	//   _jkm_, thaí_, लिप्, _uvož,
   {{0x2004d79a,0x4424d79b,0x6b9d579c,0x3dca0176}},	//   mimi_, _mkm_, rfsg, _onbw_,
   {{0x2004d79d,0xe9ff801c,0x7c240c56,0x6abd0646}},	//   limi_, _tuấn_, _ekir, rvsf,
   {{0x26c24b43,0xa3ae8072,0x7647018f,0xdb160176}},	//   _arko_, _कसं_, _rijy, _layè,
   {{0x2d9ea9b5,0xdb00d79e,0x23669320,0x27f20c0b}},	//   lfte_, _jamó, jboj_, ghyn_,
   {{0x98af02bb,0x26c2017f,0xdb00816a,0x63abd79f}},	// [4490] ınız_, _crko_, _mamó, vegn,
   {{0x2004d7a0,0x6eb186a7,0xdb0b8bdd,0xa2c2a518}},	//   himi_, _अनसु, ndgå, लिन्,
   {{0x2004d7a1,0x81c68264,0x7bc9bf19,0xe759004a}},	//   kimi_, ৎসা_, _pneu, _нині_,
   {{0x628baa0f,0x2004cda3,0xb5fb01a8,0x629981ec}},	//   tugo, jimi_, _stád, ttwo,
   {{0x27e90867,0x63ab8bc5,0x81d880ab,0xe94502e3}},	//   mkan_, regn, াসন_, _ترکی,
   {{0x27e92a6f,0x63ab920c,0x7bc9831d,0x628bd7a2}},	//   lkan_, segn, _wneu, rugo,
   {{0x545421a7,0x63ab8098,0x27e90280,0x659457a3}},	//   _авст, pegn, okan_, _шару,
   {{0x27e93859,0x68e385ee,0x2004d7a4,0x66050458}},	//   nkan_, rynd, gimi_, lihk,
   {{0x27e943d8,0x68e384dc,0xa3ce0526,0x200dba03}},	//   ikan_, synd, रास_, rnei_,
   {{0x27e9045c,0xee3687ac,0x6d4ea8d2,0x7c2bd7a5}},	//   hkan_, нны_, žban, llgr,
   {{0x27e957a6,0x64c980d4,0x20048168,0xdb00d7a7}},	//   kkan_, िमेश, bimi_, _famó,
   {{0xca290051,0x66051600,0x8ca80c28,0xab5d8035}},	//   _הם_, hihk, _घनघो, _poży,
   {{0xc7d68f60,0x27e957a8,0xd9e380c2,0x1ae18264}},	//   _רוני_, dkan_, _औकात_, _খেতে_,
   {{0xdb00809a,0x67e30074,0x7c2b948c,0xb8663df2}},	//   _zamó, _mõju, hlgr, فارو,
   {{0x27e90057,0xa3c186bf,0x6605010b,0x6e218369}},	//   fkan_, ्ञा_, dihk, molb,
   {{0x27e90b13,0x7c24211a,0x628637a2,0xdb0083a8}},	//   gkan_, _ukir, prko, _xamó,
   {{0x442257a9,0x63a457aa,0xd7c40072,0x8d661df3}},	// [44a0] mok_, _ibin, _लोणच, евзе,
   {{0x442257ab,0x27e920d5,0xa3ce450b,0x2004d7ac}},	//   lok_, akan_, राव_, zimi_,
   {{0x27e90393,0x442480dd,0x6449a5eb,0x225f8748}},	//   bkan_, _pkm_, _biei, _atuk_,
   {{0xe29aa20b,0x27e904b8,0x442257ad,0xd5c9090a}},	//   зад_, ckan_, nok_, राउज,
   {{0xdb00ad84,0x5b2387ac,0x2004d7ae,0xd32382c7}},	//   _ramó, льша, vimi_, льши,
   {{0x44221066,0x69de4847,0x2a6000ee,0xdb008176}},	//   hok_, _jope, _mtib_, _bamò,
   {{0x2004d7af,0x6d4e57b0,0x26c057b1,0x63a404be}},	//   timi_, _igba, lvio_, _obin,
   {{0x69de57b2,0x8c438bba,0x3ebf111b,0x3f920326}},	//   _lope, _бесе, _šuti_, ngyu_,
   {{0x2004d7b3,0x442257b4,0x7c22858f,0x62800019}},	//   rimi_, dok_, moor, ámol,
   {{0xdd908277,0x69de49b0,0x2004d7b5,0x63a457b6}},	//   جود_, _nope, simi_, _abin,
   {{0x6f66839d,0x4ac3035a,0x2d9eafc3,0x6d4e082e}},	//   _звез, शिभव, rfte_, _mgba,
   {{0x442257b7,0x7c22bbd5,0x2bc6d7b8,0xcfaf80ab}},	//   gok_, noor, _रोमा, কাউন,
   {{0x81b38a49,0xa2be03dd,0x6d5c06c0,0x2bb20beb}},	//   টার_, शिष्, _ofra, _जसरा,
   {{0x7c228b3c,0x69de2ed2,0x3c32027f,0xdb028e15}},	//   hoor, _cope, ráva_, ndoñ,
   {{0x27e9045c,0x442257b9,0x7c22d7ba,0x69de127a}},	//   tkan_, bok_, koor, _dope,
   {{0x442257bb,0x6d4e57bc,0x629a0087,0x2b498bda}},	//   cok_, _agba, ător, žaci_,
   {{0x27e9045c,0xf65316a5,0x66050359,0x7e6416fb}},	// [44b0] rkan_, ائر_, tihk, gpip,
   {{0x27e90393,0x984b57bd,0x6d5ad7be,0x7bdf023e}},	//   skan_, _няма_, ncta, _hoqu,
   {{0x27e90393,0x225f838e,0x55778158,0x7c22a04f}},	//   pkan_, _stuk_, געבן_, foor,
   {{0x6d5c2fa4,0x660515bd,0x7c2290b5,0x69de007a}},	//   _efra, sihk, goor, _zope,
   {{0x6449d7bf,0x629d57c0,0x6d5c0114,0x66052419}},	//   _viei, ntso, _ffra, pihk,
   {{0x7bdf3e92,0x44220e14,0x1e1a809a,0xdb0bbdf7}},	//   _loqu, zok_, नकोष_, negé,
   {{0x70bd85e8,0x5ba78a94,0x7c229ebf,0xd3a786b5}},	//   ्मेल, _праз, boor, _прап,
   {{0x63af111b,0x6d4e811f,0x442b8129,0x7c22c762}},	//   jecn, žbal, _óc_, coor,
   {{0xee39867c,0x629d3f3f,0x22849663,0x225f8359}},	//   мни_, jtso, _бухг, _utuk_,
   {{0x645a07a3,0x442208b3,0x628f4bc7,0x63bbd7c1}},	//   _étic, wok_, duco, _haun,
   {{0x442257c2,0x63bb8a14,0xa806017b,0x7bdf106c}},	//   tok_, _kaun, lmış, _boqu,
   {{0x63bbbe09,0x32078e04,0x7bdf57c3,0xa2be1344}},	//   _jaun, liny_, _coqu, शिल्,
   {{0x442257c4,0x63bba3a8,0xa806017b,0x21f402f1}},	//   rok_, _maun, nmış, _lähe_,
   {{0x442257c5,0x32078e04,0x26c001e8,0x63bbd7c6}},	//   sok_, niny_, vvio_, _laun,
   {{0x442257c7,0x64c5005c,0x21f401ec,0x44c10084}},	//   pok_, nčić, _nähe_, _nė_,
   {{0xb8da1094,0x63bb8cf4,0x63a40dc5,0x6d5c0d02}},	//   _आई_, _naun, _ubin, _sfra,
   {{0x539b0051,0xf7728158,0x7c228b3c,0x3207816b}},	// [44c0] _חיפו, יקן_, voor, kiny_,
   {{0x7c2290f4,0x4d631aeb,0xe73757c8,0x3207826f}},	//   woor, икув, теу_, jiny_,
   {{0x32078efc,0xeb9a8e8e,0x7c22d7c9,0x26c0041c}},	//   diny_, дие_, toor, svio_,
   {{0x7bdf0580,0x31780035,0x7e7b8100,0xe7279a16}},	//   _xoqu, larz_, ksup, _نص_,
   {{0x7c22a8ac,0x63bbd7ca,0x32079075,0x8004819d}},	//   roor, _daun, finy_, ịakọ_,
   {{0x7c229eb6,0x7e7b8338,0xa3ce01a2,0xa3ae86a7}},	//   soor, dsup, राँ_, _कसक_,
   {{0xc9530039,0xfc4a001c,0x7c2286a8,0x629b8037}},	//   סמה_, _hậu_, poor, _equo,
   {{0x61df01fe,0x67f58038,0x63bb8084,0xb21b006a}},	//   _नक्ष, _nájd, _gaun, træk,
   {{0x6d4e80ce,0x7bdf57cb,0x7e7b93d2,0x32078873}},	//   žbam, _roqu, gsup, biny_,
   {{0x63a2d7cc,0x63bb84b9,0x7bdf385e,0xdbd6046d}},	//   lfon, _zaun, _soqu, _gùús,
   {{0x7bdf309b,0x63af57cd,0xb4cc86ae,0x624b04b7}},	//   _poqu, tecn, रमे_, _bżon,
   {{0x601304b7,0xd5be81a9,0x629d0687,0xbf9b041c}},	//   għml, _šāda_, ttso, _amên,
   {{0x80c08b9f,0x61e1016d,0x63af095e,0x6825816a}},	//   विवे, öllo, recn, pódr,
   {{0x629d00ad,0x63af0503,0x7a32006a,0xdcfc02d6}},	//   rtso, secn, sætn, _adrč,
   {{0x7bdf57ce,0xdb04002a,0x67f58061,0xa8060380}},	//   _toqu, _baió, _fájd, zmış,
   {{0xa3ce01a2,0x7bcd57cf,0xdb04002a,0x0eb68beb}},	//   राः_, _unau, _caió, _अनाड,
   {{0x442957d0,0x63bb97ee,0xfc4a001c,0x2caa0b99}},	// [44d0] _ika_, _raun, _cậu_, _apbd_,
   {{0x7c2f1a34,0x2caa02f7,0xb5fb026b,0x201202ec}},	//   llcr, _bpbd_, _awár, anyi_,
   {{0x3207803e,0xb90800c8,0x63bba022,0x9f9c008b}},	//   viny_, _মে_, _paun, _tíð_,
   {{0x7e62d7d1,0x64c5012b,0xa80607c0,0x44290176}},	//   _otop, včić, tmış, _jka_,
   {{0x53a5058c,0x3207826f,0x20093521,0x26c68282}},	//   ग्यश, tiny_, miai_, _nroo_,
   {{0x20090a8e,0x6d4e992c,0xa8060380,0x644d2dc8}},	//   liai_, žbaj, rmış, _liai,
   {{0x7e62862f,0x63bb8cd5,0x3207d7d2,0xa3e4064a}},	//   _atop, _taun, riny_, पॉड_,
   {{0x20090a8e,0x442957d3,0x7e7bd7d4,0x26c682f7}},	//   niai_, _nka_, tsup, _broo_,
   {{0xfc4a0028,0x7c29811e,0xa3d7123a,0x32079c32}},	//   _mật_, _iker, सान_, piny_,
   {{0x442957d5,0xf99388ca,0xe616c792,0x645524d4}},	//   _aka_, _خبر_, лды_, _kuzi,
   {{0xeb9a214a,0xd131845a,0x65753ddf,0x7e7bd39d}},	//   нин_, _اما_, _mezh, ssup,
   {{0xa3ce0768,0x44290168,0x442f8118,0x65750168}},	//   राइ_, _cka_, nlg_, _lezh,
   {{0x61e1d7d6,0x6da5a466,0xe5a59810,0xe2c70ea6}},	//   _koll, _била, _били, гляд_,
   {{0x442957d7,0x61e18009,0x27eda2ea,0x090500c8}},	//   _eka_, _joll, lken_, _শুধু_,
   {{0xfc4a0028,0x644d3554,0x6455032d,0x7c29b111}},	//   _bật_, _fiai, _nuzi, _oker,
   {{0x27edd7d8,0x20091450,0x7c29b070,0x2d8357d9}},	//   nken_, giai_, _nker, _adje_,
   {{0xee3a0951,0x7c2657da,0x27edd7db,0x64552838}},	// [44e0] ена_, mokr, iken_, _auzi,
   {{0x61e1a043,0x6455020c,0xdd92006b,0x7c3bd7dc}},	//   _noll, _buzi, صوص_, _ahur,
   {{0x27edd7dd,0x399b00be,0x65750609,0x67f5801b}},	//   kken_, _אייד, _dezh, _záje,
   {{0x27ed8613,0xa3d70aed,0x248601ac,0x200957de}},	//   jken_, साय_, čom_, ciai_,
   {{0x0cb081cb,0xc6940158,0x7c3bd7df,0x09e6935f}},	//   _जन्म, _דאָ_, _dhur, лодн,
   {{0x2d83030b,0x61e1914e,0x27ed8a0f,0x7c298135}},	//   _gdje_, _coll, eken_, _eker,
   {{0xee0980c8,0x645557e0,0x7c2657e1,0x61e1d7e2}},	//   রকাশ_, _guzi, kokr, _doll,
   {{0xd6dad7e3,0xd252803d,0x6b840c2e,0xdb040118}},	//   ето_, _هنر_, _ndig, _laiñ,
   {{0x3ea057e4,0x61e1d7e5,0xa3ce0bb8,0xb4cc9c9d}},	//   ntit_, _foll, राई_, रम्_,
   {{0x44291918,0x57e1035a,0x61e1d7e6,0x6b8457e7}},	//   _ska_, _नव्ह, _goll, _adig,
   {{0x2ed10af3,0x806696ba,0xc223803d,0xf0669a51}},	//   _सप्त, _свеж, _اکنو, _скеп,
   {{0x764e054e,0x27ed92a1,0x3ea057e8,0xab6203bf}},	//   _liby, cken_, ktit_, şünd,
   {{0xa3d705e8,0x61e18182,0x20090110,0xe3bf57e9}},	//   साब_, _yoll, viai_, goña_,
   {{0x2fc03d05,0x249c80ee,0x764e00b4,0xe80202f1}},	//   edig_, _tqvm_, _niby, रोसा_,
   {{0x657a8234,0xb21b006a,0x4426d7ea,0xf55b81c6}},	//   math, kræv, koo_, _אדומ,
   {{0xb8dd113d,0x4426a202,0x657ad7eb,0x645557ec}},	//   _इन_, joo_, lath, _ruzi,
   {{0x4426d7ed,0x200901e2,0xfc4a0028,0x33a80698}},	// [44f0] doo_, riai_, _vật_, _също_,
   {{0x78ba8025,0x200901e2,0x7c3bc81b,0x7c29d7ee}},	//   _ostv, siai_, _shur, _sker,
   {{0x38c900d5,0x2ee9237e,0xd7c4816f,0xfc4a00ff}},	//   _شادی_, syaf_, वयाच, _tật_,
   {{0x61e1d7ef,0x442682a3,0x657aa3e3,0x200c00e7}},	//   _soll, goo_, hath, édit_,
   {{0x657aa941,0x63bf3145,0x61e1c24d,0x3ea007f1}},	//   kath, _maqn, _poll, ctit_,
   {{0x17ed85e8,0x64551f73,0x2006836e,0x2d8304a8}},	//   जस्व_, _tuzi, _amoi_, _udje_,
   {{0x4426d7f0,0x61e1c90b,0x27edd7f1,0x657ac05b}},	//   boo_, _voll, tken_, dath,
   {{0x7c3bd1a0,0x3fe5a184,0x61e1c9f6,0x27edc494}},	//   _uhur, ржив, _woll, uken_,
   {{0x27edc885,0xe7e68665,0x657aa821,0x63a9d7f2}},	//   rken_, _ओकरा_, fath, _iben,
   {{0x657acd25,0x80bb00ab,0x61e180b9,0x67ea01d0}},	//   gath, _উপন্, _uoll, _výji,
   {{0x21f40074,0xdb04002a,0xee368087,0x2fc029f6}},	//   _näha_, _raiñ, рнэ_, ydig_,
   {{0x92d780ab,0xab5d8372,0xe3bf03a8,0x09aa8264}},	//   ানী_, _dażg, toña_, _গোপা,
   {{0x63a9803d,0x657a805d,0x63bf0609,0x59b9908a}},	//   _mben, bath, _daqn, _इसार,
   {{0x657ad7f3,0xe1ff01df,0x6fa18beb,0xb5fb57f4}},	//   cath, spón_, क्रू, _stán,
   {{0xab5d8063,0x614657f5,0x7c262e9c,0x412a05c2}},	//   _każd, рева, pokr, тово_,
   {{0x4426d7f6,0x2fc0038e,0x1f66096b,0x3ea00aa8}},	//   xoo_, udig_, ркам, ttit_,
   {{0x2fc02707,0xed5a2070,0x3ea057f7,0x4426b31b}},	// [4500] rdig_, воз_, utit_, voo_,
   {{0x3ea057f8,0x63a9d7f9,0xc27b093f,0xa3d70996}},	//   rtit_, _aben, _שריי, साथ_,
   {{0x3ea019e3,0x8fa6130f,0xb5fb57fa,0x7a2d807b}},	//   stit_, _кане, _itál, nútu,
   {{0xb5fb0019,0x03a6a4dc,0x657a8234,0xa87b00be}},	//   _után, ридо, zath, _באטר,
   {{0x4426d7fb,0xdce3801b,0x764e056c,0x657a81f6}},	//   roo_, _peně, _tiby, yath,
   {{0x442682c1,0x63a9d7fc,0x80aa80ab,0x645a0866}},	//   soo_, _eben, কিস্, _étio,
   {{0x44c580eb,0x218900be,0x44268198,0xdb0f2564}},	//   _nē_, אָפּ, poo_, recé,
   {{0x4fc6ae39,0x67f80144,0x657aa6b4,0x7afd55e7}},	//   рска, _fíje, wath, yzst,
   {{0x8f9b012a,0x7e6980e4,0x657ad7fd,0xd6d78c6e}},	//   דיפי, gpep, tath, атэ_,
   {{0x35f4b606,0x26c08110,0x7bc0d7fe,0x7bc28bfd}},	//   спор, _šios_, _hamu, ldou,
   {{0x78baadee,0xd7ef9d5c,0x7d7b0496,0x6aa2d7ff}},	//   _ustv, _ду_, כניו, ltof,
   {{0x7bc0d800,0x0ed6000d,0x3869826c,0x657ad801}},	//   _jamu, ठमाड, ćart_, sath,
   {{0x7bc0cc66,0x6aa2d802,0x657ad803,0x7a2d808b}},	//   _mamu, ntof, path, rútv,
   {{0x7bc0d804,0x7a2d8177,0x657a85e7,0x44c58176}},	//   _lamu, sútv, qath, _fē_,
   {{0xfc64819f,0xf8073f21,0x16b681a2,0xa3d72f0d}},	//   _اختی, ачан, _अनुब, साद_,
   {{0x7bc08763,0x74150bca,0x25aa04be,0xe802064a}},	//   _namu, _دوبا, _abbl_, रोला_,
   {{0x645889f8,0x7c2d5805,0xe7ee8665,0x65788282}},	// [4510] _huvi, _ikar, _जवना_, _kevh,
   {{0x6458d806,0x7bc0b65a,0x63a980dd,0x6f0d80c3}},	//   _kuvi, _aamu, _sben, _žack,
   {{0x090500c8,0x7bc081d3,0x8d740e06,0xdcbb0081}},	//   _শুরু_, _bamu, زالا, ъща_,
   {{0x64588609,0xdb160144,0x97a70425,0x81b80264}},	//   _muvi, _hayá, _трол, ছাঃ_,
   {{0x7bc0d807,0x61e55808,0xfc4a0129,0xdb0602d0}},	//   _damu, _kohl, _mập_, rekç,
   {{0x65789ded,0xfc4a0028,0x64588073,0xa4d50a18}},	//   _nevh, _lập_, _ouvi, _логі,
   {{0x92d780c8,0x7c2d5809,0x61e5027f,0x7bc0a371}},	//   ানে_, _okar, _mohl, _famu,
   {{0xe739d80a,0x43948009,0x7bc0d80b,0x32558470}},	//   лей_, _масс, _gamu, _гвар,
   {{0x442db7a0,0x443fd80c,0x6abbd80d,0x601301b9}},	//   _ike_, _ihu_, _usuf, għmi,
   {{0x7c2d580e,0x6e288132,0x7bc0d80f,0x7e69ccfd}},	//   _akar, godb, _zamu, rpep,
   {{0x443f8028,0x6458802e,0x7bc086b0,0xdb06072c}},	//   _khu_, _cuvi, _yamu, ndkö,
   {{0xb5fb027f,0x69c1d810,0xfc4a0028,0x645883a7}},	//   _stál, _hale, _cập_, _duvi,
   {{0xa3e9058c,0x442dd811,0x61e55812,0xeb970098}},	//   _मकर_, _mke_, _bohl, щия_,
   {{0x7c2d0102,0x69c1a7c8,0x200d8c7b,0x237d81c5}},	//   _ekar, _jale, liei_, hawj_,
   {{0x69c1d813,0x442dd814,0x443f8135,0x7c9580f7}},	//   _male, _oke_, _ohu_, _العص,
   {{0x2fdf8eef,0x442db7a0,0x200d8012,0x69c1d815}},	//   njug_, _nke_, niei_, _lale,
   {{0xed168986,0xe61a0364,0x0d860056,0x38a180f7}},	// [4520] _نہیں_, гда_, йлан, hór_,
   {{0x442dd816,0x7bc090fe,0x69c1d817,0x443f8135}},	//   _ake_, _samu, _nale, _ahu_,
   {{0x315704de,0xa9bb007c,0x6458802a,0xe66281bc}},	//   _ליין_, _גזיר, _xuvi, _mọọb,
   {{0x6d555818,0x443fd819,0x037a8829,0x6aa2b564}},	//   _egza, _chu_, احات_, ttof,
   {{0x1db7864a,0x21788e11,0x7bc0838a,0x200d9b2b}},	//   _असंत, айлы_, _vamu, diei_,
   {{0x442d91d3,0x6aa2d81a,0x27e04b19,0xed5714bc}},	//   _eke_, rtof, ljin_, _гор_,
   {{0x6aa2d79c,0x69c18ebf,0xf8c5816f,0x7bc0d81b}},	//   stof, _dale, विषय, _tamu,
   {{0xb8d08665,0x74168c2a,0x27e02a0b,0x657e005d}},	//   _ओह_, _اورا, njin_, laph,
   {{0x64408364,0x69c1d81c,0x6458d81d,0xa3d73d25}},	//   _ihmi, _fale, _suvi, सास_,
   {{0x69c1d81e,0xf1a98077,0x22f78039,0x628da50d}},	//   _gale, _نامه_, _הזמן_, šaoc,
   {{0xa3bc835a,0x705684c1,0x62828079,0x11d781a8}},	//   _असा_, _انصا, lsoo, _دولة_,
   {{0x69c1d81f,0x27e0204b,0x61e55820,0x200db448}},	//   _zale, jjin_, _sohl, ciei_,
   {{0x61e503fb,0x6578c609,0xa3ce090f,0x62829bad}},	//   _pohl, _tevh, राज_, nsoo,
   {{0x6458a8ce,0x6282826b,0x998301d0,0x27e0008e}},	//   _tuvi, isoo, rojů_, ejin_,
   {{0x16d10996,0xfc4a0104,0x37ab227b,0xdb160144}},	//   सम्ब, _tập_, лтан_, _vayá,
   {{0x27e00168,0x7c2d5821,0x27e6d822,0x61e55808}},	//   gjin_, _ukar, _joon_, _wohl,
   {{0x6d480a56,0x442b57d2,0x63ad5823,0x36d40aac}},	// [4530] _údaj, moc_, _iban, потр,
   {{0x443fb8b6,0x9b950077,0xd0470201,0x442dd824}},	//   _shu_, _الکت, _əmək, _ske_,
   {{0x2bdd03eb,0xe7c406ce,0x442d8101,0x443f8947}},	//   यापा, _लोकप, _pke_, _phu_,
   {{0x62829c2b,0xb21b006a,0x69c1d825,0xeb909f33}},	//   fsoo, præs, _sale, فظه_,
   {{0x69c1d826,0x63ad5827,0x8aa79628,0x6282d828}},	//   _pale, _mban, сред, gsoo,
   {{0x7e6d48ed,0x69c1b474,0xda78a252,0xa2ba80d4}},	//   mpap, _qale, сяц_, _एनर्,
   {{0x443fd829,0x200d802e,0x69c38456,0x80c08cf0}},	//   _thu_, tiei_, rdne, विगे,
   {{0x1665ae9f,0x442d80e8,0x63ad01bc,0x57e98b26}},	//   овим, _uke_, _nban, рдим_,
   {{0xa3bf1d2a,0x7c2bd82a,0x69c1d82b,0x27e6be4c}},	//   ीयन_, mogr, _tale, _doon_,
   {{0x63ad44a5,0x200d8c7b,0x69c1d82c,0xac858811}},	//   _aban, siei_, _uale, огол,
   {{0xca48a6fc,0x04460c8e,0xab5b4011,0x27e6867f}},	//   _الله_, женн, rdün, _foon_,
   {{0x38858029,0x7e6d3437,0xeb9a023f,0x2bcf8054}},	//   mēr_, kpap, шим_, _सोमा,
   {{0xe72e8cde,0xce6b9cf5,0x7cff8032,0x645e8036}},	//   _це_, _сред_, _báré, _épin,
   {{0x63ad582d,0x27e680f3,0x0dcb84ae,0x644881e8}},	//   _eban, _zoon_, _људи_, _èdiv,
   {{0x27e690e4,0x2a69011b,0x9c6580d7,0xdfd21f33}},	//   _yoon_, _etab_, _بهبو, ويس_,
   {{0x62803ad7,0x6b89b9ad,0xb4d5d82e,0x63ad19ab}},	//   ámos, _ndeg, समी_, _gban,
   {{0xa3d71b91,0x7e6d1882,0x7c2b805c,0xe57a013a}},	// [4540] सार_, gpap, dogr, иза_,
   {{0x6440b11a,0x7bd6022c,0x0d861138,0x67f80061}},	//   _shmi, _hnyu, ілен, _díja,
   {{0x2eb68770,0xdddb82a5,0xb60780eb,0xd9464434}},	//   _अन्त, kruž, mašī, _фени,
   {{0x926ab312,0x2bdd0eb4,0xd36f80f7,0xdddb811f}},	//   арка_, याया, نهم_, jruž,
   {{0xdddb914d,0x7bc42f53,0x27e6d5cd,0x2bac3841}},	//   druž, _maiu, _roon_, ट्या,
   {{0x6282a229,0x6b89d82f,0xc8c580d4,0xdce38b80}},	//   rsoo, _edeg, विंट, _lenđ,
   {{0x27e6d830,0x23ca01a2,0xfbca001b,0x2e2f0192}},	//   _poon_, ियाद, ियाम, rüft_,
   {{0x254e8201,0x657c5831,0xeeaaa250,0x7bc402e8}},	//   vəl_, _herh, аток_, _naiu,
   {{0xdefa93cd,0x442b1100,0x645c3873,0xdde38087}},	//   рый_, voc_, _huri, ârşi,
   {{0x645c5832,0x50d6806b,0x27e68cfa,0xd946917e}},	//   _kuri, _وزار, _woon_, _дези,
   {{0x26c9003b,0x27e6838e,0xa3d703b7,0xdb0f05e4}},	//   zvao_, _toon_, साल_, recí,
   {{0x645c5833,0x7a3f80e7,0xab5d8372,0xb5fb128a}},	//   _muri, rête, _każa, _pták,
   {{0x2bdd000c,0x442b5834,0x23dd016f,0x657c016d}},	//   याबा, roc_, याबद, _oerh,
   {{0x67fcd835,0x81d88264,0x645c03cd,0x7bd61896}},	//   _déje, াসক_, _ouri, _enyu,
   {{0x7c2bd836,0xba3d801b,0x957c8035,0xf65f006a}},	//   yogr, _způs, ając, _træk_,
   {{0xcb0b08cc,0x63ad5837,0x6825809a,0x3e6086c0}},	//   _вход_, _uban, wódz, _kòt_,
   {{0x657c0393,0x645c5838,0x81b38264,0x6ecd914f}},	// [4550] _berh, _auri, য়াত_, तियु,
   {{0x7c2b8247,0xdce18110,0xf2d200be,0x2bac0035}},	//   wogr, galė, _װעט_, ट्ठा,
   {{0x3e608205,0x69d721ea,0x7e6d2d81,0x403524dc}},	//   _lòt_, _inxe, spap, _неос,
   {{0x6b9d1839,0xf3ff0073,0x645c5839,0x69c5583a}},	//   ngsg, nhã_, _duri, _hahe,
   {{0xa3bc85e8,0x657c29f3,0x216982d3,0x69c5583b}},	//   _असर_, _ferh, били_, _kahe,
   {{0x69c7583c,0x645c583d,0xf1cb0a27,0x61e8d83e}},	//   ndje, _furi, ायिन, _codl,
   {{0x2903249d,0x758204c0,0x645c583f,0x69c55840}},	//   nzja_, _سینم, _guri, _mahe,
   {{0x69c55841,0xb5fb001b,0xe7a68a75,0x765d00ee}},	//   _lahe, _stáh, क्लप, _kusy,
   {{0x645c5842,0x41cb2c5d,0x06099e58,0x3e6082d6}},	//   _zuri, ायास, йник_, _còt_,
   {{0x645c5843,0x2d811849,0x765d10e1,0xc33283c8}},	//   _yuri, nahe_, _musy, _טון_,
   {{0x645c5844,0xc3290039,0x645e8036,0x00000000}},	//   _xuri, _עו_, _épil, --,
   {{0xe6720059,0x69d72da4,0x75f302d0,0xb5fb01a8}},	//   _ölçü, _anxe, _hızı, _dtái,
   {{0x69c50a5a,0x75f30214,0x765d00ee,0xc5f58081}},	//   _bahe, _kızı, _nusy, _някъ,
   {{0xcefd8059,0x7c27007a,0x216707b6,0xa9671cf8}},	//   ığın_, čkra, зири_, зира_,
   {{0x69c502af,0x31af83bf,0xf7721e09,0xa3bcd845}},	//   _dahe, mızı_, فاء_, _असल_,
   {{0x69d7184f,0xb8e40aed,0x645c0314,0x26cf8b80}},	//   _enxe, _एन_, _ruri, _krgo_,
   {{0xa3df901b,0x35d0800f,0x645c5846,0x44200a2c}},	// [4560] तान_, _थोड़, _suri, _iji_,
   {{0x62860025,0x2c6183b0,0x31af85c5,0x3c3205b9}},	//   msko, _kód_, nızı_, rávu_,
   {{0x657c105d,0xd7bd853e,0x6fbd8b86,0xc1730051}},	//   _verh, ्याच, ्यां, _אחת_,
   {{0x2c61b554,0xe363cbf2,0x26cf8118,0x5f070035}},	//   _mód_, екци, _orgo_, _सेक्_,
   {{0x6286007d,0x61e8a8ee,0x657c5847,0x44200010}},	//   nsko, _podl, _terh, _mji_,
   {{0x20120201,0x26c25848,0x62865849,0xb5fb016a}},	//   liyi_, _isko_, isko, _cuád,
   {{0x4420584a,0x645c0006,0x6286026c,0x777d0069}},	//   _oji_, _uuri, hsko, _yesx,
   {{0x4420584b,0xab66981d,0x2012584c,0x764380dd}},	//   _nji_, _хвал, niyi_, _ahny,
   {{0x62860025,0xb5fb00f7,0xfaa4804e,0x290301b9}},	//   jsko, _stái, _تجزی, zzja_,
   {{0x6286003b,0x720680d5,0x4420584d,0xa3da81ce}},	//   dsko, _عوام, _aji_, ़ाव_,
   {{0x43950972,0x2c6180f7,0xbebb0168,0x6456584e}},	//   манс, _cód_, _nxën, _biyi,
   {{0x64441009,0x67228069,0x6b82d84f,0x645605ee}},	//   _chii, _txoj, naog, _ciyi,
   {{0x62861309,0x644402a3,0x6456554e,0x20120201}},	//   gsko, _dhii, _diyi, diyi_,
   {{0x4420082e,0x225986c0,0x6f04009a,0x44320c56}},	//   _eji_, _èske_, dzic, _eky_,
   {{0x69c50665,0xa3bc835a,0x26c2011e,0xa41c9a42}},	//   _vahe, _असं_, _asko_, पचाप_,
   {{0x75378051,0x999e8110,0x2d9ea3dd,0x64561d43}},	//   _מאוד_, _kitų_, lgte_, _giyi,
   {{0x69c52afa,0x65655850,0x6b8d5851,0xdb0880e7}},	// [4570] _tahe, tchh, _idag, _élèv,
   {{0x44395852,0x2d9eaffb,0xddc40289,0x317e81ec}},	//   lls_, ngte_, tpiš, _netz_,
   {{0x645782ba,0x76553cfa,0x999e8110,0x271e80ff}},	//   _éxit, _vizy, _litų_, ịnh_,
   {{0x7a32013c,0xa3d3086a,0x44cc800d,0x20000087}},	//   sætt, _होम_, _mě_, chii_,
   {{0x44395853,0xa3df93f5,0xddc4025b,0x2d8701ca}},	//   ils_, ताब_, spiš, ónes_,
   {{0xf77f0201,0x44391705,0x75f30085,0x3ea93d2b}},	//   _heç_, hls_, _qızı, mtat_,
   {{0x63b9809a,0xd90f8065,0x2fc682d5,0x44cc81d0}},	//   pewn, دیا_, _baog_, _ně_,
   {{0x2fc91384,0xa009990c,0x6b8d5854,0x44395855}},	//   ndag_, تقبل_, _ndag, jls_,
   {{0x3ea95856,0xa3da809a,0xdcf88115,0x44391670}},	//   ntat_, ़ार_, _devč, dls_,
   {{0x64445857,0xee368084,0x20125485,0x64565858}},	//   _shii, мны_, ziyi_, _siyi,
   {{0x6f04047f,0x7983d859,0x39408326,0x645621ba}},	//   zzic, manw, ƙisa_, _piyi,
   {{0x442f805c,0x6286012b,0x2fc90a0f,0x3ea9585a}},	//   nog_, tsko, jdag_, ktat_,
   {{0xee2e97a1,0x3ea900f1,0xe5a58d70,0x6fda80d4}},	//   _ан_, jtat_, _жили, भारं,
   {{0x42550396,0x442fd65b,0x7d288019,0xd2520019}},	//   етст, hog_, épsé, ئنس_,
   {{0x442f803a,0xd9ff05b3,0x628603ab,0x6456585b}},	//   kog_, _उतरत_, ssko, _tiyi,
   {{0x6286003b,0x2fc9270d,0x942605e9,0xdb160020}},	//   psko, gdag_, _імпе, _mayú,
   {{0xe7370364,0x442f831d,0xf41380c8,0x79838435}},	// [4580] дет_, dog_, িকার_, kanw,
   {{0x6f04585c,0x200002a3,0x2012585d,0xfbc686a7}},	//   rzic, shii_, siyi_, _रोजम,
   {{0xdce18029,0xc486002e,0x6289826c,0xa3cf8424}},	//   dalī, флек, _aveo, _वोह_,
   {{0x442f8025,0xb4ae000f,0xab5d809a,0x7c650875}},	//   gog_, _कही_, _ważn, ءالل,
   {{0x3ea913df,0xaaba80b7,0x26c20ca1,0x2d9e8366}},	//   ctat_, تدار_, _usko_, ygte_,
   {{0xb5fb026f,0x7983d85e,0xeb9f0257,0xbbca11be}},	//   _stáv, ganw, niør_, ियुक,
   {{0x442fc9a2,0xada3585f,0x6da31860,0xe5a35860}},	//   bog_, _шарл, _шира, _шири,
   {{0x442f80d7,0x232a942c,0xab5b0380,0xab2acd5e}},	//   cog_, _доби_, rdük, _доба_,
   {{0x2bdd1880,0x79838870,0xfbdd1869,0x9f4902d0}},	//   यासा, banw, यासम, rkaç_,
   {{0x4439022b,0x67fcd861,0xdd908b8c,0xdb0f1243}},	//   wls_, _déja, دود_, lecç,
   {{0x5597010f,0x2fc901b0,0xdb0b9eb4,0x6b808135}},	//   ודיע_, ydag_, regå, _kemg,
   {{0x69caafc7,0x225f8573,0x63a40362,0x3ea91e51}},	//   ldfe, _yuuk_, _ccin, ytat_,
   {{0xa3df853e,0x81b380c8,0xf7738051,0x65949b8b}},	//   तात_, য়ার_, _סקס_, _залу,
   {{0x3f84d862,0x69c8d863,0xfd0f80d5,0x6d5c0077}},	//   lamu_, _jade, اجی_, _ngra,
   {{0x1958076a,0xa934054c,0xcec88028,0x442fd864}},	//   дары_, верш, _hộ_, yog_,
   {{0x765880f6,0x3ea95865,0x3f84d866,0x69da833e}},	//   _hivy, ttat_, namu_, _lnte,
   {{0x442f803b,0x2fc91412,0x69dad867,0x63bd3799}},	// [4590] vog_, rdag_, _onte, mesn,
   {{0x3ea95868,0x69c8998b,0xa3d32f7b,0x629d5869}},	//   rtat_, _nade, _होत_, muso,
   {{0x3ea91602,0x3f849fa4,0x628982a5,0x629d0461}},	//   stat_, kamu_, _sveo, luso,
   {{0x69da84f0,0x3ea9586a,0xf41f0009,0x60c5586b}},	//   _ante, ptat_, nnä_, _ishm,
   {{0x3f84a4d4,0x3e6447da,0x644b8502,0xfc4a00ff}},	//   damu_, _göt_, rmgi, _cậy_,
   {{0x442fd86c,0xa2d0064a,0xfc4a001c,0xe29c0039}},	//   sog_, दित्, _dậy_, קשור,
   {{0x205583bd,0x28c2946d,0x69c8d86d,0x236085f5}},	//   нтир, _वैदि, _dade, žija_,
   {{0xcec88104,0xa2ba8f12,0x63bd02fd,0x4439d86e}},	//   _bộ_, _शैक्, jesn, _ós_,
   {{0xef198c8e,0x7bdbd86f,0x63bd12b9,0x15f31b91}},	//   ями_, _inuu, desn, _आकार_,
   {{0x69c8d870,0x629d5871,0x645a023e,0x6b8081a9}},	//   _gade, duso, _ètic, _zemg,
   {{0x3f84b22c,0x03a61617,0xc984817c,0xfc4a027d}},	//   bamu_, нино, _шути, _zậy_,
   {{0x9f4b0003,0x69c88419,0xc4d200be,0x629d106c}},	//   _você_, _zade, אגט_, fuso,
   {{0x765881c0,0x69da8286,0x539a81c6,0x501a83de}},	//   _fivy, _ynte, הירו, _צונו,
   {{0x80cc016f,0x6da5b21a,0xa3e4064a,0xe5a58b26}},	//   हिले, _чика, पॉज_, _чики,
   {{0x60265195,0xb4ae0b85,0x63bd0904,0xd8261cf8}},	//   едва, _कहे_, besn, едви,
   {{0x6d43803a,0x6d5c5872,0x63a45873,0x2d85d874}},	//   _izna, _sgra, _ucin, lale_,
   {{0x7c242e3b,0xa3bf0072,0x2bdd2c07,0x38550081}},	// [45a0] _ijir, ीयर_, यारा, търс,
   {{0x2d85867b,0xee374094,0x3f84d875,0x2bac03dd}},	//   nale_, ену_, zamu_, ट्रा,
   {{0x6d5c0353,0xdb060074,0x272180ff,0xdb0f0187}},	//   _vgra, hekü, ỳnh_, tecç,
   {{0x03269b56,0x69c8d876,0x2d85d877,0xb5fb001b}},	//   нден, _sade, hale_, _stát,
   {{0x69c8d878,0xc7b30039,0xba3b023e,0xdb0f041c}},	//   _pade, _גבר_, buïd, recç,
   {{0x6d5c003b,0xfc4a0028,0x2d8586ae,0xaefb0032}},	//   _ugra, _vậy_, jale_, _afùw,
   {{0x2d85d879,0x69c8bba5,0x3f84d87a,0x15431073}},	//   dale_, _vade, tamu_, _берм,
   {{0x7c24587b,0x3f820042,0x69c89579,0xf65f0366}},	//   _njir, _jeku_, _wade, _træt_,
   {{0x63bd587c,0x3f84d87d,0x2417812a,0xfe6f84c0}},	//   vesn, ramu_, _נחמן_, یدی_,
   {{0x69da834a,0x48e6a6df,0x3f848b3f,0x3f8227d5}},	//   _unte, _позв, samu_, _leku_,
   {{0x29188006,0x29078063,0x63bd587e,0x3f848359}},	//   _ära_, czna_, tesn, pamu_,
   {{0x63a2d87f,0x3f82003a,0x629d5880,0x68f50110}},	//   ngon, _neku_, tuso, vyzd,
   {{0x1dd105e8,0x63bd44ce,0x7f42836a,0x63a281e0}},	//   _सफलत, resn, _uzoq, igon,
   {{0x2d85d881,0x63bd5882,0x7c240870,0x7d0680e7}},	//   cale_, sesn, _ejir, _céré,
   {{0x3f82085c,0x7d06c3e0,0x2c86846d,0x63bd5883}},	//   _beku_, _déré, _dídá_, pesn,
   {{0x7c240168,0x7e628d55,0x653b8039,0xdb1d03ed}},	//   _gjir, _kuop, _מעוד, nesë,
   {{0xa3da823c,0x6e940162,0x63a2d884,0x644f0326}},	// [45b0] ़ाई_, литу, dgon, mmci,
   {{0x63a2baab,0x4df4004a,0x7c3d2126,0x7d068866}},	//   egon, ляєт, llsr, _géré,
   {{0xd3719368,0xb7d90065,0x41de06ab,0xd49b2789}},	//   لها_, _ہوگا_, मारस, яра_,
   {{0x63a2d885,0x2cb80b99,0x2d85d886,0x30af80ab}},	//   ggon, _dprd_, zale_, কিৎস,
   {{0x2d85d887,0x16bc942d,0x69dd800d,0x7bcb8106}},	//   yale_, ्टोब, पाली, rdgu,
   {{0xe1f88196,0x3f820bcf,0xa3dfa7af,0xb5fb041c}},	//   нгі_, _zeku_, ताह_, _etár,
   {{0x9f40008b,0x3f825888,0x99838084,0x26c690ba}},	//   lkið_, _yeku_, _ųjų_, _asoo_,
   {{0xe8c185b3,0x2d85d889,0x7981d88a,0x2907d88b}},	//   _शनीच, wale_, _welw, rzna_,
   {{0x32558470,0x2d83588c,0x1e8281e5,0x6d4800f7}},	//   _авар, _keje_, алым, _údar,
   {{0x7c36588d,0x2d83137a,0x388c801b,0xa3df89c1}},	//   _skyr, _jeje_, běr_, ताव_,
   {{0x2d83588e,0xeb9a1c9b,0xfbdd025a,0x4e958019}},	//   _meje_, мин_, यांम, رشکر,
   {{0x2d83588f,0x0f158009,0x88c000ab,0x785c00fe}},	//   _leje_, _имею, _উপলক, _očvr,
   {{0xa3b3873c,0x27e927f8,0x3f824615,0x64498cb5}},	//   ज्य_, djan_, _reku_, _mhei,
   {{0xb82380ab,0xaa460081,0x27e90144,0x2d8581f6}},	//   _পঠিত_, тегл, ejan_, qale_,
   {{0x6d43896a,0xdcfc5890,0xb7bd8162,0x505a0a41}},	//   _uzna, _perč, anţe, дшая_,
   {{0x2fcdd099,0x27e95891,0x73ec80ab,0x2b5f8129}},	//   ndeg_, gjan_, _কষ্ট_, _nguc_,
   {{0x3eadd892,0x2d8319ff,0x9f4f8722,0x3f821e20}},	// [45c0] ntet_, _beje_, _algú_, _veku_,
   {{0x6b8401c6,0x601b0364,0x3ead82af,0x25f780d4}},	//   _heig, tämä, itet_, एसटी_,
   {{0x6449954c,0x26cf00f2,0x3f825893,0x6b840706}},	//   _bhei, ågor_, _teku_, _keig,
   {{0x6449d894,0x3eadd895,0xa3e503ca,0x6b8401e2}},	//   _chei, ktet_, नाय_, _jeig,
   {{0x64498c64,0xe7e591bc,0x67fc82be,0x2360807a}},	//   _dhei, काना_, _séjo, žijo_,
   {{0x6b845896,0xc33302f6,0x67f58019,0xb5fb0216}},	//   _leig, בוד_, _máju, _huán,
   {{0x64498068,0xfce30b88,0x3ea04b98,0xa3e50fcc}},	//   _fhei, _коро, luit_, नाम_,
   {{0x6449925b,0x3ead920b,0x8c468009,0x765c00b4}},	//   _ghei, ftet_, _ребе, _hiry,
   {{0xa3df8128,0x3ea01699,0xa3dc0327,0x96348ae7}},	//   तार_, nuit_, ठाई_, лниц,
   {{0x25a7c22f,0x27e90372,0xa3da8ad5,0x20048168}},	//   _ccnl_, zjan_, ़ाक_, shmi_,
   {{0x6b845897,0xf1a9803d,0xd59b0039,0x659b0039}},	//   _beig, _ساله_, וביל, וייק,
   {{0xa806017b,0x7c22d898,0xd7ef80f7,0x765c4bbb}},	//   nlığ, nnor, _وكل_, _liry,
   {{0x51871132,0x5694a5f5,0x6b845899,0xddc9d89a}},	//   кува, _салт, _deig, speš,
   {{0x3ea003d3,0x7c2282af,0x5a340cb1,0x765c0a03}},	//   duit_, hnor, инят, _niry,
   {{0x27e94ac0,0x925801e5,0xa80602d0,0x97a71444}},	//   tjan_, тарт_, klığ, крал,
   {{0xb5fb0693,0x23aa016f,0x28d3909b,0xf7730bbe}},	//   _cuán, _कायद, थिति, شار_,
   {{0x6449a0b9,0x27e93d80,0x3ea0589b,0x35b50568}},	// [45d0] _rhei, rjan_, guit_, лбар,
   {{0x6449cf82,0x6b8402af,0x9f40008b,0xfc3f01a8}},	//   _shei, _zeig, rkið_, llí_,
   {{0xa3df923a,0x290a009a,0x2baa016f,0x23aa000d}},	//   ताल_, czba_, _कामा, _कामद,
   {{0x7c22d89c,0x3ea042b5,0x200c0722,0x3eadbf3e}},	//   gnor, buit_, èdit_, ytet_,
   {{0xee8413cd,0x02a78e8e,0x3ea00162,0x2d830168}},	//   _высо, трем, cuit_, _teje_,
   {{0x785c011f,0x7d1580e1,0xb6da00be,0x27ef80e8}},	//   _učvr, úzsk, _אַלט, _sogn_,
   {{0x6449c6ff,0x89d681a8,0xa3ab864a,0xdb040362}},	//   _thei, طوير_, _खाप_, _dbiù,
   {{0x3ead8f06,0xb4c12594,0x44d32cf6,0x79850326}},	//   ttet_, ्टी_, _ić_, _lehw,
   {{0x2a64915c,0xdbdd007b,0xf1a78f75,0xfc3f01d0}},	//   _gumb_, _ráðs, _арен, dlí_,
   {{0x3ead91e6,0x41c086b7,0x6b84589d,0x7bdf3c6b}},	//   rtet_, _एसएस, _seig, _anqu,
   {{0x3eadd89e,0xed5881ac,0x6b84589f,0x25a5007b}},	//   stet_, teľa_, _peig, _öllu_,
   {{0xe29a21a6,0x3eadafc7,0x4c9a03c8,0x657aa44b}},	//   нам_, ptet_, עברו, abth,
   {{0x6b8411a9,0xfbaa000d,0xa3abd8a0,0xa806007e}},	//   _veig, _काठम, _खान_, nlış,
   {{0x6e928013,0x5e9280f7,0xfb168158,0x64a5b941}},	//   _الوا, _الوط, אַלט_, _бака,
   {{0x63a987f5,0xfc3f0013,0x6b840110,0x3e69801c}},	//   _ocen, blí_, _teig, _hút_,
   {{0x3ea058a1,0x765c0a07,0xfc3f01a8,0xe3b201a8}},	//   tuit_, _siry, clí_, _طرب_,
   {{0x66e300af,0xdee3067c,0x2fc058a2,0xab5d8372}},	// [45e0] бота, боти, reig_, _fażi,
   {{0xfdfc8996,0x3ea04b98,0xb4c11344,0x63a9baad}},	//   एसएस_, ruit_, ्टू_, _acen,
   {{0x3ea00970,0x2a648748,0xa3df8894,0xb4de06ab}},	//   suit_, _sumb_, तां_, तमे_,
   {{0x9e6600f7,0x765c1bca,0xa3da047d,0x289b03de}},	//   _ماسن, _wiry, _डोम_, _איטא,
   {{0xa3e558a3,0xa8060059,0x7c228bcb,0x3e69801c}},	//   नात_, rlığ, rnor, _nút_,
   {{0xe9188084,0xddcd18ad,0xdd921ca3,0xb5fb1075}},	//   колі_, rpaţ, _دوس_, _utáp,
   {{0x66031f7d,0xdb1d0065,0xab5b080a,0x67f580e1}},	//   _упра, resé, ndür, _nájs,
   {{0xa3d3000f,0xb4d0016f,0xa3df9ad7,0x3e6980ff}},	//   _हों_, वटी_, ताः_, _bút_,
   {{0x8d868071,0x2d98802a,0x3e69827d,0xc326ca82}},	//   лунд, óreo_, _cút_, _смак,
   {{0x3207800d,0xb5fb01a8,0xb21b0366,0x6f1d8174}},	//   chny_, _nuál, nsæt, úsca,
   {{0x0ce280c8,0x2369803a,0x7bcd0bb6,0xddcd026c}},	//   মন্ত, žaje_, _paau, npaš,
   {{0xac1902c7,0xdb550009,0xdcfa80c3,0x7bc281c6}},	//   тому_, ивны, hatć, neou,
   {{0xa3d61094,0xb21b006a,0xdd9280d7,0xa8378e82}},	//   _सफर_, ksæt, _هوش_, _גראד_,
   {{0xc3338051,0xb5fb06a5,0xfc3f016b,0xa7fb02f9}},	//   מור_, _cuál, slí_, _miñe,
   {{0xb21b006a,0x3a3a008e,0xa7fb0118,0x2f7201bc}},	//   dsæt, _dkpp_, _liñe, _ọtọm,
   {{0xc864091c,0xd9048117,0x7bdf1cb9,0xa2c5109b}},	//   стри, _ہی_, _unqu, िबद्,
   {{0xa3e8800f,0xdd9b1a1f,0x44290091,0xa7fb0388}},	// [45f0] बान_, еше_, _ija_, _niñe,
   {{0x27338104,0x628f054a,0x27218028,0xd90489a7}},	//   ợng_, msco, ẳng_, _فی_,
   {{0x644d58a4,0x628f00f7,0x27208fea,0xb4c10f0a}},	//   _khai, lsco, मपुर_, ्टे_,
   {{0x907a03c8,0xd9e30fd5,0x44291a1a,0xa7fb02f9}},	//   _שטרי, खावत_, _jja_, _biñe,
   {{0x644d0068,0x661a8057,0x628f58a5,0x442958a6}},	//   _mhai, kitk, nsco, _mja_,
   {{0x3d19035a,0xa7fb04c3,0x4095938c,0x3e69801c}},	//   _येथे_, _diñe, арит, _rút_,
   {{0x44293d5c,0xa3d601c4,0x69ad4452,0x661ad8a7}},	//   _oja_, _सफल_, _जानी, ditk,
   {{0x442958a8,0x7bc29c4f,0xe739844f,0x660380e1}},	//   _nja_, ceou, кей_, _slnk,
   {{0x0ab88416,0x3d19016f,0x4fe68162,0x249137bc}},	//   _مطلب_, _येते_, рмын_, _hvzm_,
   {{0x442933a9,0x7c298bc5,0x0f5803c8,0xed598a9f}},	//   _aja_, _hjer, ניזם_, коп_,
   {{0x644d0af9,0xe005053f,0x9d45b6ac,0x628f28f8}},	//   _bhai, रसाद_, ренд, esco,
   {{0x69c3d8a9,0x3f898125,0x6b8bd8aa,0x644d46ff}},	//   lene, _þau_, nagg, _chai,
   {{0x7c29d8ab,0x644d5000,0xeb97292d,0x7c3b8010}},	//   _mjer, _dhai, шия_, _mkur,
   {{0x412a0c8e,0x44290549,0x69c3b3b8,0x602181a9}},	//   вого_, _eja_, nene, dēmi,
   {{0x644d0c64,0x26cb0388,0x7c298216,0x2d8781e8}},	//   _fhai, _asco_, _ojer, _iene_,
   {{0x7c29d8ac,0xb8de02f1,0x69c3d8ad,0x644d0f58}},	//   _njer, _इह_, hene, _ghai,
   {{0x69c3d8ae,0xb4de0f0f,0x2d87d8af,0x46a611a8}},	// [4600] kene, तम्_, _kene_, разв,
   {{0x7c3bd8b0,0xdbdfa37b,0xe5771541,0x7c29b9b3}},	//   _akur, _síðs, изу_, _ajer,
   {{0x2d87812b,0xb21b2401,0x399b00be,0x7c29d8b1}},	//   _mene_, rsæt, _בייד, _bjer,
   {{0xa7fb0feb,0x6b8bd8b2,0x27ff8279,0x61e19193}},	//   _piñe, gagg, jkun_, _anll,
   {{0x69c3d8b3,0xe7fb05e8,0x27ed8b67,0xa3e88beb}},	//   fene, _एकता_, djen_, बाब_,
   {{0x200002a3,0xa3d30665,0x7c3bd8b4,0xa7fb05e4}},	//   lkii_, _होई_, _ekur, _viñe,
   {{0xf8069878,0x7c298b40,0xf9930039,0x661a890c}},	//   ичин, _fjer, קרה_, vitk,
   {{0x44c80459,0x200002a3,0x61e1d8b5,0x7c29d203}},	//   _iş_, nkii_, _enll, _gjer,
   {{0xa3ab9d2a,0x539b8051,0x2d87d8b6,0xa3cf800f}},	//   _खात_, _שימו, _bene_, _वोट_,
   {{0x2d87bb66,0x64428364,0x644d4e68,0xe839801b}},	//   _cene_, lloi, _shai, ější,
   {{0x2dd9093f,0x644d2081,0xd5d90158,0x4426d8b7}},	//   אַרב, _phai, אַרש, ono_,
   {{0x4426d8b8,0xef1a80c4,0x20092e6b,0x92d880ab}},	//   nno_, _име_, xhai_, াহী_,
   {{0x4426d8b9,0x200002a3,0x5457898a,0x661ad8ba}},	//   ino_, dkii_, יסטן_, pitk,
   {{0xa3e50105,0x628f58bb,0x4426d8bc,0xedd384a3}},	//   नाह_, rsco, hno_, _ويند,
   {{0x644d2081,0x04948307,0x2d8cd8bd,0x200958be}},	//   _thai, _البح, made_, thai_,
   {{0x4426935a,0x2d8cd8bf,0x6f0d07e2,0x69c3d8c0}},	//   jno_, lade_, tzac, zene,
   {{0x44268e3f,0x60d301e2,0x63ad58c1,0xac07004e}},	// [4610] dno_, _žemė, _ican, _مذکو,
   {{0x2d8cd8c2,0xa3e5123a,0x200901c5,0x69c3cd27}},	//   nade_, नाव_, shai_, xene,
   {{0x6b8bd8c3,0x2a6901e9,0x20000079,0x201e023e}},	//   tagg, _huab_, bkii_, ètic_,
   {{0x443958c4,0x4426d8c5,0x69c3d8c6,0x2d8cd8c7}},	//   nos_, gno_, wene, hade_,
   {{0x7c29830b,0x2d8cd8c8,0xf2c78098,0x44391d16}},	//   _vjer, kade_, рсен, ios_,
   {{0x443958c9,0x2d8cd5fc,0x2a6910af,0x89a8835f}},	//   hos_, jade_, _muab_, иків_,
   {{0x2d8c87e1,0x44391d93,0x7c2988cf,0x69c3d8ca}},	//   dade_, kos_, _tjer, rene,
   {{0x44392a85,0x442682a5,0x7c3bd8cb,0x7c29a767}},	//   jos_, cno_, _ukur, _ujer,
   {{0xee398abe,0x27ed86a4,0x63bb8397,0xa9c78698}},	//   лни_, rjen_, _ibun, _всек,
   {{0x2d8cc19f,0x2d8780f1,0x27ed84b1,0x7988a2cb}},	//   gade_, _qene_, sjen_, _gedw,
   {{0x443958cc,0x2d87bb80,0x6b898074,0x27edd3f4}},	//   fos_, _vene_, _keeg, pjen_,
   {{0xc0b280ff,0x27ed8168,0x26c93c86,0xdbd60032}},	//   _lưới_, qjen_, kwao_, _gùìs,
   {{0x2a6901c5,0x6b8983b2,0x63bbd8cd,0x1dc72123}},	//   _cuab_, _meeg, _mbun, रजात,
   {{0x7f3a893f,0x49990364,0x2a6901e9,0x5d8580f7}},	//   _גענו, ится_, _duab_, _الثل,
   {{0x443958ce,0x4426d8cf,0x63bb8a40,0x200058d0}},	//   bos_, yno_, _obun, tkii_,
   {{0x44391313,0x6b89b826,0x6e3c0132,0xb4fa8039}},	//   cos_, _neeg, _skrb, _תפקי,
   {{0x200002c1,0x7bc6022e,0x7c399670,0x629201d6}},	// [4620] rkii_, meku, dowr, ýkoľ,
   {{0x7bc6272e,0x4426809a,0xc0b2801c,0xbd8a003d}},	//   leku, wno_, _cưới_, انان_,
   {{0xf8a5a003,0xe0580077,0xc0b28028,0x78be1252}},	//   _تک_, _نیست_, _dưới_, _uppv,
   {{0x4426a782,0x44d7802e,0x7bc60074,0x2d8c89b2}},	//   uno_, _mă_, neku, zade_,
   {{0x6b8982a3,0xa91c8038,0x2ca58f67,0x2a69022c}},	//   _deeg, _veľm, huld_, _xuab_,
   {{0x443958d1,0xa2d902a8,0x3c320a56,0xfce65010}},	//   zos_, मित्, rávy_, _лого,
   {{0x7afd0d38,0xa3e8901b,0x443930e5,0x64a322f7}},	//   zyst, बाद_, yos_, _нара,
   {{0x44392cec,0x4fc68009,0x661e2c77,0xc7c6974f}},	//   xos_, сска, lipk, сски,
   {{0x2d8cd8d2,0xdb1d0019,0x7e7bb0e5,0x2d8a0300}},	//   tade_, tesí, gpup, _kebe_,
   {{0x63bb85f5,0x2737001c,0xa7fb01df,0x7afd0fe6}},	//   _zbun, ủng_, _miña, vyst,
   {{0x44392b56,0x44d78c6e,0xa7fb04c3,0x2d8a0133}},	//   tos_, _că_, _liña, _mebe_,
   {{0x7afd1405,0x2d8cd8d3,0x7bc6004f,0xceb40085}},	//   tyst, sade_, geku, ktə_,
   {{0xa3ab89a3,0xa7fb05a4,0x2d8cd8d4,0x2a69022c}},	//   _खास_, _niña, pade_, _quab_,
   {{0x7afd58d5,0x2d9c03a7,0xdb040118,0x2bd9116e}},	//   ryst, óvel_, _abió, _बोरा,
   {{0xa15958d6,0x61fa0106,0x7bc658d7,0x661e02f7}},	//   раву_, ötla, beku, dipk,
   {{0x2a690282,0xceb40085,0x3ea058d8,0x7bc658d9}},	//   _tuab_, ftə_, frit_, ceku,
   {{0x60250110,0x6b898074,0xf41f0198,0x798e00b4}},	// [4630] nėmi, _reeg, miä_, babw,
   {{0x7c2d24f1,0xd5674ca2,0x6b89d8da,0xf41f0009}},	//   _hjar, стап, _seeg, liä_,
   {{0x2d8a58db,0x386200b9,0x7c2d007b,0x69c758dc}},	//   _debe_, _fikr_, _kjar, meje,
   {{0x3ea04c72,0x69c70646,0xf41f0009,0x2911026c}},	//   brit_, leje, niä_, mzza_,
   {{0xdefb01bb,0x3ea007fc,0x78678061,0x6d4e81d6}},	//   _сын_, crit_, _műve, ýbaj,
   {{0x6b89d8dd,0x7bc62194,0x600a01ac,0x69d558de}},	//   _weeg, zeku, _výme, ndze,
   {{0xb5fb1ded,0x2bd48076,0xe7e581fe,0xf41f0009}},	//   _otáz, _ठोका, काला_, kiä_,
   {{0x63bb9267,0xdd0e03bf,0xfaff00f1,0x2ca580f3}},	//   _ubun, lışa, ncës_, vuld_,
   {{0x44d78c6e,0x443fd8df,0x442dd8e0,0x3f8b0b67}},	//   _să_, _iku_, _ije_, _mecu_,
   {{0xa1949e16,0x7c2d1e92,0x69c758e1,0x69d52508}},	//   _науч, _ajar, jeje, jdze,
   {{0x7c2d0a35,0x1ee78077,0x442d8353,0xfbc610f8}},	//   _bjar, _گوشی_, _kje_, обно,
   {{0x3f8b0052,0x44d7802e,0x2baa016f,0x7e7b9c70}},	//   _necu_, _vă_, _काळा, ppup,
   {{0x7bc644b3,0x69c70019,0x7c2d3232,0x798e2cf7}},	//   reku, feje, _djar, tabw,
   {{0x7bc6373a,0xc8ad9251,0xa3da0105,0x69c758e2}},	//   seku, _टमाट, _डोर_, geje,
   {{0x443fd8e3,0x442dd8e4,0x7bc622c2,0x7c2d007b}},	//   _oku_, _oje_, peku, _fjar,
   {{0x442d922b,0xfc322219,0x1dac0063,0x3ea001f7}},	//   _nje_, _تحت_, _चाहत, trit_,
   {{0xe61a2df8,0x3f8b3527,0xe7fb0665,0xc60500c8}},	// [4640] ада_, _decu_, _एकरा_, োচনা_,
   {{0x443f9e92,0x442dd8e5,0xe5a31b06,0xa7fb0e15}},	//   _aku_, _aje_, дифи, _viña,
   {{0xa91c8038,0x7e63d8e6,0x246581a9,0x741300d7}},	//   _veľk, _minp, _tēmu_, _رویا,
   {{0x66e61e16,0xdee61e25,0xa7fb04c3,0x3ea058e7}},	//   _дома, _доми, _tiña, prit_,
   {{0x2d8a02a5,0x442dd8e8,0xa3ab99a1,0xf773003d}},	//   _tebe_, _dje_, _खार_, _تاپ_,
   {{0x442dd8e9,0x443fd8ea,0x6d43817b,0xddc2a847}},	//   _eje_, _eku_, _oyna, _stož,
   {{0x9d43171c,0x23aa016f,0xf1b2009a,0x41b20441}},	//   _жерд, _कांद, _जानन, _जानस,
   {{0x8ca385e8,0x3b868e8e,0x442dd203,0xdfda8081}},	//   _कमजो, _флаг, _gje_, рък_,
   {{0xc6f787ac,0x6b82a60d,0xf41f0009,0x6d43aae8}},	//   жных_, mbog, viä_, _ayna,
   {{0x6e28a651,0x7e6381c0,0xa2d900d4,0x6d43ce54}},	//   undb, _cinp, मिस्, _byna,
   {{0x6d4381e6,0xf41f0009,0x64748221,0x69c758eb}},	//   _cyna, tiä_, ягну, veje,
   {{0x9f49008b,0x200dd8ec,0x69ad0072,0x7ee681a8}},	//   kkað_, chei_, _जाही, _وكان,
   {{0x934700f7,0x69c758ed,0xf41f0198,0xe51a801b}},	//   تخدم, teje, riä_, _फेरि_,
   {{0xf41f0364,0x1fbc80ab,0x720500f7,0x7e638420}},	//   siä_, _অফিস, أوسم, _ginp,
   {{0x69c758ee,0x290558ef,0x6d438286,0x63ab98b6}},	//   reje, ála_, _gyna, yggn,
   {{0x7c2d0458,0x533517d4,0x99830110,0x69c758f0}},	//   _ujar, _нейт, tojų_, seje,
   {{0x85569125,0x656d880a,0x70c6897d,0x356b046e}},	// [4650] _دیگر_, _şahi, लबुल, арен_,
   {{0x6440808e,0x41b206a7,0x2bb10d14,0x6b8d01a8}},	//   _akmi, _जायस, _झाडा, _heag,
   {{0x6b8d0458,0x2d810427,0x27e69210,0xdd0e2353}},	//   _keag, rbhe_, _onon_, rışa,
   {{0x7c3d1639,0x6b8290ab,0x6458023e,0xf8e480c2}},	//   nosr, gbog, _èxit, _कपड़ा_,
   {{0x7f76012a,0x6b8d3c6d,0x236982d4,0x442b58f1}},	//   _מערב_, _meag, žajo_, inc_,
   {{0x3ea932bb,0x7e6b81e2,0x6d58016b,0x2452016b}},	//   muat_, _rugp, ývac, máme_,
   {{0xc5f2036b,0x3ea958f2,0x7e63826b,0x47d480ab}},	//   _אדם_, luat_, _rinp, থানী,
   {{0xd3e3819f,0x443fd8f3,0xa7fb01df,0x6b8d0087}},	//   _تقری, _uku_, _miño, _neag,
   {{0xb4e38a27,0x7e638091,0xa3e8923a,0xe619b10c}},	//   नम्_, _pinp, बार_, йди_,
   {{0xee368009,0x443dd8f4,0xa3ab8fb2,0x201f8196}},	//   знь_, low_, _खाँ_, siui_,
   {{0xa7fb05b4,0x044605e9,0x2452016b,0x0ee80035}},	//   _niño, зенн, háme_, _ऐप्स_,
   {{0x7e639217,0x3ea90c8f,0x6d43828f,0x38978087}},	//   _winp, kuat_, _vyna, măr_,
   {{0xe72ed8f5,0x6d43809a,0xdb1d01df,0x6b8d01e4}},	//   _че_, _wyna, tesá, _deag,
   {{0x443dd11c,0x2452026f,0xbb3a80be,0xddc380eb}},	//   how_, dáme_, מערי, _minū,
   {{0xdb1d016b,0x6b8d56a3,0x38978162,0x443dd8f6}},	//   resá, _feag, năr_, kow_,
   {{0x6b9bb9ad,0x27e6165f,0x4c9a8039,0xf1c7816b}},	//   _ndug, ñon_, _השקע, _hráč_,
   {{0xe7ec82f1,0xdfcf01a8,0x6fbd92c6,0x443d99c5}},	// [4660] झाता_, ديق_, व्यू, dow_,
   {{0x273a801c,0x6b9b846d,0x656902d0,0x9f49008b}},	//   ừng_, _adug, _şehr, rkað_,
   {{0x50461317,0x14c8003d,0x6b8d05ee,0x7d01839c}},	//   _необ, تهای_, _yeag, nyls,
   {{0x3ea90867,0x6aa2d8f7,0x68e1006a,0x27f90b80}},	//   buat_, trof, ælde, _gosn_,
   {{0x7bd658f8,0x6b82cd26,0x3f920b17,0x26c200b9}},	//   _mayu, rbog, mayu_, _upko_,
   {{0x3f921cdf,0x442258f9,0x7bd658fa,0xceb302f6}},	//   layu_, hik_, _layu, _איש_,
   {{0xa3ac2e2e,0xa3cc0327,0xa3be0b9f,0x442258fb}},	//   खला_, रजा_, ीजा_, kik_,
   {{0x6aa2d8fc,0x442258fd,0xaca4019d,0x443d9bbe}},	//   prof, jik_, _chụp, cow_,
   {{0x6b8d54e5,0x442258fe,0xfaa3d0a8,0x6e21874d}},	//   _reag, dik_, _пато, filb,
   {{0xddcb87d9,0x3f92059e,0x7bd6076d,0x4498804a}},	//   ğişt, hayu_, _aayu, овою_,
   {{0x61e8d8ff,0x44223f41,0x7bd6300e,0x6b8d02f1}},	//   _indl, fik_, _bayu, _peag,
   {{0x44225900,0x1016845b,0xa7fb0216,0x61fad901}},	//   gik_, _عباد, _riño, _hotl,
   {{0x7bd65902,0x3f9206cb,0x319f81a9,0x69ca800b}},	//   _dayu, dayu_, bāzē_, oefe,
   {{0x69d8d903,0xaa64038c,0xa7fb256c,0x2452001b}},	//   ndve, етск, _piño, váme_,
   {{0x6b8d2ab6,0x61fa837f,0x7c2b8114,0x443d81b4}},	//   _teag, _motl, yngr, yow_,
   {{0x44225904,0xb8e52e04,0x3ea913f0,0x7bd63a74}},	//   cik_, _एह_, tuat_, _gayu,
   {{0x47340a7c,0x45d50162,0xdb1b807b,0x386680ee}},	// [4670] ентс, моас, _nauð, _mior_,
   {{0x443dd905,0xa3e509f2,0x2d8ed906,0x2452016b}},	//   wow_, नाक_, _jefe_, ráme_,
   {{0x69cad907,0x7c228b57,0xf9fc0039,0x7ae0d908}},	//   defe, fior, _להזמ, _armt,
   {{0x7c228698,0x4ab11344,0x61e8bae3,0x320c82f7}},	//   gior, _जमाव, _andl, _aldy_,
   {{0x3ea90722,0xe3b0936d,0xa3d512ee,0xf42a0009}},	//   quat_, ارم_, _सघन_, ltää_,
   {{0x44225909,0xe8190076,0x443dd90a,0x69cad90b}},	//   zik_, नोरा_, sow_, gefe,
   {{0x4422590c,0xf9909e44,0xf42a0009,0x7c22809a}},	//   yik_, ابه_, ntää_, bior,
   {{0x69d71045,0x7c22d90d,0xddc28110,0x2d93590e}},	//   _laxe, cior, _ruoš, laxe_,
   {{0x7bd600a4,0x3e72802e,0x442217ab,0x6e2195f8}},	//   _rayu, _cât_, vik_, tilb,
   {{0x7bd6352d,0x2d9304c3,0x49bb8077,0x7bcbd90f}},	//   _sayu, naxe_, _دارد_, legu,
   {{0x7bd60590,0x69c1aeb6,0x3866851e,0x3f8480dd}},	//   _payu, _ible, _fior_, bbmu_,
   {{0x7bcbb2be,0xea01001c,0x6e21d910,0xe825803d}},	//   negu, _đạt_, silb, _غذای,
   {{0x44220cdb,0x2480803a,0xa3ab92ee,0x2d8e8915}},	//   rik_, _čime_, _खाई_, _fefe_,
   {{0x44225911,0x7c22d912,0x7bcba27a,0xa06a16d9}},	//   sik_, zior, hegu, жава_,
   {{0x442203d2,0xd94302a4,0x69c1cfdc,0x7e7d2b47}},	//   pik_, вери, _mble, _atsp,
   {{0xdee60dd3,0x7bcbae0a,0x7b070061,0xdb0987f1}},	//   моби, jegu, örté, _oceà,
   {{0x44205913,0x69c19234,0x69d71031,0x69cac598}},	// [4680] _imi_, _oble, _faxe, yefe,
   {{0x2d8e81df,0x2d858247,0x44205914,0x69bf850a}},	//   _xefe_, nble_, _hmi_, ल्मी,
   {{0x2d85b009,0x442002d5,0x61fad915,0x136aa184}},	//   ible_, _kmi_, _rotl, ошли_,
   {{0xf7679301,0x7bcbd916,0x69c1d917,0x3f8fd918}},	//   _لا_, gegu, _able, _negu_,
   {{0x7c22d7cd,0xab5b0352,0x44205919,0x2d930118}},	//   rior, rfüg, _mmi_, baxe_,
   {{0x7c22d91a,0xc5d506b5,0x2d858088,0x273e026b}},	//   sior, _пісь, jble_, _ẹnì_,
   {{0x442010ab,0x69cad91b,0x386683a7,0x69d8d91c}},	//   _omi_, refe, _pior_, rdve,
   {{0x69c1810c,0xa3ab8b75,0x4420046d,0xf8b30039}},	//   _eble, _खाए_, _nmi_, דשה_,
   {{0xf65f013c,0xdbdd026b,0x3f8f86a2,0x7c208706}},	//   _især_, _dáìs, _degu_, _immr,
   {{0x4420591d,0x6282d91e,0xf42a0198,0x64443943}},	//   _ami_, mpoo, ytää_, _akii,
   {{0xf4be80c8,0xae1d8054,0xa3d280d4,0xd5e28032}},	//   েম্ব, योधन_, _वसा_, _awọ,
   {{0x2d9304c3,0xb5fb06a5,0x69d701b4,0x69c18af8}},	//   zaxe_, _juár, _saxe, _zble,
   {{0x27f7826f,0x4420591f,0x236d007a,0xfc3f01a8}},	//   žená_, _dmi_, žejo_, roí_,
   {{0x7e7db5d5,0x44205920,0xf42a0364,0x3494b5aa}},	//   íspe, _emi_, ttää_, _закр,
   {{0x44202a1a,0xa3de8f97,0x7e6701ed,0x7bcb9267}},	//   _fmi_, तया_, _rijp, yegu,
   {{0x23dd835a,0x7a290267,0x26c68133,0xf42a0198}},	//   _नोंद, džte, _kpoo_, rtää_,
   {{0x2d930373,0x7bcbd921,0xf42a0009,0x7e6700f3}},	// [4690] taxe_, vegu, stää_, _pijp,
   {{0x7bcbd922,0xa2dd80c2,0x6d475923,0xdd9107c3}},	//   wegu, पिस्, _pyja, اوا_,
   {{0x7bcbd924,0x2d930b6e,0x79950234,0x7d0d80fc}},	//   tegu, raxe_, mazw, _ƙasi,
   {{0x2d9304c3,0x6d4703f2,0x628480eb,0x799526b4}},	//   saxe_, _vyja, ģion, lazw,
   {{0x823403f8,0x62848012,0xc2cb8077,0x6f16009a}},	//   _سریا, ţion, تبال_, czyc,
   {{0x7bcbd925,0xa2f98b85,0x2cac804a,0x624d8118}},	//   segu, ्नौज_, kudd_, cúol,
   {{0xab5b011c,0xd49825f5,0xc8d80a27,0xa966d926}},	//   rdüy, _орт_, डिएट, ниша_,
   {{0x200901e2,0xdb0d002a,0xb5fb0216,0x764382d5}},	//   nkai_, _acaí, _guár, _skny,
   {{0x5a35ad49,0x9f590144,0x0e659617,0x79954be0}},	//   _знат, _bosé_, нкин, kazw,
   {{0x273e0142,0xac859ff9,0x272c0104,0x442f8ec9}},	//   ững_, нгол, ếng_, lng_,
   {{0x442fd927,0x2d915928,0x3f8fd929,0x656d81cc}},	//   ong_, _meze_, _tegu_, _şahs,
   {{0xafdb013c,0x442fd22c,0xfaa6014c,0x99878084}},	//   _skøn, nng_, намо, ponų_,
   {{0xe2972bef,0x442fd92a,0xef0e92b2,0x200fd92b}},	//   ная_, ing_, _см_, _ilgi_,
   {{0x645d537f,0xd25208ca,0x442f81e0,0x2fcdd92c}},	//   amsi, انس_, hng_, leeg_,
   {{0x3ead82f7,0x76418061,0x2fd91bc2,0x7e6009c4}},	//   luet_, moly, _basg_, _èmpi,
   {{0xad1a8051,0x4420592d,0xdb1b802a,0x76418106}},	//   _מוצר, _umi_, _abuí, loly,
   {{0xddc601e2,0xe7370009,0x2a7f8282,0xcfd980ab}},	// [46a0] _aukš, еет_, _ntub_, থাপন,
   {{0x9f5904c3,0x7ae4011e,0x8c96021e,0x6e4608ca}},	//   _xosé_, _irit, ерді, رنام,
   {{0x2d911dea,0x6f160063,0xe3bf01df,0xb0af01ce}},	//   _deze_, szyc, liña_, जूदग,
   {{0x69ce592e,0xe7df8996,0x69dc34b3,0x442f9400}},	//   lebe, _खोला_, ldre, gng_,
   {{0xd12f0077,0x76419e5e,0xe3bf03a8,0x2fcd9e12}},	//   _نمی_, koly, niña_, deeg_,
   {{0x442fd92f,0x69dc0cf7,0x69ce11e6,0x4a9b007c}},	//   ang_, ndre, nebe, לינג,
   {{0x6282a48d,0x69dc5930,0x03a691d0,0x442f82c4}},	//   spoo, idre, _пиво, bng_,
   {{0x7ae45931,0x69ce5932,0xd6d080f7,0x69dc0428}},	//   _orit, hebe, لقب_, hdre,
   {{0x61eb8065,0xcf268013,0x69ce5933,0x27fdd934}},	//   állí, عربي, kebe, _down_,
   {{0x4426d935,0xa3e88b9f,0x7641d936,0xba3b13fc}},	//   lio_, बाक_, goly, nuït,
   {{0xd82f814c,0x7ae40102,0x69dc22c9,0x5455066a}},	//   _бэ_, _arit, ddre, квот,
   {{0x1beb10c5,0x38ba80f1,0x8cb18035,0x2cac804a}},	//   टाइल_, mër_, _अमरो, rudd_,
   {{0x7ae435b2,0x69ce5937,0x79950a5a,0x69dc0d35}},	//   _crit, febe, tazw, fdre,
   {{0x4426d938,0x7ae45939,0x69ce593a,0x69dad93b}},	//   hio_, _drit, gebe, _jate,
   {{0x4426d93c,0x61fe0775,0x7ae437d5,0x2fc0593d}},	//   kio_, _dopl, _erit, ffig_,
   {{0x69dad521,0x23698639,0x67d412d7,0x20090084}},	//   _late, žaji_, лосу, ukai_,
   {{0x4426abc2,0xe3bf04c3,0x7ae428d1,0x23c10054}},	// [46b0] dio_, ciña_, _grit, ष्णद,
   {{0x69ce00a9,0xe45f00f2,0x442f831d,0x2009189e}},	//   cebe, lmö_, wng_, skai_,
   {{0x2d91003a,0x4426d93e,0x2a7f9d53,0xdcf880eb}},	//   _veze_, fio_, _stub_, _ievē,
   {{0xf1d98e70,0x4426c22f,0x7ae40364,0xe7fb101e}},	//   _योजन, gio_, _yrit, _एकटा_,
   {{0x69dabc7d,0x3f8912b0,0x442f8359,0xa3b918b8}},	//   _bate, mbau_, rng_, _चान_,
   {{0x69da9b90,0xc6920158,0x3ea9593f,0x442f86cb}},	//   _cate, _דאך_, mrat_, sng_,
   {{0x6b758fe7,0x6299d940,0x69dad941,0x27fd80ee}},	//   _албу, sswo, _date, _pown_,
   {{0x44269fd3,0xf094007c,0x3f8901ec,0x3ea9023e}},	//   cio_, אנק_, nbau_, orat_,
   {{0x69dad942,0x7bcf3928,0x5334d943,0x69dc23a2}},	//   _fate, decu, _бетт, ydre,
   {{0x7ae4020f,0x2fcd81e9,0xe3bf01df,0x38ba8168}},	//   _rrit, seeg_, viña_, bër_,
   {{0x6d4a8355,0x7c260110,0xa2d58d1c,0x7641d944}},	//   _cyfa, tikr, _मैत्, roly,
   {{0x3ea9414d,0xe29a28ca,0x61fe2119,0xab2a05e9}},	//   krat_, мам_, _sopl, дома_,
   {{0x69daac1d,0x69ce5945,0x7bdb820d,0xe784d946}},	//   _yate, tebe, _mauu, _сухо,
   {{0x4426d947,0x8c3d0459,0xe3bf04c3,0x7c262d75}},	//   zio_, duğu, riña_, sikr,
   {{0x69ce0542,0x7ae40051,0x290c026f,0x69dc4cd8}},	//   rebe, _writ, áda_, rdre,
   {{0x69ce029b,0x44268b6e,0xea010028,0xa3b9000f}},	//   sebe, xio_, _đất_, _चाय_,
   {{0x61fe5948,0xcf928158,0x7c245949,0x1f660a08}},	// [46c0] _topl, יטן_, _imir, ткам,
   {{0xee3724c1,0x44268114,0x9f590061,0x62860123}},	//   вну_, wio_, _alsó_, mpko,
   {{0x3ea9594a,0x4426d94b,0x7c240267,0x69dad94c}},	//   arat_, tio_, _kmir, _rate,
   {{0xdca3594d,0x3ea9594e,0x3e76013c,0x69da9d99}},	//   раци, brat_, _tæt_, _sate,
   {{0x69dad94f,0xc7b30bea,0x7c24082e,0x38605950}},	//   _pate, _דבר_, _mmir, mmir_,
   {{0x38ba820f,0x4426d951,0xa158c875,0x38600085}},	//   tër_, sio_, налу_, lmir_,
   {{0xc2130051,0x69dad952,0x7bdb8362,0xed350162}},	//   שהו_, _vate, _fauu, _бэтэ,
   {{0xc7c68dbd,0x69dab780,0xf0930039,0x7d03016d}},	//   тски, _wate, בנה_, änse,
   {{0x8d868767,0x69dad953,0x09aa00ab,0x626687b6}},	//   кунд, _tate, খ্যা, _аваа,
   {{0x7c245954,0x38ba820f,0x5fae816f,0x602786c0}},	//   _amir, për_, _टाकल, _pèmè,
   {{0x2618800c,0xa8a58b76,0x439530bb,0x7ae2a3ac}},	//   योगी_, _مصنو, ланс, lvot,
   {{0xa3e883bb,0xd9f08076,0x6abd119b,0x442480b9}},	//   बाट_, चावत_, ttsf, _jmm_,
   {{0x9f590698,0x6d58016b,0x7bcf0162,0x7c2402a6}},	//   _così_, ývaj, recu, _dmir,
   {{0x7c240c56,0x7bcf3a5d,0x3ea924c8,0x6abd04e1}},	//   _emir, secu, vrat_, rtsf,
   {{0xb4d101ab,0xef19809a,0x4424822b,0x19940c07}},	//   _वने_, daży_, _omm_, рася,
   {{0xe3bf062f,0x3ea94515,0x3d0e8075,0x6e288289}},	//   miño_, trat_, ानीं_, lidb,
   {{0x9f555955,0x3ea95956,0xe3bf01df,0x7ae2811f}},	// [46d0] увач, urat_, liño_, jvot,
   {{0x3ea95957,0x80b880ab,0xa567004e,0x28ce02f1}},	//   rrat_, _আনন্, ندان, _हैकि,
   {{0x629d358e,0x3ea95958,0xd371880b,0x7bdb82d5}},	//   lsso, srat_, مها_, _pauu,
   {{0x3ea95959,0xfbdf041c,0x2d9c0118,0x7640008b}},	//   prat_, ndê_, óver_, _ímyn,
   {{0x629d2210,0x59c00bc2,0xeabf01e8,0xe3bf0118}},	//   nsso, श्वर, ntù_, hiño_,
   {{0x26d900a9,0x2a6c80ee,0x6e2889d1,0x2fc682c4}},	//   _isso_, _cidb_, jidb, _abog_,
   {{0x04678a28,0x74f70061,0xfbab0264,0x9f4001fa}},	//   _атам, _جہاز_, গ্যত, ljið_,
   {{0x31580039,0x629d0bcb,0xe3bf28cf,0xdb1d1277}},	//   כיון_, ksso, diño_, besø,
   {{0x2f548c8e,0x601580e1,0x98be8084,0x2907927a}},	//   итьс, _náme, _rytą_, syna_,
   {{0x7c24011f,0x8ca48128,0x3201026f,0x629d595a}},	//   _smir, _किशो, _nohy_, dsso,
   {{0x25e88d86,0xdb00d95b,0x629d1388,0x3860595c}},	//   जाजी_, _admè, esso, ymir_,
   {{0x629d2578,0x26d91a4e,0xdd4103f7,0x6e95841c}},	//   fsso, _osso_, _aŋŋa, _биду,
   {{0x2bc5835a,0x645b9a2f,0x8f9a8039,0xd90f8065}},	//   ळ्या, _mhui, _ניסי, _دیں_,
   {{0x2fc6803b,0x9f5907f1,0xad2481f9,0xddc38493}},	//   _zbog_, _cosí_, اریو, _dinţ,
   {{0xf6528051,0x07a605d3,0x2fdd81e9,0xe3bf01df}},	//   _הצג_, лавн, _kawg_, ciño_,
   {{0x27ef808e,0x2fdf8122,0x629d0bcb,0x6286595d}},	//   _jngn_, ndug_, bsso, ppko,
   {{0x823603f8,0x6f09d95e,0x63a4595f,0x60158144}},	// [46e0] _مردا, nyec, _idin, _gáme,
   {{0x64465960,0x645b819d,0xdcfc01a1,0xa37b041c}},	//   loki, _ahui, _serđ, rdõe,
   {{0x6b965961,0x645b925b,0x6015826f,0x26d90081}},	//   _keyg, _bhui, _záme, _esso_,
   {{0x645b9523,0x0ecf000f,0xdb19809a,0x69de5962}},	//   _chui, _सैकड, jewó, _hape,
   {{0x645b8ad0,0x244e827f,0x69c38252,0x141781a8}},	//   _dhui, nými_, ffne, دينة_,
   {{0x200200dd,0x27e05963,0x69de5964,0xa3e491bc}},	//   _hoki_, ldin_, _jape, _भोर_,
   {{0xa3e405b3,0x69de5965,0xed5724dc,0x64465966}},	//   नया_, _mape, _бор_, koki,
   {{0x27e05967,0xb8cc81b6,0x69de5968,0x8c469c9b}},	//   ndin_, _कट_, _lape, _себе,
   {{0x26c00114,0x644606a2,0x27ef89da,0x60e08110}},	//   ntio_, doki, _dngn_, _žymė,
   {{0x63a45969,0xe3bf2a95,0x2d9a596a,0x60158c83}},	//   _adin, tiño_, nape_, _cámb,
   {{0x85f70158,0x6e28d96b,0x3d0e8035,0x1dc609c2}},	//   אציע_, ridb, ानें_, र्यत,
   {{0xe3bf0feb,0x64460102,0x629d236b,0x6e288503}},	//   riño_, goki, tsso, sidb,
   {{0x27e0596c,0xe60f8077,0x34d100bc,0x2d9a009e}},	//   ddin_, زشی_, _सन्द, kape_,
   {{0x629d2210,0xeabf047f,0x628401a8,0x2fdd81c0}},	//   rsso, rtù_, _dtio, _zawg_,
   {{0x69de0072,0x2002596d,0x2fdd81c5,0x7d7b83de}},	//   _dape, _boki_, _yawg_, _אנוו,
   {{0x6c8380f7,0x6015802a,0xf7730250,0xa2ad0072}},	//   _اليم, _táme, صار_, _जिप्,
   {{0xc05801e5,0x2002596e,0x442b596f,0xa3cb00d4}},	// [46f0] уір_, _doki_, mic_, _रॉय_,
   {{0x442b5970,0x6449c43c,0x645b808c,0x60da82f1}},	//   lic_, _skei, _shui, _ostm,
   {{0x5c0785e9,0xdcf500eb,0x2002039c,0x6f1b80e5}},	//   ляда, _iezī, _foki_, zzuc,
   {{0xd5642ce0,0x69de0942,0x7bdf26f6,0x1e01816f}},	//   ступ, _zape, _jaqu, _लक्ष_,
   {{0x26c05971,0xfaa79c56,0x68e88114,0x2fdd81c0}},	//   ctio_, ушен, _ardd, _rawg_,
   {{0x442b1c4f,0x7bdf00e7,0x20022a06,0x7c9731a7}},	//   hic_, _laqu, _zoki_, _مشرا,
   {{0x645bd972,0x20020176,0x6ce400e8,0x2fdd81c5}},	//   _thui, _yoki_, _літе, _pawg_,
   {{0x7bdf0548,0x442b1f66,0x2fdd81c0,0xa92804e8}},	//   _naqu, jic_, _qawg_, loží,
   {{0x442b5973,0xf1a78a29,0xcdf581bb,0xddcb80eb}},	//   dic_, _брен, ачны, _augš,
   {{0x7c2bd974,0x3ebfd791,0x7ae98091,0x244e803e}},	//   ligr, rtut_, _iret, vými_,
   {{0x69de1495,0x64462af2,0x442b0927,0x62842dde}},	//   _rape, toki, fic_, _stio,
   {{0x69de5975,0x8c460dbd,0x0446197d,0x442b1bb4}},	//   _sape, реме, ремн, gic_,
   {{0x7bdf0548,0x20025976,0x63a48174,0x32181075}},	//   _daqu, _roki_, óini, thry_,
   {{0xc332804c,0x20025977,0x3ead8bbd,0x244e9dc5}},	//   קום_, _soki_, mret_, rými_,
   {{0x69de5978,0x2d9a05f3,0x245c816b,0x7c2b8122}},	//   _vape, vape_, líme_, kigr,
   {{0x63a45979,0x69de0c85,0x6ca4804e,0x6d4e0690}},	//   _udin, _wape, _اصول, _ryba,
   {{0x27e0597a,0xa0671289,0xdce18182,0x18672f33}},	// [4700] rdin_, рата_, malı, рати_,
   {{0x66038364,0xe6172e35,0x26c05636,0xe5a60012}},	//   _jonk, аду_, rtio_, рижи,
   {{0xeb9a9d20,0x7ae9d97b,0x2d9a597c,0x2002597d}},	//   вие_, _aret, rape_, _toki_,
   {{0xa2ad01c4,0x6d4e027f,0x7ae98625,0x7d03016d}},	//   _जिम्, _vyba, _bret, änsa,
   {{0x245902be,0x60180019,0x3ead806a,0x60da80b9}},	//   néma_, _címe, jret_, _sstm,
   {{0x7ae9d8b5,0x5bd3123a,0x245c9c32,0x3ead8f06}},	//   _dret, _तस्व, díme_, dret_,
   {{0x64a31958,0x8ccd005e,0x7ae9d97e,0x05c6016f}},	//   _мара, _सहयो, _eret, र्णब,
   {{0x8c438676,0x2d9800f8,0x442b02e6,0x7ae9d97f}},	//   _десе, _here_, xic_, _fret,
   {{0x2d985980,0x6603805d,0x7bdf16dc,0x3ead8687}},	//   _kere_, _bonk, _raqu, gret_,
   {{0x59b206a7,0xa3b901ce,0x9a6a8872,0x2d9827eb}},	//   _जागर, _चाह_, _شمال_, _jere_,
   {{0x2d985981,0x442b1bb4,0x660380c9,0xa17b83c8}},	//   _mere_, tic_, _donk, _סטאט,
   {{0x2d981741,0x3ea05982,0x245c816b,0x3eadd983}},	//   _lere_, ksit_, bíme_, bret_,
   {{0x3ead8e22,0x6603d984,0x799c031d,0x60180118}},	//   cret_, _fonk, farw, _oímb,
   {{0x442b5985,0x2d985986,0x3f8216ea,0x799c5987}},	//   sic_, _nere_, _afku_, garw,
   {{0x442b5988,0x6d5880eb,0x3ea000f1,0x76489106}},	//   pic_, _uzva, esit_, mody,
   {{0x34fb8bea,0x6603805d,0x2d985989,0x20d8801c}},	//   _יהוד, _zonk, _aere_, _mũi_,
   {{0x2d98598a,0x799c598b,0x6603805d,0x7c2b96f2}},	// [4710] _bere_, barw, _yonk, vigr,
   {{0x7ae9820f,0x27338104,0x2d98002e,0xb8dd00ab}},	//   _rret, ảng_, _cere_, _ইন_,
   {{0x7ae9a43e,0x69d5598c,0x2d98598d,0x245c801b}},	//   _sret, meze, _dere_, zíme_,
   {{0x69d5598e,0x25fb22bd,0x3eadc944,0x37ac80ab}},	//   leze, लॉजी_, yret_, ক্তর,
   {{0x44290a2c,0xf1ec023c,0x2d98598f,0x3ea00019}},	//   _mma_, _छोड़_, _fere_, csit_,
   {{0x2d985990,0x2ba78028,0x409582a4,0x245c826f}},	//   _gere_, ốc_, брит, víme_,
   {{0x442934b0,0xb7bd802e,0x3f990da8,0x9f4b01ca}},	//   _oma_, liţi, _kesu_, _tocó_,
   {{0x01381a15,0x3f995991,0x2d815992,0x44290135}},	//   ירות_, _jesu_, lche_, _nma_,
   {{0x69d55993,0x7c29d994,0x6015840e,0x7ae9a557}},	//   keze, _imer, _cáma, _uret,
   {{0x44295995,0x2d815996,0xe6169ae5,0x644d4fd9}},	//   _ama_, nche_, йды_, _akai,
   {{0x2d813f8f,0xeb9a24dd,0x61e1d997,0x660380e1}},	//   iche_, лин_, _iall, _vonk,
   {{0x61e1b480,0x3f992211,0x6603805d,0x6b9d1ab0}},	//   _hall, _nesu_, _wonk, gasg,
   {{0x61e1d998,0x7c299292,0x799c04b9,0x8e85d999}},	//   _kall, _mmer, tarw, _угле,
   {{0x4429599a,0x644d0102,0x27ff81b9,0x661a8f67}},	//   _ema_, _ekai, ljun_, chtk,
   {{0x2d98599b,0x7c29b11a,0xfbdf03a7,0x799c599c}},	//   _rere_, _omer, glês_, rarw,
   {{0x61e184b9,0x2d98599d,0x3ea050ee,0x3205802a}},	//   _lall, _sere_, tsit_, _loly_,
   {{0x2d98599e,0x69d5599f,0xee3a0d9d,0x6b8459a0}},	// [4720] _pere_, beze, гна_, _ifig,
   {{0x82360077,0xc333010f,0x3ea059a1,0x9f404edd}},	//   _دربا, _מוח_, rsit_, ndié_,
   {{0xd91009d7,0x44290355,0x2d98021e,0x3ea059a2}},	//   _غیر_, _yma_, _vere_, ssit_,
   {{0x2d9859a3,0xa3cb0327,0xeb9a8591,0x3ea059a4}},	//   _were_, र्प_, اضات_, psit_,
   {{0x7c3bd9a5,0x2d9859a6,0x6a6002af,0xdcfa81a9}},	//   _djur, _tere_, röff, tatī,
   {{0x2d810081,0x61e1d9a7,0x7c29d9a8,0x27e20326}},	//   cche_, _call, _emer, _hakn_,
   {{0x3f992fa7,0xa3b9146d,0x61e19140,0x845a97c8}},	//   _yesu_, _चाल_, _dall, _брат_,
   {{0x6c3684e3,0x61e18219,0x7c3b8168,0x68e100ec}},	//   _افرا, _eall, _gjur, ældi,
   {{0x628004c3,0xa3cb3d6d,0x69d50019,0x7de68071}},	//   ímol, र्फ_, yeze, бінд,
   {{0x645f0b18,0x644d1d76,0xa3cb04c5,0x2d98d9a9}},	//   _shqi, _skai, र्न_, úre_,
   {{0x764881e2,0xb7bd802e,0x69d50019,0xf8ac8105}},	//   rody, ziţi, veze, _घटिय,
   {{0x69d53bbe,0x61e1d9aa,0xdb04002a,0x25a78118}},	//   weze, _zall, _aciñ, _ednl_,
   {{0x69d5358b,0x442959ab,0x61e18326,0x6d5c00b9}},	//   teze, _vma_, _yall, _lzra,
   {{0x98dc83eb,0xf8dc83a4,0x61e1d9ac,0x6b8402df}},	//   _मनाए, _मनाय, _xall, _efig,
   {{0x95838063,0x69d559ad,0x5d9b8039,0x2d9ed9ae}},	//   łącz, reze, _גבוה, mate_,
   {{0x442959af,0xb90112ee,0x69d559b0,0xdb008118}},	//   _uma_, _धन_, seze, _admí,
   {{0x200690f4,0x443959b1,0x69d50fe0,0xd6d70264}},	// [4730] _mooi_, mns_, peze, সম্প,
   {{0x443959b2,0x7c2995d8,0xdb0402af,0x799a967c}},	//   lns_, _smer, _heiß, _netw,
   {{0x2d8105ed,0x44393885,0x2264001b,0x9379846e}},	//   rche_, ons_, řské_, абет_,
   {{0x443959b3,0x2d811736,0x61e1d9b4,0x7c2f002a}},	//   nns_, sche_, _sall, nicr,
   {{0xa3cb00d4,0x81e280c8,0x799a8051,0x443959b5}},	//   र्य_, ধান_, _betw, ins_,
   {{0x2d9ed9b6,0x61e1d9b7,0x7aed53d4,0x20898081}},	//   jate_, _qall, _mrat, айки_,
   {{0xf8a98077,0x61e1a0a2,0xb4c78006,0x799a83ec}},	//   شگاه_, _vall, _उहे_, _detw,
   {{0xa3cb00d4,0x7c29c22b,0x6b828081,0x20c1818d}},	//   र्म_, _umer, ccog, rói_,
   {{0x61e1d9b8,0xd5c6000c,0x442fd9b9,0xa3dd0b9f}},	//   _tall, र्वज, mig_, ड़न_,
   {{0x442fd9ba,0xdce508c5,0xf993830f,0xfc40016b}},	//   lig_, lahı, _ربط_, čím_,
   {{0x7aed59bb,0x63a48125,0x6d468214,0xa3cb0cf0}},	//   _arat, ðing, şkan, र्भ_,
   {{0x7aed59bc,0x442f843c,0xd7e48221,0x6b9b838e}},	//   _brat, nig_, _нічо, _jeug,
   {{0xab5b01ec,0x93463941,0x29050106,0x2d9ed9bd}},	//   nfüh, інге, älan_, bate_,
   {{0x2d9ed9be,0xca7a810f,0xe81c000c,0x6b9b8014}},	//   cate_, ינשט, नसभा_, _leug,
   {{0xa3b99d2a,0x442fd9bf,0x63a9a642,0x5fddcda8}},	//   चला_, kig_, _oden, _मसाल,
   {{0x63a9d9c0,0x6b9bd9c1,0x7aed59c2,0x6015d9c3}},	//   _nden, _neug, _frat, _mámo,
   {{0x442fd9c4,0x562a28e6,0x644b8114,0xaa7b016b}},	// [4740] dig_, ажам_, dogi, jvýh,
   {{0x6607026c,0x7e560221,0x237f01d6,0xdd1c01d6}},	//   _cojk, ітац, ľuje_, ráža,
   {{0x442fd9c5,0x237f59c6,0x16000540,0x6b9bd9c7}},	//   fig_, žuje_, लॉगर_, _beug,
   {{0x2d9ed9c8,0x442fd9c9,0xab5b0799,0x6aa2c792}},	//   zate_, gig_, ffüh, tsof,
   {{0x2d9ecb34,0x200681b0,0x6aa80105,0x63a9abe5}},	//   yate_, _rooi_, _कटोर, _dden,
   {{0xaab2023c,0x6b82957a,0x6aa2d9ca,0x660701dd}},	//   _जिनक, scog, rsof, _gojk,
   {{0xa3cb0a3a,0x442f849f,0x6b9ba4de,0x2d9ed9cb}},	//   र्ड_, big_, _feug, vate_,
   {{0x63a4808b,0x644bd9cc,0x442fa4c2,0x6015bad7}},	//   ðind, cogi, cig_, _dámo,
   {{0x2d9eb672,0x601c8019,0x41ca052a,0x4439006a}},	//   tate_, _néme, िभास, vns_,
   {{0x70f6990c,0x443959cd,0x63a9936f,0x200680b9}},	//   _وسائ, wns_, _zden, _wooi_,
   {{0x7d7b0039,0xd7fa8d8e,0x7aed051e,0x69d888e0}},	//   יניו, _вул_, _srat, meve,
   {{0x2d9ed9ce,0x443959cf,0xd7ef80f7,0x24590118}},	//   sate_, uns_, _لكم_, rémo_,
   {{0x78758110,0x106980f7,0x47369459,0x443959d0}},	//   _išva, _احلى_, _براز, rns_,
   {{0x442f8a0f,0x644bd9d1,0xdb0401ec,0x3ea6826c}},	//   zig_, zogi, _weiß, _ivot_,
   {{0xcf9b0fbb,0x69c307d9,0x442fd9d2,0x6018007b}},	//   ија_, _önem, yig_, _síma,
   {{0x69d8d9d3,0x2ee9826c,0x442fd9d4,0x2d9c8163}},	//   heve, _šafi_, xig_, _heve_,
   {{0xa3cb0b6f,0x7aed59d5,0x7c2d59d6,0x660759d7}},	// [4750] र्ण_, _urat, _imar, _pojk,
   {{0x69d88988,0x442fd9d8,0x63bd59d9,0x2fc9183d}},	//   jeve, wig_, lgsn, sfag_,
   {{0x442f8c1b,0x69d89b37,0x7c2d0295,0x628f4b66}},	//   tig_, deve, _kmar, lpco,
   {{0x2d9cd9da,0x60180125,0x3eb2068f,0x601c887a}},	//   _leve_, _tíma, bryt_, _lémb,
   {{0x442f92af,0x38690687,0x61e5005d,0x7c2d59db}},	//   rig_, mmar_, _kahl, _mmar,
   {{0x69d8cbc1,0x442fd9dc,0x2d9cd9dd,0xaca301bc}},	//   geve, sig_, _neve_, _ahụa,
   {{0x442fd9de,0xb8820ed7,0xe4a40e97,0x7c2d59df}},	//   pig_, žíva, _орто, _omar,
   {{0x386959e0,0x63a9813c,0xb8d383db,0x97d980e8}},	//   nmar_, _uden, _झट_, ську_,
   {{0x442dd9e1,0x443f8135,0x386959e2,0x2d9c80e5}},	//   _ime_, _iju_, imar_, _beve_,
   {{0x7c2d59e3,0x61e5003e,0x8c0800c8,0x69d8d9e4}},	//   _amar, _nahl, _লগইন_, ceve,
   {{0x2d9c98a0,0x442d82c4,0x443f81a1,0x7e7559e5}},	//   _deve_, _kme_, _kju_, _mizp,
   {{0xca29004c,0x38690088,0x63bd0711,0x88838019}},	//   _גם_, jmar_, ggsn, _ٹیکن,
   {{0x442dd9e6,0x7e7d59e7,0x61e50234,0x5ed300ab}},	//   _mme_, _nusp, _bahl, সিডে,
   {{0x7e688122,0x60338493,0x61e517c9,0xbfa107b6}},	//   cmdp, rămu, _cahl, ãªnc,
   {{0xfe708288,0x442dd9e8,0x443f90ab,0x7e7d59e9}},	//   _شده_, _ome_, _oju_, _ausp,
   {{0x7e7d0088,0x06863941,0x7e7559ea,0xbb460110}},	//   _busp, зган, _aizp, _нейк,
   {{0x7e7d0083,0xd00746dd,0x441b007c,0x69d8d9eb}},	// [4760] _cusp, чете_, _לוקס, yeve,
   {{0xa3e4ae04,0x442dd9ec,0x443f8d62,0x9f42001b}},	//   _भोज_, _ame_, _aju_, _jaké_,
   {{0x7c2d0114,0xdcfc00eb,0x442dd9ed,0xb33b041c}},	//   _ymar, _ierī, _bme_, maça,
   {{0x61e559ee,0xb33b59ef,0x69d88039,0xe4529a3e}},	//   _zahl, laça, weve, رضا_,
   {{0xcfc380c8,0x201f804f,0xfbc104c5,0x2bc101cb}},	//   ্যান, dhui_, ष्टम, ष्टा,
   {{0x442d8a2c,0x64a60221,0x443fd9f0,0xb33b1b0d}},	//   _eme_, _нага, _eju_, naça,
   {{0x69d8d9f1,0x2d9ca218,0x672459f2,0x7bd98c4d}},	//   reve, _reve_, lzij, bewu,
   {{0xa2ad2aef,0x69d8b00e,0xd01080f7,0x6011108c}},	//   _जिल्, seve, ئلة_, _påmi,
   {{0xc6f787ac,0x5eca00ab,0x63a29ffc,0xba3d801b}},	//   зных_, রিকে, maon, _kvůl,
   {{0x1dcf0c78,0xab5b1209,0x6018016a,0x63a2d9f3}},	//   स्पत, ngüe, _oímo, laon,
   {{0x386900fc,0xa3cb0006,0x442dd9f4,0x9f4701d0}},	//   ymar_, _रउआ_, _yme_, ěné_,
   {{0x63a2b298,0x25a101ec,0x61e559f5,0xbb940198}},	//   naon, zahl_, _sahl, нающ,
   {{0x61e51295,0x2d9c8073,0x601cd9f6,0xc9052770}},	//   _pahl, _teve_, _témb, रह्म_,
   {{0x27e681a8,0x2600104f,0x63a29b9c,0x7e7d59f7}},	//   _haon_, राफी_, haon, _rusp,
   {{0x2600090f,0x63a2d9f8,0x799e06c4,0x3d2288f9}},	//   रानी_, kaon, _depw, _déwé_,
   {{0x61e559f9,0x7c2d59fa,0x63a2d9fb,0x25a10192}},	//   _wahl, _umar, jaon, wahl_,
   {{0x644f11b9,0xdce882bb,0x63ad59fc,0xf77f2761}},	// [4770] moci, madı, _idan, _caça_,
   {{0x442d8038,0xdce883bf,0x443f8b64,0x628d0c53}},	//   _sme_, ladı, _sju_, _itao,
   {{0xf65016a5,0x443f808e,0xb88301d0,0x7c3d59fd}},	//   ائق_, _pju_, říbr, onsr,
   {{0x644f59fe,0xf77f0073,0xd3719368,0x63a2d9ff}},	//   noci, _faça_, نها_, gaon,
   {{0x27e95a00,0x443f8088,0x91e5b9d0,0x9f4b02df}},	//   mdan_, _vju_, доле, _cocô_,
   {{0x2d850006,0x27e90b0b,0x200b00e1,0xdb1d0106}},	//   _üle_, ldan_, _hoci_, besö,
   {{0xa3dd101b,0x94d40dc0,0x200b2407,0x2489826c}},	//   ड़ा_, _порц, _koci_, _čamo_,
   {{0x27e902fa,0x63ad33ac,0x442dda01,0xd0f80039}},	//   ndan_, _ndan, _ume_, למות_,
   {{0x26c92c57,0x200b5a02,0xdce887c0,0x627980e1}},	//   ntao_, _moci_, dadı, _dňoc,
   {{0x63ad0d53,0x27e90046,0xa3cb235e,0x7b7481a8}},	//   _adan, hdan_, र्स_, _أطفا,
   {{0x1dcf000c,0x044611d2,0x672401b9,0x628d5a03}},	//   स्यत, денн, zzij, _atao,
   {{0x200b07df,0x3f1595f7,0x629b81bc,0x443d8114}},	//   _noci_, _одес, _kwuo, nnw_,
   {{0x9f42000d,0x0cba0bb8,0xe72e9fb1,0x27e95a04}},	//   _také_, _उम्म, _ре_, ddan_,
   {{0xf77f3a50,0x6724026c,0x628d01a8,0x1dcf052a}},	//   _raça_, vzij, _dtao, स्मत,
   {{0x63a2da05,0x200b5a06,0xb33b5a07,0x6b89823e}},	//   yaon, _boci_, raça, _ofeg,
   {{0x27e92435,0x6f168063,0x644f0baf,0x998d0668}},	//   gdan_, _życi, coci, đeš_,
   {{0x200b0052,0x63a2c955,0xb33b5a08,0x6da63e1c}},	// [4780] _doci_, vaon, paça, диза,
   {{0x6b898813,0x69cd03b7,0x7ae4005d,0x63a28010}},	//   _afeg, द्दी, _isit, waon,
   {{0x1dcf84e5,0xa3cb03dd,0x63a287fe,0x614603bd}},	//   त्यत, र्व_, taon, _цена,
   {{0x69dc2315,0x200b0bda,0x9f42816b,0x69ce074c}},	//   lere, _goci_, žké_, lfbe,
   {{0x27e68083,0x34dada09,0xb3c600d4,0x78bc00b9}},	//   _raon_, _बन्द, _वानख, lurv,
   {{0x2bae8028,0x201d84bf,0x6b898133,0x7ae4004f}},	//   ộc_, _alwi_, _efeg, _msit,
   {{0x63a28b6d,0x6443816a,0x69dc30fe,0x27e6a737}},	//   paon, énic, iere, _paon_,
   {{0x69dc5a0a,0xb8d69664,0x2fc05a0b,0x7ae45a0c}},	//   here, _जि_, ngig_, _osit,
   {{0x69dc5a0d,0x6fd00b9f,0x6015826f,0x19c697c8}},	//   kere, ड्यू, _zámk, _обам,
   {{0x69dc5a0e,0x7c2280a9,0x660a82a3,0x601c82be}},	//   jere, lhor, _qofk, _déma,
   {{0xf9c78bca,0x45b70051,0x27e69882,0x27e95a0f}},	//   _تحقی, ופיל_, _taon_, ydan_,
   {{0x61e882a3,0x6280da10,0x63a0826f,0x7c22a388}},	//   _hadl, _kumo, _jemn, nhor,
   {{0xdce8862a,0x6280da11,0xa3cb123a,0x61ca0054}},	//   radı, _jumo, र्ष_, िभूष,
   {{0x69dc2291,0x200b3cc3,0x644f3428,0x63a08087}},	//   gere, _soci_, soci, _lemn,
   {{0x7ae44c61,0x6280da12,0x27e90085,0x61e89a7e}},	//   _esit, _lumo, tdan_, _madl,
   {{0xb907023c,0x63ad5a13,0xe3d0001c,0x7c2283c1}},	//   _मई_, _udan, _hằng_, jhor,
   {{0x69dc5a14,0x27e95a15,0xfc3f000d,0x200b5a16}},	// [4790] bere, rdan_, mní_, _voci_,
   {{0xfc3f03bb,0x61e882a5,0x69dc5a17,0xea010028}},	//   lní_, _nadl, cere, _đặt_,
   {{0x26c90fda,0x69c50870,0x29198201,0x27e95a18}},	//   stao_, _iche, _əsas_, pdan_,
   {{0xfc3f5a19,0x27e90085,0x68e55a1a,0x200b017f}},	//   nní_, qdan_, _ishd, _uoci_,
   {{0x1dc70105,0x320c8e25,0x63a0da1b,0x62809495}},	//   _लापत, _body_, _demn, _cumo,
   {{0xaab20063,0x0d840fe6,0x11d981a8,0x260003dd}},	//   _जिसक, _алён, سوعة_, राणी_,
   {{0x69c5022e,0x3ea95a1c,0xe0d18019,0x61e8da1d}},	//   _mche, lsat_, ازت_, _dadl,
   {{0x69dc5a1e,0x3866bf8f,0xfc3f03fb,0x61fa81ec}},	//   zere, _chor_, jní_, _entl,
   {{0xfc3f03bb,0x69dc5a1f,0xe3d00104,0x7a2202be}},	//   dní_, yere, _bằng_, _hôte,
   {{0x6cea9094,0x69dc08f1,0x69c50870,0xe3b2026a}},	//   टिंग_, xere, _nche, گرد_,
   {{0x2600035a,0x25e0800d,0x69dc5a20,0x60158511}},	//   राती_, _कसरी_, vere, _lámi,
   {{0x69c55a21,0xeb970364,0x601c801b,0xccf200be}},	//   _ache, нию_, _téma, אכט_,
   {{0x386d8bbd,0x6015da22,0x81e28264,0x6d588380}},	//   mmer_, _námi, ধার_, _eyva,
   {{0x64a58721,0x386d8687,0x3ea95a23,0x442203ed}},	//   _зака, lmer_, dsat_, shk_,
   {{0xfc3f000d,0x25a5da24,0xa3cb00d4,0x3ea90706}},	//   bní_, mall_, _रॉक_, esat_,
   {{0x69c5082e,0x69dc589e,0x7bdd5a25,0x7ae40074}},	//   _eche, sere, cesu, _tsit,
   {{0x69dc5a26,0x63a65a27,0x9f420247,0x3ea90122}},	// [47a0] pere, makn, _ankò_, gsat_,
   {{0x63a08012,0xa3c0073c,0x63a62e55,0xf77f03a7}},	//   _semn, ुभव_, lakn, _faço_,
   {{0x399b0451,0x44e181e2,0x3ea903ac,0x386d81ac}},	//   _מייד, _jų_, asat_, kmer_,
   {{0xf76791ac,0x63a65a28,0xc5f880eb,0x628082c4}},	//   _ما_, nakn, nmēr_, _pumo,
   {{0xa3b80c1c,0x81e980ab,0x087700be,0xafdb004a}},	//   _चयन_, যান_, _רעכט_, _kjøn,
   {{0x7c22da29,0xc33300be,0x7bdd5a2a,0x63a6010b}},	//   shor, נוג_, zesu, hakn,
   {{0x44202da0,0x320c803e,0xe643035f,0xe3d00028}},	//   _oli_, _vody_, _серп, _rằng_,
   {{0xc6f8ae9f,0x63a609da,0xefb2803d,0x320c809a}},	//   дних_, jakn, ایشگ, _wody_,
   {{0xfc3f03bb,0x63a60500,0x25a58fb6,0xc24695da}},	//   vní_, dakn, fall_, _знак,
   {{0xceb3004c,0x25a5da2b,0x64470115,0x7ed381a8}},	//   נית_, gall_, čkim, ازيا,
   {{0x439519bb,0xfc3f03bb,0x4420179a,0x60180019}},	//   канс, tní_, _bli_, _címk,
   {{0x63768182,0x69c55a20,0x63a60886,0x6d58816b}},	//   _günü, _sche, gakn, _vyva,
   {{0x25a5da2c,0xfc3f000d,0xb33b5a2d,0x69c50953}},	//   ball_, rní_, raço, _pche,
   {{0x44205a2e,0x171b8158,0xfc3f001b,0x7af68198}},	//   _eli_, _צוגע, sní_, äyty,
   {{0x9f47000d,0xa2ad01ce,0xfc3f03fb,0xb33b5a07}},	//   ění_, _जिक्, pní_, paço,
   {{0x44200021,0x601c82be,0x63a6008e,0x36d5310c}},	//   _gli_, _mémo, cakn, кобр,
   {{0x2bc60c78,0x69c503ec,0x50645a2f,0xfc4001d0}},	// [47b0] _वाता, _tche, утра, čít_,
   {{0x69c55a30,0x4420012b,0x645d3b6d,0x63a4807b}},	//   _uche, _zli_, llsi, ðinn,
   {{0x09bf8a49,0xe1ff8104,0x3ea95a31,0x44200364}},	//   _ইসলা, _đó_, ssat_, _yli_,
   {{0xa3d4000f,0x69cd10c8,0xdb1b8511,0x3ea9001b}},	//   स्प_, द्री, _acuá, psat_,
   {{0xfbd306bf,0x2bd3024c,0x645d01a8,0xdb00810c}},	//   ध्यम, ध्या, ilsi, _jemè,
   {{0xdc138059,0xdb008168,0x1a9c00be,0xf2d403de}},	//   rşıs, _zemë, לידע, רעס_,
   {{0x63a632bb,0x25a5da32,0x6d420087,0x2ee681b0}},	//   yakn, vall_, şoar, _asof_,
   {{0x601cda33,0x8f75c26b,0x75288ec3,0x7f758c75}},	//   _démo, купі, dzdz, купц,
   {{0x386dda34,0x25a5da35,0x2459026f,0x63a65a36}},	//   rmer_, tall_, nému_, vakn,
   {{0x273e0028,0xa3d406b7,0x6b8d0032,0x386dda37}},	//   ắng_, स्न_, _afag, smer_,
   {{0x44200247,0x63a600ce,0x25a35a38,0x9d4581a1}},	//   _pli_, takn, _mejl_, тенд,
   {{0x66b5a8fb,0x2459016b,0x3de180ab,0x44200037}},	//   _абду, kému_, বাইল, _qli_,
   {{0x8af002bf,0xe3b80182,0x27ed8584,0x25a5da39}},	//   _azər, ğı_, mden_, pall_,
   {{0xe3b80059,0x27edc90b,0x63a63090,0xe3d580ab}},	//   şı_, lden_, sakn, _সোমব,
   {{0x69c3da3a,0x63a64560,0xe9a32f07,0x3ebfda3b}},	//   igne, pakn, расп, luut_,
   {{0x27ed977a,0x44203cb2,0x7848801b,0xf7721c2c}},	//   nden_, _uli_, pěve, لاء_,
   {{0x27edd5ef,0xe7371269,0x26cd8511,0x3ebf8cfa}},	// [47c0] iden_, вет_, nteo_, nuut_,
   {{0x63a45a3c,0x644383b0,0x27ed8009,0x200fda3d}},	//   _hein, énin, hden_, _logi_,
   {{0x63a45a3e,0x60182e3c,0xdb008168,0xafdb00e8}},	//   _kein, _lími, _temë, _kjøl,
   {{0x27ed8613,0x7af609a4,0xb4d2009a,0x69c48072}},	//   jden_, _kryt, _वही_, _राही,
   {{0xa3d40dbc,0x27edda3f,0x63a411e6,0x7bc283c9}},	//   स्य_, dden_, _mein, rgou,
   {{0xbda507bd,0x27e034e5,0x63a43b8a,0x80db80c8}},	//   _محفو, lein_, _lein, ভিন্,
   {{0x7d0300f2,0x403486c8,0xdca314b8,0x7af60110}},	//   änst, лекс, _васи, _lryt,
   {{0x63a45a40,0x6b8580f7,0x27edda41,0x601c802a}},	//   _nein, _مشكل, gden_, _vémo,
   {{0x7e7c0190,0xc8ae83eb,0x6d5c0aa8,0x29183090}},	//   _kirp, _टिकट, _hyra, hyra_,
   {{0x44268003,0x7c86845d,0x4b558698,0x601ca076}},	//   lho_, куме, _съст, _témo,
   {{0x63a45a42,0x27e05a43,0xa3e6816f,0xdb0083ec}},	//   _bein, kein_, _बघा_, _semè,
   {{0x44268003,0x61fe0247,0x64428009,0x7af65a44}},	//   nho_, _anpl, nnoi, _bryt,
   {{0x63a4327f,0x59c99d41,0x27e01a9d,0x34df0571}},	//   _dein, _रामर, dein_, _नन्द,
   {{0x2459026f,0x3eb980e1,0x200f8326,0x7bd60c2e}},	//   vému_, áste_, _zogi_, _ebyu,
   {{0x442691e8,0x63a45a45,0x19582252,0x29184068}},	//   kho_, _fein, вары_, gyra_,
   {{0x442681ac,0xe7ed02f1,0x63a41151,0x61fe5a46}},	//   jho_, _चोखा_, _gein, _enpl,
   {{0x44395a47,0x62840d76,0x4426da48,0x26c002c4}},	// [47d0] mis_, _guio, dho_, guio_,
   {{0x27ed87d9,0x2fdf82af,0x442681ac,0x2459016b}},	//   zden_, zeug_, eho_, rému_,
   {{0x27edda49,0x44391390,0x9f4f8106,0x7e7c0286}},	//   yden_, ois_, _ingå_, _dirp,
   {{0x44395a4a,0xc4d38158,0x4426da4b,0x6d5c26f4}},	//   nis_, יגע_, gho_, _dyra,
   {{0x1dc289a3,0x59a7000d,0x69c48651,0x200fda4c}},	//   _शांत, _औजार, _राशी, _rogi_,
   {{0x44395a4d,0x78ba0025,0x21699541,0xa9699170}},	//   his_, štve, нили_, нила_,
   {{0x44394166,0x205589b8,0x26000fb2,0x69c3da4e}},	//   kis_, лтир, रारी_, rgne,
   {{0x4426da4f,0x44395a50,0xe3b0830f,0x27edace9}},	//   cho_, jis_, _ورق_, uden_,
   {{0x27edda51,0x69d707f4,0x63a429fd,0xdb0603ed}},	//   rden_, _obxe, _rein, rakë,
   {{0x63a409af,0x26cdda52,0x27e00102,0xafdb021e}},	//   _sein, rteo_, zein_, _sjøl,
   {{0x7fd5bce9,0x63a41b48,0xdb00da53,0x26cd8216}},	//   _білі, _pein, _remé, steo_,
   {{0x60185a54,0x2d8e9384,0xdb064068,0x9ef581a8}},	//   _tími, _effe_, laké, _مستش,
   {{0x8c1a8051,0x628452ed,0x27e05a55,0x2bd300c2}},	//   גורי, _quio, vein_, ध्धा,
   {{0x63a45a56,0x44392682,0x29180168,0x7c260168}},	//   _wein, ais_, tyra_, shkr,
   {{0x44395517,0x63a42980,0x3ead829e,0x291e5a57}},	//   bis_, _tein, lset_, áta_,
   {{0x7ae9b933,0x1dcfa13e,0x58951c56,0xd5cf816f}},	//   _oset, त्रत, ршру, त्रज,
   {{0x291e003a,0x26001344,0x7c245a58,0x7e7c0267}},	// [47e0] šta_, राली_, _ilir, _pirp,
   {{0x3ead8009,0x44268609,0xdb061f1c,0x683e8ec3}},	//   iset_, who_, jaké, mūde,
   {{0x4426da59,0xa3cb024c,0x7ae9da5a,0x273380ff}},	//   tho_, र्क_, _aset, ảnh_,
   {{0x7bc601da,0x3ead825d,0x6d5c110d,0x69c30214}},	//   ngku, kset_, _vyra, _öner,
   {{0x4426da5b,0x6d5c009a,0xf772015b,0x6442da5c}},	//   rho_, _wyra, _داد_, rnoi,
   {{0x44268774,0x44395a5d,0xa3d401d2,0x38605753}},	//   sho_, zis_, स्त_, llir_,
   {{0x7ae9da5e,0x44393cf4,0x442691e8,0x60158125}},	//   _eset, yis_, pho_, _náms,
   {{0x4fc6844f,0xb4fb0051,0x79818114,0x6b808122}},	//   уска, _אפלי, _eglw, _ugmg,
   {{0x74138277,0x442482f1,0x67041e4b,0x3ead9af9}},	//   _اوقا, _ilm_, रमिक_, gset_,
   {{0x44395a5f,0x4424af54,0x68ed809a,0x7c360176}},	//   wis_, _hlm_, łada, _amyr,
   {{0xdb09a620,0xd6570039,0x97c68199,0xd7ef8adb}},	//   _ideá, ריית_, _مقاو, _лу_,
   {{0x6015803e,0x225a00ee,0x7c245325,0x661d93de}},	//   _dáms, _akpk_, _clir, ëskr,
   {{0x443905d8,0xa3cb0305,0x2bc6009a,0xa3bc864a}},	//   ris_, र्ग_, _वारा, _आयन_,
   {{0x44395a60,0xa2cc800c,0x2c7b0032,0xf77381c6}},	//   sis_, _समन्, _bàdì_, _פקס_,
   {{0xbd558077,0x1959076a,0xd7fb01e5,0x667180d7}},	//   _پروژ, тавы_, нуа_, _بگير,
   {{0x5f950e8e,0x9f4b0388,0x6e3a8366,0x6d469238}},	//   риат, _hacé_, litb, şkas,
   {{0xd5bb117e,0x245c928a,0x9f590580,0x96355a61}},	// [47f0] есе_, nímu_, _rosó_, анац,
   {{0x4424813c,0xafdb004a,0x236902d6,0xa3dd00c2}},	//   _alm_, _kjøk, _izaj_, ड़क_,
   {{0x386007fa,0x4424b2bb,0x9f591da9,0xb8670019}},	//   blir_, _blm_, _posó_, _ماحو,
   {{0x4424802a,0x69c7021e,0x7ae9817f,0xf41f0009}},	//   _clm_, lgje, _pset, nkä_,
   {{0x4424b932,0x81e980ab,0x9f4201d6,0xcfaa8264}},	//   _dlm_, যাস_, _taká_, ওলান,
   {{0xd05a8086,0xa3cc0740,0x7ae98a21,0x69c75a62}},	//   _istə, _लाभ_, _vset, ngje,
   {{0x2bf506a7,0x44248168,0x6e3ada63,0xafdb004a}},	//   इयां_, _flm_, ditb, _skøy,
   {{0xb8cd823c,0x3ead8100,0x69d58105,0xe3b3806b}},	//   _कब_, tset_, _मॉरी, _درس_,
   {{0x53358847,0x600691e9,0x78a48a20,0xf7458a7c}},	//   _теат, рным_, ćiva, репо,
   {{0x63aba20d,0x3eadc1af,0x3f8d83a7,0x7c2400d7}},	//   lagn, rset_, sceu_, _slir,
   {{0x99849301,0x3ead9da3,0x61e3da64,0x7c242dd5}},	//   _المو, sset_, menl, _plir,
   {{0xf7708117,0x61e3ae76,0x60c3c0d3,0xda03a7bc}},	//   _کام_, lenl, munm, लावत_,
   {{0x2bd79880,0x60c38457,0x20d1801c,0x501a8039}},	//   ण्या, lunm, _hơi_, _שונו,
   {{0x672d5a65,0x7a2b13da,0xe297117e,0x61e3da66}},	//   dzaj, _lütf, рар_, nenl,
   {{0x28dd8d86,0x463a80be,0x98a61c9b,0x6d468713}},	//   _महफि, _בעסע, рибе, şkar,
   {{0x63ab803a,0xa3d78105,0x7c2440ff,0x61e38192}},	//   jagn, ़्म_, _ulir, henl,

   {{0x63ab8081,0x6f1b89ca,0x61e3da67,0x6b8402c4}},	// [4800] dagn, nyuc, kenl, _igig,
   {{0x645bc06f,0xbda501a8,0x630694a0,0x63ab82c4}},	//   _akui, محمو, یوال, eagn,
   {{0x20d18028,0x61e3da68,0xdddd0087,0x20e78019}},	//   _nơi_, denl, _susţ, _női_,
   {{0xe29ab1a9,0x63ab8bcb,0x644629d1,0x60c38041}},	//   вад_, gagn, nnki, dunm,
   {{0xa3cb22f9,0xf1948009,0x99830110,0x672d009a}},	//   र्ट_, биль, cijų_, czaj,
   {{0x61e3da69,0x6b84026c,0x20d180ff,0x645bda6a}},	//   genl, _lgig, _bơi_, _ekui,
   {{0x03a680e8,0x4424da6b,0x63abda6c,0x48a78190}},	//   _вибо, _tlm_, bagn, атым_,
   {{0xdfda8098,0xdb0b0214,0x63ab9268,0x4424da6d}},	//   тък_, _çiçe, cagn, _ulm_,
   {{0xde888135,0x2360022c,0xe61f00ff,0x61e3d7ff}},	//   _bịa_, _nyij_, _muôn_, benl,
   {{0xe61f0028,0x20d6835f,0x22585a6e,0x6b845a6f}},	//   _luôn_, _відс, jork_, _agig,
   {{0xf41f0009,0x24800362,0x629605ee,0x6e3a83a6}},	//   tkä_, _biim_, _atyo, ritb,
   {{0xa3a981ce,0x6f0983a8,0x386081a8,0x6aa4018f}},	//   _खड़ा_, bxec, _óir_, _bwif,
   {{0x6e948013,0x81e980c8,0xe69480f7,0x27f2031d}},	//   _التا, যার_, _التد, ddyn_,
   {{0x2002537e,0xa3cb01d2,0x64460a5b,0x6b845a70}},	//   _anki_, र्ज_, anki, _egig,
   {{0x97a7197d,0x69c75a71,0x26c49aa1,0x27ef80dd}},	//   ирал, rgje, lumo_, _yagn_,
   {{0x61e387d9,0x02a70b9b,0xcf980b30,0x5d7b81c6}},	//   zenl, _кром, ију_, _באוק,
   {{0xf7730288,0x61e393f4,0x63abda72,0x95d90b79}},	// [4810] زار_, yenl, vagn, лдат_,
   {{0x60c3d4c4,0x645b81b0,0x99830110,0x20024b34}},	//   yunm, _skui, rijų_, _enki_,
   {{0xa3d40076,0x228b821e,0x63ab8625,0x99830084}},	//   स्व_, _søk_, tagn, sijų_,
   {{0xa3cb3a60,0x601c80e7,0x20d1801c,0x7aed09e1}},	//   र्च_, _fémi, _rơi_, _ksat,
   {{0x61e3da51,0xe21402e3,0xadf8863a,0x7848801b}},	//   tenl, _طبیع, ्ञान_, těvn,
   {{0x63abda73,0x60c39040,0x26c4da74,0xdb008144}},	//   sagn, tunm, dumo_, _gemí,
   {{0x26091880,0x63abda75,0x61e3da76,0x601801d0}},	//   साठी_, pagn, renl, _tímt,
   {{0x9f950006,0x7aed5a77,0x60c3880a,0x7bcd01c5}},	//   _nüüd_, _osat, runm, _ncau,
   {{0x6e27026c,0xa3cb001b,0x26c48084,0x27efda78}},	//   _kljb, र्छ_, gumo_, _vagn_,
   {{0x6459da79,0x443dda7a,0x2d83806a,0x60c3803d}},	//   lowi, liw_, øje_, punm,
   {{0x30858013,0x63a982a3,0x7aed5328,0x90998779}},	//   _الصف, _keen, _asat, _свет_,
   {{0xe29a3d85,0x64598063,0x6281da7b,0x04460749}},	//   лам_, nowi, _hilo, семн,
   {{0x7aed0065,0x63a9d54f,0xe60eda7c,0x05c70072}},	//   _csat, _meen, _ед_, _लांब,
   {{0x63a9da7d,0x62818326,0x7aed0372,0x6ec101d0}},	//   _leen, _jilo, _dsat, _लमजु,
   {{0xb4e603bb,0x7aed1604,0x64598035,0x016623b2}},	//   _भने_, _esat, kowi, скво,
   {{0x765c5a7e,0x6281da7f,0x9ac504b7,0x63a9da80}},	//   _skry, _lilo, fiċċ, _neen,
   {{0x6459809a,0x92b61ec9,0x66155a81,0xa0670323}},	// [4820] dowi, _احبا, _bozk, сата_,
   {{0x62819217,0x7bdb91b5,0xaca38133,0xa3d40035}},	//   _nilo, _abuu, _ndịi, स्र_,
   {{0x63a9da82,0x60de00f2,0xa63a80be,0x7afbda83}},	//   _been, _uppm, נגער, _arut,
   {{0x3ebfda84,0x6281c18d,0x63a98579,0xdc190035}},	//   krut_, _ailo, _ceen, _błęd,
   {{0x6281da85,0x7afb8068,0x63a990b0,0x6d5c8a21}},	//   _bilo, _crut, _deen, ýraz,
   {{0xed5a1db0,0x6d430013,0xa8a6b4fd,0x59db0bb8}},	//   _бог_, únac, брик, म्पर,
   {{0x92e880c8,0x62819600,0x7afbda86,0x64598035}},	//   যমে_, _dilo, _erut, bowi,
   {{0x7afbda87,0x69cdac17,0xde88819d,0x63a9da88}},	//   _frut, _साथी, _dịn_, _geen,
   {{0x7afb8dba,0xfaa3a8c5,0x91fc8362,0xdb0082df}},	//   _grut, _нато, _bhāt, _demã,
   {{0x6281da89,0x7bcd002e,0x26c4da8a,0x63a9da8b}},	//   _gilo, _scau, rumo_, _zeen,
   {{0xa3bc809a,0xa3cfc5d2,0x9f4f86c0,0x25aa0088}},	//   _आया_, _शाम_, _lagè_, _mebl_,
   {{0x7f868013,0x26c00a20,0x69d8800b,0x6281bac9}},	//   _الإن, krio_, lfve, _zilo,
   {{0xd5a804e5,0xcc3b80be,0x7c3d1abb,0x7c228f3e}},	//   गराज, רעכט, risr, ikor,
   {{0xab5b5a8c,0x6aa918e6,0x26c028ef,0x6459809a}},	//   ngüi, _कबीर, drio_, zowi,
   {{0x463b80be,0x7c22da8d,0x661509a4,0xde8880ff}},	//   _געגע, kkor, _rozk, _xịn_,
   {{0x2c7b0341,0x7aed5a8e,0x26c01670,0x3a3a1b9c}},	//   _līdz_, _tsat, frio_, _empp_,
   {{0x44295a8f,0x7aed5a90,0x7c22c04a,0x5a350049}},	// [4830] _ila_, _usat, dkor, _мнит,
   {{0x44291393,0x63a981ab,0x644aace1,0x09b300ab}},	//   _hla_, _seen, éfin, ঞ্জা,
   {{0x26c0160a,0x6459da91,0x443d876d,0x7afb8090}},	//   ario_, towi, tiw_, _srut,
   {{0x237f0052,0x7afb9303,0x8cc08f85,0xaa7b016b}},	//   žuju_, _prut, _विनो, jvýz,
   {{0x64598063,0x69c4da92,0xd90f82e3,0x248d083d}},	//   rowi, _राखी, کیا_, _čemu_,
   {{0x40959300,0x63a981b0,0xdb008118,0x56942167}},	//   орит, _ween, _admó, _харт,
   {{0x64598d38,0x44295a93,0x6281bd2b,0x1b1780ab}},	//   powi, _ola_, _vilo, _দেশে_,
   {{0xe7399cf9,0x7c22816d,0x442910ab,0x682a001b}},	//   ией_, ckor, _nla_, _týde,
   {{0x7c3bda94,0x7afba6da,0x7c29da95,0x6281da96}},	//   _imur, _urut, _iler, _tilo,
   {{0x44295a97,0xc8ab8698,0x644d0b20,0x7fb9803d}},	//   _ala_, _бъде_, _ajai, _چهار_,
   {{0x44295a98,0x5f9587eb,0xf3e61056,0x7c29da99}},	//   _bla_, _диет, ожно, _kler,
   {{0x7bcb859c,0x443b0081,0xc2090039,0x5f74826a}},	//   nggu, _cmq_, _בה_, _کامر,
   {{0x44290d38,0x69db0267,0x627981d6,0x7c29810c}},	//   _dla_, đuen, _dňov, _mler,
   {{0xa2cc80ba,0x442938c3,0x5ebe80c8,0x765a810c}},	//   _समस्, _ela_, ্বশে, coty,
   {{0x7c3bda9a,0x7c29da9b,0x442200b9,0x717601a8}},	//   _omur, _oler, pkk_, زهرا,
   {{0x78ba3899,0xfc3f0a21,0x59db5a9c,0x601c816a}},	//   štvo, cií_, म्बर, _fému,
   {{0x3205d01e,0xf99f801c,0x78a90bcf,0xdb1d0338}},	// [4840] _only_, _đèn_, ćeva, ggsä,
   {{0xdb00803e,0x26c28025,0x442900d2,0x7c3b83c3}},	//   _nemá, škog_, _zla_, _amur,
   {{0x20f800d2,0x7c22da9d,0x7c29da9e,0xd30281a2}},	//   _uči_, tkor, _bler, लम्ब_,
   {{0xf8b3004c,0x26c00698,0xab66a15b,0x6f0d002a}},	//   _קשר_, prio_, овел, bxac,
   {{0x3ce600e1,0x7cf7819d,0x19949fd9,0x8cc080c2}},	//   ňov_, _ịru, паля, _विभो,
   {{0x64a612b2,0x7c2286ee,0x7c29bd5c,0xdca602a4}},	//   _мага, skor, _eler, _маги,
   {{0x7c298f06,0x628fbb09,0xdb008693,0x082a8396}},	//   _fler, _écon, _demá, иции_,
   {{0xdfd09168,0xd6da8785,0xdb008722,0x920382f1}},	//   ريخ_, ато_, _temà, लाउज_,
   {{0x69968098,0x63a481fa,0x63af0b80,0xe297a4dc}},	//   _дрех, ðinu, vacn, _мат_,
   {{0xddd8803b,0x44290a0f,0xdb1d5a9f,0x69da00d4}},	//   _bivš, _sla_, ngså, _पॉली,
   {{0x44295aa0,0xa3cc0105,0x6563831d,0x81468065}},	//   _pla_, _लाश_, _cynh, _بنان,
   {{0x2d8784d6,0xccf8928a,0x9f4b136f,0x6a6487f1}},	//   _egne_, rvě_, _sací_, dòfi,
   {{0xfc3f026f,0x447b80be,0x44295aa1,0x7a2b0380}},	//   rií_, ינטע, _vla_, _rütb,
   {{0x4429177c,0xe5348d15,0x6018023e,0xfc3f01d6}},	//   _wla_, _нель, _símp, sií_,
   {{0x4429011a,0x65638114,0x63a2daa2,0x69de008e}},	//   _tla_, _gynh, kbon, _dbpe,
   {{0x1ddd05e8,0x36348077,0x44295a48,0xa3dc8105}},	//   न्नत, _برچس, _ula_, त्म_,
   {{0x36d40364,0x645d5aa3,0x2d87007a,0xc9874bf2}},	// [4850] мотр, mosi, žnem_, _муни,
   {{0x645d5aa4,0x60c70140,0xdd9b3d2e,0xc33201c6}},	//   losi, pujm, рша_, _נוי_,
   {{0x63ad416a,0x69c48701,0xdb008118,0x89da0019}},	//   _kean, _राजी, _remá, _اوپر_,
   {{0x645d5aa5,0x515a0039,0x63a2a610,0xdb009986}},	//   nosi, _לכתו, gbon, _semá,
   {{0xfaa58698,0x7c29daa6,0x27e95aa7,0x63ad0039}},	//   чало, _vler, mean_, _mean,
   {{0x27e95aa8,0x62855aa9,0x645d0114,0x786586a5}},	//   lean_, _jiho, hosi, móvi,
   {{0xa3cc09a3,0x645d230e,0x628516f2,0x2484807b}},	//   _लाल_, kosi, _miho, _fimm_,
   {{0x27e92a39,0x1bb88b76,0x7c3bdaaa,0x62854a7c}},	//   nean_, _واقع_, _umur, _liho,
   {{0xdb008acf,0xee39920c,0x63bbc34e,0xe293803d}},	//   _temá, йни_, _idun, _آذر_,
   {{0x62855aab,0xe8098054,0x27e90046,0x661881c0}},	//   _niho, वाहा_, hean_, _covk,
   {{0x63ad5aac,0x1ddd0a74,0xed59daad,0x80a480f7}},	//   _bean, न्यत, сон_, _يمكن,
   {{0x63ad154c,0x644bdaae,0xf0f9800f,0x27e92a1a}},	//   _cean, nngi, ्मीद_, jean_,
   {{0x27e91f51,0xf1d28935,0x63ad0c49,0xda070540}},	//   dean_, _सामन, _dean, शांत_,
   {{0x1dc72f7b,0xf77084e3,0x877a80be,0xf67580be}},	//   _लागत, _شان_, _פאסי, _צײַט_,
   {{0x7641daaf,0x62851600,0x63bbd5f1,0x63ad31c5}},	//   mily, _diho, _odun, _fean,
   {{0x20195ab0,0x27e95ab1,0x63ad5ab2,0x2bc6016f}},	//   _cosi_, gean_, _gean, _वाटा,
   {{0x0cdb815c,0x6f16809a,0x20195ab3,0x628501b9}},	// [4860] _बहुम, _życz, _dosi_, _fiho,
   {{0x63bb9341,0x63a2dab4,0xceb40085,0x0e630fe6}},	//   _adun, wbon, rsə_, екун,
   {{0x27e90cdb,0x629bdab5,0x20190609,0xceb4011c}},	//   bean_, _atuo, _fosi_, ssə_,
   {{0x69dc5ab6,0x27e95ab7,0x20190135,0x9f4280e1}},	//   lfre, cean_, _gosi_, ľkú_,
   {{0x628f82be,0x41d304e5,0x7641dab8,0x249f01a1}},	//   _écol, _तामस, kily, _čume_,
   {{0x7848800d,0x69dc5ab9,0x69d587d9,0x3ea00812}},	//   pěvk, nfre, _özel, mpit_,
   {{0xfce3069b,0x64a6084b,0x645d5aba,0x2d8a2e3b}},	//   _поро, _хаба, yosi, _igbe_,
   {{0x25ee8076,0x6ebd86b7,0x7d1c835f,0xafdb0aa2}},	//   _असही_, _शिशु, ørsm, _hjør,
   {{0xae20000f,0x2bd1835a,0x96f88a29,0xafdb035f}},	//   _मकान_, _हाता, цепт_, _kjør,
   {{0x4426dabb,0x63ad5abc,0x27e90102,0x824a830f}},	//   lko_, _sean, zean_, _اشرف_,
   {{0xa96a99f7,0x645d3d87,0x63ad2536,0x2d8a0a2c}},	//   _امام_, tosi, _pean, _mgbe_,
   {{0xb8658b76,0x9f401378,0x69dc816d,0x27e90102}},	//   _قانو, ndió_, _öreb, xean_,
   {{0x69dc5abd,0xe80980a5,0x4426dabe,0x765e02e7}},	//   ffre, वारा_, iko_, kopy,
   {{0x4426824a,0xa3dc873c,0xdb040511,0x7a300106}},	//   hko_, त्त_, _adió, _nätd,
   {{0xa3cc9d2a,0x69ce09a3,0x7ae45abf,0x44269b0e}},	//   लला_, _तारी, _epit, kko_,
   {{0xdc2b0077,0x2d8a0091,0x2d980176,0x6ee201bc}},	//   _دسته_, _agbe_, _afre_, _ọbag,
   {{0x4426dac0,0x62854f6d,0x7c2d5ac1,0xafdb054f}},	// [4870] dko_, _tiho, _ilar, _bjør,
   {{0x4426dac2,0x27e910a2,0xa3cf81c4,0x682a026f}},	//   eko_, sean_, _शाह_, _výda,
   {{0x7c2d0bfa,0x40350468,0xb8352d94,0xa3d40305}},	//   _klar, _женс, _женщ, स्क_,
   {{0x22430586,0x7641c4bd,0x644ba836,0x7bcf13e0}},	//   lijk_, zily, ungi, ngcu,
   {{0x38691739,0xdcf70085,0x245881e2,0x6493022b}},	//   mlar_, raxı, чаць_, _għin,
   {{0x4426dac3,0xdd868250,0x7c2d009f,0xafdb035f}},	//   ako_, _لو_, _llar, _gjør,
   {{0x7c2d0afe,0xe8099344,0x23bf0b85,0xe61f001c}},	//   _olar, वाला_, ्लाद, _nuôi_,
   {{0x38690b06,0xccf20051,0x44269f3e,0xb69b02be}},	//   nlar_, _בכל_, cko_, _grâc,
   {{0x442db9cf,0x22430613,0x997e802e,0x443fdac4}},	//   _ile_, kijk_, tăţi_, _imu_,
   {{0x38690380,0x442ddac5,0x7a30156e,0x20d7007e}},	//   hlar_, _hle_, _käte, kçi_,
   {{0x38695ac6,0x7ae43ad2,0xa2c98540,0xa3ea1597}},	//   klar_, _spit, हूर्, одна_,
   {{0x386907d9,0x4ad18c78,0xca290496,0xdd1c00e1}},	//   jlar_, _समाव, _דם_, náša,
   {{0x38695ac7,0xdb0081ec,0x290109ab,0x7c2d010c}},	//   dlar_, _gemä, _arha_, _dlar,
   {{0x442ddac8,0x442680ad,0x68fc21d1,0x64428037}},	//   _lle_, zko_, tvrd, zioi,
   {{0x442ddac9,0xa3cc0076,0x7a3000f2,0x443f8c56}},	//   _ole_, _लाऊ_, _näte, _omu_,
   {{0x98a7809a,0x443fdaca,0x3869088b,0x3b0001b9}},	//   czną_, _nmu_, glar_, _triq_,
   {{0xe61a10fc,0x7ae4003a,0xf7430b9b,0x64428009}},	// [4880] ода_, _upit, вето, vioi,
   {{0x442db931,0x443fdacb,0xf1d28dbc,0x7c2d0115}},	//   _ale_, _amu_, _साधन, _zlar,
   {{0x4426dacc,0x38695acd,0x442d8cde,0x938adace}},	//   tko_, blar_, _ble_, осла_,
   {{0xdca30af2,0x0ea904e5,0x4426dacf,0x68310370}},	//   таци, _चौकड, uko_, _rådg,
   {{0x25ee89a3,0x8db6035f,0x5f060196,0x442d801b}},	//   _असली_, _осві, _ўзга, _dle_,
   {{0x442ddad0,0x20ee800d,0x443f8365,0x38603917}},	//   _ele_, _při_, _emu_, loir_,
   {{0x26119513,0x35a7800f,0xafdb035f,0xda6580f7}},	//   तानी_, _ग़ज़, _kjøp, راهي,
   {{0xd0108307,0x68e302af,0x442ddad1,0x7d03013c}},	//   الة_, _ände, _gle_, ænse,
   {{0xc6f787ac,0x661c5ad2,0x78ad8067,0x5fbf86b7}},	//   дных_, _kork, ćava, _एयरल,
   {{0x3869017b,0x20ee801b,0x442ddad3,0x7c2d0502}},	//   zlar_, _tři_, _zle_, _slar,
   {{0x38693a9e,0x44fe0110,0x442ddad4,0x994a8060}},	//   ylar_, _jį_, _yle_, _بلال_,
   {{0x61f70201,0x224300f3,0x69daa594,0x38695ad5}},	//   _saxl, wijk_, प्री, xlar_,
   {{0x6288dad6,0x386912a3,0xe80d0697,0x661c067f}},	//   _kido, vlar_, हासा_, _oork,
   {{0x20d703bf,0x6831006a,0x7d030106,0x78538162}},	//   tçi_, _måde, ånsk, măva,
   {{0x38695ad7,0x22430a0f,0x6288dad8,0x64408372}},	//   tlar_, rijk_, _mido, _ommi,
   {{0x7c2d112e,0x6f02ad3e,0x6ce380e8,0x6288dad9}},	//   _ular, _kroc, _ріше, _lido,
   {{0x38695ada,0x78a20d11,0x6b8d5adb,0x682a001b}},	// [4890] rlar_, _čove, _igag, _týdn,
   {{0x6440939a,0x443f8e6d,0x09c600ab,0x24890069}},	//   _ammi, _smu_, শ্বা, _hiam_,
   {{0x24890176,0x442d809f,0x38695adc,0x2c720c83}},	//   _kiam_, _ple_, plar_, láda_,
   {{0x38690201,0xdddc01e2,0x447c00be,0xdcfa880a}},	//   qlar_, _virš, ַנגע, natı,
   {{0xa3d40894,0xd6c692dc,0x6288dadd,0x661c0bc5}},	//   स्ट_, _حق_, _bido, _fork,
   {{0x24895ade,0x661c5adf,0x863500be,0x6440dae0}},	//   _liam_, _gork, _טאָג_, _emmi,
   {{0x9f40007b,0x6288dae1,0x1b1780c8,0x22498042}},	//   ldið_, _dido, _দেখে_, đak_,
   {{0x443fbbdb,0x248901e9,0x6b8d5ae2,0x628883a8}},	//   _umu_, _niam_, _ngag, _eido,
   {{0xf62588cc,0x9f400125,0x3eb9b958,0x23695ae3}},	//   едпо, ndið_, ést_, _nyaj_,
   {{0xa3e210c5,0x6b8d5ae4,0x644f1986,0x78ba00d2}},	//   न्न_, _agag, enci, štvi,
   {{0x1d09813a,0x6aad5a8b,0xb7d58032,0xd46a2903}},	//   чени_, _awaf, _aṣet, зине_,
   {{0x62888503,0xce958698,0x24890282,0x6aad0365}},	//   _zido, _задъ, _ciam_, _bwaf,
   {{0xe72e8785,0x386003d3,0x27ed94d0,0x24895ae5}},	//   _се_, voir_, meen_, _diam_,
   {{0x27eddae6,0x200b04b9,0xc33284de,0x4a750a41}},	//   leen_, _anci_, רוך_, выст,
   {{0xafe60b88,0x50b50e97,0x12d000ab,0x42d000ab}},	//   новл, ксту, িবেদ, িবেশ,
   {{0x27eddae7,0x661c5ae8,0x248900ff,0x7e61808e}},	//   neen_, _sork, _giam_, lolp,
   {{0x64465ae9,0x7bd600b4,0x7a2b1c08,0x38600036}},	// [48a0] miki, _icyu, _kütl, roir_,
   {{0x68310e23,0x27eddaea,0x7af60034,0x6b9b8365}},	//   _råde, heen_, _isyt, _afug,
   {{0x61d70159,0xf1c98bb8,0x27eddaeb,0x41c99a8f}},	//   _אויף_, _राजन, keen_, _राजस,
   {{0x6288927b,0x64465aec,0xe3b2830f,0x661c0051}},	//   _sido, niki, ارا_, _work,
   {{0xa3e2073c,0x27eddaed,0x59f88656,0xe803816f}},	//   न्य_, deen_, деля_, _शोधा_,
   {{0x644650b6,0x8cc080d4,0x61fc5aee,0x61ee2bdf}},	//   hiki, _विलो, ndrl, nebl,
   {{0x64465aef,0xdcfa82bb,0xa2cc86b7,0x6288b8d6}},	//   kiki, yatı, _समक्, _vido,
   {{0xf1d28076,0x683e8029,0x27e05644,0x27edcc96}},	//   _सावन, līdz, nfin_, geen_,
   {{0x64461d7c,0xc5f88029,0x24890282,0x26018fd5}},	//   diki, klēt_, _riam_, _वोही_,
   {{0x2c7593c2,0x4375a5f5,0x7e6181ca,0x61ee0140}},	//   råde_, _руст, golp, jebl,
   {{0xa3cc0e70,0x64465af0,0x6f02daf1,0x27ed8079}},	//   _लाख_, fiki, _wroc, been_,
   {{0x6f02daf2,0x644600b4,0xe80015fb,0x27ed8079}},	//   _troc, giki, _लोला_, ceen_,
   {{0x7d0396a1,0x61fadaf3,0xdcfa861c,0x248907b6}},	//   _erns, _katl, ratı, _viam_,
   {{0x61ee0799,0x7e6180e5,0xb69b0162,0x2c72016b}},	//   gebl, colp, _brân, ráda_,
   {{0x2bd1823c,0x248901e9,0x61fadaf4,0xe80d016f}},	//   _हाला, _tiam_, _matl, हाला_,
   {{0xb9090d38,0x63a901df,0x24890748,0x64465af5}},	//   _यह_, ñend, _uiam_, ciki,
   {{0x2ba70f3d,0x9df91b35,0xa2cc8b84,0xe7e293ba}},	// [48b0] _क्या, мнат_, _समग्, क्या_,
   {{0x27e05af6,0xb69b0493,0x6b9b847f,0x04b78019}},	//   afin_, _frân, _sfug, _تھیں_,
   {{0x27ed82c1,0xbc6807d2,0x682302f1,0x92ad8264}},	//   yeen_, _زمین_, _sõdu, _কমে_,
   {{0x09c98d14,0x27eddaf7,0x442b0140,0x683e8196}},	//   रल्य, xeen_, nkc_, būdi,
   {{0x61fa878c,0x27edbd9f,0x321e81d0,0x9f5903ed}},	//   _batl, veen_, _boty_, _masë_,
   {{0x64465af8,0xceb200be,0x321e81e0,0x9f44823e}},	//   ziki, _דיך_, _coty_, demà_,
   {{0x27eddaf9,0x2055a66e,0x260e1513,0x64465afa}},	//   teen_, ктир, ठारी_, yiki,
   {{0x26054d54,0x6e200162,0x7a303e43,0x6446011b}},	//   _होती_, _îmbr, _mäta, xiki,
   {{0x27ed9322,0x03ec00ab,0x64462e8f,0x61fadafb}},	//   reen_, য়ামী_, viki, _fatl,
   {{0x27eddafc,0x38668057,0x26c38353,0x26c900d2}},	//   seen_, _ekor_, čjo_, irao_,
   {{0x64465afd,0x853c8110,0x7e61dafe,0x7a300338}},	//   tiki, lbėj, rolp, _näta,
   {{0x8c460087,0x61aa036d,0x61fadaff,0x61e51997}},	//   теме, कर्ष, _zatl, _abhl,
   {{0x386ddb00,0x26cd85e4,0xdb099727,0x6d588144}},	//   mler_, queo_, _ideó, _exva,
   {{0x64464b97,0xa2c4858c,0x66828019,0x7ae68106}},	//   siki, _रिस्, _پیپل, _äkte,
   {{0x64d0023c,0x386d9486,0xa06a0323,0xa967164f}},	//   _हमेश, oler_, дава_, вира_,
   {{0x2c08000f,0x386d87d9,0x70e218b8,0x7ae98009}},	//   षाओं_, nler_, _पहील, _opet,
   {{0xa0670572,0xc7b2893f,0x18671ac6,0x60dc5b01}},	// [48c0] тата_, יבן_, тати_, strm,
   {{0x386d82af,0xdee30256,0x44205b02,0xa9261ff9}},	//   hler_, рофи, _hoi_, _адол,
   {{0x386ddb03,0xd49900e8,0x61fadb04,0x387fb745}},	//   kler_, ері_, _ratl, kmur_,
   {{0x4420002e,0xf7678c2a,0xad1a8158,0x351a80be}},	//   _joi_, _نا_, ווער, ווענ,
   {{0x80e2101b,0x44205b05,0x386d93ca,0xe36391d5}},	//   _पहुं, _moi_, dler_, акци,
   {{0x44205b06,0xa3e2005e,0x386ddb07,0x78758110}},	//   _loi_, न्त_, eler_, _išvy,
   {{0x6444194c,0xdb0f0626,0x386ddb08,0x6e43214a}},	//   _omii, vací, fler_, _терз,
   {{0x44205b09,0x386d9c6d,0xc6f8ae9f,0x7643db0a}},	//   _noi_, gler_, ених_, _amny,
   {{0x09b800c8,0x61fac19e,0xa3cc0fb8,0x78a90024}},	//   _জানা, _tatl, _लाज_, ćevi,
   {{0xceb30039,0x442001a8,0x35e380e8,0x6444227f}},	//   סית_, _aoi_, ацюв, _amii,
   {{0x386d9da3,0x4432079f,0xd7ef8193,0x29058503}},	//   bler_, _bly_, _ку_, _grla_,
   {{0x64440b99,0x44205b0b,0x6d4300f7,0x07a684ae}},	//   _cmii, _coi_, únai, _радн,
   {{0xa3e200bc,0x27e6c382,0x290c0106,0x442001c6}},	//   न्ध_, _ibon_, ådan_, _doi_,
   {{0x442008f1,0x2c5600eb,0xb7d5846d,0x7c208f35}},	//   _eoi_, rāda_, _iṣat, _lomr,
   {{0x442007e1,0x44320367,0x6d459517,0x29055b0c}},	//   _foi_, _fly_, _žhav, íla_,
   {{0xceb40086,0x26c902a5,0x44200c4b,0xa3e200a5}},	//   yyət_, trao_, _goi_, न्द_,
   {{0x41d283b7,0x09ca80c8,0x7a220036,0xda028072}},	// [48d0] _सांस, ল্যা, _vôtr, लयात_,
   {{0xe7e28519,0x386d8457,0x387fdb0d,0x0e3405a8}},	//   क्ता_, zler_, zmur_, аную,
   {{0x7ae9db0e,0x386d8214,0x2d8703e3,0xee843ff2}},	//   _spet, yler_, äne_, рыто,
   {{0xa2c4823c,0xdb0f0187,0xd01101a8,0x7a3006ae}},	//   _रिश्, cacã, _الح_, _jätn,
   {{0x3e7980e7,0x7c2b9c2b,0x386ddb0f,0x7a300106}},	//   lète_, rkgr, vler_, _mätn,
   {{0x386dd4ec,0x27e6a240,0x853c8084,0xde888129}},	//   wler_, _abon_, rbėj, _xịt_,
   {{0x09b800c8,0x386ddb10,0x2166db11,0x3e7980e7}},	//   _জামা, tler_, лиши_, nète_,
   {{0xb8dba120,0x224789ff,0x8bbf1869,0x386ddb12}},	//   _अब_, sink_, ्लोअ, uler_,
   {{0x44205b13,0x386ddb14,0x3b55cd3e,0x764381c0}},	//   _roi_, rler_, _скар, _pmny,
   {{0x69c1813c,0x386ddb15,0x44205b16,0x7c2080e1}},	//   _udle, sler_, _soi_, _zomr,
   {{0xc3291a6a,0xb7d58b76,0x44200698,0x386dd21d}},	//   _צו_, _مقاب, _poi_, pler_,
   {{0x22998205,0x41dfdb17,0x248d822b,0xe7b78651}},	//   _kèk_, प्रस, _jiem_, _इजिप,
   {{0x44205b18,0xe2970912,0x27fd831d,0x55e58071}},	//   _voi_, лая_, _iawn_, _болб,
   {{0xed599c64,0x628f82be,0x27fd84b7,0x442000dd}},	//   _пол_, _écou, _hawn_, _woi_,
   {{0x68312024,0x44205b19,0x7d1c805f,0xde8880ff}},	//   _såda, _toi_, ørst, _vịt_,
   {{0xc2f980c8,0xf7720064,0x6444009c,0x69cd83b7}},	//   _আপনি_, ماء_, _umii, _साझी,
   {{0x6729bc86,0x27ffdb1a,0x63b997ac,0x7d030366}},	// [48e0] nyej, idun_, dawn, ænsn,
   {{0xc3330051,0x3e79bd62,0x248200dd,0xe8fa1c0b}},	//   _לוח_, bète_, lmkm_, _зло_,
   {{0x7c208bcf,0x63b63f6f,0x200fcc26,0x69db0b80}},	//   _pomr, _keyn, _ongi_, đuet,
   {{0x442087ca,0x6296273c,0x229986c4,0x981601a8}},	//   ði_, _kuyo, _bèk_, _إبدا,
   {{0x61fe5b1b,0x248ddb1c,0x27f201b4,0x229988f9}},	//   _kapl, _diem_, meyn_, _cèk_,
   {{0x26d205b0,0x673b80e1,0x2ee002f7,0x63b65b1d}},	//   muyo_, dzuj, mtif_, _leyn,
   {{0xc31c80ab,0x76488242,0x20000079,0x7c20db1e}},	//   _দেখি_, vidy, odii_, _tomr,
   {{0xba010076,0x26c2803a,0x61fe03ec,0x76aaab83}},	//   _ऊफ्फ_, škom_, _lapl, нтов_,
   {{0x2ee0253a,0x96348293,0x7648b3f8,0x9f59396d}},	//   ntif_, иниц, tidy, _pasé_,
   {{0x14ca8364,0xa3e203dd,0xf2978039,0x6fa48935}},	//   ными_, न्स_, _עכבר_, _ग्रं,
   {{0xb9939ecd,0x63b6062a,0x6aa44227,0xd7e680e8}},	//   _المب, _beyn, _atif, _біло,
   {{0xc0a984e3,0x6f04011f,0x62961eda,0x8706804e}},	//   _شامل_, kvic, _buyo, _مبتل,
   {{0xfe0405e8,0x200002c1,0x051480c8,0x629606a5}},	//   रयास_, ddii_, ানের_, _cuyo,
   {{0xad26803d,0x62962ccd,0x69351073,0x9f4b01a8}},	//   _مربو, _duyo, ангу, _tacú_,
   {{0x61fe2a0f,0xd5b88029,0x2611db1f,0xa3e2483a}},	//   _dapl, skās_, तारी_, न्ह_,
   {{0x629600b9,0x3e798036,0x50675068,0x63b60df6}},	//   _fuyo, rète_, утга, _geyn,
   {{0x6296123c,0x3da7197d,0x248d9c2b,0x26d21ffc}},	// [48f0] _guyo, греб, _riem_, guyo_,
   {{0x7aed0637,0x61fe309c,0x2d9e802e,0x63b607c0}},	//   _ipat, _gapl, ncte_, _zeyn,
   {{0x2ee00458,0xe817800d,0xb65a10ab,0xfbdf001c}},	//   atif_, थामा_, nrẹ́, hiêm_,
   {{0x7aed0870,0x81bc81a9,0x26d22022,0x3e9701a8}},	//   _kpat, _slēp, buyo_, _مؤسس,
   {{0x26c28a20,0x2ee05b20,0x63b9809a,0x248d80e1}},	//   škoj_, ctif_, rawn, _viem_,
   {{0x3ea90393,0x65943200,0x248d809a,0xdd940084}},	//   mpat_, _гару, _wiem_, _гары,
   {{0x248d80eb,0x44395b21,0x3b090122,0x3ea95b22}},	//   _tiem_, khs_, _lraq_, lpat_,
   {{0xaec595d2,0x7aed1249,0x63ad85e4,0x2ba710be}},	//   абил, _opat, ñand, कुमा,
   {{0x63b60125,0xa3d92441,0xdb268065,0x644bdb23}},	//   _reyn, ालन_, _پولی, migi,
   {{0x644bdb24,0xcee881a8,0x7d098eef,0xdb0f0118}},	//   ligi, ارين_, вног_, xacá,
   {{0xed598767,0x6aa40ed0,0x7aed5b25,0x59dc1344}},	//   тон_, _stif, _apat, _बाबर,
   {{0xe29a36de,0x69c55b26,0x644bdb27,0x63861071}},	//   кам_, _adhe, nigi, игна,
   {{0x61fe2b47,0x683801d0,0x63bb008b,0x628f8866}},	//   _papl, _jíde, ðuna, _écos,
   {{0xa2cd80ba,0x644bdb28,0x63b60079,0x27f20079}},	//   _सिन्, higi, _weyn, weyn_,
   {{0xa96a24dc,0x6026204d,0x69d72a90,0x644bdb29}},	//   тива_, адва, _बारी, kigi,
   {{0x32040063,0x4439238c,0x3db200ab,0xa3e580d4}},	//   śmy_, chs_, _চাইল, _बॉल_,
   {{0x6e23db2a,0x6aa45b2b,0x645d3b09,0xde8880ff}},	// [4900] _konb, _utif, érie, _kịp_,
   {{0xee374317,0x09e400c8,0x35dd8cfd,0x2ee05b2c}},	//   ану_, _ফোরা, _माफ़, rtif_,
   {{0x644b8cb5,0x7c24113f,0xbef28f85,0x37e615b7}},	//   figi, _koir, _अन्न_, _конг,
   {{0xa3d9085d,0x644b82b8,0x7aed0110,0x2ee05b2d}},	//   ालय_, gigi, _ypat, ptif_,
   {{0x7c24051e,0x69c1008b,0x7aed0bfd,0x539b01c6}},	//   _moir, ðleg, _xpat, דינו,
   {{0x7c245b2e,0x98c6a23c,0x6e238cdb,0x7a34851e}},	//   _loir, асил, _nonb, _bàta,
   {{0x644bdb2f,0x7a3487f1,0x7afbdb30,0x26c00084}},	//   bigi, _càta, _esut, lsio_,
   {{0x58868048,0x7c2400e7,0xb8ce8665,0xb8fe864a}},	//   шыла, _noir, _कऽ_, _तम_,
   {{0xe7e28e70,0xe29aacd1,0xfba70eed,0x4424db31}},	//   क्षा_, _раз_, _क्षम, _iom_,
   {{0x4424db32,0x26c00428,0x7c242360,0xb3b00264}},	//   _hom_, isio_, _aoir, _কাগজ,
   {{0x4424db33,0x7aed5b34,0x7c241581,0x0d970039}},	//   _kom_, _spat, _boir, יכים_,
   {{0xdee6a46b,0x4424db35,0x7c245b36,0x66e6b4d5}},	//   _води, _jom_, _coir, _вода,
   {{0x7ae2db37,0x7c24032f,0x26cd8333,0xa3ce80c2}},	//   ntot, _doir, creo_, _शयन_,
   {{0x4424db38,0x05dd835a,0xfba727fb,0xb7e299eb}},	//   _lom_, _मायब, _क्रम, क्रम_,
   {{0x7c245b39,0x644b81d3,0x4424db3a,0x6835816b}},	//   _foir, yigi, _oom_, _háda,
   {{0x4424db3b,0x3ea95b3c,0x7c240014,0x5f4500f7}},	//   _nom_, tpat_, _goir, منزل,
   {{0xdb009f22,0xe7f9873c,0x3ea95b3d,0x7aed5b3e}},	// [4910] _memó, ्यता_, upat_, _upat,
   {{0x63bd5b3f,0x31354c78,0x3ea9121e,0x69c55b40}},	//   lasn, _геор, rpat_, _udhe,
   {{0x4424db41,0x03ec00ab,0x26cd8699,0x78a9017f}},	//   _bom_, য়ারী_, zreo_, ćevs,
   {{0x3ea6859c,0x3ea91cbf,0x68380511,0xa2ce0cf0}},	//   _otot_, ppat_, _píde, _तिम्,
   {{0x4424db42,0x81ae80c8,0x09df80c8,0xdb0081ec}},	//   _dom_, _কাজ_, _যোগা, _gemü,
   {{0x683803fd,0x644bdb43,0xc244902a,0x44c4846d}},	//   _víde, sigi, онік, _ajọṣ,
   {{0x63bd0025,0x644b87fe,0x4424a598,0xd90f804e}},	//   kasn, pigi, _fom_, بیا_,
   {{0x2ba71370,0x9b899dd2,0x26cd8118,0x7afb80fc}},	//   _क्ला, _منزل_, treo_, _tsut,
   {{0x63bd0052,0x600681bb,0xdb00816a,0x68358118}},	//   dasn, сным_, _demó, _cáda,
   {{0x7c245216,0x26cd960a,0xee368a7f,0x6e3a8aff}},	//   _soir, rreo_, йны_, ghtb,
   {{0x2fd98b76,0x44248069,0x7c245b44,0x26cd8042}},	//   _مواد_, _yom_, _poir, sreo_,
   {{0xca29004c,0x3ebf978b,0xd79580f7,0x60d50289}},	//   _אם_, psut_, _الإخ, duzm,
   {{0x6e238247,0x7c2400e7,0x59dc1130,0x320102c4}},	//   _tonb, _voir, _बादर, _bahy_,
   {{0x6e3a8a11,0xe2970764,0xa2da873c,0x09b800ab}},	//   chtb, сар_, _नमस्, _জাহা,
   {{0x7c240ad0,0x63bd09da,0x64498118,0x27eb0326}},	//   _toir, basn, _omei, _bbcn_,
   {{0x5eeecc4d,0xdb008722,0x81ae8264,0x1cb681c6}},	//   _अहम्_, _memò, _কাছ_, _פלפל_,
   {{0x4424db45,0xe7e9853e,0x7a301ea9,0x6f1d92d2}},	// [4920] _rom_, झ्या_, _jätk, äsch,
   {{0x44248bfa,0x6449db46,0x6ecf800d,0x26c05b47}},	//   _som_, _amei, _दिनु, rsio_,
   {{0x442490af,0xdcea8d11,0x26c00652,0x69fb007c}},	//   _pom_, čiće, ssio_, _גליק,
   {{0xe29a8196,0x746980e8,0x7ae2db48,0xf487853d}},	//   гад_, арів_, ttot, مانی,
   {{0x4424db49,0xa3d90996,0x853c8110,0xdb0083a8}},	//   _vom_, ालत_, lbėt, _remó,
   {{0x78a202fd,0x7ae2db4a,0x2002022e,0xc5d5035f}},	//   _čovj, rtot, _haki_, _місь,
   {{0x2002059c,0x63a42e5d,0xf41f0009,0x69d8d625}},	//   _kaki_, _ofin, yjä_, rgve,
   {{0x6d5700be,0x2002009a,0x628f81e8,0x63a40144}},	//   _הילף_, _jaki_, _ècon, _nfin,
   {{0x368ac060,0x3b07932a,0x41e081af,0x501b0039}},	//   лсон_, _лето_, _नापस, רופו,
   {{0x20025b4b,0x63a400a2,0x63bd5b4c,0x2a6a333c}},	//   _laki_, _afin, wasn, jobb_,
   {{0xe85384c0,0x63bd5b4d,0x69c89ad9,0xdb00802a}},	//   _کنند, tasn, _idde, _temó,
   {{0x24805b4e,0x63a2db4f,0x49178039,0x20025b50}},	//   _chim_, ncon, _לקבל_, _naki_,
   {{0x7e68826f,0x63a40122,0xb8658250,0x3ea680e4}},	//   podp, _dfin, _بالو, _utot_,
   {{0x63a280b9,0x290c826c,0x63a45b51,0xe5348ea6}},	//   hcon, _krda_, _efin, _мель,
   {{0x20023916,0x28d91094,0x25dd8074,0xdddc2d77}},	//   _baki_, बंधि, _खाती_, _birž,
   {{0x290c8bcf,0x20025b52,0x98a501cc,0x25be8122}},	//   _mrda_, _caki_, çlı_, latl_,
   {{0x69c8db53,0x63a2b23e,0x20025b54,0xf7730b53}},	// [4930] _odde, dcon, _daki_, سار_,
   {{0x290cdad7,0x7a300338,0xdceb01d6,0x2007066f}},	//   _orda_, _näth, žiči, śni_,
   {{0x5f95002e,0x7f95174a,0xadea8074,0x59d28072}},	//   _минт, _манх, ज्यन_, _साजर,
   {{0x69d804b8,0x69dbaf7b,0xfbd08077,0x69c88051}},	//   _över, _नाही, فته_, _adde,
   {{0x387e02be,0xdc3984b7,0x2be1103e,0x290cb408}},	//   ître_, għġb, _कानू_, _arda_,
   {{0x290c82a5,0x27e9031d,0x20025b55,0x644f5b56}},	//   _brda_, lfan_, _zaki_, hici,
   {{0xa3d90894,0x644f00a4,0x200200a4,0x6615190f}},	//   ाला_, kici, _yaki_, _inzk,
   {{0x2bdb09a9,0x63a28098,0x09ca80c8,0x27e903ec}},	//   _भाषा, ccon, ল্লা, nfan_,
   {{0xee39c675,0xcdf5a252,0x25dd9344,0x290c8144}},	//   ини_, очны, _खादी_, _erda_,
   {{0x63a45b57,0x7bdf519e,0xa6e2007b,0x24805b58}},	//   _sfin, _acqu, æðin, _shim_,
   {{0xcb09073a,0x24805b59,0x63bb8057,0x61558019}},	//   _של_, _phim_, _keun, _بنائ,
   {{0x63bb83d3,0x644f02be,0x59dc0321,0x645983ec}},	//   _jeun, gici, _बाहर, nnwi,
   {{0xe29a4bc8,0xa3e19299,0x67d48221,0x41e092e0}},	//   раг_, _दान_, _хочу, _नामस,
   {{0x3ead91ee,0xa509a955,0x20025b5a,0x63bb8b2e}},	//   mpet_, _века_, _saki_, _leun,
   {{0x290c5b5b,0xf41f0364,0x24805b5c,0x27e92aae}},	//   ída_, mmän_, _thim_, ffan_,
   {{0x6603db5d,0xf41f0c3c,0x670505fc,0x59dc00d4}},	//   _hank, lmän_, रिंक_, _बावर,
   {{0x66038f38,0x7e261e4e,0x63a2826c,0x3e6f0019}},	// [4940] _kank, одаж, vcon, yütt_,
   {{0xe6173142,0x66038b48,0x63a2bb39,0x2002054e}},	//   оду_, _jank, wcon, _waki_,
   {{0x69dc5b5e,0x6835826f,0x63bb9670,0x20025b5f}},	//   mgre, _nádo, _beun, _taki_,
   {{0x69dc11f8,0x6603db60,0xd00a0895,0x717b0051}},	//   lgre, _lank, _теме_, _כניס,
   {{0x6f0985f5,0xd838a145,0x63a2db61,0xda668098}},	//   jvec, _juče_, rcon, овди,
   {{0x6281db62,0x2486807d,0x683c82be,0x63a2a13b}},	//   _chlo, smom_, _méde, scon,
   {{0x644f5b63,0x63a2890d,0xed571a21,0x6ab75b64}},	//   yici, pcon, _дор_, _अब्र,
   {{0x2120803b,0x3ec6b5aa,0x6603a229,0x63bb8d00}},	//   ćih_, особ, _aank, _geun,
   {{0xb5fc84b7,0x31698380,0x7c22a176,0x2be130ee}},	//   loġi, ğaza_, mjor, _काबू_,
   {{0x69c88efa,0x6603db65,0x644f009a,0x2002807a}},	//   _udde, _cank, wici, žki_,
   {{0x66038faf,0xa3e1800f,0xafe6835f,0x644f1b90}},	//   _dank, _दाम_, _можл, tici,
   {{0x09d3035a,0x7c22db66,0x1ee980d7,0x660d89ab}},	//   तल्य, njor, جویی_, _ɗaki,
   {{0x6603db67,0x6756804e,0x261a847d,0xdddc01b9}},	//   _fank, _بخار, बादी_, _birż,
   {{0x644f2e3c,0x7e04000c,0x38698024,0x69dc5b68}},	//   sici, रयोग_, čare_, ggre,
   {{0x26050063,0x7a3f001b,0xe3bf03a8,0xf84b02a9}},	//   _होगी_, vště, pañ_, ачай_,
   {{0x26c2816b,0x60c901a9,0x2d985b69,0x68380144}},	//   škou_, ņemo, _agre_, _pída,
   {{0xdd9b0fbe,0x27e91a61,0x9f4b0722,0x7c22db6a}},	// [4950] аше_, rfan_, _racó_, djor,
   {{0x44290104,0x61f8a50d,0x26c4a2f8,0x63bbdb6b}},	//   _hoa_, jevl, ismo_, _seun,
   {{0x6aa9db6c,0x4429011b,0x201601ac,0x644d00ee}},	//   _stef, _koa_, ácií_, _kmai,
   {{0x7bdd5b6d,0x44295b6e,0x7c22b43d,0x29015b6f}},	//   ngsu, _joa_, gjor, _isha_,
   {{0x44295b70,0x78a2005c,0x62818a2a,0x68310aa2}},	//   _moa_, _čovi, _phlo, _rådh,
   {{0xceb24100,0x44295b71,0x2c5601a9,0x6f0f0037}},	//   _איך_, _loa_, rādi_, _ircc,
   {{0x628f81e8,0x6603db72,0x644d0198,0x63bb9c2b}},	//   _ècom, _rank, _omai, _teun,
   {{0x44295b73,0x59d789a3,0x66038a76,0x6f09816d}},	//   _noa_, _ठाकर, _sank, tvec,
   {{0x6603db74,0xef1697ae,0x69dc43c9,0xf1a79f2f}},	//   _pank, змы_, ygre, _дрен,
   {{0xee39964f,0x644d1960,0x683cdb75,0x3eb901ec}},	//   сно_, _amai, _réde, _mwst_,
   {{0x4429156b,0x7c29cb07,0x6603db76,0x7c3bdb77}},	//   _boa_, _koer, _vank, _klur,
   {{0x442907f4,0x3ead904a,0x6603985b,0x7c29d502}},	//   _coa_, ppet_, _wank, _joer,
   {{0x66039bcd,0x44295649,0x69dc5b78,0xc05280be}},	//   _tank, _doa_, tgre, _אזא_,
   {{0x683c8019,0xd838812b,0xc60a06a7,0x2496803d}},	//   _véde, _vuče_, _होंठ_, _کنيد_,
   {{0x7c3ba1e8,0x28cf914f,0x3eb90114,0xe7e2815c}},	//   _olur, सूचि, _awst_, क्का_,
   {{0x7a30016d,0xd83881dd,0xb8f40cf0,0x644d5b79}},	//   _nätv, _tuče_, _हट_, _gmai,
   {{0xe7e3959a,0x7d0e05b7,0xee3a0c9b,0x2fc00224}},	// [4960] _गाना_, _srbs, бна_, raig_,
   {{0x7c3bdb7a,0x2fc05b7b,0xd6cf0199,0x3ea003ed}},	//   _alur, saig_, اقل_, rqit_,
   {{0x7c2990f4,0x399b012a,0xb3a982bb,0xa06a0071}},	//   _boer, _לייד, ğını, _гана_,
   {{0x386d89c4,0xb3a9817b,0xd6d9809a,0x7c29db7c}},	//   joer_, şını, kuł_, _coer,
   {{0x7c229c33,0x224c808e,0x320582f9,0x08e68264}},	//   rjor, _pmdk_, _baly_, কিছু_,
   {{0xd5b20b76,0xa2cdbd6d,0x38a38059,0x6831128d}},	//   _سفر_, _सिर्, _sıra_, _rådi,
   {{0x490f27ec,0x61f8db7d,0x60c80174,0x764e0314}},	//   डियो_, revl, ádmh, _imby,
   {{0x61f8812b,0x97148698,0x8f468098,0xd6da80e8}},	//   sevl, дмиц, зход, бто_,
   {{0xbbd881a2,0xa2ce008e,0x26c48196,0x7a3d83ec}},	//   डलीक, _तिष्, usmo_, _sète,
   {{0xba29ce5c,0x2d98835f,0xceb30039,0x7bc0007b}},	//   _وسلم_, øre_, עית_, ðmun,
   {{0x25dd8076,0xfc3f00f7,0x386d9a47,0xe0d28019}},	//   _खारी_, thí_, boer_, _سزا_,
   {{0x2fc08125,0x897b80be,0x6249016b,0x644d0609}},	//   _þig_, _פראצ, nžov, _qmai,
   {{0x288b84c0,0x44295b7e,0x7afd00f3,0x764e01a3}},	//   _اصلی_, _voa_, uwst, _omby,
   {{0x26c28110,0x6f02b55b,0xa2ce01d0,0x7de69abb}},	//   škos_, _isoc, _तिर्, _رستم,
   {{0x0cd700c8,0x44295b7f,0xae0a001b,0x61142183}},	//   _সন্ত, _toa_, _होइन_, ндру,
   {{0x644d404b,0xa2cd815c,0x940b954b,0x764e4b34}},	//   _umai, _सिल्, _सोंच_, _amby,
   {{0x7c299151,0x387e0036,0x7bcd02f9,0x92080ec3}},	// [4970] _roer, îtra_, _idau, _brāļ,
   {{0xd3580039,0x290101c0,0x248482c4,0x6aad5b80}},	//   _משחק_, _tsha_, _ahmm_, _itaf,
   {{0x7c3bdb81,0xd7dc853e,0x7c299abb,0xdb04007b}},	//   _plur, _यांच, _poer, _heið,
   {{0x442987ca,0x628a81b0,0x683801d0,0x645d5b82}},	//   ða_, emfo, _jídl, nnsi,
   {{0x7c298b3c,0xa3e20ebf,0x25dd93ba,0x386d9ae1}},	//   _voer, न्ट_, _खाली_, voer_,
   {{0x20090110,0xae0a016f,0x629f008e,0x2484808e}},	//   ldai_, _होऊन_, _muqo, _ehmm_,
   {{0x6f02db83,0xdb040125,0x7c298b3c,0x2ee90125}},	//   _asoc, _leið, _toer, ltaf_,
   {{0x200900dd,0x77f981cb,0x7a3002af,0xd6d9809a}},	//   ndai_, ्येक_, _hätt, tuł_,
   {{0xfaf09368,0x2ee9031d,0x7a300074,0xd7068009}},	//   _مثل_, ntaf_, _kätt, дные_,
   {{0x7bcd0012,0xf1a79289,0x7a305b84,0x62975b85}},	//   _adau, _хран, _jätt, _nixo,
   {{0x20068307,0x6607003b,0x69c39473,0x6f0d0042}},	//   _faoi_, _majk, mane, hvac,
   {{0x7a3000f2,0x69c383fd,0x6607005c,0x6fd6880a}},	//   _lätt, lane, _lajk, rücü,
   {{0x20090355,0x7a348a2a,0x261ab41c,0x26c28088}},	//   ddai_, _bàth, बाशी_, škor_,
   {{0x27ed82af,0x660729b4,0x20090110,0x7a301a57}},	//   lfen_, _najk, edai_, _nätt,
   {{0x63a9db86,0x261a890f,0xafe600e8,0x6f0d828f}},	//   _ofen, बारी_, мовл, _šach,
   {{0xf7721ecd,0x6d4509ca,0x629716cb,0x6b9bdb87}},	//   ناء_, dzha, _eixo, _ngug,
   {{0x7a3004b8,0x69c3db88,0x2cad02ee,0xf4130039}},	// [4980] _bätt, kane, _čeda_, _יפה_,
   {{0x20195b89,0x69c3db8a,0x63a9846d,0x6607111b}},	//   _ensi_, jane, _afen, _cajk,
   {{0x621b093f,0x61fc07d5,0xafdb0edd,0x290400eb}},	//   _וויק, merl, _blød, āmas_,
   {{0x25fa2708,0x61fc16fa,0x629f20d8,0xa3e25b8b}},	//   _उसकी_, lerl, _yuqo, न्च_,
   {{0x69c3829b,0xdb0081ac,0x62491c3f,0x59d223e7}},	//   fane, _nemô, ržov, _तयार,
   {{0x69c38d23,0x27e05b8c,0x27edacad,0x320a45a7}},	//   gane, lgin_, efen_, ndby_,
   {{0x27edcd9c,0x26f88576,0x2c0e0063,0x63a9c24b}},	//   ffen_, ्ट्र_, ियां_, _ffen,
   {{0x27e02079,0x66072e1e,0x61e901dd,0x161c016f}},	//   ngin_, _zajk, đeli, नावर_,
   {{0xa3e203bb,0x644280f7,0x61fc2370,0x60dc010c}},	//   न्छ_, mhoi, kerl, hurm,
   {{0x38698025,0x4426aea1,0x6838026f,0x61fc0669}},	//   čara_, ljo_, _sídl, jerl,
   {{0x61fc5b8d,0x7bc0db8e,0xb143802e,0x6aad53db}},	//   derl, _kemu, _инфл, _staf,
   {{0x7bc08b17,0x6835826f,0x64428009,0x6aa0ade9}},	//   _jemu, _nádh, nhoi, _kumf,
   {{0x7bc09cc9,0xf047819f,0x61fc5b8f,0x645d4ac6}},	//   _memu, _تعلی, ferl, rnsi,
   {{0x7bc0cdb8,0x60dc022b,0xdb04007b,0xc5d580ab}},	//   _lemu, furm, _veið, ত্বপ,
   {{0x7a3004b8,0xdb1d008b,0xa3e70f97,0x8c671071}},	//   _rätt, masí, _पाप_, _отид,
   {{0x7a302fc8,0x27e024d0,0x7bc09517,0x6f0d00fe}},	//   _sätt, ggin_, _nemu, tvac,
   {{0x61fc07d9,0x4426854b,0x290c016d,0x6aad0010}},	// [4990] berl, djo_, ådar_, _utaf,
   {{0x61fc5b90,0x2ca704c3,0xab5dcaf7,0x60dc5b91}},	//   cerl, índo_, _jeże, burm,
   {{0x69c3db92,0xb3a98059,0x63a9db93,0x7bc08019}},	//   vane, şımı, _pfen, _bemu,
   {{0x44390367,0x69c3db94,0x7bc080ee,0x09d7816f}},	//   nks_, wane, _cemu, ठल्य,
   {{0x69c3b136,0xe5c705c2,0x7bc0db95,0xa3e7035a}},	//   tane, _осво, _demu, _पान_,
   {{0xdd868bbe,0xd3380051,0x683c80e7,0xa2d72123}},	//   _مو_, ורדה_, _réda, _बिन्,
   {{0xdb0b8013,0x27ed87d9,0x3e74016d,0x2eff8239}},	//   tagó, tfen_, rätt_, wwuf_,
   {{0x6442db96,0x44390a0f,0xb91a0a2c,0x7bc0978f}},	//   choi, jks_, _anyị_, _gemu,
   {{0x443fdb97,0x27eddb98,0xf70880ff,0x9f4b016b}},	//   _ilu_, rfen_, _củ_, _obcí_,
   {{0x442d81d8,0x44395b99,0x7bc082ee,0xab84a0ad}},	//   _hoe_, eks_, _zemu, _руск,
   {{0x442ddb9a,0x443fa0d5,0x7af65b9b,0x7c2d5b9c}},	//   _koe_, _klu_, _spyt, _boar,
   {{0x69c1db9d,0x290582a3,0xd8389487,0xb91a01bc}},	//   _hele, _isla_, _tuča_, _enyị_,
   {{0x2bd0816f,0x442ddb9e,0x7c2d0162,0x3f9d8133}},	//   हणता, _moe_, _doar, _igwu_,
   {{0x69c1db9f,0x442d8006,0x97568039,0x60dc5ba0}},	//   _jele, _loe_, _אינו_, turm,
   {{0x7c2d0012,0x69c1d847,0x3da6835f,0x443fdba1}},	//   _foar, _mele, _якщо_, _olu_,
   {{0x69c1dba2,0x02df88fd,0x442d8cde,0x44395ba3}},	//   _lele, _नमून, _noe_, cks_,
   {{0x7bc62a7a,0x683585e4,0x27e05ba4,0x068601cf}},	// [49a0] maku, _cádi, rgin_, еган,
   {{0x7bc0845c,0x7bc60393,0x2d9c0bc5,0x69c1dba5}},	//   _semu, laku, øve_, _nele,
   {{0x7bc0859c,0x442d9ee8,0x443fdba6,0x644280f7}},	//   _pemu, _boe_, _blu_, thoi,
   {{0xdd8f12dc,0x09c8816f,0x4426dba7,0xa06a0071}},	//   حوم_, रण्य, ujo_, _хама_,
   {{0x68e300f2,0x4426c29e,0x443fd41d,0x7794026a}},	//   _ändr, rjo_, _dlu_, _شیطا,
   {{0x443fdba8,0xfce640bd,0x78a1dba9,0x3f9ddbaa}},	//   _elu_, _пого, _bulv, _agwu_,
   {{0x7bc65bab,0x7bc0dbac,0x443fa59e,0x644281a8}},	//   kaku, _temu, _flu_, phoi,
   {{0x38603e0c,0x68e303ba,0xfba483eb,0x6b840135}},	//   nnir_, _ånde, _ओलिम, _ozig,
   {{0x6440db1a,0x69c18065,0x7bc65bad,0x09d800ab}},	//   _ilmi, _fele, daku, দ্যা,
   {{0x69c1dbae,0x6e2e0094,0x443f80d2,0x7c2d095d}},	//   _gele, _jobb, _zlu_, _soar,
   {{0x6e2e4314,0x78a18aa2,0x7c2d0087,0x3860007b}},	//   _mobb, _gulv, _poar, knir_,
   {{0x61e5034a,0x7bc606a0,0xf708801c,0xda1e8075}},	//   _schl, gaku, _tủ_, पावत_,
   {{0xa3e7146d,0x629ab3d5,0x44395baf,0x2aab0656}},	//   _पाठ_, _kito, rks_, ятно_,
   {{0x4439235d,0x171b8039,0x6e2e22e7,0x629adbb0}},	//   sks_, _מודע, _nobb, _jito,
   {{0xa3e183db,0x6b84580c,0x7bc63adc,0x2cad017f}},	//   _दाल_, _ezig, baku, _čedo_,
   {{0x3860007b,0x4ea711d2,0x629adbb1,0xc6a72d5d}},	//   gnir_, ержа, _lito, ержи,
   {{0x63ad031d,0x64438168,0x63bb008b,0x7c3d03ed}},	// [49b0] _ifan, ënim, ðunu, ërru,
   {{0x629adbb2,0x443fb83a,0x6e2e2651,0x6440dbb3}},	//   _nito, _slu_, _cobb, _almi,
   {{0x6e2e5bb4,0xf65380be,0x69c75bb5,0x442ddbb6}},	//   _dobb, נצע_, maje, _poe_,
   {{0x69c75bb7,0x13a78077,0x629ab86d,0xe3b38829}},	//   laje, رنتی_, _aito, ارض_,
   {{0x629a9f37,0x63ad28b2,0x09e580b3,0x91e5dbb8}},	//   _bito, _mfan, волн, воле,
   {{0x69c75bb9,0x660a8859,0x7bc60518,0x6440dbba}},	//   naje, _nafk, zaku, _elmi,
   {{0xa2cd91be,0xfa1300c8,0x7bc64289,0x63ad5bbb}},	//   _सिक्, _সকাল_, yaku, _ofan,
   {{0xe81e8074,0x200b02a5,0x62888009,0x69c1dbbc}},	//   भाषा_, _jaci_, _ehdo, _wele,
   {{0x600691e9,0x629adbbd,0x69c7029b,0xdcfc00eb}},	//   тным_, _fito, kaje, _izrā,
   {{0x7bc64349,0x63ad5bbe,0x660a84b9,0x7a300106}},	//   waku, _afan, _cafk, _nätp,
   {{0x69c75bbf,0x04460364,0x7bc64062,0x0d828987}},	//   daje, венн, taku, ильн,
   {{0x200b0052,0x25dd85fc,0x2af58074,0x3f9d8870}},	//   _naci_, _खाकी_, _इहाँ_, _ugwu_,
   {{0xe72ec7de,0xde05999a,0x38600176,0xdee5a829}},	//   _те_, _апли, vnir_, _роли,
   {{0xe2972bef,0xc3328051,0x7bc65bc0,0xe5a2802e}},	//   кая_, סום_, saku, _киши,
   {{0xe2975bc1,0x7bc62933,0x200b5bc2,0xa2ce09c1}},	//   тар_, paku, _baci_, _तिक्,
   {{0x63a904c3,0x27ffced7,0x200dc434,0x200b5bc3}},	//   ñent, neun_, ndei_, _caci_,
   {{0x38600125,0xe9f90104,0xe5a6067c,0x200b5bc4}},	// [49c0] rnir_, _quả_, визи, _daci_,
   {{0x69c70052,0x683803a7,0x200b0197,0x4f950087}},	//   caje, _mídi, _eaci_, урсу,
   {{0x27ff808e,0x69d90158,0x200b13df,0x629adbc5}},	//   keun_, _אַרו, _faci_, _rito,
   {{0x629adbc6,0x27ff826b,0x69d781df,0x7794015b}},	//   _sito, jeun_, óxen, _میزا,
   {{0x6e2e5bc7,0x7c659a05,0x200d911d,0x6aa40036}},	//   _tobb, دالل, ddei_, _juif,
   {{0x5333cc6f,0x9586104b,0x6f040314,0x200b09ab}},	//   решт, _алге, mwic, _zaci_,
   {{0x2576003d,0x9c7d0289,0x645880e7,0x98c38a8e}},	//   _شهرس, luče, évis, асыл,
   {{0x629ad232,0x27ff82f7,0xdfd080f7,0x6d489e51}},	//   _wito, geun_, حية_, vzda,
   {{0xe7e38076,0x629adbc8,0xfaa6884b,0x26c7005c}},	//   _गारा_, _tito, _разо, ćnog_,
   {{0x4375827e,0x63ad0087,0x629a815f,0x200d8162}},	//   _суст, _sfan, _uito, adei_,
   {{0x2489570d,0x69c75bc9,0xd5b881a9,0x63ad0192}},	//   _pham_, vaje, rbā_, _pfan,
   {{0xa3ea8076,0x5fe11c58,0x6fa68072,0x26cf0061}},	//   _माफ_, _फाइल, _ऑलिं, ágok_,
   {{0xa3ea9344,0x660a8041,0xfe468d9e,0x1de243bc}},	//   _मान_, _tafk, _индо, _पांत,
   {{0x7df3000d,0xaa641697,0x200b5bca,0xab5d8372}},	//   _měsí, атск, _saci_, _jeża,
   {{0x69c70bc1,0x24895bcb,0x200b5bcc,0x0efd0072}},	//   raje, _tham_, _paci_, ॉट्स_,
   {{0x6ebf913d,0x69c75bcd,0x63ad00b8,0x63a0808e}},	//   लीवु, saje, _ufan, _ngmn,
   {{0x81cd80c8,0x09d800ab,0x44ce8d42,0x22840106}},	// [49d0] ষ্ট_, দ্ধা, lę_, söka_,
   {{0x7c3d5bce,0x7aed586b,0x7a3d8980,0x41a703ca}},	//   lksr, _iqat, _rèto, _खलिस,
   {{0x44ce8d42,0x3cd515a6,0x723401a8,0x200b5bcf}},	//   nę_, ужес, _خريط, _taci_,
   {{0xccf38158,0x1c1d8305,0x7a2b01ec,0xf34e81bc}},	//   יכע_, फाइल_, _nütz, rụnụ_,
   {{0x69c50057,0x62358152,0x41a71a42,0x6458823e}},	//   _kehe, леду, _खलास, èvia,
   {{0x44ce8d42,0x2fc91c2b,0x657c26f4,0x68385bd0}},	//   kę_, laag_, _fyrh, _rídi,
   {{0x69c55bd1,0x44ce809a,0x27ffa51d,0x63a4dbd2}},	//   _mehe, ję_, teun_, žina,
   {{0xd7099ba8,0x69c55bd3,0xead1077f,0x44cea9d9}},	//   ение_, _lehe, _pẹlu_, dę_,
   {{0x200ddbd4,0x27ff8706,0xe5a58dc0,0xe8e10129}},	//   rdei_, reun_, липи, _ướp_,
   {{0x9a87acd1,0x7afb8637,0x41c7dbd5,0x69c55bd6}},	//   _рубл, _iput, _रजिस, _nehe,
   {{0x25eb0076,0x6ed8858c,0x44cea9d9,0x3866804a}},	//   _चानी_, _मिथु, gę_, _fjor_,
   {{0xc209004c,0xdb040118,0x9f058019,0x999e8176}},	//   _מה_, _afiá, _موصو, _antň_,
   {{0xa3e1acfc,0x69c54e6c,0x2fc95bd7,0x628f81e8}},	//   _दाई_, _behe, daag_, _ècos,
   {{0x644656cd,0x387fbb43,0x9c7d005c,0x6fe1064a}},	//   shki, llur_, vuče, _फाउं,
   {{0x213e1e09,0x69c51ad9,0x44ce809a,0xd9430371}},	//   áth_, _dehe, cę_, бери,
   {{0x6f0402af,0x2b55003d,0x9c7d0289,0x69c52022}},	//   twic, ایید_, tuče, _eehe,
   {{0x44201dda,0x33260086,0x6459999b,0x645600b4}},	// [49e0] _ini_, _çox_, diwi, _imyi,
   {{0x44325bd8,0x69c51781,0xa20646dd,0x9c7d21d1}},	//   _hoy_, _gehe, _спод, ruče,
   {{0x320c8e04,0x7afb81bc,0x442037ee,0x63a921f6}},	//   _rady_, _aput, _kni_, žene,
   {{0xf7678288,0x0b46ac18,0x320c826f,0xfaa6976e}},	//   _ها_, лнен, _sady_, гадо,
   {{0xa3e70fcc,0x4caa80c8,0x60c90029,0xa09b00be}},	//   _पास_, _কিছু, ņemt, _ריכט,
   {{0xa2d7000c,0x35a35bd9,0xada30196,0x2d878088}},	//   _बिस्, _гарг, _гарл, _ozne_,
   {{0x6601a588,0x7afbdbda,0x629e0144,0x320c84e8}},	//   delk, _eput, _mipo, _vady_,
   {{0x04438318,0xc6f8a4c1,0x387f807b,0x4420026b}},	//   _лесн, вних_, glur_, _nni_,
   {{0xab668656,0x320c801b,0x44ce8035,0x627b8035}},	//   _свал, _tady_, wę_, _słoń,
   {{0x44205bdb,0x44ce8d42,0x1ef78013,0x9e06a6c8}},	//   _ani_, tę_, اعية_, учил,
   {{0x44ee027f,0x69c5393c,0x44200101,0x387fdbdc}},	//   ný_, _rehe, _bni_, blur_,
   {{0x69c55bdd,0xa2db9c58,0x69cad915,0x443206cb}},	//   _sehe, _निम्, lafe, _coy_,
   {{0x44205bde,0x6601dbdf,0x44320e1b,0x44cecb13}},	//   _dni_, belk, _doy_, sę_,
   {{0x44205be0,0x69cadbe1,0xdd948196,0x44ce9c43}},	//   _eni_, nafe, _калы, pę_,
   {{0x629e0b20,0x61f582d0,0x69c50061,0x765adbe2}},	//   _dipo, _özle, _vehe, mity,
   {{0x765ad60c,0xa2ce016f,0x7ae28110,0x57b534d5}},	//   lity, _तिच्, kuot, рбат,
   {{0xcddb19e6,0x69c55be3,0xf3f000f7,0x2fc90fb0}},	// [49f0] ење_, _tehe, _رأي_, raag_,
   {{0x59e0800c,0x765a9c07,0x7ae28110,0x443d81bf}},	//   _नागर, nity, duot, wkw_,
   {{0x6459dbe4,0x2d87016d,0x660e01b4,0xc66803a7}},	//   tiwi, åne_, _dabk, уште_,
   {{0x6601809a,0x765a8009,0x64440706,0x629e038a}},	//   zelk, hity, _xlii, _zipo,
   {{0x34c18b6f,0x3ea90609,0x645981bf,0x660e0282}},	//   _शब्द, qqat_, riwi, _fabk,
   {{0x50b811fb,0x08d58656,0x6459a833,0x6835826f}},	//   _جدید_, ация, siwi, _nádr,
   {{0x90c29ba8,0x765adb7a,0xdb0d002a,0x63bd02c4}},	//   обще, dity, _meañ, kbsn,
   {{0x44d10a8e,0x3ea682d5,0xc0a88199,0x38aa8362}},	//   mą_, _buot_, داول_, _dùr_,
   {{0x7afb803a,0xeab09e7b,0x7bcb9fae,0x41e791cc}},	//   _uput, _فعل_, magu, _مساف,
   {{0xee3995e0,0x44325be5,0xee368364,0x7bcbdbe6}},	//   тно_, _soy_, ины_, lagu,
   {{0x9967812f,0x44d11c4c,0x629e5be7,0x248d8640}},	//   _стал, ną_, _ripo, _khem_,
   {{0x2aab8022,0x68e3dbe8,0x629e5be9,0x7bcb85ac}},	//   _køb_, mund, _sipo, nagu,
   {{0xa3e71344,0x68e3dbea,0x443200ab,0x66018102}},	//   _पार_, lund, _voy_, pelk,
   {{0x7bcbaaf1,0x44d101e2,0x200fdbeb,0x7f8480f7}},	//   hagu, ką_, _hagi_, _الهن,
   {{0x44d10d12,0x68e3dbec,0x20564324,0x4420061b}},	//   ją_, nund, атар, _tni_,
   {{0x44ee0a56,0x44d10d42,0x645d5bed,0x7bcbb00e}},	//   vý_, dą_, érit, jagu,
   {{0xe7370364,0x7bcbdbee,0x2ca79766,0x68e3dbef}},	// [4a00] ает_, dagu, _hund_, hund,
   {{0x68e3dbf0,0x200f8812,0x44ee003e,0x2ca7cabe}},	//   kund, _lagi_, tý_, _kund_,
   {{0x9c7d0024,0x44d118eb,0x68e38074,0x89db0039}},	//   luča, gą_, jund, _בחיי,
   {{0x44ee0a56,0x2ca788cf,0xf09f5bf1,0x66e63606}},	//   rý_, _mund_, _già_, _кома,
   {{0x69cadbf2,0x63a4bbe2,0x6b89809a,0x291a2f56}},	//   tafe, žino, _czeg, _hrpa_,
   {{0x68e3dbf3,0x7ae281e2,0xc8da016f,0x09d800ab}},	//   fund, ruot, _बटाट, দ্রা,
   {{0x200f845c,0x68e3a769,0x7bcbcfa6,0x3ea6c4c5}},	//   _bagi_, gund, bagu, _suot_,
   {{0x63a4303d,0xa2d71c6f,0x63ad8511,0x64a31597}},	//   _ngin, _बिल्, ñant, _фата,
   {{0x9c7d011f,0x3ea6cb69,0xf1c605fc,0x09e6c353}},	//   juča, _quot_, वरान, _возн,
   {{0x63a4011e,0x9c7d02a5,0x68fe035f,0xd838811f}},	//   _agin, duča, _oppd, _muči_,
   {{0x24421220,0x69c8dbf4,0x63a4008e,0x765adbf5}},	//   _cómo_, _iede, _bgin, rity,
   {{0x69c8dbf6,0x765a8364,0x200fdbf7,0x290c8cf4}},	//   _hede, sity, _gagi_, _isda_,
   {{0x69c8dbf8,0xab8705e9,0xba7701a8,0x78a88338}},	//   _kede, рунк, لاست, _hudv,
   {{0x69c8b4dd,0x2004dbf9,0x63a400ad,0x2245007b}},	//   _jede, lemi_, _egin, ólk_,
   {{0x645d02be,0x6cd489a7,0x228981ac,0x7bcbd50b}},	//   éris, _اقبا, núka_, yagu,
   {{0x69c8a315,0x9c7d0301,0x2004dbfa,0x44d10084}},	//   _lede, buča, nemi_, vą_,
   {{0x44d1009a,0xcf9380be,0x78a8dbfb,0x69c88bfd}},	// [4a10] wą_, ַטע_, _ludv, _oede,
   {{0x645d5bfc,0x38698025,0x44d11c4c,0x68e3dbfd}},	//   lisi, čari_, tą_, yund,
   {{0x7bcbdbfe,0x6b898019,0x2004dbff,0x248d81c5}},	//   tagu, _szeg, kemi_, _phem_,
   {{0x645d5c00,0x44d10d42,0x68e3dc01,0xdcef82a5}},	//   nisi, rą_, vund, žeći,
   {{0x7bcbdc02,0x77640698,0x68e3dc03,0xd8388279}},	//   ragu, _държ, wund, _guči_,
   {{0x27e95c04,0x7bcbdc05,0x78a8825b,0x21699541}},	//   lgan_, sagu, _budv, лили_,
   {{0x645d5c06,0x200f8867,0x248ddc07,0x66050359}},	//   kisi, _pagi_, _them_, mehk,
   {{0x27e91e92,0x66050057,0x2ca782af,0xb8ff800c}},	//   ngan_, lehk, _rund_, _ति_,
   {{0x200fdc08,0x2ca78ac6,0x27e95c09,0x6b80dc0a}},	//   _vagi_, _sund_, igan_, _gymg,
   {{0x69c8dc0b,0x68e3dc0c,0x27e90362,0x2ca7aeca}},	//   _gede, pund, hgan_, _pund_,
   {{0x645d009e,0x200fdc0d,0x63b88187,0xda7a83de}},	//   fisi, _tagi_, _àaná, _ענער,
   {{0x4aab85b3,0x6aa18352,0x69c8dc0e,0x69d703a8}},	//   _चढाव, _hilf, _zede, _adxe,
   {{0xd87480f7,0x660500ee,0x69c882d0,0x7bc99151}},	//   _بالب, kehk, _yede, _meeu,
   {{0x9c7d005c,0xe5a58081,0x7bc983b2,0x683c80e7}},	//   ruča, _уики, _leeu, _rédi,
   {{0x64b5a219,0x61430c99,0x6aa19106,0xd9430aac}},	//   _احتر, пера, _milf, пери,
   {{0x27e92a37,0x63a40503,0x645d1b90,0x7bd602c4}},	//   ggan_, _ugin, cisi, _udyu,
   {{0xef1a0110,0x7c244500,0x44f1dc0f,0x2bb5103e}},	// [4a20] ыма_, _inir, lá_, ंडरा,
   {{0xa3ea809a,0x27e90014,0x7ae65c10,0x7c360b0b}},	//   _माह_, agan_, mukt, _hoyr,
   {{0x68fe04b8,0x44f184ab,0xeafa0416,0x7ae647c8}},	//   _uppd, ná_, _شرکت_, lukt,
   {{0x69c8dc11,0x69ce4b2c,0x2c21000f,0xd8388da8}},	//   _sede, labe, याएं_, _tuči_,
   {{0x69c882b1,0x44f1826f,0x06b200ab,0x26cf0019}},	//   _pede, há_, _চিকি, ágot_,
   {{0xfe678307,0x9c7d04c4,0x645d5c12,0x660507cf}},	//   _رد_, jučn, zisi, cehk,
   {{0x69c8dc13,0x7c242ad7,0x2004dc14,0xa3d80a16}},	//   _vede, _onir, temi_, ाणा_,
   {{0xdd8f00f7,0x44f19c4b,0x6d5c9c1f,0x69c8a389}},	//   _سوق_, dá_, úram, _wede,
   {{0x69ce534f,0x69c8dc15,0x20049a54,0x6aa1b01d}},	//   kabe, _tede, remi_, _filf,
   {{0x2004dc16,0x7c245c17,0x6442dc18,0x225a0748}},	//   semi_, _anir, lkoi, _nmpk_,
   {{0x645d5c19,0x99869ecd,0x667b0158,0xd7faa4dd}},	//   tisi, _الاو, רטיק, _бул_,
   {{0xdee6838d,0x3d000fea,0x9c7d050b,0x2ee05c1a}},	//   _годи, _रहने_, krče, krif_,
   {{0xd7968307,0x645d5c1b,0x073a9dd2,0xafdb0366}},	//   _الشخ, risi, _حساب_, _fløj,
   {{0x7c245c1c,0x69ce5c1d,0xa2dbaf0d,0x44f1936f}},	//   _enir, gabe, _निस्, bá_,
   {{0x27e90428,0x645d0042,0x6e3509a4,0xd2581138}},	//   tgan_, pisi, _rozb, сця_,
   {{0x63a48042,0x25eb0074,0xdbf1801b,0x2ee00114}},	//   žinj, _चाही_, _přík, frif_,
   {{0x69ce5c1e,0x94120085,0x40340198,0x6e355c1f}},	// [4a30] babe, _niyə_, четс, _pozb,
   {{0x69ce0333,0x7bcf20d5,0x6b8d1768,0x27e95c20}},	//   cabe, lacu, _izag, sgan_,
   {{0x40350087,0x9f5905a4,0x4424bd11,0x66052419}},	//   _денс, _pasó_, _bnm_, rehk,
   {{0x26cf0019,0x6aa1cf98,0xbebb0168,0x7bcf5c21}},	//   ágos_, _silf, _rrëf, nacu,
   {{0x7981ae3e,0x38695c22,0xa3e7000f,0x44f1cc83}},	//   _sylw, mnar_, _पाई_, zá_,
   {{0x6ca708cc,0x6e3500d2,0xe2999677,0x41e780e8}},	//   _граж, _uozb, шал_, сіда,
   {{0x44f1841c,0x6443dc23,0xa2db8b99,0x7bc98bfd}},	//   xá_, ënis, _निव्, _teeu,
   {{0x44f18a56,0x69ce5c24,0x38692c9f,0x7ae60122}},	//   vá_, zabe, nnar_, yukt,
   {{0x6aa1805f,0x38695c25,0xac9481e5,0x09e100ab}},	//   _tilf, inar_, _хатш, ম্যা,
   {{0x44f18626,0xc0cbcbc4,0x3f8380eb,0xe81e816f}},	//   tá_, _буде_, āju_, _मोठा_,
   {{0x6449a389,0x9c7d10d1,0x38692b2e,0x3207dc26}},	//   _klei, ručn, knar_, meny_,
   {{0x78a28698,0x69ce5c27,0x32079122,0x7ae61400}},	//   _giov, wabe, leny_, tukt,
   {{0x69ce5c28,0x683ca755,0xe042835f,0x26c6819d}},	//   tabe, _cédu, _інши, _gwoo_,
   {{0x6449c99f,0x38699487,0x2fd9002a,0x539a825f}},	//   _llei, čaru_, _adsg_, יירו,
   {{0x69ce5c29,0x6449dc2a,0x6b8d011e,0x3ce08035}},	//   rabe, _olei, _ezag, _किये_,
   {{0x69ce5c2b,0x386946e8,0xa3e70996,0x44d58029}},	//   sabe, gnar_, _पाए_, mā_,
   {{0xa2db8b84,0x69ce4794,0x44d580eb,0x24802e9c}},	// [4a40] _निष्, pabe, lā_, _ikim_,
   {{0x44248079,0x09e100ab,0x645b81a8,0xf65f3ea6}},	//   _snm_, ম্বা, _amui, _svær_,
   {{0x44d58029,0x6449dc2c,0x6f1d02af,0x8fa60eb3}},	//   nā_, _blei, _ersc, _мане,
   {{0x9c830a21,0x984c801b,0x64498224,0x442480e5}},	//   _účto, věď_, _clei, _qnm_,
   {{0x64428364,0x4424bcf6,0xb60582d4,0x3f821238}},	//   rkoi, _vnm_, _kršč, _uyku_,
   {{0xa2db885d,0x44d58029,0x6449b230,0x248000ee}},	//   _निर्, kā_, _elei, _lkim_,
   {{0x44d58341,0x64498357,0x8c468ab2,0xf65f007b}},	//   jā_, _flei, _деве, _tvær_,
   {{0x09b70c78,0x6449dc2d,0x44d580eb,0x24800282}},	//   _अभ्य, _glei, dā_, _nkim_,
   {{0xf09301db,0x7bc282be,0x32079517,0x466aa39f}},	//   ונה_, mbou, beny_, иром_,
   {{0xa3ea800f,0x386d0503,0x683c82be,0x2486821e}},	//   _माँ_, čeri_, _rédu, llom_,
   {{0x64498364,0x7bcf393d,0x683c8036,0x3869099b}},	//   _ylei, tacu, _sédu, ynar_,
   {{0x7bc2dc2e,0x9c7d016b,0x80b1025a,0x6b840314}},	//   nbou, ručo, _आंबे, _byig,
   {{0xfbd38051,0x25eb05b3,0x7e7a812b,0x61fe00b9}},	//   ותר_, _चाली_, potp, _bbpl,
   {{0xa3e70361,0x24800214,0x7bcf0216,0x6f02b45a}},	//   _पाक_, _ekim_, sacu, _ipoc,
   {{0x24868503,0xa3ea809a,0xa2d70b04,0x63b60114}},	//   klom_, _मां_, _बिक्, _ffyn,
   {{0x765c031d,0x24868088,0x6f028133,0xd8388da8}},	//   _amry, jlom_, _kpoc, _tuču_,
   {{0x38695c2f,0xddab1071,0x69da875f,0x248680e1}},	// [4a50] rnar_, ател_, _odte, dlom_,
   {{0xe81b0076,0x291e8059,0x7ae286aa,0xf1bf801c}},	//   _पोरा_, _orta_, drot, _đáo_,
   {{0x628705f5,0x6449dc30,0x38693032,0xd49b846e}},	//   mljo, _plei, pnar_, ард_,
   {{0x248682a5,0x69da80ee,0x3cfb80be,0x442781a8}},	//   glom_, _adte, שלאנ, غراف,
   {{0x44c78065,0x7ae2ae86,0x291eaeb0,0x644981b0}},	//   ző_, grot, _arta_, _vlei,
   {{0x6aad5c31,0x6f0d0c53,0xab5d822b,0x64498428}},	//   _muaf, mwac, _jeżi, _wlei,
   {{0xa3eb023c,0x291e812b,0x3f89826c,0x768b02d0}},	//   मला_, _crta_, _šau_, lüyo,
   {{0x3207ca38,0x3d000321,0x7ae2888b,0x44d580eb}},	//   seny_, _रहते_, brot, vā_,
   {{0x63a9dc32,0x768b0214,0x7ae2dc33,0x9c7d0289}},	//   _igen, nüyo, crot, ručl,
   {{0x44d58029,0x44c78065,0x24800ad4,0x5bb6024c}},	//   tā_, tő_, _skim_, ूर्व,
   {{0x7bcd2527,0x66155c34,0x69c3807a,0x3eb980eb}},	//   _beau, _mazk, mbne, ūst_,
   {{0x44d580eb,0x801480e8,0x7bcd0087,0x66155c35}},	//   rā_, _офіц, _ceau, _lazk,
   {{0x7ff4826a,0x44d580eb,0x63a9804f,0x7d1a81c0}},	//   _آسما, sā_, _mgen, avts,
   {{0x27ed892e,0xe29a0071,0x3ebf978f,0xdb0f0013}},	//   lgen_, саг_, mput_, ódái,
   {{0x929d8063,0x660a0086,0x63a9dc36,0x20d704b7}},	//   _usłu, _ölkə, _ogen, għi_,
   {{0x27edbfea,0x38b18117,0x63a9b03d,0x63a4bbe2}},	//   ngen_, _már_, _ngen, žini,
   {{0x628182a5,0x6d41a9d1,0x3ebf812b,0x27ed8e83}},	// [4a60] _oklo, lyla, nput_, igen_,
   {{0x2d9612bc,0x7bdb8079,0x64460009,0x386001b4}},	//   прес, _aduu, lkki, siir_,
   {{0x602634d5,0x6abbdc37,0x2c21016f,0x6f0d0079}},	//   _една, _atuf, याचं_, awac,
   {{0x27ed8613,0x64460009,0xeb9a8396,0x63a98118}},	//   jgen_, nkki, бие_, _cgen,
   {{0x3ebf8088,0x937a9459,0x3a3a2e99,0x7bdb9a1a}},	//   jput_, حصار_, _kopp_, _dduu,
   {{0x26c05c38,0x63a9adc2,0x27edca03,0x38b18019}},	//   mpio_, _egen, egen_, _bár_,
   {{0xf6230b69,0x2bed016f,0x6abb81bc,0x40348a0e}},	//   _ядро, _झालं_, _etuf, дейс,
   {{0x27edbcaf,0x7e7e5c39,0x291e811a,0x38b181a8}},	//   ggen_, lopp, _vrta_, _dár_,
   {{0x1be61344,0xab5d8035,0x7bcd17c9,0x68e38299}},	//   _काजल_, _odży, _reau, arnd,
   {{0x93258077,0x291eb351,0x7e7e3f4e,0x7bcd5c3a}},	//   _ترفن, _trta_, nopp, _seau,
   {{0xa3e0864a,0xc04f835f,0xab5d851c,0x41bb8039}},	//   _दया_, _зі_, _reżi, _הצבע,
   {{0x7e7e5c3b,0xf0448180,0x33205c3c,0x6608dc3d}},	//   hopp, _تعطی, _brix_, sedk,
   {{0xa3ea8006,0x9c7d0fda,0x7e618078,0x62870b80}},	//   _माई_, lučk, bilp, tljo,
   {{0x8f9b81c6,0x9fbf04e8,0x7ae00e06,0xa2c18a27}},	//   _הידי, rčík_, ámta, रीट्,
   {{0xd5fb8039,0x26c701dd,0x66150353,0x6d41dc3e}},	//   _הפור, ćnom_, _razk, cyla,
   {{0xb9050c78,0xb4d8816f,0xd4680b30,0x11f7003d}},	//   _नि_, ाळी_, _није_, _کودک_,
   {{0x44295c3f,0x2bc30dbc,0xb8f409a3,0x644d5c40}},	// [4a70] _ina_, _व्या, _सौ_, _ilai,
   {{0x6f0d5c41,0x42550077,0x644d0282,0xddab1b56}},	//   rwac, _آندر, _hlai, стал_,
   {{0x644d2ad0,0x443b0cc0,0x58d40009,0x9c7d135a}},	//   _klai, _koq_, _поэт, jučk,
   {{0x9f9d80a9,0x44290052,0x26d98019,0xa3bf09c1}},	//   nção_, _jna_, ások_, ेरि_,
   {{0x66155c42,0x9f9d83a7,0x44295c43,0xddc8911b}},	//   _tazk, ição_, _mna_, dodž,
   {{0x38b18658,0x7e7e047f,0x443b0144,0x644d0428}},	//   _pár_, copp, _loq_, _llai,
   {{0x9c7d00d2,0x64465c44,0x25fd016f,0x27eda888}},	//   ručj, ykki, र्णी_, tgen_,
   {{0x44290870,0x63a9dc45,0x1c1d0074,0x27eddc46}},	//   _nna_, _ugen, _बोलल_, ugen_,
   {{0x27ed890d,0xf1bf2263,0x7e61dc47,0x61fb00d2}},	//   rgen_, ्रान, tilp, đulj,
   {{0x44292ef8,0x644d2c1e,0x6281803b,0x3ebfdc48}},	//   _ana_, _alai, _uklo, rput_,
   {{0x7c3b8247,0x644d5c49,0xac0a1dc4,0x240a0081}},	//   _kour, _blai, онна_, онни_,
   {{0x332003d3,0x31c609a3,0x7c3b8809,0x26c7369f}},	//   _prix_, वर्ध, _jour, ćnoj_,
   {{0x7c3b8247,0x64460364,0x6d41dc4a,0x78a600fe}},	//   _mour, rkki, syla, _rikv,
   {{0x44295c4b,0x9f9d8073,0x386ddc4c,0x32180326}},	//   _ena_, ação_, lner_, udry_,
   {{0x386d8082,0x7c298ab3,0xa3e7016f,0x32180123}},	//   oner_, _oner, _पाच_, rdry_,
   {{0x644d5c4d,0x9f9d83a7,0x44290122,0xa2d7047d}},	//   _glai, cção_, _gna_, _बिच्,
   {{0xee3a2206,0x3a3a03e5,0x7e7e2e99,0x2d910c2e}},	// [4a80] она_, _topp_, topp, _azze_,
   {{0x4429003a,0x2fcf821e,0x7c29dc4e,0x386ddc4f}},	//   _zna_, _legg_, _aner, hner_,
   {{0x7e7e5c50,0x78a6005c,0x4429031d,0x25fd2b28}},	//   ropp, _tikv, _yna_, र्धी_,
   {{0x7c3b8809,0x387f82be,0x26c015a6,0x7e7e2225}},	//   _cour, jour_, ppio_, sopp,
   {{0x7c3b8548,0x386dcda0,0xd12f803d,0x2905810c}},	//   _dour, dner_, یمه_, _apla_,
   {{0x2d8b8d38,0x93438098,0x3f86808e,0x386dab18}},	//   ęcej_, ънче, _ryou_, ener_,
   {{0xaca401bc,0xd5ad0065,0x7c3b90b6,0x2fcf8362}},	//   _afọi, _اہم_, _four, _begg_,
   {{0xd6dadc51,0x8f469242,0x386da322,0x7c3bdc52}},	//   ото_, дход, gner_, _gour,
   {{0x6e3c4217,0x3ea7953a,0x63a91b4e,0x69de02d4}},	//   _korb, _bint_, ženk, _odpe,
   {{0x44290068,0x3eb9a755,0x644d5c53,0xe81e82f1}},	//   _sna_, ísta_, _slai, _मोरा_,
   {{0x9c7d003a,0x6e3c5c54,0x644d06f8,0x248480b9}},	//   luči, _morb, _plai, _kkmm_,
   {{0x386ddc55,0x21211ee8,0x628ac6fb,0x6e3c5c56}},	//   cner_, _rrhh_, llfo, _lorb,
   {{0x3ea78082,0xccf8800d,0x9f9d83a7,0x9c7d0110}},	//   _fint_, stě_, rção_, nuči,
   {{0x6e3c5c57,0x6aa88197,0x29188174,0xe46a062c}},	//   _norb, _jidf, _áras_, ttöä_,
   {{0x6aa8dc58,0x9f9d83a7,0xd83f00e1,0x30a715ff}},	//   _midf, pção_, áčov_, драв,
   {{0x44295c59,0x44f8dc5a,0xa3ea801b,0xdb250162}},	//   _una_, mé_, _माग_, ăpân,
   {{0x6e3c0025,0x44f8dc5b,0x63ad385d,0x81e680ab}},	// [4a90] _borb, lé_, _igan, য্য_,
   {{0x3ea71836,0x7c3b8766,0x7c29a4a0,0xb6a580ff}},	//   önt_, _sour, _sner, _nhậ,
   {{0x44f8dc5c,0xdcf88029,0x69d55c5d,0x7c3b90b6}},	//   né_, _izvē, maze, _pour,
   {{0x4429dc5e,0x25eb0076,0x337594bc,0x64838074}},	//   ña_, _चाकी_, нгер, võis,
   {{0x6e3c0e40,0x44f8c210,0x38b50082,0x2019002e}},	//   _forb, hé_, _hår_, _iasi_,
   {{0x201925fc,0x7bdf0fa4,0x386ddc5f,0x7aebdc60}},	//   _hasi_, _ldqu, wner_, rugt,
   {{0x20195c61,0x387fa9bf,0x386d888a,0x2b498289}},	//   _kasi_, tour_, tner_, šac_,
   {{0x67228025,0x63ad5c62,0x3ea7dc63,0x38b5016d}},	//   _broj, _ngan, _sint_, _mår_,
   {{0x69d50234,0xdb16008b,0x63bbdc64,0x38b512f1}},	//   kaze, _neyð, _ifun, _lår_,
   {{0x20195c65,0x387f80b9,0x63ad5c66,0x69d55c67}},	//   _lasi_, sour_, _agan, jaze,
   {{0x38b5005f,0x63a48110,0x3ea7dc68,0x6618807a}},	//   _når_, žint, _vint_, _davk,
   {{0xa01b00f2,0x20194e28,0x3ea780f3,0x2ca9051e}},	//   _skön, _nasi_, _wint_, _ciad_,
   {{0x63ad008e,0x63bbb5eb,0x69d55c69,0x6722dc6a}},	//   _dgan, _mfun, faze, _groj,
   {{0x44f8dc6b,0x63ad5c6c,0x69d51c5d,0x3d000006}},	//   bé_, _egan, gaze, _रहले_,
   {{0x2019022e,0x7d020063,0x44f880e7,0x9c83007a}},	//   _basi_, łosz, cé_, ščaj,
   {{0x201927e1,0x54360019,0x6e3c5c6d,0x628501f6}},	//   _casi_, _سربر, _sorb, _ekho,
   {{0x2cbf0668,0x201906cb,0x6b89dc6e,0xc05283c8}},	// [4aa0] _čuda_, _dasi_, _nyeg, אזן_,
   {{0x38b508f8,0xe6175c6f,0x63bba2eb,0xd91009a7}},	//   _får_, нду_, _afun, _پیر_,
   {{0x6e3c5c70,0x38b508f8,0x0446d3c0,0x10a61d5c}},	//   _vorb, _går_, нежн, _пион,
   {{0x61138201,0x27ffdc71,0x20195c72,0x2d953941}},	//   _gələ, jfun_, _gasi_, трус,
   {{0xeb9a8087,0xbb3b00be,0x98a78084,0xab838469}},	//   чид_, ּעצי, lynė_, лушк,
   {{0x44f8dc73,0xb866803d,0x63bbc1b5,0xb42581f9}},	//   yé_, کاتو, _efun, _یعقو,
   {{0x321a0e04,0x6b89dc74,0xa5070764,0x27ff8326}},	//   _mapy_, _eyeg, _пера_, ffun_,
   {{0x44f89de2,0x69c70fda,0x63a94a41,0xdfd080f7}},	//   vé_, zbje, ženi, جية_,
   {{0xd5bd9055,0x64ac07d9,0xe666be1c,0x25fd5c75}},	//   ोरंज, _eğit, етно, र्वी_,
   {{0x44f8dc76,0xa2d40076,0x2ca90013,0x28e10a43}},	//   té_, _बौध्, _siad_, _फिलि,
   {{0x9e038048,0x827783de,0xdb1601fa,0x4d98804a}},	//   учыл, _טעמע_, _seyð, ькою_,
   {{0x44f89de7,0xe7ea80d4,0x2d8a00b9,0xe73a8198}},	//   ré_, _टाटा_, _mybe_, _нее_,
   {{0x44f8d2db,0x63ad008e,0xfdf006a7,0x38b5006f}},	//   sé_, _vgan, _चांस_, _sår_,
   {{0x44f8dc77,0x20195c78,0x63ad82ba,0x160203eb}},	//   pé_, _sasi_, ñanz, र्मर_,
   {{0xdfd51006,0x2019020f,0x69d55c79,0x67d5433f}},	//   ковы, _pasi_, raze, кову,
   {{0x63ad0545,0x38b5104d,0x2747077f,0x61138085}},	//   _ugan, _vår_, _nínú_, _qələ,
   {{0x8aa727ee,0x02a714b7,0x160206b7,0x20195c7a}},	// [4ab0] _прод, _пром, र्भर_, _vasi_,
   {{0x4439016d,0x3b0901e0,0xb7140198,0xbebb03ed}},	//   ljs_, _ipaq_, ыдущ, _frën,
   {{0x61138201,0x20190704,0x70590fbf,0x63bbdc7b}},	//   _tələ, _tasi_, _жанр_, _pfun,
   {{0x7afd0b3c,0x20195c7c,0x7af201d0,0x9fb581d0}},	//   otst, _uasi_, šetř, třík_,
   {{0x2fc93e4b,0x7de700e8,0xee3f0129,0x7c2d0c53}},	//   mbag_, _півд, _buýt_, _mnar,
   {{0x3eaa0352,0xdd868bca,0x2fc95c7d,0xd2b8025f}},	//   _gibt_, _نو_, lbag_, עלות_,
   {{0xdd940110,0x9c7d0503,0x7c2d5c7e,0x6594321a}},	//   _бары, luču, _onar, _бару,
   {{0x63bbace6,0x7c2d019d,0x7afd22c8,0x2fc901e0}},	//   _ufun, _nnar, ktst, nbag_,
   {{0x39498341,0x442ddc7f,0xe803016f,0xc2210105}},	//   ņas_, _ine_, ऱ्या_, मयाब_,
   {{0x7aef5c80,0x443f90f4,0xa01b18b6,0xb0e1064a}},	//   duct, _hou_, _sköl, _फिंग,
   {{0x443f8247,0x2bc3035a,0x2ee95c81,0x7afd1e12}},	//   _kou_, _व्हा, hraf_, etst,
   {{0x443fdc82,0x442ddc83,0x7afd5ab6,0xbebb0168}},	//   _jou_, _jne_, ftst, _rrën,
   {{0x443fd177,0x7afd45a7,0x442d826f,0xae0212e0}},	//   _mou_, gtst, _mne_, र्डन_,
   {{0x443f9f5a,0x62839152,0xdddc192c,0x26d9936f}},	//   _lou_, nono, _okrš, ásou_,
   {{0x442ddc84,0x7afd35cd,0x389e8133,0x7c3f02a6}},	//   _one_, atst, _ọria_, _foqr,
   {{0x443fdc85,0x442dba87,0x2fc9033e,0xb3a987c0}},	//   _nou_, _nne_, gbag_, şıyı,
   {{0x2ee95c86,0x98a30758,0xa6861285,0x59d18006}},	// [4ac0] graf_, рите, влад, हरार,
   {{0x442ddc87,0x628386b9,0xfaa61bbf,0xaf06026b}},	//   _ane_, jono, _шапо, _ajùú,
   {{0x443fdc88,0x64a68221,0x2fc90326,0x77798609}},	//   _bou_, важа, bbag_, _lxwx,
   {{0x0b468221,0xb60900eb,0x3d19809a,0x443fbdf9}},	//   кнен, _atšķ, _बनने_, _cou_,
   {{0x442d9d1a,0xd36f80f7,0x443fdc89,0x60c185ee}},	//   _dne_, يهم_, _dou_, _atlm,
   {{0xf5060758,0xfe678872,0x26c214ce,0xc4bc8264}},	//   _изго, _ضد_, _itko_, _আয়োজ,
   {{0x443fdc8a,0xd46a8e1d,0x9e630226,0xd13081a8}},	//   _fou_, _живе_, _тврд, صمة_,
   {{0x661c2a19,0x44fc5c8b,0xdd8f0591,0x443fdc8c}},	//   _hark, mí_, _ذوق_, _gou_,
   {{0x661c5c8d,0x44fc57f4,0x6283c2c0,0xae0215bc}},	//   _kark, lí_, bono, र्थन_,
   {{0x7c2d12f1,0x6283dc8e,0x443f8613,0xd9ee0076}},	//   _snar, cono, _zou_, _जागत_,
   {{0x661c0bde,0x6440dc8f,0x443f873a,0x44fc21e7}},	//   _mark, _komi, _you_, ní_,
   {{0xae02085d,0x69d8dc90,0x443f007b,0x7afd035f}},	//   र्तन_, lave, ðu_, ttst,
   {{0x38b887ca,0xee3a8037,0x44fc01d6,0x7b6403a7}},	//   _hér_, _онд_, hí_, атре,
   {{0x6440dc91,0x7afd0b2b,0x7aef5c92,0x61bf224b}},	//   _lomi, rtst, ruct, ्रेष,
   {{0x44fc000d,0x2cbf005c,0x7aef1486,0x7afd57d8}},	//   jí_, _čudo_, suct, stst,
   {{0x38b887ca,0x44fc5c93,0x69d8a315,0x2ee906a8}},	//   _mér_, dí_, have, traf_,
   {{0x2fc92651,0x661c0788,0x63adab0d,0x443fdc94}},	// [4ad0] rbag_, _bark, žank, _rou_,
   {{0x443fdc95,0x9c7d496c,0x6283bfe4,0x6b8d02a3}},	//   _sou_, ruču, xono, _iyag,
   {{0x443fbf0e,0xf3ff00a9,0x442d8706,0x44fc453d}},	//   _pou_, nião_, _pne_, gí_,
   {{0x8c3d82bb,0x6283dc96,0x6b8d0c2e,0x661c02f9}},	//   _kişi, wono, _kyag, _eark,
   {{0x661c5c97,0x443fdc98,0xfaff00f1,0x644080ef}},	//   _fark, _vou_, ntë_, _domi,
   {{0xfe712003,0x443fdc99,0x38690a46,0xf41f0364}},	//   _اگر_, _wou_, liar_, hdä_,
   {{0xfaff0b18,0x443f8205,0x44fc5c9a,0x64ac8059}},	//   htë_, _tou_, cí_, _işin,
   {{0x442ddc9b,0x6440dc9c,0xef199593,0x6d48dc9d}},	//   _une_, _gomi, еми_, dyda,
   {{0x6283dc9e,0xfaff00f1,0x69d8827f,0x6b8d40bb}},	//   pono, jtë_, bave, _nyag,
   {{0x9967da7c,0x7bd9dc9f,0x69d89b05,0x69cab07c}},	//   _ител, lawu, cave, _स्पी,
   {{0xf3ff0073,0x6b8d0e05,0xe81e8fd5,0x6440dca0}},	//   gião_, _ayag, _मोका_, _yomi,
   {{0xfaff00f1,0x6b8d020c,0x80d08264,0x8c3d8850}},	//   ftë_, _byag, সংখ্, _bişi,
   {{0xdee5879e,0x44fc03fb,0x66e58c9b,0x6d5a8102}},	//   _соли, zí_, _сола, azta,
   {{0x6a860aac,0x41a50beb,0x64b701a1,0x09e58264}},	//   улга, _गृहस, _aćim, প্রা,
   {{0x628e2651,0x50b50c9d,0x09d880ab,0xe29704ae}},	//   rlbo, исту, _সামা, уар_,
   {{0x661c5ca1,0x201d8077,0x44fc03fb,0x69d8cd81}},	//   _sark, _jawi_, ví_, zave,
   {{0x201db9e1,0x29050214,0x5baa00e8,0x9c7d04e8}},	// [4ae0] _mawi_, çlar_, _яким_, ručt,
   {{0x44fc0a56,0x2bcc8c78,0x6440dca2,0x533700be}},	//   tí_, ार्थ, _somi, _ענין_,
   {{0x661c461b,0x2d962b57,0x2cad81b0,0x69d8bf4c}},	//   _vark, урас, _bied_, vave,
   {{0x44fc209f,0x629a80f1,0x661c5ca3,0x3ce601ac}},	//   rí_, _shto, _wark, čov_,
   {{0x661c5ca4,0x38b887ca,0x44fc5ca5,0x20124846}},	//   _tark, _sér_, sí_, meyi_,
   {{0x201207c0,0x661c0695,0x44fc5ca6,0x98aa0084}},	//   leyi_, _uark, pí_, tybė_,
   {{0x6440803a,0xdd9209d7,0xf41f0009,0x64ba8609}},	//   _tomi, _طور_, ydä_, _aċin,
   {{0xdb0284c3,0x64408081,0x06c880ab,0x6456189e}},	//   scoñ, _uomi, _শিবি, ūzij,
   {{0xd5b08013,0xc9f680f7,0x61f681a8,0x6f0701a9}},	//   يفة_, _مساع, _مساء, cībā,
   {{0x6aca80ab,0x3869011b,0x715a9b8b,0x2489343d}},	//   _রিপো, ziar_, _прес_, _skam_,
   {{0x5fb405b3,0x20125ca7,0xdd948110,0x5c750c9b}},	//   ंखाल, keyi_, раны, илот,
   {{0x6d48dca8,0xdd9781e5,0x201d9acd,0xc0ff80ff}},	//   ryda, ышы_, _gawi_, _lướt_,
   {{0x38690531,0x6d5adca9,0x6eb01251,0x4e1406a7}},	//   viar_, szta, _अंगु, ड़ाई_,
   {{0xfaff020f,0x290c80dd,0xc987031f,0x672406ec}},	//   rtë_, _kpda_, губи, dvij,
   {{0xfaff00f1,0x672400eb,0xaa7b016b,0x649601a8}},	//   stë_, evij, krýv, máin,
   {{0x60180160,0x649601a8,0x6b8d02d5,0x3d19dcaa}},	//   лося_, láin, _tyag, _बनते_,
   {{0x2cad822b,0xe8069862,0x38690558,0xe8158cfd}},	// [4af0] _ried_, व्या_, riar_, ढ़ता_,
   {{0x38695cab,0x63a9016b,0xd01d80ab,0x201f93bd}},	//   siar_, žens, থায়_, zdui_,
   {{0x867b810f,0x2caddcac,0x7bd9bd92,0x9d15310c}},	//   ערבו, _pied_, tawu, рдеч,
   {{0x644f5513,0x3d05159a,0xe7871b56,0x69d75cad}},	//   nkci, _रहीं_, _буго, _hexe,
   {{0x1614800f,0x201d90e1,0x7bd9dcae,0xb7da0039}},	//   तजार_, _rawi_, rawu, _בקרי,
   {{0xeab0803d,0x7bd9b0c1,0x201d8642,0x62870612}},	//   سعه_, sawu, _sawi_, nojo,
   {{0x2486dcaf,0x20559505,0xa3c5009a,0x69d70187}},	//   boom_, итир, एडा_, _mexe,
   {{0xaae78154,0x9c7d0267,0xdb1d02f1,0xa6e59935}},	//   _مسئو, brči, lasõ, ажил,
   {{0x62875cb0,0xfd100065,0x61e5016b,0x86998073}},	//   kojo, _وجہ_, _odhl, ктот_,
   {{0xe7088013,0x60c50c9e,0x7b748f99,0xb8db80ab}},	//   اتين_, _othm, _اطفا, _অব_,
   {{0xa3e9864a,0xa115b06f,0x4815ac18,0x67290267}},	//   _मया_, _خوات, _вмес, _šejl,
   {{0xd46a1361,0x61e50219,0x20d38493,0x38698338}},	//   тиме_, _adhl, mţi_, _öar_,
   {{0xd6c384c0,0xe81e92ee,0x308480f7,0x20d3802e}},	//   _امتی, _मोटा_, _النف, lţi_,
   {{0x35a58084,0xe29a028e,0x2ba71199,0xe5a5a19f}},	//   _калг, таг_, _गणरा, _кили,
   {{0x20d3802e,0x290c5cb1,0x69d75cb2,0x68460081}},	//   nţi_, ïda_, _dexe, анва,
   {{0x67240341,0x7ae90024,0x78af026c,0xe8e0001c}},	//   tvij, šeta, _cicv, _liệt_,
   {{0x7643dcb3,0x6287221f,0x44321e51,0x33290216}},	// [4b00] _kony, bojo, _iny_, _grax_,
   {{0x44205cb4,0x672401a9,0x443202f7,0x6444010c}},	//   _hai_, rvij, _hny_, _hoii,
   {{0x44205cb5,0x764390e1,0x67240654,0x248689ff}},	//   _kai_, _mony, svij, toom_,
   {{0x03269cf2,0x69c1dcb6,0x09d880c8,0x44205cb7}},	//   иден, _afle, _সাধা, _jai_,
   {{0x44205cb8,0xe8e00028,0x2b168009,0x59da4b7c}},	//   _mai_, _biệt_, рьер, _बजार,
   {{0x44205cb9,0x69dc5cba,0x5eeb064a,0x2eed8114}},	//   _lai_, nare, _चित्_, dref_,
   {{0x44325cbb,0xdb1f2761,0xe8e0001c,0xddc88084}},	//   _ony_, _seqü, _diệt_, sidū,
   {{0x64599f8b,0x38bc5cbc,0xf106bd25,0x3fb48264}},	//   chwi, _mír_, _शहीद_, ঘর্ষ,
   {{0xa2b22f52,0x04f280ab,0x7643dcbd,0x20d3802e}},	//   _इंग्, _জনের_, _bony, aţi_,
   {{0x44320051,0x7c22d306,0x38bc0511,0x7643a01d}},	//   _any_, ldor, _oír_, _cony,
   {{0x442015d6,0x69d704c3,0x7c20dcbe,0x69dc5cbf}},	//   _bai_, _rexe, _kamr, dare,
   {{0x442008ac,0x98be000d,0x7aed80cd,0x26060744}},	//   _cai_, ště_, šate, स्ती_,
   {{0x44205cc0,0x69dc03a6,0x62875cc1,0x629e026c}},	//   _dai_, fare, tojo, _bhpo,
   {{0x5ef3816f,0xdb1d0019,0x7c208326,0x3b000372}},	//   ंढर्_, ncsé, _lamr, _dqiq_,
   {{0x4420377e,0x3d05000f,0x69d704c3,0x62875cc2}},	//   _fai_, _रहें_, _vexe, rojo,
   {{0x44205cc3,0x7c208353,0x0854004a,0x69d70df6}},	//   _gai_, _namr, овсю, _wexe,
   {{0x7bdd1922,0x7c228114,0x6287221f,0x57a70081}},	// [4b10] masu, ddor, pojo, ршва,
   {{0x69dc5cc4,0x442003c3,0x7d0100f2,0x2cb80609}},	//   care, _zai_, _älsk, _burd_,
   {{0x44205cc5,0x25fd0beb,0x26c902a5,0x60c506df}},	//   _yai_, र्गी_, spao_, _uthm,
   {{0x44205cc6,0x68f5007e,0x8c3d8162,0x4c958198}},	//   _xai_, muzd, _nişt, щиес,
   {{0x69c181ec,0x7c20d2f6,0x26c681c5,0xda041834}},	//   _pfle, _damr, _ntoo_, श्वत_,
   {{0xf20791d2,0x98e580f7,0x27e68300,0x4422026c}},	//   рядо, مكتو, _adon_, zdk_,
   {{0xe8e00104,0x7bdd400a,0x2a580039,0xa06996fc}},	//   _việt_, kasu, שבון_, лака_,
   {{0x69dc5cc7,0x76438caa,0x2eedd48f,0x20d3802e}},	//   zare, _sony, tref_, rţi_,
   {{0x44205cc8,0x3eb90051,0x76439a4f,0x69dc5cc9}},	//   _rai_, _just_, _pony, yare,
   {{0x44205cca,0x44325ccb,0x3eb95ccc,0x645d5ccd}},	//   _sai_, _sny_, _must_, ërin,
   {{0xb9958013,0x44201b22,0x200b026f,0x671c8466}},	//   _الاب, _pai_, _obci_, _बैठक_,
   {{0xf09f0142,0x69dc5cce,0x7bdd3a86,0x645d0110}},	//   _nhà_, ware, gasu, ūrin,
   {{0x44205ccf,0x386ddcd0,0x2245dcd1,0x249f810c}},	//   _vai_, mier_, _kolk_, _mhum_,
   {{0x386d8ee9,0x442004b9,0x6146017c,0x610a811c}},	//   lier_, _wai_, бега, _həla,
   {{0x44205cd2,0x69dc5cd3,0x44325cd4,0x7bdd51ee}},	//   _tai_, rare, _tny_, basu,
   {{0xe3b2045b,0x44e38182,0x386dd41e,0x69dc1473}},	//   _عرب_, mı_, nier_, sare,
   {{0x44e3884a,0x8fa30d5f,0x69dc32d4,0x127a0019}},	// [4b20] lı_, зате, pare, _محدث_,
   {{0xcf928158,0x7c20dcd5,0x38bc00f7,0x386ddcd6}},	//   לטן_, _samr, _tír_, hier_,
   {{0x44e38459,0xf1bf8028,0x25fe12ee,0x6f1d5cd7}},	//   nı_, _đáp_, _लाठी_, _essc,
   {{0xaae68013,0x249f8c49,0x7c209fbc,0xa3d827af}},	//   مستو, _chum_, _qamr, िरि_,
   {{0x7c22820f,0x3eb952a0,0x386d93c2,0x31cf80ab}},	//   rdor, _gust_, dier_, _রাজশ,
   {{0x09d880c8,0x4df54817,0x44e38201,0x7c2294fb}},	//   _সাহা, _мяст, kı_, sdor,
   {{0x386ddcd8,0xa3d82c5d,0x8d630193,0x6b9b8133}},	//   fier_, िरा_, _евре, _ezug,
   {{0x44e382bb,0x8cd29305,0xc5630d15,0x7ae402d4}},	//   dı_, _भौगो, _экск, _ovit,
   {{0x2bce835a,0x64a381e5,0x6f0437cf,0x649601a8}},	//   _ह्या, _хата, ntic, ráil,
   {{0x59cfbe85,0x7bdd1fa4,0xb8fe80ab,0x14ca862c}},	//   _स्पर, wasu, _তম_, лыми_,
   {{0x25fd06b7,0x69da8029,0x7bdd00ad,0x386ddcd9}},	//   र्टी_, _iete, tasu, bier_,
   {{0x7bc2dcda,0x6f0421d1,0x69da8094,0x386ddcdb}},	//   ncou, ktic, _hete, cier_,
   {{0x69da94e5,0x7ae48013,0x7ae409d1,0xab870f75}},	//   _kete, áith, _cvit, сунк,
   {{0x29031daf,0x7bdd395f,0x69da80f1,0x7ae2808e}},	//   ttja_, sasu, _jete, isot,
   {{0x7bdd49a3,0x44e38457,0x6f040037,0xa1581fd9}},	//   pasu, cı_, etic, бару_,
   {{0x69dadcdc,0x6f0417c9,0x6f1d00b9,0x2ca05cdd}},	//   _lete, ftic, _pssc, _ghid_,
   {{0x78ba826c,0x25578085,0x95d906a1,0x2ca682d5}},	// [4b30] _lutv, vələ_, идат_, dmod_,
   {{0x291e843d,0x69dadcde,0x3a750e97,0x249f80f1}},	//   _osta_, _nete, _флор, _shum_,
   {{0xf09f2266,0x628a81e0,0x7d0d8bda,0x6f0417d6}},	//   _thà_, dofo, _ćask, atic,
   {{0xd3719a43,0x3cfb80be,0x25fd0f0a,0x69da86ab}},	//   وها_, רלאנ, र्जी_, _aete,
   {{0x69dab4bd,0x386ddcdf,0x291e8012,0x6f04079a}},	//   _bete, vier_, _asta_, ctic,
   {{0x44e387d9,0x291e82d5,0x2557811c,0x610a811c}},	//   yı_, _bsta_, sələ_, _səla,
   {{0x386da076,0x224584eb,0x69dac26a,0x67290858}},	//   tier_, _volk_, _dete, _šejh,
   {{0xdb2100e1,0xd6d19e09,0xaec584ad,0x7bc2dce0}},	//   _štýl, وقع_, обил, ccou,
   {{0x291eac70,0x386d9da3,0x69ca8ebf,0x9f400125}},	//   _esta_, rier_, _स्वी, ngið_,
   {{0x69da905d,0x44e38059,0xa01b008b,0x386d8a85}},	//   _gete, tı_, _fjög, sier_,
   {{0xe806835a,0xc5f204de,0xa5099285,0x1d0990ca}},	//   व्हा_, ודי_, шена_, шени_,
   {{0x44e3b8d1,0x69c52401,0x69dadce1,0x6abb8c53}},	//   rı_, _afhe, _zete, _kuuf,
   {{0x44e38b06,0x69da8214,0x8c1a84de,0x888c83de}},	//   sı_, _yete, בורי, _גראַ,
   {{0x1e8490ac,0x59cf861e,0x26cd8037,0xa3d806a7}},	//   _елім, _स्मर, mpeo_, िरह_,
   {{0x8c460b5b,0x81ab80ab,0xd8262829,0x26cd8144}},	//   _меке, কুর_, одви, lpeo_,
   {{0x7ae41c9a,0x6f045ce2,0x645d5ce3,0xa9278084}},	//   _tvit, ttic, chsi, mažė,
   {{0x6e23cba4,0xaa7b008b,0x76900009,0x6729dce4}},	// [4b40] _kanb, msýn, käyt, nvej,
   {{0xee37045d,0xa01b1252,0x7bc29916,0x6e238242}},	//   ону_, _sköt, wcou, _janb,
   {{0x69da9f29,0x41d003bb,0x6e23a598,0x3218222f}},	//   _rete, _त्यस, _manb, mery_,
   {{0x69da8734,0x7bc282be,0x32184e54,0x51f6015b}},	//   _sete, ucou, lery_, _اسکر,
   {{0x7c241536,0xbb4387ac,0x7bc2dcdb,0x2ca6c030}},	//   _mair, мецк, rcou, rmod_,
   {{0x27e05ce5,0x98c6af4f,0x7c245ce6,0xa905003d}},	//   lain_, осил, _lair, _ببین,
   {{0x7ae2c5ea,0x69dacc7d,0x61e88037,0x41c68a0d}},	//   ssot, _vete, _vddl, रुषस,
   {{0x6e239afa,0x69daa6d0,0xe8e08104,0x628a92f5}},	//   _aanb, _wete, hiệp_, sofo,
   {{0x69dac068,0x6e23dce7,0x81ab80ab,0x645d0168}},	//   _tete, _banb, কুল_, ërim,
   {{0x4424dce8,0x27e05ce9,0x78ba8006,0x64428966}},	//   _ham_, hain_, _tutv, ljoi,
   {{0x4424dcea,0x6e23dceb,0x27e05cec,0x7c244990}},	//   _kam_, _danb, kain_, _bair,
   {{0x44268c6b,0x7c245430,0x2bb18105,0xfe788084}},	//   ndo_, _cair, ुँचा, snį_,
   {{0x4424c90a,0x4426a790,0x27e049f1,0x7c2437d0}},	//   _mam_, ido_, dain_, _dair,
   {{0x4424db4e,0x64428009,0x2ef201b0,0x4426a6fb}},	//   _lam_, hjoi, dryf_, hdo_,
   {{0x7c2410b6,0x4426dced,0x551e8035,0x6b51026b}},	//   _fair, kdo_, _बनिए_, _bógú,
   {{0x4424c7b7,0x7c240cc8,0x4426b99a,0x27e001ba}},	//   _nam_, _gair, jdo_, gain_,
   {{0xb90205e8,0x4426dcee,0xd5bb5cef,0x32185cf0}},	// [4b50] _नौ_, ddo_, асе_, bery_,
   {{0x69ca80d4,0x551e9660,0x7c245cf1,0x2fdfd498}},	//   _स्ली, _बनाए_, _zair, zaug_,
   {{0x4424dcf2,0x7c8781a4,0x9c830824,0x6abb8df6}},	//   _bam_, оуде, ščuj, _suuf,
   {{0x27e01627,0x7d051106,0x212100dd,0xfc3f2119}},	//   cain_, rths, _ishh_, zmín_,
   {{0x2cbf00ce,0x76900198,0x083a03de,0x883a025f}},	//   _čudu_, täyt, _הערל, _התרו,
   {{0xdcfb003d,0x76ba01c6,0x01d90264,0x660e02f9}},	//   _پرسش_, _למשפ, _তাঁদ, _gbbk,
   {{0x6e23dcf3,0x4426dcf4,0x76b28035,0x2fdf81c0}},	//   _ranb, bdo_, _płyn, taug_,
   {{0x7cc18341,0x4424dcf5,0x397c098a,0x6e2386c0}},	//   _bērn, _gam_, יטונ, _sanb,
   {{0xf7718307,0x6e238bb1,0xdbd9007b,0x7c245cf6}},	//   عاب_, _panb, væði, _rair,
   {{0x4424dcf7,0x6729dcf8,0x7c240009,0x27e00102}},	//   _zam_, rvej, _sair, zain_,
   {{0x442490af,0xfc3f026f,0x27e05cf9,0x64499384}},	//   _yam_, rmín_, yain_, _koei,
   {{0x44248069,0x160b00d4,0x59cf8a0d,0x6e2392f9}},	//   _xam_, स्तर_, _स्तर, _wanb,
   {{0x7c243ffd,0x64498b3c,0xeb9f013c,0xdb080059}},	//   _vair, _moei, lføj_, _ölüm,
   {{0x19b9035f,0x7c242fe3,0x27e05cfa,0x44268110}},	//   жуть_, _wair, wain_, zdo_,
   {{0x20560eef,0x7c240cac,0x10a60615,0x4426d8cf}},	//   птар, _tair, зивн, ydo_,
   {{0x7c241a2f,0xa01b18b6,0x442681b4,0xaec6171c}},	//   _uair, _skör, xdo_, збал,
   {{0x27e05cfb,0x44268824,0x32185cfc,0x1f665946}},	// [4b60] rain_, vdo_, pery_, чкам,
   {{0x17790cde,0x4424dcfd,0x27e05cfe,0xea64003d}},	//   ість_, _sam_, sain_, _آپدی,
   {{0x4424dcff,0x27e05d00,0x628e5d01,0x64499c2b}},	//   _pam_, pain_, mobo, _boei,
   {{0x645b861f,0x4426dd02,0x69de4c77,0x78a980f1}},	//   _clui, udo_, _hepe, jmev,
   {{0x6442825d,0x69de1e92,0x27f7026f,0x38600834}},	//   rjoi, _kepe, šené_, mhir_,
   {{0x645b8d62,0xf7880085,0x26c281ac,0x69de0168}},	//   _elui, _neçə_, íkom_, _jepe,
   {{0x4424dd03,0xa3ac0a74,0x69de5d04,0xbea31246}},	//   _tam_, केत_, _mepe, _чарк,
   {{0xdb160065,0x6449a51d,0x50668196,0x09b9016f}},	//   _egyé, _goei, ятла, _आल्य,
   {{0xa41183bf,0x628e300e,0x09e200ab,0x29078b7e}},	//   lığı_, kobo, _বানা, atna_,
   {{0x7ae9011f,0x69de5d05,0xdbe503b7,0x649d0f35}},	//   šetk, _nepe, कण्ड_, géin,
   {{0x38600867,0x628e2015,0xd7efa7f4,0xfbe10264}},	//   khir_, dobo, _пу_, _ভাবত,
   {{0x6ab50935,0x35678071,0x00bb8039,0x09c50072}},	//   ंद्र, ярын_, _המאמ, वड्य,
   {{0x69de03b2,0x38600f58,0x2121008e,0xd90e803d}},	//   _bepe, dhir_, _sshh_, _شیک_,
   {{0x69de5d06,0x628e5d07,0xbd0181df,0x2480010c}},	//   _cepe, gobo, ñéce, _ejim_,
   {{0x69de4073,0x19580048,0x06b1928a,0x00000000}},	//   _depe, пары_, řící_, --,
   {{0xa41182bb,0xa01b2bf5,0x661add08,0xf0b405a8}},	//   dığı_, _sjöb, letk, ейсь,
   {{0xead780c8,0xf7730b8c,0x06b70180,0x64499151}},	// [4b70] _সম্ম, رار_, سناک_, _roei,
   {{0x645b85f8,0x69de1c2b,0x13d58d1c,0x661ac6ae}},	//   _slui, _gepe, दर्भ, netk,
   {{0x38600046,0x645bdd09,0x6449a388,0xa25b00e1}},	//   bhir_, _plui, _poei, spôs,
   {{0x69c8dd0a,0x38605d0b,0x69de0fe2,0x765c038a}},	//   _afde, chir_, _zepe, _elry,
   {{0x7bdf0580,0x0dcb0c9b,0xcfab00d7,0x6ab70197}},	//   _mequ, _губи_, _دادم_, _kixf,
   {{0x7bdf00e7,0x200f80b9,0x672d5d0c,0x29078bcb}},	//   _lequ, _sbgi_, mvaj, ttna_,
   {{0x672d3df7,0x661a844a,0x67228091,0xf49780d7}},	//   lvaj, detk, _asoj, _فشرد,
   {{0x7bdf5d0d,0x610a8085,0x628e34e6,0x2907dd0e}},	//   _nequ, _gəlm, zobo, rtna_,
   {{0x628e0578,0x2907dd0f,0x26018740,0x649d0b6a}},	//   yobo, stna_, _शादी_, téin,
   {{0x661ad287,0x7ae9a21f,0x69c70140,0x628e36b5}},	//   getk, _ivet, jcje, xobo,
   {{0x61e3d0f1,0x628e53f5,0xa787803d,0x7bdf5d10}},	//   manl, vobo, _کشاو, _bequ,
   {{0x69de045c,0x61e3dd11,0x7ae98a21,0x7bdf0118}},	//   _sepe, lanl, _kvet, _cequ,
   {{0x69de5d12,0xe8e0001c,0x25fe097d,0x3d1983db}},	//   _pepe, _thịt_, _लाली_, _बनके_,
   {{0x672d3899,0x661a8052,0x764a831d,0x61e3dd13}},	//   dvaj, cetk, _gofy, nanl,
   {{0x38605d14,0x63bbdd15,0x27ffdd16,0xe2975d17}},	//   thir_, _ogun, ogun_, фар_,
   {{0x27ffbbde,0x628e0c56,0x63bbdd18,0xb8f60665}},	//   ngun_, sobo, _ngun, _हऽ_,
   {{0x6f0989b2,0x61e382fa,0x69de48d2,0x628e5d19}},	// [4b80] ntec, kanl, _tepe, pobo,
   {{0x63bb8397,0x38605d1a,0x6f09802a,0xe2920f24}},	//   _agun, shir_, itec, _جذب_,
   {{0x7ae9aaed,0x67290858,0xdbc68074,0x61e3dd1b}},	//   _avet, _šejt, _mööd, danl,
   {{0xae021a4d,0xed57004a,0x68fc5d1c,0x6aa6864a}},	//   र्जन_, ьох_, murd, गग्र,
   {{0x7ae98b89,0x671c8fea,0xaca4819d,0xb5e38264}},	//   _cvet, _बैंक_, _haịp, _মানচ,
   {{0x63bb80ad,0x7df986b7,0x61e3dd1d,0xbe16003d}},	//   _egun, ्भोग_, ganl, _توسع,
   {{0x661add1e,0x247601a9,0x200d8037,0xdd920180}},	//   vetk, nāms_, ffei_, _شور_,
   {{0xdfd08013,0x764a84e6,0x200282f1,0x2000019a}},	//   دية_, _sofy, üki_, ngii_,
   {{0x7bdf426a,0xf0930039,0x41cf8aed,0xb6070197}},	//   _requ, כנה_, _स्वस, _feġġ,
   {{0x3f988029,0x64ac87c0,0x644601c0,0x7bdf5d1f}},	//   āru_, _eşit, ejki, _sequ,
   {{0x7bdf1313,0xe01e0df4,0x38c8804e,0xab5b08c5}},	//   _pequ, _पसंद_, _راضی_, rcüm,
   {{0x68fc031d,0x83fd8019,0xfbad00ab,0x3a3a00fc}},	//   durd, _előf, _ক্ষত, _anpp_,
   {{0xe666a00d,0xd62ab9df,0x92bc80ab,0x661adbc9}},	//   _отко, _моде_, _আবু_, petk,
   {{0x6cfe0441,0xe56f8180,0x8f9b81c6,0x38a1b554}},	//   _उमंग_, اطی_, _וידי, móra_,
   {{0x19940098,0xfbde8697,0x69c70168,0x38a1dd20}},	//   варя, मराम, rcje, lóra_,
   {{0x6e270b80,0x200001b4,0x27e49f48,0x69c705f3}},	//   _sajb, ggii_, namn_, scje,
   {{0x61e383bf,0x59d03ef1,0x610a8085,0x3eb8008b}},	// [4b90] yanl, _त्वर, _bəlk, _birt_,
   {{0x5ec800c8,0x7afd5d21,0x27e48186,0x44295d22}},	//   _লিখে, must, hamn_, _haa_,
   {{0x7ae9ca41,0xb8f40a49,0x44295d23,0x61e3dd24}},	//   _svet, _হয়_, _kaa_, vanl,
   {{0x8c1c0158,0x44294a79,0x61e380dd,0x2d9803ba}},	//   ַווי, _jaa_, wanl, _dyre_,
   {{0x44295d25,0x7afd3d47,0x271d800d,0x2d9801e0}},	//   _maa_, nust, _भनेर_, _eyre_,
   {{0x44295d26,0x78ad5d27,0xf2d400be,0x644d016a}},	//   _laa_, lmav, דעס_, _loai,
   {{0x61e3dd28,0x7afd0074,0x85570019,0x6f098299}},	//   ranl, hust, _تیار_, wtec,
   {{0x61e3884a,0x44295d29,0x26019a42,0x63bbdd2a}},	//   sanl, _naa_, _शाही_, _ugun,
   {{0x61e3dd2b,0xef168009,0x7c3b999b,0xe811016f}},	//   panl, емы_, _inur, ड्या_,
   {{0x7c29dd2c,0x6f09dd2d,0x7afd5d2e,0xe8df81bc}},	//   _haer, rtec, dust, _alụm_,
   {{0x6f09dd2f,0x44295d30,0xa90780d5,0xc6920039}},	//   stec, _baa_, _زبان, ראי_,
   {{0x7c2ba13c,0xc2090039,0x6459a796,0x3d07009a}},	//   ndgr, _לה_, nkwi, _हमने_,
   {{0x61e1dd31,0x60c1a0f6,0x7c3bbff5,0x644d245f}},	//   _kell, _hulm, _mnur, _doai,
   {{0x60c1dd32,0x61e1dd33,0xf2d2898a,0x66f68039}},	//   _kulm, _jell, רעם_, _נמצא_,
   {{0x61e18558,0xf9928158,0xc5f283c8,0x44295d34}},	//   _mell, ָרן_, _עדה_, _faa_,
   {{0x44290870,0x387f807b,0xe3da00ab,0x212590e1}},	//   _gaa_, nnur_, _থাকব, _mslh_,
   {{0x2000085d,0x3f8603a7,0xa3ac5d35,0xdbd9808b}},	// [4ba0] rgii_, çou_, केश_, _ræðu,
   {{0x61e18021,0x63a45d36,0x44295d37,0x78ad01e8}},	//   _nell, _izin, _zaa_, amav,
   {{0x44295d38,0x7c29dd39,0xa3ac01d0,0x89db025f}},	//   _yaa_, _baer, केर_, _מחיי,
   {{0x7c29831d,0x5ed580ab,0x3eb8022b,0x649601a8}},	//   _caer, _দিনে, _wirt_, máis,
   {{0x7c2994e5,0x61e1a9da,0xe29a85c2,0x649600f7}},	//   _daer, _bell, пад_, láis,
   {{0x2d9808cf,0x61e18213,0x60c18214,0x63a40c53}},	//   _tyre_, _cell, _bulm, _mzin,
   {{0x61e1d731,0xada310ac,0x26c2022e,0xe5a300e5}},	//   _dell, _барл, _huko_, _бири,
   {{0x26c20578,0x661e2834,0x3b0a818b,0x7c298114}},	//   _kuko_, lepk, _небо_, _gaer,
   {{0x44295d3a,0x7afd01df,0x61e1dd3b,0x39a68032}},	//   _raa_, xust, _fell, _bísí_,
   {{0x44295d3c,0x3eb8bc54,0x628004c3,0x61e1831d}},	//   _saa_, ört_, émol, _gell,
   {{0x44295d3d,0x2d988bc5,0x764e5d3e,0x26c25931}},	//   _paa_, ære_, _moby, _luko_,
   {{0x7afd18c5,0xe7869da6,0x61e1d423,0x63a44471}},	//   tust, _пуло, _zell, _bzin,
   {{0x26c202a0,0x442b0db1,0x61e1dd3f,0x291e02d0}},	//   _nuko_, rdc_, _yell, çtan_,
   {{0x44290962,0x7afd25ac,0x63a401a9,0x764e0cf4}},	//   _waa_, rust, _dzin, _noby,
   {{0x44295d40,0x7afd5d41,0x63a45d42,0x6abadd43}},	//   _taa_, sust, _ezin, _mitf,
   {{0x759b8496,0x442902f7,0x26c20c8b,0x645f0168}},	//   _מיוח, _uaa_, _buko_, _ulqi,
   {{0x78ad3033,0x26c20267,0xf41f0198,0x64960174}},	// [4bb0] rmav, _cuko_, meä_, ráit,
   {{0x7c3bc321,0x38a1807b,0xb8f700ab,0x4b7c01c6}},	//   _snur, jórn_, _সি_, _מאחו,
   {{0x61e1dd44,0x649600f7,0x7aed5d45,0x7c29dd46}},	//   _rell, cáis, _hvat, _paer,
   {{0x610a8201,0x61e1dd47,0x999a001b,0x7aed5d48}},	//   _gəli, _sell, _např_, _kvat,
   {{0x60c180f1,0x442981ac,0x6459afc1,0x7c2bd8a6}},	//   _sulm, ľa_, rkwi, rdgr,
   {{0x60c1dd49,0x4429a9b4,0x764e0cf4,0x61e18168}},	//   _pulm, ža_, _goby, _qell,
   {{0x6f0d35d3,0x9d1819b8,0x26cf8144,0xf41f0198}},	//   ltac, _порт_, _stgo_, keä_,
   {{0x61e736a4,0x26c2313e,0xa3ac0006,0x6f0d0229}},	//   hajl, _yuko_, केँ_, otac,
   {{0xb8c88076,0x61e1dd4a,0x7c8481a1,0x387fdd4b}},	//   _खी_, _tell, _суре, rnur_,
   {{0x2ca91bea,0x6285017f,0x9f5f9b0d,0xd121064a}},	//   _ahad_, _njho, ngué_, मबाण_,
   {{0xc959a003,0x63a40065,0x423680be,0x69caab07}},	//   _تلاش_, _szin, _שנעל_, _स्टी,
   {{0x9055844f,0xed5680e8,0xa01b0106,0x91fc81a9}},	//   _швец, тою_, _sjön, _glāb,
   {{0x7aed00ce,0x032300e8,0xa85681c6,0x2ca90706}},	//   _cvat, адян, _שינה_, _dhad_,
   {{0x26c25d4c,0x2ca9026c,0x64960174,0xfaa60e63}},	//   _ruko_, _ehad_, gáir, таго,
   {{0xfbe100c8,0x26c281ac,0x4096197d,0x09e680ab}},	//   _ভারত, íkov_, врат, _নামা,
   {{0x249d81e9,0x20c7001c,0x26c200d2,0x4e1406b7}},	//   jlwm_, _dõi_, _puko_, न्नै_,
   {{0x764e0e04,0x6b9b8019,0x63a45d4d,0x2bd801d0}},	// [4bc0] _poby, _nyug, _uzin, _भ्या,
   {{0x787b0364,0x7ae904b7,0x0e6325f5,0x3f9c01a9}},	//   tävä, ġett, акун, āvu_,
   {{0xa06a0a42,0x7aed0024,0x6f0d051e,0xf8b384c5}},	//   _жана_, _zvat, atac, ुदाय,
   {{0xf53680be,0x26c25d4e,0x6f0d09ab,0x6b9bcae1}},	//   כטער_, _tuko_, btac, _byug,
   {{0xa01b1252,0x80af0035,0x6f0d0cf7,0x6b9b818e}},	//   _mjöl, ंगरे, ctac, _cyug,
   {{0x9f420168,0x98b80196,0xdce9928a,0x67240157}},	//   _lekë_, tyrė_, áněn, mwij,
   {{0x672401ed,0xda6581a8,0x6b8997c9,0x3e608706}},	//   lwij, داني, _exeg, _nòta_,
   {{0xc9530051,0x628fdd4f,0xdca68c66,0x64a68254}},	//   שמה_, _ícon, _раби, _раба,
   {{0xa4918077,0xb22690ca,0xe3e100ab,0x672400f3}},	//   _اینت, _имал, _ভালব, nwij,
   {{0x291a016f,0x7aed0669,0x2bce8a74,0x6aba89ff}},	//   _oppa_, _rvat, हुरा, _uitf,
   {{0x765a80f2,0x4e350158,0x7aed5d50,0x61e70bda}},	//   rkty, אָרן_, _svat, vajl,
   {{0x897983de,0x67245d51,0x2baf8075,0x017983de}},	//   _אָנה, kwij, जेवा, _אָנל,
   {{0x291a0b99,0xae0305fc,0x61e75d52,0xfb870071}},	//   _appa_, _लालन_, tajl, тынн,
   {{0x175781c6,0x97378538,0x25fe27cf,0x6724090d}},	//   _בסדר_, _שרגא_, _लागी_, dwij,
   {{0xc6938159,0xa01b07ca,0x61e75d53,0x7ae081c0}},	//   _דאס_, _fjöl, rajl, _lwmt,
   {{0x20c70665,0x6f0d5d54,0x61e707d9,0x9f9d007b}},	//   _või_, ttac, sajl, _bæði_,
   {{0x53350676,0xc62580ab,0x7aed0669,0x672439e0}},	// [4bd0] _септ, বারা_, _uvat, gwij,
   {{0x6f0d26dc,0x7c2d0a10,0x3a2cb8f8,0x81dd00ab}},	//   rtac, _haar, _nadp_, _ডাক_,
   {{0x7bf98993,0x9f5f876b,0x6f00b640,0x0b941abb}},	//   енер_, rgué_, humc, _مجید,
   {{0x7c2d3d43,0x645d5d55,0x6f0d5d56,0x6f00c3e7}},	//   _jaar, nksi, ptac, kumc,
   {{0x27e90a5b,0x610a8086,0x6f00826c,0x7cc18ec3}},	//   maan_, _məlu, jumc, _vēri,
   {{0xdd868013,0x7c2d2820,0x2c62026f,0x3a2c8118}},	//   _هو_, _laar, _móda_, _cadp_,
   {{0xc6920051,0xa3e3269d,0x645d2461,0x3a3e89c4}},	//   _האם_, धरा_, kksi, _dntp_,
   {{0x27e95d57,0xccf20051,0x39498289,0x7c2d5d58}},	//   naan_, _לכל_, ćas_, _naar,
   {{0x443f90ab,0x62950019,0xdd2e81d0,0xe3b398e0}},	//   _inu_, kozo, měře, _ضرر_,
   {{0x27e95d59,0x442d847b,0xb7bd8087,0x83528065}},	//   haan_, _hae_, deţe, _دھما,
   {{0x27e95d5a,0x7c2d5d5b,0x69c1dd5c,0x2f0b813c}},	//   kaan_, _baar, _igle, søg_,
   {{0x27e95d5d,0x442d90e4,0x78bd5d5e,0x7c2d0df6}},	//   jaan_, _jae_, _nisv, _caar,
   {{0x442da0af,0x27e9438f,0x7c2d01d8,0x81d50a49}},	//   _mae_, daan_, _daar, _হয়_,
   {{0x412a176a,0x7c2f3c77,0x442ddd5f,0xc87987c0}},	//   ного_, adcr, _lae_, liş_,
   {{0x443fdd60,0xc9550071,0x8cca8ebf,0x7c2d0079}},	//   _onu_, атты, _संयो, _faar,
   {{0x27e95d61,0x7c2d5d62,0xc8798182,0x67245d63}},	//   gaan_, _gaar, niş_, twij,
   {{0xee3a1ef7,0x44225d64,0x98a3140b,0x69c18ee1}},	// [4be0] нна_, mek_, сите, _ogle,
   {{0x443fdd65,0x67240613,0x69c18154,0xb2260705}},	//   _anu_, rwij, _ngle, _смол,
   {{0xae069513,0x69dc10cd,0x27e937d7,0x442db6bf}},	//   _शासन_, mbre, baan_, _bae_,
   {{0x44225d66,0x27e95d67,0x442ddd68,0xe4d7026a}},	//   nek_, caan_, _cae_, اونت_,
   {{0x442d879f,0x68e3013c,0x6d43016d,0xcec880ff}},	//   _dae_, _ændr, änar, _mộc_,
   {{0x443fdd69,0x69dc0dc2,0x11548ada,0xcec880ff}},	//   _enu_, nbre, иклю, _lộc_,
   {{0x44225d6a,0x6e21852e,0x645d0009,0x7d0183a6}},	//   kek_, delb, yksi, juls,
   {{0x44225d6b,0x8cca81b6,0x7d01930c,0x62838114}},	//   jek_, _संबो, duls, anno,
   {{0x20570158,0xd4678003,0x7de685a8,0x6440dd6c}},	//   טיקל_, _сите_, лінд, _inmi,
   {{0x7c2d1ee7,0x6e21dd6d,0x91d4000f,0x27e90ad4}},	//   _saar, gelb, _ब्लै, zaan_,
   {{0x27e95d6e,0xa3e889a3,0x7c2d5d6f,0x6295001b}},	//   yaan_, _मजा_, _paar, vozo,
   {{0x27e902c1,0x44220019,0x7c2d02a3,0x645d0009}},	//   xaan_, gek_, _qaar, uksi,
   {{0x7c2d2720,0x27e95a43,0x78bd047f,0xeb070198}},	//   _vaar, vaan_, _risv, ычно,
   {{0x7c2d01d8,0x27e91197,0x6e2e0c2e,0x45d4b2d7}},	//   _waar, waan_, _nabb, _токс,
   {{0xd49b310c,0x27e902a1,0x7c2d5d70,0x6440837a}},	//   _при_, taan_, _taar, _onmi,
   {{0x44220179,0x20ca801c,0x4fd520e2,0x61e53869}},	//   cek_, _mùi_, ржат, _wehl,
   {{0x6283998c,0x7c22dd71,0x6e2e03c3,0x6d5a8019}},	// [4bf0] ynno, deor, _babb, lyta,
   {{0x442ddd72,0x2be3000f,0xe45f016d,0x64408147}},	//   _sae_, परवा, lkö_, _anmi,
   {{0x27e94008,0x6e2e1d15,0xf3ff03a7,0x7bcf0081}},	//   paan_, _dabb, nhão_, occu,
   {{0x27e90079,0x7c22dd73,0x628882d4,0x7afd5d74}},	//   qaan_, geor, _ajdo, orst,
   {{0x6e2e23b5,0x23af81b6,0x7e7a810b,0x38690cb5}},	//   _fabb, जेंद, kitp, mhar_,
   {{0x386900a9,0x261403a4,0x44225d75,0x442d8077}},	//   lhar_, न्दी_, zek_, _wae_,
   {{0x291100ad,0x44224266,0x442ddd76,0x29035d77}},	//   ntza_, yek_, _tae_, nuja_,
   {{0x443f8870,0x38695d78,0x5d8400f7,0x7ccc03bf}},	//   _unu_, nhar_, _الفل, _uğra,
   {{0xc87982bb,0xf8bf0264,0x6e21dd79,0xaec28e11}},	//   riş_, _mié_, telb, обыл,
   {{0xee36dc6f,0x63a9dd7a,0x29035d7b,0x44225d7c}},	//   ань_, _izen, kuja_, wek_,
   {{0x44225d7d,0xc05b835f,0x6da59290,0x35a58071}},	//   tek_, _під_, рина, ранг,
   {{0x3e640106,0x6f1d01ed,0x6e21dd7e,0x76b28035}},	//   _möta_, _opsc, selb, _błys,
   {{0x44225d7f,0x6e21dd80,0x69dc1412,0x38690387}},	//   rek_, pelb, tbre, dhar_,
   {{0x44225d81,0x26c405db,0x320782f7,0x6d5add82}},	//   sek_, _émoi_, ngny_, byta,
   {{0x44225d83,0xdca60009,0x69dc5d84,0xc0e60ca0}},	//   pek_, _каки, rbre, робк,
   {{0x6e2e5d85,0xad1a8039,0x38695d86,0x7cc50084}},	//   _sabb, _יוצר, ghar_, _gėri,

   {{0xd90d0077,0xf77f1b32,0x27fd009a,0x929d809a}},	// [4c00] ویی_, _peça_, ówna_, _wpły,
   {{0x7df380a5,0x2bde8d72,0x45d609b5,0x29035d87}},	//   _आयोग_, मर्थ, рцат, buja_,
   {{0x38690ad0,0xa5260087,0x98a61fe8,0xa0a609f7}},	//   bhar_, рмед, _вине, _ванд,
   {{0x7ae402a0,0x1d168158,0x20ca80ff,0x3d070074}},	//   _kwit, יקער_, _rùi_, _हमरे_,
   {{0x6e2e00a4,0x7e600087,0x7bc48110,0x7c22dd88}},	//   _tabb, _împo, žiuo, reor,
   {{0x7c228867,0x63a9bb08,0xb8f481a8,0x64588035}},	//   seor, _dzen, مكتب, _ścią,
   {{0x61ead73b,0x6f040083,0x672b80f1,0x63a9dd89}},	//   rafl, luic, _asgj, _ezen,
   {{0x14d702f6,0x6440dd8a,0x649d5d8b,0x5fc606a7}},	//   _כולל_, _unmi, néit, लखिल,
   {{0x7e7a9d88,0x44f184b7,0x76aa8198,0x63a98115}},	//   titp, eġ_, ктов_, _gzen,
   {{0x7afd135a,0x6d5a8084,0x7bc40372,0x27e68144}},	//   vrst, tyta, _agiu, _weon_,
   {{0x160b0f0a,0x994a92c8,0x24868503,0xe45f0009}},	//   स्टर_, _جلال_, onom_, tkö_,
   {{0x6298ad06,0x6d5aacf5,0x2486821e,0x291e83ac}},	//   lovo, ryta, nnom_, _ipta_,
   {{0x20118085,0x3d08016f,0x7afd1412,0x3ed481a8}},	//   əzi_, ांडे_, urst, _اقتر,
   {{0x6d5a809a,0x61e8a35f,0x48fd800d,0xda7b24b6}},	//   pyta, _jedl, रूको_, тям_,
   {{0x61e88e23,0x3869003c,0x2bd80743,0x07e702de}},	//   _medl, thar_, _भ्वा, ицам,
   {{0x7cc18029,0x29030304,0x38600b99,0x16190e5b}},	//   _vērt, ruja_, gkir_, न्नर_,
   {{0x629887dd,0x395f00eb,0xab5b0085,0x6f045d8c}},	// [4c10] kovo, ņus_, rcüs, guic,
   {{0x386910fe,0x61e88370,0x644f012b,0x1a650019}},	//   shar_, _nedl, ljci, _ایسی_,
   {{0x63a9dd8d,0x91fc8029,0x3866dd8e,0x2486817f}},	//   _szen, _plān, _olor_, fnom_,
   {{0xef1f8214,0x6280026f,0x2486dd8f,0x644f017f}},	//   çük_, émov, gnom_, njci,
   {{0x28c0000f,0x261413ba,0x649d1867,0x96f80162}},	//   _शूटि, न्ही_, léis, _кеят_,
   {{0xa3ac086a,0x3866c85b,0x20095d90,0x5ed580ab}},	//   केट_, _alor_, lgai_, _দিলে,
   {{0xceb20158,0x25a50019,0x5c078198,0x2486a9b4}},	//   _מיך_, _áll_, _вяза, bnom_,
   {{0x200920ac,0x6add00c8,0x6c8580f7,0x4c94862c}},	//   ngai_, _বিনো, _الرم, _дисс,
   {{0x6298816b,0x63a9dd91,0xf749803d,0x69c50135}},	//   bovo, _uzen, اجعه_, _oghe,
   {{0x6287011f,0x0e6582cb,0x69c52160,0x765503ec}},	//   jnjo, скон, _nghe, _jozy,
   {{0x62870025,0xc329010f,0x993592c8,0x7ae401c6}},	//   dnjo, _רו_, _دفات, _swit,
   {{0xdd380029,0x15f395a7,0x491c8b75,0x44e38061}},	//   nāša, _आयकर_, _महतो_, rű_,
   {{0x38a1807b,0x2fdf80d7,0x27eddd92,0x649d0118}},	//   jóri_, mbug_, maen_, véit,
   {{0x2486811f,0xfbd81305,0x27ed831d,0x2bd806ce}},	//   znom_, _भ्रम, laen_, _भ्रा,
   {{0x76438063,0xa06a0098,0x291e0722,0x649d1b9c}},	//   _inny, гава_, ïta_, téit,
   {{0xb8d05d93,0x320c009a,0x69c501bc,0x7cd38162}},	//   _ओठ_, żdy_, _eghe, _căre,
   {{0xe61a3f61,0x24868ee0,0x38602a6c,0x6444009c}},	// [4c20] лда_, vnom_, rkir_, _inii,
   {{0x44325d94,0x6f0454c3,0x3860008b,0xf41f062c}},	//   _hay_, ruic, skir_, nnän_,
   {{0x4432435e,0x5bc680f7,0x61ee2dc8,0x200900dd}},	//   _kay_, مقال, mabl, bgai_,
   {{0xdd8f0872,0x64560136,0x61ee4b4f,0xd49980e8}},	//   رون_, _joyi, labl, арі_,
   {{0xa3c9823c,0x4432004c,0x6298a3f8,0x27e05d95}},	//   ोड़_, _may_, tovo, mbin_,
   {{0x64560032,0x523a0158,0x3320001b,0x649d00f7}},	//   _loyi, רײַנ, _mpix_, néir,
   {{0x629e0135,0x61e8dd96,0x64a69c28,0xed570c6e}},	//   _mkpo, _vedl, _гава, _лор_,
   {{0x74168277,0x7643dd97,0x443237cd,0xc6f8a4c1}},	//   _دورا, _anny, _nay_, аних_,
   {{0x33668d8e,0x7d1b026c,0x629e0135,0x254e8085}},	//   _уваг, _ćusi, _okpo, məli_,
   {{0x4426dd98,0x78a4026f,0x61ee0144,0xbb3b80be}},	//   leo_, hliv, jabl, _געמי,
   {{0x78a45d99,0xe0da8b30,0x64565d9a,0x443225cf}},	//   kliv, _све_, _boyi, _bay_,
   {{0x4426dd9b,0x7643dd9c,0x7cd38087,0x629e01bc}},	//   neo_, _enny, _bărb, _akpo,
   {{0x4432501e,0x628702a5,0x78a4016b,0xddc88369}},	//   _day_, tnjo, dliv, midž,
   {{0xfaff020f,0x61ee1ee8,0x60c280f7,0x69c800e1}},	//   rrë_, gabl, _hiom, žden,
   {{0x4426822e,0x44325d9d,0x7cd38087,0xf77f0187}},	//   keo_, _fay_, _păre, _peço_,
   {{0xc7d9012f,0x629e0135,0x4426dd9e,0x661c0115}},	//   рмах_, _ekpo, jeo_, _abrk,
   {{0x4426dd2e,0x623550bc,0x7655009a,0x62870115}},	// [4c30] deo_, _депу, _pozy, pnjo,
   {{0x63ad00ad,0x518719bb,0x44321b1d,0xe1338301}},	//   _izan, _гума, _zay_, ščić_,
   {{0x81e780c8,0x27e004b9,0x78a45d9f,0x4426dda0}},	//   _ভাল_, bbin_, bliv, feo_,
   {{0xac19caa5,0x241981bb,0x44325da1,0xc1b5103e}},	//   роду_, роды_, _xay_, ंधीग,
   {{0xa3ea0f97,0x3de800ab,0x7eaf804a,0xdea40019}},	//   यरत_, _পারল, løpe, _کیلی,
   {{0x672f111b,0x7c265da2,0x63ad1ffb,0xdcf42353}},	//   _iscj, zekr, _mzan, _çağl,
   {{0x4426dda3,0x6d5e010c,0x7cd38162,0x27edb5aa}},	//   beo_, cypa, _mărc, taen_,
   {{0x26c305a4,0x61ee0a0c,0x63ad5759,0x60c2dda4}},	//   _hijo_, zabl, _ozan, _ciom,
   {{0x2fdfd474,0x60c2dda5,0x27eddda6,0x656d8326}},	//   rbug_, _diom, raen_, _ƙaho,
   {{0x248d8b40,0x8cca81cb,0x44325da7,0x26cb0314}},	//   _hjem_, _संशो, _say_, _muco_,
   {{0x26c35da8,0x63ad5da9,0x7cd38087,0x248d821e}},	//   _mijo_, _azan, _sărb, _kjem_,
   {{0x2907ddaa,0xdb078789,0x16190cf0,0x3a27826c}},	//   muna_, _ímót, न्तर_, lenp_,
   {{0xd6db9cf8,0x6d5e009a,0x61ee1b90,0x44325dab}},	//   _сте_, zypa, tabl, _vay_,
   {{0x386d80a9,0x44320051,0xfce580b3,0x4426811f}},	//   lher_, _way_, _доко, zeo_,
   {{0x61ee5dac,0x78a404e8,0x44320104,0x2907b4f5}},	//   rabl, tliv, _tay_, nuna_,
   {{0xe3bf00ab,0x248dddad,0x44268511,0x26cb00e5}},	//   seña_, _njem_, xeo_, _buco_,
   {{0x4426803b,0xa0670381,0x8fa30d31,0x290784a7}},	// [4c40] veo_, цата_, дате, huna_,
   {{0x2907bf1c,0xa3af2f7b,0x9f44bdc8,0x78a404fe}},	//   kuna_, _करत_, namá_, sliv,
   {{0x4426ddae,0x26c300ab,0x2907ddaf,0xfc3f03a8}},	//   teo_, _dijo_, juna_, llía_,
   {{0xf7461935,0x2907ddb0,0x629c1c9e,0x26cb002a}},	//   _демо, duna_, loro, _fuco_,
   {{0x26c323e5,0x386d81b9,0x9d0a00ab,0xda05950e}},	//   _fijo_, dher_, রবেন_, _राखत_,
   {{0x4426ddb1,0x29078a40,0x16190ebf,0x6f165db2}},	//   seo_, funa_, न्दर_, mtyc,
   {{0x2907ddb3,0xa3ea0b75,0x60c2847f,0xddc88699}},	//   guna_, यरा_, _piom, tidž,
   {{0x629c5db4,0x3ea5816d,0x63a45db5,0x26c3026c}},	//   horo, ellt_, _oyin, _zijo_,
   {{0x63a43488,0x629c5db6,0xf8b302f6,0x29078087}},	//   _nyin, koro, ושה_, auna_,
   {{0x2ca6ddb7,0x629c5db8,0xb5e80264,0x76aa83a7}},	//   llod_, joro, _পাঁচ, јтив_,
   {{0xa06aa6de,0x60c28cb5,0x63a422e8,0x63ad2dd7}},	//   _кажа_, _tiom, _ayin, _szan,
   {{0x386d837e,0x6f16009a,0x63a402a0,0x2ca6911e}},	//   cher_, ktyc, _byin, nlod_,
   {{0x09e200c8,0x629c444f,0x63a40a03,0x7792881b}},	//   _বাজা, foro, _cyin, _زیدا,
   {{0x59dd800d,0x32d0801c,0x9c130133,0x628ac808}},	//   नुपर, _mày_, _nọve, nnfo,
   {{0x58d41232,0x6e28ddb9,0x628addba,0xc0cb215b}},	//   дост, medb, info, руге_,
   {{0x6722819d,0x200f02f1,0x43950a18,0x62800866}},	//   _kpoj, ügi_, _найс, émor,
   {{0x32d08142,0x629c5dbb,0x765881c0,0x29078102}},	// [4c50] _này_, boro, _kovy, zuna_,
   {{0xe3bf0511,0x6e28b9f7,0x26cb082c,0x249f9da3}},	//   leño_, nedb, _vuco_, _skum_,
   {{0x7d08ad8f,0x1bf200d4,0x5fca9869,0x69d5066f}},	//   nuds, _अजमल_, ाखाल, mcze,
   {{0xa3af1880,0x81e780c8,0x2907a1ee,0x61fa8118}},	//   _करा_, _ভাই_, vuna_, _adtl,
   {{0x4c3c0158,0x9327803d,0x3ea5ddbc,0x32d08129}},	//   יגאצ, تران, yllt_, _cày_,
   {{0x6e2882ce,0x99910019,0x32d080ff,0xdc558019}},	//   jedb, lező_, _dày_, _کرسک,
   {{0x386d804c,0xd24e80f7,0x823480f7,0x67228032}},	//   ther_, انى_, برنا, _apoj,
   {{0x629c5dbd,0x628a81a1,0x25ed8072,0xe3bf0144}},	//   zoro, anfo, _आजही_, jeño_,
   {{0x2907ddbe,0x386d82af,0x629c0a5a,0xe3bf0333}},	//   suna_, rher_, yoro, deño_,
   {{0x670c0beb,0x7ae9ddbf,0x386dddc0,0x6e355dc1}},	//   िंतक_, _iwet, sher_, _jazb,
   {{0xcb090051,0x629c46b7,0xdca620e2,0x64a61287}},	//   _תל_, voro, зани, зана,
   {{0x7ae9dc27,0x629c1111,0x69d5009a,0x672d1f50}},	//   _kwet, woro, ecze, kwaj,
   {{0x629c2ac8,0x7052a45e,0x20d18129,0x87049e2a}},	//   toro, _سنوا, _hái_, _قبول,
   {{0x70b40ee6,0xf77082e3,0x7ae9ddc2,0x2f140106}},	//   ंग्ल, _جام_, _mwet, väg_,
   {{0xd9432118,0x629c4d16,0x6da2bd23,0x213e01a8}},	//   нери, roro, _пиша, íth_,
   {{0x786a003e,0xfc3f5dc3,0x20d1801c,0x629c5dc4}},	//   _býva, llín_, _mái_, soro,
   {{0x44205dc5,0x629c5dc6,0x20d1801c,0x3e6086c0}},	// [4c60] _ibi_, poro, _lái_, _sòti_,
   {{0x7c3602d0,0x388581a9,0x6a700338,0x6f16066f}},	//   _hayr, mēru_, _säff, rtyc,
   {{0x6f160063,0x0c26b553,0x6e3501a1,0x261383ca}},	//   styc, змен, _dazb, _दानी_,
   {{0x3d1c2f80,0xc20e800f,0x9b6a8221,0x7ae98365}},	//   _नहीं_, _साहब_, йшла_, _bwet,
   {{0xe3638ab2,0x44205dc7,0x09c500c8,0x7c3602b8}},	//   нкци, _mbi_, ্রণা, _mayr,
   {{0x8d660396,0x44205dc8,0x628a8333,0x6f0451af}},	//   _евге, _lbi_, unfo, mric,
   {{0x6722a1d1,0x20d18104,0x4420082e,0x6e28c6b7}},	//   _spoj, _cái_, _obi_, vedb,
   {{0x64a39c8a,0x69d55dc9,0x27f20079,0x2b40026c}},	//   _заса, zcze, nayn_, _oric_,
   {{0x213e8355,0x07f780f7,0x6f041cd9,0x290a0234}},	//   _wrth_, سريع_, nric, huba_,
   {{0x290a4a7d,0x44205dca,0x27f20079,0x6f040c5e}},	//   kuba_, _abi_, hayn_, iric,
   {{0x7c361010,0x6e28803a,0x20d18028,0x44205dcb}},	//   _bayr, redb, _gái_, _bbi_,
   {{0x2b208b3b,0x60c6059c,0x7d08806a,0x6e2882d4}},	//   _यहाँ_, _nikm, ruds, sedb,
   {{0xfc3f2333,0xa5f882de,0xe3bf5dcc,0xe8e00129}},	//   blín_, _делу_, reño_, _thớt_,
   {{0xe3bf040e,0x44205dcd,0xf7bb81c6,0x7c361407}},	//   seño_, _ebi_, _הזדמ, _eayr,
   {{0x290a5dce,0xe3bf0511,0xdd8f8048,0x6f040037}},	//   guba_, peño_, _чш_, eric,
   {{0x29030168,0x7c3602d0,0x672d0314,0x6e35128a}},	//   rrja_, _gayr, twaj, _sazb,
   {{0xa01b5dcf,0xbfab2252,0xcc3400f7,0x3ed901a8}},	// [4c70] _björ, стве_, _سريع, زواج_,
   {{0x442b399c,0x672d1258,0x44395dd0,0x7bc98014}},	//   lec_, rwaj, lds_, _sgeu,
   {{0x7ae9ddd1,0x290a1267,0x6e3501d0,0x2dd801a8}},	//   _swet, cuba_, _vazb, سبلة_,
   {{0xc0ab07bd,0x44395493,0x442b5dd2,0x7c365dd3}},	//   _داخل_, nds_, nec_, _xayr,
   {{0x44395dd4,0x6f0401df,0x1a658416,0x9f59861c}},	//   ids_, cric, ویری_, üsü_,
   {{0x78a2826c,0x442b5dd5,0xbb4299f8,0xa01b008b}},	//   _akov, hec_, тешк, _gjör,
   {{0x442b4b5b,0xe1f09a43,0x6594117c,0x261381d0}},	//   kec_, اسه_, _зару, _दाबी_,
   {{0xba77803d,0x4439442b,0x673b8bcf,0x7ae9ddd6}},	//   _کارت, jds_, tvuj, _twet,
   {{0x5215c543,0x290a00b4,0x200d86ab,0x7afb0140}},	//   _одат, zuba_, rgei_, šutj,
   {{0x443905f8,0x4420368b,0x20d1801c,0x7c2ba038}},	//   eds_, _sbi_, _tái_, legr,
   {{0x90e78077,0xfc3f5dd7,0xb5798009,0x291808dc}},	//   _رسان, rlín_, ющих_, xtra_,
   {{0x442b0988,0x645b92b6,0x6f045dd8,0xff519e5c}},	//   gec_, _joui, yric, _لخت_,
   {{0x201882bf,0x6f09ddd9,0x25aa10be,0x78a98b81}},	//   əri_, quec, _कर्ण, mlev,
   {{0x290a5dda,0x29181b14,0xc332807c,0x60c65ddb}},	//   tuba_, ttra_, דוך_, _sikm,
   {{0x442b0e04,0x3d0c009a,0x6449c9a6,0x6f045ddc}},	//   bec_, _हमें_, _onei, wric,
   {{0x44202b6d,0x78a9dddd,0x26c780b4,0x6add00ab}},	//   _ubi_, nlev, _hino_, _বিরো,
   {{0x26c7ddde,0x98a30468,0x26cfdddf,0x6283dde0}},	// [4c80] _kino_, тите, _jugo_, kino,
   {{0x26cfdde1,0x6f0449f6,0x26c7dde2,0x27f25de3}},	//   _mugo_, rric, _jino_, sayn_,
   {{0x6283dde4,0x26cf862f,0x645bd5df,0x6f045d7e}},	//   dino, _lugo_, _boui, sric,
   {{0x26c7dde5,0x7c2b8faf,0x32d40009,0x50b6222c}},	//   _lino_, gegr, _käy_, _існу,
   {{0x78a99ff6,0x645b8866,0x93cb8019,0x2d828326}},	//   dlev, _doui, زانہ_, ̄ke_,
   {{0xfe6783f8,0x442b06b9,0x78a2813c,0x38cb00d7}},	//   _شد_, zec_, _skov, _دایی_,
   {{0x65c30110,0x7c2bdd7e,0xe5a6197d,0x44395de6}},	//   _абра, begr, _циви, yds_,
   {{0xcec88104,0x2900a978,0x765c5de7,0x2c62016b}},	//   _hội_, čia_, _hory, _kódu_,
   {{0x26c782ec,0x09b500ab,0x61fe2454,0xd426811c}},	//   _bino_, _জ্ঞা, _odpl, ışdı_,
   {{0x628382d7,0x7cd38162,0x5d54a0ab,0x26c789c4}},	//   cino, _căro, екот, _cino_,
   {{0x26c7dde8,0x78a9dde9,0x7ae2ddea,0x7e600162}},	//   _dino_, blev, lpot, _împu,
   {{0x27ef807b,0x765c5deb,0xa3d643bc,0xfc3f002a}},	//   _gegn_, _lory, ाँग_, rlío_,
   {{0x44395dec,0x26c7dded,0x442b30d8,0x8cca8127}},	//   rds_, _fino_, rec_, _संको,
   {{0x26c7a45a,0xb06184a2,0x9958001b,0x65949d38}},	//   _gino_, _ääre, láře_, _палу,
   {{0xcec88104,0x6d58062c,0x6aaa8428,0xf7730061}},	//   _nội_, äval, ilff, ھار_,
   {{0x9ed90071,0x26c78365,0xb8d702f1,0x2480008e}},	//   змат_, _zino_, _छठ_, _gmim_,
   {{0x69daddee,0xeb0d8bb8,0xb8d60576,0x7bcd00eb}},	// [4c90] _ofte, _समेत_, _ची_, _igau,
   {{0x6283887a,0x6449ddef,0xb90500ab,0x765c45a7}},	//   xino, _snei, _নি_, _cory,
   {{0xd49b917e,0x8c3d8214,0xdb00802a,0x25de06a7}},	//   орд_, _akşa, _gzmú, गड़ी_,
   {{0x1ddf18a9,0xd5df0a0d,0x05df0e70,0x69dac6df}},	//   _प्रत, _प्रज, _प्रब, _afte,
   {{0x7c2b83a8,0xe8df0028,0x27ef8370,0x38690041}},	//   regr, _khỏe_, _regn_, mkar_,
   {{0x6e38ddf0,0x38691a37,0xdcfb0077,0x7aed42c3}},	//   _navb, lkar_, _ورزش_, _mwat,
   {{0x6283ddf1,0x6f0d2fe5,0x8cca8006,0x26c7b1b4}},	//   rino, luac, _संगो, _rino_,
   {{0x69da8786,0x26c7ddf2,0x38690687,0x7bcd2079}},	//   _efte, _sino_, nkar_, _ngau,
   {{0x6f0d2e3c,0x78a9ddf3,0x261381ce,0x27ef852a}},	//   nuac, rlev, _दादी_, _vegn_,
   {{0x99678371,0x02cb9905,0x7bcd5df4,0x63a9912e}},	//   _отел, ादीन, _agau, _iyen,
   {{0x7aed40e8,0x78a9a2ea,0xd0118019,0x6f0d2259}},	//   _awat, plev, _ملا_, huac,
   {{0xeb9a0f2e,0x3e6981ac,0x63a98365,0x7aed2c1d}},	//   зим_, _túto_, _kyen, _bwat,
   {{0x3ea10006,0x38695df5,0x2f2301a9,0x63a9818f}},	//   koht_, dkar_, nīgā_, _jyen,
   {{0xd7748b8c,0x42798158,0x6f0d1883,0x7afb8c53}},	//   _جامع, לאָג, duac, _mvut,
   {{0xe29730be,0x628e2257,0x48b60d70,0xd826046e}},	//   хар_, rnbo, ещат, ндви,
   {{0x786a003e,0x38691600,0x63a9ddf6,0xddca82d6}},	//   _vývo, gkar_, _oyen, _anfň,
   {{0x63a9d821,0x7c2402a0,0x6f0d5df7,0x06e380ab}},	// [4ca0] _nyen, _ibir, guac, _মিডি,
   {{0xba760077,0xdb9b0496,0xa2d50e81,0x7bdbc953}},	//   _ساخت, _מספר, _यंत्, _afuu,
   {{0x9f420364,0x7afbd385,0x7c2404b7,0x7871128d}},	//   _sekä_, _avut, _kbir, _såve,
   {{0xdee61f64,0x386900f2,0x66e61a1f,0x78710687}},	//   _поми, ckar_, _пома, _påve,
   {{0x7ae28067,0x6f0d11b9,0x2907a7f8,0x7c245df8}},	//   upot, cuac, erna_, _mbir,
   {{0x7ae28359,0xcec8801c,0x9f5206c0,0x3a3a0106}},	//   rpot, _tội_, vayè_, _japp_,
   {{0xdd920307,0xfd078277,0x7c245df9,0x98c68087}},	//   _صور_, _حج_, _obir, нсил,
   {{0x7f428201,0x9d1b04de,0x61f502a5,0x7ae2ddfa}},	//   _proq, _מולט, zazl, ppot,
   {{0x63068c48,0x29078083,0x26ca2f0f,0x63a9ddfb}},	//   _سوال, arna_, _kibo_, _gyen,
   {{0xdbfb0a16,0x7c242b5c,0xe0ce80ab,0x3b83ae27}},	//   ्ल्ड_, _abir, _রবীন, _слуг,
   {{0xdb160065,0xdd948196,0xfc3f026f,0xf76f803d}},	//   _együ, таны, slím_, لای_,
   {{0x26ca0c27,0x7f428c1d,0x7ccc07c0,0x2486866f}},	//   _libo_, _troq, _uğru, niom_,
   {{0x4e10000d,0xfbab17ae,0x6d43ddfc,0x7eb00338}},	//   ालाई_, ятой_, _erna, väpn,
   {{0x7c240c56,0x442482c4,0x26ca5dfd,0x2ba50d72}},	//   _ebir, _lbm_, _nibo_, _गुणा,
   {{0xe4a71da4,0x3e728087,0xe29f007b,0x290e8041}},	//   _прио, _câte_, nuði_, nufa_,
   {{0x2ea90054,0x7aed3d92,0x26ca01a1,0xd49801e2}},	//   कत्त, _twat, _aibo_, _пры_,
   {{0x644d5dfe,0x7c2f009f,0x3869088b,0x26ca5dff}},	// [4cb0] _inai, mecr, rkar_, _bibo_,
   {{0x38695e00,0x290eb148,0x7c240805,0x26ca0081}},	//   skar_, kufa_, _zbir, _cibo_,
   {{0x4424de01,0x443b00f1,0x6287076a,0x9419a2f1}},	//   _bbm_, _kaq_, mijo, джет_,
   {{0x62875e02,0x7c3d02fe,0x6281801b,0x4424ab8c}},	//   lijo, ndsr, _smlo, _cbm_,
   {{0xa7fb07f4,0x27e95e03,0x26190f12,0x6f0d5e04}},	//   _coñe, mban_, _पापी_, quac,
   {{0x78ad5e05,0x628712b9,0x26ca02c4,0x63a9804f}},	//   llav, nijo, _gibo_, _vyen,
   {{0x40959cfb,0x248688ae,0x644d56a3,0x569427d6}},	//   крит, biom_, _onai, _сарт,
   {{0x27e90065,0x7e600087,0x6f1bd268,0x7c3d0366}},	//   nban_, _împr, ttuc, jdsr,
   {{0x442fde06,0x2ba88105,0x8ccb141b,0x5b158b73}},	//   meg_, _छुपा, _संजो, _шмат,
   {{0x442f8558,0x7c3bde07,0x644d5e08,0x83fd8065}},	//   leg_, _haur, _anai, _előt,
   {{0x27e90065,0x2619123a,0x78ad41f8,0x7c3bde09}},	//   kban_, _पानी_, klav, _kaur,
   {{0x442f8114,0x7c3b811e,0xddce001b,0x3201008e}},	//   neg_, _jaur, _dobř, _adhy_,
   {{0x7c3ba898,0x987a80be,0xe73981f3,0x3e641252}},	//   _maur, _קאנט, _цел_, _kött_,
   {{0xd2520c3b,0x62870110,0x6d4381ac,0x161886b7}},	//   جنس_, gijo, _trna, _दायर_,
   {{0xc21284de,0x78ad008b,0x78b981c0,0x7fd60221}},	//   יהם_, flav, _khwv, візі,
   {{0x442f803a,0x27e90019,0x7c3bde0a,0x3eb802c4}},	//   jeg_, gban_, _naur, _shrt_,
   {{0x442fa157,0x62875e0b,0xee3a28ca,0x984580eb}},	// [4cc0] deg_, bijo, мна_, dēļ_,
   {{0x62870084,0x6d41876c,0x34ca8f12,0x60cb8901}},	//   cijo, ovla, िद्द, _ligm,
   {{0x27e95e0c,0x5fa7016f,0x7c3b9500,0x26ca01e8}},	//   bban_, _कुठल, _baur, _vibo_,
   {{0x25410a8e,0xa7fb062f,0xb5098beb,0x7c3bde0d}},	//   _dėl_, _poñe, _विनय_, _caur,
   {{0x7c3bde0e,0x26ca5e0f,0x332900b9,0x2c1a081f}},	//   _daur, _tibo_, _xpax_, _भानू_,
   {{0x6f09de10,0x5b7b00be,0xe18909a7,0x442480b9}},	//   drec, ורנא, _آئین_, _wbm_,
   {{0xcec88142,0x6e3c5e11,0x442483a7,0x7c3bde12}},	//   _một_, _iarb, _tbm_, _faur,
   {{0x442f8052,0x7c3bde13,0x62870110,0x65632b16}},	//   ceg_, _gaur, zijo, änhe,
   {{0x291c82a5,0x6e3c5e14,0x83fd8019,0x60cb809c}},	//   stva_, _karb, _elős, _digm,
   {{0x644d5e15,0xa80603bf,0x7c3bde16,0xb90880ab}},	//   _snai, ldığ, _zaur, _বি_,
   {{0xa96aa003,0x6f09802e,0xb7bd8087,0x27e90061}},	//   _تمام_, arec, deţu, yban_,
   {{0x6f098eb9,0xa80603bf,0x9ffa8eca,0x70be0c33}},	//   brec, ndığ, _آراء_, ्दोल,
   {{0x6f09ad84,0x62875e17,0x63b6009a,0xcec880ff}},	//   crec, tijo, _czyn, _bột_,
   {{0x2be30063,0xc60800ab,0xcec880ff,0x3e640106}},	//   _क्रं_, র্তা_, _cột_, _möts_,
   {{0x62875e18,0x442fbd8b,0x27e90065,0x236d01ac}},	//   rijo, yeg_, tban_, šej_,
   {{0x62870a28,0x27e95e19,0x6e3c1d73,0x61f8826c}},	//   sijo, uban_, _aarb, havl,
   {{0xdef80b71,0x442fde1a,0x2ca90a20,0xc0c84a48}},	// [4cd0] вых_, veg_, _ikad_, туре_,
   {{0x78ad0b72,0x7c3b83c3,0x63ad5e1b,0x27e90019}},	//   slav, _saur, _iyan, sban_,
   {{0x6e3c3e07,0x7c22de1c,0x7c3b8081,0x569403c7}},	//   _darb, ffor, _paur, шафт,
   {{0x7c22de1d,0xfc3f5e1e,0x25410110,0x6e3c051e}},	//   gfor, ndí_, _vėl_, _earb,
   {{0x6e3c5e1f,0x442f92af,0x2911071f,0x4ea702df}},	//   _farb, reg_, luza_, _арва,
   {{0x442fde20,0x63ad5e21,0x7c3b8326,0x7afd3bf3}},	//   seg_, _myan, _waur, isst,
   {{0x7c3ba67e,0x2911507d,0x7c22de22,0x63ad47f2}},	//   _taur, nuza_, bfor, _lyan,
   {{0x20d8863e,0x6f09de23,0x81d900c8,0x83fd8019}},	//   _déi_, trec, ারি_, _előr,
   {{0x62850613,0x63ad5e24,0xb4bf8768,0x29115e25}},	//   _omho, _nyan, ँगी_, huza_,
   {{0x3d08035a,0x7afd0370,0x29112403,0x6f098cf7}},	//   ांचे_, dsst, kuza_, rrec,
   {{0x63ad5e26,0x6f09dd7e,0x81d900ab,0x60cb8bb1}},	//   _ayan, srec, ারা_, _tigm,
   {{0x67030aed,0x6d41a464,0x29115e27,0x2246080a}},	//   _लिंक_, rvla, duza_, _şok_,
   {{0x63ad02f4,0xd7f885e9,0x7afd220d,0x9c1411d3}},	//   _cyan, _рух_, gsst, _fọnt,
   {{0xa3e40a74,0x454580d5,0x29115e28,0x78710bbd}},	//   _प्र_, _منتق, fuza_, _råva,
   {{0x69dc02be,0x044628ff,0x63ad5b30,0x29112b72}},	//   rcre, _бейн, _eyan, guza_,
   {{0x61f882a5,0x6e3c5e29,0x388c801b,0x69dc2b56}},	//   zavl, _sarb, běru_, scre,
   {{0x6d4757d9,0x386d83b2,0x7c2283ba,0x290a0267}},	// [4ce0] _arja, iker_, vfor, srba_,
   {{0x2619035a,0x29115e2a,0xe6171541,0x7ae40a63}},	//   _पाणी_, buza_, лду_, _itit,
   {{0x386d92f0,0x0446ac75,0x6e3c5e2b,0x787581ac}},	//   kker_, лежн, _varb, _záve,
   {{0xeb9a8991,0x6e3c02a3,0x386d8a0f,0x3ea59de6}},	//   ние_, _warb, jker_, holt_,
   {{0x6e3c5e2c,0x7c22afac,0x5efe052a,0xa806080a}},	//   _tarb, rfor, _लिट्_, rdığ,
   {{0x7c22dbb4,0xd13a8656,0x386d9151,0xfc3f016b}},	//   sfor, ехи_, eker_, zdí_,
   {{0x26190b9f,0x14cf816f,0x7c22aef4,0xe9df827d}},	//   _पाती_, _संगण, pfor, _đút_,
   {{0x64a6dba7,0x63a90063,0x7ae42b2f,0x61f88d11}},	//   _саба, żeni, _otit, savl,
   {{0x44f181e2,0x6a169a05,0xeb979073,0xa3e482f1}},	//   eš_, _مبار, _бит_, पुण_,
   {{0x7afd0370,0x6ce6ca82,0x2ca6aa24,0x073704de}},	//   vsst, ліме, lood_, נאים_,
   {{0x7ae45e2d,0x63ad5e2e,0x2bc7064a,0x628ade2f}},	//   _atit, _syan, रेना, mifo,
   {{0x2ca6de30,0x386dbfdc,0xd5b79ae5,0x29111add}},	//   nood_, cker_, ысы_, vuza_,
   {{0xfc3f3e80,0x2f18a4b6,0x657a8019,0x6d410661}},	//   rdí_, _роль_, szth, _álav,
   {{0x2ca6aadb,0x63ad5e31,0x7afd5e32,0x29110b5e}},	//   hood_, _vyan, rsst, tuza_,
   {{0x7ae40870,0x63ad5e33,0x2ca6aafa,0x9f4b07f1}},	//   _etit, _wyan, kood_, _secà_,
   {{0x29115e34,0x628ade35,0x7ae40609,0xda1703ca}},	//   ruza_, hifo, _ftit, _तावत_,
   {{0x26cec07d,0x209811e9,0x44294dc0,0x35f50790}},	// [4cf0] _kifo_, укты_, _iba_, ипар,
   {{0xdd9b004a,0x32d986c0,0xa7fb016a,0x7cd38162}},	//   нше_, _rèy_, _doña, _sări,
   {{0xceb3893f,0x7cd38087,0x3cfe86cb,0x69c80d2f}},	//   ציע_, _pări, nstv_, žder,
   {{0xd3718013,0x2ca6de36,0xae19001b,0x23bb026b}},	//   يها_, good_, न्जन_, _gàjí_,
   {{0x4429082e,0x291e8197,0x447c03de,0x7c3f0df6}},	//   _mba_, _aqta_, ענדע, _maqr,
   {{0xaa45c094,0x61f70101,0x6d47008e,0x06e38264}},	//   рекл, _jexl, _trja, _মিলি,
   {{0x44295e37,0x60cf00d2,0x3a3e8118,0xc6920039}},	//   _oba_, _kicm, _datp_, _ואם_,
   {{0xf8b50ee6,0x6f0d0090,0x248b01a1,0xaf0584ad}},	//   ंतिय, orac, jicm_, апил,
   {{0x3255807f,0x7c29de38,0x443fde39,0xcf8e8077}},	//   _квар, _iber, _iau_, وژه_,
   {{0x443fde3a,0x386dde3b,0x44294af2,0x628a802a}},	//   _hau_, sker_, _aba_, cifo,
   {{0x443f8274,0x7ae45e3c,0x44295e3d,0x6f0d2630}},	//   _kau_, _stit, _bba_, hrac,
   {{0x443fbffd,0x64a62e39,0xcb6a01f3,0xdca6411c}},	//   _jau_, рама, ваме_, рами,
   {{0x443fde3e,0x7c2988b8,0x27edde3f,0x26ce846d}},	//   _mau_, _mber, mben_, _fifo_,
   {{0x443fde40,0x27edde41,0x877a80be,0x44294392}},	//   _lau_, lben_, _באני, _eba_,
   {{0x7c29de42,0xa7fb0693,0x2effa240,0x257b8032}},	//   _ober, _soña, lsuf_, _dálé_,
   {{0x3fe629b6,0x4429077f,0x443fde43,0x6f0d3fb7}},	//   ржав, _gba_, _nau_, frac,
   {{0x7e63de44,0x27ed8352,0xa6860791,0x78780073}},	// [4d00] _konp, iben_, алад, _níve,
   {{0x7c29d0fc,0x61408019,0xf5e7002e,0x60cf0037}},	//   _aber, nálá, имул_, _eicm,
   {{0x27ed8065,0x6f0d1a2f,0x2ca6d11c,0x7e638bfe}},	//   kben_, arac, tood_, _monp,
   {{0x499b0f60,0x61fc3c89,0x0b469109,0x443fde45}},	//   _ישיב, larl, инен, _cau_,
   {{0x443fde46,0xa01b016d,0x2ca6857b,0x7c298642}},	//   _dau_, _omöj, rood_, _dber,
   {{0x61fc5e47,0x443f82be,0x27ed8352,0x27e03640}},	//   narl, _eau_, eben_, lcin_,
   {{0xd1308013,0x628ade48,0xed571a21,0x443f821e}},	//   سمة_, rifo, _кор_, _fau_,
   {{0x27e003c3,0x443fde49,0x7416815b,0x20548098}},	//   ncin_, _gau_, _خورا, ския,
   {{0x61fc3ee1,0x6440a26a,0x27e037f7,0x4426de4a}},	//   karl, _iami, icin_, mfo_,
   {{0x61fc5e4b,0xa3bd0bb8,0x443fa732,0x7c29de4c}},	//   jarl, _अरब_, _zau_, _zber,
   {{0x27edde4d,0x443fde4e,0x61fc5e4f,0xa2b7000d}},	//   bben_, _yau_, darl, ोगस्,
   {{0x4426de50,0x6440a0c5,0x443fc328,0x746b220b}},	//   nfo_, _jami, _xau_, тров_,
   {{0x7b642be0,0xec718158,0x6140b240,0x61fc20e5}},	//   отре, פֿט_, bálá, farl,
   {{0x28db1094,0x443f4873,0x6f0d141f,0x7d03026f}},	//   _मंदि, žu_, vrac, ánsk,
   {{0x60c400b9,0x7c3f022b,0x753c0140,0x6f0d5e51}},	//   fmim, _taqr, _nsrz, wrac,
   {{0x6440de52,0x6d4a9286,0x6f0d5e53,0x44295e54}},	//   _nami, _irfa, trac, _uba_,
   {{0x443f946a,0xd7f85e55,0x61fc5e56,0xdddc0301}},	// [4d10] _rau_, рус_, barl, _smrš,
   {{0x443fde57,0x7c2984c3,0x61fc22f8,0xe45f016d}},	//   _sau_, _sber, carl, ljö_,
   {{0x443fa761,0x6440c278,0x6f0d0046,0xf8b107d2}},	//   _pau_, _bami, srac, _فکر_,
   {{0x6f0d1122,0x29360158,0x6f02826f,0x443fb77f}},	//   prac, _פארן_, _ovoc, _qau_,
   {{0x6440de58,0x443fde59,0xa6db0125,0x91e58db4}},	//   _dami, _vau_, _orði, боле,
   {{0x443fde5a,0x200680ee,0x64428118,0xe80f02f1}},	//   _wau_, _adoi_, adoi, िलका_,
   {{0x443f946a,0x27ed8065,0xdd940196,0x65940f25}},	//   _tau_, tben_, _дары, _дару,
   {{0x6440de5b,0x26d15e5c,0x61fc5e5d,0x27edde5e}},	//   _gami, _hizo_, zarl, uben_,
   {{0x27edde5f,0xbb8580f7,0x7e63de60,0x6d4ade61}},	//   rben_, _الذي, _ponp, _arfa,
   {{0x6440bc6f,0x24895e62,0x7875826f,0x60c400d2}},	//   _zami, _amam_, _dáva, zmim,
   {{0x41b58b76,0x26d90207,0xe5a58037,0x26d15e63}},	//   _امار, _luso_, сини, _mizo_,
   {{0x25458029,0xf8bf0028,0x672f009a,0x26d10118}},	//   _vēl_, _nhé_, _opcj, _lizo_,
   {{0x6d4ade64,0x9f40807b,0xd7a70c28,0xfc3f0118}},	//   _erfa, _þið_, _कुलच, moíl_,
   {{0x7e7ade65,0x63bb804f,0x91e318d1,0x09e31628}},	//   chtp, _mzun, зоре, зорн,
   {{0x61fc5e66,0x7875826f,0x6a6b080a,0xa7fb01ca}},	//   rarl, _záva, _nüfu, _coño,
   {{0x26d95e67,0x61fc3c56,0xf8bf5e68,0x27e00300}},	//   _buso_, sarl, _ché_, ucin_,
   {{0x44f501ac,0x60c45e69,0x7bd6228a,0x2bc70054}},	// [4d20] eť_, rmim, _igyu, रेदा,
   {{0x61fc20d8,0xc7b283c8,0x3e76007b,0x27e000fc}},	//   qarl, לבן_, _bæta_, scin_,
   {{0x6440de6a,0xa3df04e5,0x63a904b7,0xa0a60110}},	//   _pami, दुक_, żent, _ганд,
   {{0x628e5e6b,0xf8bf00ff,0x26d94d93,0x78a98b80}},	//   libo, _ghé_, _fuso_, joev,
   {{0x8c1b02f6,0x28b500d4,0x38ba8168,0x26d1435e}},	//   רוני, ंतरि, jëra_, _fizo_,
   {{0x66e30098,0x63bba4a7,0xdee300ae,0x2cbfa050}},	//   _хора, _dzun, _хори, _ehud_,
   {{0x67245e6c,0x6440de6d,0xb5099521,0x2ee6de6e}},	//   ltij, _tami, _विषय_, _stof_,
   {{0x04968064,0x38601e92,0xe45f016d,0x628e5a1a}},	//   _الرح, njir_, xjö_, hibo,
   {{0x628e0033,0x1ddc01a2,0x421a830f,0x3f8000e1}},	//   kibo, _बलात, _مزاج_, nziu_,
   {{0xa3e4923a,0x626580f7,0x8c448087,0x1ed781a8}},	//   पुर_, _والق, ăşur, حبيب_,
   {{0xd7efde6f,0x67245e70,0x998c8858,0x628e1400}},	//   _ну_, htij, _hadž_, dibo,
   {{0x672449f7,0x7d0305e4,0xac1900e8,0x6aaa800b}},	//   ktij, ánsi, шому_, loff,
   {{0xa7fb01df,0x628e5e71,0x938b24dd,0x0b8b31ad}},	//   _soño, fibo, усна_, усни_,
   {{0x38668b3c,0x26d90333,0xb69b0087,0xe45f0106}},	//   _hoor_, _ruso_, _avân, sjö_,
   {{0x54e6806b,0x9f59079f,0x26d95e72,0x65939052}},	//   _استق, _gesê_, _suso_, _нашу,
   {{0x43954120,0x26d95e73,0x67245e74,0x7602801b}},	//   _майс, _puso_, ftij, bízí,
   {{0x9df92006,0x628e2cf7,0x3866de75,0x6aaac7ea}},	// [4d30] инат_, bibo, _moor_, koff,
   {{0x88bc81d0,0x2cad8937,0x7875936f,0x32f6866f}},	//   _zpět, _sked_, _návn, dły_,
   {{0xd5bb24b2,0x38740333,0xf8bf0036,0x6eff046d}},	//   уса_, ñará_, _thé_, _bàbá,
   {{0x3866de76,0x2a6582d5,0x6298998b,0x26d919b3}},	//   _noor_, _solb_, envo, _tuso_,
   {{0x44f535d5,0x7c2d32ef,0xe7840012,0x629a016b}},	//   sť_, _mbar, _еуро, čtov,
   {{0x60da88ae,0x6aaade77,0x7c2d01a1,0xf99002e3}},	//   _butm, goff, _lbar, _آبی_,
   {{0x32f6809a,0x7875816b,0x48798081,0x386690b0}},	//   ały_, _dávn, исия_, _boor_,
   {{0xd7098991,0x38668118,0x4f0995b7,0x61fa9384}},	//   ание_, _coor_, анин_, _eetl,
   {{0x3866de78,0x442dce82,0x63bb85b2,0x628e0518}},	//   _door_, _ibe_, _uzun, yibo,
   {{0x7c2d2249,0x6aaa89c4,0x7ae9de79,0x76455e7a}},	//   _abar, coff, _itet, ndhy,
   {{0x628e02d6,0x7ae98088,0x7c2d0362,0x2d810174}},	//   vibo, _htet, _bbar, nzhe_,
   {{0x386681b4,0x69d7112e,0x7f758012,0x6f0e85b2}},	//   _goor_, _agxe, _мулц, üncü,
   {{0x28df91bc,0x628e5e7b,0xc61100c8,0x442dde7c}},	//   _पंडि, tibo, স্যা_, _mbe_,
   {{0x7875816b,0x9c13019d,0x3e7b8036,0x27ff808b}},	//   _kávo, _nọfe, _bête_, laun_,
   {{0x628e5e7d,0x76439083,0xd9435e7e,0x442dde7f}},	//   ribo, _iany, мери, _obe_,
   {{0x7643de80,0x67245e81,0x4fea15d2,0x628e5e82}},	//   _hany, ttij, рман_, sibo,
   {{0x7643de83,0x442003d3,0x628e02c4,0x16660ea6}},	// [4d40] _kany, _ici_, pibo, овам,
   {{0x442dde84,0x3e7b80e7,0x6456022c,0x764384b9}},	//   _abe_, _fête_, _hnyi, _jany,
   {{0x67245e85,0x7643de86,0x7875803e,0xfe21864a}},	//   stij, _many, _návo, _मानस_,
   {{0x2bc70076,0x291800b4,0x61fade87,0x6143001b}},	//   रेवा, mura_, _setl, sílá,
   {{0x7d003240,0x6aaa94cf,0x29185e88,0x61fa8503}},	//   _bárá, toff, lura_, _petl,
   {{0x442d8a2c,0x7643b332,0xa6e2008b,0x71250061}},	//   _ebe_, _nany, áðun, _بریل,
   {{0x69c302ba,0x6f041d3f,0x291802a0,0x787c85db}},	//   _únet, lsic, nura_, _léve,
   {{0xb4d6023c,0x442d90ab,0x6444009c,0x61faca06}},	//   सदी_, _gbe_, _naii, _wetl,
   {{0x38669302,0x7643de89,0xf220023c,0x29180423}},	//   _voor_, _bany, _बाढ़_, hura_,
   {{0x29185e8a,0x64564b2b,0x60da8059,0x35af0740}},	//   kura_, _anyi, _tutm, _जुड़,
   {{0x7643de8b,0x2fc7001c,0x9f5900f1,0x29185e8c}},	//   _dany, ̀ng_, _pesë_, jura_,
   {{0x9c1301bc,0x629e074a,0x76439a1a,0x9f590176}},	//   _mọge, _ajpo, _eany, _fesè_,
   {{0x7643da30,0x7875801b,0xfbca8e88,0xa09b8039}},	//   _fany, _závo, िधिम, _דיאט,
   {{0x787c83d3,0x7643de8d,0x29185e8c,0x645622b2}},	//   _déve, _gany, fura_, _enyi,
   {{0x60c2de8e,0x29055e8f,0x867b8039,0x98ba0176}},	//   _khom, éla_, _דרגו, _espč_,
   {{0xda170b9f,0x29034af7,0x7c2d41ed,0x787584e8}},	//   _ताकत_, rsja_, _ubar, _návl,
   {{0xcddb0fbb,0x2fcf00f2,0x6d4e5e90,0x7643930e}},	// [4d50] ање_, ägg_, _arba, _yany,
   {{0x3e7b82be,0x29185e91,0x454b1d1f,0x69c806d4}},	//   _tête_, bura_, ичем_, ýdec,
   {{0x29184733,0x7ae9de92,0x7e670088,0x27f20338}},	//   cura_, _stet, _vojp, bbyn_,
   {{0x2b4dde93,0xe7870eef,0x6f040799,0x91fc8ec3}},	//   _prec_, _дуго, bsic, _glāz,
   {{0x09e5a150,0x6d4e5e94,0x44395b12,0x6f045e95}},	//   полн, _erba, ies_, csic,
   {{0x44394b9b,0x69c303a8,0x27e68114,0x60c2de96}},	//   hes_, _únes, _afon_, _ahom,
   {{0x6d4e007d,0xc27c0039,0x27ff9abb,0x649601d6}},	//   _grba, שרוי, taun_, lšie,
   {{0x44395e97,0x60c2b4ce,0x7643de98,0xd12e880b}},	//   jes_, _chom, _sany, امي_,
   {{0x60c2d174,0x76439452,0x7ae98010,0x9c1301bc}},	//   _dhom, _pany, _utet, _mọde,
   {{0x458585c2,0x2fd9015d,0x7875de99,0x787cbb09}},	//   згов, _lgsg_, _távo, _réve,
   {{0xc61100c8,0x7643de9a,0x04461052,0x27ffde9b}},	//   স্থা_, _vany, пенн, paun_,
   {{0x44394c6e,0x291800b4,0x7643d1c2,0x2245de9c}},	//   ges_, vura_, _wany, _halk_,
   {{0x7643de9d,0xf0928039,0xeb971bcf,0xb7da8039}},	//   _tany, _אנא_, зия_, _הקני,
   {{0x11da00f7,0x60c982d0,0xc6110264,0xa96a02df}},	//   صورة_, lmem, স্তা_, бига_,
   {{0x6601b21c,0xfaa32326,0x6d5c8074,0x6b82847f}},	//   malk, харо, ärat, zzog,
   {{0x44390806,0x83fd8065,0x44200699,0x29185e9e}},	//   ces_, _előz, _uci_, rura_,
   {{0x27fd8355,0x27f2031d,0x6d4e5e9f,0x60168457}},	// [4d60] _mewn_, rbyn_, _srba, lümü,
   {{0x29180886,0x6f040352,0x6601b135,0x44e1877f}},	//   pura_, rsic, nalk, _kó_,
   {{0x44e1dea0,0x6f045ea1,0x89db04de,0x6016807e}},	//   _jó_, ssic, _לחיי, nümü,
   {{0x44e1dea2,0x60c99b01,0x6d4e10d3,0xfe1e02f1}},	//   _mó_, jmem, _vrba, _पावस_,
   {{0x387f820f,0x44e18324,0x6601b4c9,0x61fe5ea3}},	//   dhur_, _ló_, kalk, _kepl,
   {{0x44395ea4,0x442081cd,0x63b60009,0x60c2c59a}},	//   zes_, żi_, _myyn, _shom,
   {{0x44e1dea5,0x44395ea6,0x6601daed,0x2245879f}},	//   _nó_, yes_, dalk, _dalk_,
   {{0x04439421,0x8c439b5a,0x787104d6,0x61fe5ea7}},	//   _песн, _песе, _påvi, _lepl,
   {{0x44390918,0x64960267,0x6601dea8,0x26dd810c}},	//   ves_, kšib, falk, _cuwo_,
   {{0x44e1c833,0x61468c0e,0x66018be6,0xd0918201}},	//   _bó_, _неза, galk, _müəl,
   {{0x44e1dea9,0x70f69c2c,0xb0db01ce,0x27fd831d}},	//   _có_, _رسائ, _मूंग, _fewn_,
   {{0x44e1deaa,0x44392c91,0xf3f98087,0x6fbe5eab}},	//   _dó_, ues_, _poţi_, ्धां,
   {{0x6601deac,0x61fe251d,0x76805bf6,0xfbad0264}},	//   balk, _bepl, _köyd, _গণহত,
   {{0x44e184be,0x61fe5ead,0xaa640c9b,0x442b0609}},	//   _fó_, _cepl, нтск, sfc_,
   {{0x61fe5eae,0x44391098,0x79a4075a,0xa5d782e3}},	//   _depl, pes_, ерте, _عبور_,
   {{0x76800009,0x7d1a80b4,0xf3f98087,0x443936fb}},	//   _löyd, muts, _toţi_, qes_,
   {{0xbed801cf,0x7d1adeaf,0x7af0016b,0x9f34021e}},	// [4d70] здух_, luts, čitý, неті,
   {{0x61fe0574,0xdcfc02bb,0xfbd00013,0x7aed5eb0}},	//   _gepl, _ayrı, _حتى_, _itat,
   {{0x947587d2,0x7d1a8314,0x06e380ab,0x38978162}},	//   وگرا, nuts, _মিছি, sări_,
   {{0x69da879f,0x254c801b,0x61e880ee,0x6a6f805f}},	//   _agte, _měl_, _afdl, _løft,
   {{0xfebb003d,0x7d1adeb1,0xdb1b8129,0x2245deb2}},	//   _هاست_, huts, _nguô, _palk_,
   {{0x7d1adeb3,0x7aed2b8c,0x66018df6,0x6016a353}},	//   kuts, _mtat, xalk, yümü,
   {{0x6601deb4,0xa3b4000d,0x7d1ac913,0xc61906b7}},	//   valk, _जुन_, juts, दलीय_,
   {{0x443987e2,0x44e1deaa,0x69da879f,0x31580039}},	//   _ús_, _ró_, _egte, ליון_,
   {{0x44e1deb5,0x60c9deb6,0x7bc083a8,0xa7fb0144}},	//   _só_, rmem, _gzmu, _coñi,
   {{0x44e1deb7,0x387f820f,0x649602a5,0x2caf80f3}},	//   _pó_, shur_, kšic, logd_,
   {{0xdca60a94,0x61fe5eb8,0xd9998013,0x7aed5eb9}},	//   дани, _repl, _بنات_, _atat,
   {{0x69c1deba,0x6601debb,0x61fe5ebc,0x7afb819d}},	//   _izle, salk, _sepl, _kwut,
   {{0xf745bd2f,0x660180f4,0x44e18324,0x61fe02d6}},	//   _цело, palk, _wó_, _pepl,
   {{0x44e18324,0x7d1a82a0,0x201f8722,0x68fb00ce}},	//   _tó_, buts, lgui_, ćudn,
   {{0x7aed5ebd,0x2d948098,0x6729ce13,0x629c048d}},	//   _etat, _пръс, ltej, rnro,
   {{0x201fdebe,0x63a40102,0x7bdb8c2e,0xb90606a7}},	//   ngui_, _txin, _nguu, _पढ_,
   {{0xe4c71125,0x61fe027f,0x6729debf,0x258280e7}},	// [4d80] _تصوی, _tepl, ntej, _télé_,
   {{0x80be0996,0x78a90353,0xaae18105,0xee3710ef}},	//   _वीरे, čeva, _पढ़क, мну_,
   {{0x787caff3,0xa01b12d2,0xa06a04ae,0xf41f016d}},	//   _léva, _blöd, _дана_, miär_,
   {{0xf4878077,0x7875826f,0x6e3adec0,0xe81986af}},	//   وانی, _dávk, zetb, _धागा_,
   {{0x69c1bd11,0x76488114,0x63be8035,0xd0418300}},	//   _azle, yddy, ępno, _hulɗ,
   {{0x9c140133,0x3b06a0d8,0x9f400b24,0x7bdb85ee}},	//   _kọst, rsoq_, ncií_, _eguu,
   {{0x28c30063,0xa01b0106,0x7afbaa34,0x26d84a7c}},	//   _वीडि, _flöd, _ewut, _iiro_,
   {{0xa3ae03b7,0x807b00be,0xa7fb0118,0x7d1a8314}},	//   कथा_, ַניצ, _poñi, vuts,
   {{0x3f84825b,0x26d81588,0xe29aa8ff,0x9f4000e1}},	//   uzmu_, _kiro_, _даа_, kcií_,
   {{0x443256a2,0x7d1ab10a,0x44248028,0x26d80079}},	//   _aby_, tuts, _hcm_, _jiro_,
   {{0x7aed5ec1,0xb80e235e,0xc58a8009,0xeae680ab}},	//   _stat, िणाम_, ющие_, _নিয়ম,
   {{0x7d1adec2,0x7ae0dec3,0x291c805d,0xa7fb0118}},	//   ruts, _kumt, muva_, _toñi,
   {{0x4424dec4,0xc0a9936d,0x291cdec5,0x7ae081a9}},	//   _mcm_, _عامل_, luva_, _jumt,
   {{0x44320c56,0x78ada98e,0x7c245ec6,0x7d1adec7}},	//   _eby_, čave, _ecir, puts,
   {{0x7ae080f1,0x4432008e,0x4c950cec,0x8637807c}},	//   _lumt, _fby_, _пикс, _חרוב_,
   {{0x030e80cf,0x78780061,0xd5f40129,0x64a40115}},	//   _सिंह_, _hívj, _đán, rđic,
   {{0x26d85869,0x7c3d0359,0x7ae0b516,0x7aed004f}},	// [4d90] _biro_, mesr, _numt, _utat,
   {{0x2004dec8,0xd5bb5ec9,0x291cb9d3,0x752f8035}},	//   hami_, осе_, kuva_, ńcze,
   {{0x60c901b9,0x25b8010c,0x26d801b4,0xe3b00fd3}},	//   ċemb, _cyrl_, _diro_, _مری_,
   {{0x2004deca,0x4424decb,0x26d800eb,0x6f160035}},	//   jami_, _ccm_, _eiro_, bryc,
   {{0x2004decc,0x60cd5ecd,0xf8b20e82,0xfdbb864a}},	//   dami_, mmam, _תשכ_, _उर्फ,
   {{0x26d80ab3,0x60cd1d84,0x65954430,0x4424dece}},	//   _giro_, lmam, _загу, _ecm_,
   {{0x6605178f,0x4424decf,0x63ba0035,0x08d5847f}},	//   mahk, _fcm_, ętni, нция,
   {{0x409493cd,0x660513b8,0x27e95ed0,0x29078b67}},	//   крыт, lahk, ncan_, rsna_,
   {{0x290780f2,0x645bded1,0x6d5a1a98,0xb9068128}},	//   ssna_, _inui, _àtar, _यू_,
   {{0x443da3b3,0xef82a187,0x44320e6d,0x6729dd46}},	//   lew_, ульп, _sby_, rtej,
   {{0x20048933,0x6729ded2,0x50678ada,0x291c8b80}},	//   bami_, stej, _отда, cuva_,
   {{0x2004dac0,0x443daa82,0x7c3d016d,0x6729ded3}},	//   cami_, new_, gesr, ptej,
   {{0x68e1ded4,0x6605010b,0x394589d1,0xa3e480d4}},	//   _huld, kahk, _hsls_, पुट_,
   {{0xddc3802e,0x68e1ded5,0xe5a5be32,0x660509ca}},	//   _conţ, _kuld, _пили, jahk,
   {{0x205616d4,0x26d80032,0x66053932,0x19b900e8}},	//   нтар, _riro_, dahk, дуть_,
   {{0x6f164afc,0x60cd02b8,0x26d85ed6,0xa01b016d}},	//   tryc, gmam, _siro_, _smör,
   {{0x6f09b928,0x91e60ca0,0x26d85ed7,0x443dded8}},	// [4da0] nsec, _попе, _piro_, dew_,
   {{0x2004ded9,0x68e18176,0x98c0080a,0x7a338457}},	//   zami_, _ould, ırır_, nıtı,
   {{0xe820816f,0x2004deda,0x2480074c,0x2c7ec9d6}},	//   _याला_, yami_, _klim_, _aïda_,
   {{0x27e95edb,0x644983a8,0x44220d3a,0xc4868a14}},	//   ccan_, _caei, ngk_, элек,
   {{0x26d85edc,0x66051eea,0x26c7826c,0x2004a356}},	//   _tiro_, bahk, _ohno_, vami_,
   {{0x2004d27c,0x291c9608,0x6605010b,0x68e1dedd}},	//   wami_, tuva_, cahk, _buld,
   {{0xa3d01c21,0x7875826f,0x2004dede,0x46a30048}},	//   वेत_, _závi, tami_, _сарв,
   {{0x64498307,0x2002519a,0x291c8338,0x2b448338}},	//   _gaei, _jeki_, ruva_, _tsmc_,
   {{0x2004dedf,0x9f405ee0,0x03a3a017,0x7d1e03ba}},	//   rami_, ncià_, _бито, lups,
   {{0x68e1813c,0x6462dee1,0x27e91b63,0x24805ee2}},	//   _fuld, štič, zcan_, _alim_,
   {{0x27e902bf,0x68e1b842,0x6d418114,0x04b80019}},	//   ycan_, _guld, gwla, کھوں_,
   {{0x7c22a137,0x66050359,0x6295009a,0x69de0362}},	//   ngor, zahk, wizo, _agpe,
   {{0x9f499ca8,0x2918016a,0x66050359,0x7c3d5ee3}},	//   _það_, erra_, yahk, resr,
   {{0x56949285,0x7bc42392,0x443ddee4,0x64960084}},	//   _шалт, _dziu, zew_, ršia,
   {{0xc17712c8,0x3e76007b,0x60cd5ee5,0x64960b80}},	//   ردست, _gæti_, tmam, mšin,
   {{0x629526b4,0x660500dd,0x2002274a,0x60cd5ee6}},	//   sizo, wahk, _ceki_, umam,
   {{0x60cd5ee7,0x7c228da8,0xa3d00b9f,0x66050590}},	// [4db0] rmam, dgor, वेद_, tahk,
   {{0x27e95ee8,0x06b7026a,0x644980eb,0x2480017f}},	//   scan_, رناک_, _saei, _zlim_,
   {{0x98738012,0x66050867,0xa3d384e5,0xddc380e1}},	//   nţă_, rahk, हेन_, _konš,
   {{0x66050057,0x7c22b090,0x6ac98da0,0x25f101ab}},	//   sahk, ggor, िग्र, ेरही_,
   {{0x6283831d,0x290c91b9,0x68e1dee9,0xbb45a639}},	//   thno, _avda_, _suld, телк,
   {{0x660500b9,0x672d5eea,0x38695203,0x7c228cdb}},	//   qahk, mtaj, ljar_, agor,
   {{0x672d5eeb,0x443d84b7,0x6f098bfd,0xecbba3e0}},	//   ltaj, pew_, wsec, _فطرت_,
   {{0xfd658104,0x38693c3f,0x6f09de33,0x787c80e7}},	//   _thuậ, njar_, tsec, _dévo,
   {{0x672d5eec,0x3e76007b,0xfc3f016b,0x66158061}},	//   ntaj, _sæti_, deí_, ózko,
   {{0x68e1bb06,0x78bbdeed,0x63bbdeee,0x672d5eef}},	//   _tuld, sluv, _iyun, itaj,
   {{0x6281def0,0xe5a59a3b,0x63bb90e4,0x3207ca38}},	//   _illo, тини, _hyun, many_,
   {{0xeb9a134e,0x63bb8708,0x6d55026c,0x38695ef1}},	//   дим_, _kyun, _mrza, jjar_,
   {{0xc4d28158,0x28db058c,0xdb0b077f,0x6d4e919b}},	//   יגט_, _मंजि, _ènìy, åbar,
   {{0x3ce20076,0x6d5504c3,0x63bb8681,0x09d580ab}},	//   _ओढले_, _orza, _myun, _স্যা,
   {{0x2b918028,0x99878110,0x200202d0,0x11390a14}},	//   ạch_, menų_, _peki_, няты_,
   {{0x63bb8459,0x66038364,0xbb8600f7,0x43b3082e}},	//   _oyun, _henk, _للبي, ụrụ_,
   {{0xb8e9023c,0x6281def2,0x6d470006,0x63bbdef3}},	// [4dc0] _ली_, _ollo, _asja, _nyun,
   {{0x32078690,0x6d550bcf,0x6603def4,0xe8e000ff}},	//   jany_, _brza, _jenk, _chợt_,
   {{0x63a9862f,0x63bbdef5,0x6603990d,0x3207809a}},	//   _axen, _ayun, _menk, dany_,
   {{0x6d550025,0x74138064,0x7ae4348c,0x6603def6}},	//   _drza, لوما, _kuit, _lenk,
   {{0x4fa300e8,0x628180f1,0x38ba8168,0x7d1e4a7c}},	//   _вияв, _bllo, qëri_, sups,
   {{0x7ae45ef7,0xc7b30051,0x6603def8,0x4ed51be4}},	//   _muit, _כבר_, _nenk, _бюст,
   {{0x09d58a49,0x81b400c8,0x30a69957,0x63a985e4}},	//   _স্বা, জের_, крив, _exen,
   {{0x628186a5,0xd01080f7,0xe8df819d,0x237183ed}},	//   _ello, حلة_, _gbọm_, ënjë_,
   {{0xf093078d,0x1ae6835f,0xa2e6835f,0x6603def9}},	//   ינה_, _розм, _розд, _benk,
   {{0x78ad8025,0x6603defa,0xb0618009,0x787826ca}},	//   čava, _cenk, _ääne, _dívi,
   {{0x6603a1c9,0xfe6f80f7,0xf76f8077,0x7e7adefb}},	//   _denk, تدي_, مای_, rktp,
   {{0x7ae40ee8,0x6298d9c6,0x2486defc,0x7d0303a7}},	//   _buit, livo, nhom_, ânsi,
   {{0x6603aed5,0x64965efd,0x7ae45efe,0x6d5e80c3}},	//   _fenk, pšin, _cuit, _špad,
   {{0x7ae405f8,0x261c8074,0x6298d6f9,0x66038646}},	//   _duit, _माटी_, nivo, _genk,
   {{0x38695eff,0xfce38eef,0x6608df00,0x7ae40362}},	//   tjar_, _којо, madk, _euit,
   {{0x70bf05b3,0x672d0364,0x6603df01,0x6608df02}},	//   ्षेल, ttaj, _zenk, ladk,
   {{0x44295f03,0x3d050076,0x38693117,0xd9048065}},	// [4dd0] _ica_, हीने_, rjar_, _ڈی_,
   {{0xd9049125,0xd04b8201,0x66088079,0x644d0cda}},	//   _وی_, _digə, nadk, _haai,
   {{0x3207816b,0xf1ab003d,0xdc4301d0,0x442902df}},	//   vany_, _زاده_, _léčb, _kca_,
   {{0x32078063,0x261c835a,0x5f13800f,0x660895e8}},	//   wany_, _माझी_, _दिल्_, hadk,
   {{0x644d18c5,0x3207ca38,0x09cb853f,0x4429323e}},	//   _maai, tany_, ाध्य, _mca_,
   {{0x26dcdf04,0x6e951c60,0x62988358,0x2009067f}},	//   _nivo_, _сигу, givo, laai_,
   {{0x56940e9f,0x32078e04,0x60dd1380,0x6603df05}},	//   _тарт, rany_, _kism, _renk,
   {{0x44295f06,0x60dd02a6,0x6603906f,0x248685b9}},	//   _nca_, _jism, _senk, chom_,
   {{0x60dd5f07,0x660387ac,0x99bf00ab,0x32078690}},	//   _mism, _penk, _আলোক, pany_,
   {{0x6281802a,0x44290014,0x7ae414cc,0x66038168}},	//   _ullo, _aca_, _ruit, _qenk,
   {{0x44295f08,0x7c298042,0x6603df09,0x7ae45f0a}},	//   _bca_, _kcer, _venk, _suit,
   {{0x09d580c8,0x4429070d,0x6f0d042b,0x6603df0b}},	//   _স্থা, _cca_, ksac, _wenk,
   {{0xe7398012,0x660386cf,0xaca38135,0x6608ce5e}},	//   _чел_, _tenk, _abịa, badk,
   {{0x81bf00ab,0x7ae42cdc,0x1e848221,0xbf9a83c8}},	//   েশন_, _vuit, _клім, _אינש,
   {{0x63be809a,0xb606026f,0x32058019,0x64860118}},	//   ępni, ntáž, _mely_, _póid,
   {{0x27eddf0c,0x7ae44869,0x26dc8042,0x60dd5f0d}},	//   ncen_, _tuit, _zivo_, _cism,
   {{0x6d5ec372,0x9b460199,0xa3d05f0e,0x60dd1ac5}},	// [4de0] _àpar, _صندو, वेश_, _dism,
   {{0x7c29ac70,0x628719cc,0x60dd0084,0xe1fa0a8e}},	//   _acer, chjo, _eism, _яго_,
   {{0x2486df0f,0x672082ce,0x6f0d0c41,0x29560098}},	//   thom_, zumj, asac, _съпр,
   {{0x7c265f10,0x7641df11,0xac2580e8,0x236681c0}},	//   ngkr, hely, ифік, txoj_,
   {{0x62989313,0xe29aa4c1,0x68e55f12,0x2486df13}},	//   tivo, над_, _zuhd, rhom_,
   {{0x851c0076,0x55e3179e,0x7c2981bf,0x6f1bdf14}},	//   _पटपट_, _горб, _ecer, druc,
   {{0x7641df15,0x649601a1,0x78ad82d4,0x6608df16}},	//   dely, tšil, čavn, vadk,
   {{0x764e313e,0x6298df17,0x3f149ae2,0x7521bdf7}},	//   _haby, sivo, адис, dulz,
   {{0x764e5f18,0x44268bb1,0x27e20b50,0xb606d0e2}},	//   _kaby, mgo_, _mgkn_, лянк,
   {{0x4426df19,0x7641df1a,0x225e89ca,0x644281a8}},	//   lgo_, gely, _untk_, leoi,
   {{0x649652d8,0x05ce816f,0x66088079,0x644d5f1b}},	//   mšij, हेंब, radk, _paai,
   {{0x4426dbf0,0x69c8df1c,0x6f1bbdca,0x27ed84b9}},	//   ngo_, _izde, bruc, ccen_,
   {{0x24995f1d,0x6608df1e,0x4426df1f,0x6f1bb928}},	//   rism_, padk, igo_, cruc,
   {{0x764e5f20,0x60dd5f21,0x24995f22,0x68e50198}},	//   _naby, _sism, sism_, _puhd,
   {{0xd918176e,0x648600f7,0x4429297d,0x02e1800d}},	//   льт_, _dóib, _tca_, _पढ्न,
   {{0x60dd011c,0x6f029415,0xa3e906b7,0x6d4adef0}},	//   _qism, _kwoc, _बलि_, _isfa,
   {{0x6d588a20,0x764e313c,0x64428013,0x60dd00eb}},	// [4df0] _hrva, _baby, deoi, _vism,
   {{0x4426df23,0x81b400ab,0x6f0d5f24,0x7c29ae31}},	//   ego_, জেই_, rsac, _scer,
   {{0x60dd5f25,0x3e76008b,0x62855f26,0x290c1bff}},	//   _tism, _rætt_, _ilho, ádat_,
   {{0x4426df27,0x6442c544,0x6f0d0362,0x6f028035}},	//   ggo_, geoi, psac, _owoc,
   {{0xd5af0117,0xae1e03eb,0x442981a9,0x768002d0}},	//   _کہا_, _पाचन_, ļa_, _köyl,
   {{0x4426df28,0x4429df29,0x7875803e,0x657a81e0}},	//   ago_, ża_, _návr, kyth,
   {{0x7641df2a,0xfa7801c6,0x201982df,0x272f2353}},	//   vely, רעות_, ósio_, lün_,
   {{0x6f1b9883,0x69d5803e,0x69c8009a,0x76418114}},	//   truc, _územ, żdeg, wely,
   {{0x6d58870a,0x272f0182,0x8fa59052,0x62855f2b}},	//   _arva, nün_, рапе, _olho,
   {{0x6f1bcdd9,0x9c1301bc,0xbb8480f7,0x78a45f2c}},	//   rruc, _dọme, _الكي, zniv,
   {{0x6d588267,0x2ca90609,0x81eb0264,0x38ba83ed}},	//   _crva, _bjad_, মরা_, tërt_,
   {{0x752f809a,0x6285589b,0x673d3409,0x6f1b81ec}},	//   ńczo, _alho, _opsj, pruc,
   {{0x6d589afa,0xa3d001b6,0x386d920e,0x768007d9}},	//   _erva, वें_, mjer_, _böyl,
   {{0x386d8e23,0x4426a271,0x471a80be,0x660701d0}},	//   ljer_, zgo_, _יונג, _nejk,
   {{0xaca4019d,0x628501ac,0x3d0503b7,0xd94618a2}},	//   _agụi, _dlho, _हौले_, шеви,
   {{0xe0df0098,0x386db59d,0x661502f7,0x7d568039}},	//   _ciò_, njer_, _adzk, _כיצד_,
   {{0x753c0d38,0x272f05c5,0x387f81fa,0xe3b80085}},	// [4e00] _sprz, gün_, ikur_, şıb_,
   {{0x98481010,0x290c01a8,0x764e01b4,0xed5a0fbf}},	//   rşı_, ádas_, _qaby, коз_,
   {{0x387f807b,0x644280f7,0x386ddf2d,0x920281a9}},	//   kkur_, teoi, kjer_, šāka,
   {{0xf5368158,0x629c5f2e,0x386d81b9,0xe058004e}},	//   יטער_, liro, jjer_, _حیرت_,
   {{0x644280f7,0x386d8582,0x9c13019d,0x764e5f2f}},	//   reoi, djer_, _bọje, _taby,
   {{0x4426df30,0x291c8d11,0x644281a8,0x8b5700be}},	//   sgo_, trva_, seoi, יינס_,
   {{0xe5a32995,0xddc708ae,0x7bc98326,0x64a401a1}},	//   _дири, _tojš, _ezeu, rđij,
   {{0x629c4877,0x69c8886f,0x9f4f81ca,0x64a6816c}},	//   hiro, _vzde, _negó_, _таба,
   {{0xe666bba1,0x629c12e5,0x657a8114,0x087703de}},	//   атно, kiro, wyth, שעפט_,
   {{0x6d58a3c3,0x629c0326,0x291c811f,0x8f370538}},	//   _prva, jiro, prva_, סטיג_,
   {{0xd7ef8abe,0x629c5f31,0x69c8a585,0x6996854c}},	//   _му_, diro, _uzde, _трах,
   {{0x768002bb,0x629c1d64,0xb17b8158,0xc19b8039}},	//   _söyl, eiro, _שטאר, _בשבי,
   {{0x6d5a011f,0x68e8bd81,0x6285022c,0x395a09c4}},	//   _štal, _hudd, _plho, _arps_,
   {{0x6d588efc,0x68e8df32,0x629c5f33,0x8af00085}},	//   _trva, _kudd, giro, _irəl,
   {{0x6d58be43,0xf80724dd,0xfc3f0333,0xdd938084}},	//   _urva, ичан, anía_, _машы,
   {{0x272f0a0b,0x68e8df34,0x63ad0102,0x673d09c4}},	//   tün_, _mudd, _txan, _ppsj,
   {{0x7c2d5f35,0x68e8aab7,0x660701f4,0x35e70bc7}},	// [4e10] _icar, _ludd, _pejk, ацев,
   {{0xbebd9c3a,0x629c1727,0xc61f00ab,0x387f8196}},	//   ltūr, ciro, ন্না_, zkur_,
   {{0x2ca6831d,0x9c1301bc,0xab6282d0,0x6d5a0061}},	//   fnod_, _nọke, _şüph, _átal,
   {{0xdd868986,0xbebd8df1,0xa5d980be,0x940b0085}},	//   _ہو_, ntūr, אַני, ticə_,
   {{0x7bc0831d,0xb4c78105,0x64860187,0xbd05826b}},	//   _cymu, _उठी_, _jóia, _atẹ́,
   {{0xa2298b79,0x1df80e11,0x7bc08114,0x8e8501a8}},	//   ужка_, _веры_, _dymu, _السه,
   {{0xbebd8df1,0x68e8df36,0x3cf001d6,0x3a2c9df1}},	//   ktūr, _cudd, ľové_, _dcdp_,
   {{0x629c003a,0x68e8a221,0x3cf0016b,0xbca5c084}},	//   ziro, _dudd, žové_, _امري,
   {{0x387fdf37,0x7bc08114,0x7c3bab1c,0x6a7d86c0}},	//   rkur_, _gymu, _ibur, _lèfi,
   {{0xe1f0c29b,0xba748307,0x7c2d01f1,0x629c5f38}},	//   _قسم_, _والت, _acar, xiro,
   {{0x629c5f39,0x68e882a3,0xa3d3816f,0x443b4799}},	//   viro, _gudd, हेर_, _bbq_,
   {{0x7ae1df3a,0xb4e7800d,0x64a602fb,0x629c5f3b}},	//   _hilt, _बढी_, сама, wiro,
   {{0x7ae1df3c,0x629c5f3d,0x7c3bdf3e,0x27ffb5a3}},	//   _kilt, tiro, _mbur, mbun_,
   {{0x6d5a2997,0x412a11d2,0x787c83e6,0x26d981d0}},	//   _štam, лого_, _révi, ůsob_,
   {{0x7c3bdf3f,0x7ae98009,0xada29ca4,0x68e88df6}},	//   _obur, _luet, _нашл, _xudd,
   {{0x442d8069,0x629c0110,0x27ffdf40,0x6a7d823e}},	//   _nce_, siro, nbun_, _dèfi,
   {{0xee3a0abe,0xa01b00f2,0x7ae98144,0x64465f41}},	// [4e20] лна_, _glöm, _nuet, meki,
   {{0x64465f42,0x5986028b,0x5d6a08b0,0xcf2500f7}},	//   leki, _глоб, лизм_, ترفي,
   {{0x7bc0831d,0xa3dadf43,0x09d60264,0xd9f88327}},	//   _symu, डेन_, _ত্রা, ुरसत_,
   {{0xa507272b,0x64464c58,0x1d072109,0x186a47cb}},	//   сеца_, neki, сеци_, _сами_,
   {{0x7ae1df44,0x7d1e02a5,0x205704de,0x7ae98144}},	//   _bilt, srps, _היכל_, _cuet,
   {{0x60c45f45,0x46160117,0x7c3b8133,0xdd20001b}},	//   llim, _دوسر, _ebur, může,
   {{0x5d860013,0x68e884b7,0x7ae183ed,0x7ae98580}},	//   _الأل, _qudd, _dilt, _euet,
   {{0x6d5c452c,0x60c45f46,0x6d4e5f47,0x69c18114}},	//   _irra, nlim, _isba, _dyle,
   {{0xd6daa159,0x69c18214,0x661cdf48,0xa01b0106}},	//   лто_, _eyle, órko, _blöj,
   {{0x7c2d2ed2,0x273090ab,0x7ae1df49,0x60c40a48}},	//   _scar, ràn_, _gilt, hlim,
   {{0xe72f8bca,0xb6bb0158,0x245f0009,0x6d5a1b46}},	//   وصی_, רציי, _nämä_, _štaj,
   {{0x320e8101,0x69c10214,0x60c4026c,0x996481d0}},	//   lafy_, ülem, jlim, _kůže_,
   {{0x7c2d0370,0x27e6b79b,0x7ae98473,0xdc9b81c6}},	//   _vcar, _igon_, _xuet, ריכל,
   {{0x9964800d,0xa3da8b9f,0x442d0035,0x6d5c5f4a}},	//   _může_, डेय_, że_, _orra,
   {{0x7e7509a4,0x6446013d,0x9f490174,0x29df822b}},	//   _rozp, beki, rcaí_, _għaċ_,
   {{0xc4c4850c,0x60c45f4b,0x64a40dc7,0xb4c78105}},	//   _سے_, glim, _наја, _उठे_,
   {{0x29110065,0x6d5c28bc,0xe7301921,0x6e99196f}},	// [4e30] ssza_, _arra, فصل_, авар_,
   {{0x443910f4,0xf7700829,0x7bcd01a9,0x29110035}},	//   lfs_, راق_, _izau, psza_,
   {{0x44391393,0x7e750144,0x7ae9df4c,0x24890123}},	//   ofs_, _vozp, _suet, _klam_,
   {{0x7ae190c0,0x27e6801c,0x7afd1699,0xccf380be}},	//   _silt, _ngon_, opst, לכע_,
   {{0x6d5c5f4d,0x7ae18074,0xa3d38740,0x6d4e503d}},	//   _erra, _pilt, हें_, _esba,
   {{0x64465f4e,0x27e6828c,0xd9fb170c,0x09d28264}},	//   zeki, _agon_, ्रित_, াশনা,
   {{0x68e2df4f,0x442ddf50,0xdcf581a9,0xaefb0362}},	//   _biod, _tce_, ēcīg, _brùg,
   {{0xef19895a,0x7c3b8578,0x2eb3816f,0x69c1826f}},	//   ами_, _ubur, ुत्त, _vyle,
   {{0x7ae18e51,0x68e2df51,0x7c2480f7,0x200b0087}},	//   _tilt, _diod, óire, _meci_,
   {{0x248956a6,0xee3697d4,0x27e6811e,0x273b0087}},	//   _alam_, онь_, _egon_, mână_,
   {{0x2b400118,0x68e28229,0x24895f52,0x660a80c3}},	//   _spic_, _fiod, _blam_, _defk,
   {{0x2d8b8063,0x7c2b923c,0xf9928039,0x6d5a00ce}},	//   ące_, nggr, _קרא_, _štak,
   {{0xe60e8fbb,0x64463f57,0x2d839491,0x24895f53}},	//   _од_, reki, šje_, _dlam_,
   {{0xf8bf59a9,0x64465f54,0x78bb801b,0xc61f00ab}},	//   _aké_, seki, louv, ন্তা_,
   {{0x38c804c0,0x7bcd0102,0x24890580,0x7f5d0706}},	//   ماری_, _ezau, _flam_, _arsq,
   {{0x200b5f55,0x78bba6f2,0x53a600e8,0x2247cc81}},	//   _ceci_, nouv, _майб, henk_,
   {{0x60c40ad4,0x200b5f56,0xe1ff801c,0x26c5a203}},	// [4e40] rlim, _deci_, _đón_, ollo_,
   {{0x245f0364,0x26c583a8,0xd62601a8,0x66cf804a}},	//   _tämä_, nllo_, تعري, bøke,
   {{0x37e60adb,0x60c45f57,0x26c5df58,0x78bb86c0}},	//   _монг, plim, illo_, kouv,
   {{0x629a82f7,0xb922819d,0x67df0196,0x6abc286f}},	//   _smto, akpọ_, _sąjū, lorf,
   {{0x2cad9351,0x69c583e3,0xaefb0362,0x926aa041}},	//   _djed_, ühen, _crùd, ирка_,
   {{0x27345f59,0x200b0087,0xdce981d0,0xaefb0706}},	//   män_, _zeci_, íněn, _drùd,
   {{0x6d5c2837,0x27340198,0x660a826c,0x6d4e5f5a}},	//   _urra, län_, _refk, _usba,
   {{0xa7749878,0xb97b00be,0xdd8f045b,0x26c5991f}},	//   злич, ינצי, _شوق_, ello_,
   {{0x920a05e8,0xeeaa80e8,0x660a8bda,0x7bc40573}},	//   वराज_, иток_, _pefk, _nyiu,
   {{0x6283a651,0xd6d08875,0xe29781ae,0x69c12181}},	//   ckno, عقد_, _дау_, ülek,
   {{0x2734025d,0x24895f5b,0xceb30158,0x994a8013}},	//   hän_, _plam_, ויז_, _خلال_,
   {{0x66e685da,0x78bb83d3,0xe3b80182,0xe78690ac}},	//   _дода, couv, ğın_, _муло,
   {{0x200b0025,0xe3b8017b,0x27340009,0x443910c9}},	//   _reci_, şın_, jän_, rfs_,
   {{0x27340364,0x9f590081,0xaaca801b,0x7afd3e67}},	//   dän_, _gesù_, ितिक, rpst,
   {{0x7648df5c,0x31c41e4e,0x7cf304b7,0xfc3f01d0}},	//   medy, дств, _oħra, lním_,
   {{0x7648df5d,0x24890cef,0x7afd2130,0xda78816b}},	//   ledy, _ulam_, ppst, _loď_,
   {{0x200b01ac,0x66cf804a,0x41e70a4c,0xaaca81d0}},	// [4e50] _veci_, søke, _міна, िताक,
   {{0x764882e7,0x2cbf85b1,0x78ad8904,0xadc3826b}},	//   nedy, _skud_, čavi, _afẹh,
   {{0x2ee300f3,0x92b400f7,0x7aed563c,0xea0000ff}},	//   _vijf_, _تحيا, _huat, _hiếu_,
   {{0xa3c41995,0xe3b382e3,0x7aed5f5e,0x6ac39a4d}},	//   _्रम_, ورش_, _kuat, षत्र,
   {{0x395edf5f,0x76489acd,0xdb078380,0xeab01e5c}},	//   _arts_, kedy, _ömür, _سعی_,
   {{0x09df0a49,0xe1f18bca,0x7aed1295,0xfc3f001b}},	//   _ব্যা, رست_, _muat, dním_,
   {{0x7aed04bc,0x91e2df60,0x320c82f7,0x6283bb11}},	//   _luat, ноше, _dedy_, rkno,
   {{0x7ae50006,0x7aed5f61,0x6283df62,0x2cad8b80}},	//   _liht, _ouat, skno, _ujed_,
   {{0x443fdf63,0x3211003e,0x78a9bdac,0x600687ac}},	//   _ibu_, kazy_, rnev, чным_,
   {{0x7655003e,0x7afb876d,0x78a9a5cc,0x6eed81d6}},	//   _jazy, _itut, snev, _hĺbk,
   {{0x69c50082,0xc8ab8098,0x648601a8,0x26c5802a}},	//   _nyhe, _къде_, _fóil, rllo_,
   {{0x7aed497d,0x3f4d37bc,0xc86495a6,0xfc3f01d0}},	//   _buat, _ožu_, _отчи, bním_,
   {{0x7aed0c15,0x443f8f59,0x6abc5f64,0x69c7806a}},	//   _cuat, _mbu_, torf, _øjeb,
   {{0x27345f59,0xddc881a9,0x76550035,0x7afb8c93}},	//   vän_, ņoša, _nazy, _mtut,
   {{0x443fdf65,0x186a1445,0xd13200f7,0xa06a0e17}},	//   _obu_, бави_, عمر_, бава_,
   {{0x386602ba,0x4fea174a,0x67360009,0x7aed5f66}},	//   ñor_, сман_, ttyj, _fuat,
   {{0xe61a229c,0x6abc03a7,0x44320314,0x1e860196}},	// [4e60] йда_, porf, _icy_, плам,
   {{0x443fdf67,0x8cc40035,0x7ae501f4,0x27345f68}},	//   _abu_, रतको, _giht, rän_,
   {{0x7afb9192,0x64562b75,0x27340198,0x3f8603f2}},	//   _atut, _kayi, sän_, šou_,
   {{0x443f89da,0x66e614f6,0xdee61229,0x2b5fdf69}},	//   _cbu_, _нома, _номи, _bruc_,
   {{0x64562b75,0x648600f7,0x201236a0,0x6f630110}},	//   _mayi, _nóim, mayi_, _звяз,
   {{0x443fdf6a,0x64560201,0x6d43d903,0xfc3f001b}},	//   _ebu_, _layi, _opna, vním_,
   {{0x15430049,0x7afbdf6b,0x9d430dc0,0xd90d815b}},	//   _перм, _etut, _перд, لیل_,
   {{0x20123640,0x443fa3c5,0xfc3f01d0,0x64561eda}},	//   nayi_, _gbu_, tním_, _nayi,
   {{0x320c801b,0x7e788353,0x67245f6c,0x629e09b6}},	//   _tedy_, _povp, nrij, _ompo,
   {{0x2486df6d,0x660e0029,0x46be001b,0x9f970039}},	//   lkom_, _jebk, ्तिह, פדיה_,
   {{0x67240613,0x7aed0867,0x64563adc,0x6b82ab76}},	//   hrij, _suat, _bayi, lyog,
   {{0x68e6003e,0x3866802e,0x629e1ed6,0x7ae51ea9}},	//   _nikd, _unor_, _ampo, _siht,
   {{0x7aed5f6e,0x787c82be,0x7648de2e,0x6b829f37}},	//   _quat, _févr, pedy, nyog,
   {{0x67240613,0xdfa58013,0xdee381a1,0x34a98105}},	//   drij, _تحمي, _зочи, _कद्द,
   {{0xe63b8039,0xfc3f00e1,0x291e2365,0x321109a4}},	//   _התוכ, nník_, štan_, razy_,
   {{0x629e5f6f,0x7aed0014,0x24868024,0x3ebe8019}},	//   _empo, _tuat, jkom_, lott_,
   {{0x67245f70,0xa2b51957,0x98a7812b,0xe8d78039}},	// [4e70] grij, _обич, šiću_, לולר_,
   {{0xcb12004c,0x64565f71,0x20c181a8,0x443fdf72}},	//   _שלי_, _zayi, nóir_, _sbu_,
   {{0x7afbdf73,0x64565f74,0x2d875f75,0xaefb0706}},	//   _stut, _yayi, áne_, _brùc,
   {{0x672438c4,0xfc3f026f,0x20c180f7,0x317e01ec}},	//   brij, dník_, hóir_, ätze_,
   {{0x2d874108,0x61ec0019,0x2fc681c5,0x3ebe909a}},	//   šne_, _állá, _nyog_, kott_,
   {{0x60c2df76,0x2b5f817f,0xa9698e8e,0x78ad5f77}},	//   _akom, _vruc_, жика_, lnav,
   {{0xa2a0035a,0x3ebedf78,0x78ad5bd0,0x6d5a0da8}},	//   _ऑगस्, dott_, onav, _štav,
   {{0x443f8578,0x78ad5f79,0x24868ee0,0x2b5fdf7a}},	//   _ubu_, nnav, ckom_, _truc_,
   {{0x64565f7b,0x66d01cce,0x66cb061c,0x64960b80}},	//   _rayi, läka, yükl, kšir,
   {{0x644bdf7c,0x60c2c176,0x6459df7d,0x20c180f7}},	//   legi, _ekom, ldwi, góir_,
   {{0xe3b803bf,0x672402ce,0x248da3f9,0xa90787c3}},	//   ğım_, zrij, _klem_, _ربان,
   {{0x6459b279,0x644bdf7e,0xe3b803bf,0x03a612c0}},	//   ndwi, negi, şım_, димо,
   {{0xee2e8dca,0xeb97239a,0x6729df7f,0xb7f406ae}},	//   _ин_, дия_, quej, _अलबम_,
   {{0x60c9df80,0xa50999b9,0x672415f5,0x23600a0f}},	//   llem, _дека_, vrij, _vrij_,
   {{0x2d1c0540,0x64565f81,0xb9b50098,0xd5d184e5}},	//   _पटेल_, _tayi, естъ, _हरिज,
   {{0x76800364,0x20551bbf,0x291e0289,0x60c9df82}},	//   _löyt, нтур, štao_, nlem,
   {{0x8fa30cb1,0xe7371285,0x2486df83,0x200fdf84}},	// [4e80] вате, мет_, vkom_, _megi_,
   {{0x67245f85,0x200fdf86,0x248d8b62,0x20125f87}},	//   rrij, _legi_, _alem_, sayi_,
   {{0x60c9df88,0x6aa3df89,0x78ad14cf,0x67245f8a}},	//   klem, dinf, bnav, srij,
   {{0x3ebe8065,0xfc3f003e,0x44f38028,0x644bdf8b}},	//   zott_, vník_, _mã_, gegi,
   {{0x60c98bfa,0x2486df8c,0x44f3df8d,0x4bda8fd3}},	//   dlem, rkom_, _lã_, آباد_,
   {{0x60c2df8e,0xfc3f016b,0x44328035,0xa50a046e}},	//   _skom, tník_, ży_, _мега_,
   {{0x644b8ad4,0xa9678992,0x200f811b,0x44f3df8f}},	//   begi, дија_, _begi_, _nã_,
   {{0x60c9df90,0x6496075f,0x2120881d,0x9f54b96b}},	//   glem, zšir, čih_, евич,
   {{0x3ebe8065,0xb05b016d,0x200fdb1d,0xdca3937b}},	//   tott_, _okän, _degi_, _рати,
   {{0xda669168,0x60c9df91,0x44f38129,0x78a424a1}},	//   _تاري, alem, _bã_, hiiv,
   {{0x3ebedf92,0x9986845b,0x6fd50006,0x20c181a8}},	//   rott_, _تلاو, _दरभं, róir_,
   {{0x25fe87e6,0x9f401f57,0x101680d5,0x60c2b21f}},	//   _श्री_, nció_, _آباد, _ukom,
   {{0x78ad0353,0x69c8df93,0x3ebe8019,0x2fc68122}},	//   vnav, _hyde, pott_, _uyog_,
   {{0x44f383a7,0x60c0df94,0x09d580ab,0x81d800ab}},	//   _fã_, lomm, _স্টা, িশন_,
   {{0x7ae88bc5,0x442f9235,0x76800198,0x19580a14}},	//   _midt, ygg_, _löys, мары_,
   {{0x58d423e1,0x60c0df95,0x315783de,0x628722c9}},	//   вост, nomm, וילן_, skjo,
   {{0x69c8df96,0x644b92fa,0x6d5e80c3,0xb3d302f1}},	// [4e90] _lyde, vegi, _špah, _सरिख,
   {{0x23480077,0x644b837a,0x3ce90282,0x248ddf97}},	//   _کلیپ_, wegi, _hiav_, _slem_,
   {{0x644bdf98,0x60c08a51,0x44f38028,0x7e7c13c7}},	//   tegi, komm, _xã_, _dorp,
   {{0x6ab9800c,0x7e7c0cb5,0x9475803d,0x7762802a}},	//   ेत्र, _eorp, رگزا, _orox,
   {{0x200fc849,0x6aa3df99,0x7e7c0aa2,0x6459a136}},	//   _regi_, tinf, _forp, rdwi,
   {{0x200f9d06,0x9f40009f,0x644bcb2c,0x7658df9a}},	//   _segi_, ació_, segi, _navy,
   {{0x60c989bd,0x200f83ac,0x349599f8,0x6aa3df9b}},	//   tlem, _pegi_, _завр, rinf,
   {{0x45d40364,0x9f400813,0x249f88de,0x3ce901c0}},	//   _росс, cció_, _umum_, _niav_,
   {{0x60c984e6,0x44f3df9c,0xf41f0198,0x7658df9d}},	//   rlem, _sã_, tkän_, _bavy,
   {{0xee399878,0xfe718013,0xb6cc817b,0xe3b80214}},	//   чно_, ادة_, şünü, şık_,
   {{0x200f90b5,0x765882d6,0x9f4001e8,0x78a400b9}},	//   _tegi_, _davy, nciò_, yiiv,
   {{0x3ce90282,0x60c0a527,0x7762802a,0x26c15535}},	//   _ciav_, comm, _frox, hoho_,
   {{0xf74590bf,0x3ce9022c,0x26c1026f,0xdd8e826a}},	//   _чело, _diav_, koho_, لوی_,
   {{0x2739df9e,0x291e012b,0x09e380ab,0x3f7a83de}},	//   mèn_, štam_, _ন্যা, _מאנס,
   {{0x78a401c2,0x614312e9,0x04460a41,0xd9431c60}},	//   tiiv, лера, _зейн, лери,
   {{0xd9c0103e,0x645a01a9,0x2ca02828,0xafe630ed}},	//   _एडीट, ētis, _umid_, еобл,
   {{0x44205f9f,0x3cff0024,0x673bdfa0,0x7643808e}},	// [4ea0] _idi_, _čuva_, ntuj, _kbny,
   {{0x78bb003b,0x78a414c7,0xb7d71ca3,0x3ea586ae}},	//   čuva, siiv, رولا_, nilt_,
   {{0x1a9b093f,0xa01b22f3,0x69c10065,0x9f590144}},	//   _זייע, _plöt, ület, _besó_,
   {{0x673b8e04,0x69c8dfa1,0x3ce90282,0x6d5e02f1}},	//   ktuj, _ryde, _xiav_, rvpa,
   {{0x7e7c0085,0x3ea59375,0x26c1046d,0xa3da897d}},	//   _torp, kilt_, boho_, डें_,
   {{0xada60652,0x7d1cb87a,0x2739dfa2,0x2d85dfa3}},	//   _загл, ársk, dèn_, kyle_,
   {{0x6f042d84,0x442011d3,0x9f405fa4,0x60c0dfa5}},	//   lpic, _odi_, pció_, tomm,
   {{0x7762c395,0x7ae8dfa6,0x44205fa7,0x76588084}},	//   _prox, _widt, _ndi_, _savy,
   {{0x76588110,0x656380f3,0x7643808e,0x60c08eb9}},	//   _pavy, _arnh, _bbny, romm,
   {{0x69c8dfa8,0x60c0dfa9,0x3ce90282,0x6996860a}},	//   _tyde, somm, _siav_, _прех,
   {{0x291e003b,0x3b0000b9,0x3ce901c5,0xc6930039}},	//   štaj_, _atiq_, _piav_, ראת_,
   {{0x2ebe03eb,0xe1ff80ff,0x64440706,0x66cb5f16}},	//   ्तुत, _đói_, _cbii, tükk,
   {{0x366a8364,0x3ea58bbd,0x7643808e,0x8b671459}},	//   _надо_, bilt_, _fbny, راحم,
   {{0x2d85dfaa,0x44205fab,0xa6aa8872,0x628aa0cf}},	//   byle_, _edi_, _عاشق_, nkfo,
   {{0xe5f78051,0x3cea8740,0xdd8f89f7,0x3ce901c5}},	//   _אזור_, _घंटे_, _сш_, _tiav_,
   {{0x672d0dd7,0x7d1a8b81,0xceb4011c,0x69d58b99}},	//   tuaj, msts, zrət_, येटी,
   {{0x66d0016d,0x6d47007b,0x16be0035,0xaefb026b}},	// [4eb0] räkn, _spja, ्तूब, _erùn,
   {{0x644f3cc4,0xc13b801c,0x44203887,0x26d80706}},	//   leci, _cướp_, _zdi_, _chro_,
   {{0x09df00c8,0x7d1c0289,0x44200114,0x7d1add7e}},	//   _ব্রা, _cvrs, _ydi_, nsts,
   {{0x673b9c17,0x645d5fac,0x2bde2f52,0xe4e4a22c}},	//   ytuj, ndsi, नेवा, гічн,
   {{0x645d01e4,0x69d800e1,0x20093d3e,0x60cd5fad}},	//   idsi, _úver, mbai_, mlam,
   {{0xaa459c9b,0x78a2c79a,0x7d1a897a,0x7dee0061}},	//   текл, _amov, ksts, rősí,
   {{0x644f12ae,0xd49b8c6e,0xfd660135,0x45d40db3}},	//   keci, _ера_, _mkpọ, _борс,
   {{0x42d180c8,0x673b8009,0x44f70457,0x60cd5fae}},	//   াদেশ, ttuj, _iç_, nlam,
   {{0x644f5faf,0x7528809a,0x3f8b81ac,0x3ea588c7}},	//   deci, erdz, ácu_, tilt_,
   {{0x2d850006,0x60cd179f,0x628ac7ea,0x2739dfb0}},	//   _üles_, hlam, ckfo, rèn_,
   {{0x673baad2,0x44205fb1,0xc5f202f6,0x3f8b8301}},	//   stuj, _pdi_, ידי_, šcu_,
   {{0x64a60b73,0xdca6200d,0x291e00d2,0xfd660870}},	//   тама, тами, štak_, _akpọ,
   {{0x60cd5fb2,0x29014883,0x3ea5dfb3,0x8c1a825f}},	//   dlam, _atha_, pilt_, וורי,
   {{0xc33283de,0x68eb8bb1,0xcb128039,0x66d00198}},	//   בוך_, _higd, שלם_, väko,
   {{0xa56480f7,0x78bb0115,0x6f1b8799,0x7641a2b7}},	//   _مدين, čuvn, lsuc, mfly,
   {{0x68fc8065,0x4420528c,0x645b8326,0x68eb8197}},	//   _érde, _udi_, _naui, _jigd,
   {{0xd9ad85b3,0x68ebdfb4,0x7d1c0024,0x6f1b81ec}},	// [4ec0] टपुट, _migd, _svrs, nsuc,
   {{0x60cd563c,0xaefb001c,0x7641870b,0xe6be0d5d}},	//   alam, _trùn, nfly, ्तेज,
   {{0x6729dfb5,0x60cd5fb6,0x6f1b81ec,0xe0da04ae}},	//   hrej, blam, hsuc, _ово_,
   {{0x6aca8c78,0x68eb87c6,0x6f041d82,0x32183228}},	//   ित्र, _nigd, ppic, lary_,
   {{0xe29a996f,0x24800035,0x2ca6dfb7,0xda7a8162}},	//   мад_, _moim_, riod_, дяй_,
   {{0x644f0063,0x60c4061a,0x32185fb8,0x66032361}},	//   zeci, loim, nary_, _впра,
   {{0xbea35fb9,0x7d1c011a,0x7641806a,0xdbdc826b}},	//   _тарк, _uvrs, dfly, _dáák,
   {{0x7d5700be,0x765c5fba,0x518395ff,0xc98399a7}},	//   _בילד_, _hary, руша, руши,
   {{0x765c5fbb,0x6729ab0d,0x68eb89c4,0x644f5fbc}},	//   _kary, grej, _digd, veci,
   {{0x3aeb803d,0x7528826c,0x60c401a8,0xd337825f}},	//   _قبلی_, trdz, hoim, _ברמה_,
   {{0xb05b016d,0x644f5fbd,0x60c40198,0x245504a3}},	//   _skäm, teci, koim, هندس,
   {{0x4fc68ab2,0x52bd0526,0x78a280d2,0x321337cd}},	//   _исла, ोत्स, _umov, _sexy_,
   {{0x24840106,0x645d5fbe,0x7d1adfbf,0x98a3066f}},	//   ömma_, rdsi, ssts, nują_,
   {{0x765c5fc0,0xc7d781c6,0x7afddfc1,0x31355fc2}},	//   _nary, _סוגי_, _éste, легр,
   {{0x60cd326a,0x611416cf,0x63be8035,0xb6d980be}},	//   tlam, идру, ępny, _אַקט,
   {{0x2aad370f,0xf0b42f8d,0x98a30035,0x6d4a8db1}},	//   džbe_, айсь, kują_, _ipfa,
   {{0x6d5a005c,0x765c2674,0x20090110,0xd7f83edc}},	// [4ed0] _štap, _bary, rbai_, тус_,
   {{0x60cd022e,0xd2510077,0xba5519e6,0x79a710ff}},	//   slam, _اند_, _свој, _арме,
   {{0x765c19b5,0x60cd5fc3,0x67299b39,0xf1df0576}},	//   _dary, plam, zrej, फेशन,
   {{0x7bcd00a4,0x60c40122,0x1b198198,0x6f02dfc4}},	//   _kyau, coim, ежды_, _otoc,
   {{0x4c9c007c,0x291e82d4,0x0c24a22c,0xa09a00be}},	//   ובאו, _avta_, рмін, _נישט,
   {{0x6d58825b,0xbbd38740,0x67299c89,0x6d4a806a}},	//   _osva, _तरीक, vrej, _opfa,
   {{0x81cb80c8,0xc69203de,0xa3aa103e,0x6f02dfc5}},	//   রেন_, _פאל_, _गेन_, _atoc,
   {{0x66155fc6,0x6729dfc7,0xc1740039,0x88c5801b}},	//   _hezk, trej, שחק_, _ověř,
   {{0x6615011b,0x7641c321,0x765c5fc8,0x6d4a818e}},	//   _kezk, tfly, _yary, _apfa,
   {{0x6f1b8352,0x6729af5f,0x82d88012,0x64ab128a}},	//   rsuc, rrej, _адус_, yřic,
   {{0x3218016b,0x764184e1,0xceb403c8,0x34aa1a1f}},	//   vary_, rfly, ייץ_, евно_,
   {{0x6281b2d9,0x6729dfc9,0x6f1b8387,0xab2a18d1}},	//   _holo, prej, psuc, нома_,
   {{0x32185fca,0x6281dfcb,0x3cedcff4,0x4fa480e8}},	//   tary_, _kolo, _miev_, _київ,
   {{0x62818a87,0x78a9dfcc,0xb607ae8c,0x6615128a}},	//   _jolo, liev, _рядк, _nezk,
   {{0x26c5dfcd,0x60c425ac,0x6281dfce,0x291e5fcf}},	//   molo_, toim, _molo, éta_,
   {{0x32185fd0,0x6281dfd1,0x63bb8085,0x26c581f6}},	//   sary_, _lolo, _oxun, lolo_,
   {{0x7c240013,0xddd5027f,0x765c5fd2,0x648600f7}},	// [4ee0] _idir, _rozš, _pary, _dóit,
   {{0x26c588f1,0x6281a6fb,0x20f802a5,0xa3c78105}},	//   nolo_, _nolo, _učio_, _उड़_,
   {{0x765c41f8,0xa0a63ec4,0x60c403a7,0xa2c1016f}},	//   _vary, _банд, poim, लकर्,
   {{0x2056095a,0xb4c08006,0x26c58234,0x317b00be}},	//   _стор, ुते_, holo_, _נאכד,
   {{0x38602670,0x26c5be3e,0x765c0110,0x6442dfd3}},	//   mdir_, kolo_, _tary, rfoi,
   {{0x62818ca9,0xc3330bea,0x38605fd4,0x3b0693de}},	//   _colo, מוד_, ldir_, rpoq_,
   {{0x6281dfd5,0x6f02dfd6,0x26c5c55b,0x2ca4808e}},	//   _dolo, _stoc, dolo_, _tmmd_,
   {{0x38602670,0x9958026f,0x7c245fd7,0x65000135}},	//   ndir_, káže_, _ndir, _ịkwụ,
   {{0x62818012,0xa3cb83db,0x3860198f,0x26c5dfd8}},	//   _folo, _रुप_, idir_, folo_,
   {{0x0f570051,0xa2e6a150,0x7c245fd9,0x9b938013}},	//   ניים_, _созд, _adir, _الكت,
   {{0x38600850,0x442480b9,0x7bcd00dd,0x64bc8088}},	//   kdir_, _kdm_, _syau, pčid,
   {{0xd00fb06f,0x3a3a002a,0xfbcd00ab,0x628e0123}},	//   _فلم_, _acpp_, রেফত, ekbo,
   {{0x38605fda,0x26c580e1,0x69c00214,0x6281dfdb}},	//   ddir_, bolo_, şmel, _yolo,
   {{0x8f9b893f,0x26c58698,0x7c240201,0x2eb181a2}},	//   _אידי, colo_, _edir, ीकृत,
   {{0x6d588052,0x661ad536,0x9928012f,0x66155fdc}},	//   _usva, matk, люта_, _rezk,
   {{0x6947003b,0x661adfdd,0x395a0122,0x6aaa81ec}},	//   jčeš, latk, _dsps_, hiff,
   {{0xb4c300d4,0xceb40085,0x2ba4a7cf,0x8e150cec}},	// [4ef0] ्ती_, rsən_, _खेला, идац,
   {{0x645f00dd,0xd5bb25f2,0xc7d78039,0x661adfde}},	//   _haqi, нсе_, רומי_, natk,
   {{0x5d5550a8,0x6281d38a,0xf1ab003d,0x3860011c}},	//   ркет, _rolo, _ساده_, bdir_,
   {{0x44fa8b18,0x661a8057,0x3af98205,0x6281dfdf}},	//   _më_, hatk, _pèp_, _solo,
   {{0x661ac3d8,0x09dd8b86,0x5bd301aa,0xa7fb0020}},	//   katk, मध्य, _सरोव, _cañe,
   {{0xb4c30aad,0xe8e0001c,0x44fa81b0,0x2ba4816f}},	//   ्तु_, _đức_, _oë_, _खेळा,
   {{0x661adfe0,0x44fa9674,0xd1758791,0x78a9cd33}},	//   datk, _në_, рылы, tiev,
   {{0x645f5fe1,0x5f759f33,0x2eee9bc2,0x63bb9fe7}},	//   _naqi, لاخر, _aiff_, _txun,
   {{0x6281dfe2,0x26c5dfe3,0x672d5fe4,0x78a9dfe5}},	//   _tolo, tolo_, nraj, riev,
   {{0x99980019,0x661aa11b,0x201b0d7a,0x3860080a}},	//   zerű_, gatk, haqi_, zdir_,
   {{0x26c5dfe6,0x672d026f,0x6d5ea9ad,0x38605fe7}},	//   rolo_, hraj, _špar, ydir_,
   {{0x26c582ec,0x7f5981c0,0xb87b0118,0x2369010c}},	//   solo_, _tswq, _xiít, _braj_,
   {{0x661a8867,0x64498013,0x26c5ce4e,0x5f7784c1}},	//   batk, _mbei, polo_, _حاضر,
   {{0x412a0c8e,0xee0f1a42,0x6f098216,0x648600f7}},	//   кого_, िरोध_, mpec, _cóir,
   {{0x7c3b8693,0x91e60b5b,0x628e5fe8,0x38600085}},	//   _ocur, рове, rkbo, tdir_,
   {{0xf7720013,0x7c242f78,0x27ffa651,0x7bcd80eb}},	//   ياء_, _udir, ncun_, ļauj,
   {{0x38605fe9,0x672d06e4,0xee3a0847,0xa3e52263}},	// [4f00] rdir_, graj, кна_, भेद_,
   {{0x6449dfea,0x44248b99,0x2bdc8fd5,0xaa460adb}},	//   _abei, _sdm_, _बरबा, _теол,
   {{0x64bc8499,0xc27b0051,0x6d41ad30,0x395a5feb}},	//   jčic, _סרטי, ntla, _usps_,
   {{0x8c4691c7,0xdd8f0d4a,0x0446a0a9,0x645f0079}},	//   реде, بوم_, редн, _xaqi,
   {{0x661aa0d5,0x7d09007a,0x39ae8085,0x68e41923}},	//   yatk, _čese, _səs_, mmid,
   {{0xd36f80f7,0x6d41dfec,0x68e402f3,0x7c3bdfed}},	//   بهه_, ktla, lmid, _ecur,
   {{0x5bd30b6f,0x649382bb,0x6aaadfee,0x661adfef}},	//   _सर्व, _için, riff, vatk,
   {{0x6b8b9da3,0x8f468160,0x6d5c0e5a,0x224982a5}},	//   bygg, аход, _isra, đaka_,
   {{0x44fa88cf,0xd6da9bcf,0x20050085,0x661adff0}},	//   _së_, кто_, _əli_, tatk,
   {{0x26c70025,0x3cf85ff1,0x7afd86a5,0x443b0118}},	//   čnog_, _kurv_, _ésta, _scq_,
   {{0x44fa8b18,0x661adff2,0x200001ac,0x2484977b}},	//   _që_, ratk, kcii_, _komm_,
   {{0xb4c30a16,0x661a810b,0x69dac464,0xdb0401df}},	//   ्ते_, satk, _izte, _axiñ,
   {{0x661a94ff,0x6d41a1b3,0xdce40b80,0x6d5c0122}},	//   patk, atla, _grnč, _lsra,
   {{0x44fadff3,0x171b84de,0x236900e1,0xe80e8074}},	//   _të_, _יודע, _vraj_, सरका_,
   {{0x2bd30592,0x30a70ddc,0x3eacd7ff,0xddd89502}},	//   _सरका, арав, midt_, _fovš,
   {{0x1410800f,0x2366805c,0x88940009,0x68e4110f}},	//   ारोह_, kvoj_, оисх, gmid,
   {{0xe3b80059,0x6d5c1bea,0x661881c0,0xaa8912c8}},	// [4f10] şır_, _asra, _kevk, _منظم_,
   {{0xde191e7b,0x42550c48,0x672d011e,0x4439005f}},	//   اقات_, _اندر, rraj, lgs_,
   {{0x6f0984e8,0x44390144,0x2bda00d7,0x672d25ac}},	//   zpec, ogs_, _لایک_, sraj,
   {{0x44395ff4,0x672d5ff5,0x6618807a,0x315600be}},	//   ngs_, praj, _levk, _פירן_,
   {{0x69da811e,0x6b658a08,0xe3b084a3,0x62855ff6}},	//   _azte, скла, وره_, _koho,
   {{0x62855ff7,0x20191fe7,0x78ad0110,0x6b8bba79}},	//   _joho, _hesi_, liav, rygg,
   {{0x2019022e,0xb5e500c8,0x62855ff8,0xf59500f7}},	//   _kesi_, _প্রচ, _moho, _الأج,
   {{0xb4c3000d,0x20191351,0x6ca484ad,0x62855ff9}},	//   ्तो_, _jesi_, _друж, _loho,
   {{0xb8fe80cf,0x20195ffa,0xb4c3000d,0x27ffdffb}},	//   _दी_, _mesi_, ्तै_, rcun_,
   {{0x6f098359,0x27ffbcc3,0x2019005d,0x78ad5ffc}},	//   rpec, scun_, _lesi_, hiav,
   {{0x74ea0c9b,0x79a7b4ad,0xaefb0229,0xddd885b7}},	//   лдог_, _трае, _drùi, _povš,
   {{0x6d41dffd,0x44390bcb,0x648600f7,0xc18c80be}},	//   rtla, ggs_, _cóip, _שטאָ,
   {{0x6d41dffe,0x64bcbbe2,0x26d9809f,0xe60e8c0e}},	//   stla, nčia, ïsos_, _нд_,
   {{0x64bc8110,0xcb128039,0x2bde150e,0xd37a83de}},	//   ičia, הלך_, नेगा, ארשט,
   {{0x62851807,0x2019059c,0x40960171,0xf2d29101}},	//   _doho, _besi_, брат, פעל_,
   {{0x387f861b,0x60c9838e,0x10a301a4,0x2aad016b}},	//   njur_, noem, писн, ržba_,
   {{0xa0670698,0x201914a9,0x64bc80e1,0xac9705ff}},	// [4f20] щата_, _desi_, jčia, _دنيا_,
   {{0x68e45fff,0xe7f400d4,0xdc1080c2,0x20000037}},	//   smid, _अलका_, ार्ड_, scii_,
   {{0x3ce0022c,0x64bc8110,0x629c00f7,0x321c9075}},	//   _khiv_, ečia, mhro, vavy_,
   {{0xeb9aa39a,0x291e01e2,0x62856000,0x78ad5bd0}},	//   лие_, štas_, _zoho, ciav,
   {{0x387f8106,0x321c816b,0x69da8061,0x649385aa}},	//   djur_, tavy_, _szte, _içil,
   {{0x6e960307,0x6d5c01a8,0x6d178035,0xd9fa2b38}},	//   _السا, _tsra, _दबंग_, ्डित_,
   {{0x5fac035a,0x321c8efc,0x81cb80ab,0xd7fa8088}},	//   _घेतल, ravy_, রেস_, луп_,
   {{0x387fdf84,0x2ed08a75,0xceb40085,0x831a8c2a}},	//   gjur_, हत्त, ksək_, _مقرر_,
   {{0xdfd08307,0x7f446001,0xdddc0087,0x6720911b}},	//   بية_, ntiq, _forţ, usmj,
   {{0xa7fb05b4,0x2d9e82af,0x69da826c,0xb87b00ff}},	//   _maña, tzte_, _tzte, _khíc,
   {{0x6285136f,0x69dae002,0x3eac928d,0xa7fb0118}},	//   _roho, _uzte, ridt_, _laña,
   {{0x6722e003,0x3ce001c5,0x3eaa00b9,0xb87b01a8}},	//   _tvoj, _chiv_, _lmbt_, _mhíc,
   {{0x628521f8,0x443903ab,0x661e0057,0x201916ce}},	//   _poho, rgs_, kapk, _resi_,
   {{0x20196004,0xdd948d15,0x65948087,0xdb0a1434}},	//   _sesi_, _малы, _малу, ðnám,
   {{0x661e09ca,0x78ad6005,0x66d00009,0x201900e5}},	//   dapk, tiav, näku, _pesi_,
   {{0xa7fb1f88,0xb7150081,0x2a616006,0x3ce6a3fa}},	//   _baña, ждащ, _wahb_, jmov_,
   {{0x628503fb,0x20193ae1,0xa7fb1e86,0x644d011b}},	// [4f30] _toho, _vesi_, _caña, _ibai,
   {{0xa7fb06a5,0x6c35026a,0x661e00dd,0x43d401a8}},	//   _daña, _افکا, gapk, _عزيز,
   {{0x201912d0,0x291e2a06,0x7f4400e7,0xb87b6007}},	//   _tesi_, štar_, atiq, _chíc,
   {{0x42550019,0x3e8501d0,0xb87b0174,0x44fe0123}},	//   _انگر, _sítě_, _dhíc, _dï_,
   {{0xa7fb062f,0xa03a0158,0x644d00f7,0x1dcf8105}},	//   _gaña, _דערפ, _mbai, _सुनत,
   {{0x661e0057,0x660d8668,0x64bcaa7c,0x442902df}},	//   capk, _đako, rčia, _lda_,
   {{0x644d003c,0x44296008,0x60c99727,0x6f0d6009}},	//   _obai, _oda_, toem, lpac,
   {{0xa3aa2e04,0xaf059bbf,0x7afd86a5,0x3f42807b}},	//   _गइल_, опил, _ésto, fðu_,
   {{0x660482bb,0x7c29846d,0xb4d592c6,0x60c9910f}},	//   _şika, _ider, हती_, roem,
   {{0x4429600a,0x644d600b,0xda02800f,0x6d454b8b}},	//   _ada_, _abai, रुआत_, otha,
   {{0xa2c6909b,0x6d45600c,0x7afb8009,0x443f8267}},	//   िवर्, ntha, _huut, _kcu_,
   {{0x6d45031d,0x4429600d,0x7afbc288,0xa775964f}},	//   itha, _cda_, _kuut, _млеч,
   {{0x4429600e,0xfc4a026b,0x629c46ff,0x7afbca79}},	//   _dda_, _adíá_, thro, _juut,
   {{0x7afb8181,0x4429600f,0x64bc811f,0x201f8359}},	//   _muut, _eda_, jčin, laui_,
   {{0x81cb8a49,0x443f805c,0x04460098,0xfbde14fc}},	//   রের_, _ocu_, _дейн, नेजम,
   {{0x7c29e010,0xa7fb06a5,0x443f822c,0x6f0d090d}},	//   _nder, _paña, _ncu_, fpac,
   {{0xe73a0c8e,0xe61a24dc,0x661e0867,0x7e63e011}},	// [4f40] рез_, ида_, tapk, _kanp,
   {{0x7c29e012,0x443f8013,0x7e63826b,0x6d451433}},	//   _ader, _acu_, _janp, ftha,
   {{0x7f442a1e,0x661e0867,0x22580cfa,0x91e66013}},	//   stiq, rapk, merk_, _фоне,
   {{0x7e638102,0x82360019,0x69de6014,0xe73a0198}},	//   _lanp, _ارکا, _izpe, _кем_,
   {{0x6d450083,0xdee60098,0x66090214,0x7c298114}},	//   atha, _моми, _şeke, _dder,
   {{0x7c29e015,0xb87b0104,0x6d456016,0x6da60b5b}},	//   _eder, _thíc, btha, _дига,
   {{0x67240c7f,0xb05b2bf5,0xdd920019,0x6d456017}},	//   lsij, _fjäd, _غور_, ctha,
   {{0x661c5a68,0xf8ba80c8,0x7e63838e,0xdddc27b5}},	//   _herk, ুষ্ঠ, _aanp, _gorš,
   {{0x67241f0a,0x661c294f,0xa3aa0006,0xda0b816f}},	//   nsij, _kerk, _गेल_, _स्वत_,
   {{0x442914c9,0x3f428125,0x63a2e018,0x09e6866c}},	//   _sda_, rðu_, mzon, _дозн,
   {{0x7c29813c,0x64bc81e2,0x80c782f1,0x6288a8bd}},	//   _yder, nčio, ावशे, _iodo,
   {{0x6f0d0953,0xceb8cb13,0x06de00ab,0xe4a7004a}},	//   ypac, snę_, _ভূমি, ірно,
   {{0x63a2e019,0x67240289,0xa2a1954b,0x443f00eb}},	//   nzon, jsij, कोक्, ļu_,
   {{0x6288810b,0x6724026c,0x6d450428,0x443f17ac}},	//   _jodo, dsij, ytha, żu_,
   {{0x6288e01a,0x2d83813c,0x68e289da,0x48ab1652}},	//   _modo, øjet_, _khod, атам_,
   {{0x62888e80,0x4429601b,0xd5b980e8,0x26cc89c4}},	//   _lodo, _uda_, _усі_, lodo_,
   {{0x661c0397,0x63a28a0f,0x64bc8b80,0x68e28090}},	// [4f50] _berk, jzon, tčin, _mhod,
   {{0x6f0d601c,0x62888029,0x7bdf1099,0x63a2809a}},	//   rpac, _nodo, _izqu, dzon,
   {{0x68e2826f,0x7afb84a2,0x6d450fe9,0xdddc0088}},	//   _ohod, _suut, utha, _porš,
   {{0x236de01d,0x6d454be5,0xb4d58a16,0x7afb88e5}},	//   _prej_, rtha, हते_, _puut,
   {{0x0f79093f,0x64bc9487,0x66d00106,0x443f8609}},	//   _האָב, mčil, täkt, _vcu_,
   {{0x248937f7,0x4efa01c6,0x60cd03e4,0x661c601e}},	//   _loam_, _להשו, loam, _gerk,
   {{0x26ccdb7a,0x6288c4f7,0x7e638247,0x68e29e2c}},	//   dodo_, _dodo, _ranp, _bhod,
   {{0x68e289a4,0x60cd262c,0x64bc9807,0x63a2a9d8}},	//   _chod, noam, nčil, bzon,
   {{0x63a28063,0x7e63e01f,0x201f808e,0x6288a052}},	//   czon, _panp, raui_, _fodo,
   {{0x26cce020,0x6459e021,0x35d003b7,0x776981df}},	//   godo_, lewi, _तुड़, rvex,
   {{0x225842cd,0x27f90118,0x68e29997,0xd46a04dd}},	//   verk_, _ogsn_, _fhod, бине_,
   {{0x225816a1,0x62838503,0x649a0cc1,0x7c3d0711}},	//   werk_, ljno, стор_, ggsr,
   {{0xee2e8554,0x7e638763,0x68e9805f,0x22586022}},	//   _пн_, _tanp, mmed, terk_,
   {{0xa7fb05a4,0x68e9e023,0x2cbf816d,0x68e29c32}},	//   _baño, lmed, _ljud_, _zhod,
   {{0x40961354,0x63a2ab31,0xa7fb0020,0x5bb89b91}},	//   прат, zzon, _caño, _अश्व,
   {{0x03261878,0xb05b00f2,0x6e21adbe,0xa7fb247e}},	//   _един, _skär, lalb, _daño,
   {{0x4422478c,0x661c0dab,0x6459c9ee,0x2258074c}},	// [4f60] mak_, _perk, dewi, perk_,
   {{0x44226024,0x672454be,0x68e98754,0xddc18019}},	//   lak_, rsij, hmed, lelő,
   {{0x67246025,0x6288d8ce,0xa7fb01df,0x60cd6026}},	//   ssij, _rodo, _gaño, boam,
   {{0x44226027,0x661c0574,0x645996a1,0x6288e028}},	//   nak_, _werk, gewi, _sodo,
   {{0x661c0393,0x68e2831d,0xd7f200f7,0x6e218110}},	//   _terk, _rhod, _سكس_, kalb,
   {{0x44220455,0x63a2e029,0x62888079,0x68e2bc59}},	//   hak_, rzon, _qodo, _shod,
   {{0x4422602a,0x63a2b380,0x20070063,0x66d00009}},	//   kak_, szon, śnie_, säks,
   {{0x25e1009a,0x63a2e02b,0xc05ab941,0x55bb01c6}},	//   _करती_, pzon, сік_, _המלו,
   {{0x44221dda,0x62888510,0x68e2803e,0x201d8cf1}},	//   dak_, _todo, _vhod, _dewi_,
   {{0x6e218666,0x7c228032,0x7bcd81a9,0x59a78074}},	//   galb, laor, ļaut, _केकर,
   {{0x7bd600a4,0x26cc8110,0x1dbe1299,0x68e980e1}},	//   _ayyu, rodo_, ्थित, bmed,
   {{0x4422602c,0x2d828d11,0x7c22e02d,0xd1978039}},	//   gak_, ćke_, naor, _מכבי_,
   {{0x6e21e02e,0x2d83806a,0xb921019d,0xa0c981a8}},	//   balb, øjer_, basị_, _بذلك_,
   {{0xb87b0104,0x1dbe2441,0x2ec789a9,0x4422008e}},	//   _chín, ्थात, रकृत, aak_,
   {{0x44225f8b,0x31c415e0,0xa9c40110,0x7c22e02f}},	//   bak_, еств, естк, kaor,
   {{0x44226030,0x64bca3c3,0x321ee031,0x50cc8072}},	//   cak_, učil, _lety_, ाविष,
   {{0xb90409a3,0x7c2d6032,0x60cd2e24,0x290c8cd4}},	// [4f70] _पी_, _idar, roam, _ltda_,
   {{0xaefb0a2a,0x2cada9e3,0x65950087,0x765ae033}},	//   _brùr, _smed_, мазу, nety,
   {{0x753a8352,0x6459a608,0x64bc807a,0x6d48e034}},	//   nutz, tewi, mčij, ntda,
   {{0x765a8198,0x66056035,0xc435881b,0xfbe101d0}},	//   hety, schk, بکست, _नराम,
   {{0x753ac9b6,0x386948e8,0x321ee036,0x38790db1}},	//   hutz, mdar_, _bety_, _insr_,
   {{0x442231ec,0x9f960039,0x38696037,0x66d0016d}},	//   zak_, _חדשה_, ldar_, säkr,
   {{0x442245d8,0x7c2d0b4c,0x776d01df,0x68e9e038}},	//   yak_, _odar, lvax, tmed,
   {{0x38696039,0x7c2d603a,0x2cbf9eea,0x05d082f1}},	//   ndar_, _ndar, _ujud_, _हड़ब,
   {{0x64bc8582,0xcb348098,0x7e6716f2,0x53349df3}},	//   kčij, _петъ, _kajp, _петт,
   {{0x4422603b,0x7c2d22c2,0xdd1b816b,0x321e8123}},	//   wak_, _adar, _váže, _gety_,
   {{0x4422603c,0x442de03d,0x6d48e03e,0x753a8102}},	//   tak_, _kde_, gtda, gutz,
   {{0x442d801b,0x7e672051,0x4422011b,0xb87b01a8}},	//   _jde_, _lajp, uak_, _shín,
   {{0x44220781,0x3869603f,0x7c2d031d,0x765a951f}},	//   rak_, ddar_, _ddar, bety,
   {{0x7e6709b3,0x7ea06040,0xb87b00f7,0x7c2d6041}},	//   _najp, _köpe, _bhío, _edar,
   {{0x442de042,0xa3d485e8,0xb87b6043,0xa9671bc0}},	//   _ode_, _सुन_, _chío, мира_,
   {{0x98a08d11,0x442de044,0xb87b00f7,0x25d680be}},	//   čić_, _nde_, _dhío, _קוקן_,
   {{0x7f49e045,0x7e670b80,0x44200087,0x64bcb99a}},	// [4f80] nteq, _bajp, _iei_, učim,
   {{0xf767a003,0x7c2d0e04,0x44206046,0x442de047}},	//   _یا_, _zdar, _hei_, _ade_,
   {{0x7c2280ee,0xa0a602c0,0x68fe02c4,0x629e00e5}},	//   taor, _жанд, _uupd, _ilpo,
   {{0x442001e2,0x69c00214,0x321e8690,0xa3d20651}},	//   _jei_, şmes, _sety_, _वडा_,
   {{0x7c228d02,0x629e00b9,0x442de048,0x26c38301}},	//   raor, _klpo, _dde_, čjoj_,
   {{0x44206049,0x442de04a,0x38668068,0x7c228748}},	//   _lei_, _ede_, _saor_, saor,
   {{0xd90d84c0,0x2f0400f2,0x6d48e04b,0x44200bfd}},	//   میل_, _hög_, xtda, _oei_,
   {{0x44201fd9,0x442d8d11,0xd01081a8,0x00000000}},	//   _nei_, _gde_, دلة_, --,
   {{0x6f021301,0x765ae033,0xb6f48a3d,0xc246acab}},	//   íoch, tety, нзиј, _онак,
   {{0x24868052,0x442d800d,0x6996a7ee,0x753a89e8}},	//   ljom_, _zde_, _орех, tutz,
   {{0x4420604c,0xf76f83f8,0x2d988038,0x2f04007b}},	//   _bei_, های_, áre_, _lög_,
   {{0x44200012,0x765aa1ba,0x442d83ac,0x6fc980d4}},	//   _cei_, sety, _xde_, _हुकू,
   {{0x44202012,0xd7e2a8d7,0xe7e28107,0xfc3f00f7}},	//   _dei_, _परिच, _परिप, rgí_,
   {{0x44200118,0x7d03387a,0x80dc00ab,0x7817097d}},	//   _eei_, ínsk, _মূল্, तर्क_,
   {{0xa2b1805e,0x44203d06,0xd5afe04d,0x480c019d}},	//   _अगस्, _fei_, _рс_, _ọzịz,
   {{0xdd8e8065,0x81cb80ab,0x660d8115,0x4420322f}},	//   _موڈ_, রেক_, _đaki, _gei_,
   {{0x3869604e,0x645d604f,0x7af701b9,0x24868bcf}},	// [4f90] rdar_, mesi, _tixt, djom_,
   {{0x76d50013,0x69c501e9,0x44200a0f,0xb87b00f7}},	//   رياض, _txhe, _zei_, _thío,
   {{0x38692acb,0x7e6701c0,0xaefb026b,0x752881a9}},	//   pdar_, _vajp, _erùp, nsdz,
   {{0x645d6050,0x8b6b80eb,0x2aad012b,0xb69b0162}},	//   nesi, ņēmē, džbi_, _atât,
   {{0x68ed6051,0x511f0074,0x628e00d2,0x7e670197}},	//   mmad, _बबुआ_, žnoš, _tajp,
   {{0xa9698676,0x290115d0,0x2d470187,0x21699afd}},	//   зика_, _kuha_, põe_, зики_,
   {{0x7c2080f1,0x645d6052,0xac198e1d,0x6e25008e}},	//   _femr, kesi, _нову_, mahb,
   {{0x442de053,0x29013351,0x645d6054,0x68ed2353}},	//   _ude_, _muha_, jesi, nmad,
   {{0x44206055,0xe8200076,0x68ed6056,0x290130e5}},	//   _rei_, बरता_, imad, _luha_,
   {{0x4420370b,0x39648364,0x7c2080f1,0x458590ca}},	//   _sei_, ässä_, _zemr, егов,
   {{0x044601d9,0x29010ad4,0x68ed6057,0xa6e2008b}},	//   ненн, _nuha_, kmad, íðin,
   {{0x859a0039,0x802780d7,0x64ca1299,0xd46a3448}},	//   פשרו, _آرام, रवेश, чиме_,
   {{0xe72ee058,0x44206059,0xaca38028,0x1dcf93e5}},	//   _ще_, _vei_, _chứn, _सुरत,
   {{0x249fe05a,0x60dbe05b,0xa764804a,0x68ed03ca}},	//   _llum_, llum, _шкід, emad,
   {{0xf09f0362,0x4420605c,0x2bdc91be,0xf3f98162}},	//   _blà_, _tei_, _बर्थ, _daţi_,
   {{0x645d605d,0x290104a7,0x68ed02a3,0x248d9ae1}},	//   cesi, _duha_, gmad, _noem_,
   {{0x672985b4,0x7c260234,0xace900d7,0x8fa3220b}},	// [4fa0] nsej, makr, _ترول_, гате,
   {{0x6da6246b,0xe5a601f3,0x7c264068,0x249f9916}},	//   низа, низи, lakr, _alum_,
   {{0x60db9cdf,0xe3bf04c3,0x249fe05e,0x200601df}},	//   klum, maña_, _blum_, ñois_,
   {{0x64a38b69,0xac07d5b3,0x0ca980f7,0x61e11266}},	//   лаха, енца_, وطني_, ülle,
   {{0xc5f88029,0x7cfe8029,0xe3b28a47,0xeb978198}},	//   ldēt_, _vīri, درا_, ниц_,
   {{0x7d0d890c,0x6e250d8b,0x645d605f,0x9966959f}},	//   _časn, cahb, zesi, етил,
   {{0x645d6060,0x55e3031f,0x1dcf8540,0x64a6d0e2}},	//   yesi, _борб, _सुलत, _зава,
   {{0x60dbe061,0xa3cb8105,0x62988084,0x7c265a55}},	//   glum, _रुक_, skvo, jakr,
   {{0xb907853e,0x59d2035a,0xb4cc9130,0xdca38294}},	//   _मी_, _दुसर, रकी_, _сати,
   {{0x44268272,0x645d4005,0xddd8801b,0x2ef8807b}},	//   lao_, wesi, _zavř, örf_,
   {{0x7d0921e7,0x645d6062,0x5fe2835a,0x01368591}},	//   _česk, tesi, _परवल, _سعاد,
   {{0x7afa9f48,0x4426dd4e,0x2fc690af,0x6442a9db}},	//   _hitt, nao_, _txog_, ngoi,
   {{0x087780be,0x78a440d0,0x29013f83,0x6e2500ee}},	//   _רעדט_, dhiv, _suha_, yahb,
   {{0x7afa81b9,0x877b80be,0xe3bf0661,0x3ce78054}},	//   _jitt, _מאדי, gaña_, _छीने_,
   {{0x7afae063,0x68ed6064,0xf09f07f1,0x7cfe8196}},	//   _mitt, tmad, _plà_, _būre,
   {{0x44268025,0x7afae065,0x7c26008e,0x7bde809a}},	//   jao_, _litt, cakr, ępuj,
   {{0x4426803b,0x3d068b9f,0x6a151d27,0x9f340163}},	// [4fb0] dao_, _संडे_, _импу, леті,
   {{0xa3aa1a42,0x7afa8197,0x3f8701dd,0x249f8706}},	//   _गेट_, _nitt, ćnu_, _slum_,
   {{0xeab18bca,0xceb3898a,0x3ce90069,0x200900ee}},	//   یعت_, ניע_, _khav_, pcai_,
   {{0x44268025,0x2bdc8076,0x78a46066,0x7c849631}},	//   gao_, _बरखा, chiv, луче,
   {{0x7afae067,0x69da85b0,0x69e3025b,0x6f02ae93}},	//   _bitt, _ayte, šteć, _nuoc,
   {{0xc61b00c8,0x7afa8698,0x69dae068,0x6d58cbc1}},	//   _ঢাকা_, _citt, _byte, _opva,
   {{0x4426a6b8,0x7afaae31,0x7d0dd9c6,0x7f4d3461}},	//   bao_, _ditt, _časo, ltaq,
   {{0x4426e069,0x7afa8125,0xa3c309a9,0x249f9600}},	//   cao_, _eitt, ्था_, _ulum_,
   {{0xc62400c8,0x60db8859,0x6f028081,0x7f4d011c}},	//   _পাতা_, rlum, _cuoc, ntaq,
   {{0x7afa87d9,0xf1a790ca,0x60dbe06a,0x82378bbe}},	//   _gitt, _прен, slum, _سرطا,
   {{0xdca6119d,0x4df48153,0x6729af5f,0x64a643e8}},	//   вани, ляют, ssej, вана,
   {{0x224980fe,0x7d04e06b,0x7afacf60,0x3ce901c5}},	//   đaku_, _čist, _zitt, _chav_,
   {{0x26c7003b,0xccf280be,0xe3bf0511,0x7ea00106}},	//   čnoj_, יכט_, taña_, _löpa,
   {{0x386d806f,0xd02680c8,0x64410084,0xa7fb02f9}},	//   lder_, _যায়_, ėlia, _gañi,
   {{0xaca38142,0x26d30825,0xa01b016d,0x4426e06c}},	//   _nhữn, doxo_, _onöd, yao_,
   {{0x2aad111b,0x3a2782c4,0x6e23e06d,0xe3bf0333}},	//   džbu_, hanp_, _henb, saña_,
   {{0x4426803b,0xe3bf160a,0xb05b04b8,0x6e238247}},	// [4fc0] vao_, paña_, _tjän, _kenb,
   {{0xb05b04b8,0x78a413fa,0x4426c914,0x386d8428}},	//   _hjäl, shiv, wao_, hder_,
   {{0x7d0390e4,0x4432001b,0x6e2380dd,0x2d9c01ac}},	//   _juns, _kdy_, _menb, áve_,
   {{0x7afae06e,0x386de06f,0x7d039b25,0xb4be8a16}},	//   _sitt, jder_, _muns, ीके_,
   {{0x4426803b,0x7c2407ca,0x93439b56,0x8c43a1a7}},	//   rao_, _meir, инце, рече,
   {{0x44268025,0xe8e00028,0x386d8ac5,0x386001e4}},	//   sao_, _độc_, eder_, leir_,
   {{0x69da820f,0x4426803b,0x7afae070,0x6f02e071}},	//   _qyte, pao_, _vitt, _suoc,
   {{0xfce68cde,0x7afa8ac5,0xe0cf80f7,0xf993025f}},	//   _робо, _witt, يزي_, שרה_,
   {{0xf8b30051,0x7afae072,0xc6f89ff8,0x7d038362}},	//   ישה_, _titt, нних_, _auns,
   {{0x7afa98c7,0x7d03e073,0x15e618a4,0x60cd81a1}},	//   _uitt, _buns, _करार_, čama,
   {{0x7c246074,0xceb30051,0x6e2392a2,0x4424e075}},	//   _beir, שית_, _denb, _kem_,
   {{0x80e080c8,0x79b78051,0x4424b038,0x35b3a3b2}},	//   _পূর্, _בלבד_, _jem_, рбюр,
   {{0x7c244808,0x4424e075,0x7d03808e,0xd007c6b2}},	//   _deir, _mem_, _euns, _рече_,
   {{0x4424e076,0x28ae8074,0x6e23806a,0x78a28115}},	//   _lem_, जोरि, _genb, _hlov,
   {{0x81d480c8,0x7c246077,0xe2f8004a,0xb05b0106}},	//   সের_, _feir, тері_, _fjäl,
   {{0x44248986,0xb4cc83bb,0xb4be83bb,0x4432050d}},	//   _nem_, रको_, ीको_, _gdy_,
   {{0xe3bf040e,0xf7731e7b,0x64bc8110,0xfc3f0118}},	// [4fd0] maño_, جاز_, nčiu, chía_,
   {{0xa3e805b3,0xed4d8986,0x7f4d6078,0xe3bf01df}},	//   _भरत_, _بھی_, rtaq, laño_,
   {{0x442480a9,0xa9c40d70,0x386de079,0x7f4d607a}},	//   _bem_, _всяк, yder_, staq,
   {{0x4424e07b,0xe7e2b6cf,0x6ba802d0,0x7c2403a8}},	//   _cem_, _परंप, _örgü, _xeir,
   {{0x4424d89e,0xe7842432,0x386d804a,0x6f020174}},	//   _dem_, _куро, vder_, íoct,
   {{0xdce401d0,0x539c0e82,0x672d607c,0x98b80ec3}},	//   _brně, וידו, msaj, murā_,
   {{0x27e68019,0x672d0338,0x79a78081,0x64bc8196}},	//   _azon_, lsaj, ърде, ečiu,
   {{0x2ca68265,0x6e23e07d,0x386d80f3,0x78a2e07e}},	//   chod_, _senb, uder_, _clov,
   {{0x386da8bb,0x672d0a49,0x68fd43dc,0x7c24607f}},	//   rder_, nsaj, _misd, _reir,
   {{0xb05b04b8,0x44248070,0x7c24061f,0x764533af}},	//   _själ, _zem_, _seir, nghy,
   {{0x391599bb,0x4424e080,0x236900f1,0x7c246081}},	//   _смер, _yem_, _asaj_, _peir,
   {{0x44248142,0x3a25e082,0xe3bf01ca,0x6e23b3e0}},	//   _xem_, _help_, gaño_, _wenb,
   {{0x2905e083,0x629c0668,0x7d0381ec,0xceb8809a}},	//   _hula_, tkro, _wuns, bię_,
   {{0x2905d1c6,0x2d732cf6,0x7d0393d7,0x68fd0706}},	//   _kula_, _oće_, _tuns, _aisd,
   {{0x2905e084,0x7c24347b,0x629c20e5,0xa7fb0118}},	//   _jula_, _teir, rkro, _mañu,
   {{0x6d41c8aa,0x1c461289,0x2905e085,0x629c2d24}},	//   mula, _сним, _mula_, skro,
   {{0x2905d460,0xe7371e4e,0xe7c400ab,0x68fd1181}},	// [4fe0] _lula_, лет_, ্ধ্য, _disd,
   {{0x4424be81,0x6449df17,0xda66531b,0x7e61dd7f}},	//   _sem_, _acei, _свои, nelp,
   {{0x44248069,0x6d41e086,0x21761448,0x88bc801b}},	//   _pem_, nula, _супр, _květ,
   {{0x64460812,0x29180531,0x64bc803b,0x672d01b9}},	//   ngki, mpra_, jčit, bsaj,
   {{0x4424e087,0x2905d1d1,0x6d4197b7,0x6d4103a6}},	//   _vem_, _aula_, hula, _ålan,
   {{0x78a299a4,0x6d41e088,0x2905e089,0xaa58968a}},	//   _slov, kula, _bula_, тику_,
   {{0x4424e08a,0x248005f5,0x2905807d,0xa3d48054}},	//   _tem_, _onim_, _cula_, _सुर_,
   {{0x4734be32,0x6d4e0a76,0x644980f7,0x60c4608b}},	//   анис, _iqba, _gcei, nnim,
   {{0x7c938013,0x69d60105,0x29059400,0x6e28e08c}},	//   _القص, _मुसी, _eula_, tadb,
   {{0x2480009c,0x6e989a1f,0x2905e08d,0x6d41e08e}},	//   _anim_, твор_, _fula_, fula,
   {{0x2905b745,0x6d41e08f,0x7afd8081,0x241917ae}},	//   _gula_, gula, _èsta, коны_,
   {{0x78a2e090,0xbd87803d,0x236901a1,0xa3c300bc}},	//   _ulov, چنین_, _psaj_, ्थल_,
   {{0x60c46091,0x7e618be7,0x68fd09f4,0x6d41a471}},	//   dnim, belp, _risd, aula,
   {{0x6d5c1f2a,0x7afe01da,0x24806092,0x23690353}},	//   _opra, _cipt, _enim_, _vsaj_,
   {{0x19580071,0x6f066093,0x35d90b9f,0x6eeb6094}},	//   лары_, _aukc, _बुढ़, nübe,
   {{0x23690282,0x60c46095,0x30150b5b,0xa8151c9b}},	//   _tsaj_, gnim, рдар, рдаш,
   {{0x6d5c6096,0x6d4e01b4,0x68fd0b82,0xa3c30072}},	// [4ff0] _apra, _aqba, _visd, ्थळ_,
   {{0x3255433f,0x644980f7,0x88bc81d0,0xba552cab}},	//   _твор, _scei, _zvět, _твој,
   {{0x68fd6097,0x672d333e,0x60c46098,0x6722838a}},	//   _tisd, ssaj, bnim, _lwoj,
   {{0xc8671b1c,0x48670698,0xb4c18074,0xddc3912b}},	//   _стои, _съоб, ुवे_, _janš,
   {{0x6d41e099,0x2905e09a,0xcb69c543,0xa7fb0388}},	//   zula, _sula_, тале_, _pañu,
   {{0x2905a853,0xeb96a4dd,0x442b21cc,0x6d41d21f}},	//   _pula_, риш_, hac_, yula,
   {{0x0dc8035f,0xe5098028,0xdd940196,0x442b609b}},	//   _бути_, _mặc_, _лары, kac_,
   {{0x38ba9482,0x27e6009a,0x64bca3c3,0x6d41e09c}},	//   tūra_, żone_, učit, vula,
   {{0x8b588b8c,0x3a258072,0x6d5c001b,0x6d418573}},	//   _مجلس_, _telp_, _zpra, wula,
   {{0x88bc800d,0xcdf58009,0x2905809c,0xe8df819d}},	//   _svět, ичны, _tula_, _idọm_,
   {{0x6281c248,0x3ced81c0,0x7afe09c4,0x442b583d}},	//   _inlo, _khev_, _ript, fac_,
   {{0x6d419238,0xeb9a36b8,0x442b0079,0x7afe0b67}},	//   rula, вим_, gac_, _sipt,
   {{0x6d41b3a8,0x60c4007a,0x87e79562,0xe0d084c1}},	//   sula, vnim, _сюже, _عزم_,
   {{0x6e2701d0,0x7c2b8118,0xe5098129,0x7ea002d0}},	//   _nejb, hagr, _cặc_, _röpo,
   {{0xfce62118,0x60c41809,0x7bcd12ab,0x6f060035}},	//   _коко, tnim, _exau, _sukc,
   {{0xa3b10361,0x98b80162,0x661c82d0,0x80660a2e}},	//   _टेक_, dură_, ırke, јваж,

   {{0xa06718a0,0x6d5c2038,0x60c4609d,0x62819447}},	// [5000] шата_, _spra, rnim, _onlo,
   {{0x6f06026c,0x611181a9,0x2d9a0c6b,0x29180338}},	//   _vukc, _zāle, type_, ppra_,
   {{0x056624ac,0x69da816f,0x98b80162,0x05d903db}},	//   рвен, _पुढी, gură_, _बुदब,
   {{0x7d09003a,0xeb9a825d,0x6d5c0db7,0xed5680be}},	//   _čest, кие_, _vpra, יבער_,
   {{0x3ced81c0,0x78bb80e5,0xe8e20072,0x78a30162}},	//   _dhev_, diuv, पतीच, _înva,
   {{0x442b011f,0x7ea00338,0x3d2800d7,0x38721277}},	//   zac_, _köpm, _متری_, ldyr_,
   {{0x67228063,0x81d800ab,0x6d4e0748,0xc448803d}},	//   _swoj, ়ের_, _uqba, _میان_,
   {{0xc05a8163,0x8c438abe,0x6eeb02af,0x672286c0}},	//   тік_, _месе, rübe, _pwoj,
   {{0x442b003b,0x660907d9,0x6eeb0192,0xdb24010c}},	//   vac_, _şeki, sübe, _èsèn,
   {{0xf708dea9,0x7d00e09e,0x442b5e51,0x62818a2a}},	//   _của_, _hims, wac_, _gnlo,
   {{0xa0a68364,0x442b609f,0x7d00e0a0,0x69d6016f}},	//   _кажд, tac_, _kims, _मुली,
   {{0x67228063,0xd00f8b76,0x78a99ad0,0x395e8748}},	//   _twoj, _قلم_, chev, _ipts_,
   {{0xbf9b03a7,0x2007066f,0x7c360286,0xdfd28a19}},	//   _agên, śnik_, _ddyr, _بيش_,
   {{0x7c2be0a1,0x799c0114,0xdddc02a6,0x1b038264}},	//   zagr, fyrw, _borż, রীকে_,
   {{0x64400511,0x45448061,0xddce01a9,0x61038e06}},	//   ómic, _انعق, _dabū, _tőle,
   {{0xd2510077,0xd5fb8051,0x7bcd01e9,0x7d00e0a2}},	//   _کند_, _בפור, _txau, _nims,
   {{0x28f80364,0xe5098129,0x7d0d82d4,0x644d0db1}},	// [5010] реть_, _tặc_, _časi, _icai,
   {{0x7d008cac,0x44290006,0x98b8002e,0x4fc40b73}},	//   _aims, _hea_, tură_, іста,
   {{0x3ced81c0,0xa2b7853f,0x7cff0110,0xdef824bd}},	//   _phev_, ्चस्, _jūro, рыт_,
   {{0x3ced8282,0x7d0081a1,0xdd398493,0xe43c928a}},	//   _qhev_, _cims, lăţe, bříč,
   {{0x7c2be0a3,0x4429002e,0xa3dd009a,0xd7fb04ae}},	//   ragr, _mea_, _तुम_, _јун_,
   {{0x44295157,0x3e57001b,0x6e35011f,0x69158197}},	//   _lea_, _dětí_, _udzb, _jġeg,
   {{0x442903ec,0x3ced8282,0x69da80d4,0xb7bd8162}},	//   _oea_, _thev_, _पुदी, maţi,
   {{0xc31d00c8,0x6d4560a4,0xb7bd802e,0x26c7026f}},	//   _তিনি_, muha, laţi, čnou_,
   {{0x6d452022,0x78a9c8b0,0xa9e4001b,0x00000000}},	//   luha, rhev, _गर्छ_, --,
   {{0x26e5146d,0x7c2982b5,0x644d60a5,0x78a9b213}},	//   _कठोर_, _heer, _acai, shev,
   {{0x6d4545d8,0x7c29e0a6,0x38720c0b,0x78a98163}},	//   nuha, _keer, ydyr_, phev,
   {{0x44290012,0xb4c43064,0x7c299e6e,0x443e02af}},	//   _cea_, ्वे_, _jeer, ßt_,
   {{0x442960a7,0x7c29e0a8,0x61e1e0a9,0x6d4560aa}},	//   _dea_, _meer, _hyll, huha,
   {{0x61e18364,0x7c29c05a,0x6d4550cc,0x442902a6}},	//   _kyll, _leer, kuha, _eea_,
   {{0x91e61acf,0x44290216,0x61e1806a,0x395e0722}},	//   сове, _fea_, _jyll, ïts_,
   {{0x6d4560ab,0x7c299eb6,0xa9281c32,0x3eb810e8}},	//   duha, _neer, _nižš, _smrt_,
   {{0x4fea0a13,0x57ea60ac,0xe29a01a1,0x387222c9}},	// [5020] уман_, удам_, _бап_, rdyr_,
   {{0x645be0ad,0xb7bd8087,0xb87b046d,0x442959e5}},	//   _abui, gaţi, _akíd, _zea_,
   {{0x7c29b593,0x6d4560ae,0x69158197,0x2b5f8493}},	//   _beer, guha, _jġed, _apuc_,
   {{0x0446a0a3,0x395e8118,0x308601a8,0x645b8706}},	//   седн, _rpts_, _الحف, _cbui,
   {{0xe29aac75,0x61e18144,0x7c299fb7,0x7f44076b}},	//   лад_, _ayll, _deer, quiq,
   {{0x6d452124,0xb7bd802e,0x290260af,0x7d1a816b}},	//   buha, caţi, _hika_, ypts,
   {{0xfce69628,0x290242c0,0x61e18114,0x6d450683}},	//   _гово, _kika_, _cyll, cuha,
   {{0x29020fc7,0x7c29927b,0x26da04be,0xb4c4114f}},	//   _jika_, _geer, lopo_, ्वो_,
   {{0x442960b0,0x290260b1,0x644d60b2,0x7e2a902a}},	//   _rea_, _mika_, _rcai, ліна_,
   {{0x61e19808,0x2902101f,0xed4f0117,0x644d00f7}},	//   _fyll, _lika_, _تھے_, _scai,
   {{0x44290074,0x61e1aaae,0x7c299a2b,0xe0d6a361}},	//   _pea_, _gyll, _yeer, _людь,
   {{0x7c298079,0xb7bd8087,0xf1c000ff,0xb5fb00be}},	//   _xeer, zaţi, _ương_, טליכ,
   {{0x442960b3,0x26da074b,0xdd398087,0x5f94891e}},	//   _vea_, kopo_, tăţe, _филт,
   {{0x290260b4,0x6d4560b5,0x442960b6,0x0db98065}},	//   _aika_, yuha, _wea_, ائیں_,
   {{0x51841982,0x290209d8,0x30a732a7,0x3211009a}},	//   пута, _bika_, брав, rczy_,
   {{0xfd4d0028,0x25ef146d,0x2bda0c1c,0x3ebee0b7}},	//   _thoạ, _अरबी_, _युवा, litt_,
   {{0x59df8c78,0x29020870,0x7cff00eb,0xb7bd8087}},	// [5030] _पुनर, _dika_, _jūrm, taţi,
   {{0x6d455638,0x7c29e0b8,0x2aab813c,0xdef811e9}},	//   tuha, _seer, _købe_, бых_,
   {{0x62855a3b,0xb7bd802e,0x290260b9,0xb87b01a8}},	//   _inho, raţi, _fika_, _dhír,
   {{0xa3bd0bb8,0x290260ba,0x3ebee0bb,0x27e60035}},	//   _आधा_, _gika_, hitt_, żona_,
   {{0x7c299316,0x6eef806a,0x2aab806a,0xb87b01a8}},	//   _veer, løbe, _løbe_, _fhír,
   {{0x7c298c11,0x61e1e0bc,0x78ad04dc,0x236d807a}},	//   _weer, _pyll, lhav, _vsej_,
   {{0xd9f90063,0xa2d28013,0x9d180463,0x7c29e0bd}},	//   ंधित_, بيوت, _гост_, _teer,
   {{0x78ad0022,0x7f598073,0xa3d48c28,0x6009a39f}},	//   nhav, ајот_, _सुक_, шним_,
   {{0xdddc07d9,0xfa0100c8,0x7d0a82af,0x442fe0be}},	//   _karş, ্রিল_, _aufs, mag_,
   {{0x86998049,0x3ebe804a,0x61e1e0bf,0xe5098129}},	//   ртит_, gitt_, _tyll, _dặn_,
   {{0x2ca91e12,0xaca380ff,0xdddc0380,0xf1a7917f}},	//   _blad_, _chủn, _marş, _уран,
   {{0x644b8cef,0x442fe0c0,0x2b40ca41,0x2299e0c1}},	//   nggi, nag_, šice_, _tèks_,
   {{0xee2ee0c2,0x290260c3,0x26da004f,0x7cd200eb}},	//   _он_, _rika_, yopo_, vārd,
   {{0xe5a59860,0x60c9d44c,0x6da5a7d4,0x290260c4}},	//   _мили, lnem, _мила, _sika_,
   {{0x409621a7,0x290260c5,0x442f833e,0xc61681c6}},	//   орат, _pika_, kag_, _וחצי_,
   {{0xd0071eb5,0x60c9e0c6,0x02b68eed,0x6f03e0c7}},	//   жете_, nnem, _अग्न, _hinc,
   {{0x39478032,0x60c980e7,0x62970118,0x290260c8}},	// [5040] huns_, inem, _foxo, _vika_,
   {{0x290202b8,0xc9665195,0x41c9816f,0x7ea00106}},	//   _wika_, _двой, िपास, _köpi,
   {{0x29020029,0x7d04393c,0x78ad3247,0x60dbd890}},	//   _tika_, _kiis, bhav, koum,
   {{0x23770bca,0x78ad1075,0x60c98933,0x26da15d0}},	//   _امید_, chav, jnem, sopo_,
   {{0xa3d483b7,0x60db8289,0x7d040079,0x26da010c}},	//   _सुख_, doum, _miis, popo_,
   {{0x6f038065,0x644b8081,0x7d0460c9,0x7c2f01e8}},	//   _ninc, aggi, _liis, zacr,
   {{0xa2cd0b6f,0x3947ae33,0x64a69878,0x40348973}},	//   _सदस्, guns_, _дава, пейс,
   {{0x7cf18e23,0x290280f2,0x60c9e0ca,0x7d04037b}},	//   gård, öka_, gnem, _niis,
   {{0x6f03e0cb,0xdb2480d5,0xe6669fb5,0x49110074}},	//   _binc, _روای, отно, _दूनो_,
   {{0x7c22e0cc,0x7d04008e,0x39478187,0x6f03b110}},	//   lbor, _aiis, buns_, _cinc,
   {{0x3ebeb805,0x867b03c8,0x6f03e0cd,0x291a816b}},	//   ritt_, בריו, _dinc, ípad_,
   {{0x7d0d803e,0x7c22a28b,0x1b1d80ab,0x6b8200eb}},	//   _čast, nbor, _নিতে_, _šoga,
   {{0x7c2f3009,0xfe6f803d,0x6d41e0ce,0x2ca92eb0}},	//   racr, ردی_, arla, _vlad_,
   {{0x7c2f0baf,0xaabc83eb,0xaca3e0cf,0x2ca90114}},	//   sacr, ्चिक, _ihụn, _wlad_,
   {{0x290ce0d0,0x442fa73b,0x28c70f12,0x644bb8b9}},	//   _juda_, yag_, रचलि, yggi,
   {{0x261685b3,0x290ca650,0x6d4887d5,0xa3aa809a}},	//   पुरी_, _muda_, muda, खना_,
   {{0x9f595e3b,0x6d48e0d1,0x6297002a,0x7c22bfa7}},	// [5050] _også_, luda, _toxo, dbor,
   {{0xdddc0086,0x60c0aa19,0x442fa705,0x62850118}},	//   _qarş, himm, wag_, _unho,
   {{0x442fe0d2,0x6d48e0d3,0x7c2d015d,0xd6d81138}},	//   tag_, nuda, _kear, іту_,
   {{0x7c22a2ef,0xb4d5809a,0x7d040079,0x60db8118}},	//   gbor, सके_, _xiis, xoum,
   {{0x442f9839,0xdfc68013,0x6d4884b9,0x7cf1816d}},	//   rag_, _أي_, huda, vård,
   {{0x38691e38,0x7ead81ac,0x6d48e0d4,0x442fe0d5}},	//   lear_, _kúpe, kuda, sag_,
   {{0x81dd00c8,0x6d48b090,0x442f9882,0x6f03e0d6}},	//   তের_, juda, pag_, _rinc,
   {{0x386960d7,0x290c965f,0x6f03a7de,0x39478187}},	//   near_, _duda_, _sinc, runs_,
   {{0x60c9e0d8,0x7c3ba2c2,0xea0000ff,0x7d041989}},	//   rnem, _idur, _phẫu_, _riis,
   {{0x38690c49,0x0ea98364,0x7d0460d9,0x60c9e0da}},	//   hear_, ской_, _siis, snem,
   {{0x442de0db,0x290c80a4,0x7d041ea9,0x7c2d60dc}},	//   _kee_, _guda_, _piis, _bear,
   {{0x7c2d061f,0x442d84cd,0x6d41e0dd,0x895a9101}},	//   _cear, _jee_, rrla, _לדעת,
   {{0x442de0de,0x7c2d061f,0xdd8e8bca,0x7d04043d}},	//   _mee_, _dear, نوی_, _viis,
   {{0x290c82ec,0xfaa6076a,0x7c2d0362,0x442d81c6}},	//   _yuda_, чаго, _eear, _lee_,
   {{0xd1790cde,0x2bdc1551,0x64a6140b,0x703a0364}},	//   ості_, _गुरू_, _нака, йчас_,
   {{0x7c2d003c,0x442d85f8,0x38692630,0xb4d58023}},	//   _gear, _nee_, gear_, सको_,
   {{0xee3a0973,0x237f8282,0x78a40687,0x7c22e0df}},	// [5060] йна_, _nruj_, rkiv, vbor,
   {{0x7c3b84be,0x6b7b010f,0x78a460e0,0x60c081ec}},	//   _adur, _פרינ, skiv, zimm,
   {{0x929b0051,0x7c2d4727,0xe29b0039,0x6abe1e91}},	//   _היית, _year, _השיר, _impf,
   {{0x442de0e1,0xb4d68076,0x386960e2,0x2fcd0115}},	//   _cee_, हवे_, cear_, _žege_,
   {{0x442d8d10,0x290c8503,0x7c22e0e3,0x1ddd816f}},	//   _dee_, _suda_, rbor, _नुसत,
   {{0x3ce6aea1,0x6d48e0e4,0x7c3be0e5,0x3f808110}},	//   slov_, yuda, _edur, _šiuo_,
   {{0x3ce682a5,0x395800eb,0x82338019,0x60c0e0e6}},	//   plov_, ntrs_, رروا, timm,
   {{0x6e2e0586,0xb05b00f2,0x442de0e7,0x25ae0214}},	//   _hebb, _hjär, _gee_, ıklı_,
   {{0xd6da8698,0x60c0e0e8,0x7f441571,0x7d0e441d}},	//   йто_, rimm, nriq, _hubs,
   {{0x7c2d60e9,0x6d48e0ea,0x60c08364,0x290c80d2}},	//   _sear, tuda, simm, _tuda_,
   {{0x7c2d0ad0,0x63a2e0eb,0x442de0ec,0x6288e0ed}},	//   _pear, lyon, _yee_, _indo,
   {{0xd5b78196,0x0cab00b3,0x7cff0110,0x6d48db46}},	//   ясы_, стои_, _kūri, ruda,
   {{0x6d489283,0x629ad536,0x7d0e60ee,0x7eade0ef}},	//   suda, _koto, _lubs, _súpe,
   {{0x27e682b8,0x6e2e5d17,0x7f4460f0,0x629ae0f1}},	//   _iyon_, _nebb, driq, _joto,
   {{0x30a7091c,0x38690013,0x26dee0f2,0x7e750db7}},	//   прав, tear_, moto_, _razp,
   {{0x61e5003e,0x6abe0352,0x25e0009a,0x629ac719}},	//   _vyhl, _empf, _कड़ी_, _loto,
   {{0x4c3c0051,0x442daf78,0x628880ad,0xb4d90740}},	// [5070] _התחב, _ree_, _ondo, ़की_,
   {{0x442d9d99,0x38691997,0xcb1400be,0x63a2b52f}},	//   _see_, sear_, _אלץ_, dyon,
   {{0x386960f3,0x6e2e2e31,0x442dc99a,0x27e6e0f4}},	//   pear_, _debb, _pee_, _lyon_,
   {{0x6288e0f5,0x7f4460f6,0x26dee0f7,0x442d81c5}},	//   _ando, briq, hoto_, _qee_,
   {{0x6e2e0098,0x26dee0f8,0xb05b016d,0xe29992ea}},	//   _febb, koto_, _fjär, жал_,
   {{0x442d882e,0x91e58ada,0x629ac79a,0xfc3f05bf}},	//   _wee_, моле, _coto, chív_,
   {{0x442de0f9,0x27e682b8,0xac1985e9,0x629ae0fa}},	//   _tee_, _ayon_, _мову_, _doto,
   {{0x60cd3ec7,0x26cce0fb,0x92bf80c8,0x63a2a76a}},	//   nnam, endo_, ীতে_, byon,
   {{0x26dee0fc,0x2d98e0fd,0x60cd60fe,0xa8068661}},	//   foto_, ären_, inam, _riñó,
   {{0x2489198f,0xddc8adab,0x68e2e0ff,0x6f0f047f}},	//   _anam_, cedū, _ekod, _mucc,
   {{0x04460b79,0x8c4610ee,0x6f0f0081,0xa8068333}},	//   менн, мене, _lucc, _piñó,
   {{0x6f0701c0,0x629ab8c0,0x98bc8110,0x38c3826b}},	//   _lijc, _zoto, tuvą_, _dèrè_,
   {{0x7ea0016d,0x68e984dc,0x26dee100,0x629ae101}},	//   _köpt, mled, boto_, _yoto,
   {{0x65c59383,0x68e9a90e,0xddc590ef,0x24896102}},	//   _обла, lled, _обли, _enam_,
   {{0x81e600c8,0x91e32935,0x09e30139,0x35fb82e3}},	//   বেন_, воре, ворн, _ارشد_,
   {{0x2a6a0065,0x60cd35ff,0x20fa0a0d,0x6f0f2d70}},	//   sebb_, gnam, ्देश_, _bucc,
   {{0x6f0f379d,0x65690267,0x395800eb,0x63a00106}},	// [5080] _cucc, _ćeha, strs_, ämnd,
   {{0x2489003a,0xee3a0110,0x290c1313,0x68e9800d}},	//   _znam_, іне_, ídas_, hled,
   {{0xd00a6103,0xed5707a1,0xd82611d2,0x602650c4}},	//   _мене_, дох_, _одни, _одна,
   {{0x6e2e6104,0x68e9813c,0x2eaa809a,0x60cd00f7}},	//   _webb, jled, _छत्त, cnam,
   {{0x41c383eb,0x68e9bd9a,0x99878390,0xb05b1cce}},	//   _वेबस, dled, vanš_, _tjär,
   {{0x2ca6a715,0x6d4300f7,0x60c425a5,0x7d0e022c}},	//   skod_, ánac, liim, _tubs,
   {{0x63a2e105,0x629aa75e,0xde030676,0x6f0f0081}},	//   syon, _voto, _апри, _zucc,
   {{0x68e9805c,0x88bc801b,0xa774ac18,0x7cff00eb}},	//   gled, _hvěz, елич, _tūri,
   {{0x4426b15e,0x629aa713,0x26de822e,0xb4bc816f}},	//   mbo_, _toto, toto_, ेची_,
   {{0x60cd1807,0x4426e106,0x7e9880f7,0x60c401b4}},	//   znam, lbo_, سنجر_, hiim,
   {{0x68e9e107,0x26dee108,0x60c46109,0x60cd610a}},	//   bled, roto_, kiim, ynam,
   {{0x4426c096,0xb4d9000f,0x26de948e,0xb87b0091}},	//   nbo_, ़के_, soto_, _akín,
   {{0x80c1104f,0x26dee10b,0x78a30087,0x25088019}},	//   रोफे, poto_, _învi, _کرتی_,
   {{0xe7e2000f,0x45d48572,0x26de81b4,0x68e0913b}},	//   _खड़ा_, _полс, qoto_, lomd,
   {{0x31c40a29,0x6f0f33b0,0x442697ea,0x60cd610c}},	//   вств, _succ, kbo_, tnam,
   {{0x2d5880e7,0x2489610d,0x61e8d7d2,0x60cd336c}},	//   mée_, _unam_, _mydl, unam,
   {{0x4426e10e,0x2d5882be,0x2ca40106,0xa3c2073c}},	// [5090] dbo_, lée_, ömde_, ्पण_,
   {{0x05eb0003,0x60cd610f,0x44269262,0x7ead80e1}},	//   офеи_, snam, ebo_, _kúpa,
   {{0x2d5883d3,0x403504db,0x7ae509da,0x68e9e110}},	//   née_, _пенс, _ikht, yled,
   {{0x6d5a8364,0x4426e111,0x3f820699,0xb4bd01ab}},	//   itta, gbo_, _frku_, _इगो_,
   {{0x291e8528,0x27ff0036,0x2d588036,0x6ef8019d}},	//   _atta_, _àun_, hée_, ụbar,
   {{0x61e8827f,0xef1f02d0,0x4426b593,0xa3c20beb}},	//   _bydl, _itü_, abo_, ्पत_,
   {{0x4426cee0,0x68e9e112,0x387900fc,0x6d5ae113}},	//   bbo_, tled, _kasr_, jtta,
   {{0x2d5880e7,0x2aad04e8,0xd7ca8035,0x69d70609}},	//   dée_, ržby_, ापंच, _mxxe,
   {{0x68e9800b,0x443f803a,0x68fb89ec,0x41df873c}},	//   rled, _idu_, rmud, _पुरस,
   {{0xf1a79ff8,0x7d09e114,0x2d7e82a6,0x6d5a9388}},	//   _орен, _hies, _bċe_, ftta,
   {{0x7d0991d4,0x35a5d2e4,0x2d5880e7,0x6cc601e2}},	//   _kies, ханг, gée_, ейна,
   {{0x7cf61e51,0x7c2d808b,0x7fd58084,0x443f928a}},	//   káre, ðarh, _пілі, _jdu_,
   {{0x7d09e115,0x7655009a,0x6d5a853b,0x386dcb7e}},	//   _mies, _oczy, atta, meer_,
   {{0x386d80c9,0x78a9d567,0x7cf62631,0x44268824}},	//   leer_, lkev, dáre, zbo_,
   {{0x6d5ac2f3,0x2d5880e7,0xddc3c94f,0x60c433e1}},	//   ctta, cée_, _hanž, tiim,
   {{0xef1a039d,0x7d09c81c,0x7afc0503,0x78a9b36c}},	//   зма_, _nies, smrt, nkev,
   {{0x60c40ec8,0x068601a1,0x2b4600f7,0x645600b4}},	// [50a0] riim, нган, _íoc_, _icyi,
   {{0xddc3803e,0x386d9ecc,0x60c46116,0x443fc413}},	//   _manž, heer_, siim, _adu_,
   {{0x386d867f,0x443237cd,0x78a983ba,0x6da318d1}},	//   keer_, _key_, kkev, лифа,
   {{0x6b840370,0x26c5bee9,0x3f820b67,0xb4bc816f}},	//   _krig, hilo_, _trku_, ेचे_,
   {{0x7d09e117,0x386de118,0xaca3801c,0x07a34a8a}},	//   _dies, deer_, _giọn, _баян,
   {{0x443205b4,0xc3330051,0x4426e119,0x6d5ab117}},	//   _ley_, רוג_, sbo_, ytta,
   {{0x7d0986a5,0x2bc080d4,0x044680e8,0x09068162}},	//   _fies, _शेरा, _певн, нчим,
   {{0x386d9afa,0x2d5882be,0xa3c2016f,0x7d09e11a}},	//   geer_, vée_, ्पा_, _gies,
   {{0x26c58098,0x3f829dc5,0x68e3009f,0x68e0b635}},	//   filo_, íku_, _índe, romd,
   {{0xc6f793cd,0x61e880f2,0x2d5882be,0x629e611b}},	//   нных_, _tydl, tée_, _nopo,
   {{0xceb30bea,0x386d90f4,0x2f16006a,0x6b84611c}},	//   רית_, beer_, _læg_, _arig,
   {{0x2d5883d3,0x61e48214,0x6d5ae11d,0xac1900e8}},	//   rée_, ğild, rtta, ьому_,
   {{0x2d5883d3,0xdcf58063,0x60c2e11e,0x629e611f}},	//   sée_, _urzą, _imom, _bopo,
   {{0xda1085b3,0x629e6120,0x2d9884d6,0x2d588036}},	//   ाशित_, _copo, øres_, pée_,
   {{0x81e28a49,0x629e6121,0x6440a14e,0x6b846122}},	//   নের_, _dopo, _odmi, _erig,
   {{0x6b840f3b,0xb4da800d,0x61e58192,0x2e46826b}},	//   _frig, ठको_, ühli, _fífà_,
   {{0x7d09e123,0x6b844c78,0xf77300d5,0x84640098}},	// [50b0] _ries, _grig, داز_, _съще,
   {{0x443f8392,0x7ae500dd,0xf1b0856b,0x752d809a}},	//   _sdu_, _ukht, जनान, _łazi,
   {{0x7d09e124,0x387901ac,0x60c2ac5a,0x753a94cf}},	//   _pies, _tasr_, _omom, nstz,
   {{0x6b840144,0x7cf61727,0x38b18061,0xef1f06ae}},	//   _yrig, márc, _márc_, _ttü_,
   {{0x7d09e125,0x889a0bea,0x68ed6126,0x386d85f8}},	//   _vies, _חברי, mlad, veer_,
   {{0x386d837a,0x7d09e127,0x290b01a1,0x236900b9}},	//   weer_, _wies, _hica_, _mpaj_,
   {{0x7d099e52,0x26c5935a,0x386d837a,0x68ed6128}},	//   _ties, vilo_, teer_, olad,
   {{0x443fe129,0xb7f514fc,0xd6c400ab,0x290b612a}},	//   _udu_, _आराम_, ্তৃপ, _jica_,
   {{0x386dbcbc,0x290b612b,0x68ed612c,0x44323920}},	//   reer_, _mica_, ilad, _rey_,
   {{0x290b003b,0x386d92af,0xa68299bb,0x38b514a2}},	//   _lica_, seer_, альд, _hård_,
   {{0x68ed1385,0x26c5c108,0x19ab97ae,0x249f8176}},	//   klad, rilo_, _этап_, _koum_,
   {{0x629e612d,0x26c5bdc7,0x7cea81fa,0x68ed0efa}},	//   _sopo, silo_, týri, jlad,
   {{0xeb971bcf,0x629e399c,0x2d988bc5,0x6d48e12e}},	//   вия_, _popo, ører_, arda,
   {{0xc3328039,0x61e48214,0x7cf8b673,0x443201b4}},	//   שום_, şile, míre, _wey_,
   {{0x2056612f,0x68ed6130,0x291301df,0x6cda1194}},	//   ктар, flad, _cuxa_, _офис_,
   {{0x2055116b,0x7ae3e131,0xe3b2003d,0x290b6132}},	//   лтур, hont, _نرخ_, _cica_,
   {{0x629e6133,0x290b6134,0xb2261860,0x15f402f1}},	// [50c0] _topo, _dica_, _импл, _अरहर_,
   {{0x68ed6135,0x3f8013bd,0x248dc971,0x386011ee}},	//   alad, rviu_, _anem_, sfir_,
   {{0x200f8698,0x290b6136,0x7ae3e137,0x67246138}},	//   _oggi_, _fica_, dont, spij,
   {{0x67242a0a,0x68ed0fba,0x673bd05e,0xb7340019}},	//   ppij, clad, ksuj, _مہرب,
   {{0x7ae3e139,0x2bc8016f,0xdbcc8118,0x68e4613a}},	//   font, रपटा, _póño, moid,
   {{0x7ae38aa8,0x248de13b,0x29000009,0xe73704ae}},	//   gont, _enem_, lmia_, _јер_,
   {{0x2913041c,0xa9678195,0x2ab40799,0x290b0a03}},	//   _xuxa_, вија_, _gäbe_, _yica_,
   {{0x7e7c613c,0x7cf881df,0x68e4613d,0x64a39fb5}},	//   _harp, fíre, noid, _каса,
   {{0xb50c09a3,0x64a389c7,0x1306853b,0xdca38493}},	//   _संजय_, _тата, _азам, _тати,
   {{0xa3e605b3,0x3c320142,0x7ae39f21,0x68e4613e}},	//   _बुध_, _được_, cont, hoid,
   {{0x68ed3a59,0x6d489e12,0x68e4613f,0x2ab08032}},	//   ylad, urda, koid, _gàba_,
   {{0x249f07ca,0x7e7c002a,0x68e40198,0x7cf881d0}},	//   ðum_, _larp, joid, bíre,
   {{0xe0b78158,0xdb580d70,0x6b8280e5,0x7f4983a8}},	//   _בלאט_, кюр_, nvog, creq,
   {{0x68ed02c1,0x290b10e4,0x1ddd816f,0x29006140}},	//   wlad, _sica_, _नुकत, emia_,
   {{0x79a4117e,0xb50c00c2,0xf1a40a08,0x623412b2}},	//   арте, _संचय_, артн, ресу,
   {{0x38b1ddc8,0x645504ae,0x6b828140,0x6f0d80e5}},	//   _kára_, _свиђ, kvog, _èacc,
   {{0x44396141,0x68ed6142,0x57f5079e,0xc6f90329}},	// [50d0] mas_, rlad, упат, енах_,
   {{0x68ed3a88,0xa3c2146d,0x7d0d2c30,0x29130118}},	//   slad, ्पर_, _hias, _tuxa_,
   {{0x68ed6143,0xe7e3000d,0x7d0d022e,0x7e7c031d}},	//   plad, _कुरा_, _kias, _darp,
   {{0x44390f29,0x73d994f6,0x442b151e,0x78b60110}},	//   nas_, ндер_, nbc_, chyv,
   {{0x44396144,0x7d0d0063,0xe3b080a0,0x7ae3aea5}},	//   ias_, _mias, يره_, tont,
   {{0x443945d0,0x7ead80f7,0xddce0019,0x78ad0254}},	//   has_, _cúpl, _ebbő, lkav,
   {{0x44391de0,0x260212ee,0xceb200be,0x2d9c0edd}},	//   kas_, वेदी_, _פיל_, øvet_,
   {{0x44392585,0x7ae3e145,0x6e356146,0x7e7c0c43}},	//   jas_, sont, _hezb, _zarp,
   {{0xe50a0104,0xa6e58162,0x7ae3e147,0x0fca809a}},	//   _mặt_, лжил, pont, ापगढ,
   {{0x63a48009,0xc7b98019,0x1ab795bc,0xe3b0853d}},	//   äine, rző_, _अतिथ, _برف_,
   {{0x64a619bb,0x3cca091e,0x78ad3d47,0x60559a43}},	//   гана, елно_, kkav, _مناط,
   {{0x44396148,0x7d0d6149,0xb4de016f,0x38b18b4e}},	//   gas_, _cias, तके_, _fára_,
   {{0x889a812a,0xf7459df3,0x387fd73b,0x60c9dfd2}},	//   _רבני, _село, mdur_, miem,
   {{0x387f8125,0x7f3a810f,0x60c98791,0x3866e14a}},	//   ldur_, _טענו, liem, _zbor_,
   {{0x4439614b,0xa06a1a20,0x1a6602e3,0x3916003d}},	//   bas_, нава_, نیکی_, اورز,
   {{0x443907a3,0x387fe14c,0x7d0d0420,0x2d5c06a5}},	//   cas_, ndur_, _gias, víe_,
   {{0x6e351487,0xa4fb0039,0x0e6600c4,0x442059a0}},	// [50e0] _bezb, _אלקט, лкан, _ifi_,
   {{0x7c3650e3,0x7643808e,0x387d8114,0x42560162}},	//   _heyr, _jdny, _lawr_, _стит,
   {{0xa9a60d9e,0x6e350087,0x60c99c43,0x7d0d022c}},	//   _синд, _dezb, kiem, _yias,
   {{0x6d5e614d,0x6adc8a27,0x7c360326,0x387d8114}},	//   rtpa, मक्र, _jeyr, _nawr_,
   {{0x7e7c0b71,0xfaa6a8f9,0x387fd0e3,0x44200300}},	//   _tarp, ладо, ddur_, _mfi_,
   {{0x4439612d,0x38b5035f,0x6b82e14e,0x442001e0}},	//   zas_, _våre_, rvog, _lfi_,
   {{0x6722c9e5,0x81e600c8,0x38b18b4c,0x44202c5a}},	//   _stoj, বের_, _sára_, _ofi_,
   {{0xb4de000d,0xa96780f7,0xfce6806d,0x3f868722}},	//   तको_, اميم_, _собо, _prou_,
   {{0xdfd080f7,0x2d87920b,0x7d0d614f,0xddcf811f}},	//   تية_, _arne_, _rias, _češa,
   {{0x44396150,0x44204e75,0x7d0d5008,0x3f86879f}},	//   was_, _afi_, _sias, _vrou_,
   {{0xa9269b1c,0x2d87803b,0x387d831d,0x8b03801b}},	//   _сдел, _crne_, _fawr_, ířen,
   {{0x60c9e151,0xd5b797d4,0x3f86e152,0xab5b0061}},	//   ciem, усь_, _trou_, nzüg,
   {{0x44392e58,0x2d87e153,0x9990012b,0x7c3610ea}},	//   ras_, _erne_, _čaše_, _deyr,
   {{0xbda688ca,0x78a2e154,0x3ce69d6d,0x8c3d8085}},	//   _محبو, _hoov, hoov_, _xoşb,
   {{0x7d0d01c0,0x2b40803e,0xc693807c,0x7cf66155}},	//   _tias, šich_, _לאס_, márn,
   {{0x7cf66156,0x6e3ae157,0x443904b7,0x7d028c83}},	//   pára, latb, qas_, jmos,
   {{0x96350e0b,0xe50a0028,0x611c007a,0x81e60264}},	// [50f0] инац, _vặt_, _včla, বেল_,
   {{0xd251019f,0x78ad6158,0x7cf60e93,0xda190ebf}},	//   _بند_, skav, nárn, _दलित_,
   {{0x7ae7003a,0x2d870df0,0x6e35025b,0xdd1e016b}},	//   mojt, íne_, _vezb, _píše,
   {{0x81cd80c8,0x611c0eef,0x387f8201,0x52dd903e}},	//   রথম_, _učla, xdur_, यव्स,
   {{0x60c9c09d,0x2d9c0aa2,0xa85604de,0x7cf6026f}},	//   viem, øver_, _דירה_, kárn,
   {{0xddda8065,0xae048ebf,0x38a702f1,0x6925a60a}},	//   hető, रधान_, _võru_, амка,
   {{0x746b9ff3,0x60c9be67,0x59df8074,0xa5f80ba1}},	//   _прав_, tiem, _पुखर, _беру_,
   {{0x6aa180ed,0x52d20fb8,0xe7f08fb2,0xcf458037}},	//   _wolf, _सद्स, _चरखा_, аний,
   {{0x44206159,0x60c9e15a,0x6e3a826c,0x387fdfd4}},	//   _rfi_, riem, fatb, rdur_,
   {{0x4d658dc8,0x60c9e15b,0xb05b016d,0x7c361d84}},	//   аков, siem, _smäl, _seyr,
   {{0xcc8a003d,0x9962816b,0xd9998290,0x60c9e15c}},	//   ننده_, píše_, _جنات_, piem,
   {{0x38589a3e,0x7c360085,0x6b89ad0e,0x2d8782d4}},	//   _مشهد_, _qeyr, _kreg, _vrne_,
   {{0x6e3a8420,0x7c290b5a,0x7643808e,0x290f81b4}},	//   batb, ñera, _tdny, _iiga_,
   {{0xceb8809a,0x7643806a,0xab2736ac,0x290f82c4}},	//   chę_, _udny, рора_, _higa_,
   {{0xe2972f63,0x7c360428,0x81138264,0x61ed89ab}},	//   шар_, _teyr, _সবুজ_, ƙalu,
   {{0x290f96ea,0xdd2f001b,0xa01b18b6,0x3ce68282}},	//   _jiga_, _běžn, _snör, xoov_,
   {{0xe8012f7b,0xc87f02af,0x1fa71cfb,0x7cf600e1}},	// [5100] लेला_, _daß_, акти_, láro,
   {{0x645b9727,0xda660396,0x27f28163,0x63ab8338}},	//   _acui, _твои, _øyne_, dygn,
   {{0x7cf603b0,0x2480022c,0x6b89e15d,0x290f8216}},	//   náro, _kaim_, _areg, _oiga_,
   {{0xb4c42e04,0x6b89e15e,0x232aa7d4,0x248000dd}},	//   _एगो_, _breg, води_, _jaim_,
   {{0x93778013,0x6b89e15f,0x24800282,0xf74604ae}},	//   لصور_, _creg, _maim_, _њего,
   {{0x78a28006,0x3ce681c5,0xddda8019,0x24800282}},	//   _soov, soov_, zető, _laim_,
   {{0x7cf62620,0x6b898314,0x290fe160,0x6e3a8061}},	//   várn, _ereg, _biga_, vatb,
   {{0x645b8013,0x7afd80eb,0x7cf8801b,0x63ab8edd}},	//   _gcui, _īste, bíra, bygn,
   {{0x290fe161,0x7c2de162,0x7cf60c83,0x6569026c}},	//   _diga_, ñare, tárn, _ćehi,
   {{0x4aaa85fc,0x290fac9f,0x27ef8106,0x1b1d8264}},	//   _कविव, _eiga_, _dygn_, _নিচে_,
   {{0x7cf6026f,0x7cfd28d6,0x290f8b57,0x2480123c}},	//   rárn, hére, _figa_, _baim_,
   {{0x290f84be,0x55770158,0x7cf60019,0x49110074}},	//   _giga_, בעטן_, sárn, _दूगो_,
   {{0x248001e9,0xe8d78039,0xa2bd8a27,0xbbd127bc}},	//   _daim_, _דואר_, वोक्, सपेक,
   {{0x290f8133,0x7cfd0036,0x61ed8326,0x175783de}},	//   _ziga_, dére, ƙalt, _כסדר_,
   {{0x7ae700f1,0x6ac49885,0x4de6016f,0x290fe163}},	//   rojt, _वगैर, _जुलै_, _yiga_,
   {{0x7cfd02be,0x2d850118,0x290f0f02,0x290f8df6}},	//   fére, _álei_, öga_, _xiga_,
   {{0x69de6164,0x7d1881c0,0xb8cf03ca,0x7ae7016b}},	// [5110] _expe, _huvs, _कव_, pojt,
   {{0x26cca018,0x6b89820f,0x7c3d6165,0x7f4d0980}},	//   nido_, _rreg, lasr, rraq,
   {{0x68e3157a,0x641581a8,0xaadc01c6,0xafdb2474}},	//   _índo, مواط, _בחזר, _idøm,
   {{0x40950013,0x8c3d861c,0x2480022c,0x88bc81d0}},	//   _الحر, _boşa, _xaim_, _stěn,
   {{0x26cc8637,0x7cf66166,0x290fe167,0x21258101}},	//   kido_, záro, _riga_, _stlh_,
   {{0x60cd6168,0x290f80a2,0x26cc86a5,0xe50a0129}},	//   liam, _siga_, jido_, _lặp_,
   {{0x26cc8510,0x290f8245,0x272380e1,0x7cf6002a}},	//   dido_, _piga_, kčný_, xáro,
   {{0x60cd6169,0x6b89820f,0x3949c966,0x2602016f}},	//   niam, _treg, čas_, वेळी_,
   {{0x6b89e16a,0x443de16b,0x290f82f1,0xea0000ff}},	//   _ureg, maw_, _viga_, _thầu_,
   {{0x443dd86c,0xe8e00028,0x7cf60065,0x7ead81ac}},	//   law_, _đọc_, táro, _kúpi,
   {{0x290f8812,0x60cd01e2,0x3cff8069,0x248001c0}},	//   _tiga_, kiam, _khuv_, _paim_,
   {{0x6459e16c,0x62819b8e,0x7cf6616d,0x443d8948}},	//   ngwi, _halo, ráro, naw_,
   {{0x26cc9986,0x60cd30af,0x2480616e,0x68e9bbcb}},	//   bido_, diam, _vaim_, moed,
   {{0x26cc9313,0x443de16f,0x26c79083,0x68e98114}},	//   cido_, haw_, _umno_, loed,
   {{0x6281a786,0x443de16b,0x60cd6170,0x24806171}},	//   _malo, kaw_, fiam, _taim_,
   {{0x7cfd07bc,0xe50a0028,0x6281e172,0x443d81b9}},	//   tére, _gặp_, _lalo, jaw_,
   {{0x7c246173,0x2d8a10d3,0x98a30758,0xddd5007a}},	// [5120] _ifir, _srbe_, чите, _razš,
   {{0x38b504b8,0x6281cb39,0x68e98355,0x81e280ab}},	//   _våra_, _nalo, hoed, নেট_,
   {{0x99860013,0x60cd0098,0xc27b00be,0x6d41e174}},	//   _الجو, biam, _גריי, nsla,
   {{0x26cc83a7,0x443d8948,0x7cfd5496,0x6281e175}},	//   zido_, gaw_, mérc, _aalo,
   {{0x44270086,0x68e9831d,0x44220326,0x7cf60376}},	//   _ən_, doed, ick_, járm,
   {{0x26cc862f,0x6d41e176,0x2480883d,0x62838267}},	//   xido_, ksla, žim_, gdno,
   {{0x443dc6e1,0x26cc9820,0x6281e177,0x7c243065}},	//   baw_, vido_, _dalo, _ofir,
   {{0xa3b81299,0x6d4184fe,0x236984b7,0x68e9e178}},	//   चना_, dsla, ħajr_, goed,
   {{0x26cc8510,0x291a48e9,0x6281e179,0x6d418cab}},	//   tido_, _lupa_, _falo, esla,
   {{0x6d419ead,0x7cf60065,0x60cd58b7,0x877b03de}},	//   fsla, sárl, ziam, נאיי,
   {{0x26cc8510,0x7c2905e4,0x7cf8b541,0x7c3b0789}},	//   rido_, ñero, níro, ðuro,
   {{0x6281e17a,0x7c22b326,0x7aeae17b,0x2b40992c}},	//   _zalo, ncor, loft, šicu_,
   {{0x940301b6,0x26cc80a2,0x60cd617c,0x6e38bddf}},	//   रेंच_, pido_, viam, _tevb,
   {{0x2b448118,0x6281e17d,0x7c2f0118,0x7c24029a}},	//   _mvmc_, _xalo, sbcr, _efir,
   {{0x443d843b,0x60cd617e,0x291a3570,0x7c2402a6}},	//   yaw_, tiam, _cupa_, _ffir,
   {{0x291a0012,0x7cf882b7,0x776401b9,0x26ca617f}},	//   _dupa_, díro, ftix, _ambo_,
   {{0x60cd130f,0x7bda07d9,0xfc3f00f7,0x2aab813c}},	// [5130] riam, ştur, maí_, _købt_,
   {{0x765a8110,0xfc3f0013,0xd5bb0071,0x60cd6180}},	//   ngty, laí_, лсе_, siam,
   {{0x443de181,0x7c240125,0x443b00f1,0x3cffcbb1}},	//   taw_, _yfir, _keq_, _phuv_,
   {{0xfc3f0307,0x6b8d6182,0xaca3801c,0xb4e380dc}},	//   naí_, _krag, _miện, नके_,
   {{0xeb99838d,0x6281e183,0x68e9837a,0x20d3802e}},	//   рил_, _palo, voed, nţie_,
   {{0xfc3f0013,0x443d95d0,0x38696184,0x7c22e185}},	//   haí_, saw_, lfar_, acor,
   {{0x442200f2,0x443de186,0x3cff822c,0xaa5684ae}},	//   yck_, paw_, _thuv_, цију_,
   {{0x7c22e187,0x386900f7,0x81e600ab,0x7c3b008b}},	//   ccor, nfar_, বেক_, ðurl,
   {{0x6449e188,0x6281d5bc,0xef1691e9,0xfc3f00f7}},	//   _idei, _talo, омы_, daí_,
   {{0x7c3be189,0x823489d7,0xee39867c,0x6d419412}},	//   _heur, _فرما, шно_, tsla,
   {{0x6b8d618a,0x7cd20029,0x7c3be18b,0x6da595fe}},	//   _arag, kārt, _keur, цина,
   {{0x291a0886,0x6b8d56ef,0x4422618c,0xfc3f01a8}},	//   _rupa_, _brag, uck_, gaí_,
   {{0x7c3bbb61,0xe7399ff3,0x6d41a130,0x2d98816d}},	//   _meur, _тел_, ssla, ärer_,
   {{0x291a0091,0x7c3b83d3,0x6b8d079a,0x6d41e18d}},	//   _pupa_, _leur, _drag, psla,
   {{0xed59b2a7,0x6b8d011e,0x3869618e,0x64a6618f}},	//   _той_, _erag, ffar_, _мака,
   {{0x7c3be190,0xb4e383bb,0x7c2281df,0x6b8d49f6}},	//   _neur, नको_, xcor, _frag,
   {{0xee3a05f1,0x3ea788c2,0xc31f80ab,0x20d3802e}},	// [5140] ина_, _kont_, নীতি_, cţie_,
   {{0x6449831d,0x291a11ca,0x7cfd03e6,0x7764002a}},	//   _adei, _tupa_, méra, rtix,
   {{0x7c3be191,0x6e3e6192,0x77646193,0x3ea7d433}},	//   _beur, rapb, stix, _mont_,
   {{0x61fe4464,0x7c3be194,0x2fc06195,0x672d01c0}},	//   _izpl, _ceur, pzig_, bpaj,
   {{0x7c22e196,0x7cfd03d3,0x7c3bbbe3,0x75248052}},	//   rcor, néra, _deur, _čizm,
   {{0x7c22e197,0x7cf883b0,0x6d5701df,0x68f66198}},	//   scor, píro, buxa, llyd,
   {{0x44248118,0x7c3bd1af,0x7cfd6199,0x7aea92ec}},	//   _tfm_, _feur, héra, roft,
   {{0x6e3c619a,0x8f468c3e,0xddd8826f,0xbebb00f1}},	//   _herb, оход, _navš, _atëh,
   {{0xd6da8021,0x629e8364,0x24868bb1,0x7ead92ca}},	//   ито_, öpos, mdom_, _lúpu,
   {{0x3ea78012,0x2366b77f,0x7cfd272c,0x3eb8bde3}},	//   _cont_, mtoj_, déra, órt_,
   {{0xfc3f0307,0x691583bb,0x3ea78220,0x6e3c619b}},	//   taí_, _všec, _dont_, _merb,
   {{0x2486b139,0xef1f0192,0x92da00ab,0x672d0282}},	//   ndom_, _früh_, ়তো_, ypaj,
   {{0x3ea781b3,0xfc3f0013,0x2bc5035a,0x395800e7}},	//   _font_, raí_, _लेखा, eurs_,
   {{0x6b8d02d8,0xfc3f0013,0xd6d9809a,0x6e3c619c}},	//   _vrag, saí_, kuły_, _nerb,
   {{0x298815b5,0x2486e19d,0xfc3f01a8,0xca140081}},	//   осто_, kdom_, paí_, ддръ,
   {{0x7cfd2386,0xa3e6086a,0x27208242,0x92bd00ab}},	//   béra, _बुक_, _kòn_, েকে_,
   {{0x6e3c010b,0x3869619e,0xb4e700c2,0x7c3b9cb2}},	// [5150] _berb, rfar_, बकी_, _reur,
   {{0x7c3b8364,0x2720e19f,0x612787d9,0x6e3c0114}},	//   _seur, _mòn_, _yıld, _cerb,
   {{0x628502c4,0x6e3c2bc2,0x7c3be1a0,0x6fdd06af}},	//   _iaho, _derb, _peur, _यशवं,
   {{0x645d04bf,0x7d1c61a1,0x24869da3,0x6abaa3d9}},	//   ngsi, _durs, gdom_, _altf,
   {{0x62851f3c,0x7c3b87e2,0x889a0039,0xd37b9a1f}},	//   _kaho, _veur, _הברי, рче_,
   {{0x7d1c61a2,0x6e3c61a3,0x63a0016d,0x29090198}},	//   _furs, _gerb, ämni, lmaa_,
   {{0xf2d40158,0x62852335,0x7c3b8a48,0x3ea798e8}},	//   ועס_, _maho, _teur, _ront_,
   {{0x3ea786e3,0x6e3c011e,0x6d452f61,0x38bc00f7}},	//   _sont_, _zerb, msha, _tíre_,
   {{0x27208104,0x6d4502a3,0x3ea7e1a4,0x6e3c61a5}},	//   _còn_, lsha, _pont_, _yerb,
   {{0x6285000d,0x92b780d5,0x7cf661a6,0x260202f1}},	//   _naho, _بحرا, mári, वेकी_,
   {{0x6d4561a7,0x7cf6335a,0x3ea7e1a8,0xbec301a9}},	//   nsha, lári, _vont_, _ķīli,
   {{0x7f4400e7,0xf2c900be,0x7cff0110,0x7cfd2e90}},	//   ysiq, _גע_, _kūry, téra,
   {{0x7cf60907,0x628561a9,0x68ed0101,0x2720801c}},	//   nári, _baho, doad, _gòn_,
   {{0x395861aa,0xe0df0032,0x6d45286c,0xdd0100eb}},	//   turs_, _ajò_, ksha, ītāj,
   {{0x6285132b,0x272086c0,0x7641e1ab,0xdddc0087}},	//   _daho, _zòn_, maly, _marţ,
   {{0x6f1d2b49,0x6e3c61ac,0x6d45413a,0x7cfd61ad}},	//   _busc, _serb, dsha, péra,
   {{0x6e3c3897,0x7d1c61ae,0x6f1d00e5,0x6f1547d1}},	// [5160] _perb, _surs, _cusc, _bizc,
   {{0x1fb5035f,0x6f1d0004,0x7cf661af,0x226501d6}},	//   єстр, _dusc, dári, ľský_,
   {{0xc27b004c,0x6e3c3139,0x68ed04c3,0x7f4400e7}},	//   _פרטי, _verb, boad, ssiq,
   {{0x6e3c02af,0x13b000ab,0x6285141f,0x6f1d61b0}},	//   _werb, _চেয়, _zaho, _fusc,
   {{0x6e3c045c,0x2486e1b1,0x6aa88668,0x7d044280}},	//   _terb, rdom_, _podf, _mhis,
   {{0x7d1c02a5,0x3f8202c1,0x66c0016d,0x46c01513}},	//   _turs, _isku_, _sökf, _एतिह,
   {{0x386b00f7,0x6f1d01ec,0x60dbd79c,0xfe55004e}},	//   _éirí_, _zusc, fnum, _زینب_,
   {{0x78a4003a,0xfaff00f1,0x4ddb0039,0x23668168}},	//   njiv, jtën_, _החלו, ptoj_,
   {{0x4426e1b2,0x2ca90039,0x289b2b7b,0x7cf609b2}},	//   mco_, _road_, מיקא, cári,
   {{0x4426be36,0x7d042f57,0x7d1602d6,0x02ce0035}},	//   lco_, _ahis, _aiys, होमभ,
   {{0x62852a19,0x69c38063,0xfaff0168,0x442680e5}},	//   _raho, czne, ftën_, oco_,
   {{0x7d0461b3,0x44269f21,0x62850461,0x6442e1b4}},	//   _chis, nco_, _saho, naoi,
   {{0x68e32755,0x78a40052,0xaf078077,0x7d042cef}},	//   _índi, djiv, تقیم_, _dhis,
   {{0x764a806a,0x64428c41,0x6f1d61b5,0xb05b0192}},	//   _udfy, haoi, _rusc, _kläg,
   {{0x6f1d0018,0x291e8483,0x68ed42da,0x62874c3f}},	//   _susc, _juta_, toad, rdjo,
   {{0x291ee1b6,0x9ddb8039,0xe8b50214,0x7cfd00e7}},	//   _muta_, _לקוח, _dışı, méro,
   {{0x442961b7,0x291ee1b8,0x20d38087,0x6f150661}},	// [5170] _ifa_, _luta_, nţia_, _pizc,
   {{0x6d450234,0x7cf60c83,0x290907b8,0x80c1170c}},	//   tsha, vári, smaa_, रोजे,
   {{0x6f15434c,0x7c2d8511,0x3f820102,0x6e250192}},	//   _vizc, ñaro, _esku_, rchb,
   {{0xdd8680d5,0x7cf609e9,0x7bf98dae,0xe45f0106}},	//   _یو_, tári, онер_, ngö_,
   {{0x6d4561b9,0x2d9c016d,0x6d5ae1ba,0x68e483f2}},	//   ssha, äver_, huta, čidl,
   {{0x7cf60073,0x28ca8d86,0x4426e1bb,0x1ee71e5c}},	//   rári, ़ोसि, aco_, _روزی_,
   {{0x6d5ae102,0xaca381bc,0x7641e1bc,0x7cf661bd}},	//   juta, _akụn, valy, sári,
   {{0x4426e1be,0x7cfd0b2c,0x291e859e,0x6d5ae1bf}},	//   cco_, déro, _duta_, duta,
   {{0x3eaa61c0,0x6d4ea3b9,0xf70880ff,0x69c3900b}},	//   _yobt_, ában, _hủy_, szne,
   {{0x442961c1,0x7d0461c2,0x443f809f,0x644d61c3}},	//   _afa_, _shis, _heu_, _adai,
   {{0xb05b00f2,0x6d5ad75e,0x443f8970,0xa50a15b7}},	//   _kläd, guta, _keu_, жена_,
   {{0x443f83d3,0x2d9102a5,0x41748154,0x3f8f8805}},	//   _jeu_, _mrze_, _سامس, _trgu_,
   {{0x443fe1c4,0xaca3801c,0xdddc1247,0x20d3802e}},	//   _meu_, _chỉn, _marš, cţia_,
   {{0x6d5abe4b,0x442961c5,0x442685a4,0x66c0257d}},	//   buta, _efa_, zco_, _köke,
   {{0x7cfd087a,0x7d045fa3,0x3f8d8548,0x442961c6}},	//   céro, _this, lveu_, _ffa_,
   {{0x443f9f8b,0xe8fa05e9,0xf1b804b7,0x44269f1f}},	//   _neu_, іла_, ġġ_, xco_,
   {{0x2ab40006,0x98a6a0f1,0xf7432865,0xa6860187}},	// [5180] _läbi_, žiće_, кето, млад,
   {{0x6b843219,0x2d910024,0x61e481cc,0x257e01d0}},	//   _isig, _brze_, şili, _půl_,
   {{0x329b0039,0x1a9b0039,0x4426e1c7,0x201e0087}},	//   _וביד, _וייע, tco_, _ştiu_,
   {{0x291e91b9,0x44268272,0x2d9102a5,0x386d80f3}},	//   _ruta_, uco_, _drze_, jfer_,
   {{0x443f8931,0x7c3b007b,0x64428090,0x291eccc1}},	//   _deu_, ðuri, raoi, _suta_,
   {{0x291e803b,0x7c298133,0x44269441,0x2bd2816f}},	//   _puta_, _efer, sco_, _देणा,
   {{0x443fae48,0x7cfd01df,0x2d8c0317,0x7c298114}},	//   _feu_, xéro, _éde_, _ffer,
   {{0x6b84003a,0x52bb0f85,0x38605a54,0x2724016d}},	//   _osig, _उत्स, ngir_, _kön_,
   {{0x4fc681bb,0x291e8337,0x27240019,0x776992b7}},	//   ьска, _wuta_, _jön_, gtex,
   {{0x6440e1c8,0x6d5a80ad,0xc6f781bb,0x442901e0}},	//   _hemi, tuta, мных_, _sfa_,
   {{0x629ae1c9,0x6b8461ca,0x2724016d,0x443f80ff}},	//   _into, _asig, _lön_, _yeu_,
   {{0xe57100be,0x7e7a8f33,0x3f8d8bda,0x409380f7}},	//   אַך_, setp, bveu_, _للمر,
   {{0x6d5a8665,0x6440848f,0x6288e1cb,0x764e009a}},	//   suta, _memi, _kado, _odby,
   {{0x6440e1cc,0xdd909ec9,0x6288e1cd,0x628aa2b7}},	//   _lemi, _موت_, _jado, ndfo,
   {{0x6b8461ce,0x29068028,0x44290037,0xaf0781a8}},	//   _esig, _khoa_, _tfa_, _تقوم_,
   {{0x6440e1cf,0xd788801c,0x2b498bcf,0xe45f1647}},	//   _nemi, _kể_, šaci_, riös_,
   {{0x443fe1d0,0x6d48e1d1,0x7c29dc71,0x569501e5}},	// [5190] _reu_, lsda, _rfer, наат,
   {{0x443f907f,0x27240457,0x629a808e,0xceb898eb}},	//   _seu_, _dön_, _nnto, nkę_,
   {{0x443fe1d2,0x6d48a539,0x6d5a016d,0x6440d598}},	//   _peu_, nsda, _åtal, _bemi,
   {{0x629ae1d3,0x6440e1d4,0x6288846d,0x7769810c}},	//   _anto, _cemi, _aado, ytex,
   {{0x6288c0ee,0x66c000f2,0x443f9209,0xf8bf077f}},	//   _bado, _söke, _veu_, _ilé_,
   {{0x6288e1d5,0x6d488186,0x29190010,0x248901c0}},	//   _cado, ksda, _hisa_, _laam_,
   {{0x6288e1d6,0x443fe1d7,0x291961d8,0xceb88035}},	//   _dado, _teu_, _kisa_, dkę_,
   {{0x24892468,0x629a9883,0x6440d68b,0x26dee1d9}},	//   _naam_, _ento, _gemi, ento_,
   {{0x386de1da,0x2369022c,0x6288d53d,0xb275a109}},	//   rfer_, _nqaj_, _fado, _плаш,
   {{0xd7068364,0x6440e1db,0x386d9e34,0x7ce80085}},	//   нные_, _zemi, sfer_, zırd,
   {{0xab5b0065,0x7769e1dc,0x6440e1dd,0xf8bf61de}},	//   szül, stex, _yemi, _olé_,
   {{0x291961df,0x672f0042,0x0fd0816f,0x6440e1e0}},	//   _nisa_, _otcj, _तेवढ, _xemi,
   {{0x7f5b8079,0x2cad9384,0x68fb82d0,0x2bba01a8}},	//   quuq, _moed_, mlud, ساحة_,
   {{0xc3329a15,0xf8bf0091,0x290da5f1,0xdbcd1434}},	//   רום_, _alé_, lmea_, róðr,
   {{0x291961e1,0xf652810f,0x2724016d,0x3d1882f1}},	//   _bisa_, _עצה_, _sön_, _बूझे_,
   {{0x7cf88510,0xb05b016d,0xf8bf33f7,0x6f1886ec}},	//   píri, _smär, _clé_, _zivc,
   {{0x2919020f,0x64460274,0x386061e2,0x27e602be}},	// [51a0] _disa_, maki, rgir_, çon_,
   {{0x6446486e,0x291e0ece,0x212100b9,0x2cbf8144}},	//   laki, ítas_, _fuhh_, _alud_,
   {{0x6440859c,0x62888b48,0x2cbf826c,0x68fb93c2}},	//   _pemi, _rado, _blud_, klud,
   {{0x9346a2e9,0x8fa661e3,0x644661e4,0x291961e5}},	//   енде, _заме, naki, _gisa_,
   {{0x6288e1e6,0x7cf600e1,0x691584e8,0xceb8e1e7}},	//   _pado, lárs, _všel, ykę_,
   {{0x644661e8,0x764e006a,0x7645008e,0x9258896b}},	//   haki, _udby, cahy, факт_,
   {{0x62889d93,0x644661e9,0x6440e1ea,0x66e34f8f}},	//   _vado, kaki, _temi, _сора,
   {{0x2cad98db,0x6288a71b,0x6d4e8511,0x7e7e61eb}},	//   _goed_, _wado, ábam, lepp,
   {{0x6d5e61ec,0x93aa8b76,0xdefa8071,0x644661ed}},	//   lupa, _عارف_, зын_, daki,
   {{0x2489079f,0x6d48848d,0x59b202f1,0x26de847f}},	//   _saam_, tsda, ीनार, unto_,
   {{0xd5b78a08,0x68fb8052,0x61db8f21,0x998c8b80}},	//   еся_, blud, यपृष, _hedž_,
   {{0x68fb8051,0x7cf601ac,0xb87b026b,0x27e60035}},	//   clud, dárs, _ajín, żony_,
   {{0x29191cd4,0x60c4135e,0x5ef561ee,0x7e7e008b}},	//   _risa_, dhim, ्तम्_, kepp,
   {{0x2919059c,0x8f9b83c8,0x8caa83b7,0xfd748162}},	//   _sisa_, _מידי, _झकझो, _алкэ,
   {{0xa2b3836d,0x644661ef,0x291918de,0xf8bf00f7}},	//   _अवस्, baki, _pisa_, _plé_,
   {{0x6d5e0867,0xb5fb810f,0x76450359,0x60c41341}},	//   dupa, _מלוכ, wahy, ghim,
   {{0x291961f0,0x3f8683bb,0xf1b900eb,0xddc8e1f1}},	// [51b0] _visa_, _jsou_, ņš_, nedž,
   {{0x798501e9,0xdd950009,0xb05b016d,0x212100dd}},	//   _tshw, казы, _bläc, _tuhh_,
   {{0x7cf661f2,0x764561f3,0x291961f4,0xe2a7007b}},	//   párt, rahy, _tisa_, æður_,
   {{0x2bd29d41,0xec158077,0x2919008e,0x7c2d0609}},	//   _देहा, نواد, _uisa_, _jfar,
   {{0x68fbe1f5,0x45188fd3,0x80a492c6,0x2cad8a53}},	//   vlud, رآمد_, काने, _voed_,
   {{0x6d5e12fb,0x644661f6,0xeb969577,0xb05b3cac}},	//   bupa, zaki, тиш_, _fläc,
   {{0x6446015d,0x3f8686c4,0x6d5e1140,0x7ae48118}},	//   yaki, _asou_, cupa, éita,
   {{0xa3c1053e,0x2bd287e6,0x2919816d,0xddc88b80}},	//   ंना_, _देवा, ösa_, fedž,
   {{0x776d61f7,0x442dab2f,0x644661f8,0x5b15b068}},	//   ntax, _ife_, vaki, _амат,
   {{0x7c2d61f9,0x644661fa,0x68fbe1fb,0x1e9581cf}},	//   _afar, waki, slud, трир,
   {{0x644661fc,0x7d1bb186,0x7f498037,0x3eae8338}},	//   taki, _kius, sseq, _doft_,
   {{0x7c2d00f1,0x893480f7,0x2247d5b9,0x60c403ed}},	//   _cfar, _إعلا, lank_, xhim,
   {{0x442d8870,0x78a9ae94,0x7d098010,0x387f829c}},	//   _mfe_, mjev, _mhes, meur_,
   {{0x387fe1fd,0x644661fe,0x4804835f,0x3eae81c0}},	//   leur_, saki, _спів, _goft_,
   {{0x442de1ff,0x44393cc0,0x64466200,0x60c46201}},	//   _ofe_, bbs_, paki, thim,
   {{0x78a984c4,0x442dae3b,0x8c3d8214,0x387fe202}},	//   njev, _nfe_, _koşu, neur_,
   {{0x7643e203,0x2fc924de,0x442010ab,0x60c420d5}},	// [51c0] _keny, gzag_, _igi_, rhim,
   {{0x60c46204,0x6d5e40ff,0x06e380ab,0x442de205}},	//   shim, tupa, _নীতি, _afe_,
   {{0x76438458,0x2b4d9cb0,0x78bb84a2,0x629e6206}},	//   _meny, _avec_, kkuv, _inpo,
   {{0x6d5e0393,0x7643e207,0x7e7e1e75,0x7523930e}},	//   rupa, _leny, sepp, _munz,
   {{0x2bd2816f,0x7d1b8458,0x6d5e4794,0xfbd290be}},	//   _देशा, _dius, supa, _देशम,
   {{0x442de208,0x628e6209,0x442009ca,0x3866e20a}},	//   _efe_, ndbo, _lgi_, _scor_,
   {{0xe5a30b01,0xada3620b,0x67228009,0x442d82ec}},	//   _кири, _карл, _suoj, _ffe_,
   {{0x7d1b8698,0x442d808e,0x61fa83f2,0x2b4d0bda}},	//   _gius, _gfe_, _vytl, šeci_,
   {{0x7643e20c,0xaca38028,0xb4be809a,0x6f1c620d}},	//   _beny, _giốn, इसी_, _kirc,
   {{0x7cfd620e,0x38b5016d,0x7c2d620f,0xb87b026b}},	//   méri, _hårt_, _sfar, _ajíl,
   {{0x7643e210,0x7cfd0e14,0xceb3012a,0xb8e880c8}},	//   _deny, léri, ייז_, _ঈদ_,
   {{0x6b9604fe,0x776d0085,0xc5f30039,0xb86580d7}},	//   _bryg, ytax, ידת_, _ماهو,
   {{0x44396211,0x60c28280,0x3f86a47a,0x317a4fc7}},	//   rbs_, _ilom, _usou_, _appz_,
   {{0x7523ac2f,0x76438205,0x6b966212,0x26c580e1}},	//   _funz, _geny, _dryg, chlo_,
   {{0x7c3b0125,0x34952432,0x60c2cddb,0x7c2901df}},	//   ðurs, _байр, _klom, ñers,
   {{0x6b96006a,0x7c2d1ffb,0x764380b8,0x629e03ec}},	//   _fryg, _ufar, _zeny, _enpo,
   {{0x7d1b8098,0x7643a7cb,0x7d09831d,0x2247808e}},	// [51d0] _rius, _yeny, _rhes, yank_,
   {{0x776d6213,0xfe701e09,0x6f1c33b0,0x7648be23}},	//   rtax, قدم_, _circ, nady,
   {{0x776d6214,0x60c2e215,0x387f80e7,0x6f1c6216}},	//   stax, _olom, yeur_, _dirc,
   {{0x8c3d8162,0xf4e18264,0xaf3700d7,0x387f9a25}},	//   _noşt, বত্ব, _لرست, xeur_,
   {{0x7cfd6217,0x42d58221,0x387f902d,0x7d1ba5eb}},	//   géri, ліку, veur_, _vius,
   {{0xf990026a,0x91e58391,0x6d581e51,0x69158084}},	//   _ابی_, лоле, ávac, _išei,
   {{0xfa78073a,0x387fa636,0x7d098051,0x60c293c2}},	//   דעות_, teur_, _thes, _blom,
   {{0x6fd483b7,0x7cfd6218,0x752385ee,0x88bc928a}},	//   _बेहू, béri, _runz, _stěr,
   {{0x7643859c,0x6d5ae219,0x78a9cf57,0x387fe21a}},	//   _peny, erta, rjev, reur_,
   {{0xb7bd802e,0x61278214,0x387f9030,0x6b89e21b}},	//   ncţi, _yıll, seur_, _iseg,
   {{0x04460ca0,0x78a98654,0xb87b0032,0x387f8036}},	//   ленн, pjev, _ajím, peur_,
   {{0x76439e79,0x3f4f0029,0x248d8580,0x7cf60c1d}},	//   _weny, kļu_, _jaem_, tárq,
   {{0x20248038,0xeb971194,0x765c8063,0x6d5ae128}},	//   ásiť_, гия_, óryc, arta,
   {{0x7cf60207,0x60c2a1f6,0x7cc40019,0x644400b9}},	//   rárq, _zlom, nőrz, _weii,
   {{0x6d5a805c,0x2729c42c,0x2d87805c,0x22459bb0}},	//   crta, _hún_, _usne_, _melk_,
   {{0x6b96070b,0x291d8397,0x272984be,0x26c3026c}},	//   _tryg, _jiwa_, _kún_, _aljo_,
   {{0x2729cb0e,0x3f4f00eb,0x4806621c,0x6f1c01a9}},	// [51e0] _jún_, gļu_, упав, _pirc,
   {{0x6da6028b,0xe5a613f1,0x629e02e6,0x2729e21d}},	//   лиза, лизи, _unpo, _mún_,
   {{0x6b89b34d,0x2d960048,0xe45ad3b1,0x2729e21e}},	//   _aseg, ырас, еже_, _lún_,
   {{0x7cfd621f,0xa34a8a13,0x5fd5016f,0x9b6a867c}},	//   téri, езда_, _ठेवल, ешка_,
   {{0x38b50448,0x68e402f7,0xb05b0884,0x2d87006a}},	//   _vårt_, mnid, _klän, æner_,
   {{0x60c2811f,0x29005b48,0x929491f3,0x88c60264}},	//   _slom, llia_, ракц, _এদিক,
   {{0x272985b4,0x6b89e220,0x80b803eb,0xa9678992}},	//   _aún_, _eseg, _इकाइ, гија_,
   {{0x7cfd02be,0x92e480c8,0x6d5a8390,0x68e44777}},	//   péri, নতে_, vrta, nnid,
   {{0x291de221,0xd90d803d,0x68e40114,0xceba8326}},	//   _diwa_, ذیه_, inid, _liƙe_,
   {{0x27299ccc,0x672610e1,0x557486f9,0x22458609}},	//   _dún_, _mukj, агот, _gelk_,
   {{0x7648a71d,0x65618187,0x2900004f,0xd6db025f}},	//   rady, gulh, klia_, תחיל,
   {{0x27298324,0x76488c27,0x6d5a8c49,0x7ce8080a}},	//   _fún_, sady, rrta, tıra,
   {{0xaab88076,0x6d5a80d2,0xf09f001c,0xb05b0338}},	//   _अवाक, srta, _giày_, _blän,
   {{0x248d0b5d,0x66c000f2,0x291d804f,0x59a8881f}},	//   žem_, _sökn, _ziwa_, _कपार,
   {{0x7af526f7,0x291d84b9,0x68e40114,0x6234004a}},	//   rozt, _yiwa_, fnid, сесу,
   {{0x29000698,0x5455132a,0x38351b78,0x95539a05}},	//   glia_, _твит, рнар, _اخوا,
   {{0x1ee7003d,0x7d0d6222,0xe8940198,0x2d986223}},	// [51f0] هوری_, _ihas, щать, _arre_,
   {{0x68e46224,0x29005ca4,0xaca380ff,0x248d841c}},	//   anid, alia_, _phỏn, _saem_,
   {{0x7f4d0372,0x7d0d34ed,0x29006225,0x6b89e226}},	//   ssaq, _khas, blia_, _sseg,
   {{0x63b98063,0x20070201,0x29006227,0xddc880e1}},	//   tywn, ənin_, clia_, radň,
   {{0x2d980065,0x03a58012,0x9098120c,0x66c00380}},	//   _erre_, рило, _свят_, _kökl,
   {{0x2729e228,0x291db516,0x7d0d09ab,0x26da3fde}},	//   _rún_, _siwa_, _lhas, cipo_,
   {{0x61150110,0x27298091,0x387900b9,0x63b9866f}},	//   _sąly, _sún_, _kbsr_, sywn,
   {{0x78ad135a,0x249f8789,0x224580f3,0x6b89e229}},	//   njav, _unum_, _welk_, _tseg,
   {{0x644be22a,0x6a6795e4,0x29038029,0x09d2016f}},	//   magi, _مطال, ēja_, _सध्य,
   {{0x644be22b,0x4905800f,0x81bb00c8,0x3f99026c}},	//   lagi, _हीरो_, _আইন_, _mrsu_,
   {{0x7d0d622c,0x64a60196,0x78ad3232,0x68e4057b}},	//   _bhas, аана, kjav, ynid,
   {{0x628387f1,0x2729877f,0xb05b016d,0x6561a3ea}},	//   leno, _tún_, _slän, rulh,
   {{0x7d0d5a48,0xee2eaee8,0xf7459821,0x78ad0088}},	//   _dhas, _мн_, _тело, djav,
   {{0x644ba140,0x60c9e22d,0x6283e22e,0x13ba83de}},	//   hagi, lhem, neno, דזשע,
   {{0xd946622f,0x66c00106,0x6726008e,0x644be230}},	//   реби, _söko, _sukj, kagi,
   {{0x61fe0efc,0x92d600c8,0x60c98009,0x6283e231}},	//   _vypl, িকে_, nhem, heno,
   {{0x644be232,0x443202f7,0x62838978,0x7c2440bb}},	// [5200] dagi, _ify_, keno, _igir,
   {{0xee371f43,0xfd4c8028,0xdcf9001b,0x60db81e8}},	//   ину_, _nhiệ, _osvě, hium,
   {{0x628380ce,0x14268b9c,0x4a5b0039,0x26da6233}},	//   deno, адем, _בדיו, ripo_,
   {{0x644be234,0x7cfd3cf5,0x672600b9,0x26da6235}},	//   gagi, sérv, _tukj, sipo_,
   {{0x60c9e236,0x20d38087,0x66c0011c,0xd4678087}},	//   dhem, cţii_, _hökm, риче_,
   {{0x6283a0ff,0xb87b046d,0xd954866e,0x27e08084}},	//   geno, _ajíh, منتخ, _žino_,
   {{0x644bb510,0x6d5594b5,0x8c46872a,0x69ce6237}},	//   bagi, ázal, _вебе, nzbe,
   {{0x7c246238,0xb4c503ca,0x7c2d8216,0xf4c100ab}},	//   _ngir, _एते_, ñart, _উদ্ব,
   {{0xc6a68dc9,0x4ea6bd85,0x6283e239,0x752701c0}},	//   арни, арна, beno, _zujz,
   {{0x7d0d1581,0x7c242c33,0xfaff00f1,0x7520826c}},	//   _shas, _agir, ntët_, _himz,
   {{0x7aed80e7,0x06970039,0x7cfd0061,0xd82f8012}},	//   éate, בדים_, kért, _мэ_,
   {{0x7d0282af,0xf8da83db,0x9abc81b9,0x66c48176}},	//   nlos, _बगिय, _diċe, _dòka,
   {{0x66e6c8ac,0xd0d3e23a,0x4ab40b99,0x9f4981fa}},	//   _кода, _بينظ, ुसंव, _áað_,
   {{0x7d02a42a,0x60c6623b,0x644bcc08,0x7764023e}},	//   hlos, _alkm, zagi, duix,
   {{0x1fe880ab,0x644be23c,0x7d0d623d,0x7d02e23e}},	//   _পরিস, yagi, _thas, klos,
   {{0x26d8623f,0x7d02817f,0x7ce8007e,0x7d0d6240}},	//   _amro_, jlos, nırl, _uhas,
   {{0x78ad6241,0x6283e242,0x6d580a21,0xdcf201b9}},	// [5210] rjav, yeno, ávan, _żgħi,
   {{0x6b8d02c1,0xed4d8117,0x6283802a,0x644be243}},	//   _isag, _تھی_, xeno, wagi,
   {{0x63bd08bd,0x20c70665,0x62838304,0x644bc9a5}},	//   lysn, _võib_, veno, tagi,
   {{0x77640722,0xfc3f6244,0xb05b0106,0x6283d030}},	//   buix, nbí_, _kläm, weno,
   {{0x644ba185,0x6283e245,0x307a00be,0x76470282}},	//   ragi, teno, _גארנ, _tejy,
   {{0x78a2b8f8,0x644be246,0xa5f90a41,0x6b8d6247}},	//   _anov, sagi, _бегу_, _msag,
   {{0x60c9805d,0x644be248,0x6915826f,0x44248915}},	//   them, pagi, _ošet, _fgm_,
   {{0x38692b2e,0x6283e249,0x9abc84b7,0x6b8d011b}},	//   ngar_, seno, _riċe, _osag,
   {{0xfd4c8028,0x60dbe24a,0x60c9836e,0x68fd02f7}},	//   _thiệ, rium, rhem, _mksd,
   {{0x4d659273,0x60dbe24b,0xddb581a8,0x78a2ba10}},	//   бков, sium, محجب, _enov,
   {{0x6b8d624c,0x60c9e24d,0x60db8037,0xa294804a}},	//   _asag, phem, pium, _фахі,
   {{0xe1f09459,0xf41f0198,0xe7998a47,0xfce60087}},	//   _غسل_, ydät_, _مختص_, сомо,
   {{0x80a492ee,0x66c0257d,0xfaff0168,0x2d8a8366}},	//   कारे, _sökm, jtës_, æber_,
   {{0x78a29807,0x216a0f27,0xa96a0adb,0x6d5cc0ea}},	//   _znov, лиги_, лига_, árac,
   {{0xb05b0364,0xcd358077,0x20560071,0x6b8d624e}},	//   _eläm, _ارتب, йтар, _esag,
   {{0x25718125,0x3869088b,0xfaff00f1,0x7c240435}},	//   mál_, ggar_, ftës_, _ugir,
   {{0xc7a30ada,0x03e280ab,0x543b00be,0x8fa30198}},	// [5220] питк, _বর্ণ, _געפא, пате,
   {{0x7ce81010,0x394597fe,0x6d5e011f,0x528600f7}},	//   zırl, _owls_, trpa, _الدك,
   {{0x7d028067,0x2571a825,0x6b9be24f,0xb8ce00ab}},	//   tlos, nál_, _arug, _কত_,
   {{0x6b9b8ae1,0xab2aa613,0xfaff00f1,0xed5680be}},	//   _brug, года_, stët_, מבער_,
   {{0x7d02e250,0xa80501df,0x2bd2a7cf,0xb87b0032}},	//   rlos, ruñé, _देखा, _ajíw,
   {{0x6b9be251,0x26d8003b,0x7d02e252,0xd6271aea}},	//   _drug, _umro_, slos, _горе_,
   {{0x7ce8017b,0xd2598221,0x6b9b8133,0xfc3f01d0}},	//   tırl, рці_, _erug, ybí_,
   {{0x4424861b,0x6b9b806a,0x644981ec,0x47348ab2}},	//   _ugm_, _frug, _geei, онис,
   {{0xd9a500d4,0x60c0e253,0x307781a8,0x6b9be254}},	//   _ऑप्ट, rkmm, صحية_, _grug,
   {{0x66fa09c8,0x8c3d83bf,0xa29f801b,0x24868bcf}},	//   ्तिक_, _inşa, _गोप्, leom_,
   {{0x7c2d9408,0xd24f9459,0x39458609,0xf76f80d7}},	//   žare, _سنن_, _gwls_, وای_,
   {{0x78a2807a,0x7cfd6255,0x7bcf0144,0x248680c3}},	//   _unov, vérs, tzcu, neom_,
   {{0x6915b5d5,0x66fa0076,0x06fa125f,0x38cb8180}},	//   _všet, ्ताक_, ्ताव_, _حالی_,
   {{0x77608713,0x6d4e81df,0x3da6a4b6,0x7ae480f7}},	//   mrmx, ábas, _гриб, éith,
   {{0x26de98f1,0x20021040,0x69238bcf,0xf8bf0036}},	//   mito_, _ayki_, _uđet, _liée_,
   {{0x764a8355,0x6915826f,0x58d40c9d,0x320c816b}},	//   _hefy, _ušet, пост, _mzdy_,
   {{0xf7701ecd,0x29048406,0x6d580029,0x3869607f}},	// [5230] فال_, ilma_, šval, rgar_,
   {{0x6b9b820f,0xdddc0110,0x38690fe9,0x6efd80e7}},	//   _rrug, _darž, sgar_, lèbr,
   {{0x212239e9,0x62876256,0xf60b2183,0xfaff0168}},	//   _fikh_, mejo, ухай_, stës_,
   {{0xe9a98077,0x6b9b805c,0xd5fb80be,0x26de8037}},	//   یگان_, _prug, נפאר, hito_,
   {{0x60cd6257,0xfb8580d7,0x765884e8,0x69d8008b}},	//   mham, تدای, _odvy, _þver,
   {{0xe2998f04,0x62876258,0x60cd6259,0x6b9b81b0}},	//   рак_, nejo, lham, _vrug,
   {{0x26dee25a,0x96080a8e,0x32cb804a,0x00000000}},	//   dito_, _гэта_, _nøye_, --,
   {{0x60cd625b,0x25718061,0x7ce8061c,0xceba8300}},	//   nham, vál_, tırm, _riƙa_,
   {{0x6b9b82a0,0x28d8800f,0x62871ef8,0x26dece13}},	//   _urug, बोधि, kejo, fito_,
   {{0x673ba11b,0x200380eb,0xd25184e3,0x6d46826c}},	//   rpuj, āji_, _آنا_, ćkan,
   {{0x34aa2d01,0x60cd0234,0x80c903eb,0x2d9c81f4}},	//   авно_, kham, रसाइ, _crve_,
   {{0x644f3722,0x2360812b,0x7c2900fe,0x26cc81b4}},	//   gaci, šije_, žern, ahdo_,
   {{0x26dee197,0xab2a2187,0x98f4845b,0x60cd3d74}},	//   bito_, рога_, _عثما, dham,
   {{0x26de9d03,0x81cc80ab,0x68fb8198,0xb05b0106}},	//   cito_, রপর_, loud, _fläk,
   {{0x2d988370,0x200b8503,0x5d6980e5,0x691582d4}},	//   året_, škić_, _тийм_, _ušes,
   {{0x644f2e3c,0x33660d0e,0x60cd15d0,0x6723e25c}},	//   caci, _двиг, gham, _hinj,
   {{0xe8f700e8,0x6723e25d,0xfaff0168,0x464a197d}},	// [5240] ілу_, _kinj, rtër_, изан_,
   {{0x2be00076,0x68fba82c,0xdddc0110,0xfaff00f1}},	//   _पेया, houd, _varž, stër_,
   {{0xc27b012a,0x68fb8176,0x2d9c2620,0x527b1101}},	//   _דריי, koud, íve_, _דניא,
   {{0x60cd625e,0x6723c951,0xdd1c816b,0x2d9ab377}},	//   cham, _linj, sážn, _špek_,
   {{0x6d55026c,0x26de8a03,0x60c42b8c,0x248681f4}},	//   _evza, yito_, mkim, reom_,
   {{0x644f05e4,0x7afc625f,0x60c46260,0x75246261}},	//   zaci, nort, lkim, _liiz,
   {{0x7c2f85b7,0x3f82008e,0x644f6262,0xed571a51}},	//   _širš, _hpku_, yaci, _мор_,
   {{0x60c46263,0x764a831d,0x644f57cb,0x3eb80722}},	//   nkim, _sefy, xaci, _hort_,
   {{0x3eb80d1a,0x26dea5dc,0x6723e264,0xb05b016d}},	//   _kort_, tito_, _binj, _släk,
   {{0x67238052,0x644f04b9,0x7afc01a3,0xddde0087}},	//   _cinj, waci, jort, cepţ,
   {{0x644f11b9,0x3eb824d2,0x672384b7,0x60c404a2}},	//   taci, _mort_, _dinj, kkim,
   {{0x26deaf32,0x644282f9,0x62950035,0x26cc83ed}},	//   sito_, nboi, wdzo, shdo_,
   {{0x6d58003e,0x26dee265,0x6723826b,0x752409ca}},	//   ávaj, pito_, _finj, _diiz,
   {{0x25478065,0x6723b5e4,0x7afc6266,0xe5728b8c}},	//   ből_, _ginj, gort, _قطع_,
   {{0x60cd6267,0x644f05d8,0xdb1d0019,0x7c360114}},	//   tham, paci, nysé, _ffyr,
   {{0x26ca6268,0x628703a7,0x34b98f3d,0x473543e8}},	//   _albo_, sejo, _आवेद, знас,
   {{0x3eb81816,0x44296269,0x60cd2715,0x7afc626a}},	// [5250] _bort_, _iga_, rham, bort,
   {{0x60cd626b,0x3eb8626c,0xdd9b626d,0xadfe9d6a}},	//   sham, _cort_, ише_, _उडान_,
   {{0x3eb844cb,0x68e9831d,0x60cd005d,0x644d0748}},	//   _dort_, yned, pham, _keai,
   {{0x442909ca,0x6b808133,0xf9fa01c6,0x224c82f9}},	//   _jga_, _ịgag, _להתמ, _aedk_,
   {{0x44291635,0x656888ce,0xd7d985fc,0xeb9993f1}},	//   _mga_, hudh, _बेंच, сил_,
   {{0x77ba0039,0xda7b9bd8,0x02c58935,0x6568e26e}},	//   _המשח, ряд_, वसेन, kudh,
   {{0xceb2093f,0xca7c03c8,0x6723e26f,0x200981a9}},	//   _אים_, ינגט, _rinj, _šai_,
   {{0x44296270,0x25750082,0x6723e271,0xa3cb1a8f}},	//   _nga_, mål_, _sinj, लना_,
   {{0x6723e272,0xb4e7835a,0x7641831d,0x34c78105}},	//   _pinj, यची_, tbly, लसीद,
   {{0x44296273,0x25478019,0xddde1807,0x7524026c}},	//   _aga_, től_, lepš, _siiz,
   {{0x7cfd2755,0x6da58811,0x442901e0,0xb05b0009}},	//   térp, чина, _bga_, _eläi,
   {{0x25478065,0x7afc6274,0xdb0d00e1,0x44296275}},	//   ről_, wort, ľkýc, _cga_,
   {{0x7afc6276,0x67239083,0xa2d28670,0x8fa5a844}},	//   tort, _tinj, भोक्, _хале,
   {{0x44294c26,0x386d8a38,0xf67580be,0x64428087}},	//   _ega_, lger_, _זײַט_, zboi,
   {{0x2f141918,0x7d110065,0x60c40009,0x44290118}},	//   lägg_, üksé, tkim, _fga_,
   {{0x386d8aa2,0xf992893f,0x7c29e277,0xddde120e}},	//   nger_, ערן_, _nger, jepš,
   {{0x60c46278,0xb87b046d,0x386dcd9c,0x3eb82527}},	// [5260] rkim, _ajís, iger_, _port_,
   {{0x7c29e279,0x645b80b9,0xd00f00f7,0x60c427f6}},	//   _ager, _adui, الك_, skim,
   {{0x657701c0,0x3abb025f,0xf09f0a2a,0x7abb01c6}},	//   gtxh, _המינ, _chàs_, _הציו,
   {{0x27ed003a,0x3eb801ec,0xf53680be,0x386de27a}},	//   _žene_, _wort_, לטער_, jger_,
   {{0x29020006,0x64429f2f,0xa294902a,0x212c808e}},	//   _ikka_, rboi, далі, _sudh_,
   {{0x386d8a11,0x3205801b,0x6568b9d2,0x6577022c}},	//   eger_, _byly_, yudh, btxh,
   {{0x8c468293,0xb909001c,0x2480025b,0x7c2d8390}},	//   _неве, _nghỉ_, _obim_, žara,
   {{0x386d8082,0x3ea7e27b,0xf4849e5c,0xc10481a8}},	//   gger_, _annt_, _تاسی, بوعي,
   {{0x644d1d16,0x36d4954f,0x7b09807b,0x4fc69fd9}},	//   _reai, допр, ðstö, яска,
   {{0x692a83bb,0x3f1381e5,0x68e0e27c,0x3ea78362}},	//   _před, ндыс, simd, _cnnt_,
   {{0xceb30051,0x598694bc,0xaab0627d,0x28a998b8}},	//   תית_, _хлеб, ञानक, काशि,
   {{0x6abae27e,0x6298e27f,0xc98581a8,0x6568e280}},	//   _hotf, ldvo, _تشكي, rudh,
   {{0x7bc282f7,0x66c00085,0x46a6a590,0xde588d8e}},	//   nyou, _höku, _надв, _далі_,
   {{0x765c08cf,0x753c0063,0x29026281,0x764e001b}},	//   _ndry, _otrz, _akka_, _neby,
   {{0x25dc016f,0x51840a41,0x27328129,0x867b81c6}},	//   _गेली_, нута, _hân_, _הרוו,
   {{0x44296282,0x02d98c87,0xb87b026b,0x776403a8}},	//   _uga_, _भग्न, _ajír, frix,
   {{0xf77305ff,0xf09f0706,0x764e1da3,0x76b95068}},	// [5270] عار_, _bhàr_, _beby, олар_,
   {{0x20070ec3,0x2732a160,0xf09f0a2a,0x6abaaaf6}},	//   āni_, _mân_, _chàr_, _notf,
   {{0x764e0114,0x386d8b81,0x2732e283,0x3915002e}},	//   _deby, yger_, _lân_, _омор,
   {{0xb4e7835a,0x765c031d,0x5fde0fb2,0x386d0366}},	//   यचे_, _edry, _नेवल, _øer_,
   {{0x68ed1042,0x05de86bf,0x889a0039,0x7aed8036}},	//   mnad, _फेसब, _וברי, éato,
   {{0x628aa9d6,0x764e1277,0x63a08bcf,0x03a2960e}},	//   gefo, _geby, _drmn, тишо,
   {{0x68ed2769,0x28a9801b,0x236084b7,0xd5b8002e}},	//   onad, कालि, ġija_, _ест_,
   {{0x68ed6284,0x27329e85,0x23608289,0x5fc8800d}},	//   nnad, _bân_, šija_, ाईंल,
   {{0x6d58e285,0x2732e286,0x386dcb9b,0x68ed3ea1}},	//   _avva, _cân_, rger_, inad,
   {{0x27328104,0x057580f7,0x68ed536a,0x2ca96287}},	//   _dân_, واجد, hnad, _anad_,
   {{0x7ae38fe6,0x68ed2e02,0x6b8401e8,0x386d8106}},	//   mint, knad, _spig, pger_,
   {{0x7ae3e288,0xcd02809a,0xf2c903c8,0x69c38428}},	//   lint, _gość_, _דע_, myne,
   {{0x1e0a0da0,0x7e0a0f85,0x7ae3b476,0x2732a160}},	//   _वर्ष_, _वर्ग_, oint, _gân_,
   {{0x7d0700e7,0x672708ae,0x32008214,0xe0df6289}},	//   térê, _nijj, şiye_, _amò_,
   {{0x764e2f0f,0xb0c91299,0x6281e28a,0xdb26811c}},	//   _reby, रसंग, _mblo, şqçi,
   {{0x7ae3e28b,0x7764628c,0x629881dd,0x764e1088}},	//   hint, trix, zdvo, _seby,
   {{0x7ae3e28d,0xd0070185,0x6281e28e,0x753c009a}},	// [5280] kint, дете_, _oblo, _strz,
   {{0x9d462cea,0xbefa0f12,0x7ae3e28f,0x68ed6290}},	//   дежд, ्तेन_, jint, anad,
   {{0x7ae3e291,0x6d41e292,0x7e7e80f2,0x6aba9388}},	//   dint, npla, _öppe, _rotf,
   {{0x040400ab,0x7c2d811a,0x69c3e293,0xf48381b5}},	//   রেণী_, žarn, dyne, вушн,
   {{0xe7e880c8,0x7ae3e294,0x6d670110,0x628ab904}},	//   _পর্য, fint, _įraš, tefo,
   {{0x7ae3e295,0x6d41b0c5,0x68e46296,0xd13aa361}},	//   gint, kpla, liid, охи_,
   {{0x2732801c,0x62988cfa,0x753c0035,0x7bc282d6}},	//   _sân_, rdvo, _utrz, syou,
   {{0x6281de71,0x7ae3851e,0x628a805f,0x692a81d0}},	//   _eblo, aint, sefo, _přeb,
   {{0x7c29496c,0x692a928a,0x628a8299,0xb05b0799}},	//   žerk, _břec, pefo, _gläu,
   {{0x7d044b97,0x2732801c,0x2ca9001b,0x2ab40106}},	//   _akis, _vân_, _snad_, _täby_,
   {{0x6d41e297,0x27e98125,0x62970b6e,0xb05b0106}},	//   gpla, _þann_, _raxo, _klät,
   {{0x7d166298,0x692a800d,0x2732a15d,0x66c06299}},	//   _chys, _třeb, _tân_, _köks,
   {{0x68e432a1,0xfeb7803d,0xf8bf0216,0x68ed2e99}},	//   diid, سایت_, _bién_, vnad,
   {{0x7d040c56,0x629701b4,0x6d41c327,0x057685ff}},	//   _ekis, _qaxo, bpla, _قاعد,
   {{0x6d558019,0x41e4102a,0xdb008168,0x68ed4951}},	//   ázat, віта, _armë, tnad,
   {{0x7ae3e29a,0x5064096f,0xdce200eb,0x7c87102a}},	//   zint, ктуа, pulā, _цуке,
   {{0x7ae3e29b,0x7c2d629c,0x3cf286a7,0x97150087}},	// [5290] yint, _igar, ंचने_, емац,
   {{0x20c70665,0x68ed629d,0x7ae38079,0x66c482d6}},	//   _kõik_, snad, xint, _bòki,
   {{0xa29f8b49,0x7ae3e29e,0x25788019,0xe3b0803d}},	//   _गोष्, vint, nél_, یره_,
   {{0x809e86b7,0x6281b654,0x66c0257d,0x4439629f}},	//   _खोले, _sblo, _sökt, ncs_,
   {{0x6d419640,0x7ae3e2a0,0x60d60bea,0x443962a1}},	//   zpla, tint, _נושא_, ics_,
   {{0xdb258019,0x69c39c3b,0x4439026c,0x2bd0056b}},	//   _épül, tyne, hcs_, हनता,
   {{0x6d41bd81,0x64460035,0xb05b0338,0x78bd62a2}},	//   xpla, ybki, _flät, _kosv,
   {{0x7ae3e2a3,0x7c2d62a4,0x2f1402af,0xa3c10e88}},	//   sint, _ngar, räge_, ूना_,
   {{0x692a801b,0x7c3baaaa,0x69c3e2a5,0x6d418bfd}},	//   _přec, _ifur, syne, wpla,
   {{0x7c2d62a6,0x1dca816f,0x7d043fe3,0x2900011b}},	//   _agar, ानंत, _skis, zoia_,
   {{0x75298a0f,0x1d0a091e,0xa50a16fc,0x7d16480c}},	//   _kiez, зени_, зена_, _phys,
   {{0x92bc00c8,0x55da00be,0x26cee2a7,0x6d418e79}},	//   _আগে_, פֿינ, _elfo_, rpla,
   {{0x7529e2a8,0x31c8582e,0x00d8803d,0x78abae23}},	//   _miez, रन्ध, _تبلت_, _ingv,
   {{0x60c9e2a9,0x6d41e2aa,0x387fe2ab,0x7c2d62ac}},	//   lkem, ppla, lfur_, _egar,
   {{0x442d8a2c,0x7c3bc16e,0x13bd801b,0x2cab00f7}},	//   _oge_, _ofur, ्नुभ, áidí_,
   {{0x26fa000c,0x75298063,0x442de2ad,0x60c9e2ae}},	//   ्त्र_, _niez, _nge_, nkem,
   {{0xfaa61155,0xd00f0013,0xb6a626c5,0x6e3b0214}},	// [52a0] _запо, ملف_, ниал, _şuba,
   {{0x63a462af,0xa29f8b84,0x7c3be2b0,0x7c2d06da}},	//   _irin, _गोल्, _afur, _zgar,
   {{0x60c9e2b1,0x63a4007b,0x752981a9,0xb05b28cb}},	//   kkem, _hrin, _biez, _plät,
   {{0x628e62b2,0x63a42c9f,0x2366936f,0xe45292c8}},	//   lebo, _krin, troj_, اضا_,
   {{0x26068105,0x7529e2b3,0x6abe01ec,0x63a200c3}},	//   _सुनी_, _diez, _kopf, _šonj,
   {{0x629c62b4,0x442de2b5,0x63a400d7,0xb05b1f9d}},	//   ndro, _ege_, _mrin, _fläs,
   {{0xa3e7064a,0x6ec3800d,0x629c59b2,0x7c3b831d}},	//   _येन_, ाउनु, idro, _ffur,
   {{0x628e62b6,0x63a462b7,0xf1b30039,0x25789f04}},	//   hebo, _orin, רסה_, vél_,
   {{0xb4be8c1c,0x7d02e2b8,0xb05b0192,0x67d4910e}},	//   ेसी_, moos, _klär, топу,
   {{0x7d02e2b9,0x7c2d62ba,0x6d5c0115,0x628e04fe}},	//   loos, _sgar, _kvra, jebo,
   {{0x63a462bb,0x2b400473,0x6d4e008e,0xa4d501b5}},	//   _arin, _atic_, _jwba, воні,
   {{0x629c0123,0x629ae2bc,0xbebc81a9,0xe3a78061}},	//   edro, _hato, kmīg, _تشہی,
   {{0x629ae2bd,0x44393d84,0x9b580698,0xddcb81dd}},	//   _kato, rcs_, ният_, ćišt,
   {{0x69a486bf,0x628e0c1b,0x443902e6,0x56938860}},	//   किपी, gebo, scs_, _башт,
   {{0x63a462be,0x3a2504b8,0x629ae2bf,0x30a70009}},	//   _erin, älp_, _mato, нрав,
   {{0x629ae2c0,0x69d880d2,0x6d5abda6,0x7c2d62c1}},	//   _lato, izve, msta, _ugar,
   {{0x63a462c2,0xe81c0076,0xe7332219,0x2906822e}},	// [52b0] _grin, पेला_, اصر_, _mkoa_,
   {{0xdef82bef,0x629ae2c3,0x66c0016d,0x7c3b8372}},	//   ных_, _nato, _sökr, _sfur,
   {{0x7529e2c4,0x68e2e2c5,0x63a43636,0x6c6a0065}},	//   _piez, _omod, _zrin, _علیہ_,
   {{0x9e040162,0x69a48a75,0x69d881a9,0x629aa88c}},	//   учул, किनी, dzve, _aato,
   {{0xe2999878,0x60c982d4,0x7529e2c6,0x6d5c62c7}},	//   дал_, vkem, _viez, _evra,
   {{0x91e5afd6,0x6d5ac166,0x68e28114,0x629a9b0a}},	//   коле, ksta, _amod, _cato,
   {{0x7d02e2c8,0x6f01e2c9,0x212b233f,0x68e28609}},	//   boos, volc, _kich_, _bmod,
   {{0x442d813c,0x6d450234,0x629a9a34,0x212b01d0}},	//   _uge_, mpha, _eato, _jich_,
   {{0x212b0352,0x60c9a645,0x6d5ae2ca,0x387fe2cb}},	//   _mich_, rkem, esta, rfur_,
   {{0x6d5aa06b,0x2cbf80f3,0x2cad83f1,0xfbd700ab}},	//   fsta, _houd_, _hned_, সপাত,
   {{0xb9b5b06f,0x63a41916,0x2cbfe2cc,0x628e42ae}},	//   _جماع, _srin, _koud_, vebo,
   {{0xfce612b2,0x7bc60063,0x212b62cd,0x83fd8061}},	//   томо, tyku, _nich_, _időb,
   {{0x6d5ae2ce,0x629ab607,0x75658065,0x629c0422}},	//   asta, _yato, ریکہ_, tdro,
   {{0x3d12159a,0xceb88063,0x212b0a2a,0x66c48032}},	//   _धीरे_, cję_, _aich_, _bòku,
   {{0xab271628,0x628e1142,0x23270c24,0x6d5ae2cf}},	//   тора_, rebo, тори_, csta,
   {{0x09e100ab,0x26d11d4a,0xceba8326,0x27360366}},	//   _মুহা, _alzo_, _riƙi_, _pæn_,
   {{0x212b62d0,0x6e3b1487,0xc05280be,0x290de2d1}},	// [52c0] _dich_, _đubr, יזן_, ilea_,
   {{0x212b0355,0xb8c90665,0x7f440168,0x69a48b84}},	//   _eich_, _गो_, rpiq, किमी,
   {{0x225847a8,0x6b89a8d5,0x212b02d6,0x290dafe3}},	//   mark_, _apeg, _fich_, klea_,
   {{0x6d5c8013,0x09f704de,0xa3cea23e,0xcb6a9a1f}},	//   árai, _ימים_, शनल_, даде_,
   {{0x629ae2d2,0x6d5a8f28,0x693c026f,0x2bb7816f}},	//   _pato, zsta, _učeb, _आपणा,
   {{0x6d5ae2d3,0x212b0613,0xdd920bca,0x6e43555c}},	//   ysta, _zich_, _پور_, _верз,
   {{0x66e30adb,0x6b89826c,0x6d4506e7,0x610c01ec}},	//   _тора, _epeg, cpha, eßli,
   {{0x629a822e,0x2cbfe2d4,0x69d8e2d5,0x290d85f3}},	//   _wato, _goud_, rzve, glea_,
   {{0x6c7b80be,0x6d5a809a,0x24078012,0x69c7009a}},	//   _קאמפ, wsta, _анти_, zyje,
   {{0x2b468722,0x291f804f,0x70bf001b,0x2bdb9905}},	//   mpoc_, amua_, _एक्ल, _मेटा,
   {{0xd5b7835f,0x6d5ae2d6,0x63a2e2d7,0x1e570039}},	//   вся_, usta, lvon, כשיר_,
   {{0x23698289,0x13c680ab,0xf09f0032,0x9ad3819d}},	//   šaje_, _শেয়, _akàn_, _jịnj,
   {{0x3f9880eb,0x212b62d8,0x29049502,0x21200824}},	//   ārus_, _rich_, moma_, dmih_,
   {{0x212b0943,0x6d5ae2d9,0x25fd8105,0x27ed1e0f}},	//   _sich_, psta, _रुकी_, _ženo_,
   {{0x7aed82be,0x31c437be,0x6d5a822b,0xe7178039}},	//   éati, аств, qsta, _שחור_,
   {{0x63a2c4ca,0xa3b2801b,0x257c01d0,0x68fb4a31}},	//   kvon, टमा_, díl_, čudo,
   {{0x260681ab,0x6d454a98,0xdb0400d7,0x212b0580}},	// [52d0] _सुती_, wpha, _oriè, _vich_,
   {{0x257c01a8,0x20f30267,0x2cbf81d0,0x290d811b}},	//   fíl_, pćio_, _soud_, zlea_,
   {{0x2904e2da,0xa3e7035a,0x6b89e2db,0x765701b4}},	//   koma_, _येत_, _speg, raxy,
   {{0x0ce180c8,0xe7de001b,0x60d662dc,0x5fde081f}},	//   যক্ত, _नेकप, chym, _नेकल,
   {{0x2904e2dd,0xfd5381bc,0x692a801b,0x63858a41}},	//   doma_, _begị, _přen, угла,
   {{0xe3b08ea5,0x3f9962de,0x291f81c0,0x4999a442}},	//   ترم_, _issu_, wmua_, етия_,
   {{0xa3e38006,0x45d50009,0x49bb803d,0xc8798380}},	//   _फेर_, _совс, باشد_, lişi_,
   {{0x60cd62df,0x2904b9d1,0xb92881bc,0xf99092c5}},	//   nkam, goma_, _ikwụ_, تبه_,
   {{0x2fc92172,0x645983f8,0x7d09e2e0,0x59d1800d}},	//   nyag_, mawi, _ikes, तनहर,
   {{0x60cd62e1,0x6459e2e2,0x752d002a,0x1e95997d}},	//   hkam, lawi, _aiaz, урир,
   {{0x7d1b885c,0x60cd62e3,0x290d8216,0xf8758199}},	//   _khus, kkam, plea_, _مهاج,
   {{0xc3290051,0x7e7e80f2,0x2904be5b,0x75354cea}},	//   _זו_, _öppn, coma_, _muzz,
   {{0x60cd62e4,0x753562e5,0x2258624b,0xb3831273}},	//   dkam, _luzz, tark_, блял,
   {{0xb05b00f2,0x68e9e2e6,0x31a38214,0xdb2081ac}},	//   _släp, lied, _kız_, _štúd,
   {{0x6459e2e7,0xaca3aaaa,0xb928819d,0x443f81bc}},	//   kawi, _akọn, _nkwụ_, _ofu_,
   {{0x60cd043b,0x6459809a,0x68e99a28,0x7d09862b}},	//   gkam, jawi, nied, _nkes,
   {{0xef1a3915,0xad1b010f,0x068628d8,0x9d1b0039}},	// [52e0] ема_, _אוקר, лган, _אוקט,
   {{0x539b0051,0x68e9a64a,0x7d065dea,0x7d1b9c0d}},	//   _טיפו, hied, loks, _ahus,
   {{0xc27b0158,0x765506c0,0x645662e8,0x629e0122}},	//   _אריי, _dezy, _keyi, _iapo,
   {{0x257c3352,0x7d1be2e9,0x629e1049,0x6459e2ea}},	//   ríl_, _chus, _hapo, gawi,
   {{0x629e3437,0xaca38028,0x59b6bb82,0xdb041a25}},	//   _kapo, _chốn, _अपहर, _priè,
   {{0x2d51803a,0x6721803a,0x7d098133,0x63a28631}},	//   kše_, jmlj, _ekes, rvon,
   {{0x2d518db7,0x918680f7,0x2904e2eb,0x629e4e46}},	//   jše_, اجتم, toma_, _mapo,
   {{0x629e62ec,0x6459e2ed,0xeb9a8f2e,0x6d5e1d94}},	//   _lapo, cawi, _пиб_, mspa,
   {{0x2904e2ee,0x6d438110,0x752d002a,0x03a395b1}},	//   roma_, _atna, _riaz, _лито,
   {{0x2904aa5a,0xcaa680f7,0x672e0122,0x60cd62ef}},	//   soma_, _حصري, _jibj, zkam,
   {{0x68e9e2f0,0x752d0098,0x58868048,0x443202c4}},	//   bied, _piaz, _была, _bgy_,
   {{0x68e99313,0x799a8205,0x60cd02a3,0x629e5dff}},	//   cied, _istw, xkam, _aapo,
   {{0x64560086,0x752d5f9a,0x69c81e01,0x3eb88338}},	//   _deyi, _viaz, øden, örts_,
   {{0x44320986,0x945d8063,0x629e4386,0x6d5e2783}},	//   _egy_, _końc, _capo, kspa,
   {{0x765aa9d9,0x48ab2326,0x160b9199,0x60c2e2f1}},	//   maty, нтам_, _सुपर_, _koom,
   {{0x645662f2,0x7c2d8669,0x7d0600b9,0x765ae2f3}},	//   _geyi, žari, coks, laty,
   {{0x62889234,0x7aea8082,0xce6b2361,0x6f1c0362}},	// [52f0] _obdo, kift, еред_, _bhrc,
   {{0x60c290b5,0x7c2950be,0x6b8d62f4,0xc8798457}},	//   _loom, žers, _ipag, rişi_,
   {{0x6459e2f5,0x999e81e2,0x3d950d9d,0x6d5e048d}},	//   tawi, _metų_, риер, gspa,
   {{0xfc3f5ca6,0x6b8d0133,0x6456011c,0xc50b80d7}},	//   ncí_, _kpag, _xeyi, رتال_,
   {{0x64598063,0x3f8007e2,0xa3e5000d,0x20d880f7}},	//   rawi, ctiu_, पछि_, _méid_,
   {{0x68e98d38,0x629e01df,0x7aeaa2ea,0x6459c336}},	//   wied, _xapo, gift, sawi,
   {{0x68e9936e,0x7d1bd3ab,0xfc3f027f,0x31a38085}},	//   tied, _thus, kcí_, _qız_,
   {{0x2d5180d2,0xaca38028,0x6b8d0091,0x08c59a07}},	//   vše_, _thốn, _opag, рбин,
   {{0x68e9e2f6,0xaac611bc,0x645606c0,0x60c2e2f7}},	//   ried, रॉडक, _reyi, _doom,
   {{0x63a9a4b4,0x6b9b82a3,0x66d2007b,0x249f81c5}},	//   _iren, _isug, _lækn, _haum_,
   {{0x68e9b8b7,0x249fe2f8,0x7d060009,0x60c2e2f9}},	//   pied, _kaum_, toks, _foom,
   {{0x2d810307,0x629e62fa,0xe1f08154,0x2d51941f}},	//   ithe_, _sapo, _عسل_, rše_,
   {{0x9f6b8098,0x07478f75,0x765ae2fb,0x249f8282}},	//   _чрез_, _схем, baty, _maum_,
   {{0xe5a59fb1,0x212f8051,0xdb0083a7,0x63a9e2fc}},	//   _вики, _high_, _irmã, _mren,
   {{0x2056002e,0x645662fd,0x6d438122,0xf09f046d}},	//   итар, _teyi, _utna, _baà_,
   {{0xfc320872,0x249fe2fe,0x236080ce,0x776d01df}},	//   _بحث_, _naum_, šiji_, frax,
   {{0x629e4be4,0x26c362ff,0xb605819d,0xe73724c7}},	// [5300] _tapo, _bojo_, _fláà, иет_,
   {{0x6d5e0ac5,0x2ca0178f,0x3f802cec,0x26c30216}},	//   tspa, _haid_, rtiu_, _cojo_,
   {{0x63a9e300,0x273b8104,0x3f804021,0x249fa7f2}},	//   _aren, _lên_, stiu_, _baum_,
   {{0x63a9d203,0x249f8069,0x98a60162,0x692a81d0}},	//   _bren, _caum_, _тиме, _přem,
   {{0x273b8104,0x249fe301,0x7aea948c,0x63a9a2fb}},	//   _nên_, _daum_, tift, _cren,
   {{0x60c2e302,0x63a9e303,0x99668a13,0x809e94df}},	//   _soom, _dren, атил, _खोजे,
   {{0x7aea9da3,0xaca38028,0x291d80dd,0x212f8706}},	//   rift, _chồn, _bhwa_, _bigh_,
   {{0x273b8028,0x23698024,0x68f60114,0x63a9e304}},	//   _bên_, šaja_, nnyd, _fren,
   {{0x69d58117,0xd90d8077,0x765ae305,0xbb43c07a}},	//   _üzen, ریه_, taty, _метк,
   {{0x249f81e9,0x2486826c,0xeeaa841c,0x212f8a2a}},	//   _zaum_, lfom_, ттик_, _eigh_,
   {{0x63a982ee,0x6b8d1180,0xdcfccb13,0x765ae306}},	//   _zren, _spag, _sprę, raty,
   {{0x20188086,0x765a8176,0x249f822c,0x57ea8cd0}},	//   ərin_, saty, _xaum_, _идем_,
   {{0x765ae307,0xd010803d,0x29120122,0x386682f9}},	//   paty, _علت_, dlya_, _idor_,
   {{0x81e800ab,0xfc3f01a8,0x2d816308,0x6d489f48}},	//   _বড়_, scí_, ythe_, ppda,
   {{0x68f60355,0xf1a422f1,0x171b8158,0x26c315c7}},	//   fnyd, ортн, _שווע, _rojo_,
   {{0x776d6309,0x273b801c,0x40340198,0xfce42cab}},	//   trax, _yên_, жетс, _мојо,
   {{0x645d0270,0x7d0d00ad,0x693c04ef,0x692a801b}},	// [5310] masi, _ikas, _učen, _přej,
   {{0x2be004e5,0x249f81c5,0x2ca03c76,0x539c0039}},	//   _पेटा, _saum_, _zaid_, _ייחו,
   {{0x6295630a,0x249f81c0,0x66d2007b,0x63a980d7}},	//   mezo, _paum_, _tækn, _sren,
   {{0x645d630b,0x69c4000d,0x76588009,0x6295630c}},	//   nasi, रहरी, _levy, lezo,
   {{0x68ed5561,0x26c30118,0xd37b8ce6,0x7d0d630d}},	//   miad, _tojo_, тче_, _mkas,
   {{0x645d480e,0x68ed630e,0x7658850f,0x6295630f}},	//   hasi, liad, _nevy, nezo,
   {{0x645d6310,0x20d18013,0x49938bca,0x7d0d0fc2}},	//   kasi, _fáil_, تیار, _okas,
   {{0x68ed6311,0x629562e0,0x645d6312,0x6b9b8300}},	//   niad, hezo, jasi, _tsug,
   {{0x9267a6ee,0x63a9925c,0xa49b06c0,0x386681a1}},	//   _ندام, _uren, vlòp, _ddor_,
   {{0x7d0d1fa4,0x2ca06313,0x68ed0114,0x6295026c}},	//   _akas, _said_, hiad, jezo,
   {{0xdb2684c0,0x68f6031d,0xdca61285,0x09e580ab}},	//   _اولی, ynyd, бани, _পুরা,
   {{0x273b8104,0x6aa1800b,0xdb0084c3,0x3981a3db}},	//   _tên_, _half, _irmá, mós_,
   {{0x68ed0355,0xb05b00f2,0x2ca00006,0xa3d786ce}},	//   diad, _poän, _vaid_, ानि_,
   {{0x8c1a8039,0x62950d35,0x6449811c,0x645d05ee}},	//   טורי, gezo, əmiş, aasi,
   {{0x645d6314,0x6aa1e315,0xf8db8063,0xa06a227b}},	//   basi, _malf, _बताय, лава_,
   {{0xa3d79521,0x68ed0114,0x60db8073,0xaca380ff}},	//   ाना_, giad, nhum, _khổn,
   {{0xbb860013,0x62956316,0x6d4700eb,0xdb0981ed}},	// [5320] _الخي, bezo, _atja, _creë,
   {{0x692a801b,0xfca9e23a,0x68f61407,0xe45f008b}},	//   _přek, یانو_, snyd, gjöf_,
   {{0x0d862f33,0x94128085,0x60db805d,0x3981e317}},	//   слен, ədən_, khum, jós_,
   {{0x68ed28d5,0x27038076,0x6b82b6b9,0x045a81bd}},	//   ciad, रकुर_, ttog, اجات_,
   {{0xdb00e318,0xa3d28105,0x8c3d8214,0x69ce6319}},	//   _armá, हैं_, _başb, lybe,
   {{0x645d631a,0x78a41af9,0xd5d604d9,0x3981823e}},	//   zasi, ldiv, _любы, fós_,
   {{0x645d631b,0x6b82c5cc,0x60dbe31c,0x6f08a35f}},	//   yasi, stog, fhum, vodc,
   {{0x78a40698,0x27ed005c,0xa3e39995,0x6b82aaa6}},	//   ndiv, _ženi_, _फेक_, ptog,
   {{0xa92604e8,0x9ed8802e,0xd01081a8,0x629501f6}},	//   mažď, имит_, بلة_, yezo,
   {{0x645d11b7,0x693c0a20,0x68ed631d,0x3981bfef}},	//   wasi, _pčel, ziad, bós_,
   {{0x645d631e,0xc04fa22c,0x62951809,0xb80000ab}},	//   tasi, _ні_, vezo, ্ধিত_,
   {{0x691307d9,0x68ed04c3,0x6442c30d,0x60dbe31f}},	//   rçek, xiad, ncoi, chum,
   {{0x6295011f,0x645d2ec6,0x68ed0510,0x78a42414}},	//   tezo, rasi, viad, ddiv,
   {{0x68ed2a6d,0xadfa03e8,0x27e0009a,0x7c360019}},	//   wiad, ्थान_, dzin_, _egyr,
   {{0x68ed031d,0x692a800d,0x36338f24,0xd5af8791}},	//   tiad, _přeh, _عروس, _эс_,
   {{0x957c8063,0x316c01ac,0x645d011c,0x32cb804a}},	//   rząd, ádza_, qasi, _høyt_,
   {{0x68ed6320,0x62956321,0x6d470a35,0x78a28c53}},	// [5330] riad, pezo, _stja, _maov,
   {{0x63ad6322,0x68ed4d1e,0xb8d003db,0xa3ac8816}},	//   _iran, siad, _टो_, गिन_,
   {{0x68ed2790,0x403501e2,0x69ce00f3,0x6aa1e323}},	//   piad, _менс, cybe, _ralf,
   {{0x63ad6324,0x398182b7,0x81c100ab,0x764907c0}},	//   _kran, vós_, ্ছদ_, _şeyd,
   {{0x2d9c013c,0xd0068124,0x256387c0,0x987a00be}},	//   æver_, _آل_, zıl_, _דארט,
   {{0x2369807a,0x3981c06d,0x63ad1abb,0x2563899b}},	//   šajo_, tós_, _mran, yıl_,
   {{0x60db8234,0x6aa19c02,0xa4d580e8,0xfd13806b}},	//   thum, _valf, _дові, _فجر_,
   {{0x63ad045c,0x2b49003b,0x3981c473,0x69d58019}},	//   _oran, _otac_, rós_, _üzem,
   {{0x3ea32051,0x6aa1a9cb,0x2b4903e4,0xbcb4936f}},	//   _kajt_, _talf, _ntac_, šším,
   {{0x60dbb022,0x66e580e8,0x4d659bc0,0x7bcf00b9}},	//   shum, іона, оков, dycu,
   {{0x60db805d,0x3f84815d,0x27e06325,0x2b494a4a}},	//   phum, atmu_, zzin_, _atac_,
   {{0x7fd58d13,0xa50a1adc,0x81c100ab,0x3ea301a1}},	//   _мілі, рема_, ্ছা_, _lajt_,
   {{0x256387d9,0xf8bf00e7,0x78a4016b,0x60c600e1}},	//   sıl_, _liés_, vdiv, _rokm,
   {{0x63ad20ff,0xe57192c8,0x645b8362,0x78a28b80}},	//   _dran, _قطب_, _leui, _zaov,
   {{0x63ad6326,0x7c3b0669,0xdb09ca45,0xd7658019}},	//   _eran, žura, _creé, _انڈی,
   {{0x63ad6327,0x26c78c0b,0x8b960b79,0x27e06328}},	//   _fran, _hono_, _дроч, tzin_,
   {{0xeb9a2373,0x46ea41a4,0xaec63ba1,0x26c7803d}},	// [5340] _тип_, адан_, обал, _kono_,
   {{0xafdb005f,0x27e06329,0x26c7e32a,0x3200a353}},	//   _iføl, rzin_, _jono_, şiyi_,
   {{0x63ad026f,0xa2a3016f,0x66d20215,0x765e632b}},	//   _zran, _छोट्, _hækk, rapy,
   {{0xa3c1016f,0x83fd8061,0x645b8706,0xf8bf1b9c}},	//   ूनच_, _időj, _ceui, _chéd_,
   {{0x693c0289,0x160b8076,0xfc3f05e4,0x7ed600e8}},	//   _oček, _सुसर_, ndía_, _дівч,
   {{0x3860632c,0x44020063,0x6442a4a9,0x29008196}},	//   lair_, _लखनऊ_, scoi, čiam_,
   {{0x66d2632d,0xd2598a8e,0x645b902d,0x201d818f}},	//   _lækk, сці_, _feui, _azwi_,
   {{0x38604c93,0xe81e8074,0x478a84dd,0xf4868061}},	//   nair_, _परदा_, асом_, _گاڑی,
   {{0x27e981f4,0xb60201d0,0x20ca8362,0x77640118}},	//   _žanr_, řádn, _bùir_, nsix,
   {{0x3860061f,0x753c632e,0x26c7e32f,0x66d2007b}},	//   hair_, _kurz, _cono_, _sækj,
   {{0x63ad5de8,0xa2be0592,0xd6d7835f,0x2b496330}},	//   _sran, शान्, іть_, _stac_,
   {{0x63ad4219,0x2ca6e331,0x386006cb,0xd05f0085}},	//   _pran, ndod_, jair_, biqə,
   {{0x3860082a,0x26c7a5dc,0x61358110,0xd0f980be}},	//   dair_, _fono_, _išla, _פּער,
   {{0x66d2006a,0xb4e78a27,0x8c3da353,0x248013de}},	//   _dækk, _पष्_, _maşa, _ecim_,
   {{0x692a801b,0x26f885fc,0x3ea32520,0x63ad0428}},	//   _dřev, ुवीर_, _rajt_, _wran,
   {{0x63ad6332,0x3ea36333,0x38600857,0x765c02d6}},	//   _tran, _sajt_, gair_, _aery,
   {{0xb8e303b7,0x14ab8ebf,0x63ad50c1,0x765c6334}},	// [5350] _एच_, _घोषण, _uran, _bery,
   {{0x6298a3c3,0x957c8063,0xddab1071,0x7f4d0085}},	//   jevo, cząc, ител_, rpaq,
   {{0x80c700ab,0x3ea32051,0x38604883,0x765c6335}},	//   রোগ্, _vajt_, bair_, _dery,
   {{0x8c3d8214,0x38604b35,0xd251026a,0x291e0722}},	//   _başa, cair_, _تنگ_, ïtat_,
   {{0x645b82be,0x6aa509ca,0x765c44bd,0xd7f86336}},	//   _veui, _kahf, _fery, _дур_,
   {{0x7f3a0051,0x62988b3c,0xe299a2f7,0x212900ee}},	//   _לעשו, gevo, сак_, lmah_,
   {{0x645b89c4,0x6aa500ee,0x753c04b9,0x7c9781a8}},	//   _teui, _mahf, _gurz, _وشرا,
   {{0x26c78021,0x26de8198,0x01fc01c6,0x673d6337}},	//   _sono_, ehto_, יפול, _kusj,
   {{0x73d986e6,0x26c78071,0x6298b747,0x753c0192}},	//   _удар_, _pono_, bevo, _zurz,
   {{0x76452651,0x66d2013c,0x6298e338,0xd25180f7}},	//   nchy, _rækk, cevo, _أنا_,
   {{0x21294ba7,0x386000dd,0xdca60878,0x64a6130f}},	//   kmah_, yair_, пани, пана,
   {{0x8c3d8459,0x656e81a8,0x38600609,0x64410035}},	//   _yaşa, ábha, xair_, ślin,
   {{0xf7498307,0x69ce834a,0x692a801b,0xd05f0085}},	//   _التي_, _über, _přev, qiqə,
   {{0x26de803e,0xfc3f0511,0xfaff0168,0x66d20366}},	//   chto_, rdía_, drës_, _vækk,
   {{0x38604b8b,0xfaff03ed,0x76ba81c6,0xdb041b9c}},	//   tair_, erës_, _למספ, _criá,
   {{0x765c6339,0x68fb807b,0xa5070098,0x24800bcf}},	//   _sery, nnud, _неща_, _ucim_,
   {{0x3860633a,0x765c633b,0x969610f8,0x2ca480b9}},	// [5360] rair_, _pery, зреш, _ramd_,
   {{0xfc3f633c,0x442060fc,0x38600c41,0x7e61e33d}},	//   ndín_, _izi_, sair_, nalp,
   {{0x80db923a,0x1dcba263,0x2a5701c6,0xba9b01c6}},	//   बसाइ, ाहित, _מבין_, _פסטי,
   {{0xa3d78072,0x8c3da138,0x644618eb,0x6281913b}},	//   ानं_, _paşa, ncki, _aclo,
   {{0x7e618029,0x2ca6a92f,0x6298e33e,0xaae5003d}},	//   kalp, rdod_, tevo, _رسیو,
   {{0x60c4003a,0x05cb8fcc,0x753c3bd2,0x62818362}},	//   ljim, ाहाब, _turz, _cclo,
   {{0x78a60025,0x6298e33f,0x628a831d,0x691302d0}},	//   _kakv, revo, rffo, rçev,
   {{0x60c40025,0x44200a2c,0x64a38bac,0x4034b696}},	//   njim, _ozi_, _паса, мейс,
   {{0x20d88307,0x6298d69a,0x44206340,0xa3d7864a}},	//   _féin_, pevo, _nzi_, ानः_,
   {{0x7e618144,0xfa67a361,0xe8040035,0x7c208301}},	//   galp, _наук_, _रखना_, _izmr,
   {{0x44206341,0x3eb802f7,0xceb30039,0x78a66342}},	//   _azi_, _mnrt_, גית_, _oakv,
   {{0x98ab0162,0x48e3828e,0x60c41ac7,0x75242b8c}},	//   _mică_, _похв, jjim, _chiz,
   {{0x60c40289,0x6b9d01ed,0x66d302d0,0x61359075}},	//   djim, uwsg, _yıkı, _ušla,
   {{0x7e618216,0x27f7816b,0x236d02d4,0x75240cdb}},	//   calp, šená_, šejo_, _ehiz,
   {{0x673d6343,0x44206344,0x78a60840,0xbd878124}},	//   _susj, _ezi_, _bakv, _فنون_,
   {{0xd5fb8039,0x60c40168,0x657a9aa1,0xfaff03ed}},	//   _לפור, gjim, muth, trës_,
   {{0x6aa503ac,0x213e8a87,0x657aa0fd,0x67350144}},	// [5370] _tahf, _luth_, luth, _pizj,
   {{0x21294134,0xdb04188b,0xfaff0168,0xb99900e8}},	//   smah_, _triá, rrës_, _двох_,
   {{0xfc3f0333,0x76450428,0x26ca02d4,0x0c4a81bc}},	//   ndío_, rchy, _dobo_, _ịdịl,
   {{0xe4e48d13,0x66d30214,0xb4d7ae2e,0x6615001b}},	//   нічн, _sıkı, िसे_, _vyzk,
   {{0x65656345,0xfaa59bf5,0x657a8234,0x6f020036}},	//   sshh, дало, huth, éocc,
   {{0x657a91e8,0xb87b002a,0xf2c78fe6,0x4fd601c6}},	//   kuth, _emít, ясен, _חושב_,
   {{0x26fb05e8,0x659404f6,0xdd940084,0x7d0f0061}},	//   ्वीर_, _пару, _пары, kocs,
   {{0x23690025,0x26dc8187,0x213e8362,0x318e811c}},	//   _ovaj_, _alvo_, _duth_, _qəza_,
   {{0x3f8907d5,0x7e61e346,0x75241916,0x7c3ba557}},	//   ntau_, talp, _rhiz, _igur,
   {{0x68fb8264,0xe3b09dd2,0xef168009,0xb87b01d0}},	//   snud, _حرف_, ммы_, _hlíd,
   {{0xfc3f6347,0x645f0ace,0x213e8c41,0x23690bcf}},	//   rdín_, _beqi, _guth_, _avaj_,
   {{0xb4ca0e5b,0x3f8900b9,0x2d6781dd,0x7e61b098}},	//   ोसे_, ktau_, rđe_, salp,
   {{0xef0e8c6e,0x7e6182d5,0x78a602f1,0x2d67826c}},	//   _ам_, palp, _rakv, sđe_,
   {{0xb4ba81ce,0xc72480e8,0x657a8234,0x60dd00f3}},	//   _अच्_, _здій, buth, _alsm,
   {{0x26ca6348,0x692a801b,0x7c3bc278,0x78a60084}},	//   _robo_, _třet, _ogur, _pakv,
   {{0x387fe349,0x7c3be2fc,0x693c005c,0x2b4d826f}},	//   ngur_, _ngur, _očev, _otec_,
   {{0xf7720013,0x3ea7a633,0x26ca04c3,0x60c42eec}},	// [5380] ضاء_, _kant_, _pobo_, rjim,
   {{0x63a4634a,0x290081e2,0x7c3b86a2,0x6449818a}},	//   _isin, čiai_, _agur, _afei,
   {{0x78a6003a,0xdb0986a5,0x693c0088,0xa9261c78}},	//   _takv, _creí, _ačev, _одол,
   {{0x26ca0247,0xdb008019,0x60cb8fb0,0x628e634b}},	//   _wobo_, _ismé, _nogm, lfbo,
   {{0xab9a826a,0x78a9b01d,0x3f890114,0xbb43b4ad}},	//   تخار_, ddev, ctau_, вечк,
   {{0xed5a4916,0x64498073,0x63a40010,0x78a9847f}},	//   _мог_, _efei, _msin, edev,
   {{0xa7fb01df,0x64498114,0x60cbe34c,0x78a99384}},	//   _veñe, _ffei, _bogm, fdev,
   {{0x63a4634d,0x387fe34e,0x2b588019,0x657a81f6}},	//   _osin, ggur_, _فیصد_, vuth,
   {{0xa7fb062f,0x60cb82f7,0xb8f6a49a,0xe29284a3}},	//   _teñe, _dogm, _हव_, _لذا_,
   {{0x629c5a0e,0x20188029,0x692a800d,0x66cd81ac}},	//   jero, āri_, _přes, _súkr,
   {{0x9e770051,0x78a98279,0x58868048,0x6e3c00c3}},	//   וגיה_, bdev, _жыла, _mgrb,
   {{0x657a808c,0x63a40609,0xfc3f0333,0x6aa89670}},	//   ruth, _bsin, rdío_, _hadf,
   {{0x629c634f,0x63a40065,0x3ea780e8,0x9b580081}},	//   fero, _csin, _fant_, мият_,
   {{0x3ea7e350,0x81cd00c8,0x7f44011c,0x63a402f7}},	//   _gant_, _শেষ_, dqiq, _dsin,
   {{0x8c3d8afe,0x63a46351,0xf67b8039,0x23c500f1}},	//   _başl, _esin, _ואומ, _bëjë_,
   {{0x2369812b,0xe7d2bb6b,0x25f45845,0xcd2b00d7}},	//   šaji_, _तथाप, ्पनी_, _بستن_,
   {{0x6d4e0029,0x6d5c1abb,0x6aba800b,0x21268362}},	// [5390] _atba, _awra, _ontf, _mhoh_,
   {{0xdef804d9,0x6d40017f,0x7c3b8229,0x4a5500e8}},	//   мых_, _čmar, _sgur, _якос,
   {{0x62850135,0x3f8920db,0x2d8700e7,0x2ca91e6e}},	//   _icho, stau_, îne_, _kaad_,
   {{0xd0100065,0x20d881a8,0x245881e2,0x2a7f0326}},	//   الے_, _béim_, даць_, ɗuba_,
   {{0xe66700c4,0x20d881a8,0xdcfc81a9,0x007601c6}},	//   _отво, _céim_, _aprē, _אתרי_,
   {{0x213900b9,0x2ca96352,0x66d2008b,0x394105ee}},	//   _hish_, _laad_, _bæku, _kuhs_,
   {{0x8c3d8182,0x7e650101,0xb87b001b,0xf99188ca}},	//   _yaşl, mahp, _umís, ابت_,
   {{0x3ea7e353,0x3a380051,0x6aba82af,0x7e6509ca}},	//   _sant_, ורום_, _entf, lahp,
   {{0x629c29de,0x78a9c4eb,0x692a81d0,0x213903ed}},	//   yero, rdev, _přer, _mish_,
   {{0xb4ca03bb,0x629c2f72,0x2139413a,0x62850133}},	//   ोस्_, xero, _lish_, _ncho,
   {{0xa2be1299,0x63a403f7,0xa3d7873c,0x6738cf57}},	//   शास्, _ssin, ानक_, _divj,
   {{0x62856354,0x3ea78051,0x63a40267,0x629c6355}},	//   _acho, _want_, _psin, wero,
   {{0x3ea7e356,0x36d5b0ff,0x629c6357,0x2ca910b8}},	//   _tant_, _подр, tero, _daad_,
   {{0xbea29677,0x21390101,0x693c007a,0xe0df03ec}},	//   _башк, _aish_, _očet, _alò_,
   {{0x09e60b9c,0xc5fa00ab,0x682a0019,0x7e650748}},	//   ховн, _অর্থ_, ködé, dahp,
   {{0x63a46358,0xe45f1e5e,0x6738e359,0xe0df01e4}},	//   _tsin, ljön_, _zivj, _clò_,
   {{0x629c2645,0x63a40051,0x2139635a,0xd00712ea}},	// [53a0] pero, _usin, _dish_, еете_,
   {{0xa3b385e8,0xef174f97,0x3ce001c0,0x69c8006a}},	//   टिन_, ему_, _hliv_, ødes,
   {{0xe7f003eb,0x69c102f1,0x8c3d82d0,0xb917826b}},	//   _घेरा_, älet, _taşl, _didẹ_,
   {{0x20d1cd67,0x290231b8,0xe73a2903,0x63f700d7}},	//   _máis_, _ujka_, _нем_, _آفیس_,
   {{0x883b0051,0x2912005d,0x98160250,0xdb098706}},	//   _מתכו, moya_, _سبحا, _breà,
   {{0x68e4635b,0x9f4001ac,0x21268168,0x79a69b56}},	//   lhid, nzií_, _shoh_, ерие,
   {{0x7c969a8c,0x6ee00065,0x3ce0635c,0xdb040a53}},	//   _прац, _több, _oliv_, _asië,
   {{0x7c240353,0x3eaa01ec,0xb87b03aa,0x29002561}},	//   _ozir, _habt_, _ilíc, nnia_,
   {{0xd2528013,0x2ca928ac,0x7c2434d8,0x2900181c}},	//   _منذ_, _raad_, _nzir, inia_,
   {{0x15f40128,0x2ca9635d,0x7d04635e,0x63a2867d}},	//   _आधार_, _saad_, _ajis, mwon,
   {{0x3ce0013c,0x20d680e8,0x291205ee,0x68e4635f}},	//   _bliv_, _підс, koya_, khid,
   {{0x62856360,0xa7fb016a,0x26c38106,0x26d983ed}},	//   _scho, _leña, öjor_, ësor_,
   {{0x29000063,0x21396361,0x2912008e,0x63a2e362}},	//   dnia_, _rish_, doya_, nwon,
   {{0x29008a8e,0x29000063,0x657e029b,0x2471001c}},	//   čiau_, enia_, kuph, ễm_,
   {{0x61258825,0x3862311a,0x59a6850d,0x2912026b}},	//   sóle, _bekr_, _कैमर, foya_,
   {{0x63a2d030,0x29000081,0x291204b9,0xa3e08ef0}},	//   kwon, gnia_, goya_, दना_,
   {{0x2d980205,0x62850bfe,0xd251003d,0x442481a1}},	// [53b0] _apre_, _tcho, _پنج_, _nzm_,
   {{0x62855100,0x290003b7,0x7d1d358e,0x7d04001b}},	//   _ucho, ania_, llss, _zjis,
   {{0x291232ca,0x68e46363,0x7e6500dd,0x63a281ed}},	//   boya_, bhid, rahp, ewon,
   {{0x693c6364,0xdb040176,0x68e46365,0x2b4986ea}},	//   _včet, _asiè, chid, íaco_,
   {{0x03a5a265,0xdb09be80,0x386f841c,0x5c14acd1}},	//   тило, _areá, _rdgr_, льшу,
   {{0xe2969354,0x78ad2a09,0xf8bf00ff,0x2ca9826c}},	//   ваш_, ldav, _khéo_, žad_,
   {{0x692a801b,0xdb099727,0xb87b0118,0x693c007a}},	//   _přep, _creá, _glíc, _hčer,
   {{0x78ad6366,0x0c7280d7,0x693c0140,0x27e900fe}},	//   ndav, _نگهد, _kčer, ozan_,
   {{0x27e922a6,0x443fd7e7,0x93948199,0x64598314}},	//   nzan_, _igu_, _مجلا, mbwi,
   {{0x7d162183,0xdb098118,0x443f808e,0xf1b30ec5}},	//   _skys, _freá, _hgu_, ुमान,
   {{0x1d0a1a1f,0xa50a067c,0x3ce001c0,0x77698187}},	//   дени_, дена_, _pliv_, ssex,
   {{0x2369805c,0x434618a0,0x764903bf,0x8e360039}},	//   šaju_, кемв, _şeyl, כנתא_,
   {{0x68e46367,0xe72ee368,0x83fd8019,0x26ce92ab}},	//   vhid, _ве_, _idős, _fofo_,
   {{0x78bd0bfa,0x8c3d87d9,0x68e42dd5,0x6283a833}},	//   _ansv, _başk, whid, ngno,
   {{0x3f8dc524,0x68e4051e,0x29002a87,0x443fe369}},	//   lteu_, thid, tnia_, _ogu_,
   {{0x443fe36a,0xa7fb05b4,0x60dbe36b,0x7e638a84}},	//   _ngu_, _seña, nkum, _henp,
   {{0x1e860002,0xa6861091,0x6d43e311,0x2d98002e}},	// [53c0] клам, клад, _huna, _spre_,
   {{0x6d43e36c,0xd37b012a,0x68e4636d,0x5b7b04de}},	//   _kuna, _קריט, shid, _קריא,
   {{0x60db870f,0x181e805e,0xdb040118,0x64a68f9c}},	//   kkum, _पर्व_, _oriú, кажа,
   {{0x7ae1dc22,0x752984cd,0x63a2e36e,0x60db8267}},	//   _allt, _chez, twon, jkum,
   {{0x6d439364,0xa7fb04c3,0x31da801b,0xa8032361}},	//   _luna, _teña, बन्ध, _взял,
   {{0x7e638247,0x66d2013c,0x63a2e36f,0xdb098333}},	//   _nenp, _væks, rwon, _preá,
   {{0x6d438041,0x693c0efd,0x99638071,0x63a2e370}},	//   _nuna, _učes, атыл, swon,
   {{0x7c3b0042,0x63a280f3,0x442480b9,0x752986d8}},	//   žuri, pwon, _tzm_, _ghez,
   {{0x673c0181,0x68e30087,0x6d43e371,0xb8fae372}},	//   _kirj, _înde, _auna, _ठक_,
   {{0x7d02931b,0x6d43e373,0x661c0687,0x6440026c}},	//   lnos, _buna, _kyrk, žmil,
   {{0x7e63b58a,0x6d43e374,0x867b0039,0x6d4480e1}},	//   _denp, _cuna, וריו, _čias,
   {{0x6d439341,0x7d02e375,0x63b6195f,0x7ce6018a}},	//   _duna, nnos, _bryn, _nórd,
   {{0x69d587d9,0x7d1d4298,0x56948fbf,0x78ad0669}},	//   _üzer, rlss, _балт, vdav,
   {{0xdb0d062f,0x67da00eb,0x60cf6376,0x68e2a1f8}},	//   _traí, _mājā, _socm, _hlod,
   {{0x69d88019,0x68e2e377,0xb87b016a,0x7d02c7f7}},	//   nyve, _klod, _alía, knos,
   {{0x7ce61099,0x27e90102,0x20188085,0x63b66378}},	//   _córd, tzan_, ərir_, _fryn,
   {{0x78ad6379,0x6d438353,0xb4df050d,0x3f80107f}},	// [53d0] rdav, _zuna, णसी_, guiu_,
   {{0x6d43e37a,0xe71900f7,0x64490110,0x443f806a}},	//   _yuna, ريات_, žeid, _sgu_,
   {{0x693c1234,0x28c583db,0x60cf0087,0x673c3f41}},	//   _včer, वामि, _tocm, _dirj,
   {{0x657a8c49,0x661c0257,0x6125807b,0x7d028ca9}},	//   irth, _dyrk, kóla, gnos,
   {{0xdfc69368,0xf8bf01ac,0x2919026c,0x38691aae}},	//   _اي_, _iné_, _iksa_, maar_,
   {{0x386905f8,0xa92781ac,0x8c3d802e,0x9f9c807b}},	//   laar_, _obľú, _maşi, _ræða_,
   {{0x69d89450,0x7d02c509,0x68e29da3,0x2489026c}},	//   gyve, bnos, _blod, _ocam_,
   {{0x443f82c1,0xe9468077,0x7d0287df,0x38690b3c}},	//   _ugu_, دروی, cnos, naar_,
   {{0x776d062f,0x6d4385a3,0x60c9885c,0x60dbe37b}},	//   nsax, _suna, rjem, rkum,
   {{0x6d43d723,0xfe7180f7,0x3f8de37c,0xeb0e83eb}},	//   _puna, حدة_, rteu_, ाकृत_,
   {{0x386910f4,0x26d101df,0x68e29fd7,0x2d813899}},	//   kaar_, _mozo_, _flod, nuhe_,
   {{0x68e298f4,0x38690fb0,0x63b60114,0x24890580}},	//   _glod, jaar_, _pryn, _ccam_,
   {{0x657ae37d,0xd1108aec,0xf8bf00ff,0x38694ff0}},	//   arth, ावरण_, _chém_, daar_,
   {{0x6d43e37e,0x6449062f,0x7d02935a,0x43430e8e}},	//   _tuna, ñeir, znos, серв,
   {{0x09e3197d,0x2a658267,0x7d02a5dc,0x6d43e37f}},	//   борн, _melb_, ynos, _uuna,
   {{0xc486024b,0x4c860652,0x673c6380,0x205506f9}},	//   _слик, _слив, _sirj, итур,
   {{0x7d02c1a2,0x63a9a1bb,0x661c00ee,0xdd0401a9}},	// [53e0] vnos, _nsen, _syrk, šsēd,
   {{0x7d02a251,0x3ea10192,0x661c0198,0x6b5b0e82}},	//   wnos, geht_, _pyrk, _רדיפ,
   {{0x386902b5,0x63a9e381,0x6b9b819d,0xa2c29199}},	//   baar_, _asen, _apug, लास्,
   {{0x98ba0012,0x0b8ab6f4,0x938a82a4,0x5c068b79}},	//   _după_, ески_, еска_, ляла,
   {{0x628107a3,0x254c801b,0x63a98061,0x66741190}},	//   ólog, _měla_, _csen, _نگار,
   {{0x661c0e51,0x610881d0,0x68e2afbe,0x37cd0264}},	//   _tyrk, děla, _slod, _রেকর,
   {{0x63a9e382,0x7d029807,0x39459ed6,0xfd6501bc}},	//   _esen, pnos, _culs_, _mesị,
   {{0x58d4ac18,0x02d1000d,0x6ad10107,0x2edc800d}},	//   роит, _सक्न, _सक्र, यस्त,
   {{0xdfd081a8,0x6cc38087,0x78a090ac,0x00000000}},	//   زيد_, _уйта, remv, --,
   {{0x2489151e,0x539b8039,0x83fd8019,0x6146b6f4}},	//   _scam_, _אימו, _időp, _бежа,
   {{0xdd948196,0x6b82e383,0x38690079,0xd5b78470}},	//   шаны, luog, yaar_, гся_,
   {{0xdb098003,0x13d880ab,0x657a80f7,0x705680f7}},	//   _preç, _দেয়, rrth, _إنشا,
   {{0x38691ae1,0xfd1f047f,0x7e6880e4,0x2d8100c3}},	//   vaar_, rlì_, padp, zuhe_,
   {{0xa7fb040e,0x3869037a,0xf41f0106,0x32d986c4}},	//   _seño, waar_, ffär_, _pèyi_,
   {{0x31c4017a,0x38696384,0x318e8085,0xa7fb0144}},	//   бств, taar_, _bəzi_, _peño,
   {{0x3eae8772,0x90551c79,0x6ad18072,0x6b82ab8c}},	//   _haft_, рвац, _तक्र, kuog,
   {{0x38690c11,0x81cd00ab,0x26d111b9,0x386680ee}},	// [53f0] raar_, _শেখ_, _pozo_, _meor_,
   {{0xbd6b396b,0x386697ca,0xe945026a,0x386958da}},	//   ерде_, _leor_, _پردی, saar_,
   {{0x80ba85b3,0x386914fb,0x752d435e,0x7127006b}},	//   _शोभे, paar_, _khaz, _مرحل,
   {{0x2d816385,0x63a98bcf,0xa8a70a0e,0xdb160176}},	//   ruhe_, _psen, _срок, _aryè,
   {{0x3cfd000f,0x60cd4062,0xd7fb01a1,0xda6590f8}},	//   _लगने_, mjam, _чун_, авли,
   {{0x321e826f,0x450b00ab,0x6125809a,0xe299e386}},	//   _byty_, রতিক_, góln, так_,
   {{0x60cd01e2,0xd49b8a8e,0x6ee008aa,0xdb009f28}},	//   ojam, _пра_, _möbl, _armó,
   {{0xdfd18013,0x44292da4,0x50b5a1a6,0x2cbf8122}},	//   قيع_, _oza_, рску, _unud_,
   {{0x7d1b80ad,0x6d472851,0x63a9e387,0x82878829}},	//   _ikus, _huja, _usen, _مجال,
   {{0x6d476388,0x59678698,0x7c29e389,0x8c3d8214}},	//   _kuja, _бъда, _izer, _başv,
   {{0x28c581a2,0x4429638a,0xa3b3809a,0x6cc63a46}},	//   वादि, _aza_, टिव_, айна,
   {{0x386987ca,0x6d47638b,0x752d638c,0x6125818a}},	//   _þar_, _muja, _chaz, mólo,
   {{0x7d09830b,0x89348b76,0x68e9e38d,0x6125802a}},	//   _mjes, _اعلا, mhed, lólo,
   {{0x60cd00eb,0x7e67001b,0x7d0994ce,0x68e9e38e}},	//   ejam, _nejp, _ljes, lhed,
   {{0x7d1be38f,0xa06a08d5,0x44295394,0x6125a790}},	//   _okus, кава_, _eza_, nólo,
   {{0x68e9976f,0x752d4139,0x2a6a0019,0x0f1e01a2}},	//   nhed, _ghaz, sabb_, भत्स_,

   {{0xb8fe1499,0x0e661506,0x27edc15a,0x03a62865}},	// [5400] _तक_, икан, nzen_, _типо,
   {{0xe9da0abe,0x44206390,0x7d1be391,0x6d472e9c}},	//   _ако_, _iyi_, _akus, _buja,
   {{0x7c298201,0xc27b012a,0x6aa3a3dd,0xa6db007b}},	//   _azer, _בריי, denf, _guðm,
   {{0x7afc07d9,0x6ec406ab,0x44201bcc,0x81b98326}},	//   lirt, राहु, _kyi_, _gaɓɓ,
   {{0x27ed8613,0x7c298063,0x68e9d400,0xdb008144}},	//   jzen_, _czer, dhed, _asmá,
   {{0x66e601f3,0x78a46392,0x7d1b8234,0x6aa3e393}},	//   _тога, leiv, _ekus, genf,
   {{0xdcfe80fe,0x386682ba,0x7c29e394,0x64a6ae39}},	//   lupč, _peor_, _ezer, _кава,
   {{0x68e9b700,0xc9530451,0x44200135,0x68fb8081}},	//   ghed, חמה_, _oyi_, giud,
   {{0x442021ce,0x6125809a,0x6d470503,0x69dc6395}},	//   _nyi_, póln, _zuja, hyre,
   {{0x7d1b801b,0x60cd07d8,0x7522e396,0x64440706}},	//   _zkus, zjam, lloz, _agii,
   {{0x6d40ca93,0x6125a8d5,0x44206397,0x75228904}},	//   _kima, cólo, _ayi_, oloz,
   {{0x6d40a344,0x68e9e398,0x752d4b47,0x68fb923d}},	//   _jima, ched, _qhaz, ciud,
   {{0xdcfc80eb,0x8f5486e2,0x3eae82f7,0x60c2e399}},	//   _aprī, _انتش, _taft_, _inom,
   {{0x3f84e39a,0x6e948250,0x35f7803d,0xdb0992f1}},	//   mumu_, _طلبا, ارید_, _treå,
   {{0x5d848013,0x4420077f,0x3f84e39b,0x60cd0722}},	//   _العل, _eyi_, lumu_, tjam,
   {{0x6d5a8e99,0x6d40e39c,0x6d47639d,0x44200295}},	//   mpta, _nima, _ruja, _fyi_,
   {{0x60cd639e,0x6d473017,0x7afc4b52,0x7d09de70}},	// [5410] rjam, _suja, birt, _rjes,
   {{0x63ad360e,0x6d471b15,0x539a0039,0xc9871cae}},	//   _isan, _puja, _עיתו, _куми,
   {{0x7c298986,0x7d09e39f,0xdb0d0214,0x6d40afba}},	//   _szer, _pjes, _araç, _bima,
   {{0x3f84aa22,0xbd188cde,0x4518835f,0x6d4090fe}},	//   kumu_, ації_, ація_, _cima,
   {{0x3f848341,0x6d40a95b,0x7c20a0af,0x889a0496}},	//   jumu_, _dima, _cymr, _גברי,
   {{0xd945a902,0x60c2e3a0,0x3f84e3a1,0xa9699e0b}},	//   беки, _anom, dumu_, гика_,
   {{0x7d0982ce,0x442981ac,0x6d4080fc,0xe05782e3}},	//   _tjes, ťa_, _fima, لیات_,
   {{0x27ede3a2,0x7d1b805d,0x27ed003e,0x6d40b396}},	//   tzen_, _ukus, _ženy_, _gima,
   {{0x8aa785c2,0x7c208355,0x3f84e3a3,0x68e9b700}},	//   _вред, _gymr, gumu_, rhed,
   {{0x28c5946d,0x39b58029,0x2bcb06b7,0x27ed9da1}},	//   वाहि, _tās_, ामना, rzen_,
   {{0x44260029,0x63ad63a4,0x99d98013,0x44200590}},	//   _šo_, _asan, _حواء_, _syi_,
   {{0x3f84e3a5,0x7afc01ec,0x2b410176,0x7d198035}},	//   bumu_, wirt, _aihc_, nows,
   {{0x7ce600f7,0xeb972cea,0x7afc22cc,0x2b49002a}},	//   _córa, бия_, tirt, _cuac_,
   {{0x69dc49fe,0x63ad008e,0x386d89ff,0x59bd8f0f}},	//   tyre, _dsan, laer_, ्मपर,
   {{0x63ad63a6,0xf2d28158,0x69dc87d9,0x7afc0125}},	//   _esan, לעך_, _üret, rirt,
   {{0x7ce60307,0x63bb8091,0x26c30187,0xdcfb00eb}},	//   _fóra, _orun, _anjo_, putā,
   {{0x6d40e3a7,0x44260028,0x2d85d1d5,0x7afc63a8}},	// [5420] _rima, _áo_, lule_, pirt,
   {{0x6d40e3a9,0x3ea599fa,0x69c82aaf,0x7c5700d7}},	//   _sima, nelt_, ädes, _پلیر_,
   {{0xa0a663aa,0x63bb905c,0x6d40e3ab,0x7522ccc8}},	//   _ланд, _arun, _pima, tloz,
   {{0x20d88013,0x237f077b,0xdb0d0187,0xfd508032}},	//   _léir_, šuje_, _praç, _aadọ,
   {{0x3ea5a2ea,0x2d85e3ac,0xd91b0039,0x26180ad5}},	//   kelt_, hule_, _תוכל, _बुरी_,
   {{0x2d85e3ad,0x291d8870,0x394201bf,0x6f1c011f}},	//   kule_, _akwa_, _hiks_, _ukrc,
   {{0xd1308117,0x63bbe3ae,0x3ea5829e,0xa96784bd}},	//   ومت_, _erun, delt_, бија_,
   {{0x3f84e3af,0x63bbe3b0,0xdb0d63b1,0xa3a90006}},	//   tumu_, _frun, _traç, _गईल_,
   {{0x63bb95ce,0x39420006,0x3ea5e3b2,0x7b07bde3}},	//   _grun, _miks_, felt_, órtá,
   {{0x3f84e3b3,0x3ea5e3b4,0xb6c68009,0x675380f7}},	//   rumu_, gelt_, ссий, أخير,
   {{0x63ad0c2e,0x3860036e,0x2d85e261,0x2a6e808e}},	//   _ssan, kbir_, gule_, mafb_,
   {{0x6d5a8df1,0x39420b3c,0x63ad01d0,0xdb0463b5}},	//   rpta, _niks_, _psan, _orió,
   {{0x386028fa,0x3ea584fe,0xddc18b67,0x28c58bb8}},	//   dbir_, belt_, ralš, वारि,
   {{0x2d85b4e7,0x628a84fe,0xde58a22c,0xd84f01bc}},	//   bule_, ngfo, _такі_, _lọta_,
   {{0xa3a905e8,0x2d85e3b6,0x13c380ab,0x31c40992}},	//   _गैर_, cule_, ্নয়, пств,
   {{0x63ad63b7,0xdb0401df,0x3f802dbe,0x7ce619b1}},	//   _tsan, _brió, friu_, _tóra,
   {{0x69c80884,0x7d0d008e,0x61050110,0x6d4ab496}},	// [5430] äder, _ijas, nėli, _hufa,
   {{0x6d4aa8b2,0x3ce9265d,0x7c2d63b8,0x7c26936f}},	//   _kufa, _hlav_, _izar, _úkry,
   {{0x957c809a,0x39420147,0xd84f11d3,0x386001b9}},	//   cząt, _fiks_, _bọta_, bbir_,
   {{0x6d4a8deb,0x6f1acba4,0x6aa70267,0x3f8024df}},	//   _mufa, hotc, lejf, briu_,
   {{0x3f80009f,0xd37bc543,0x7d19e3b9,0x68ed4dc9}},	//   criu_, уче_, rows, mhad,
   {{0x6d58803b,0x68ed63ba,0x4ea7002e,0xa5e71edc}},	//   _otva, lhad, _урма, _любл,
   {{0x20d88013,0xda788c5c,0x6f1a8295,0x28c5809a}},	//   _réir_, сяч_, dotc, वालि,
   {{0x63bb8add,0x68ed63bb,0xe0d99cfb,0x6f0880ee}},	//   _trun, nhad, рви_, endc,
   {{0x4439e3bc,0x6d588bb6,0x3ea5e3bd,0x63bbe3be}},	//   _às_, _atva, telt_, _urun,
   {{0x2d85e3bf,0x6d4a930e,0x7ce6002a,0x7d0d07b8}},	//   tule_, _bufa, _córn, _ajas,
   {{0x3cca0abe,0x7079819f,0x3ea5ae2b,0x7c2d63c0}},	//   ално_, _نماز_, relt_, _azar,
   {{0x3ea58665,0xf2c90039,0x6d4ae3c1,0x3ce9026c}},	//   selt_, _בע_, _dufa, _clav_,
   {{0xa3e984e5,0x7c2d009a,0xdb0428d5,0x2d8598d0}},	//   मनि_, _czar, _asiá, sule_,
   {{0x764700f1,0x7c2d00dd,0x7b1f8187,0x6f1a8362}},	//   _ngjy, _dzar, cêut, cotc,
   {{0xc5d58d13,0x442d801b,0x7c2d011e,0x6d4a82a0}},	//   _філь, _lze_, _ezar, _gufa,
   {{0x68ed125b,0x442de3c2,0xa92600e8,0x7d0d00f1}},	//   ghad, _oze_, ідал, _gjas,
   {{0x442d82ec,0x6ecd8035,0x6d4ae3c3,0x272f1238}},	// [5440] _nze_, तापु, _zufa, züne_,
   {{0x6125808b,0x63a0808e,0x98b901a9,0x1db0e3c4}},	//   fólk, _rpmn, _visā_, _जनमत,
   {{0x68ed6290,0x394200eb,0x442de3c5,0x412a004a}},	//   bhad, _tiks_, _aze_, _воно_,
   {{0x68ed0782,0x0c26831f,0x3f804a4a,0x764907c0}},	//   chad, омен, priu_, _şeyt,
   {{0x8c3d8201,0xf77212dc,0x442d8035,0x78b60048}},	//   _başq, _تاج_, _cze_, mdyv,
   {{0x6d441bf3,0xe81d8035,0xf21f03db,0x69c30118}},	//   _liia, _पड़ा_, _मुड़_, _ánec,
   {{0xfce68af2,0x442d8870,0xa7fb016a,0x84e6804a}},	//   _дово, _eze_, _reñi, _довж,
   {{0x6d5e0009,0x26d863c6,0x68e458ad,0x6d4aa8b8}},	//   mppa, _horo_, nkid, _rufa,
   {{0x6d58805c,0x27e063c7,0x7c2463c8,0x4ea6e3c9}},	//   _stva, nyin_, _nyir, орна,
   {{0x232a8698,0xf5498028,0x7f43e3ca,0xd6da8db3}},	//   _този_, _vấn_, _cinq, рти_,
   {{0x290902a3,0x3ce9377a,0x81df00ab,0x7c2d2f8f}},	//   ynaa_, _plav_, _দেন_, _szar,
   {{0x26d863cb,0xf549801c,0x98a68e8e,0x6d444d9b}},	//   _loro_, _tấn_, _фиде, _ciia,
   {{0xa7fb0216,0x7ce623be,0x6d4a808e,0x25a98b80}},	//   _teñi, _tórn, _wufa, _ćale_,
   {{0x26d863cc,0x6d4a854e,0xdb041041,0x394c826c}},	//   _noro_, _tufa, _briñ, _kuds_,
   {{0x68ed12be,0x5b14035f,0x6d58a205,0x6d440706}},	//   thad, ємст, _utva, _fiia,
   {{0x02b783bb,0x7d0d1ffb,0xb05b0106,0x6ab78072}},	//   _आफ्न, _ujas, _gnäl, _आफ्र,
   {{0x68ed1a6e,0x26d823c5,0x7d1d30d2,0xf7730277}},	// [5450] rhad, _boro_, moss, باز_,
   {{0x68ed63cd,0x7d1d2bcb,0xd5bb023a,0x26d863ce}},	//   shad, loss, исе_, _coro_,
   {{0x26d80135,0x254808c5,0xdb044b69,0x68ed63cf}},	//   _doro_, _oğlu_, _griñ, phad,
   {{0x7d1d2b2a,0xe3b19459,0xe4e48d8e,0x44248035}},	//   noss, فرت_, мічн, _bym_,
   {{0x26d860fb,0xef9309d7,0x6b8291fe,0x7ba780f7}},	//   _foro_, _زیاد, grog, تصام,
   {{0x6d020fea,0xa6db007b,0x26d863d0,0xdb0d29af}},	//   _लगभग_, _auðv, _goro_, _araú,
   {{0x7d1d15c8,0xddc38087,0x26c980ff,0x1a9c03de}},	//   koss, _menţ, _đao_, ייגע,
   {{0x26d80133,0x7f43e3d1,0x6b8297d6,0xf8bf00ff}},	//   _zoro_, _sinq, brog, _ghét_,
   {{0x6d0205b3,0x7d1d04fa,0x442daae1,0x61258825}},	//   _लगबग_, doss, _uze_, nóli,
   {{0xb05b016d,0x394c81a1,0x68e4011b,0x6d4402f1}},	//   _snäl, _fuds_, zkid, _siia,
   {{0xa3b38aed,0x7c24010b,0x394c81a3,0xe165803d}},	//   टिक_, _syir, _guds_, _رضای,
   {{0x692c01ec,0x499a8039,0x27e0338a,0x629e01a1}},	//   eßen, _לשעב, yyin_, _sbpo,
   {{0xddd50019,0xeb9715a6,0x395a0144,0x6d4424a1}},	//   _mező, пия_, _stps_, _viia,
   {{0xf09f0091,0x78a98365,0x249f8216,0x273406ae}},	//   _abà_, leev, _lbum_, mäng_,
   {{0x26d8349c,0x6f01e3d2,0xc3328039,0xf1bd9c9d}},	//   _roro_, milc, גום_, ्मिन,
   {{0x80a18063,0x26d82e3b,0x7d1d52ed,0x6125e3d3}},	//   _कॉमे, _soro_, coss, fóli,
   {{0x26d863d4,0xdb04007b,0x68e463d5,0x290005ee}},	// [5460] _poro_, _frið, rkid, riia_,
   {{0x63a463d6,0x68e41611,0x7cf62dab,0x41bd89c2}},	//   _ipin, skid, ršru, ्मास,
   {{0x629c3d70,0x32db01c6,0x27f20035,0x4424e3d7}},	//   mfro, _החינ, szyn_, _sym_,
   {{0x31570158,0xf7461264,0xf09f10ab,0xf54980ff}},	//   _מיטן_, _немо, _gbà_, _nấm_,
   {{0xaac7823c,0x61258272,0xf8bf816f,0xddc500e1}},	//   लांक, cóli, _शोधय, rahš,
   {{0x628e2d24,0xb4e90743,0xe7370098,0x249f8133}},	//   ngbo, _यत्_, _нея_, _ebum_,
   {{0xada347de,0x394c8a84,0xf549801c,0x7ce60118}},	//   _парл, _quds_, _bấm_, _pórl,
   {{0x4424a1f3,0x26c78698,0xf54980ff,0x249fba00}},	//   _tym_, _anno_, _cấm_, _gbum_,
   {{0x40538013,0x6d4e63d8,0x2b4599df,0x3ce6a3fa}},	//   رئيس, _huba, _filc_, mkov_,
   {{0x6d4e06b0,0x3ce68db7,0x7d02e3d9,0x6f1e0503}},	//   _kuba, lkov_, lios, nopc,
   {{0x63a42c3a,0x06970051,0x2d78042b,0x7d1d63da}},	//   _apin, הדים_, nče_, toss,
   {{0x6d4e25d7,0x3ce6e3db,0x7afe067f,0x7d02e3dc}},	//   _muba, nkov_, _ampt, nios,
   {{0xa847806b,0x6d4e63dd,0x629c63de,0xe81c01ce}},	//   _علوم_, _luba, ffro, _भुला_,
   {{0x6d5c6151,0xa77b8051,0x5693838c,0xdb1b8388}},	//   _otra, _פרופ, _зашт, _prué,
   {{0xd3088104,0x3a250022,0x39469142,0x2d7819d1}},	//   yện_, ælp_, _kios_, jče_,
   {{0x58d423e1,0x612587a3,0x6aaa8c19,0x3ce68619}},	//   ност, tóli, heff, jkov_,
   {{0x7d02e3df,0x3ce6875f,0x84981921,0x3946e0e2}},	// [5470] dios, dkov_, _رئيس_, _mios_,
   {{0xe8df019d,0x6d4e63e0,0xceb89c43,0xac990019}},	//   _ipọd_, _buba, ndę_, _اچھا_,
   {{0x6d4e2e58,0x3f528028,0x7bc0e3e1,0x94d58221}},	//   _cuba, _lâu_, _armu, можц,
   {{0x2ea9801b,0xeae586a7,0xa7fb0216,0xe81d8f85}},	//   _कस्त, कस्त_, _señu, _पडला_,
   {{0x212914ec,0x6d5c63e2,0xddc3826f,0xa6db007b}},	//   mlah_, _etra, _menš, _suðu,
   {{0x212904aa,0x7b3981bc,0xf549827d,0xaac781a2}},	//   llah_, _aňur, _sấm_, लाइक,
   {{0x6d5c5b3c,0x6d4e50b4,0x6f01e3e3,0x7bc089e8}},	//   _gtra, _guba, vilc, _ermu,
   {{0x21290867,0xb925046d,0xe8df81bc,0x27340338}},	//   nlah_, _aipẹ_, maịa_, täng_,
   {{0x3946b34c,0x3f528028,0x6d4e63e4,0x21290859}},	//   _dios_, _câu_, _zuba, ilah_,
   {{0x60069006,0x21290057,0x3cede3e5,0x3cff822c}},	//   ьным_, hlah_, _hlev_, _hmuv_,
   {{0x39468046,0x21292853,0x6d5c4c3f,0x34aa140b}},	//   _fios_, klah_, _xtra, овно_,
   {{0x13e180c8,0x6f01807a,0xeb9a63e6,0x59a68f3d}},	//   _মেয়, silc, оим_, _कैटर,
   {{0x4c9a8039,0x6f01e3e7,0xa2c28072,0x80098061}},	//   חברו, pilc, लाच्, _براہ_,
   {{0x7d02e3e8,0x66058c40,0xfe7180d5,0x6d5a00e7}},	//   zios, _опла, _شدت_, _étag,
   {{0x4343067c,0xa3b4800d,0x212900ee,0x7b090267}},	//   терв, _छैन_, flah_, džud,
   {{0x6d4e63e9,0x7d0284c3,0x52da8074,0x2129036e}},	//   _ruba, xios, _बक्स, glah_,
   {{0x6d4e3e63,0x3ce6a007,0x27308362,0xd24f0065}},	// [5480] _suba, vkov_, làna_, انہ_,
   {{0xe73701a1,0x212910e1,0x6c680065,0x61e381b0}},	//   деу_, alah_, _بلکہ_, kynl,
   {{0x3ce6a588,0x3ced93c2,0x550206b7,0x2734016d}},	//   tkov_, _blev_, _लगाए_, vänd_,
   {{0x25d6893f,0x7e6e63ea,0x2d85aab6,0x2d538073}},	//   ווען_, _webp, irle_, _mãe_,
   {{0x69c1e350,0x5f760eca,0x6b9981c0,0xb4ae83eb}},	//   _arle, _تاجر, gtwg, _कसी_,
   {{0x3ce6e3eb,0x98b90110,0x450600ab,0x2d780654}},	//   skov_, _visą_, ৈতিক_, pče_,
   {{0x6aaa949d,0x3f52801c,0x05660d8e,0xda001513}},	//   reff, _sâu_, _іван, ोपित_,
   {{0x3eb8115b,0x57b49b4f,0x6b8be3ec,0xceb8809a}},	//   _hart_, ебит, bugg, wdę_,
   {{0x69c1cb68,0xb7db0158,0x394689da,0x3eb80b0b}},	//   _erle, ַקטי, _vios_, _kart_,
   {{0xddce0bb6,0x6a83896f,0x75241c5d,0x81bc80eb}},	//   _nebū, _алфа, _akiz, _dzēr,
   {{0x3eb805b2,0xceb30039,0x2120026c,0x7ce60061}},	//   _mart_, דית_, koih_, _kórh,
   {{0x6ee4809f,0xa3b58074,0x3eb80168,0x0fb683b7}},	//   _mòbi, _जनम_, _lart_, _अनपढ,
   {{0x44320d38,0x29048025,0xd943b915,0x2d85900a}},	//   _czy_, mima_, _реци, arle_,
   {{0x2904e3ed,0x1eaa81ad,0x75240365,0x28e10075}},	//   lima_, _ذاتي_, _ekiz, _नवहि,
   {{0x39150381,0x21290867,0x98a68035,0x26cd00ff}},	//   емвр, tlah_, _choć_, _đeo_,
   {{0x212909ca,0xf8bf00ff,0x61258118,0x3eb863ee}},	//   ulah_, _chép_, sólv, _aart_,
   {{0x21293932,0xf7700bbe,0x2d8ce3ef,0x26dc8110}},	// [5490] rlah_, لال_, lude_, _kovo_,
   {{0x442963f0,0x21290057,0x2904e3f1,0x26dc8b80}},	//   _iya_, slah_, hima_, _jovo_,
   {{0x2d8c803b,0x61e100f2,0x2129010b,0x3ced81c0}},	//   nude_, älld, plah_, _plev_,
   {{0x29048025,0xd25109d7,0x44290c56,0xf8bf00ff}},	//   jima_, _جنگ_, _kya_, _ghép_,
   {{0x290482a5,0x80cc020e,0xb87b01a8,0x2d8ce3f2}},	//   dima_, हारे, _dlít, hude_,
   {{0x26dce3f3,0x41b5a4b2,0x78a28039,0x659513bd}},	//   _novo_, есит, _abov, _пагу,
   {{0x60dd307e,0x442902ec,0x2d8caf2c,0xdb098362}},	//   _kosm, _lya_, jude_, _breò,
   {{0x4429148e,0x290d802e,0x2d8ce3f4,0x644d01a8}},	//   _oya_, unea_, dude_, _ngai,
   {{0x442963f5,0x61e38aa2,0x290db50a,0xf0768019}},	//   _nya_, synl, rnea_, ریوں_,
   {{0x4d6585c2,0x644d46ff,0x26dc80e5,0x752463f6}},	//   нков, _agai, _covo_, _skiz,
   {{0x442963f7,0x29048503,0x7c29af8c,0x644d00dd}},	//   _aya_, bima_, _hyer, _bgai,
   {{0x29048025,0x442901d3,0x09bd84e5,0x998d009a}},	//   cima_, _bya_, ्मीय, łeś_,
   {{0x44290578,0x644d0580,0xb87b1243,0x78ad3c51}},	//   _cya_, _dgai, _moíd, deav,
   {{0x2d8c803e,0x67238289,0x68e9e3f8,0x91fc80eb}},	//   bude_, _uknj, lked, _teāt,
   {{0x28d385e8,0xf8bf0028,0x672186ec,0x60dd1e12}},	//   थापि, _phép_, molj, _bosm,
   {{0x68e9e3f9,0xb4ae816f,0x672182ce,0xa3cf800c}},	//   nked, _कसे_, lolj, षमा_,
   {{0x7c29e3fa,0x3eb80809,0xa7a70912,0xf77201a8}},	// [54a0] _nyer, _part_, нкта_, طاء_,
   {{0x290493b2,0x7d0663fb,0x6721e3fc,0x78b981c0}},	//   zima_, liks, nolj, _lawv,
   {{0x7c29e3fd,0x3eb8021e,0x68e9e3fe,0xf8bf00ff}},	//   _ayer, _vart_, kked, _thép_,
   {{0x61e10c3c,0x78ad0749,0x7c2980b4,0xb87b40a2}},	//   älle, ceav, _byer, _coíd,
   {{0x2904803b,0xa29485e9,0xd326b2de,0xdce20713}},	//   vima_, валі, ньки, ntlı,
   {{0x60cb828c,0xd24f9f33,0xdb098144,0x67218115}},	//   _angm, منه_, _breñ, jolj,
   {{0xfbd880c8,0x6721811f,0xe7370749,0x2b5f8197}},	//   _দেখত, dolj, _чер_, _etuc_,
   {{0xd3728077,0x859b0039,0x673e00f3,0x7bc463ff}},	//   _مهر_, _משלו, lmpj, _oriu,
   {{0x7c298065,0x7d066400,0x6d5a02be,0x26dc8317}},	//   _gyer, diks, _étab, _povo_,
   {{0x2d8ca51f,0x798e21bb,0x442902a0,0x75228c2e}},	//   tude_, kubw, _rya_, looz,
   {{0x44296401,0x7bc46402,0x23606403,0x7d063988}},	//   _sya_, _ariu, _atij_, fiks,
   {{0x399a80f1,0x2d8ce404,0x2ba78054,0x9c130135}},	//   mës_, rude_, _गहमा, kọta,
   {{0x66e6c675,0x24800355,0xdee68ff7,0x399a80f1}},	//   _пода, _ddim_, _поди, lës_,
   {{0x442900f6,0x657c37bc,0xd5b0803d,0x26dc847f}},	//   _vya_, _ovrh, _نفت_, _uovo_,
   {{0x399a820f,0x28c58996,0x60dd0a25,0x51840adb}},	//   nës_, वाचि, _posm, лута,
   {{0x88bd8063,0x61f58019,0x28a680d4,0x7bc4047f}},	//   mośc, _üzle, _कॉमि, _friu,
   {{0x81df00c8,0x399a80f1,0x61e10106,0x4429036a}},	// [54b0] _দেশ_, hës_, ällb, _uya_,
   {{0x399a820f,0x68e98061,0x7c29e405,0xb87b128a}},	//   kës_, zked, _ryer, _plís,
   {{0x88bd8063,0x6d4980eb,0xe31400f7,0x399a80f1}},	//   nośc, _piea, _حبيب, jës_,
   {{0x30790158,0x399a8168,0xa87903de,0x69c50362}},	//   _קאָנ, dës_, _קאָר, _irhe,
   {{0x38691295,0x06b780c8,0x98ab0035,0xeb998b5b}},	//   mbar_, জাতি, _chcą_, фил_,
   {{0x6aba9c4f,0x88bd809a,0x7d066406,0x78b98282}},	//   _catf, kośc, ziks, _sawv,
   {{0x399a80f1,0x752282ec,0x6ca78084,0x68e9df16}},	//   gës_, booz, _праж, tked,
   {{0x38696407,0xdddc0214,0x629c8106,0x610881d0}},	//   nbar_, _herş, _öron, děls,
   {{0x68e98a38,0x7d0628be,0xa3b586ae,0x78bbd929}},	//   rked, viks, _जनि_, rduv,
   {{0x3f83e408,0x68e9e409,0x3869640a,0x0ab488ca}},	//   čju_, sked, hbar_, _محمد,
   {{0xee398987,0x7d06640b,0x940c0201,0x399a8168}},	//   ьно_, tiks, ədə_, cës_,
   {{0x7bc4011f,0xe945803d,0xa3b5a7cf,0x60cba401}},	//   _priu, _شرای, _जना_, _ungm,
   {{0x67218067,0x3f8d8722,0x2ef59a1f,0xde16803d}},	//   polj, queu_, _издр, فقیت_,
   {{0x212da93f,0x2d6e801b,0xe8ca001b,0x29020748}},	//   lleh_, bře_, ाञ्च, _smka_,
   {{0x6b9d115b,0x412a04db,0xb87b02df,0xd04d0326}},	//   atsg, дово_, _alíq, nkaɗ,
   {{0x63a9d317,0x3f89640c,0x6ba50338,0x2fc0640d}},	//   _open, frau_, åtgä, tvig_,
   {{0x62818db7,0x657c003a,0xd007091e,0x61430adb}},	// [54c0] _odlo, _svrh, вете_, рета,
   {{0x75228c56,0x45140264,0x2fc057ff,0xddc701f4}},	//   wooz, _সঠিক_, rvig_, _sejš,
   {{0x63a99820,0x386915f4,0x9d468098,0xdd8f0f99}},	//   _apen, bbar_, вежд, قول_,
   {{0x399a820f,0x7afd81e2,0x80a19da7,0x62818428}},	//   vës_, _įsta, _कॉले, _adlo,
   {{0x29120393,0x8b9681a0,0x3940640e,0xc1da928a}},	//   mnya_, треч, mmis_, यङ्ग,
   {{0x399a820f,0x291213b8,0x3940640f,0x68f66410}},	//   tës_, lnya_, lmis_, lhyd,
   {{0x7d0455dc,0x2912322c,0x63a9e411,0x7f4a808e}},	//   _omis, onya_, _epen, _rifq,
   {{0x29126412,0x399a820f,0x52df3a6a,0xfce38237}},	//   nnya_, rës_, _नक्स, _косо,
   {{0x88bd8063,0x8afd800d,0x8c43a865,0x29120057}},	//   wośc, _stře, _вете, inya_,
   {{0x29120393,0x7d046413,0x399a8168,0x310210f7}},	//   hnya_, _amis, pës_, रोतः_,
   {{0x2912048f,0x7bc293f2,0xfdd08264,0x38696414}},	//   knya_, lvou, ান্ড, ybar_,
   {{0x2912036e,0x6eed8118,0x6b9d0fb6,0x657ae415}},	//   jnya_, _fúbo, ttsg, rsth,
   {{0x29120867,0x7bc285f8,0x38696416,0xf54a001c}},	//   dnya_, nvou, vbar_, _nấu_,
   {{0x2caf80f3,0x2fc6a022,0x29123e6e,0x6b9d286c}},	//   zegd_, _irog_, enya_, rtsg,
   {{0x2912010b,0x394b60dc,0x386901ec,0x8c3da828}},	//   fnya_, _pics_, tbar_, _daşy,
   {{0x7d1600f1,0x291210e1,0x2fc6e417,0x99bb8039}},	//   _gjys, gnya_, _krog_, וזלט,
   {{0xa2d00076,0x383509b4,0x38696418,0x386605e4}},	// [54d0] दाश्, унар, rbar_, ñora_,
   {{0xf54a0028,0x29121a1a,0x2d9e837a,0xb87b12ca}},	//   _dấu_, anya_, otte_, _elíp,
   {{0x29120057,0x69c515ec,0x63a9b9fd,0x272f0019}},	//   bnya_, _urhe, _spen, lünk_,
   {{0x7ce626d1,0x29120101,0x27398036,0x7c2d2f70}},	//   _fóru, cnya_, mène_, _kyar,
   {{0xceeb09d7,0x2fc690af,0xc48481e5,0x27398036}},	//   _قرآن_, _nrog_, рлік, lène_,
   {{0x68ed0c9a,0x8f9a0039,0xe29680a9,0xf8d1016f}},	//   lkad, _אישי, гаш_, हावय,
   {{0x78bd0a92,0xf2d40158,0x6eede419,0xeaf38b9f}},	//   _kasv, יעס_, _súbo, _अतीत_,
   {{0xa502016f,0x272f0061,0x6d4d0bb1,0x7c2d641a}},	//   _लगेच_, künk_, _niaa, _oyar,
   {{0x27e9641b,0xf54a001c,0x7c2d4461,0x63a98010}},	//   nyan_, _mất_, _nyar, _upen,
   {{0x6d55227d,0x442dc68b,0x2fc6ac15,0xc9879033}},	//   _kuza, _iye_, _drog_, _ауди,
   {{0x442dbcb8,0xde05e41c,0x2912015d,0x7c2d641d}},	//   _hye_, упни, ynya_, _ayar,
   {{0x78bd0db7,0x6d55641e,0x7c2d02a0,0x27e9040a}},	//   _nasv, _muza, _byar, kyan_,
   {{0xbea59e16,0xdb0d05e4,0x6d550102,0xe72eae27}},	//   _балк, _arañ, _luza, _ге_,
   {{0x442d835f,0xdb0d01df,0x29120101,0x27e9641f}},	//   _mye_, _brañ, wnya_, dyan_,
   {{0x7ae1e420,0x2912048f,0xf54a00ff,0x442de421}},	//   _molt, tnya_, _bất_, _lye_,
   {{0x442de422,0x61e1016d,0x7ce6002a,0xb4db0722}},	//   _oye_, älla, _córt, rmàc,
   {{0x29120393,0x7e7509a4,0x442dd61e,0x27e96423}},	// [54e0] rnya_, _bezp, _nye_, gyan_,
   {{0x29120393,0x4df60364,0x6d555589,0x98a026d5}},	//   snya_, ляет, _buza, klić_,
   {{0x291213b8,0x442dc68b,0x4a9b0158,0x1a9b00be}},	//   pnya_, _aye_, _אייג, _אייע,
   {{0x442db003,0x68ed00f2,0x753be424,0x2d8705e4}},	//   _bye_, ckad, _chuz, ánea_,
   {{0x7ae1e425,0xc879807e,0x7fd50558,0x442d80b4}},	//   _bolt, daş_, _кірі, _cye_,
   {{0x2d9e8aa2,0x78bd141f,0x68e30087,0x6b84826c}},	//   ytte_, _zasv, _îndr, šigo,
   {{0xee370611,0x6abe4612,0x272f0061,0x98a006ec}},	//   _бнр_, _mapf, zünk_, glić_,
   {{0x8c469071,0x442d86c4,0x3ea7841c,0x7df3811c}},	//   _бебе, _fye_, _abnt_, cəsə,
   {{0x2ef4938c,0x6d55016b,0x442d8c56,0x98ab0035}},	//   изир, _zuza, _gye_, _chcę_,
   {{0x6d4d008e,0x7f4e01b9,0x68ed6426,0x7c2d00b4}},	//   _siaa, _jibq, zkad, _ryar,
   {{0x7c2d14ec,0x6d4d0122,0xd884803d,0x645a01d0}},	//   _syar, _piaa, _نهای, ětin,
   {{0x27e9068a,0x272f0019,0x3f926427,0x27399f5a}},	//   yyan_, tünk_, kuyu_, vène_,
   {{0xf54a0104,0x78bd6428,0x2bc7902e,0x2d9ed810}},	//   _rất_, _rasv, लिया, stte_,
   {{0x78bd0025,0xbebc8029,0x7ce600f7,0x88bd8035}},	//   _sasv, glīt, _sórt, nośn,
   {{0xc3338051,0x7ce62d83,0x78bd6429,0x7e75008e}},	//   מוש_, _pórt, _pasv, _rezp,
   {{0x6d550314,0x68e2cb07,0x27e9642a,0x27398866}},	//   _ruza, _jood, tyan_, rène_,
   {{0x68ed642b,0x68e2e42c,0x629ab6db,0x7c2d0214}},	// [54f0] rkad, _mood, _octo, _uyar,
   {{0x3f87003a,0xdef807ac,0x68ed642d,0x200d0125}},	//   čnu_, лых_, skad, _þeim_,
   {{0xf54a0028,0x54559a4e,0x27e9642e,0x442de42f}},	//   _tất_, авет, syan_, _sye_,
   {{0x68e280c9,0xa3e909a9,0x442d8247,0x7ce601df}},	//   _nood, _यथा_, _pye_, _hórr,
   {{0x69c8e430,0xe2999cf4,0x6d5a02be,0x7ae1e431}},	//   _arde, вал_, _étan, _polt,
   {{0x63ad24d4,0x6d553820,0x442d86c0,0x084e8133}},	//   _mpan, _tuza, _vye_, _kọfị_,
   {{0x7ae1e432,0x68e2e433,0xdb00806a,0x2ca900c3}},	//   _volt, _bood, _opmæ, _obad_,
   {{0x3f9f8009,0x442d867f,0x98a0076c,0x00e58087}},	//   ttuu_, _tye_, rlić_, ржин,
   {{0x68e2e434,0x2d8c85f8,0x442d8234,0x60dbe435}},	//   _dood, erde_, _uye_, rjum,
   {{0x2ca9059e,0x7d0be436,0x63bbe437,0x26c100d7}},	//   _abad_, ligs, _isun, ndho_,
   {{0xa2d90e70,0x68e2e438,0x63ad6439,0x3f9f8009}},	//   मान्, _food, _apan, stuu_,
   {{0x7bc9e43a,0x7d0be43b,0x68e2e43c,0x8c460249}},	//   _kreu, nigs, _good, иене,
   {{0x61e100f2,0x2d8ce43d,0x5fa9801b,0x2cbfa126}},	//   älln, arde_, _कहिल, _maud_,
   {{0xf7708077,0x2cbfcd88,0x386d82af,0x7ce61b13}},	//   _راه_, _laud_, lber_, _córr,
   {{0xf8bf08f9,0x63ad643e,0x7d0b833e,0x68e28037}},	//   _baé_, _epan, kigs, _yood,
   {{0xc95501e2,0x786625f5,0x394f81e0,0x3f5b801c}},	//   стры, рказ, _jigs_, _kêu_,
   {{0xb8de0610,0x386d81ec,0x394f82c4,0xaf06643f}},	// [5500] _इस_, iber_, _migs_, апал,
   {{0x394f80b9,0x8ca70035,0x657e01ec,0x543b03de}},	//   _ligs_, ट्ठो, tsph, _בעפא,
   {{0x386de440,0xd91009d7,0x63bbe441,0x98a61adc}},	//   kber_, _فیس_, _asun, _кине,
   {{0x64a6a5a4,0x0b8a9a1f,0x7bc981ba,0xdca6b0bb}},	//   рада, вски_, _breu, ради,
   {{0x7bc9e442,0x2cbf800e,0x93468294,0x68e2800b}},	//   _creu, _daud_, анде, _rood,
   {{0x7bc9e443,0x3f8d8722,0x68e290b5,0xfc3f0511}},	//   _dreu, dreu_, _sood, nfía_,
   {{0x7e7a8b81,0xaca481bc,0x68e282f1,0xb05b0106}},	//   vatp, _agụp, _pood, _knäp,
   {{0x7bc9e444,0xa7748193,0x3860451b,0x2d8c817f}},	//   _freu, блич, ncir_, vrde_,
   {{0x7bc9e445,0x5fc903ca,0x6fc906f0,0x68e282f1}},	//   _greu, रियल, रियं, _vood,
   {{0x2cbf8282,0x9ed88187,0x28a6864a,0x8544819d}},	//   _zaud_, умот_, _कॉरि, _ịghọ_,
   {{0xd5b7e446,0x386d93e1,0x68e28074,0x07370039}},	//   ася_, bber_, _tood, שאים_,
   {{0x186aa4c1,0xa06ac317,0x6fc900d4,0x3f8d9ed6}},	//   _ради_, _рада_, रिमं, breu_,
   {{0x63a2e447,0xda788038,0x92d880ab,0x07da803d}},	//   nton, _keď_, াসী_, _جذاب_,
   {{0x6298be67,0x81c781a9,0x39b80176,0x63a282df}},	//   ngvo, stēš, _bōs_, iton,
   {{0xed578003,0xb6cb8065,0x58d51182,0x7c872167}},	//   _кој_, _جانے_, бовт, _купе,
   {{0x3f5b8104,0x63a2e448,0xa3d6902e,0x26de826c}},	//   _yêu_, kton, िमा_, ljto_,
   {{0x63ad5c61,0xfb85003d,0xdddaa5d6,0x752d6449}},	// [5510] _upan, _ادبی, katū, _ikaz,
   {{0x6d58e44a,0x28a69516,0x2cbf8069,0x2d8705e4}},	//   _kuva, क्ति, _saud_, áneo_,
   {{0xdfc68019,0x386de44b,0x2cbf8101,0x7d0bc5bd}},	//   _کي_, yber_, _paud_, tigs,
   {{0x7c87be1c,0x6d58e44c,0x63a2e44d,0x237f011f}},	//   руже, _muva, fton, šuju_,
   {{0x7ae524da,0x672884a8,0xd3088028,0xe78419bb}},	//   _koht, kodj, yệt_, _муро,
   {{0x7ae50364,0x7bc9e44e,0xf54a0129,0x2d93002a}},	//   _joht, _vreu, _lấp_, puxe_,
   {{0x752d644f,0xceb20039,0x386d808e,0x6d58e450}},	//   _okaz, _מים_, tber_, _nuva,
   {{0x63bb9ce9,0x7bc9e451,0x6ea9800d,0x3f8de452}},	//   _tsun, _treu, ज्नु, treu_,
   {{0x63bbb97a,0x7d09e453,0x6edb06ab,0x394f867f}},	//   _usun, _imes, नापु, _vigs_,
   {{0x3f8d895b,0x6d58e454,0x67288916,0x752d43f1}},	//   rreu_, _buva, godj, _akaz,
   {{0x776983a8,0x69c702ce,0x2d8100a4,0x6d5894a9}},	//   spex, jvje, nshe_, _cuva,
   {{0xf54a0104,0x69c702ce,0xf1c38110,0x6d58e455}},	//   _cấp_, dvje, rašė_, _duva,
   {{0x7052806b,0x67288699,0xa8568039,0x7d0980de}},	//   _عنوا, bodj, _הינה_, _mmes,
   {{0x7d1be456,0x7c3b8010,0x543a80be,0x626324ff}},	//   _ljus, _mzur, טערא, звра,
   {{0x27ede457,0x5d858013,0xc33284de,0x63a28019}},	//   lyen_, _البل, פול_, zton,
   {{0xf54a001c,0x7d1b811f,0x7c3b8133,0xa5649f33}},	//   _gấp_, _njus, _ozur, _بدون,
   {{0x27ed8205,0x7c3b8010,0x38601b0d,0x27ff8300}},	// [5520] nyen_, _nzur, rcir_, nzun_,
   {{0x7d09b6fa,0x7d1bb9ef,0x7e562428,0xf6562187}},	//   _ames, _ajus, стац, стаю,
   {{0x7c3be458,0x2734016d,0x3f80023e,0x463a15a6}},	//   _azur, länk_, ssiu_, учая_,
   {{0x6723003a,0x63a2e459,0x6eed84c3,0x6d5a645a}},	//   čnja, tton, _dúbi, _étam,
   {{0x2ca6831d,0x27ed90ed,0x611398ad,0x68fbe45b}},	//   rfod_, jyen_, căli, dhud,
   {{0x7d09e45c,0x27ed86c0,0x64410085,0x60c4645d}},	//   _emes, dyen_, əlid, ldim,
   {{0xc05a8a4c,0xddda9482,0x6728d200,0x7c3b81bc}},	//   ліп_, ratū, vodj, _ezur,
   {{0x60c4645e,0xdca38d9e,0x64a3dbb8,0x63a2e45f}},	//   ndim, _наси, _наса, pton,
   {{0x27ed8065,0x6d58a0ec,0xda78801b,0xe762819d}},	//   gyen_, _suva, _teď_, _bọọs,
   {{0xc6f7827e,0xf76f96a5,0xdb040118,0x3f8a816b}},	//   йных_, راً_, _osiñ, čbu_,
   {{0x67289024,0x6b846460,0x6eed8118,0x67fe8032}},	//   rodj, _avig, _xúbi, _bàjé,
   {{0x27ed8247,0x8af98201,0x67289455,0xa1578039}},	//   byen_, rləş, sodj, _הבאה_,
   {{0x7e7e079f,0x6b829a98,0xf54a0129,0xddd50176}},	//   kapp, nsog, _vấp_, _egzň,
   {{0x64560065,0x6b841752,0x6b890289,0x6d58e461}},	//   _egyi, _dvig, šego, _tuva,
   {{0x6b840bbd,0x752d18ad,0xddc8b583,0x7e7e4330}},	//   _evig, _tkaz, ladž, dapp,
   {{0x752d29c7,0x3e4e8085,0x61138162,0x79950435}},	//   _ukaz, mət_, tăli, ruzw,
   {{0x69c72c14,0xe80303eb,0xddc8803b,0x14d62441}},	// [5530] svje, _रेखा_, nadž, धारण,
   {{0x6d40e462,0x7d09b07d,0x7bcd0102,0x2d8101f6}},	//   _ahma, _smes, _irau, tshe_,
   {{0x6d408267,0xddc888ae,0x3e4e8085,0x2c5e8133}},	//   _bhma, hadž, nət_, _ịda_,
   {{0x60c2d000,0x7bcd2ba4,0x2d816463,0x27edabcf}},	//   _naom, _krau, rshe_, yyen_,
   {{0x889a04de,0xddc88bda,0x7e7e6464,0x7d09807a}},	//   _דברי, jadž, bapp, _vmes,
   {{0x28a68701,0x7e7e156f,0x395a02f7,0x776d03a8}},	//   क्सि, capp, _yups_, mpax,
   {{0xdd94076a,0x6aaa0352,0xa3b58054,0x659410f8}},	//   _нары, _öffe, _जनक_, _нару,
   {{0x7d09e465,0x27ed86c0,0x27ff8102,0x7a40008b}},	//   _umes, tyen_, tzun_, _hátí,
   {{0xe8f686b5,0xb87b05b9,0x7bcd01e9,0x23690282}},	//   іль_, _blíz, _nrau, _ntaj_,
   {{0x0d85af36,0x27ede466,0x05a997ae,0x45858d9e}},	//   олон, ryen_, авой_, огов,
   {{0x27ede467,0x7bcd011e,0x26c36468,0xc6920039}},	//   syen_, _arau, _majo_, ואי_,
   {{0x7bcd1de0,0x7a428019,0x03a60009,0x2d8b81d0}},	//   _brau, síté, оимо, čce_,
   {{0x28c40b9f,0xb87b0118,0xdd0c809a,0x7bcd01e0}},	//   _लोगि, _coím, _późn, _crau,
   {{0x7bcd6469,0x366984ae,0x3e4e8085,0x61ee646a}},	//   _drau, _тако_, bət_, tybl,
   {{0x7bcd0cdb,0xd5ac8065,0x2369646b,0x2d8700e1}},	//   _erau, _یہی_, _etaj_, šnej_,
   {{0x26c3046d,0x60c40110,0x290b00b9,0x44200069}},	//   _aajo_, udim, _cmca_, _txi_,
   {{0x26c305b4,0x6b8401df,0x6569026c,0x07a31a88}},	// [5540] _bajo_, _uvig, _čeha, матн,
   {{0x249f8012,0x57ba000d,0x69c80106,0x6d408168}},	//   _acum_, _उनीह, ådes, _shma,
   {{0xbc6a8277,0xe45a9628,0xa2dd801b,0x57b68074}},	//   لمان_, аже_, पान्, _अन्ह,
   {{0x629c271e,0x60c4011c,0x9b6a9e0b,0xe0df0229}},	//   lgro, qdim, ашка_, _chòd_,
   {{0xf746079e,0x8bb6803d,0x7e7e3dee,0x63a601e0}},	//   _мемо, تصاص, papp, ntkn,
   {{0x629c646c,0x3e4e8201,0x3872004a,0x2fcf006a}},	//   ngro, yət_, lbyr_, ægge_,
   {{0x14ca009a,0x6b82d463,0xaacb001b,0xe6170162}},	//   ियाण, ssog, ायतक, _ддр_,
   {{0x6d5c646d,0x37aaa27b,0x89db01c6,0x387fa4d1}},	//   _iura, атон_, שחקי, gaur_,
   {{0x28a6853f,0x6d5c15e8,0xd7fac85c,0x63ad80f1}},	//   क्षि, _hura, руй_, çant,
   {{0xddc8876c,0x2018802e,0x60c28c53,0x2ca020dd}},	//   radž, ări_, _waom, _acid_,
   {{0x7e7c0642,0x24890101,0x60c29581,0xb65b00be}},	//   _merp, _pdam_, _taom, ידיש,
   {{0xcd07035f,0x3e4e8201,0x30c500ab,0x7cff03ed}},	//   ічни, rət_, _এক্স, _mërg,
   {{0x81af00c8,0x7ac742bc,0x38cb826a,0x6d5c1651}},	//   ওয়া_, осве, _خالی_, _lura,
   {{0x2d87000d,0x6eed846d,0x6d5c1d88,0x629c0901}},	//   ánek_, _búbu, _oura, ggro,
   {{0x7ae88022,0xc0d1026b,0x7d0f01ed,0x0e7580e1}},	//   _modt, _akíọ, pics, äčší,
   {{0x58d41485,0x26c339e9,0x63a40168,0x7bcd0d88}},	//   мост, _sajo_, _fqin, _trau,
   {{0x7e7c0393,0x7cff020f,0x6d5c646e,0x6fbc81b6}},	// [5550] _berp, _përf, _aura, ्टिं,
   {{0x6d5c4851,0x7e7c0b20,0x8ca70aed,0x539a0039}},	//   _bura, _cerp, ट्रो, _פיתו,
   {{0x6d5c646f,0x7e7c0ed0,0x2bc311be,0x7bc0e470}},	//   _cura, _derp, शिका, _asmu,
   {{0x7cff00f1,0xf992010f,0xd7bc8aed,0xfd6281bc}},	//   _dërg, _ארט_, ्टाच, _satọ,
   {{0x39496471,0x7d0d0135,0x3af5af84,0xe0df6472}},	//   mmas_, _mmas, зяйс, _fiòr_,
   {{0x6d5c6473,0x39493df5,0x386681bc,0x8505881b}},	//   _fura, lmas_, _afor_, _کورن,
   {{0x39490207,0x6d5c6474,0x2d8aaff3,0x7d0d5a5a}},	//   omas_, _gura, ábel_, _omas,
   {{0x69cc016f,0x39496475,0x28bd90a1,0x6b4b0372}},	//   हिती, nmas_, ्यधि, _iżgu,
   {{0x4439cd67,0x7f5d02be,0x2d9e016d,0x394901a9}},	//   _ás_, _jusq, _äter_, imas_,
   {{0x7d0d19a2,0x6d5c6476,0x387fe477,0x443f8870}},	//   _amas, _yura, saur_, _izu_,
   {{0x6d5c09e3,0xdcfb0110,0xcee8803d,0x8cd803eb}},	//   _xura, nutė, ترين_, यालो,
   {{0x80a283b7,0x629c4799,0x26c382d4,0x7d0d0706}},	//   _गाये, wgro, žjo_, _cmas,
   {{0x443f8267,0x629c1336,0x98e481a8,0x087683de}},	//   _jzu_, tgro, _تكنو, _זענט_,
   {{0xdcfb00eb,0x7d0d50b6,0x6569026c,0x254d01d0}},	//   rstā, _emas, _čehn, _měly_,
   {{0x629c38f2,0xbbb88f97,0x867a81c6,0x91e600ae}},	//   rgro, _इन्क, _הרצו, чове,
   {{0x6d5a03d3,0x7f5d6478,0x443fe479,0x629c06a8}},	//   _étai, _busq, _ozu_, sgro,
   {{0x6d5c0763,0x81b180ab,0x6d56076d,0x629c13fc}},	// [5560] _sura, টটি_, _iiya, pgro,
   {{0x7cff08cf,0x6d5c3503,0xaa46647a,0x6d560637}},	//   _përg, _pura, _непл, _hiya,
   {{0x7e7c1781,0xfc668698,0x6d5c647b,0x2561b47c}},	//   _verp, пълн, _qura, _jól_,
   {{0x6fc9056b,0x6d5c07c0,0x6d562085,0x3949647c}},	//   रिशं, _vura, _jiya, cmas_,
   {{0x7e7c0393,0x6d56647d,0x6d5c04b9,0x6d440c41}},	//   _terp, _miya, _wura, _mhia,
   {{0x2912647e,0x6d5c647f,0x6d56478b,0x6ef680e7}},	//   liya_, _tura, _liya, _câbl,
   {{0x3f86801b,0x443f8135,0xdcfb0162,0x27f20198}},	//   _svou_, _ezu_, nstă, lyyn_,
   {{0x29126480,0x6d566481,0x290003a7,0x68e46482}},	//   niya_, _niya, nhia_, njid,
   {{0x60c6045f,0x69c1811b,0x7c2403ed,0x387d9bc2}},	//   _makm, _esle, _nxir, _dewr_,
   {{0xd6da92e1,0x6d4401bc,0x29121066,0x6440e483}},	//   сти_, _ahia, hiya_, _izmi,
   {{0x6d566484,0x39490110,0x29126485,0x2fc700ff}},	//   _biya, ymas_, kiya_, ̉ng_,
   {{0x6d446486,0x6d564a6e,0x66010214,0x29121d15}},	//   _chia, _ciya, _ülke, jiya_,
   {{0x6d566487,0x29126488,0x29006489,0x6d44648a}},	//   _diya, diya_, dhia_, _dhia,
   {{0xdee39260,0x66e3835f,0x28da8aad,0x60c602c4}},	//   _почи, _поча, भावि, _aakm,
   {{0x7cff020f,0x6d5607d9,0x291200a4,0x6d440083}},	//   _përd, _fiya, fiya_, _fhia,
   {{0x2912648b,0x3949648c,0x6d4408d8,0x7d0d648d}},	//   giya_, umas_, _ghia, _umas,
   {{0xb8e52594,0x60c615d7,0x80a1db64,0x395e852a}},	// [5570] _एस_, _dakm, क्टे, _luts_,
   {{0x6d564674,0x3949648e,0xbbc906b7,0x98b201a9}},	//   _ziya, smas_, िटीक, ībās_,
   {{0x2912482a,0x6440883a,0x6d563a1d,0x7d1d648f}},	//   biya_, _azmi, _yiya, onss,
   {{0x29006490,0x291204b9,0x7d1d00d9,0x7f5d0144}},	//   chia_, ciya_, nnss, _tusq,
   {{0xfbab8b88,0x8ca5016f,0x7d1d008b,0x27e0027d}},	//   стей_, _कानो, inss, cxin_,
   {{0x3eba6491,0x2d8580e1,0x395e8036,0x78a28580}},	//   cept_, ysle_, _buts_, _acov,
   {{0xa9c480f7,0x2d9a0036,0xb457853d,0xceb203de}},	//   فزيو, cupe_, _فیاض_, _שיל_,
   {{0x2561c084,0x6ca49a18,0x395e8580,0x28da825a}},	//   _ról_, _пруж, _duts_, भाषि,
   {{0x443fab22,0x2561df48,0x6d566492,0x29038084}},	//   _uzu_, _sól_, _riya, ėja_,
   {{0x6d566493,0x09bc80c8,0x6d446494,0x29126495}},	//   _siya, _অপরা, _shia, ziya_,
   {{0x57ba22bd,0x6d563c62,0x6d4401c5,0x69c1a3b8}},	//   _उन्ह, _piya, _phia, _usle,
   {{0xd00e89d7,0x2900377f,0x6d5640ac,0xfd660091}},	//   الی_, xhia_, _qiya, _aapọ,
   {{0x2d9a80e8,0xb4e6026b,0xbea58056,0x6eed81d6}},	//   _åpen_, _apàà, _жалк, _dúbr,
   {{0x6283e496,0x25619f04,0x853d0084,0x6d566497}},	//   nano, _tól_, ntėj, _wiya,
   {{0x6d44146a,0x248d8052,0x6d566498,0xc3328039}},	//   _thia, _odem_, _tiya, דום_,
   {{0xb4bc853e,0x6283831d,0x78bbe499,0x26c780b4}},	//   _असे_, hano, neuv, _hano_,
   {{0x2912649a,0x6283912e,0x26c7b31c,0x236d81e9}},	// [5580] riya_, kano, _kano_, _ntej_,
   {{0x2912649b,0x248024f1,0x2900649c,0x68f6649d}},	//   siya_, _heim_, shia_, skyd,
   {{0x26c7e49e,0x6283e49f,0x60c664a0,0x291235bf}},	//   _mano_, dano, _takm, piya_,
   {{0x60c98259,0x2d870187,0x6abc64a1,0x799c0314}},	//   jdem, ânea_, lerf, murw,
   {{0x62838b67,0x60c98365,0x69ce64a2,0x9f5281d0}},	//   fano, ddem, lvbe, ždém_,
   {{0xf96a9cd0,0x7cff00f1,0x27e084b7,0x290f8122}},	//   орий_, _kërc, _ħin_, _amga_,
   {{0x200d07ca,0x68eba55e,0xbebc80eb,0x65c31f2f}},	//   _þeir_, _bogd, lnīg, _ибра,
   {{0xe6431cd0,0xa3de001b,0xb4c80697,0x2bbf864a}},	//   _респ, णमा_, ईयो_, _शैवा,
   {{0x68ebe4a3,0x6abc007b,0x26c782ec,0x7d02ccfd}},	//   _dogd, kerf, _bano_, mhos,
   {{0x6283a790,0x7d0283a7,0x752f009a,0x799c0314}},	//   cano, lhos, wocz, kurw,
   {{0x24800352,0x06970039,0x75d480f7,0x15150198}},	//   _beim_, ודים_, ريحا, едня,
   {{0xb4bc816f,0x7d02e4a4,0x290f8122,0x2ebb1a4d}},	//   _असो_, nhos, _gmga_, _उस्त,
   {{0x7cff020f,0x26c7e4a5,0x27e0861c,0x752f0035}},	//   _përb, _fano_, _çin_, rocz,
   {{0xf54a0028,0xe6c81905,0x26c7c3d3,0x2fc04b08}},	//   _mấy_, रयोज, _gano_, dwig_,
   {{0xf54a0028,0x394681c0,0x752f009a,0x7d02805d}},	//   _lấy_, _khos_, pocz, khos,
   {{0x6aaa02af,0x69d864a6,0x7e6d8115,0xc1570135}},	//   _öffn, _švec, _đapi, _ụgbọ,
   {{0x78ad393d,0x26c7833e,0x7d02c0d0,0x96db06a7}},	// [5590] rfav, _yano_, dhos, नालॉ,
   {{0xa3be00d4,0xf3ff0187,0x6283e4a7,0x6b9d5064}},	//   ीटर_, lcão_, xano, musg,
   {{0x6b89803a,0x6283e4a8,0x2734016d,0x7d02c7a7}},	//   _sveg, vano, vänt_, fhos,
   {{0x26c717aa,0xf77326ee,0x69c52cde,0xf54a0129}},	//   žno_, _لاس_, _ishe, _bấy_,
   {{0x4fc40087,0xf54a0129,0x3f9b011c,0x7e6a839c}},	//   _исра, _cấy_, ququ_, _offp,
   {{0x3869201d,0x877a03c8,0x290f80dd,0x39468122}},	//   lcar_, _מאשי, _smga_, _ahos_,
   {{0x7d02936f,0x6b9d64a9,0x39468a2a,0x3959288b}},	//   bhos, husg, _bhos_, _kiss_,
   {{0x38693cc1,0x26c7e4aa,0xc7c88028,0x6283e4ab}},	//   ncar_, _sano_, _bố_, sano,
   {{0x62838ff9,0x26c7e4ac,0xc7c88028,0x39468282}},	//   pano, _pano_, _cố_, _dhos_,
   {{0x69c5359e,0x3ea10c53,0xeab081a8,0x395964ad}},	//   _oshe, nght_, _نعم_, _liss_,
   {{0x3ea11c4f,0x6d5a00e7,0x2bc790be,0x26c7abe4}},	//   ight_, _état, लिका, _vano_,
   {{0xed59800d,0x64ca1995,0x673a910f,0xfce6004a}},	//   _již_, ियेश, altj, хомо,
   {{0x394de4ae,0xdd0c8063,0x6281e4af,0x26c78010}},	//   mmes_, _różn, _kelo, _tano_,
   {{0x394de4b0,0x7cff00f1,0x6281811f,0x799c5c7b}},	//   lmes_, _përc, _jelo, turw,
   {{0x395901cd,0x7d02c77a,0x394d8722,0x28a6e4b1}},	//   _biss_, yhos, omes_, क्कि,
   {{0x0d828098,0x6281b2b3,0x395942f3,0x799c00b4}},	//   _слън, _lelo, _ciss_, rurw,
   {{0x69c564b2,0x14dd06af,0x6abc05d8,0x799c64b3}},	// [55a0] _eshe, यारण, perf, surw,
   {{0xf1c58028,0x69c500f1,0x64440db1,0x2fc029f6}},	//   _đáng_, _fshe, _izii, rwig_,
   {{0x7d02e4b4,0x395902a6,0x394d8612,0xf54a0129}},	//   thos, _fiss_, kmes_, _sấy_,
   {{0xa6de8104,0x6281831d,0xe811016f,0x69ce8118}},	//   _nhưn, _aelo, _ठेवा_, _ábei,
   {{0x28c3800c,0x6281e4b5,0x99bc80ab,0xe3af8a47}},	//   वजनि, _belo, _অপেক, مرو_,
   {{0x6281e14a,0x7d02b8b6,0xddda84e8,0x31c691f3}},	//   _celo, shos, hatš, есив,
   {{0x6281e4b6,0xc7c88104,0x7d02e4b7,0x3946e4b8}},	//   _delo, _số_, phos, _phos_,
   {{0x6d5e8036,0x3cff81a1,0x394dd433,0xa6de8129}},	//   _épai, _gluv_, gmes_, _chưn,
   {{0xf76f803d,0xf77280f7,0x7d008074,0x26ca64b9}},	//   یای_, داع_, _ilms, _kabo_,
   {{0x6281be61,0x09e69e16,0x1ddb9094,0x80a286ae}},	//   _gelo, _позн, यमंत, _गावे,
   {{0x32078063,0xceb30039,0xa2dd800c,0x7bcf022c}},	//   czny_, אית_, पार्, wvcu,
   {{0x26ca64ba,0xc7c8801c,0x6b9d64bb,0x28a7e4bc}},	//   _labo_, _tố_, tusg, _गायि,
   {{0xd12f8065,0x7b09026c,0x258681d0,0xe0df0362}},	//   _امن_, džur, _bílá_, _bhòn_,
   {{0x26ca2948,0xd84f2aaa,0x75240caa,0x02cb052a}},	//   _nabo_, _dọla_, _ejiz, ायेन,
   {{0x6b4002af,0x7d0082c4,0x69dc802a,0x318c81d0}},	//   mögl, _olms, _áred, něz_,
   {{0x3ebee4bd,0x26ca64be,0x2d9ee4bf,0xa63b81c6}},	//   lett_, _aabo_, mute_, _מגור,
   {{0xf770045b,0x2d9ee4c0,0x98170077,0x26ca1d8b}},	// [55b0] مال_, lute_, ربرا, _babo_,
   {{0x26ca1313,0x69c501e9,0x61e1016d,0x3959010c}},	//   _cabo_, _tshe, älls, _wiss_,
   {{0x21200805,0x3f8964c1,0x69c53a0f,0x4ade02f1}},	//   bnih_, ssau_, _ushe, मारव,
   {{0x6281e4c2,0xd4e48607,0x5ce49edc,0x628764c3}},	//   _selo, лючи, люча, lajo,
   {{0x62818152,0x60cd02b8,0x3ebee4c4,0xfaa58729}},	//   _pelo, mdam, kett_, вало,
   {{0x60cd64c5,0x2d9e8074,0x60dd008e,0x3869a3b3}},	//   ldam, kute_, _hnsm, _żar_,
   {{0x3ebe8eb9,0x60cd0110,0x09e5b592,0x394de4c6}},	//   dett_, odam, тойн, tmes_,
   {{0x2d9ee4c7,0x60cd138e,0x26ca273c,0x6281ca26}},	//   dute_, ndam, _zabo_, _welo,
   {{0x394de4c8,0xf771990c,0x3ebee4c9,0x5ef8085d}},	//   rmes_, جاب_, fett_, _एवम्_,
   {{0x394de4ca,0x60cd64cb,0x628764cc,0x2d9ee4cd}},	//   smes_, hdam, jajo, fute_,
   {{0x62870619,0xe8df81bc,0x2eee9d21,0x7c3b82f7}},	//   dajo, _agụm_, _doff_, _hyur,
   {{0xc329010f,0x6d4983ac,0x2904b2b9,0x7c3be4ce}},	//   _וו_, _jhea, chma_, _kyur,
   {{0x6d498ad0,0x60cd64cf,0x68e982ce,0xd9ca052a}},	//   _mhea, ddam, mjed, ाट्ट,
   {{0x68e98d26,0xe61182e3,0x60dd3e19,0xa2d90651}},	//   ljed, _پشت_, _ansm, माग्,
   {{0x26ca47a3,0x5eca00ab,0x19b92d5d,0x6b400106}},	//   _rabo_, রামে, нуть_, sögo,
   {{0x26ca64d0,0x60cd5e5b,0x60cb826c,0x20094a0d}},	//   _sabo_, gdam, _jagm, fzai_,
   {{0x628723e5,0x60cbb3df,0xf77216a5,0x26ca64d1}},	// [55c0] bajo, _magm, شاء_, _pabo_,
   {{0x21200824,0x60cb998d,0xb87b0118,0xbebc80eb}},	//   snih_, _lagm, _boís, mnīc,
   {{0x6d49803c,0xd6cf003f,0x65638073,0xc4868396}},	//   _bhea, تقل_, _junh, влек,
   {{0x3ebe8065,0x60cbe4d2,0x6d49bf88,0x26ca1d8b}},	//   zett_, _nagm, _chea, _wabo_,
   {{0xa3b48160,0x6d498c64,0x4e12000d,0xdca391d5}},	//   ублі, _dhea, _धेरै_, рачи,
   {{0x69ce8074,0x934397d6,0xdb1b816a,0x78a422c9}},	//   थिली, анче, _bruñ, lgiv,
   {{0x656387f4,0x2904e4d3,0x6d498ad0,0xe567806b}},	//   _nunh, thma_, _fhea, _خط_,
   {{0x6d49861f,0x68e98168,0x2d9e9b2e,0x3ebee4d4}},	//   _ghea, gjed, vute_, wett_,
   {{0x3ebe8065,0x60cbdc04,0xaae2a8bf,0xa3b683ca}},	//   tett_, _dagm, पादक, _जहि_,
   {{0x248481cd,0x81b900ab,0x2d9ee4d5,0x7522e4d6}},	//   _hemm_, চিত_, tute_, lnoz,
   {{0x6563e4d7,0x68e982fd,0xdb1be4d8,0x69d801e2}},	//   _cunh, bjed, _usuá, _šven,
   {{0xdddc0025,0x656387f4,0xa3b68768,0x3ebee4d9}},	//   _održ, _dunh, _जहा_, sett_,
   {{0x5f068676,0x78a40082,0x656386ff,0x628764da}},	//   _изда, dgiv, _eunh, tajo,
   {{0x2d9ee4db,0x68ef02a3,0x9b580098,0x52c0e4dc}},	//   pute_, _socd, кият_, _एसोस,
   {{0x3eab9e51,0xbbbf864a,0x30a70a18,0x5bbf864a}},	//   žitý_, _एन्क, крав, _एन्व,
   {{0x628764dd,0x442964de,0x6b8d8267,0x60c08198}},	//   sajo, _txa_, šagi, nemm,
   {{0x75228690,0xbed909c7,0x69d8002a,0x58840084}},	// [55d0] dnoz, ндах_, _áven, рыса,
   {{0x65638708,0x20092fe3,0xdf3900f7,0x60c0e4df}},	//   _yunh, rzai_, ركات_, hemm,
   {{0x7c3b9083,0x6d498083,0x62853d67,0x60c0e4e0}},	//   _syur, _phea, _ieho, kemm,
   {{0x60c0e4e1,0x6d5e8036,0x7699026b,0x21268168}},	//   jemm, _épau, _bùyà, _njoh_,
   {{0x289a012a,0x4429a379,0x68e982ce,0xfd580133}},	//   _אירא, ça_, vjed, _akaụ,
   {{0x628564e2,0x93fc03c8,0x442981b9,0x05138264}},	//   _jeho, ולדי, ħa_, িকের_,
   {{0x60cb9066,0x62853351,0x3c9382e3,0xdddc0259}},	//   _pagm, _meho, _نیاز, _zdrž,
   {{0x628564e3,0x6d5a80e7,0x50459f91,0x7c29811b}},	//   _leho, _étap, лейб, _txer,
   {{0x69c8809f,0x7b99803d,0x68fba723,0x213902f7}},	//   _esde, _سپاس_, rkud, _mksh_,
   {{0x26c164e4,0x68e982fd,0x62850e93,0x65638187}},	//   neho_, sjed, _neho, _punh,
   {{0x941e0201,0x63ad3a0f,0xe0df0706,0x60cbe03e}},	//   ətə_, _aqan, _phòl_, _tagm,
   {{0xeb9a1a03,0xf2c9012a,0xe0d088ca,0x97c5830f}},	//   ним_, _מע_, _وزن_, _مقصو,
   {{0x69d709e3,0x628564e5,0x5fb7800d,0x8ca502b4}},	//   _arxe, _beho, _अहिल, _कारो,
   {{0xe3630dca,0x63bbb190,0xe5a58396,0x69dc802a}},	//   скри, _mpun, _бики, _árec,
   {{0xceb28039,0x021900e8,0x2c1a801b,0xbebc80eb}},	//   _היו_, віть_, _मेनू_, snīc,
   {{0x386de4e6,0xe0df0706,0xa2a8152c,0x63bbe4e7}},	//   ncer_, _cnò_, ञ्ज्, _opun,
   {{0xd9431c78,0x7d0464e8,0x6b891c89,0x3f8de4e9}},	// [55e0] сети, _ilis, šegr, nseu_,
   {{0x62850e61,0x78a464ea,0x4b7b1101,0x6d438866}},	//   _geho, sgiv, _ראיו, înan,
   {{0x63bbadb0,0x386d82f7,0x3ce001a3,0x881a026b}},	//   _apun, kcer_, _kniv_, _dírẹ,
   {{0x163680be,0xa3c8052a,0x63bb8f35,0x00000000}},	//   אנער_, _ईना_, _bpun, --,
   {{0x925a0077,0x628528ba,0xdddc05b9,0x26c10b5e}},	//   _تشکر_, _yeho, _udrž, beho_,
   {{0x394024a1,0x7d0407e2,0x69c884c3,0x26c101ac}},	//   llis_, _llis, _psde, ceho_,
   {{0x7d040364,0x14aa0072,0x2f008176,0x5eca0264}},	//   _olis, _काढण, _bògn_, রাদে,
   {{0x2902e4eb,0xb87b0073,0x7643009a,0xed578c9b}},	//   óka_, _iníc, żnyc, _бос_,
   {{0x60c09485,0x7dea8085,0x1d078009,0x69d80084}},	//   remm, məsi, _сети_, _švel,
   {{0x7d0400f6,0xd24f8077,0x60c0e4ec,0x7dea8085}},	//   _alis, _کنم_, semm, ləsi,
   {{0x39401648,0x628564ed,0xdbca8074,0xe814a594}},	//   klis_, _reho, _võõr, _तेरा_,
   {{0x386d951e,0x39401083,0x2ca684a7,0x6917802e}},	//   ccer_, jlis_, ngod_, nţel,
   {{0x3eb816f2,0x26c102a0,0xab6202d0,0x7d041867}},	//   _obrt_, yeho_, şüne, _dlis,
   {{0x7d0464ee,0xe1f18065,0x628aa537,0x7dea8085}},	//   _elis, _اسے_, nafo, həsi,
   {{0x63a2aca8,0x7d0464ef,0xe91900e8,0x26c164f0}},	//   huon, _flis, вові_, veho_,
   {{0x6f1ae4f1,0x63a2e4f2,0x161a83eb,0x26c100b4}},	//   litc, kuon, _फेयर_, weho_,
   {{0x628564f3,0x26c164f4,0x3f150196,0x6d4d26e9}},	// [55f0] _teho, teho_, адас, _ihaa,
   {{0x39403b06,0x6d4d64f5,0x7d1621f3,0x63a2e4f6}},	//   alis_, _hhaa, _zmys, duon,
   {{0x63bb8278,0x69d704c3,0x8afc809a,0x26c164f7}},	//   _spun, _urxe, _międ, reho_,
   {{0x297a010f,0x26c10db1,0x1c1682f1,0x39405ada}},	//   _שטרא, seho_, _देहल_, clis_,
   {{0xdfc6880b,0x6a85a6c8,0x6d5f0d8b,0x63a2e4f8}},	//   _بي_, алла, _miqa, guon,
   {{0x68ed64f9,0xa3b68105,0x6d5f64fa,0x2d91928a}},	//   ljad, _जहर_, _liqa, ázek_,
   {{0xa2ad001b,0x6f1a81ed,0x7dea8085,0x7e740019}},	//   _जान्, ditc, bəsi, _چاہئ,
   {{0x68ed048f,0x63a2e4fb,0x7dea8085,0xe0d986e6}},	//   njad, buon, cəsi, тви_,
   {{0x386de4fc,0x60cf64fd,0x2f04016d,0x753be4fe}},	//   rcer_, _macm, _höga_, _ikuz,
   {{0x6d4d02c1,0x5187b553,0xc987a5d9,0x386d83a7}},	//   _ahaa, _буда, _буди, scer_,
   {{0x7d0464ff,0x1d0a0abe,0xa50a0abe,0x26cee500}},	//   _plis, вени_, вена_, _dafo_,
   {{0x7fd58160,0x6d4d6501,0x443f8681,0x69dc8510}},	//   _вікі, _chaa, _kyu_, _área,
   {{0x6d4d02a3,0x2909275f,0x888c80be,0x6d5f00ee}},	//   _dhaa, dhaa_, _טראַ, _diqa,
   {{0x6d4d1fe7,0xbea28196,0x39ae811c,0xdce4022b}},	//   _ehaa, _дашк, _səsi_, _kunċ,
   {{0xfc3f05a4,0xada5a442,0x6d5f00ee,0x753b8a40}},	//   rgía_, _тайл, _fiqa, _okuz,
   {{0x7529ac14,0x61e1016d,0x92b380ab,0x7d0460f2}},	//   _njez, ålla, য়ায়_, _ulis,
   {{0x07a61d38,0x39406502,0xa686004a,0x8fa603bd}},	// [5600] разн, rlis_, илад, разе,
   {{0x753be503,0x39406504,0xbe8500f7,0x6d5f6505}},	//   _akuz, slis_, مجمو, _épar,
   {{0x39406506,0x443fbbde,0x7dea8085,0xd94635ed}},	//   plis_, _ayu_, təsi, _вени,
   {{0x8fa62a13,0x29090870,0xdddc026c,0x6b8402a0}},	//   _каме, chaa_, _cerš, _kwig,
   {{0xaae2800d,0xf863035f,0xb60700eb,0x7dea8085}},	//   पालक, _євро, ekšē, rəsi,
   {{0x60c42cbd,0x29006507,0x6b840a5a,0x61138162}},	//   leim, lkia_, _mwig, călz,
   {{0xe81a05e8,0x79458063,0x6449e508,0x2ca682c4}},	//   _नेता_, równ, _ezei, pgod_,
   {{0x7cff020f,0x64a39908,0x60c4061a,0x3f428125}},	//   _përm, _маса, neim, rðum_,
   {{0x443fb437,0x28bd80d4,0x29006509,0xfaa6a432}},	//   _gyu_, ्यजि, ikia_, _вазо,
   {{0x60c41794,0x6d4d0079,0x6d4292f5,0xd6da8293}},	//   heim, _shaa, lloa, тти_,
   {{0x29000009,0xb6d900be,0x3ed900be,0x628881a9}},	//   kkia_, אַרט, אַרא, _iedo,
   {{0x60c4250d,0x69da8102,0x215aa105,0x6b840314}},	//   jeim, _irte, _شجاع_, _bwig,
   {{0x6288cdb4,0x6f1a80c3,0xdb040144,0x442d0168}},	//   _kedo, pitc, _apiñ, çe_,
   {{0x7cff020f,0x81c30341,0x628882af,0x6b84650a}},	//   _kërk, ņēmu, _jedo, _dwig,
   {{0x8d9480f7,0x60cf2651,0x6b8429b5,0x48ab0b79}},	//   _البش, _pacm, _ewig, ктам_,
   {{0x7c2d0102,0x6d428087,0x6288e50b,0x7cff03ed}},	//   _txar, jloa, _ledo, _mërk,
   {{0x68ed650c,0x195817ae,0xa1581444,0xf7731a05}},	// [5610] rjad, раты_, рату_, تاز_,
   {{0x7d1d650d,0x69da848d,0x753be50e,0x290901b4}},	//   liss, _orte, _skuz, shaa_,
   {{0x28a78540,0xdceb876c,0x23692e72,0x443f90e1}},	//   _गालि, šiči, _huaj_, _syu_,
   {{0x7d1d650f,0x23690069,0x291b0609,0xd1268bbe}},	//   niss, _kuaj_, qiqa_, _رم_,
   {{0x69da9473,0x628885f8,0xe2f990ac,0x236900f1}},	//   _arte, _bedo, леді_, _juaj_,
   {{0x2369146a,0x68e28114,0x8d77026a,0x7d1d6510}},	//   _muaj_, _anod, _نارا, hiss,
   {{0x7d1d392a,0x236901c5,0xa3a90361,0x69da81dd}},	//   kiss, _luaj_, खंड_, _crte,
   {{0x753b829b,0x1dd5df43,0x26d100fc,0x7d1d6511}},	//   _ukuz, धिसत, _hazo_, jiss,
   {{0x443f82a0,0x2d9ee512,0x6288ccdc,0x69dae513}},	//   _uyu_, erte_, _fedo, _erte,
   {{0x6288a095,0xaf059da4,0x29000102,0xb33b0118}},	//   _gedo, спол, zkia_, duço,
   {{0x7d1d6514,0x26d13b37,0x24891357,0x2d918b24}},	//   fiss, _mazo_, _beam_, éze_,
   {{0x62888358,0x7bdbb4b0,0x41558f25,0x26d15ca0}},	//   _zedo, _kruu, _увес, _lazo_,
   {{0x387fd3ac,0x2d9ee515,0x23690282,0xb4c8009a}},	//   mbur_, arte_, _cuaj_, _उसी_,
   {{0x20a7800f,0x2369377f,0x26d16516,0x291904b9}},	//   _गाँध, _duaj_, _nazo_, _amsa_,
   {{0x26c5c1e5,0x6d428bb1,0x7d1d2497,0x7bcd047f}},	//   melo_, yloa, biss, _esau,
   {{0x26c5805d,0x236901c0,0x7d1d2546,0x6b841ec7}},	//   lelo_, _fuaj_, ciss, _twig,
   {{0x69030074,0x29006517,0x3cf1026f,0x60c46518}},	// [5620] _tõen, rkia_, žová_, reim,
   {{0xb8ff058c,0x26c5805d,0x3ce618b8,0xb33b0214}},	//   _धो_, nelo_, टावे_, nuçl,
   {{0xf9921ecd,0x20a7a967,0x628e6519,0x25a59aad}},	//   _عبد_, _गांध, mabo, null_,
   {{0x6288a240,0xe76a08ca,0x26c58234,0xfd4d8133}},	//   _sedo, _محسن_, helo_, _ichọ,
   {{0x26c5805d,0x69030074,0xb87b0118,0x236901c0}},	//   kelo_, _mõel, _unía, _xuaj_,
   {{0x26c582fd,0x7cff020f,0x628e651a,0x25a5e51b}},	//   jelo_, _përk, nabo, kull_,
   {{0x64408063,0x6288cbb8,0x7e7e8074,0x7bdb8c2e}},	//   _wymi, _vedo, _õppi, _eruu,
   {{0x1f748249,0x628e651c,0x78a9e51d,0xa7748705}},	//   олия, habo, ggev, олич,
   {{0x628e651e,0x7d1d0a7c,0x7d02e51f,0x6b40007b}},	//   kabo, viss, mkos, lögu,
   {{0x7d1d6520,0x23691085,0x63a6010b,0xa7149246}},	//   wiss, _ruaj_, dukn, імні,
   {{0xd6d79006,0x2002e521,0x69da80ad,0x7d1d6522}},	//   сты_, ški_, _urte, tiss,
   {{0x7d02e523,0xc5f30039,0xa06a84ae,0x2369022c}},	//   nkos, לדת_, _сада_, _puaj_,
   {{0x26c5e524,0x7d1d63da,0x23690069,0x705687bd}},	//   belo_, riss, _quaj_, _انشا,
   {{0x7d1d6525,0x26c5e526,0x628e39bd,0x25a5e527}},	//   siss, celo_, gabo, bull_,
   {{0x25a58722,0x248904e7,0x26d1002a,0x7d02e528}},	//   cull_, _team_, _razo_, kkos,
   {{0x236910af,0x7bcd6529,0xa3e8800d,0x673a8722}},	//   _tuaj_, _tsau, यमा_, lotj,
   {{0x02fa83b7,0x26d104c3,0x752d0859,0x628e06a0}},	// [5630] ्साह_, _pazo_, _ijaz, babo,
   {{0x7d02867f,0x2fc901b0,0x628e30d2,0x387f8088}},	//   ekos, rwag_, cabo, zbur_,
   {{0x7cff00f1,0x2fc92bfa,0x7e6d9238,0x7d0289ff}},	//   _përh, swag_, _şapk, fkos,
   {{0xa8a711d2,0x30a70009,0x26c58234,0x7d02e52a}},	//   _урок, _уров, zelo_, gkos,
   {{0x26d109ab,0x6265cb1e,0x7af702f9,0x752d03e4}},	//   _tazo_, овла, _koxt, _mjaz,
   {{0x3866831d,0x49998656,0x69d816b5,0xe0df02d6}},	//   _agor_, атия_, _švei, _chòv_,
   {{0xdce4003b,0x945d8063,0x78a9838e,0x7cff00f1}},	//   _sunč, _pańs, tgev, _tërh,
   {{0xb4c80063,0x628e0a3b,0xe8f98dae,0xe800001b}},	//   _उसे_, zabo, рли_, लैका_,
   {{0x26c5a2f8,0x78a98a0f,0x7d1be52b,0x7d09826b}},	//   telo_, rgev, _imus, _iles,
   {{0x80d200c8,0xdcc206b7,0x78a986a8,0x212900ee}},	//   হায্, षज्ञ, sgev, hnah_,
   {{0x8afc8d38,0x7d09b9f7,0x6b52013c,0xe4c618ba}},	//   _więc, _kles, lægg, ойни,
   {{0x63a60359,0xa3ad8441,0x2129652c,0x25a5bd2b}},	//   tukn, _कमा_, jnah_, rull_,
   {{0x80d200c8,0x26c584c4,0xa34a2302,0x1b4a1073}},	//   হাম্, pelo_, изма_, изми_,
   {{0x63a65553,0x27ffe52d,0x7d09e52e,0x25a58168}},	//   rukn, myun_, _lles, pull_,
   {{0x628e652f,0x63a6015d,0x7d1b8c56,0xfd1200f7}},	//   rabo, sukn, _omus, _يجب_,
   {{0xb1460d13,0xa0670323,0xdfd226ee,0x7945866f}},	//   інал, жата_, ويز_, dówk,
   {{0xef1a25c4,0x628e15d0,0x09a6952c,0x6f1e0669}},	// [5640] ама_, pabo, _गम्य, tipc,
   {{0x69c1a90e,0x7d09e530,0x27ed809f,0x6d466531}},	//   _ople, _ales, ixen_, llka,
   {{0x6f1e6532,0xb87b0013,0x27ff86ff,0xa2d4873c}},	//   ripc, _gnío, hyun_, _योग्,
   {{0xf767a6c2,0x0eac016f,0xd9461401,0xdd8f1459}},	//   _يا_, _चावड, _феми, ئون_,
   {{0x6b44809f,0x6d466533,0x60d60110,0x69c1dcde}},	//   lògi, ilka, mdym, _aple,
   {{0x7d09e534,0x60d60110,0x69de0289,0x7d1ba2d7}},	//   _eles, ldym, _krpe, _emus,
   {{0xaab201c4,0xa2ad035a,0x4ab2000f,0xd90d815b}},	//   _जानक, _जास्, _जानव, گین_,
   {{0xd7c88077,0xdcfc8024,0xa2ba8540,0x60d60084}},	//   موعه_, _tvrđ, _शॉर्, ndym,
   {{0xd90d8416,0xc9530039,0xb81d8beb,0x5ed38264}},	//   دین_, ומה_, _बेदम_, তানে,
   {{0x7b1002af,0x21296535,0x28da847d,0x6d462580}},	//   _häuf, znah_, _मोरि, elka,
   {{0x673acf57,0x6b400106,0x7b100192,0x76438114}},	//   rotj, högs, _käuf, _cyny,
   {{0x290de536,0xe9ff80ff,0x1c1f8035,0x7afa6537}},	//   chea_, _hiếm_, _मेडल_, öttn,
   {{0xe9ff8028,0x8d5b80be,0x9f4681ec,0x7763802a}},	//   _kiếm_, יכטי, _groß_, _finx,
   {{0x7b1002af,0x6d466538,0xbd6a898d,0x994382d0}},	//   _läuf, alka, _крие_, _kış_,
   {{0x59ce01fe,0x320503b0,0x63a2e539,0x2129178f}},	//   _हैदर, ály_, hron, tnah_,
   {{0xf8bc86b7,0x8d1801bd,0x69a2864a,0x752d653a}},	//   ्जिय, _وزير_, _गिनी, _ujaz,
   {{0x21290393,0xc05b035f,0x63a2803d,0xf77006e2}},	// [5650] rnah_, рів_, jron, نال_,
   {{0x21291600,0x7763b9a8,0x3f7b80be,0x629ea769}},	//   snah_, _xinx, יאמס, ópol,
   {{0x2d872eef,0x63a28fa3,0xe0df0229,0x2ef8653b}},	//   ène_, eron, _bhòt_, _dorf_,
   {{0x63a2c39a,0x629aa28a,0xf9da00be,0x613e8168}},	//   fron, _adto, _פֿיל, këlq,
   {{0x63a28e9c,0x35cc8105,0x69c1e53c,0x999e81d0}},	//   gron, ़बड़, _sple, _bytů_,
   {{0x7945809a,0x78ad00eb,0x6d4088dc,0x659528d8}},	//   mówi, lgav, _ekma, _нагу,
   {{0x290de53d,0x63a2e53e,0x7d09c8b2,0x6d460df6}},	//   thea_, aron, _tles, ylka,
   {{0x6ca4941a,0x7763e53f,0x78ad6540,0x7d1baaac}},	//   _оруж, _sinx, ngav, _umus,
   {{0x6b520366,0xf8ae81f9,0x5b158162,0x77638580}},	//   læge, اکم_, _емат, _pinx,
   {{0x65640009,0xdce7826c,0x6b8981bc,0xd7098198}},	//   _siih, _mujč, _iweg, сное_,
   {{0x7bdf2777,0x248d81c0,0x9d463306,0xc8ab0035}},	//   _arqu, _keem_, зенд, _छांट,
   {{0x753d0019,0x6b8986b0,0x236581a1,0x9cf98264}},	//   gosz, _kweg, _hilj_, _আগুন_,
   {{0x80278013,0x437512bc,0x65640009,0x248d81c5}},	//   _برام, дуст, _viih, _meem_,
   {{0x63a49c0b,0xf8bf04be,0x3d02009a,0x60c9e541}},	//   šing, _abé_, _mówi_, leem,
   {{0x6721e542,0x2fcdb5cd,0x2365cef3,0xed5a002e}},	//   milj, lweg_, _milj_, _лок_,
   {{0x248d90f4,0x60c98a6f,0x6f1c0699,0x78ad2d28}},	//   _neem_, neem, _smrc, ggav,
   {{0x7cff00f1,0x8cbc0a27,0x6b898870,0x60d66543}},	// [5660] _përv, ष्णो, _nweg, rdym,
   {{0x63a28036,0x60c9800b,0x2120008e,0xe0df02d6}},	//   vron, heem, siih_, _akòd_,
   {{0x02fb025f,0x6b89838a,0x248d87b6,0x629e8118}},	//   _הלימ, _aweg, _beem_, ópom,
   {{0xccf9809a,0x61e1013c,0x248d8282,0xf8bf077f}},	//   _coś_, ælle, _ceem_, _gbé_,
   {{0x248de544,0xead48b79,0x1c168006,0x69dc12f1}},	//   _deem_, доль, _देखल_, lvre,
   {{0x67218503,0x291d8176,0xb3e9c084,0xa3adb0ee}},	//   jilj, _amwa_, تعمل_, _कमर_,
   {{0x6721805c,0x248d81c5,0x6b898133,0x51868b69}},	//   dilj, _feem_, _eweg, чула,
   {{0x63a29df8,0x8b669dd2,0x859b0039,0x248d81bc}},	//   pron, _فاطم, _לשלו, _geem_,
   {{0x6721b90d,0x68f98101,0xed57ca4e,0x2fcd998b}},	//   filj, _dowd, _хот_, gweg_,
   {{0x7522e545,0xdce400eb,0x248d8282,0x0dca964f}},	//   lioz, _runā, _zeem_, буми_,
   {{0x7ae88022,0x248d81e9,0x69dc0042,0x908a80f7}},	//   _indt, _yeem_, jvre, _هناك_,
   {{0x248d81c5,0x76a28032,0x2902be43,0x7522ccc6}},	//   _xeem_, _bíyà, ökad_, nioz,
   {{0x67218025,0x753d6546,0x656e3f66,0x66e6a8d8}},	//   bilj, rosz, _lubh, _нода,
   {{0x7afa8009,0xb87b016b,0x4ab2016f,0x7b640073}},	//   _jott, _vním, _जाणव, етсе,
   {{0x31c412a0,0x2d9c0073,0x7afae547,0xceb383c8}},	//   нств, ável_, _mott, _ניק_,
   {{0xa3ad85e8,0x8e4780f7,0x6b52006a,0x7afaa9da}},	//   _कमल_, _عليك_, væge, _lott,
   {{0x383436ac,0x78ad00f3,0x7bdf15a0,0x248d8122}},	// [5670] ентр, rgav, _urqu, _reem_,
   {{0x7d0d003e,0x7afa8098,0x6b8982a0,0x3ce90069}},	//   _hlas, _nott, _rweg, _hnav_,
   {{0x28f90987,0x8afc0039,0x248d822c,0x78ad097a}},	//   _день_, _להזי, _peem_, pgav,
   {{0x752280d2,0x656e0c41,0x69c50234,0xd5b881a9}},	//   gioz, _dubh, _iphe, itā_,
   {{0x7afae548,0x39496395,0x656e0a2a,0x248d82df}},	//   _bott, mlas_, _eubh, _veem_,
   {{0x49b80077,0xd5b880eb,0x39496549,0xe3b08199}},	//   _باید_, ktā_, llas_, طره_,
   {{0x7afa99ad,0x248d8069,0x3949654a,0x75229351}},	//   _dott, _teem_, olas_, bioz,
   {{0x7c3a009a,0x2cbf82f7,0x7ae88aa2,0x7afa82f7}},	//   ętrz, _ubud_, _endt, _eott,
   {{0x60c987e3,0x67218503,0xa2b58098,0x2d9e016d}},	//   reem, tilj, _обач, _åter_,
   {{0x69c5654b,0x2fcd9781,0x3949654c,0x60c9c694}},	//   _ophe, rweg_, hlas_, seem,
   {{0xdca60391,0x64a63799,0x3949654d,0x2fcdbdd9}},	//   мани, мана, klas_, sweg_,
   {{0x69dc0bda,0x63a48140,0x7afa94cf,0x92ea0264}},	//   vvre, šine, _zott, _মতে_,
   {{0x69c501f6,0x2bd50327,0x69d581a2,0xb87b026b}},	//   _aphe, दिगा, भिकी, _eník,
   {{0x2bc081ce,0xada181ac,0x3949654e,0x88bd8035}},	//   _एहसा, ľúbe, elas_, biśc,
   {{0x6146132a,0x7cff0168,0x63abe54f,0x5ed38264}},	//   дева, _përt, hugn, তাদে,
   {{0x39496550,0x7d0d653c,0x69dc1bd9,0x69110366}},	//   glas_, _glas, rvre, _nåed,
   {{0x7cff020f,0x69c56551,0x1f66012f,0x657c016b}},	// [5680] _vërt, _ephe, дкам, _strh,
   {{0x39495446,0xa2bf9344,0x2bd486a7,0x7d0d02d4}},	//   alas_, ल्म्, _धनबा, _zlas,
   {{0x7afae552,0x39496553,0xdd8f0c3b,0xa06a4060}},	//   _rott, blas_, لول_, _мана_,
   {{0x0c26825d,0x7afaac2f,0xb80d8c28,0x69dc808b}},	//   ммен, _sott, िनाम_, _árei,
   {{0x7522853c,0xe7d880ab,0x31c6925f,0x28a78035}},	//   rioz, _তথ্য, लब्ध, _गाजि,
   {{0x39406554,0x7522e555,0xa2fa914f,0x656e0362}},	//   lois_, sioz, ्सेज_, _tubh,
   {{0xaac0000c,0x2d680214,0x96630fc8,0x7afaa461}},	//   श्यक, _eğer_, _акре, _vott,
   {{0x92ea00c8,0x39406556,0x6d44022c,0xa0220214}},	//   _মতো_, nois_, _nkia, _şöyl,
   {{0x629e09a4,0xb8d68935,0x26d86557,0x7afa8009}},	//   _odpo, _जा_, _karo_, _tott,
   {{0x35f48abe,0x26d86558,0x7ae8806a,0xa3cd06ab}},	//   епор, _jaro_, _undt, रबस_,
   {{0x7d0d6559,0x2d98e55a,0x26d8655b,0xda6581a8}},	//   _plas, ére_, _maro_, _كامي,
   {{0xd5b880eb,0x26d8009c,0x6d560122,0x7e6d8162}},	//   rtā_, _laro_, _chya, _şapt,
   {{0xd5b88029,0x29121916,0x6d560122,0x394908dc}},	//   stā_, dhya_, _dhya, vlas_,
   {{0x7cff020f,0x17548e86,0x6594b26c,0x6d44011b}},	//   _përs, _явля, _заку, _ekia,
   {{0x69d801dd,0x26cce55c,0x394000e7,0xcda79f33}},	//   _šver, medo_, fois_, _قهوه_,
   {{0x6ec1000d,0x26d82c3a,0xa2bf00d4,0x69078144}},	//   र्नु, _aaro_, _लॉर्, _añej,
   {{0x394949a8,0x2004998a,0xd6db0098,0x2486812b}},	// [5690] rlas_, nymi_, жте_, dbom_,
   {{0xb90603bb,0x39495498,0x26cc802a,0x08540009}},	//   _यो_, slas_, nedo_, твую,
   {{0x26d8655d,0x69c50234,0x60c2b989,0x394013ff}},	//   _daro_, _uphe, _obom, bois_,
   {{0xa3d60fd5,0x63abe55e,0x6b8d655f,0x399a81a9}},	//   _सनम_, tugn, _kwag, dīs_,
   {{0x50641597,0x26d86560,0xc8641cae,0x2fc68069}},	//   _атра, _faro_, _атри, _npog_,
   {{0x6295022e,0x2909153c,0x60cd0c5e,0x60c2ac80}},	//   nazo, lkaa_, leam, _abom,
   {{0x2fc680e4,0x6145c543,0x60c283f7,0x6b8d07fb}},	//   _apog_, нека, _bbom, _lwag,
   {{0x63abe561,0x60cd6562,0x26d80326,0x29093314}},	//   pugn, neam, _zaro_, nkaa_,
   {{0x83358160,0x62956563,0x26d86564,0x7d048198}},	//   _знах, kazo, _yaro_, öise,
   {{0x6d4be565,0x60cd0c5e,0x6d560314,0x6d446566}},	//   llga, heam, _shya, _skia,
   {{0x29090364,0x62955124,0xd12e815b,0x6b8d359e}},	//   kkaa_, dazo, شمی_, _awag,
   {{0x28df29a3,0x60c291d3,0xfd120250,0x29d18115}},	//   _पोलि, _gbom, اجد_, _iša_,
   {{0xeb9702bc,0x3f4287ca,0x65698364,0xe72e891e}},	//   ния_, rður_, _mieh, _бе_,
   {{0x3b0a0009,0x60dbb12f,0x2486acf6,0x68fd0219}},	//   чего_, ldum, zbom_, _aosd,
   {{0xa18a0698,0xa50a10ca,0x68fd03a8,0x7f4186a5}},	//   ябва_, _нека_, _bosd, molq,
   {{0x60dbe567,0x26d86568,0x61e1013c,0x6569a796}},	//   ndum, _saro_, ælla, _nieh,
   {{0x07a32c60,0x237f90af,0x8fa311b3,0x26d805e4}},	// [56a0] латн, _ntuj_, лате, _paro_,
   {{0x60d9c72f,0x291202a0,0x62956569,0x7bd6076d}},	//   _lawm, shya_, cazo, _isyu,
   {{0x394000a9,0x6b9b82a0,0xdcf48289,0x60cd656a}},	//   pois_, _avug, šači, beam,
   {{0xe57280be,0xc8ae80bc,0x644985ee,0xb0ae85fb}},	//   אַס_, _टाइट, _byei, _टाइग,
   {{0x26d8656b,0x98a0009a,0x65698609,0x249f8197}},	//   _taro_, enić_, _dieh, _ddum_,
   {{0x399a80eb,0x68eb8637,0x6449db21,0x290fdc47}},	//   tīs_, _angd, _dyei, _alga_,
   {{0x2004809a,0x27e0656c,0x9966a9e4,0xdca6a4dc}},	//   wymi_, lvin_, нтил, _пави,
   {{0xa9678fbb,0x60d981c0,0x25bb0039,0x81b280ab}},	//   нија_, _cawm, _מצלמ, টবল_,
   {{0x26cca737,0x60d98609,0x399a81a9,0x212481a8}},	//   tedo_, _dawm, sīs_, rimh_,
   {{0xdcc90ebf,0x656981ec,0x2ca02203,0x7afe0087}},	//   िज्ञ, _zieh, _adid_, _nopt,
   {{0x80bd816f,0x6b8d5b21,0x26ccc816,0x7bd60886}},	//   व्हे, _swag, redo_, _asyu,
   {{0x26cce56d,0x7cff0168,0x2ca081a8,0x60d98326}},	//   sedo_, _përq, óidh_, _gawm,
   {{0x6295656e,0x04670009,0x68fd00dd,0xdceb8289}},	//   tazo, этом, _rosd, šići,
   {{0x27e0656f,0xdcfb0084,0x6d4286ae,0x7b100799}},	//   dvin_, ystė, hooa, _räuc,
   {{0x29090009,0x60d9822c,0x62340162,0xdb029727}},	//   tkaa_, _yawm, геру, ntoñ,
   {{0x58d41628,0x6b8d020c,0x62956570,0x290f01a8}},	//   лост, _twag, sazo, óga_,
   {{0x6295062f,0x290926fb,0x6b8d18e3,0xbcfb3800}},	// [56b0] pazo, rkaa_, _uwag, rméd,
   {{0x656982af,0x60cd4d40,0x81d780ab,0x6d4b8079}},	//   _sieh, seam, ামত_, wlga,
   {{0x6b9b8052,0x6449a0d5,0x63bd6571,0x60cd37eb}},	//   _svug, _syei, ltsn, peam,
   {{0x48ab0364,0x3946822c,0xeb099905,0x764a8114}},	//   _этом_, _nkos_, वस्त_, _myfy,
   {{0xc6a70dc7,0x4ea70195,0xe4a481e5,0x98a0066f}},	//   _први, _прва, урхо, wnić_,
   {{0xfe700154,0x9f3500e8,0x6569822b,0x8c1c01c6}},	//   _هدف_, _регі, _wieh, הודי,
   {{0x15a80098,0x9f3400e8,0xae1e016f,0x6569c5ea}},	//   _пъти_, _сері, _येऊन_, _tieh,
   {{0xf9940451,0x98a00fda,0x25fe0327,0x60d9d9b7}},	//   ארק_, rnić_, लहरी_, _qawm,
   {{0x200b83fb,0xe0d6827e,0x60dbe572,0x69c88144}},	//   áci_, твы_, rdum, _epde,
   {{0xb8e880d4,0x55e58188,0xa2ad0b84,0x394682df}},	//   _लॉ_, вооб, _जाग्, _ekos_,
   {{0x7cff020f,0x60d981c0,0xa2ba864a,0x290f876d}},	//   _përp, _tawm, _शॉट्, _tlga_,
   {{0xb4ac184a,0x2f04016d,0x68eba2ea,0x7afe6573}},	//   खले_, _högt_, _ungd, _sopt,
   {{0x63af0052,0x7afe6574,0x2d478187,0x394da315}},	//   gucn, _popt, lões_, mles_,
   {{0x394de575,0xa3e283eb,0xe8ff00e7,0x395fe576}},	//   lles_, धित_, _aoû_, lmus_,
   {{0x320c026f,0xcb67002e,0x63bd090d,0x764a8428}},	//   ády_, таре_, atsn, _gyfy,
   {{0x25de8076,0x2d85b885,0xdddc0110,0x8afc809a}},	//   गिरी_, mple_, _perž, _pięk,
   {{0x394d80e7,0x395901a1,0x7afe1f59,0x75241ba4}},	// [56c0] iles_, _dhss_, _topt, _imiz,
   {{0x320784e8,0xbcfb0036,0x395fac34,0x3ce606ae}},	//   kyny_, rmée, hmus_, _जोते_,
   {{0x8afc809a,0x63bb913b,0xb4e6046d,0xe0df02d6}},	//   _więk, _aqun, _gbàá, _ikòn_,
   {{0xd8260dc8,0x64a6e577,0x6da337be,0x63a92454}},	//   _адми, тада, рица, šene,
   {{0x69030074,0x2f04007b,0xdd0c8035,0x290c01a9}},	//   _võet, _sögu_, _półn, ūdas_,
   {{0x394d8548,0x69c881df,0xf9c69ff8,0x39468933}},	//   eles_, _ppde, вщин, _skos_,
   {{0x3f8f930c,0x2d47841c,0x7bc10162,0x63bb912e}},	//   _awgu_, gões_, ălui, _equn,
   {{0xf9930051,0x395f856c,0x3cffaf76,0x31ba80f1}},	//   ברה_, gmus_, _gouv_, rëz_,
   {{0xab66a2f7,0xa2bf816f,0x2489816a,0x04469c56}},	//   _авал, ल्ह्, ñame_, _реан,
   {{0x394de578,0x75246579,0x7d00e57a,0x27ff0036}},	//   ales_, _amiz, _homs, _àune_,
   {{0x6298e57b,0x394ddf5f,0xceb30039,0xd6d7853b}},	//   mavo, bles_, בית_, тты_,
   {{0x394db885,0x6298828e,0x4fc68791,0x60268103}},	//   cles_, lavo, _аска, _идеа,
   {{0xdcfb0029,0x6931803d,0xd00f80f7,0x7d00b5e8}},	//   lstī, _دکور, _ولم_, _moms,
   {{0x63af0052,0xb3458073,0x6298e57c,0x75243e3e}},	//   rucn, moçã, navo, _emiz,
   {{0x1db69370,0x57578039,0x6728e57d,0x645605ee}},	//   _अमित, _שבוע_, midj, _ezyi,
   {{0x26dc81ed,0x3944e57e,0x7524011f,0x69343941}},	//   _havo_, noms_, _gmiz, ансу,
   {{0x26dc8e2d,0x2d478187,0xb8db052a,0x80be8264}},	// [56d0] _kavo_, zões_, _घा_, ্যপ্,
   {{0xdcfb0029,0x6d4f02e6,0x3f141157,0x3f9b5cac}},	//   kstī, llca, адус, rsqu_,
   {{0x8d740250,0x7bc9e57f,0x3944e580,0x2d4783a7}},	//   لانا, _speu, koms_, xões_,
   {{0x58840b71,0x394d04b7,0x656d0b7e,0x394496b5}},	//   _выра, ċess_, _jiah, joms_,
   {{0xad1c093f,0x21290587,0xaac010be,0x4ac001c4}},	//   וואר, miah_, श्वक, श्वव,
   {{0x2129059c,0x6298e581,0x2d4783a7,0x69030074}},	//   liah_, gavo, tões_, _tões,
   {{0x27e6b495,0x80be80c8,0x60dd6582,0x395fca84}},	//   _aron_, ্যন্, _kasm, tmus_,
   {{0x27e6aaa2,0x21296583,0xdfd180f7,0x2d47841c}},	//   _bron_, niah_, ميع_, rões_,
   {{0x20090393,0x60dd6584,0x2d4783a7,0x27e68706}},	//   nyai_, _masm, sões_, _cron_,
   {{0x26dc8081,0x2129036e,0x60dd6585,0x65750168}},	//   _cavo_, hiah_, _lasm, _kuzh,
   {{0xd2518013,0x4d6630b4,0x88bd809a,0x6d5bc637}},	//   _انا_, лков, liśm, _khua,
   {{0x637f8087,0x644d05ee,0x3944adc8,0x27e6ba1a}},	//   _tână, _byai, coms_, _fron_,
   {{0x2129059c,0x65752407,0xbebc81a9,0x8fa59246}},	//   diah_, _luzh, rnīr, _сале,
   {{0x8f9a893f,0x6d5b81c0,0x68fbae5c,0xe45680be}},	//   _װיקי, _lhua, ljud, טירט_,
   {{0x6d49e586,0x21292c30,0x71761a43,0x60dd6587}},	//   _okea, fiah_, اهرا, _basm,
   {{0xdd008029,0x656d5411,0xdddc01b9,0x62988f87}},	//   ītīb, _giah, _verż, zavo,
   {{0x6d466588,0x46ea12a0,0x27e60013,0xa2ac0054}},	// [56e0] moka, ндан_, íon_, _जयप्,
   {{0x6d466589,0x6b84471d,0x6d5f00e5,0x6d5be58a}},	//   loka, _itig, _èpar, _ahua,
   {{0x6d5b8ad0,0x6937005c,0x20090590,0x21290359}},	//   _bhua, mćen, ayai_, biah_,
   {{0x6d5b861f,0xb87b1986,0x6d46391a,0xd910081b}},	//   _chua, _caíd, noka, _بیر_,
   {{0x6298e58b,0x44208028,0x6d5ba081,0x5b2681e2}},	//   tavo, ài_, _dhua, лька,
   {{0x6d46658c,0x63a4e58d,0x9e6600d7,0xa2bf8072}},	//   hoka, šino, _مازن, ल्ल्,
   {{0x62988a56,0x2902658e,0x672882a5,0x6d46658f}},	//   ravo, _koka_, vidj, koka,
   {{0x26dc8a8e,0x2902025d,0xf9930039,0x6d5b8c41}},	//   _savo_, _joka_, זרה_, _ghua,
   {{0xe2928307,0x2fc06590,0x35ba0105,0x6298e591}},	//   _هذا_, ntig_, _उमड़, pavo,
   {{0x29026592,0x2fc002af,0x2129036e,0x6d5b80fc}},	//   _loka_, itig_, ziah_, _zhua,
   {{0x68fb80f2,0x644d0812,0x64410201,0xceb30039}},	//   bjud, _syai, əliy, זית_,
   {{0x69dae593,0x2ed10fe4,0x27e6e594,0x2fc00687}},	//   _iste, _हस्त, _tron_, ktig_,
   {{0x60dd0c9e,0xc62105fb,0xdb1d0019,0x26dc8110}},	//   _rasm, _मध्य_, ltsé, _tavo_,
   {{0x501b8051,0xe81d8b85,0x60dd6595,0x212900ee}},	//   _אודו, _बेटा_, _sasm, wiah_,
   {{0x6d4653c8,0x13cd80ab,0x212900dd,0x764e01a3}},	//   boka, লিয়, tiah_, _nyby,
   {{0x2fc01277,0x2d9ea3f9,0x6d4621ba,0x70af0072}},	//   ftig_, mste_, coka, टलेल,
   {{0x2fc06596,0x21290590,0x290204b9,0x200f0019}},	// [56f0] gtig_, riah_, _doka_, ági_,
   {{0x69da9711,0x6d5be597,0xb87b0e67,0x60dd1306}},	//   _oste, _shua, _saíd, _wasm,
   {{0x2d9e998b,0x60dd5474,0x21290072,0x5c75b0be}},	//   nste_, _tasm, piah_, алет,
   {{0x2d9ee598,0x39a101e2,0x7985112e,0x01ba80ab}},	//   iste_, mės_, _ithw, ংবাদ,
   {{0x39a10a8e,0xc05810ac,0x69dace6c,0x389a0538}},	//   lės_, _бір_, _aste, _בירנ,
   {{0x3f896599,0x2d9e92af,0x6b7c00be,0x6d464d8c}},	//   mpau_, kste_, ערונ, zoka,
   {{0x39a10746,0x6d5be59a,0xd2b80039,0x6d4659ed}},	//   nės_, _thua, אלות_, yoka,
   {{0x2d9e9610,0x629700f1,0xd131880b,0xb0f380ab}},	//   dste_, _lexo, تمع_, জস্ব_,
   {{0x2d9ee59b,0xe8f68791,0x02a780b3,0x290da81c}},	//   este_, рлы_, _брем, rkea_,
   {{0x39a101e2,0x62971e31,0x26d303a8,0x81cc00ab}},	//   kės_, _nexo, nexo_, লিত_,
   {{0x6d46659c,0x2d9ea707,0xdce9b46a,0x7985022c}},	//   toka, gste_, _lieč, _nthw,
   {{0x39a10110,0xb91281bc,0x2b478088,0x00000000}},	//   dės_, _mgbọ_, lonc_, --,
   {{0xdce981ac,0x29020ed6,0x2d9ee59d,0xdb1ba790}},	//   _nieč, _roka_, aste_, _aqué,
   {{0x6d463bd7,0x2902659e,0x69daabe2,0x26c78282}},	//   soka, _soka_, _yste, _ubno_,
   {{0x6d46659f,0x4096067c,0x290265a0,0xe2970ddc}},	//   poka, ират, _poka_, рас_,
   {{0x2fc05625,0x387f978f,0x776e01c0,0x63a9011f}},	//   ttig_, ncur_, _sibx, šena,
   {{0x06d880c8,0x6937157c,0xfaa615ac,0xb912819d}},	// [5700] তারি, pćen, _капо, _agbọ_,
   {{0x39a101e2,0xef170f25,0x2fc065a1,0x3ce001c5}},	//   bės_, аму_, rtig_, _haiv_,
   {{0x2fc03cc9,0x290265a2,0xab5b02af,0x7bdb8c2e}},	//   stig_, _toka_, stüc, _asuu,
   {{0x7d040009,0x6281a6bc,0x66031a57,0xbfcd0032}},	//   _jois, _aflo, änka, _dáṣọ_,
   {{0x6562e5a3,0x3ce001c5,0xfbd2b1a7,0x28df0327}},	//   rmoh, _maiv_, تتا_, _पोटि,
   {{0xf1a6946c,0x7d0465a4,0xa3ce65a5,0x6f03d268}},	//   арин, _lois, _रहन_, _nonc,
   {{0xbcfb0019,0x35a33edc,0xe5a32109,0x316f81a1}},	//   dmén, _марг, _мири, _bigz_,
   {{0x7d0465a6,0xed5a9b3c,0x3b86afc0,0x6281e5a7}},	//   _nois, _роб_, _влаг, _eflo,
   {{0x629c65a8,0xd7fa8749,0x39a10110,0xc60e824c}},	//   karo, туй_, zės_, ान्य_,
   {{0x2d9e9afa,0x629c01ca,0xa9a68098,0x7b100192}},	//   tste_, jaro, _вижд, _bäum,
   {{0x69dacf5d,0x7bcd01e2,0x6f03809f,0x7d0465a9}},	//   _uste, _spau, _donc, _bois,
   {{0x7d04600b,0x39a101e2,0x3ce00069,0x7bc29336}},	//   _cois, vės_, _caiv_, otou,
   {{0x6f0383d3,0x2d9ee5aa,0x7d0402ce,0x7bc2e5ab}},	//   _fonc, sste_, _dois, ntou,
   {{0x6e948307,0x39a10a8e,0x8f9b8158,0x629c65ac}},	//   _الثا, tės_, _יידי, garo,
   {{0x7d044b53,0x7d1660cc,0x394b0144,0xba080081}},	//   _fois, _flys, _pkcs_, ахте_,
   {{0x39a10110,0x09c380ab,0x98752f0a,0x7d046571}},	//   rės_, ্মচা, слац, _gois,
   {{0x39a101e2,0x25de800f,0x6d4d3308,0x63a496f2}},	// [5710] sės_, गिकी_, _ikaa, šinj,
   {{0x02a765ad,0x629c3928,0x657881c0,0x39a10110}},	//   _трим, caro, _kuvh, pės_,
   {{0x5fd884e5,0x09f90013,0xdcfc8029,0xa3df0701}},	//   _बैसल, _صفحة_, _strā, णिक_,
   {{0xbcfb0019,0x26d365ae,0xdb0b86a5,0xd7a68105}},	//   zmén, sexo_, rugí, _खिंच,
   {{0x657880ee,0x2bda873c,0xaca381bc,0xd7f8151a}},	//   _luvh, _मैदा, _nnụn, _кур_,
   {{0x9735053d,0xc324a22c,0xe29681e5,0x7d1983e4}},	//   _اکرا, омік, баш_, shws,
   {{0x20028009,0x7582003d,0x3f868176,0xa0a5d946}},	//   äkin_, _فیلم, _atou_, байд,
   {{0x629c262c,0x6f03807a,0xeb040aed,0x7b1001ec}},	//   zaro, _sonc, _रक्त_, _räum,
   {{0x7529d994,0x7bc285db,0xa3e28ec5,0x6f03989d}},	//   _imez, ctou, धिः_, _ponc,
   {{0x6d4d322c,0x7d0401e4,0x7d1665af,0x629c4729}},	//   _akaa, _sois, _slys, xaro,
   {{0x629c65b0,0x3ce001c0,0x7d04286f,0x395d81c0}},	//   varo, _paiv_, _pois, _thws_,
   {{0xcb090bea,0x7ae1e5b1,0x629c65b2,0x98b001d6}},	//   _אל_, _halt, waro, _šaľa_,
   {{0x7d04230d,0x7f8580f7,0x7ae19473,0x66e5876a}},	//   _vois, _التن, _kalt, _гола,
   {{0x44630081,0x249d8069,0xf67980be,0x6f1ae5b3}},	//   явяв, hawm_, _גאַמ, chtc,
   {{0x7ae181cd,0x7d044a5e,0x629c55a5,0x7b32809a}},	//   _malt, _tois, raro, sług,
   {{0x645a0086,0x629c13a8,0xb87b05e4,0x443f8085}},	//   ətin, saro, _raíc, _oxu_,
   {{0xc6760eca,0x66761650,0x66030106,0x39522dfb}},	// [5720] مطاب, مدار, änkn, rlys_,
   {{0x1ea9080b,0xe646035f,0x7529e5b4,0x69c3dbc9}},	//   لامي_, безп, _amez, ktne,
   {{0x394901df,0x645be5b5,0x69c38b80,0x61460084}},	//   boas_, _azui, jtne, _гена,
   {{0xdca3a46b,0x63a413c2,0x69de65b6,0x39490216}},	//   заци, _kvin, _ispe, coas_,
   {{0xd9e082a8,0x7cff0168,0x7ae1e5b7,0xc30a85a8}},	//   पट्ट, _përz, _balt, ледж_,
   {{0x7bc282be,0x75298135,0x60d634f5,0x7ae1cc23}},	//   rtou, _emez, leym, _calt,
   {{0x7ae1a360,0x7bc2801b,0xf2d31101,0xe7e0064a}},	//   _dalt, stou, פעה_, निकप,
   {{0x7ae1cbe8,0x63a465b8,0xd13080f7,0x61e1006a}},	//   _ealt, _ovin, ظمة_, ælli,
   {{0xfaa68607,0x200d8061,0xaaba8bbe,0x17fa81a8}},	//   _газо, gyei_, _مدار_, ارعة_,
   {{0x69de65b9,0x6d4d01b0,0xd6daa0a9,0xb7db03c8}},	//   _ospe, _skaa, ути_, נקיי,
   {{0x63a465ba,0x63a2e5bb,0x29e785f3,0x24f90190}},	//   _avin, lson, _gđa_, анны_,
   {{0x2d731123,0x39490118,0x629a83ed,0x7ae18bfd}},	//   _kćer_, xoas_, _heto, _zalt,
   {{0x629ae5bc,0xe0438b9c,0x07e98019,0x68e465bd}},	//   _keto, _енци, _پرنٹ_, ddid,
   {{0xf1dc81b6,0x629a80f1,0x63a929c7,0xdc378158}},	//   _मनान, _jeto, šeno, מאכט_,
   {{0x63a4017b,0x80db8264,0xc33381c6,0x68e2e5be}},	//   _evin, ভার্, לוש_, _kaod,
   {{0x629ac2cb,0x9955222c,0x29000168,0x68e42c9d}},	//   _leto, ікац, gjia_, gdid,
   {{0xdb0f05e4,0x752f009a,0x394903a7,0xb87b016a}},	// [5730] lucí, micz, roas_, _caía,
   {{0x291b0713,0x629ae5bf,0x752f009a,0x63a29c2b}},	//   shqa_, _neto, licz, dson,
   {{0xf3cb0077,0x6eca8a0d,0xa282003d,0x63a465c0}},	//   _شبکه_, त्यु, _آیفو, _zvin,
   {{0x752f0063,0x81cc00c8,0x54558098,0x6aa89670}},	//   nicz, লিশ_, овет, _addf,
   {{0x629ab139,0x7ae1e5c1,0xdcfc802e,0x03a5802e}},	//   _beto, _palt, _stră, цило,
   {{0x69c3e537,0x629ae5c2,0x539c00be,0x317a06cb}},	//   ttne, _ceto, ניוו, _yupz_,
   {{0x7ae1e5c3,0x7bdf65c4,0x56940196,0x63a2d030}},	//   _valt, _lsqu, _хаст, ason,
   {{0xdb0f0e15,0x77859fe5,0xe7a99033,0x753b804f}},	//   ducí, олиз, авил_, _ujuz,
   {{0xef199383,0x6d4b8019,0x69c3e5c5,0x600681bb}},	//   ими_, moga, stne, жным_,
   {{0x629a83b2,0x6b8982a0,0x2ca965c6,0xc34b8110}},	//   _geto, _iteg, _adad_, _сябе_,
   {{0xceb20158,0x29190182,0x752f009a,0x7bdf0216}},	//   ויי_, _olsa_, ficz, _asqu,
   {{0x6d4bde46,0x752f009a,0xa3e60e5b,0x629ae5c7}},	//   noga, gicz, फिल_, _zeto,
   {{0xe72e8dac,0x636002af,0x27e90b80,0x2d5900e7}},	//   _же_, höne, jvan_, péen_,
   {{0x2ca965c8,0x63a48013,0xe29715fe,0x6d4be5c9}},	//   _edad_, áini, жар_, hoga,
   {{0x7bdf0887,0x6ee48591,0xb87b23be,0x91e32865}},	//   _esqu, _رسول, _saía, море,
   {{0x63a403a6,0xf8d981ce,0x63a4ad77,0x6b89e5ca}},	//   _tvin, ढ़िय, šini, _oteg,
   {{0x68e410dd,0x6d4be5cb,0x37060294,0xaf0652e4}},	// [5740] rdid, doga, опаг, опал,
   {{0xab5b05c5,0x0cd68264,0x65608362,0x98a9066f}},	//   ntül, _সচেত, _shmh, ynać_,
   {{0x394619dc,0x69de65cc,0x6d4b89df,0xec7ac03d}},	//   _мног, _uspe, foga, апе_,
   {{0xa3ce0d38,0xf09f0028,0x63a2c3cf,0x629a872f}},	//   _रहा_, _hoàn_, tson, _seto,
   {{0x6bd680d7,0x225880c3,0x934684db,0xd4038198}},	//   تتار, _šrk_, онде, дящи,
   {{0x63600019,0x47d900be,0xa3bbe5cd,0x37d900be}},	//   lönb, _פֿרײ, _अमर_, _פֿרע,
   {{0x65c328a7,0x629ace9a,0x63a29ea0,0x6b898c2e}},	//   _обра, _veto, sson, _eteg,
   {{0x63ad8341,0x984f8059,0x8c46867c,0x442201a1}},	//   šana, _ağır_, _дебе, kzk_,
   {{0x629ae5ce,0xdfd080a0,0x4aca0107,0x50b7803d}},	//   _teto, ريد_, िभाव, زديد_,
   {{0xe5c68364,0xcf2680f7,0xbcfb0036,0x752f0035}},	//   осмо, تربي, rmém, wicz,
   {{0x667b010f,0xd5b781d9,0xa3e290c8,0x6d4380e7}},	//   יטיק, ося_, धिक_, énag,
   {{0x6eca03dd,0x7d02aded,0x657c65cf,0x27e9007e}},	//   स्तु, njos, _murh, yvan_,
   {{0xdee69b06,0x1ae400c8,0x66e69577,0xa06a8eef}},	//   _моди, খানে_, _мода, _тада_,
   {{0xb87b0118,0xdce401a1,0x78a081f6,0x672a808b}},	//   _caín, _dunđ, lamv, _umfj,
   {{0x31c40b79,0x7bc60ad4,0x39838214,0x657c036e}},	//   мств, atku, _kısa_, _nurh,
   {{0x2eed1dac,0x6d4be500,0x2ee3022b,0x3ce695d8}},	//   _şef_, xoga, _sajf_, jdov_,
   {{0x752d2ec5,0x6d4be5d0,0xdce400fe,0x7d028b80}},	// [5750] _imaz, voga, _gunđ, djos,
   {{0x27e965d1,0x368b01e5,0x7c228805,0xa92801d0}},	//   rvan_, рсан_, dzor, _požá,
   {{0x57b7853e,0x6d4be5d2,0x657c0e6d,0x673a86a8}},	//   _आम्ह, toga, _curh, intj,
   {{0xbfa38129,0x7bf9a432,0x98a000c3,0x6f07066f}},	//   _biế, йнер_, viić_, _wojc,
   {{0x6d4be5d3,0x7ae50406,0x69c74c2e,0x4fc40b26}},	//   roga, _kaht, ltje, _осра,
   {{0x37c280c8,0x31694252,0x673a81ed,0x657c010c}},	//   ্টার, lmaz_, jntj, _furh,
   {{0x69c765d4,0x5ee100ab,0x34958767,0x7ae51bf3}},	//   ntje, নাদে, _навр, _maht,
   {{0x7ae50406,0x3169080a,0x39a580eb,0x673a86a8}},	//   _laht, nmaz_, rēs_, entj,
   {{0x63a9003a,0x69c70582,0x60c9842b,0x6b89cb4b}},	//   šenj, htje, rfem, _uteg,
   {{0x1dd21516,0xa2b4ac60,0xef1996cf,0x752d65d5}},	//   _सहमत, _обуч, смо_, _amaz,
   {{0x69c700f1,0x7d1be5d6,0xe8df81bc,0x69c501c0}},	//   jtje, _klus, _azụm_, _nqhe,
   {{0xb87b03a8,0xdce4042b,0x673a9151,0x69c70366}},	//   _saín, _punđ, antj, dtje,
   {{0x7d09e5d7,0x2bdf0327,0x7ae54041,0x69c700f3}},	//   _moes, _पैदा, _baht, etje,
   {{0xa3ae890a,0x752d3eee,0x394de5d8,0x692c02d0}},	//   _किस_, _emaz, loes_, rşem,
   {{0x7d1be5d9,0x7bc665da,0x7c2280e5,0xf77080d7}},	//   _olus, stku, zzor, _شاه_,
   {{0x04460081,0x752d082c,0x657a0036,0x64430035}},	//   _нейн, _gmaz, _éthi, _śnie,
   {{0x6843046a,0xe0431c64,0xf09f0104,0x80dd0076}},	// [5760] ента, енти, _toàn_, _पसरे,
   {{0x7d1b81c2,0x752d01ac,0x394de5db,0x8c3d82d0}},	//   _alus, _zmaz, hoes_, _keşf,
   {{0x7d09e5dc,0xf29701c6,0xfebd8264,0x63a620e5}},	//   _boes, _מכיר_, _অসাধ, lskn,
   {{0xdd8f12dc,0x7d1be5dd,0x2d870c52,0x7c228102}},	//   اون_, _clus, ínea_, tzor,
   {{0xf8b30bea,0x629e01f1,0x98a48110,0x63a665de}},	//   _אשר_, _kepo, nimą_, nskn,
   {{0x7d1baf41,0x7c22e5df,0xada60d45,0x657c0009}},	//   _elus, rzor, _нагл, _turh,
   {{0x7c228061,0x7d1d067f,0x394d8114,0x6b520366}},	//   szor, ërsk, foes_, lægs,
   {{0x629e65e0,0xbcfb0065,0xfce38758,0x26da1024}},	//   _lepo, rmék, _посо, lepo_,
   {{0x98a48110,0x6d409a83,0x44228106,0x61e18580}},	//   jimą_, _ijma, _åk_, _esll,
   {{0x629e25ea,0x2486e5e1,0x656465e2,0x68e60326}},	//   _nepo, lcom_, _ahih, _lakd,
   {{0x2d9886e3,0x27208028,0x78a080b4,0x1cd90110}},	//   ère_, _lòng_, pamv, одны_,
   {{0x2486e5e3,0x394d8187,0x68e605b0,0x291fe0f1}},	//   ncom_, coes_, _nakd, chua_,
   {{0x61dc8aed,0x399a8110,0x65644961,0x60c2e5e4}},	//   _मनुष, lūs_, _dhih, _icom,
   {{0x26da02fd,0xbcfb00f7,0x65640135,0x629e65e5}},	//   jepo_, iméi, _ehih, _cepo,
   {{0x629e2769,0x6588801b,0x68e612b7,0x5f000a27}},	//   _depo, _běhe, _bakd, रान्_,
   {{0x672e04b7,0x69c75625,0xe63b8039,0x752d65e6}},	//   _ambj, rtje, _לתוכ, _umaz,
   {{0x7ae565e7,0x69c74305,0xc05b00e8,0x7d098cab}},	// [5770] _taht, stje, сів_, _roes,
   {{0x6d4f1a4e,0x27208028,0x629e0574,0x316900eb}},	//   loca, _dòng_, _gepo, smaz_,
   {{0x7d09a5da,0x692c1238,0x6f1c1b9c,0x753d0799}},	//   _poes, kşeh, _dlrc, onsz,
   {{0x7d1d00f1,0x291f81c0,0x6ec1175d,0x6288a35c}},	//   ërsh, xhua_, र्जु, _afdo,
   {{0x3b098396,0xdb1b8187,0x63601e5e,0x96eb23b2}},	//   жело_, _aquá, löna, _льва_,
   {{0x63ad80eb,0x6d4f01a8,0x7d098cfa,0x60cd07f1}},	//   šano, hoca, _woes, lfam,
   {{0x7d0985f8,0x2fc965e8,0xe9d980e8,0x290b02d0}},	//   _toes, ltag_, іки_, _koca_,
   {{0xa3ce2e04,0x2d83816b,0x7d1b8214,0x290b0088}},	//   _रहल_, íjem_, _ulus, _joca_,
   {{0xb8d583db,0x63a48013,0x2fc93ede,0x6b8d65e9}},	//   _जय_, áint, ntag_, _ntag,
   {{0xee39abe0,0x290b3673,0x05a98009,0x656400f1}},	//   жно_, _loca_, овой_, _shih,
   {{0xdb268077,0x6aa38b50,0x6d4f65ea,0x6d47011a}},	//   _تولی, manf, foca, čkan,
   {{0x60c28013,0x629e65eb,0x63a9807b,0x6b9bad27}},	//   _gcom, _sepo, _kven, _kwug,
   {{0xa2c4800d,0xeb970656,0x249f8176,0x629e5de2}},	//   _राम्, мия_, _meum_, _pepo,
   {{0x63a60082,0x68e98c4d,0x6aa391e6,0x06e180ab}},	//   rskn, lded, nanf, বাহি,
   {{0x6b8d57ff,0x68e62240,0x60cd65ec,0xa50a1289}},	//   _etag, _pakd, ffam, _мека_,
   {{0x68e99fd3,0x249f8da4,0x63a9a315,0x26da0010}},	//   nded, _neum_, _oven, wepo_,
   {{0x2fc9033e,0x8fa310f8,0xcece80ff,0x27ede5ed}},	// [5780] gtag_, кате, _mộng_, nven_,
   {{0x27208028,0x6d599849,0x3636003d,0xdb1b8118}},	//   _vòng_, elwa, وراس, _opuñ,
   {{0x68e665ee,0xa3e60ebf,0x2486e5ef,0x6aa3ac9f}},	//   _takd, फिक_, tcom_, danf,
   {{0x290b65f0,0x249f851e,0x68e98366,0x6b9b818e}},	//   _goca_, _ceum_, jded, _bwug,
   {{0x27ed8613,0x249f8197,0xc3da803d,0x68e9e5f1}},	//   jven_, _deum_, تباط_, dded,
   {{0x60c28081,0x6d59d030,0xbcfb0f35,0x290b0118}},	//   _scom, alwa, rméi, _zoca_,
   {{0x63a9c8c8,0x81cc00c8,0x27ed80f3,0x2486d184}},	//   _even, লিক_, even_, pcom_,
   {{0xcece8028,0x63a901ac,0x2ca00006,0x78a40242}},	//   _cộng_, šeni, _neid_, naiv,
   {{0x27e065f2,0x5ee100ab,0x2d5c823e,0x64a38721}},	//   nwin_, নারে, níem_, _шата,
   {{0x2216801e,0x44268010,0x63a4e5f3,0xf4040264}},	//   _офер, mzo_, šins, উনার_,
   {{0x27e01083,0x1d350d8e,0x6b8d1ea0,0x442681e8}},	//   hwin_, ення, _stag, lzo_,
   {{0x60db82b7,0x660335e7,0x291d86c4,0x6b80c418}},	//   ceum, änki, _glwa_, _kumg,
   {{0x4426e5f4,0x7a13800d,0x290b2db0,0x1016806b}},	//   nzo_, _větš, _roca_, _تباد,
   {{0x27208176,0x290b16dc,0xbcfd8129,0xdb0b8106}},	//   _bòne_, _soca_, _nhũn, stgö,
   {{0xd90f04c0,0x290b65f5,0xc1dc816f,0x09dc8054}},	//   لید_, _poca_, _मनोग, _मनोय,
   {{0x58d40c3e,0xa2d580d4,0x2fc91b57,0xa3ae8101}},	//   кост, _मॉन्, ttag_, _किं_,
   {{0x3fbc80c8,0x40342672,0x290b0bcf,0x60cd074d}},	// [5790] _অনুষ, ветс, _voca_, rfam,
   {{0x63bd07ba,0x2d870207,0x7ae88953,0x4426e5f6}},	//   musn, íneo_, _nadt, dzo_,
   {{0xc1750c3e,0x63a98687,0xb8e500c8,0x68e98bff}},	//   _площ, _sven, _এস_, yded,
   {{0x61e565f7,0xb4b98935,0x7afae13f,0x7d0d65f8}},	//   _ishl, चले_, _antt, _joas,
   {{0xdb1d013c,0xcece801c,0x7ae8e5f9,0x7d0d4a28}},	//   rtsæ, _rộng_, _badt, _moas,
   {{0xfbb2009a,0x31668fe0,0xdcf58162,0x8f9a0538}},	//   _जिसम, _ahoz_, _buză, _מישי,
   {{0xe5c41697,0x24808052,0xaca3819d,0x6d5986c0}},	//   _исто, žima_, _azụa, plwa,
   {{0x7d0d0012,0x27ed80d2,0x3fe58b5b,0xfa7802f6}},	//   _noas, tven_, ежив, ועות_,
   {{0x6c54ab57,0x61f88038,0x68e9bef3,0x20198019}},	//   _акту, _ďalš, rded, ási_,
   {{0x60dbd27e,0x26c110e4,0x2ca065fa,0x29028338}},	//   seum, ngho_, _seid_, ökar_,
   {{0xed5a0607,0xa2c4863a,0x7bcbe5fb,0x27e01415}},	//   зон_, _रात्, ltgu, zwin_,
   {{0x6aa19ab8,0xf2c9007c,0xa3e403db,0x67218b80}},	//   _helf, _לע_, _ननद_, shlj,
   {{0x2d9c3dc8,0x63bd0c9a,0xdb06026f,0x7bcb881a}},	//   ávez_, gusn, lské, ntgu,
   {{0xada5a32d,0xe9ff8028,0x5ecf00ab,0x316de5fc}},	//   _закл, _giảm_, _হোসে, lmez_,
   {{0x44268021,0x3ea5aa09,0xdb06003e,0x216a4d43}},	//   zzo_, malt_, nské, зиви_,
   {{0x63bd0988,0x3ea5e5fd,0x316d82d0,0x79818c2e}},	//   busn, lalt_, nmez_, _mulw,
   {{0x63ad8ee1,0xd1750048,0x81d580c8,0x59750071}},	// [57a0] šanj, тыры, িটি_, тыру,
   {{0xe9e58028,0x6fb312dc,0x27e065fe,0xff7a80be}},	//   _đúng_, املا, rwin_, פטעמ,
   {{0x8236004e,0x2d9c26f2,0xdd8f1a05,0xa0a61c9b}},	//   _سردا, ève_, مول_, _панд,
   {{0x3ea5dfbf,0x3ce9022c,0x44269a01,0xb81f8072}},	//   halt_, _xaav_, tzo_, यनाम_,
   {{0x39406452,0x80c9016f,0x3ea597ab,0x6aa1e5ff}},	//   mnis_, _हॉटे, kalt_, _belf,
   {{0x4426c685,0xf6510117,0x853d0110,0x7981e600}},	//   rzo_, ائے_, gsėj, _bulw,
   {{0x6aa1c93a,0x3f82022e,0x8cc1009a,0x6d566601}},	//   _delf, _huku_, _वालो, _okya,
   {{0x3f821ec4,0x2c578063,0xdcfc976d,0x39406602}},	//   _kuku_, _będą_, _kurč, nnis_,
   {{0x9346a00d,0x0b469bd8,0x63bd026f,0xdcfcd3a3}},	//   _знае, _знан, xusn, _jurč,
   {{0x3f8204b9,0x6d443516,0x6d4721f8,0x2ca6833e}},	//   _muku_, _ajia, čkam, laod_,
   {{0x39406603,0xd36f9a43,0xf1d48074,0x613b0198}},	//   knis_, _اهل_, _दहिन, nälä,
   {{0x6aa18613,0x2724008b,0x39521e78,0x76589075}},	//   _zelf, _hönd_, joys_, _vyvy,
   {{0x8c3d87d9,0xa2d58074,0x3ea5d27e,0x7d0d0087}},	//   _teşe, _मॉड्, balt_, _voas,
   {{0x63bd0867,0x39406604,0x61230074,0x6d5602ec}},	//   rusn, enis_, _mõle, _ekya,
   {{0x63bd0057,0x3f8205a3,0xf09f00ff,0x39404a46}},	//   susn, _auku_, _hoài_, fnis_,
   {{0x3f821e92,0x365b8039,0x0e5b8039,0x63600019}},	//   _buku_, _מכונ, _מדוב, lönl,
   {{0xb4dd00cf,0xb90903bb,0x3f824250,0xdb1d1d5b}},	// [57b0] ड़ी_, _यस_, _cuku_, ttsä,
   {{0x2007003b,0x6d5d6605,0x26de9ab6,0xc43c0039}},	//   ćni_, llsa, neto_, _מתחי,
   {{0xdb1d00f2,0x394002af,0xf09f00ff,0xd5bb06d2}},	//   rtsä, bnis_, _loài_, яса_,
   {{0x6aa1e606,0xdb06026f,0x26deda0d,0xdb1d0338}},	//   _self, vské, heto_, stsä,
   {{0x81d580c8,0x26dee607,0x490486ae,0xdb1d0192}},	//   িয়া_, keto_, वानो_, ptsä,
   {{0x26dee608,0x3ce98353,0xdb06016b,0x7bcba924}},	//   jeto_, žav_, tské, rtgu,
   {{0x3ea58006,0x6aa195f8,0x2d8500e7,0x7bcb87f1}},	//   valt_, _velf, _île_, stgu,
   {{0x68ed4b02,0xdb06026f,0x63ad0687,0x3ea581ec}},	//   ndad, rské, _ovan, walt_,
   {{0x3ea58bfa,0xa3ae809a,0x6aa1e609,0xf8bf0019}},	//   talt_, _किए_, _telf, _elég_,
   {{0x3940660a,0x6569e60b,0x68ed0046,0x657b808e}},	//   znis_, _hheh, hdad, _hiuh,
   {{0x63ad0cf8,0x68fd0082,0xa3e98778,0xdc3401ac}},	//   _avan, _onsd, यिक_, rúča,
   {{0x3ea58006,0x2d83180c,0x38359715,0x78a290bc}},	//   salt_, _muje_, _инер, _geov,
   {{0x68ed6051,0x26debfb4,0x3ea5e60c,0x68eb8122}},	//   ddad, beto_, palt_, _iagd,
   {{0x68ed660d,0x26dee60e,0x68eb9acd,0x656f01c0}},	//   edad, ceto_, _hagd, amch,
   {{0x63ad660f,0x3f826610,0xa2c495bc,0xfaa3433f}},	//   _evan, _suku_, _रास्, расо,
   {{0x3f820870,0x6d44059c,0x68ed0461,0xf1b280be}},	//   _puku_, _ujia, gdad, יסל_,
   {{0x68ebe611,0x3ea32f6f,0x2fcdd099,0xf8bf07f1}},	// [57c0] _magd, _bejt_, nteg_, _amés_,
   {{0x39405a4a,0x3f820390,0x667602e3,0x68ebbd7a}},	//   snis_, _vuku_, ندار, _lagd,
   {{0x63ad22b9,0x644984c3,0x2d8302a5,0x2d559f48}},	//   _zvan, _axei, _cuje_, våer_,
   {{0x3f820d7f,0x68eb9066,0x290fe612,0x6b8440f5}},	//   _tuku_, _nagd, _noga_, _kuig,
   {{0xe7bc8a49,0x99418035,0x0fbc8264,0x69ce6613}},	//   _অন্য, kół_, _অন্ধ, ltbe,
   {{0x6569e614,0x60c46615,0x6b8401e4,0x26de802a}},	//   _eheh, lgim, _muig, xeto_,
   {{0xf1a38084,0x6b841e75,0xe5a30ff7,0xbcfb0036}},	//   арын, _luig, _виси, llée,
   {{0x60c46616,0x23b200dc,0x26dee617,0xe9ff827d}},	//   ngim, _जिंद, weto_, _chằm_,
   {{0x68ebbf60,0x26dee618,0xceba80fc,0x2fc04b66}},	//   _dagd, teto_, _alƙa_, nuig_,
   {{0xa3e7a49a,0x63ad0bda,0x24800168,0xd5b881a9}},	//   _बनत_, _rvan, _agim_, trā_,
   {{0x63ad2b33,0x557501cf,0xc9d58fd3,0x68ed0438}},	//   _svan, лгот, _مملک, ydad,
   {{0xb4dd00cf,0x69dae619,0x6b841412,0x43950d45}},	//   ड़े_, _ipte, _buig, ламс,
   {{0x26dee61a,0xe72f8077,0x02c98074,0xaac983b6}},	//   peto_, صصی_, _रामभ, _रामक,
   {{0x2d871bff,0x6b840229,0x59c6ab07,0x68e0e61b}},	//   ínek_, _duig, रंपर, lemd,
   {{0x987e07d9,0xaad201d0,0x98c72274,0x98a90035}},	//   _açık_, द्धक, ксал, niać_,
   {{0x741508ca,0xbcfb3df6,0x60c4661c,0x290f81df}},	//   _موبا, rmés, ggim, _xoga_,
   {{0x68ed2602,0x691c80e7,0xadea897d,0x2fc03e34}},	// [57d0] rdad, _réel, टिकन_, guig_,
   {{0xa2c4a8d7,0x63a9003e,0x6569e61d,0x68ed661e}},	//   _राष्, šens, _sheh, sdad,
   {{0x394685a4,0x6b8401ed,0x3cff8072,0x69ce090d}},	//   _ojos_, _zuig, ळाले_, ctbe,
   {{0x99f60051,0x2d590036,0x2fc0661f,0xa3d70072}},	//   _עזרה_, mées_, buig_, _सहा_,
   {{0xd0069168,0x63a0831d,0x2d5900e7,0x7bcf0980}},	//   _ال_, _cwmn, lées_, ntcu,
   {{0xe1f00065,0x5694222c,0x68eb813c,0x8c1c007c}},	//   _اسی_, _варт, _sagd, וודי,
   {{0x2d5902be,0x68eb97ef,0x1cbb80f7,0x38668176}},	//   nées_, _pagd, _يارب_, _azor_,
   {{0x00e58a7c,0xb4dd06a7,0x89d688ca,0x6b820037}},	//   ужин, ड़ो_, اوير_, _èogg,
   {{0x7ff5880b,0x7bcd01c0,0x6ec703db,0xa3e782f1}},	//   اسبا, _nqau, ालपु, _बनि_,
   {{0x3cff81c0,0x6b840014,0x38668122,0x8e09b0ed}},	//   _hnuv_, _ruig, _dzor_, енов_,
   {{0x290f8025,0xdca608cc,0x64a625a4,0x68ebe620}},	//   _toga_, лани, лана, _tagd,
   {{0xa3e780cf,0x2f160125,0x6b840722,0xdcfc80eb}},	//   _बना_, _hægt_, _puig, _kurā,
   {{0xf7f4819f,0xdcf900eb,0x9f406621,0xdb0407b6}},	//   _پسند, _atvē, rviú_, _aviá,
   {{0x69ce1722,0x78a982f1,0x79850deb,0x6fb29e2a}},	//   ttbe, laev, _buhw, _اموا,
   {{0x321e026f,0x2d5900e7,0xc33281c6,0x395f832a}},	//   áty_, gées_, מוך_, olus_,
   {{0x69ce2f6b,0x6b846622,0x2fc06623,0x46cfac17}},	//   rtbe, _tuig, tuig_, त्रह,
   {{0x60c46624,0x69ce6625,0x321e026f,0xe3b20019}},	// [57e0] rgim, stbe, šty_, _ارب_,
   {{0x26c580ee,0x613e81a9,0x693a81b9,0x7536016b}},	//   nglo_, rīli, nċer, _hmyz,
   {{0x629c2755,0x777c04c3,0x7524005c,0x2d590036}},	//   mbro, _virx, _kliz, cées_,
   {{0xe45f00f2,0x628197cf,0x291e01a9,0xab5b0192}},	//   mför_, _aglo, ītas_, stüt,
   {{0xbd2d0158,0x628f8087,0x6d42e626,0x98a90035}},	//   וואָ, _şcoa, rnoa, wiać_,
   {{0xbda60277,0xab5b02d0,0x7cfb062c,0x395f86ae}},	//   _محرو, ltür, _kärä, elus_,
   {{0xe45f00f2,0xe6079a3e,0xdce2825b,0x26d80041}},	//   nför_, _اش_, jmoć, _ibro_,
   {{0x391495d1,0xdce280d2,0xf38a826b,0x60f88081}},	//   рмир, dmoć, _aṣe_, тния_,
   {{0xed358196,0xa3ae8540,0x68e0e627,0x629c4083}},	//   _тэрэ, _किट_, remd, kbro,
   {{0x47349957,0x68e0b8b9,0x75243667,0x3866816b}},	//   рнос, semd, _aliz, _vzor_,
   {{0xd6d78e11,0x0f5704de,0x629c08dc,0x7bc2e628}},	//   уты_, ריים_, dbro, luou,
   {{0xd9fe0076,0x6281805c,0x395fe629,0x9e770039}},	//   _उपजत_, _zglo, clus_, טגיה_,
   {{0x38668668,0xbcfb0511,0x658881d0,0x26d85f69}},	//   _uzor_, eléc, _těho, _obro_,
   {{0x7524662a,0x6aaab00e,0x2d5900e7,0xa01b0106}},	//   _eliz, naff, tées_, _oför,
   {{0xa3ab823c,0x78a60292,0x349515a4,0xdd9081a8}},	//   _कौन_, _bekv, _кайр, _بوب_,
   {{0x6aaa9da1,0x316006c0,0x2d5900e7,0x5184002e}},	//   haff, gliz_, rées_, сура,
   {{0x4735662b,0x2d5902be,0x6aaaab11,0x656d651c}},	// [57f0] анас, sées_, kaff, _ihah,
   {{0x291e00f1,0xbcfb01df,0x2d590036,0x38bb046d}},	//   ëtar_, bléc, pées_, _bàrà_,
   {{0x395fe62c,0x3f868118,0x61f700b9,0x656d0326}},	//   ylus_, _luou_, _urxl, _khah,
   {{0x661a8748,0x057482e3,0xb87b0118,0x26d8662d}},	//   iytk, ماند, _saíu, _ebro_,
   {{0xd7e680f7,0x6aaa8041,0x63af01a8,0xab5b011c}},	//   _بك_, faff, nscn, rrüf,
   {{0x645a0087,0x212900dd,0x41b59ed5,0x6aaaaeeb}},	//   ştig, lhah_, асит, gaff,
   {{0xaa498098,0x2f163f7e,0xdb0b8018,0x395f8074}},	//   ъпка_, _vægt_, nsgé, tlus_,
   {{0xa2d58540,0x63bd2cf6,0xe8f9a432,0xc27c03de}},	//   _मॉर्, krsn, тли_, ערהי,
   {{0x68ef64fd,0xa2cd81cb,0x69158118,0x2eee8176}},	//   _macd, _साप्, _sáes, _baff_,
   {{0xe80d05e8,0x62818b67,0x21291ac7,0x2eee80e5}},	//   _सपना_, _uglo, hhah_, _caff_,
   {{0x52848013,0x60b5819f,0x75240247,0xed462995}},	//   _المك, _نمائ, _pliz, иноп,
   {{0x7ae3e62e,0x69c3831d,0x69678591,0x31600101}},	//   lent, mune, _صداق, xliz_,
   {{0xa09a8158,0x656d0303,0x21290077,0x289a80be}},	//   _סיסט, _dhah, dhah_, _סיסא,
   {{0x661a8f4c,0xa3c70105,0x290d8042,0xfaa317f9}},	//   bytk, _उमर_, ljea_, жаро,
   {{0x63bd0014,0xa2cd8a0d,0x6d498216,0xbb431444}},	//   arsn, _सान्, _ojea, церк,
   {{0xe45f04b8,0x7ae3e13f,0x629c662f,0x6d5b8282}},	//   rför_, hent, sbro, _nkua,

   {{0x7ae3c60f,0x3ea7d810,0x69c3e630,0xb8ee0c2d}},	// [5800] kent, _kent_, hune, _रा_,
   {{0x2d87e631,0x6d5bbefe,0x69c3a30e,0x656d00dd}},	//   _kune_, _akua, kune, _zhah,
   {{0x72080117,0x2d878039,0x6d473b76,0x21294f82}},	//   _صفحہ_, _june_, čkav, bhah_,
   {{0x63a43818,0x69c3e632,0x63648722,0x47dc80ab}},	//   _kwin, dune, tòno, বিতী,
   {{0x7ae3cbb3,0x68e46633,0x290200b4,0xb92a801c}},	//   fent, meid, _inka_, _thuế_,
   {{0x7ae389af,0x68e41da5,0x8c1b0051,0x63a41b86}},	//   gent, leid, כוני, _mwin,
   {{0x44209ce0,0x1bed159a,0x69c3e634,0x19a78071}},	//   ši_, _चैनल_, gune, атып_,
   {{0xa3d70e18,0x6d461d3e,0x68e45a3c,0x2eee8aee}},	//   _सहल_, jnka, neid, _saff_,
   {{0x8f46948d,0x673a8168,0x3ea7da20,0x2fd20338}},	//   иход, titj, _bent_, ntyg_,
   {{0x68e46635,0x656d6636,0x63bd003a,0x2d87802e}},	//   heid, _shah, vrsn, _bune_,
   {{0x69c3e637,0x673a9001,0x6d9304b7,0x68e46638}},	//   cune, ritj, _għad, keid,
   {{0x673ae639,0x63a42cf7,0x6aa88428,0xb87b07b6}},	//   sitj, _bwin, _hedf, _maír,
   {{0x3ea7ba85,0x69de0c55,0xa2cd8aed,0xd79480f7}},	//   _fent_, _appe, _साम्, _التخ,
   {{0x3ea7e63a,0x63a406a8,0x3cfd86a7,0x80d2801b}},	//   _gent_, _dwin, _रोने_, भ्रे,
   {{0x68e400f7,0x2729801c,0x6aa88f06,0x63a41aad}},	//   feid, _súng_, _medf, _ewin,
   {{0x644d01e9,0xdb1d05b9,0xd3a704cf,0xa3e78074}},	//   _txai, musí, _кроп, _बनल_,
   {{0x7ae3e63b,0xc05b0cde,0x64480085,0x69c38102}},	// [5810] yent, тів_, şdir, zune,
   {{0x7ae3e63c,0x6d5bcaba,0x30778039,0x21290c9e}},	//   xent, _skua, שתמש_, shah_,
   {{0xb87b663d,0x7ae3e63e,0x68e4232f,0xa3c9835a}},	//   _país, vent, beid, लून_,
   {{0x7ae3cb65,0x21200052,0x6705063a,0x753d0019}},	//   went, ckih_, राहक_, nisz,
   {{0x7ae3e63f,0xc6510019,0x2d9a0037,0xdd020140}},	//   tent, _کہاک, appe_, šući,
   {{0x69c39673,0x97250fd3,0x8ccc8ad5,0x2ca901c6}},	//   tune, _افسو, _हाथो, _lead_,
   {{0xd2b801c6,0x6d46590a,0x3495a2a0,0xdbdd04e8}},	//   בלות_, ynka, _габр, dšív,
   {{0x69c3e640,0x3ea7e641,0x78ad395f,0xe0df03ec}},	//   rune, _sent_, naav, _akòz_,
   {{0x69c3e642,0x6d59e643,0x2d878041,0x27e90915}},	//   sune, mowa, _sune_, nwan_,
   {{0x2d87e644,0x69c38049,0x291fe645,0x6d59b228}},	//   _pune_, pune, skua_, lowa,
   {{0x99858307,0x2ca91c4f,0x27e92a58,0x79970069}},	//   _الصو, _bead_, hwan_, _ntxw,
   {{0x753d0065,0x6d598063,0xeb9a6646,0x2ca9125b}},	//   gisz, nowa, лим_, _cead_,
   {{0x6b8980c8,0x68e40029,0xdcf580eb,0xef0ed0da}},	//   _jueg, veid, _atzī, _ем_,
   {{0x60c9e647,0x6e9580f7,0x27e96648,0x6b8181b9}},	//   lgem, _الغا, dwan_, _jilg,
   {{0x6d598063,0x6b8980ab,0x21200db7,0x68e46649}},	//   kowa, _lueg, tkih_, teid,
   {{0x6ed3a3e7,0x628f8087,0x27e900dd,0x6d59e64a}},	//   ब्रु, _şcol, fwan_, jowa,
   {{0x6d598063,0xa3c9800f,0x636486c0,0xb87b09b2}},	// [5820] dowa, लूम_, wònm, _saír,
   {{0xd9f785b3,0x7bc65869,0xbeaa003d,0x6b8198d5}},	//   ंटात_, muku, اهان_, _nilg,
   {{0x7bc6664b,0x248d026f,0x6d598f90,0x7d0404b7}},	//   luku, žeme_, fowa, _knis,
   {{0x6d59e64c,0xab5b0182,0x2ee5a651,0x395d8282}},	//   gowa, crüb, helf_, _nkws_,
   {{0x6b818179,0x60c9ca06,0x7d04664d,0x23d6896b}},	//   _bilg, dgem, _mnis, сцер,
   {{0x81e180c8,0xff47826a,0xf1a69e0b,0x2d5c8144}},	//   দিন_, _رخ_, брин, tíes_,
   {{0x6d59ad19,0x248980d2,0x7d040091,0x7bc643fb}},	//   bowa, žama_, _onis, huku,
   {{0x3eaa0613,0x7bc6664e,0x6b898020,0xf8ba0aed}},	//   _hebt_, kuku, _fueg, ेलिय,
   {{0x2ca9664f,0x3eace650,0x0c26a3d9,0x7bc66651}},	//   _read_, tadt_, _уман, juku,
   {{0x75228065,0x2ca919ca,0x2d8a005d,0x6b81e652}},	//   lkoz, _sead_, _kube_, _gilg,
   {{0xa2cd81ab,0x9f4006a5,0x2f5b03c8,0x27e900ee}},	//   _सात्, lvió_, רדינ, zwan_,
   {{0xf8bf01df,0x75229f8a,0x7bc627cb,0x6ed8001b}},	//   _alén_, nkoz, fuku, न्तु,
   {{0x7bc61a0e,0x673e00c3,0x6d438866,0x753d0e06}},	//   guku, kipj, énai, risz,
   {{0x2fc06653,0x6d59e654,0x7d046655,0xab5b0192}},	//   drig_, zowa, _enis, drüc,
   {{0x2d8a05e4,0x78ad39b9,0x6d599090,0x27e90326}},	//   _nube_, taav, yowa, wwan_,
   {{0x7bc61eda,0x6d472a06,0x61fa237b,0x7d0412f1}},	//   buku, čkas, ætla, _gnis,
   {{0x50673696,0x78ad0364,0xc8675f60,0x636d87e0}},	// [5830] ства, raav, стви, núnc,
   {{0x78ad2f55,0x27e91bcc,0x6b8981ca,0x2d8a5440}},	//   saav, rwan_, _rueg, _bube_,
   {{0x6d59b3e4,0x6ed8001b,0xe7ea809a,0x6b898388}},	//   towa, न्धु, _जैसा_, _sueg,
   {{0x2ee58a0f,0x7ae76656,0xab5b0192,0x2d8a58d9}},	//   zelf_, lejt, brüc, _dube_,
   {{0x6d598063,0x69d500ad,0x39496657,0x2d9802be}},	//   rowa, ltze, mnas_, _etre_,
   {{0x6d598063,0xa3aa923a,0x612a026f,0x6ed8123a}},	//   sowa, _खबर_, _výle, न्दु,
   {{0x69d500ad,0x80ac00c8,0x5ea780ab,0x7bc606a0}},	//   ntze, _ছাত্, _খালে, zuku,
   {{0x39496658,0x3f8b007d,0x7bc60d7a,0x69d50102}},	//   nnas_, _kucu_, yuku, itze,
   {{0x60c9e659,0x6b81e65a,0x69c7665b,0x7ae7016b}},	//   rgem, _tilg, huje, kejt,
   {{0x60c9b5cd,0x3cfd80d4,0x3cdc001b,0x2caf9235}},	//   sgem, _रोते_, ग्ने_, lagd_,
   {{0xf1dda3e7,0x3f8b665c,0x3949665d,0x69c70968}},	//   _महिन, _lucu_, knas_, juje,
   {{0xed5a023f,0x7bc6665e,0x7d162c96,0x63a48087}},	//   ром_, tuku, _qoys, ţine,
   {{0xdbf406b7,0xbcfb665f,0xc178936d,0x75298c53}},	//   इटेड_, plén, _اصلا_, _mlez,
   {{0x59dd8935,0x41dd800c,0xf1dd800c,0xa3ab8eed}},	//   _महार, _महास, _महान, कीय_,
   {{0x69c7179d,0x6372006a,0x753b8365,0x2bb602f1}},	//   guje, hæng, _omuz, _अटका,
   {{0x3f8b00b9,0x752981bc,0x69820133,0x09be8264}},	//   _bucu_, _nlez, _ọgbụ, _আহমা,
   {{0x78ab8065,0x3f8b44f8,0x2d8a0876,0x2fc06660}},	// [5840] _megv, _cucu_, _sube_, urig_,
   {{0x69c721f6,0xe6b781c4,0x394960e2,0x2fc054a3}},	//   buje, _आयोज, anas_, rrig_,
   {{0x75228065,0xb87b026b,0x39496661,0x7529810c}},	//   tkoz, _abíd, bnas_, _blez,
   {{0x6364823e,0xed5a8198,0xdca3b39a,0xab5b0192}},	//   mòni, шое_, даци, prüc,
   {{0x6364809f,0xfbcf8fc5,0xa2948a4c,0x0b938481}},	//   lòni, نتو_, палі, وجود,
   {{0x7529e662,0x9f400020,0x394033ec,0x61fe0b80}},	//   _elez, rvió_, liis_, _krpl,
   {{0xcebf01d0,0x6364823e,0x9f400144,0xdd921190}},	//   _úřad_, nòni, svió_, _آور_,
   {{0x39404336,0x7529e663,0x315781a8,0x48149a1f}},	//   niis_, _glez, يجية_, змис,
   {{0x8c4381a1,0xc17304de,0xfbd1801b,0x78ab81a9}},	//   _жете, וחה_, _समयम, _degv,
   {{0xa3df823c,0x6d4d01ed,0xdb061743,0x39496664}},	//   _तहत_, _sjaa, nskä, znas_,
   {{0x7ae71d1a,0x7bc2e665,0x2d850019,0x61230074}},	//   vejt, lrou, _élet_, _sõlm,
   {{0xe4e7035f,0x69c70ac1,0xc0c782de,0x2480c2c4}},	//   ціон, vuje, _душе_, žimu_,
   {{0x39498289,0xdb060106,0x394001c7,0x7ae701d0}},	//   čast_, kskä, diis_, tejt,
   {{0x4f57806b,0x7c2f87d9,0x6364823e,0x98a38196}},	//   _وجود_, _ücre, fòni, ėją_,
   {{0xd13b0698,0x7ae76666,0x3a25007b,0x3f8b6667}},	//   аха_, rejt, álp_, _sucu_,
   {{0x69d50379,0x2d9ee668,0xdc2b0077,0x2d848074}},	//   rtze, mpte_, _نسخه_, _nime_,
   {{0x39493b2b,0x7ae700f1,0x76b90071,0x69c75f1e}},	// [5850] rnas_, pejt, йлар_, suje,
   {{0x6d5d6669,0x2d8482be,0x26ccd411,0x3f8b017f}},	//   losa, _aime_, ngdo_, _vucu_,
   {{0xa2c48894,0x7529e66a,0x272980e1,0x8c3da7ef}},	//   _राज्, _plez, _júna_, _ieşi,
   {{0x2d848699,0x5c7595ac,0x6f18811a,0x3940666b}},	//   _cime_, плет, _lovc, ciis_,
   {{0x03a58790,0x7bc290b6,0xb11381bc,0x3cfc03c8}},	//   чило, grou, _hụgh, ילאנ,
   {{0x6f18803a,0x6b8d4328,0x60cd666c,0xdefb01e2}},	//   _novc, _muag, lgam, _тым_,
   {{0x6d5d018c,0x291938d6,0x2729807b,0x6b8d0122}},	//   kosa, _kosa_, _núna_, _luag,
   {{0x60cd3219,0x753b9d8b,0x63720366,0x3cf50035}},	//   ngam, _umuz, mæne, इयों_,
   {{0x853d01e2,0xd90c8077,0x6d5d666d,0x2572026f}},	//   ipėd, شیو_, dosa, nále_,
   {{0x2489348b,0xc61480ab,0x6b9be66e,0x636d808b}},	//   _agam_, াননা_, _itug, búna,
   {{0xf8bf00a9,0xf9f9815b,0x98cb0035,0x63a982c4}},	//   _além_, _دفاع_, िलाए, _hwen,
   {{0x63a9d3aa,0x2919062f,0xbcfb666f,0x60cd0168}},	//   _kwen, _nosa_, blém, jgam,
   {{0x63a98205,0x8c3d8457,0x0c233e20,0x68e9af9c}},	//   _jwen, _beşi, емян, meed,
   {{0x63a9e670,0xe2972167,0x68e98079,0x69c389ff}},	//   _mwen, зар_, leed, orne,
   {{0xc6928158,0x394009f1,0x63a98c6a,0x6d4b9400}},	//   _טאג_, tiis_, _lwen, knga,
   {{0x3991e671,0x291914e7,0x60cd1066,0x55ba8051}},	//   _más_, _cosa_, ggam, _המקו,
   {{0x8ca20063,0x2919059c,0x39406672,0x68f6031d}},	// [5860] _क्यो, _dosa_, riis_, rdyd,
   {{0x68e98079,0x7bc2e673,0x63648722,0x6d4b9272}},	//   heed, vrou, pòni, enga,
   {{0x39918a56,0xceb28039,0x291936c0,0x442201b0}},	//   _nás_, גיב_, _fosa_, lyk_,
   {{0x7bc29a9b,0x63a98555,0x6b8d01c0,0x6372006a}},	//   trou, _bwen, _yuag, sænd,
   {{0x68e9dd34,0x8c3d8214,0x63a9810c,0x44220196}},	//   deed, _yeşi, _cwen, nyk_,
   {{0x6d4bcf0b,0xf1a6b4d2,0x2d9ee674,0x6b9b80f7}},	//   anga, прин, ypte_, _dtug,
   {{0xdca69860,0x2d84804c,0xa2cd8ebf,0x64a69273}},	//   _нави, _time_, _सार्, _нава,
   {{0x44226580,0x079884ae,0x79860133,0x68e981b4}},	//   kyk_, овић_, _jikw, geed,
   {{0x6d5d2772,0x63a9d1a7,0xb8d48105,0x69c3e675}},	//   vosa, _gwen, _जज_, arne,
   {{0x539b8bea,0x79866676,0x6d4298cb,0xb4bc86b7}},	//   _לימו, _likw, lioa, _आयु_,
   {{0x6d5d13ec,0x3991bccb,0x7c2286c0,0x60cd02d0}},	//   tosa, _gás_, lyor, ygam,
   {{0xab5b01ec,0x6b8d01c0,0x6d42a8a8,0x7aeaabc4}},	//   grün, _puag, nioa, left,
   {{0x7c22c593,0x645a0087,0x8c3d8214,0xf76f803d}},	//   nyor, ştin, _peşi, ضای_,
   {{0x6d5d288c,0x6b8d01c0,0x79860362,0xb113819d}},	//   sosa, _vuag, _aikw, _pụgh,
   {{0xe9ff8104,0x29193076,0x69d88422,0xd6db81c6}},	//   _phẩm_, _posa_, ntve, _החול,
   {{0x613101a3,0x79866677,0x3eae9cd9,0x7aea878b}},	//   _målg, _cikw, _heft_, heft,
   {{0x291901df,0x79866678,0x20540162,0x752d6679}},	// [5870] _vosa_, _dikw, ектя, _ilaz,
   {{0x9f4dd2b4,0x69ca8ace,0xc987002e,0xb1138133}},	//   rveç_, kufe, _нуми, _tụgh,
   {{0x27ed8247,0x63a9e67a,0xe9ff801c,0x6b9be67b}},	//   zwen_, _swen, _thẩm_, _stug,
   {{0xe8eb0117,0x3eae8039,0x39918dbf,0x6d428c7b}},	//   _اردو_, _left_, _rás_, gioa,
   {{0x6d933086,0x68e98264,0x29d716dc,0xdb062472}},	//   _għan, veed, lça_, rrkö,
   {{0x3eae8085,0x69d8e67c,0x7aea806a,0x3991816b}},	//   _neft_, ftve, geft, _pás_,
   {{0x29d7667d,0x44221bc3,0xdce438c1,0x68e9d8da}},	//   nça_, zyk_, _uhić, teed,
   {{0x39918775,0x6d42802e,0x212b809a,0xc2e90264}},	//   _vás_, cioa, óch_, খাটি_,
   {{0x27ed8a0f,0x68e990b0,0x69dc816d,0xf1b804b7}},	//   uwen_, reed, _ären, ġġi_,
   {{0x27ed8a12,0x7d1b8051,0x752d667e,0x29d70214}},	//   rwen_, _hous, _alaz, kça_,
   {{0x752d0a0c,0x7bcbb926,0xc3328039,0x7d1be67f}},	//   _blaz, lugu, _שוב_, _kous,
   {{0xc3292bf2,0x7d1bb473,0x3f9f8198,0x44226680}},	//   _דו_, _jous, ppuu_, tyk_,
   {{0x394de681,0x7bcb977c,0xd90f8019,0x7d1b99c6}},	//   mnes_, nugu, _لیں_, _mous,
   {{0x7d1be682,0x6d4280ad,0x44226683,0x395f8551}},	//   _lous, zioa, ryk_, lous_,
   {{0x394d9220,0xaca3819d,0x7bcb9f56,0x44222183}},	//   ones_, _anọn, hugu, syk_,
   {{0x752d6684,0x394de685,0x7d1b8009,0x3f8f8079}},	//   _glaz, nnes_, _nous, _kugu_,
   {{0xef1a4094,0xa06718a0,0x394de686,0xdb0b8019}},	// [5880] ома_, дата_, ines_, zsgá,
   {{0x7bcbe687,0xe7e5809a,0x3f8f80fc,0xe6a80d86}},	//   dugu, _कहना_, _mugu_, गरेज,
   {{0x2d9c020f,0x7d1bd4ae,0x3f878006,0x3f8f8ccf}},	//   ëve_, _bous, _minu_, _lugu_,
   {{0x7d1be688,0x53d2058c,0x395f809f,0xdce280fe}},	//   _cous, _तमाश, jous_, ploč,
   {{0x6d428c76,0x7bcbaeb5,0x7d1be689,0x394da21f}},	//   rioa, gugu, _dous, dnes_,
   {{0x394d9726,0x3f87877f,0x7d09a87f,0x6d42e68a}},	//   enes_, _ninu_, _enes, sioa,
   {{0x7aeae68b,0x8e830bba,0x7c228ad4,0x7bcb80eb}},	//   reft, _агре, syor, augu,
   {{0x69d8a3f9,0x394d8eb7,0x2d8e9471,0x69ca82af}},	//   rtve, gnes_, _rufe_, rufe,
   {{0x6d40ab31,0x6f1c34c8,0x3f8f80fe,0x69ca8db1}},	//   _imma, _korc, _cugu_, sufe,
   {{0x752d0052,0x3f8f811e,0x394d9b0d,0x7d09807a}},	//   _slaz, _dugu_, anes_, _znes,
   {{0x6f1c0cf8,0xd6d78fe6,0x395f907c,0x645a0087}},	//   _morc, фты_, bous_, ştil,
   {{0x2ca6838e,0x394d817f,0x3f87807b,0xa00a80f7}},	//   nbod_, cnes_, _einu_, _وقال_,
   {{0x248d012b,0x68e29a98,0x7b6724b6,0x27328028}},	//   žemo_, _ibod, дтве, _nâng_,
   {{0x61310370,0x6d9301cd,0xf0478416,0x2ef80118}},	//   _måle, _bħal, _تعمی, _narf_,
   {{0x6d40e68c,0x7af70201,0x20023314,0x6b88e68d}},	//   _omma, _vaxt, _arki_, _midg,
   {{0x29d72761,0x752d003a,0x6376e68e,0x3944e57e}},	//   rça_, _ulaz, lând, nims_,
   {{0x51842326,0x6f1c0965,0xb8f715bc,0xc9840012}},	// [5890] тура, _borc, _सा_, тури,
   {{0x394dded9,0x6f1c668f,0xce6b0381,0x6d40e690}},	//   znes_, _corc, оред_, _amma,
   {{0x7d1bae07,0x6d933086,0x68e2882e,0x6f1c032f}},	//   _pous, _għal, _obod, _dorc,
   {{0x63ad43fb,0x629a816d,0x20020267,0x7bcba5c1}},	//   _kwan, _afto, _frki_, tugu,
   {{0x68ed0ece,0xe299a6c5,0x290b002e,0x5f11952c}},	//   mead, пал_, _inca_, ताम्_,
   {{0x63ad114c,0x68ed008c,0x26e380c8,0x68e2ac5a}},	//   _mwan, lead, _কোনো_, _abod,
   {{0x7d1be691,0xe0d18013,0x394de692,0x4429e693}},	//   _tous, هزة_, tnes_, ša_,
   {{0x21296694,0x3f879edf,0x68ed14f2,0x394d82be}},	//   nkah_, _sinu_, nead, unes_,
   {{0x394d805f,0x8b678250,0xd7e68198,0x212900b9}},	//   rnes_, _قائم, емые_, ikah_,
   {{0x27e404b8,0x68ed2686,0x395fe695,0x394de696}},	//   _ämne_, head, sous_, snes_,
   {{0x63ad6697,0x21290b20,0x3944c04b,0x395fe698}},	//   _awan, kkah_, bims_, pous_,
   {{0x63ad1b9e,0x3f8fe699,0x68ed669a,0x67b9830f}},	//   _bwan, _tugu_, jead, _فاتح_,
   {{0x78279c2c,0x69c1026f,0x3f87826b,0x236580b9}},	//   _تعال, álen, _tinu_, _kklj_,
   {{0x27328012,0x63ad248a,0x643a80be,0xf8bf04be}},	//   _când_, _dwan, לערנ, _adé_,
   {{0x63ad669b,0xc7b98019,0x21290859,0x291d84b9}},	//   _ewan, lső_, fkah_, _kowa_,
   {{0x68fb9922,0x6f1c1390,0x68ed0ce2,0x6376802e}},	//   ndud, _sorc, gead, mâne,
   {{0x63ad669c,0x291d866f,0x68f9da04,0x63bb838a}},	// [58a0] _gwan, _mowa_, _mawd, _nvun,
   {{0x248dbfd7,0x2732b9be,0x399508bd,0x2d91669d}},	//   _agem_, _vâng_, _fås_, _buze_,
   {{0xfad7093f,0x63ad0d35,0xaac983dd,0x02c983b7}},	//   _אויך_, _zwan, _राजक, _राजभ,
   {{0x8fa6130f,0x68ed0635,0x69dc1bd9,0x6d9304b7}},	//   _паме, cead, mtre, _għam,
   {{0x69dc2d55,0x6f1c669e,0x69ce071f,0xead4acd1}},	//   ltre, _torc, lube, воль,
   {{0x6d462547,0xbcfb0174,0x61310163,0x45160264}},	//   hika, rléi, _våle, াসিক_,
   {{0x69dc669f,0x6d4636cb,0x3944809f,0x2d910669}},	//   ntre, kika, tims_, _guze_,
   {{0x6d46178f,0x6d40e6a0,0x63a2b6b9,0x3f8a66a1}},	//   jika, _umma, ppon, _hibu_,
   {{0x6d462a31,0x69ce0234,0x69c70654,0x3944e6a2}},	//   dika, hube, zrje, rims_,
   {{0x63ad4a87,0xb34580a9,0x442682e7,0x3f8a0010}},	//   _rwan, riçã, myo_, _jibu_,
   {{0x4426abca,0xb3458073,0xa0a698a0,0x63ad5bce}},	//   lyo_, siçã, _заед, _swan,
   {{0x80e00a49,0x6d463d65,0x7afae6a3,0x4426e6a4}},	//   _পোস্, gika, _hatt, oyo_,
   {{0x4426cde9,0x48fb0b04,0xb87b0091,0x27e68039}},	//   nyo_, _लोगो_, _abín, _upon_,
   {{0x25724906,0x7afa822b,0xa3e88e33,0x69c7007a}},	//   rála_, _jatt, _बहन_, trje,
   {{0x68ed4d80,0xdb0405e4,0x4ac980d4,0x31c41354}},	//   tead, _avió, _राघव, лств,
   {{0x442682ec,0x69c700f1,0x212909ca,0x7bda002e}},	//   kyo_, rrje, ukah_, ătur,
   {{0x2129059c,0x2d91005c,0x63ad3f1c,0xa3e50006}},	// [58b0] rkah_, _suze_, _uwan, _नहि_,
   {{0x7afa8bfa,0x68ed66a5,0x4426e6a6,0x21291ade}},	//   _natt, sead, dyo_, skah_,
   {{0xceb38158,0x69ce08f1,0x69dc00f7,0x212914e4}},	//   ריע_, cube, ctre, pkah_,
   {{0xa567803d,0xa3e506a7,0x888300d7,0x7bdd06ae}},	//   ردان, _नहा_, _میزن, otsu,
   {{0x7bdd4a9d,0x27ff01df,0x4426e6a7,0x7afa9ea0}},	//   ntsu, _éun_, gyo_, _batt,
   {{0x6d46223a,0xbbd186ce,0x7bdd66a8,0x68f9e6a9}},	//   zika, _समीक, itsu, _sawd,
   {{0x44268de2,0x62880279,0x7afae6aa,0xe9ff80ff}},	//   ayo_, ždov, _datt, _thậm_,
   {{0x4426a246,0x25be007b,0x6009968a,0x63bbadc2}},	//   byo_, _ætla_, дним_, _tvun,
   {{0x7afae6ab,0x4426cec6,0x69ce813c,0x43958098}},	//   _fatt, cyo_, _åben, _разс,
   {{0x7d0d3a90,0x7afae6ac,0x6d46020d,0xd2f78065}},	//   _anas, _gatt, wika, _سکتا_,
   {{0x64a60a4c,0xed5a26c8,0x6ea78065,0x614789c4}},	//   кана, дон_, ونکہ_, _cèlè,
   {{0x2cb20201,0xd24e803d,0x63768187,0xceba80fc}},	//   _qeyd_, _بچه_, râne, _roƙe_,
   {{0x317f8214,0x7afae601,0x78a9ca72,0x61358a09}},	//   mmuz_, _yatt, mbev, _pálf,
   {{0x03a30364,0x69dc66ad,0x8ca21199,0x316dae90}},	//   риро, ttre, _क्रो, llez_,
   {{0x3f8a66ae,0x80e000ab,0xe2970972,0xf2d283de}},	//   _ribu_, _পোষ্, тас_, יעם_,
   {{0x69dc3a1a,0x78a983b2,0x3f8a39e1,0xdb0f00f7}},	//   rtre, nbev, _sibu_, rscá,
   {{0xf8b28158,0x7bcf4b47,0x54a501a8,0x442681b4}},	// [58c0] ישן_, cucu, _صحيف, xyo_,
   {{0x442680f6,0x61230074,0x9bb70039,0x69dc1de0}},	//   vyo_, _sõlt, _שהיה_, ptre,
   {{0x7afaa88c,0xb6068333,0x65628bb1,0x7bdb8580}},	//   _ratt, _ibáñ, tooh, _aquu,
   {{0x442681d3,0x7afa913f,0xb4ccb841,0x2fc93216}},	//   tyo_, _satt, लले_, brag_,
   {{0xeb978a7c,0xd843016b,0x7afa8ca9,0x3075255e}},	//   вич_, ročí_, _patt, _бурс,
   {{0x4426e6af,0x7afa822b,0x46a331a9,0x6376841c}},	//   ryo_, _qatt, _варв, dânc,
   {{0x7afa84b8,0x442697ef,0x3cfd8074,0xf743197d}},	//   _vatt, syo_, _रोके_, _теро,
   {{0x7afae6b0,0x4426820d,0x5ec700ab,0x63768187}},	//   _watt, pyo_, র্দে, fânc,
   {{0xe80505b3,0x798b831d,0x2bc9866b,0x63768187}},	//   रिया_, _digw, _रिया, gânc,
   {{0x61310186,0x7d0d1581,0xa2d70cf0,0x21ce8085}},	//   _måla, _snas, _बाध्, _məhz_,
   {{0x752081f6,0xb87b0032,0x7d0d008e,0x2d8c8061}},	//   _komz, _abíl, _pnas, _édes_,
   {{0xc4bf06bf,0x779289a7,0x64bf064a,0x255600eb}},	//   ्लेख, _پیدا, ्लेश, tāla_,
   {{0xd6d282e3,0xe9ff80ff,0xdb04016a,0x60c2b521}},	//   _نقش_, _thảm_, _aviñ, _idom,
   {{0x7520e6b1,0x2d8792cc,0x7bdd1611,0x70cb000d}},	//   _lomz, ínez_, rtsu, िल्ल,
   {{0x442d003b,0x2736013c,0xa92300e1,0x7bdd66b2}},	//   še_, _mænd_, áľov, stsu,
   {{0x3998938d,0x2fc966b3,0x7520836a,0x7d0d004f}},	//   _més_, trag_, _nomz, _unas,
   {{0xaad2800f,0xdb0603c1,0x6aa266b4,0x60c28c53}},	// [58d0] _सांक, lský, _şofe, _mdom,
   {{0x6d440063,0x656f66b5,0xa2f5004a,0x2cb90326}},	//   _zmia, llch, _споч, lasd_,
   {{0xdb06003e,0x60c2e6b6,0x2baf0072,0x39988866}},	//   nský, _odom, जीरा, _nés_,
   {{0xf65381c6,0xdcfc8085,0x60c2996d,0x6135826b}},	//   בצע_, _vurğ, _ndom, _kále,
   {{0x798b81b9,0xfbdf041c,0xd103970c,0xbcfb2746}},	//   _rigw, ntê_, _शोषण_, llés,
   {{0x6135807b,0xab6481e2,0x6376841c,0xf9901e5c}},	//   _mále, авіл, vânc, _دبی_,
   {{0xa969c094,0x21698c8e,0x6145e6b7,0x68fd0110}},	//   ника_, ники_, лека, _kasd,
   {{0x637683a7,0xdb06016b,0xe9ff80ff,0x6c858019}},	//   tânc, dský, _chạm_, _ملزم,
   {{0x6135826f,0x1c07009a,0x78a981eb,0x68fd114b}},	//   _nále, शिफल_, rbev, _masd,
   {{0x656f151e,0x39493d63,0x60c2c176,0x78a9874d}},	//   elch, hias_, _edom, sbev,
   {{0x63bd4069,0x458612ea,0x0d8608b0,0x2006b45a}},	//   essn, лгов, ллон, _eroi_,
   {{0xaadf8744,0xb87b0032,0x629c0326,0x6135826b}},	//   प्रक, _abím, wcro, _bále,
   {{0x66e593f7,0x290fb58e,0xeb971bcf,0x39490625}},	//   _бола, _inga_, лия_, dias_,
   {{0xcc3a80be,0xa3d50074,0x656f051e,0xdd8e810c}},	//   געשט, _हमर_, alch, _کوي_,
   {{0xa2db82a8,0xbcfb009f,0x3949106c,0x69d4016f}},	//   _नान्, glés, fias_, बंधी,
   {{0x39491520,0x68fd0118,0x81b58264,0x6d930609}},	//   gias_, _casd, _জমা_, _għai,
   {{0xb4d00076,0x27eb0326,0x7d7b2b7b,0x2fdfa4d1}},	// [58e0] शली_, _cpcn_, _אנקו, ntug_,
   {{0x63a466b8,0x888310f8,0x6566029b,0x657be089}},	//   _itin, служ, lokh, _ahuh,
   {{0x394966b9,0xf8bf02be,0x61359dc5,0x6b9666ba}},	//   bias_, _clés_, _zále, _huyg,
   {{0x3949436a,0xa37b03a7,0xac97803d,0x68fd654a}},	//   cias_, rtõe, هنما_, _gasd,
   {{0x77f28dbc,0x26f38076,0xa37b0073,0x7afe0eb9}},	//   _अनेक_, _असूर_, stõe, _kapt,
   {{0x81c900c8,0xf7460364,0x08fc00c8,0x6ed88540}},	//   োবর_, _сего, _একটু_, _माधु,
   {{0x27e066bb,0x82970051,0xe9ff8028,0x41e680f7}},	//   ltin_, נדקס_, _phạm_, استف,
   {{0x29003ccc,0xd01080f7,0xdb060e04,0x20068267}},	//   ndia_, قلب_, vský, _proi_,
   {{0x3d11835a,0x63a40135,0xfaa69bd8,0x473481a4}},	//   णारे_, _ntin, _базо, инис,
   {{0x138a80f7,0xdb06016b,0x4ad303eb,0x3998816a}},	//   _أخرى_, tský, _ताइव, _tés_,
   {{0x22938307,0x63a466bc,0x49ca8003,0xaa938829}},	//   _المس, _atin, _член_, _المث,
   {{0x394966bd,0xdb0666be,0x9f490125,0x27e02bc4}},	//   xias_, rský, hvað_, ktin_,
   {{0x39491e31,0x394684c3,0xbf9b03a7,0xa2dbd42e}},	//   vias_, _imos_, _prêm, _नाम्,
   {{0xa3c98076,0x39468282,0x6b960214,0x613581d0}},	//   लूट_, _hmos_, _duyg, _vále,
   {{0x2d9c00a9,0x63a40870,0x5fc70006,0x13d18b04}},	//   ível_, _etin, _लिहल, _सम्भ,
   {{0x27e066bf,0x2900009f,0xddcb04b7,0xbcfb0061}},	//   ftin_, gdia_, ċiżj, rlés,
   {{0x39491313,0x7afe002e,0x3f8e85ee,0x3eba0493}},	// [58f0] rias_, _fapt, _kifu_, fapt_,
   {{0x394966c0,0xaadc016f,0x63600061,0x3cfd99f1}},	//   sias_, _बायक, köny, _रोजे_,
   {{0x39492c70,0x68fd66c1,0x3946e500,0x06cc00ab}},	//   pias_, _tasd, _omos_, র্ভি,
   {{0x67d510ef,0xc56b8060,0xe7e582f1,0x68e40174}},	//   _кому, رحال_, _कहला_, cfid,
   {{0x7afe07d9,0x78ad3292,0x61fa82f9,0x6e950749}},	//   _yapt, mbav, _astl, _вигу,
   {{0xa3d60576,0x26c3008e,0x290f8122,0xeb969577}},	//   ांत_, _udjo_, _snga_, шиш_,
   {{0x2bd185e8,0x657b80f1,0x316b0088,0x798f03f7}},	//   _समका, _thuh, _kkcz_, _kicw,
   {{0xa9258258,0xceba8326,0x5ec70264,0x613113c2}},	//   рдил, _roƙa_, র্শে, _målo,
   {{0x6d4bbefc,0x61fa9e96,0x2f55d18a,0x64c80196}},	//   miga, _estl, итос, nčių,
   {{0x3cff90af,0x5745a183,0xb87b0032,0xe9ff80ff}},	//   _hauv_, рноб, _abík, _nhầm_,
   {{0xd2518064,0xbb8480f7,0x6285826f,0x3cff822c}},	//   _بنا_, _اللي, ýhod, _kauv_,
   {{0xeb9a00bf,0xd0118013,0x6d4be6c2,0x290fe6c3}},	//   ким_, _ولا_, niga, _unga_,
   {{0xe72e8934,0xed570a08,0x3cff8282,0x3ce900b9}},	//   _де_, роя_, _mauv_, _dbav_,
   {{0xa3e885e8,0x2d9582a4,0x3cffe6c4,0x6d4be6c5}},	//   _बहस_, _крис, _lauv_, higa,
   {{0xc3328039,0x98a066c6,0x6d4bcde9,0xa2d706bf}},	//   חום_, nkić_, kiga, _बार्,
   {{0x290009e8,0x10a602bc,0x18a61246,0x7afe66c7}},	//   udia_, риан, раам, _wapt,
   {{0x6d4be6c8,0x6723e6c9,0x7afe102a,0x63a41267}},	// [5900] diga, _konj, _tapt, _utin,
   {{0x613104b8,0x27e066ca,0xdb06008b,0x60d61388}},	//   _håll, rtin_, rskó, sgym,
   {{0xc0e601b5,0x48e60a95,0xdb2402e3,0x6723a01d}},	//   _конк, _конв, _نوکی, _monj,
   {{0xb64c8158,0xfce6a457,0x672386c0,0xb4c2800d}},	//   עגאָ, родо, _lonj, ूले_,
   {{0x638681a1,0x2ca982ba,0x3cff81c0,0x613801d0}},	//   агда, ñada_, _dauv_, _cíle,
   {{0x69ce0a0f,0x31c68d0e,0xa9c6a69c,0x05c580d4}},	//   orbe, асив, асик, _विंब,
   {{0xd24f845a,0x6d4bb01a,0xd90d826a,0xdce280c3}},	//   ونه_, biga, کین_, looč,
   {{0x3f8e80ee,0x752440b9,0xbcfb01d0,0x32cc8032}},	//   _sifu_, _noiz, jlép, _bóyà_,
   {{0x6723e6cb,0xd0e2873c,0x69c18214,0x14a70d72}},	//   _bonj, क्षण_, _evle, _क्षण,
   {{0x6723e6cc,0x80a6904f,0x257580f2,0x2d982a52}},	//   _conj, _ट्रे, håll_, _kure_,
   {{0x3eb80065,0x6723803b,0x6abc00e3,0x2fcde6cd}},	//   _mert_, _donj, darf, areg_,
   {{0x7d02cf87,0x7d0096f2,0x2d9866ce,0x2fcd80fe}},	//   ndos, _jams, _mure_, breg_,
   {{0x6abc031d,0x69c866cf,0x6723c42e,0x69ce09e5}},	//   farf, áden, _fonj, erbe,
   {{0x6d4bab75,0x7d009345,0x98a9050b,0x6d5d0036}},	//   ziga, _lams, rkač_, érab,
   {{0x6135cd75,0x48dd86ab,0x6d4bacde,0xff7b83de}},	//   _hála, क्को_, yiga, _שטומ,
   {{0x2d520024,0x75240102,0x67238168,0x7d00e6d0}},	//   všeg_, _goiz, _zonj, _nams,
   {{0x3eb85a41,0x2d9866d1,0x3cff822c,0x69ce5a0b}},	// [5910] _bert_, _aure_, _rauv_, arbe,
   {{0x3eb85868,0x6135e6d2,0x2d9866d3,0x3cff822c}},	//   _cert_, _mála, _bure_, _sauv_,
   {{0xd0068416,0x2bc986b7,0x3cff81c5,0x7d00b8c8}},	//   _کل_, _रिहा, _pauv_, _bams,
   {{0xe1f02003,0x7d00e6d4,0x2d9866d5,0x3cff81c5}},	//   _کسی_, _cams, _dure_, _qauv_,
   {{0xa3b285b3,0x6d4ba6c0,0xfc3f001b,0x3eb866d6}},	//   झील_, riga, nzí_, _fert_,
   {{0x6d4bd1ee,0x3eb866d7,0x2d520503,0x3da70073}},	//   siga, _gert_, pšeg_, _враб,
   {{0x2d98011e,0x6d4be6d8,0x7d008168,0x3cff822c}},	//   _gure_, piga, _fams, _tauv_,
   {{0x672386c0,0xe9a880f7,0x7d00d342,0xe8f99263}},	//   _sonj, جدون_, _gams, ули_,
   {{0xb8ffa177,0x6d498ac7,0x2d98011e,0x6d5b84cd}},	//   _ता_, _imea, _zure_, _ijua,
   {{0x3f9966d9,0x636d85e4,0x2fcde6da,0x257201fa}},	//   _musu_, gúnt, rreg_, máli_,
   {{0x3ea102af,0x37a800ab,0x6723e6db,0x752402d4}},	//   icht_, _ওয়ার, _vonj, _poiz,
   {{0xc329004c,0x69d5003b,0x3ce30076,0xb8958013}},	//   _או_, duze, ट्ले_, _الإع,
   {{0x394de6dc,0x6abc007b,0x3f99004f,0x291fc778}},	//   mies_, tarf, _nusu_, mjua_,
   {{0xfaa31a4e,0x673a80f3,0xeb971a21,0x7af566dd}},	//   заро, chtj, сир_, gezt,
   {{0x2bd1800f,0xbb431cd0,0x69d512e5,0x200b01e8}},	//   _समझा, черк, guze, _arci_,
   {{0x3a2500f2,0x399c01fa,0x3eb866de,0xa3e88dd2}},	//   älpa_, _vís_, _sert_, _बहल_,
   {{0x4e961301,0x46ea07b6,0x3d1566df,0x2d980039}},	// [5920] مشار, лдан_, धारे_, _sure_,
   {{0x6d49aeb3,0x3f9904a8,0x60dd026c,0x69d526d7}},	//   _amea, _dusu_, _ecsm, buze,
   {{0xd0f983b7,0x394dca06,0xa3d60006,0x3eb866e0}},	//   ्याण_, kies_, ांव_, _vert_,
   {{0x61fe003a,0x3ea10013,0x394de6e1,0xd9100077}},	//   _ispl, acht_, jies_, _تیر_,
   {{0x200b02a5,0x6ed89344,0x394ddeb8,0xe607804e}},	//   _grci_, _मालु, dies_, _کش_,
   {{0x290203c3,0xf6d5035f,0x8fa30098,0x7d028168}},	//   _haka_, _міся, _харе, sdos,
   {{0x7d00e6e2,0x394de6e3,0x27298118,0x61359434}},	//   _tams, fies_, _lúns_, _sála,
   {{0x21200796,0xf99304de,0x68f637b4,0x29021c9e}},	//   njih_, הרה_, neyd, _jaka_,
   {{0x290266e4,0x3d1c053e,0x74548065,0x7af50061}},	//   _maka_, याने_, _بھائ, yezt,
   {{0x61358986,0x19ba8765,0xcafc83eb,0x2d920091}},	//   _vála, _будь_, _एसिड_, _aiye_,
   {{0x394de6e5,0xd9469b62,0x25a7802a,0xb99680f7}},	//   bies_, _лежи, _ctnl_, _الصب,
   {{0xd7fe0104,0x673a820f,0x290266e6,0x2d80019d}},	//   _đăng_, shtj, _naka_, _chie_,
   {{0x2d9207d9,0x7d7b8039,0x716580f7,0xdb09807b}},	//   _diye_, טרטג, _بالك, _kveð,
   {{0x799a93b2,0x29020032,0x637f8187,0x613ce6e7}},	//   _kutw, _aaka_, cênd, _bélg,
   {{0x290266e8,0x3f991e92,0xa2db9905,0x2d9200a4}},	//   _baka_, _susu_, _नास्, _fiye_,
   {{0x69d50b67,0xa3d60eed,0x799aac1d,0x2904870e}},	//   ruze, ांश_, _mutw, ndma_,
   {{0x61fe66e9,0x645a07d9,0x76b901a1,0x63b6031d}},	// [5930] _espl, ştir, илар_, _gwyn,
   {{0xec380051,0x3ea102af,0x394ddcb0,0x6d49e6ea}},	//   _לאחר_, ucht_, zies_, _smea,
   {{0x2ca982ba,0x3f9102a5,0xa3db816f,0x2902036a}},	//   ñado_, _vizu_, ढून_, _faka_,
   {{0x3ea102af,0x5c758758,0x200b1487,0x3d1c00c2}},	//   scht_, олет, _trci_, याये_,
   {{0xb6078a56,0x320c808e,0x3ebe919b,0x394de6eb}},	//   _koší, _ardy_, katt_, vies_,
   {{0x290266ec,0x85bb12c5,0x55bb00d7,0x394dbd5b}},	//   _zaka_, _مارس_, _مطرح_, wies_,
   {{0x394de6ed,0xb529026b,0x7aea01ec,0x3d1c052a}},	//   ties_, _akọ̀, _öfte, यामे_,
   {{0x5d549dba,0x6d49e6ee,0x81ea80ab,0x672708dc}},	//   _екст, _umea, মিং_, _hojj,
   {{0x394d8b39,0x200b803e,0x320c82c4,0xe8df80ff}},	//   ries_, íci_, _erdy_, hiện_,
   {{0x394de6ef,0x63a98073,0x656bb6b9,0x6d93822b}},	//   sies_, _iten, logh, _għar,
   {{0x6d598901,0x2d923e23,0x799a8b5e,0x637f841c}},	//   onwa, _piye_, _gutw, gêne,
   {{0x29038029,0xdb06016d,0x656bb422,0x6b9be6f0}},	//   ējas_, nskö, nogh, _kuug,
   {{0xeb9a01a1,0x3ebee6f1,0xae17815b,0x4ae0816f}},	//   риг_, batt_, _گذشت, _नामव,
   {{0x29020288,0x3b0a0009,0x63a9804f,0x3ebe8037}},	//   _saka_, шего_, _mten, catt_,
   {{0xcb12878d,0x29023a9b,0x68f60009,0xdb060106}},	//   ולם_, _paka_, teyd, kskö,
   {{0x60dbe6f2,0x6f03e6f3,0x63a9a49f,0x6138007b}},	//   ngum, _hanc, _oten, _bíla,
   {{0x6f03e6f4,0xfe780110,0x2120007a,0x290266f5}},	// [5940] _kanc, _šį_, rjih_, _vaka_,
   {{0xef17176a,0x29021855,0x69c3e6f6,0x6721817f}},	//   ому_, _waka_, ksne, njlj,
   {{0x290266f7,0xe4d309a7,0x60db80b9,0x6a800032}},	//   _taka_, _عقید, kgum, _dáfí,
   {{0x7bc2951e,0x6b9b8079,0x186a32de,0xb4db023e}},	//   tsou, _buug, _вами_, liàr,
   {{0x7d0466f8,0x06cc00ab,0x25ad016b,0x69c101d0}},	//   _mais, র্ষি, _čele_, šlet,
   {{0xaff900be,0x79a690ff,0x6d4f1598,0x60db80eb}},	//   _פּרי, орие, zica, egum,
   {{0x63a9e6f9,0x7bc2bfd1,0x68e9e6fa,0x613c8718}},	//   _eten, ssou, ffed, _léle,
   {{0x7d0466fb,0x2bd28592,0x442f8114,0x26c700e1}},	//   _nais, _सिपा, byg_, ónov_,
   {{0x6f0380ee,0xd83a8196,0x290280e1,0x2572016b}},	//   _banc, рэй_, ľka_, nálu_,
   {{0x29029f07,0x6d4f66fc,0x6f03ad12,0x61358118}},	//   žka_, wica, _canc, _fálo,
   {{0x6d4f160c,0x7d0466fd,0x3ebee6fe,0x613c8019}},	//   tica, _bais, ratt_, _péld,
   {{0x7d042846,0x3ebee6ff,0x25a50118,0x6f038229}},	//   _cais, satt_, _élle_, _eanc,
   {{0x6d4f6700,0x61359dc5,0x60c0e701,0x6442b3f8}},	//   rica, _zálo, mamm, nzoi,
   {{0xdcfc81e2,0x491281d0,0x48f481d0,0x613cc385}},	//   _turė, थाको_, ्यको_, _déle,
   {{0x7d045b39,0xd90f0077,0x656b8135,0x61380825}},	//   _fais, نید_, yogh, _síla,
   {{0x7d046702,0xa2d70768,0x6f038041,0x6edd0d14}},	//   _gais, _बाक्, _zanc, _पाहु,
   {{0xe572093f,0x6d4d6703,0x6f0384b9,0x637f8187}},	// [5950] _אַז_, _imaa, _yanc, nênc,
   {{0x7d0402a5,0x61310aa2,0xb87b0118,0x69d8a3c1}},	//   _zais, _måli, _acíc, kuve,
   {{0x69d8e704,0x2d9ce705,0x6b9b8079,0x442fa9f6}},	//   juve, _juve_, _suug, wyg_,
   {{0x2fc68025,0x442f84b8,0x61358144,0x3ebca6f4}},	//   _ovog_, tyg_, _cáll, _levt_,
   {{0x18350158,0x656be706,0x613583a8,0x60c081b4}},	//   _זאָל_, rogh, _dáll, damm,
   {{0x637f8073,0xd6d817d4,0x2d9cd0f0,0x257c80e1}},	//   dênc, _мтс_, _ouve_, ríla_,
   {{0x6d4d2e95,0x69d8e707,0x6f039342,0xe5c4148d}},	//   _omaa, guve, _ranc, _осто,
   {{0x25720019,0x69c39151,0x26c16708,0x61358019}},	//   nált_, rsne, laho_, _válo,
   {{0x6f03bbde,0x63a9e709,0x798282a3,0x2bd2800f}},	//   _panc, _uten, _dhow, _सिया,
   {{0x7d04670a,0x613100f2,0x6d4d670b,0x6f0381b4}},	//   _sais, _dåli, _amaa, _qanc,
   {{0x613c82be,0xe8020540,0x366999a7,0xb9e780e8}},	//   _séle, _रैना_, сано_, _фізи,
   {{0xed5a00e2,0x6f03e70c,0x60c0e70d,0x78bd3799}},	//   сом_, _wanc, camm, _nesv,
   {{0x6f03e70e,0x7d04670f,0xc95284de,0x26c12fba}},	//   _tanc, _vais, _אמא_, kaho_,
   {{0x613c8065,0x200f8110,0xdb0600e1,0x6d4d6710}},	//   _véle, _irgi_, jskô, _emaa,
   {{0x7d046711,0x78bd0a33,0xaca4019d,0xd2520061}},	//   _tais, _besv, _ahụw, رنر_,
   {{0x25aa86a5,0x5fc70006,0x7d040c41,0x3f9da1ba}},	//   íble_, _लिखल, _uais, _kuwu_,
   {{0x78bd6712,0xf8bf002a,0xaa8a004e,0xeaaf0019}},	// [5960] _desv, _toén_, _گندم_, ئٹہ_,
   {{0xdfcf00a0,0xb87b0032,0x78a401e8,0x869a0c67}},	//   ايل_, _abís, sciv, стат_,
   {{0x1a9b0158,0x7bc60e51,0x4a9b00be,0x6edd0074}},	//   _לייע, lsku, _לייג, _पारु,
   {{0x63768012,0xc4868cdf,0xdb0d007b,0xbf9b00e7}},	//   mâni, плек, _hvað, _prêt,
   {{0x26c120d1,0x61358065,0x7bc66713,0xa806802a}},	//   baho_, _váll, nsku, _mañó,
   {{0x7982e714,0x69d8a585,0xfc3f0511,0x61358118}},	//   _show, tuve, ncía_, _dálm,
   {{0x2fc68025,0x60c0e715,0xa50a8098,0x200f8102}},	//   _svog_, tamm, _лева_, _argi_,
   {{0xd13080f7,0x637f83a7,0x613101a3,0x7bc61d73}},	//   ئمة_, tênc, _påli, ksku,
   {{0x60c08e51,0x7af882d4,0x2d9c9ae6,0x255601a9}},	//   ramm, pevt, _suve_, nālu_,
   {{0x60c0e716,0x637f80a9,0x6b6697ae,0x6d4d03b2}},	//   samm, rênc, _экза, _smaa,
   {{0x2cad0e15,0x2480083a,0x637f83a7,0x6d4d0122}},	//   ñedo_, _azim_, sênc, _pmaa,
   {{0x2fc68052,0xc27b810f,0x4a7b80be,0xa8068020}},	//   _tvog_, _פראי, _פראב, _cañó,
   {{0x7bc6126c,0x78bd08dc,0xdfcf81a8,0xddd380c3}},	//   gsku, _resv, _مين_, čaše,
   {{0x3b058085,0x2d9ce717,0x661c8884,0x9abc84b7}},	//   _xalq_, _tuve_, ärks, _soċj,
   {{0x637683a7,0x81ea80ab,0x26c100b4,0x61310711}},	//   gâni, মিক_, vaho_, _målv,
   {{0x6d4d49a3,0x39400834,0x26c10a03,0xa3cd864a}},	//   _umaa, ghis_, waho_, _शटल_,
   {{0xb905184a,0x656f0063,0xb4d91299,0xb87b026b}},	// [5970] _ना_, moch, ाली_, _abír,
   {{0xc6a40ba8,0x63ad6718,0xd24e0065,0x09b280ab}},	//   ерци, _itan, اچی_, _ঘটনা,
   {{0x7529e719,0x26c10578,0x20020214,0x6d5d671a}},	//   _poez, raho_, _eski_, onsa,
   {{0x6d5d0046,0x656f671b,0xdced04a8,0x39401db9}},	//   nnsa, noch, _okač, chis_,
   {{0xdfc68c3b,0x2919002e,0x2d520353,0x69c8868f}},	//   _جي_, _insa_, kšen_, _avde,
   {{0x68e2a564,0x63ad0010,0xb4d906b7,0x212b01ec}},	//   _acod, _mtan, ालु_, _hoch_,
   {{0x656f671c,0xd0158592,0x69c700e8,0x752980f3}},	//   koch, तम्भ_, nsje, _toez,
   {{0x56941e4a,0x7bc6671d,0x29090010,0x63ad1210}},	//   _част, ysku, ndaa_, _otan,
   {{0x600691e9,0x63ad242d,0x69d502af,0x798980dd}},	//   дным_, _ntan, hrze, rmew,
   {{0x27e92853,0x212b35fa,0x333984c0,0x02a79d1d}},	//   itan_, _loch_, _بزرگ_, _храм,
   {{0x63ad671e,0x7a3580f7,0x69d50035,0x291902c4}},	//   _atan, _تفاص, jrze, _onsa_,
   {{0x212b034a,0x6281812b,0x27e9671f,0x69c76720}},	//   _noch_, _izlo, ktan_, dsje,
   {{0x68ed00f7,0x27e9311a,0x394fe721,0x3d1e0424}},	//   dfad, jtan_, _imgs_, _बचीं_,
   {{0x6f075f1e,0x2919205d,0xaca381bc,0xdce400d2}},	//   _najc, _ansa_, _baịn, _okić,
   {{0xe2976722,0x656f0870,0x39406723,0xfc3f2e3c}},	//   дар_, boch, this_, rcía_,
   {{0x656f1f10,0xceba80fc,0x27e96724,0x29190a2a}},	//   coch, _roƙi_, ftan_, _cnsa_,
   {{0x212b0352,0xa4940077,0x27e9033e,0xb8f6000d}},	// [5980] _doch_, _سیست, gtan_, _सय_,
   {{0x39400282,0x613c80e7,0x3d1c016f,0x62818390}},	//   shis_, _méla, यावे_, _ozlo,
   {{0x27e90867,0xd946200d,0xa3d62441,0x68fb8009}},	//   atan_, _жени, ांक_, keud,
   {{0x69dc1d60,0x7afc2e8c,0xa2aa0105,0x27e92741}},	//   mure, lert, जुर्, btan_,
   {{0x27e96725,0x0edd816f,0x60c46726,0x59830221}},	//   ctan_, _मांड, maim, _шлюб,
   {{0x656f3c27,0x7afc4123,0x68e28037,0xbfa580ff}},	//   zoch, nert, _scod, _việ,
   {{0x656f3a87,0x6298003e,0x63bbe727,0x255601a9}},	//   yoch, _úvod, _ewun, nāls_,
   {{0x3f98011e,0x3d0692ee,0x60c4563c,0x4ae0852a}},	//   _hiru_, _सोचे_, naim, _नावव,
   {{0xbcfb03d3,0x6d5d1f10,0x69dc466b,0x6f0701c0}},	//   nnée, éram, hure, _yajc,
   {{0x3ce10006,0x613c80e7,0x60c46728,0x6446009a}},	//   _काहे_, _déla, haim, dzki,
   {{0x60c46729,0x68ed0214,0x6138002a,0xd5b78d15}},	//   kaim, yfad, _píll, мся_,
   {{0xb4d9000c,0x613c8125,0x2bd2816f,0x63a0cc11}},	//   ाले_, _féla, सळपा, _kumn,
   {{0x7afc672a,0x2d522145,0x656f672b,0x69a4809a}},	//   fert, pšen_, roch, _चंडी,
   {{0xf64f8117,0x69d50063,0x7afc06a2,0xc87f81ec}},	//   ائی_, trze, gert, üße_,
   {{0x69dc48cf,0x656f672c,0x43940f04,0xda780607}},	//   gure, poch, тарс, дят_,
   {{0x60c40393,0x69c74356,0x3f98672d,0x61383db4}},	//   gaim, rsje, _airu_, _fílm,
   {{0xe811901b,0x3f981e92,0x68ed672e,0x27e902d6}},	// [5990] ़िया_, _biru_, rfad, utan_,
   {{0x212b06c4,0x27e9672f,0x69d50063,0xc8088028}},	//   _woch_, rtan_, prze, _mở_,
   {{0x212b0613,0x7bdd6730,0x7bc9acf6,0x7ae554b6}},	//   _toch_, lusu, _sveu, _icht,
   {{0x27e96731,0x29191341,0x613581d0,0x27ff8114}},	//   ptan_, _unsa_, _válk, ywun_,
   {{0x7bdd6732,0x9f9a8009,0x27ff0081,0xc80880ff}},	//   nusu, nään_, _èun_, _nở_,
   {{0xfbd083f8,0x63a08012,0xc2c581a8,0x798d0326}},	//   شته_, _dumn, ريبي, lmaw,
   {{0xe1f19125,0xa4d5835f,0x18a585a8,0xe2968073}},	//   است_, _пові, найм, наш_,
   {{0x7afc358b,0x9f9a8364,0x7bdd6733,0x6d42e734}},	//   zert, kään_, kusu, choa,
   {{0x7ae56735,0x69dc80e8,0x0bd581a8,0x68fbc327}},	//   _ocht, _åren, _سياح, reud,
   {{0x200de736,0x7bdd6737,0x6135807b,0x60c46738}},	//   rvei_, dusu, _máli, zaim,
   {{0x7afc1527,0x06cc00c8,0x7d099400,0x06d500ab}},	//   vert, র্কি, _kaes, স্থি,
   {{0x7ae56292,0x7afc327f,0x613101a3,0xc0e9803d}},	//   _acht, wert, _måls, _رفتن_,
   {{0xd90f850c,0x752d0b6e,0x7afc6739,0x3ce10beb}},	//   _میں_, _doaz, tert, _कारे_,
   {{0x69dc4a0a,0x06d500ab,0xa8568039,0x66e5802e}},	//   ture, স্তি, _אינה_, _чока,
   {{0x60c4673a,0x7afc2f1d,0x6376a031,0x7d1be73b}},	//   taim, rert, mânt, _onus,
   {{0x7ae5264a,0x395fe73c,0x7bdd673d,0x26c585e7}},	//   _echt, nnus_, busu, lalo_,
   {{0x7afc010b,0x61359986,0x69dc05ef,0xfaa60254}},	// [59a0] pert, _cáli, sure, _папо,
   {{0xe2058028,0x386604b7,0x60c4673e,0xbcfb00e7}},	//   _đóng_, ħor_, saim, rnée,
   {{0x63a08025,0x1f3683c8,0x60c448ba,0x3f98673f}},	//   _sumn, ערער_, paim, _viru_,
   {{0x80be823c,0x26c5ceb8,0x9f40023e,0x395f81c0}},	//   _एजें, halo_, stià_, jnus_,
   {{0x26c5e740,0x7d098683,0x3f9800dd,0x6135b518}},	//   kalo_, _daes, _tiru_, _gáli,
   {{0xdd318201,0x26c5e741,0x4908000d,0x06d580ab}},	//   _təşk, jalo_, ाएको_, ত্তি,
   {{0xc8088028,0x3ce10035,0x6135816b,0xf77701c6}},	//   _sở_, _काले_, _záli, _נעלי_,
   {{0x7d1b826c,0x395f8687,0x2d52128a,0xab5b06ae}},	//   _gnus, gnus_, ušel_, tsük,
   {{0xb908d2c3,0x6d40ae95,0x752d0706,0x9a6a804e}},	//   _बा_, _ilma, _roaz, _کمال_,
   {{0x4734845d,0x65641ec4,0x78a981e8,0x9f9a8198}},	//   тнос, _ajih, acev, vään_,
   {{0x0f570051,0x7d0981e0,0xd6d78fe6,0x613103ba}},	//   תיים_, _yaes, хты_, _målr,
   {{0x9f9a825d,0x3ce1016f,0x8fa69fb5,0x7ae51a25}},	//   tään_, _काळे_, _заде, _scht,
   {{0x26c5e742,0x29578158,0xdb008168,0x6b9a838a}},	//   balo_, _אסאך_, _numë, _kitg,
   {{0xdb00816d,0x7bdd6743,0xf8b8001c,0xd9f4816f}},	//   _utmä, rusu, _đĩa_, _आहात_,
   {{0x6d408b06,0x6b9a8352,0x2bd30006,0x0a680705}},	//   _olma, _mitg, _तिवा, ерти_,
   {{0x9f9a8009,0x7bdd6744,0x99980c51,0x798d008e}},	//   sään_, pusu, екст_, umaw,
   {{0x671c1094,0xa3d29a4d,0x69d88192,0xdfd4062c}},	// [59b0] नांक_, _विष_, hrve, лоты,
   {{0x6d40cc0b,0x61358907,0xa3d60697,0x4de486a7}},	//   _alma, _váli, _हित_, _कमाई_,
   {{0x78a204e8,0x7d098098,0x317200b9,0x316009c4}},	//   žova, _paes, boyz_, bniz_,
   {{0x60c29d1a,0x61358789,0x6285007a,0x2fcb0088}},	//   _neom, _hálv, _izho, _tvcg_,
   {{0x26c5be3e,0x69d8bdd9,0x9f4003a8,0x672e0197}},	//   yalo_, erve, stiá_, _fobj,
   {{0x2d52012b,0x69da0216,0x6d40e745,0x212902d4}},	//   všem_, áteg, _elma, ljah_,
   {{0x290b0288,0xa969a6c8,0x78a98087,0x63768087}},	//   _kaca_, мика_, tcev, vânt,
   {{0x290b02a5,0x26c5e746,0x1a68803d,0x21296747}},	//   _jaca_, walo_, رینی_, njah_,
   {{0x33f49ecd,0x290b6748,0x395fe749,0xfbd0803d}},	//   _مسلس, _maca_, rnus_, _هتل_,
   {{0xee398fcb,0xddd88110,0xa2db93ba,0x78a9847f}},	//   дно_, _gyvū, _नाट्, scev,
   {{0x0d860bba,0x99d492dc,0x69d8812b,0x7bcd0198}},	//   клон, _متنا, crve, _avau,
   {{0xb4ac0e18,0x26c5e74a,0x2129674b,0x7052826a}},	//   गडे_, salo_, jjah_, انیا,
   {{0x2129008e,0x06cc00ab,0x8afe80fc,0x00000000}},	//   djah_, র্টি, moƙr, --,
   {{0xd5d10076,0xeb970698,0x4375674c,0x290d811e}},	//   _हिंज, кия_, густ, ldea_,
   {{0x27ed834a,0x290b0867,0xeb971ff3,0xdb0089c4}},	//   lten_, _baca_, тир_, _dumè,
   {{0x290db641,0x60c281df,0x27ed80c6,0x7bcb8338}},	//   ndea_, _xeom, oten_, ksgu,
   {{0x27ed861b,0x290b0c6e,0x672e02fd,0x31605c69}},	// [59c0] nten_, _daca_, _pobj, rniz_,
   {{0x27edd45b,0x5fd4816f,0x249f9142,0x6fd48035}},	//   iten_, _दिसल, _agum_, _दिसं,
   {{0x26c3674d,0xe7fe0740,0x290b674e,0x27ede74f}},	//   _dejo_, _उनका_, _faca_, hten_,
   {{0x27edd82b,0x63a46750,0x6b9ae751,0x6dac07c0}},	//   kten_, _kuin, _sitg, _ağac,
   {{0x69da00d2,0x27ede752,0x5ed980ab,0x29002031}},	//   šted, jten_, ব্যে, meia_,
   {{0x63a46753,0x60c29a2c,0x27e02419,0x291d81bc}},	//   _muin, _seom, muin_, _anwa_,
   {{0x44208012,0x2d968048,0x27eddf70,0x61ee081a}},	//   ţi_, _арас, eten_, ntbl,
   {{0x27edda0b,0x69cac9ed,0x69d8e754,0x290052ed}},	//   ften_, rsfe, rrve, neia_,
   {{0x60c28efd,0x53a69878,0xc9530bea,0x27edb257}},	//   _veom, _разб, ימה_, gten_,
   {{0x6b9aa468,0x7791826a,0x7792803d,0x69ca874d}},	//   _uitg, مینا, جیتا, psfe,
   {{0xdb0083d3,0x27e06755,0x27ede756,0xe514103e}},	//   _numé, huin_, aten_, _तोहि_,
   {{0x61359986,0xa9278110,0x63a4217a,0x27e06757}},	//   _sálv, gužė, _buin, kuin_,
   {{0x0ee239a1,0x27ed8613,0x4426c98c,0x63a449b1}},	//   _पांड, cten_, nxo_, _cuin,
   {{0x44269a85,0x63a4061f,0x290b28d5,0x6d4609ca}},	//   ixo_, _duin, _saca_, ahka,
   {{0x4f9b8039,0x671f800f,0x6135ced8,0x2ba50105}},	//   _קבוצ, बारक_, _válv, _गंवा,
   {{0x63a40cb5,0xe807816f,0x6285007a,0x68e46710}},	//   _fuin, वटचा_, _vzho, ggid,
   {{0x40340364,0x27e0009f,0x21290ad4,0xdb00b78d}},	// [59d0] аетс, guin_, rjah_, _eumé,
   {{0x7d0d2d7e,0x44396758,0xa6cc00ab,0x02b73a6a}},	//   _haas, mys_, র্ঘট, _अभिभ,
   {{0x7d0d60d9,0x44396759,0xa3df1a42,0x27ed811e}},	//   _kaas, lys_, दूर_, zten_,
   {{0x27ed9d73,0x656281a1,0x27e002c4,0x2d5202d4}},	//   yten_, gnoh, buin_, všek_,
   {{0x7d0d0eea,0x443941c5,0x27ed8884,0x26c3675a}},	//   _maas, nys_, xten_, _tejo_,
   {{0x7d0d675b,0x7ae381c0,0x7bcb88dc,0x799d5d51}},	//   _laas, ugnt, rsgu, _hisw,
   {{0x2b8981ac,0x799d0010,0x6138675c,0x7bcb839c}},	//   júce_, _kisw, _síli, ssgu,
   {{0x7d0d46ea,0x09f680f7,0x3ce9022c,0x78ad675d}},	//   _naas, افية_, _ncav_, ncav,
   {{0x290ddafe,0x6d59c0ff,0xb8cb85fc,0x27ede75e}},	//   rdea_, miwa, _खल_, uten_,
   {{0x6d59b308,0x4439675f,0xfb87af07,0x257c85b9}},	//   liwa, dys_, _рыбн, víli_,
   {{0x7d0d18dc,0xa01b0009,0x6135816a,0x3f9ce760}},	//   _baas, _hyöd, _bált, _divu_,
   {{0x6d599629,0x63a46761,0x10158591,0x6d462f87}},	//   niwa, _puin, _مبتد, uhka,
   {{0x63a41621,0x290007d0,0xd456004a,0x4439206c}},	//   _quin, veia_, утнь, gys_,
   {{0x6d4600f1,0x6d59809c,0x03a30198,0x61ee203c}},	//   shka, hiwa, сиро, ttbl,
   {{0x6d59acb2,0x6135ad83,0xc5d580e8,0x32430e9f}},	//   kiwa, _fált, _сіль, берг,
   {{0x27e00ff9,0x63a46762,0x2bdc0105,0x7d0d0dda}},	//   tuin_, _tuin, _बिपा, _gaas,
   {{0xe8168b9f,0x6d5602a0,0x6d440010,0x29006763}},	// [59e0] तिया_, _imya, _ilia, reia_,
   {{0x06d580ab,0x613c8061,0x60c9810c,0x27e036bc}},	//   ত্রি, _célj, haem, ruin_,
   {{0x2bc68054,0x7d0d6764,0x290003cd,0x6d446657}},	//   रीना, _yaas, peia_, _klia,
   {{0x6d59e765,0xd7d4800f,0x7d0d0079,0x6135807b}},	//   giwa, _दिलच, _xaas, _máls,
   {{0x44269704,0x69ce3b94,0x27e05433,0x9f400198}},	//   uxo_, lsbe, quin_, ttiä_,
   {{0x4426e766,0x6f01911b,0x46a31fd9,0xfbdc66df}},	//   rxo_, jelc, _гарв, _बिनम,
   {{0x6d59c8dc,0x3f9ce767,0x6d44657e,0x26790162}},	//   biwa, _rivu_, _olia, _астэ_,
   {{0x3d0e0d38,0x69ce6768,0x3f9c8009,0x4fd4a345}},	//   ियों_, isbe, _sivu_, ажит,
   {{0x3b868c91,0xddcfe769,0x44396258,0x273b801c}},	//   _благ, _češn, xys_, _kênh_,
   {{0x6d44676a,0x17f78013,0x69ce01eb,0xb1148870}},	//   _alia, ارية_, ksbe, _gụny,
   {{0x6d442ab6,0xb52100ba,0x4439676b,0xab938013}},	//   _blia, यालय_, wys_, _اللغ,
   {{0x443913cd,0x6d440c5e,0x628880eb,0x3ce68619}},	//   tys_, _clia, _izdo, ngov_,
   {{0x61358065,0x799d00dd,0x7d0d10c3,0x69ce1151}},	//   _vált, _risw, _vaas, esbe,
   {{0x4439676c,0x799d4d15,0x7d0d328e,0x6d599f50}},	//   rys_, _sisw, _waas, ziwa,
   {{0x7d0d66f0,0x443f0029,0x613c8065,0x4439676d}},	//   _taas, šu_, _nélk, sys_,
   {{0x6d44654a,0x78ad00d2,0x6288816b,0xeab00019}},	//   _glia, ucav, _mzdo, قعہ_,
   {{0xd6db19dc,0x2bdc150e,0x7d028869,0x78ad676e}},	// [59f0] ете_, _बिया, deos, rcav,
   {{0x78ad61c4,0x248900b9,0x6d599495,0x628889a4}},	//   scav, _izam_, wiwa, _ozdo,
   {{0x78a28699,0x6d59809c,0x539a0039,0xa01b0198}},	//   _ogov, tiwa, _שיתו, _syöd,
   {{0xf8b10bca,0x613c801b,0x61383334,0x637f82df}},	//   _ذکر_, _délk, _sílv, mêni,
   {{0x6d59e76f,0x9f4900f7,0xd0069c2c,0x7bcf2e24}},	//   riwa, ltaí_, _بل_, nscu,
   {{0x39490073,0x6d59e770,0x78a2e771,0x2fcd8699}},	//   lhas_, siwa, _agov, vseg_,
   {{0xdea40077,0x2ba192c7,0x2d87e772,0x6925afaa}},	//   _ایمی, _ओंका, ïnes_, имка,
   {{0x3949156b,0x7c39cbe9,0xb4f98158,0xa3d6064a}},	//   nhas_, pywr, _שפּי, _हिल_,
   {{0x9f490013,0x248900b9,0x657b8726,0xaae78a47}},	//   htaí_, _nzam_, _ikuh, _مساو,
   {{0xff51803f,0x6d446773,0x2d8d808e,0x777701b9}},	//   تخب_, _slia, _hhee_, noxx,
   {{0x6d446774,0x32679155,0x4d661ae2,0x23ab813c}},	//   _plia, _став, иков, _høj_,
   {{0xed5a2d49,0x201930d2,0x2fcd826c,0x69ce03a6}},	//   том_, _orsi_, pseg_, vsbe,
   {{0x5ed000ab,0x6569b70f,0x212d86ec,0x39490387}},	//   স্টে, _mjeh, mjeh_, dhas_,
   {{0x290fe775,0x60c64865,0x9af380fc,0x3ce6d4b5}},	//   _haga_, _sekm, _ƙeƙe_, zgov_,
   {{0x61e38059,0x290f82a3,0x7e7980be,0x637f8187}},	//   nunl, _kaga_, _באַז, gêni,
   {{0x6d5d02be,0x98a31194,0x69ce4189,0x39490cb5}},	//   érat, жите, rsbe, ghas_,
   {{0xb4e20076,0x6f0e0069,0x290fe776,0x69ce189c}},	// [5a00] दली_, _pabc, _maga_, ssbe,
   {{0x290f92cf,0xdce981ac,0x61e3e777,0x69ce1c2b}},	//   _laga_, _cieľ, kunl, psbe,
   {{0x26c7e778,0x60c60353,0x38698125,0x39490083}},	//   _meno_, _tekm, _þarf_, bhas_,
   {{0x39496779,0x2d8d8135,0x290fcaa0,0x2d9f8362}},	//   chas_, _chee_, _naga_, _ciue_,
   {{0x7d02e77a,0xb6a600e8,0xe3af9459,0x7c220118}},	//   reos, _вигл, ورو_, _áord,
   {{0x26c7e77b,0x386080ce,0x68f60114,0xc60c8264}},	//   _neno_, _žiro_, lfyd, ষমতা_,
   {{0x290fe77c,0xf1a38791,0x613ca7c4,0xf8aa103e}},	//   _baga_, орын, _héli, _कलाय,
   {{0x2d8d81bc,0x213f8590,0xb87b026b,0x3940677d}},	//   _ghee_, gkuh_, _abíy, nkis_,
   {{0x8ad6990c,0x290f8a73,0x1ae68364,0x8c438a68}},	//   _نتائ, _daga_, _возм, _дете,
   {{0x61fe035f,0x6618826f,0x26c78353,0xaae0824c}},	//   _oppl, _prvk, _ceno_, _नाटक,
   {{0x290fe77e,0x628881a9,0x2d68011f,0x3333677f}},	//   _faga_, _uzdo, rđen_, _roxx_,
   {{0x78a2803a,0x26c7838a,0x7a1c8493,0x25a06780}},	//   _ugov, _eeno_, _vătă, _ciil_,
   {{0x61fe3bf6,0xcb220b9f,0x2572016b,0x613c8118}},	//   _appl, मांड_, nály_, _néli,
   {{0x2904e781,0x394681c0,0x290fe782,0x0eba876a}},	//   lema_, _hlos_, _zaga_, _руды_,
   {{0x26cc90dd,0x39493249,0x98c714d6,0x7bcf6783}},	//   mado_, thas_, исал, sscu,
   {{0x26cc8510,0x3ce101ab,0xa37b0187,0x39406784}},	//   lado_, _काटे_, drõe, gkis_,
   {{0x6d5d0c0f,0xf0938158,0x613ce785,0x9f4901a8}},	// [5a10] misa, ַנע_, _céli, staí_,
   {{0x6d5d6786,0x26cc8510,0x613c82be,0x20190042}},	//   lisa, nado_, _déli, _vrsi_,
   {{0x3d1c035a,0x2904dae0,0x2b8981ac,0x6569826c}},	//   याचे_, kema_, júca_, _pjeh,
   {{0x26cce787,0x613cbaa1,0x2904e788,0x39406789}},	//   hado_, _féli, jema_, ckis_,
   {{0x26ccbc6e,0x290fe78a,0x29048c53,0x98a9011f}},	//   kado_, _raga_, dema_, njač_,
   {{0x60cd29b2,0xdb040013,0x26cce78b,0xfbb80039}},	//   laam, _stiú, jado_, ספות_,
   {{0x26cc90dd,0x3ce8035a,0xdb042b70,0x45d40705}},	//   dado_, _झाले_, _quié, _морс,
   {{0x61e38214,0x6569829b,0x6b4b0019,0x23ab806a}},	//   runl, _ujeh, _függ, _tøj_,
   {{0x290f87d0,0x2019ce75,0x6d5d678c,0x25a00101}},	//   _vaga_, ísi_, disa, _riil_,
   {{0x26cca602,0xbb8580f7,0x60cd678d,0x98a90b67}},	//   gado_, _الطي, haam, djač_,
   {{0x212d920e,0x63a98010,0x6d5d328e,0x290fd75e}},	//   pjeh_, _huen, fisa, _taga_,
   {{0x6d5d4de9,0x63a9822e,0x60cd04a2,0x200904b9}},	//   gisa, _kuen, jaam, kwai_,
   {{0x814c893f,0xe72e8364,0x60cd02a3,0x517480f7}},	//   _בעאַ, _ее_, daam, _بالأ,
   {{0x98a002a5,0x7fb480d5,0x26cc95c1,0x25a00079}},	//   ljić_, _بلوچ, cado_, _wiil_,
   {{0x6d5d678e,0x25a00bb1,0x5ede0264,0x3940342e}},	//   bisa, _tiil_, ন্ডে, tkis_,
   {{0x6d5d4733,0x6281e78f,0x98a00d11,0x60cd0079}},	//   cisa, _mylo, njić_, gaam,
   {{0x75242c2f,0x7d060009,0x39406790,0x6735011f}},	// [5a20] _iniz, meks, rkis_, _bozj,
   {{0x2bab800f,0xa3ab8b9f,0x32462345,0xdb0e0009}},	//   _चढ़ा, _गढ़_, _геог, äkär,
   {{0x61fe5dcf,0xa75a893f,0x27f26791,0xb8ee00ab}},	//   _uppl, נדער, styn_, _রা_,
   {{0x63a99783,0x26cc8510,0x7d066792,0xeabf80ff}},	//   _buen, zado_, neks, _đùa_,
   {{0x63a99220,0x26ccbc6e,0xdb040046,0x6b46807b}},	//   _cuen, yado_, _stiù, _aðga,
   {{0xf7678288,0x63a9811e,0x26cc8ba3,0x27e012ed}},	//   _را_, _duen, xado_, mrin_,
   {{0x26cc90dd,0x6d5d0dc4,0x2904e793,0x68e994fb}},	//   vado_, yisa, tema_, fged,
   {{0x2be084e5,0x3d18278a,0x63a9be2e,0x7d0604e6}},	//   _निपा, _बोले_, _fuen, jeks,
   {{0x26cc8510,0x290484c4,0x27e0077f,0xe8e0001c}},	//   tado_, rema_, nrin_, _ngọt_,
   {{0x290480f6,0x60cd43ca,0x3ae88077,0x26ca056f}},	//   sema_, zaam, _خبری_, _jebo_,
   {{0x26cc8228,0x6d5d6794,0x877b007c,0xa3e48576}},	//   rado_, tisa, ראיי, पूर_,
   {{0x26cca8d5,0x27e06795,0xdb0284c3,0x26ca01ac}},	//   sado_, krin_, mpoñ, _lebo_,
   {{0x40968307,0xb8968013,0x60cd445d,0x703a8277}},	//   _الشر, _الشع, vaam, _حساس_,
   {{0x26ca03bb,0x6d5d451f,0x27e06796,0x60cd270e}},	//   _nebo_, sisa, drin_, waam,
   {{0x6d5d6797,0x69da003a,0x237e826c,0x6fa219a1}},	//   pisa, šten, _mktj_, _कंजू,
   {{0x8e838013,0x26d81eaa,0x7d060214,0xbcfb0036}},	//   _عليه, _adro_, ceks, fiée,
   {{0x60cd6798,0x58870198,0xddd415d8,0xe894062c}},	// [5a30] raam, сыва, _čašn, зать,
   {{0x60cd6799,0x2b5a0118,0x6b4b0799,0xed5980c3}},	//   saam, _gmpc_, _büge, _smž_,
   {{0x63a98e1b,0x26ca0333,0x6d4b8114,0x6d680118}},	//   _suen, _debo_, thga, _ásaí,
   {{0x63a1a0d9,0x63a99783,0x27e0679a,0xe4cb803d}},	//   _siln, _puen, brin_, ابان_,
   {{0x63a18612,0x25ad00d2,0x63a98548,0xe3b3803d}},	//   _piln, _čelu_, _quen, سرش_,
   {{0x41b58c3e,0x3da72167,0x7ae785e9,0xeb9980af}},	//   осит, _граб, сюдж, шил_,
   {{0x63a18a8e,0x68e98cfa,0xdb008511,0x26c10267}},	//   _viln, tged, _atmó, mbho_,
   {{0x13a7803d,0x63a9cf15,0x628183c1,0x5ede00ab}},	//   _هنری_, _tuen, _vylo, ন্দে,
   {{0xe81c101b,0xfbe086bf,0x68e9e79b,0xbcfb026f}},	//   निया_, _नियम, rged, mnéh,
   {{0xf77187bd,0x7524007d,0x68e9e79c,0xbcfb026f}},	//   باب_, _sniz, sged, lnéh,
   {{0x2bdc12ee,0x27e052c2,0xdced00e1,0xa2ba03dd}},	//   _बिहा, zrin_, _diaľ, ्रस्,
   {{0x2bc6946d,0xc3290051,0xbcfb026f,0x2fdf8668}},	//   रीवा, _בו_, nnéh, prug_,
   {{0x613c8207,0x395fe79d,0x656d09c4,0x66e00032}},	//   _célu, mius_, _djah, _jákà,
   {{0x395fe79e,0x7d06679f,0x394d80a9,0x957d009a}},	//   lius_, seks, lhes_, stąp,
   {{0xfaa32dc1,0xe29a1f64,0x69dc904a,0x7d0643f9}},	//   даро, рав_, _året, peks,
   {{0x2bcf8327,0x27e03d45,0x26ca67a0,0xa2ba016f}},	//   _सौभा, trin_, _sebo_, ्रह्,
   {{0xdb01820f,0xbcfb0a21,0x60cb8019,0x798467a1}},	// [5a40] _cilë, dnéh, _megm, rliw,
   {{0x27e067a2,0x6d49e7a3,0x25e0a23e,0x2b5a01e0}},	//   rrin_, _alea, _किमी_, _umpc_,
   {{0x98a618ba,0x395f8110,0xb87b0174,0x248d83ed}},	//   _мине, kius_, _scít, _azem_,
   {{0x6d49b8d0,0x66e0026b,0x4c86c93f,0x92a6866f}},	//   _clea, _bákà, олев, zyłą,
   {{0xa01b67a4,0x394db727,0x6d498c41,0x26ca00dd}},	//   _szöv, dhes_, _dlea, _tebo_,
   {{0x6d42811b,0x248d826c,0x8c1b0039,0xb33c8609}},	//   skoa, _dzem_, יוני, _biħa,
   {{0x2d800640,0xbcfb1c32,0x6d49c883,0x8fa30d69}},	//   _okie_, bnéh, _flea, _царе,
   {{0x6d498c49,0x394de7a5,0x684080f7,0xa01b0009}},	//   _glea, ghes_, _nádú, _myön,
   {{0xf993078d,0xdb0287f4,0x60cb82a3,0xff0684fa}},	//   ורה_, spoñ, _degm, оянн,
   {{0x656d06cb,0x9abc8609,0x35af0327,0x2d8682f9}},	//   _sjah, _inċo, _जूड़, lloe_,
   {{0x69da001b,0x2bc68701,0xceb301c6,0x3160019d}},	//   átel, रीरा, וית_, kiiz_,
   {{0xd90e80d5,0x394d9706,0x395fe7a6,0x6eba970c}},	//   _شیخ_, ches_, cius_, _श्रु,
   {{0xd7ef80f7,0x69da3e45,0x98a901ac,0xa6d500ab}},	//   _لكن_, štel, tiaľ_, স্টট,
   {{0xada580e1,0x2bdc001b,0x23b08866,0xbcfb4fd4}},	//   _skúš, _बिरा, _màj_, inéi,
   {{0xdb018f33,0x613c8e06,0x656d1d26,0x68fd0362}},	//   _dilè, _félt, _tjah, _pbsd,
   {{0xa3e80072,0x98a901d6,0xed580a2e,0x656d60a2}},	//   मूह_, siaľ_, _мој_, _ujah,
   {{0xbcfb0a21,0x657d3c24,0x2ca901b4,0x27140264}},	// [5a50] vnéh, mosh, _igad_, ঠানো_,
   {{0x657d67a7,0x3ea70aa2,0xa29505e9,0x6d498834}},	//   losh, ønt_, _напі, _slea,
   {{0x6d49e7a8,0xbcfb026f,0xa01b0019,0x63ad4914}},	//   _plea, tnéh, _gyön, _huan,
   {{0x63ad00f6,0x395f8722,0xaae709a7,0x02b3801b}},	//   _kuan, xius_, _اسکو, ँड्न,
   {{0x69d5100b,0xbcfb026f,0x395f8084,0x58840048}},	//   lsze, rnéh, vius_, _жыра,
   {{0x27e909ca,0xbcfb016b,0x248480ee,0x2139008e}},	//   muan_, snéh, _dymm_, _hosh_,
   {{0x395f9b15,0x27e9059f,0x2bd7835a,0x4429802e}},	//   tius_, luan_, _ठिका, ţa_,
   {{0x2bdc000f,0x6d5b8135,0x26000035,0xe0df0176}},	//   _बिला, _umua, _रहती_, _amòz_,
   {{0x395fca82,0x27e967a9,0x68ed0ece,0x657d67aa}},	//   rius_, nuan_, igad, dosh,
   {{0x6738e7ab,0x395f8110,0x2ca967ac,0x69d50019}},	//   _covj, sius_, _agad_, ksze,
   {{0x27e90763,0x656be7ad,0x62852b0e,0xdce98d26}},	//   huan_, ongh, _nyho, _lječ,
   {{0xa3d70063,0x27e967ae,0x656be7af,0x69d5100b}},	//   ाओं_, kuan_, nngh, dsze,
   {{0x63ad1220,0x9fd600c8,0x27e9284c,0x31b18019}},	//   _cuan, _সঙ্গ, juan_, _ház_,
   {{0x27e92f19,0x63ad67b0,0xa026807b,0x2d990fb0}},	//   duan_, _duan, stöð, amse_,
   {{0x6b5004b8,0x62850355,0x3cff826f,0x657d0234}},	//   _lägg, _cyho, _obuv_, bosh,
   {{0x25e0835a,0x68ed67b1,0x55da8158,0x38608503}},	//   _किती_, ggad, _פֿונ, _žiri_,
   {{0x63ad309b,0xb4d80bbc,0x200de7b2,0xb90427bc}},	// [5a60] _guan, ाणी_, nwei_, _नय_,
   {{0x442067b3,0xdce982fd,0x7d1602a3,0xa01b0009}},	//   _iri_, _dječ, _hays, _työn,
   {{0x7d165f46,0x63bbe7b4,0x62850114,0x76419106}},	//   _kays, _atun, _gyho, nyly,
   {{0x8fa61c60,0x27e95e9d,0x6d4662d7,0x92e880ab}},	//   _наме, buan_, nkka, _বসে_,
   {{0x293700be,0x6d460009,0x9f44cbb9,0xb87b046d}},	//   _זאכן_, ikka, sumé_, _adíf,
   {{0x60c401e2,0x656b8013,0x7bc9831d,0x63bb808e}},	//   lbim, angh, _dweu, _dtun,
   {{0xf107823c,0xbcfb0013,0x657d35eb,0x6f08e7b5}},	//   वजूद_, snéi, yosh, vedc,
   {{0x442067b6,0xb6a31317,0x4ddb01c6,0x63bbba07}},	//   _ori_, _числ, _לחלו, _ftun,
   {{0x6738920e,0x4420082e,0xb904cb7c,0x6f088144}},	//   _povj, _nri_, _भए_, tedc,
   {{0x69d53380,0x63ad059c,0x44270104,0xa8570051}},	//   ysze, _ruan, _ăn_, פייה_,
   {{0x442067b7,0x657d67b8,0x63ad67b9,0x27e93315}},	//   _ari_, tosh, _suan, zuan_,
   {{0x27e967ba,0x4420353f,0xd843026f,0x63ad0214}},	//   yuan_, _bri_, ničí_, _puan,
   {{0x63ad213b,0x657d67bb,0x44204a6b,0x9f400388}},	//   _quan, rosh, _cri_, ntió_,
   {{0xdce9920e,0x69d51529,0x442067bc,0x6d460009}},	//   _rječ, tsze, _dri_, akka,
   {{0x4420249f,0xb909801c,0x2bd91344,0xdce98654}},	//   _eri_, _nghề_, _भटका, _sječ,
   {{0x27e967bd,0x6285003e,0x19580a14,0x69d567be}},	//   tuan_, _vyho, пасы_, rsze,
   {{0x6d4d02a3,0x69d50019,0x442067bf,0xf4850180}},	// [5a70] _ilaa, ssze, _gri_, _تاثی,
   {{0x27e967c0,0x2bcf81fe,0x68ed67c1,0xdce982ce}},	//   ruan_, सीफा, sgad, _vječ,
   {{0xfbaf00c8,0x63bb8e20,0x6d4d271e,0x27e932fe}},	//   _কবিত, _stun, _klaa, suan_,
   {{0x27e925ba,0xb4e7ab6c,0x65628115,0x798281bc}},	//   puan_, पले_, gioh, _nkow,
   {{0xe1f18077,0xfc46801c,0x26dc81a1,0x1be9804a}},	//   چسب_, _đích_, _odvo_, ідки_,
   {{0xaabf053f,0x6b50016d,0xdb0983bf,0xb87b026b}},	//   ्रिक, _vägg, _önün, _adíg,
   {{0xa3b409c8,0x60cf67c2,0xe2969577,0x6b4f8366}},	//   _जून_, _kecm, маш_, _nøge,
   {{0xa0a597a1,0x3a3a8106,0x34958196,0x673c8106}},	//   майд, äppa_, _жабр, örjn,
   {{0x24c500ab,0x63bb8435,0xaabf1a4d,0x7d1640ac}},	//   ্লাহ, _utun, ्राक, _rays,
   {{0x6d4d67c3,0xf8aa073c,0x6b4f813c,0xe8aa03db}},	//   _alaa, _कल्प, _bøge, _कल्च,
   {{0x7529825b,0x6d4d000b,0xfce601a4,0x6ad380ab}},	//   _knez, _blaa, моно, _সাপো,
   {{0x44202007,0xb4d8035a,0x9f400511,0x6d4d000b}},	//   _pri_, ाणे_, rrié_, _claa,
   {{0x6b5000f2,0x6d460009,0x753b8118,0x6b4b02f1}},	//   _läge, rkka, _mouz, _süga,
   {{0x889a8039,0x753b83a8,0x7989e7c4,0x06e300ab}},	//   _ובני, _louz, llew, ন্তি,
   {{0x03a32d94,0x6d4d019d,0x26c5de46,0xbcfb0388}},	//   тиро, _flaa, mblo_, mién,
   {{0x316d82be,0xbcfb0144,0x6d4d0bfd,0x61e10061}},	//   nnez_, lién, _glaa, álla,
   {{0x442067c5,0xbf8a801c,0x60c467c6,0x7d0bb1a7}},	// [5a80] _uri_, _đoạn_, rbim, degs,
   {{0x7529b219,0xbcfb0020,0x6d4d026c,0x60c400b9}},	//   _anez, nién, _zlaa, sbim,
   {{0x753ba519,0x2be08105,0x6b500106,0xe29a2d34}},	//   _bouz, _निहा, _vägd, _фан_,
   {{0x25e08063,0xe8df801c,0x2fc01c2b,0x448a93f1}},	//   _किसी_, _trộm_, ppig_, обен_,
   {{0x753bae07,0xa2a09513,0x32058122,0x3d00016f}},	//   _douz, गेन्, _aply_, ष्ये_,
   {{0x9f401099,0x629c816b,0x316d811b,0x7989804f}},	//   rtió_, _úrok, enez_, elew,
   {{0x9f40009f,0xbcfb0333,0xdb00bede,0xdee32cab}},	//   stió_, dién, _rumä, _јоси,
   {{0xd1308013,0x316d80e7,0x673c0079,0xa8149294}},	//   امة_, gnez_, _horj, едиш,
   {{0x6b4f8022,0x673c1bf3,0x36d48a7c,0x61ea8162}},	//   _søge, _korj, нопр, sufl,
   {{0x6d4d10f4,0xeeeb001c,0x99898668,0x4b269a43}},	//   _slaa, _đừng_, ćaš_, _تعرف,
   {{0x6d4d2464,0x673c0353,0x7989a71d,0x6aba810c}},	//   _plaa, _morj, blew, _iftf,
   {{0xc866ac18,0x69d8e7c7,0xe3c701df,0xc5f880eb}},	//   _отли, msve, íños_, rtē_,
   {{0x63a8b3f8,0x69d8a20d,0x6d4d038e,0x7bc2e7c8}},	//   _kidn, lsve, _vlaa, npou,
   {{0xbcfb06a5,0x29020326,0x673c0198,0x69d8b804}},	//   cién, _abka_, _norj, osve,
   {{0x63a88079,0xe81684c5,0x442d0087,0xd13b30be}},	//   _midn, तिका_, ţe_, оха_,
   {{0x69d8e650,0x6d4d5259,0x5ec800ab,0xd90f004e}},	//   isve, _ulaa, _লাগে, جیح_,
   {{0x6b5004b8,0xb8e70076,0x2be085fc,0x753be7c9}},	// [5a90] _säge, _उभ_, _निषा, _rouz,
   {{0x7529e7ca,0x753be7cb,0xa91d8796,0x3d00016f}},	//   _snez, _souz, može, ष्ठे_,
   {{0xa91da8ee,0x753b800d,0x7d0b8019,0x25a967cc}},	//   lože, _pouz, tegs, _kial_,
   {{0x2be085e8,0x23e08076,0x6b502fc8,0x656f1581}},	//   _निशा, _निशद, _väge, nnch,
   {{0x7bc4802e,0x7d0b8412,0x656f67cd,0x29190162}},	//   ţiun, regs, inch, _iasa_,
   {{0xb3e085b3,0xfbe084e5,0x98af8063,0x2919022e}},	//   _निरख, _निरम, _mogą_, _hasa_,
   {{0x291903c3,0x2369803a,0x2006802e,0x4b380039}},	//   _kasa_, đaj_, _apoi_, ורגל_,
   {{0x3949189e,0x5694153d,0x291914e5,0x2d788904}},	//   nkas_, _раст, _jasa_, včeg_,
   {{0x291967ce,0x2d8b67cf,0x2489022c,0xbcfb01ca}},	//   _masa_, dlce_, _nyam_, tién,
   {{0x291967d0,0x656f0073,0xa91d8289,0x27e2816b}},	//   _lasa_, ench, dože, ákna_,
   {{0x2489059c,0x2b898038,0x8d6622f1,0x62889adf}},	//   _ayam_, júci_, евне, _gydo,
   {{0x92c100c8,0x63a8811f,0x2d8400e7,0xdb018c1d}},	//   ুলো_, _zidn, ôme_, _milí,
   {{0xf992812a,0x66f02296,0x394911fe,0x2ca40106}},	//   _ערד_, _चालक_, dkas_, ämd_,
   {{0x212b0081,0x883a8039,0xa91da6d5,0x29195064}},	//   _anch_, _מתנו, sožd, _aasa_,
   {{0x291903f8,0xdb0f01a8,0xbcfb12ab,0x27ed8cdb}},	//   _basa_, ádái, gnés, luen_,
   {{0x61358019,0xa91d816b,0x386d026c,0xa3c186a7}},	//   _pály, bože, _žera_, ूठा_,
   {{0xd0070fbe,0xc72601e5,0x25bf005c,0x27ede7d1}},	// [5aa0] нете_, ндай, _čula_, nuen_,
   {{0xe1fa025d,0x80ac05b3,0x656667d2,0x2d823ad5}},	//   _его_, _झलके, likh, loke_,
   {{0x291905a3,0x644667d3,0x63a883e2,0x394937a5}},	//   _fasa_, lyki, _ridn, bkas_,
   {{0x394967d4,0x3a25013c,0x291967d5,0x41bb0039}},	//   ckas_, ælpe_, _gasa_, _מצטע,
   {{0x60d60637,0x66150019,0x7d0467d6,0x9cd701c6}},	//   maym, _eszk, _mbis, תונה_,
   {{0x69d8d7d8,0x60d630ac,0x27ed8cdb,0xdb01e7d7}},	//   tsve, laym, duen_, _filí,
   {{0x7d0467d8,0xfce6a46b,0x63a8e7d9,0x29193376}},	//   _obis, _пово, _vidn, _yasa_,
   {{0x7afb0025,0x63a8ab30,0x69d88f2c,0xeeeb001c}},	//   đuti, _widn, rsve, _đứng_,
   {{0x63a880f2,0x27edafe5,0x25a96026,0x2d823516}},	//   _tidn, guen_, _rial_, doke_,
   {{0xd6da88cc,0x4424c0a7,0x7d0467da,0xd130803d}},	//   чти_, _irm_, _abis, امک_,
   {{0x24890359,0xa3d31905,0x7c245dfd,0xfd4d8135}},	//   _syam_, हीन_, _arir, _nghọ,
   {{0xb4eb090a,0xeabf8129,0xa91d82d4,0x442488dc}},	//   मले_, _đùi_, tože, _krm_,
   {{0x291904aa,0xfd4d8135,0xf74681a4,0x9abc8197}},	//   _rasa_, _aghọ, _педо, _anċi,
   {{0x291900f6,0x7d0402ec,0x61e10061,0x7986022b}},	//   _sasa_, _ebis, állo, _akkw,
   {{0xb9e4035f,0x2d8267db,0xa01b0009,0x7c241292}},	//   літи, boke_, _työk, _erir,
   {{0xf99300f7,0x4424808c,0xa91d82a5,0xfc46801c}},	//   ابس_, _orm_, pože, _đính_,
   {{0xd3a72c87,0xb8d9278a,0x39490288,0x7a138201}},	// [5ab0] _проп, _चल_, rkas_, _vətə,
   {{0x394967dc,0x291900a4,0x7d1d00b2,0xb87b002a}},	//   skas_, _wasa_, ldss, _adíc,
   {{0x291967dd,0x26d10988,0x3f810168,0x27ed811b}},	//   _tasa_, _vezo_, rohu_, zuen_,
   {{0x7d1d2445,0x59b61834,0x442481a1,0xbc68004e}},	//   ndss, _आंतर, _brm_, _آمین_,
   {{0x7d1d1377,0x752d0c53,0x8d749459,0x53e09a4d}},	//   idss, _mnaz, دالا, _निःश,
   {{0x798d5259,0x8c4291d5,0x6566005d,0x04428073}},	//   llaw, реше, zikh, решн,
   {{0x7bd99770,0x69da0353,0x5694344f,0x6b5028c0}},	//   sswu, štev, _барт, _jäga,
   {{0x27ed80ad,0x7d1d2b36,0x8afe80fc,0x752d03f7}},	//   tuen_, jdss, riƙa, _nnaz,
   {{0x5b159a1f,0x2d821315,0x27e967de,0xa91d807a}},	//   _имат, voke_, nran_, tožb,
   {{0x27e94558,0x7d1b8788,0x27edb85d,0x752d3074}},	//   iran_, _haus, ruen_, _anaz,
   {{0x27e9198f,0x6b83840c,0x7d1be7df,0x65663efe}},	//   hran_, mong, _kaus, tikh,
   {{0x25e91344,0x644629d9,0x7d1be7e0,0xaa6499bb}},	//   _चटनी_, tyki, _jaus, _стук,
   {{0x2d8267e1,0x27ede7e2,0x7d1be7e3,0x798d01e0}},	//   roke_, quen_, _maus, dlaw,
   {{0x2d8267e4,0x7d1be7e5,0x6b83e7e6,0x27e967e7}},	//   soke_, _laus, nong, dran_,
   {{0x27e9212d,0x798d0114,0xdb0888f9,0x2d820db1}},	//   eran_, flaw, _didè, poke_,
   {{0x7d04298e,0x6b83e7e8,0x0c2635ed,0x27e967e9}},	//   _ubis, hong, _амин, fran_,
   {{0xa0671a1f,0x18674bc4,0x68431273,0x6b83e7ea}},	// [5ac0] вата_, вати_, анта, kong,
   {{0x6b83a4f4,0x998d003a,0x7986008e,0x03a61630}},	//   jong, ćeš_, _wkkw, _шипо,
   {{0x7d1bc12f,0x6b83e7eb,0xf2d30bea,0x27e967ec}},	//   _baus, dong, _דעת_, aran_,
   {{0xfce69bbf,0x44248abf,0x69de824a,0xdb0083ba}},	//   тодо, _prm_, špek, _humø,
   {{0x7d1be458,0x3f8c808b,0x69dc1de6,0x6d988144}},	//   _daus, yldu_, lsre, víad,
   {{0x6b83b4d8,0xf8bf010c,0xf41301c6,0x232785d3}},	//   gong, _anéh_, יפד_, кочи_,
   {{0xd24f880b,0x69dc0ed0,0x672e0106,0xbebc80eb}},	//   ينه_, nsre, _inbj, ldīg,
   {{0xdce2803a,0x7d1baf7e,0x60c98b4e,0x6f1c67ed}},	//   dnoć, _gaus, gbem, _harc,
   {{0x6d408ad0,0x6b838d48,0xdef884b7,0xdca390ef}},	//   _ioma, bong, liċi_, _вати,
   {{0x7d1b8025,0xa2c186bf,0x656467ee,0x6b83e7ef}},	//   _zaus, रुद्, _amih, cong,
   {{0x13d780ab,0x69dc0289,0xa4d50221,0xd00b00ab}},	//   _সময়, jsre, лоні, রিয়_,
   {{0xb4bf01b6,0x27e967f0,0x670203eb,0x6f1c107c}},	//   ेरे_, yran_, र्तक_, _larc,
   {{0x6d40e7f1,0x201880eb,0xa3b88105,0x18369a3e}},	//   _moma, āris_, _घूम_, _جراح,
   {{0x52bf000c,0x36d48d40,0x6d40e7f2,0x2bb50035}},	//   ्रेस, _сокр, _loma, ंदबा,
   {{0x25bf0289,0x96f7830f,0x27e93c6e,0x6d408df6}},	//   _čulo_, _شعور_, wran_, _ooma,
   {{0x6d40e7f3,0x44f567f4,0x6b5004fd,0x6b839a0e}},	//   _noma, _спис, _väga, zong,
   {{0x6f1c023e,0x9b450bca,0x6b8381d3,0x798d0590}},	// [5ad0] _barc, _منظو, yong, rlaw,
   {{0x5b150364,0x27e967f5,0x7d1b9247,0x7c228140}},	//   _смот, rran_, _saus, dvor,
   {{0x3ea700f2,0x2367842b,0x6b838176,0x6d40e7f6}},	//   änt_, vinj_, vong, _boma,
   {{0x6d40e7f7,0x68e2e7f8,0x6b83e7f9,0x69c767fa}},	//   _coma, _ndod, wong, mpje,
   {{0x6f1c67fb,0xdfc6880b,0x2bdc0beb,0x6b4f8aa2}},	//   _farc, _دي_, _बिछा, _døgn,
   {{0x6f1c0333,0x68e2e7fc,0x7bdd67fd,0x6d408609}},	//   _garc, _adod, issu, _eoma,
   {{0xa3d3035a,0x3da7c8ac,0x6d408242,0x6a8597ae}},	//   हीत_, _араб, _foma, ылка,
   {{0x6d40ae08,0x6b83e7fe,0x6f1c67ff,0x3169011b}},	//   _goma, song, _zarc, niaz_,
   {{0xa3e0800d,0x6b83e800,0x2367cf57,0x6b548091}},	//   _थिए_, pong, pinj_, _dàgb,
   {{0xee398951,0xdb018118,0x6d40a8c8,0xdce2876c}},	//   ено_, _filá, _zoma, tnoć,
   {{0xf8d30076,0x8c4287d9,0x9d460d8f,0x7bdf3c5a}},	//   तराय, _öğre, генд, _avqu,
   {{0x69dc0aa2,0x6d880144,0xbc1a0048,0xdce280fe}},	//   vsre, eñar, нігі_, rnoć,
   {{0x2d8f8307,0xdce2805c,0xafe581e5,0x27e981df}},	//   ilge_, snoć, _солл, _ían_,
   {{0x291da0c5,0xf8bf0091,0x69dc189c,0x291f811b}},	//   _hawa_, _afé_, tsre, ldua_,
   {{0x291de801,0x20190211,0x7bdd0037,0xdea1853d}},	//   _kawa_, _assi_, assu, _دیدی,
   {{0xdb08e802,0x291d8854,0x291f847c,0x394d955f}},	//   _vidé, _jawa_, ndua_, nkes_,
   {{0x6d40a4f5,0x27ffe803,0x291d803d,0x248d81c5}},	// [5ae0] _roma, ntun_, _mawa_, _nyem_,
   {{0x6d40e804,0x6b4f813c,0x291dc8ce,0xdef881b9}},	//   _soma, _søgn, _lawa_, tiċi_,
   {{0x25adca38,0x6ce68048,0x20190081,0x394d8257}},	//   _biel_, гіле, _essi_, kkes_,
   {{0x7c22e805,0x6f1c297a,0x25ad80e7,0x6d4086cb}},	//   tvor, _warc, _ciel_, _qoma,
   {{0x0b8a80c4,0x938a9e16,0x3f8584b7,0x25ade806}},	//   нски_, нска_, kolu_, _diel_,
   {{0x2bb7000f,0x7c228223,0x2912112e,0x6d40e807}},	//   _इंसा, rvor, leya_, _woma,
   {{0x2be080ba,0x2741800d,0x39422d77,0x3f85e808}},	//   _निका, _méně_, _koks_, dolu_,
   {{0xdb018065,0x21204ba7,0xdca68d9e,0x25ad9c2b}},	//   _vilá, ndih_, _баби, _giel_,
   {{0x20006809,0xcaf69baf,0x291db298,0x2d680019}},	//   ntii_, _مساب, _dawa_, tően_,
   {{0xade58424,0x25adca03,0x3f859c88,0x26da680a}},	//   _किशन_, _ziel_, golu_, napo_,
   {{0xd5b78364,0xa37b0073,0x1d35222c,0x64400009}},	//   лся_, nsõe, ання, ämin,
   {{0xc27b8451,0xa91de80b,0x291de80c,0x2b4100dd}},	//   _ארבי, ložn, _gawa_, _sohc_,
   {{0xfd1f0098,0x7bdd00e7,0x6fb00105,0x67d48087}},	//   rdì_, ussu, _अंगू, _толу,
   {{0x77f78051,0x6b4f806a,0xae050006,0x909780e8}},	//   _עמוד_, _nøgl, _रहलन_, _світ_,
   {{0x31c4085f,0xf993019f,0x291db31c,0xa14381a9}},	//   йств, مبر_, _yawa_, _šķir,
   {{0x2019061b,0x69c700f1,0x386982d4,0x9f520198}},	//   _pssi_, rpje, _žari_, htyä_,
   {{0x69c7680d,0xc05b00e8,0xbebc81a9,0x31690cdb}},	// [5af0] spje, хів_, mdīb, riaz_,
   {{0xbebc8029,0x7a0a8201,0x2bcf9513,0x25ade80e}},	//   ldīb, _mətb, _सौगा, _siel_,
   {{0xc3320159,0x69da011f,0x25ade80f,0xcf938158}},	//   _ווי_, šter, _piel_, צטע_,
   {{0x69c56810,0x20190282,0x44296811,0x200001b4}},	//   _ithe, _tssi_, _kra_, btii_,
   {{0x7d1f4636,0x291dc413,0x25adc15a,0x26da022e}},	//   _maqs, _rawa_, _viel_, bapo_,
   {{0x69c500f1,0x291db059,0x03a5a1f2,0xdcfbb70f}},	//   _kthe, _sawa_, шило, _okuć,
   {{0x25ade2c6,0xba77803d,0x44296812,0x2d7880c3}},	//   _tiel_, داشت, _lra_, mčen_,
   {{0x44296813,0x6d98802a,0x27ffe814,0x6009ae9f}},	//   _ora_, ríac, ttun_, вним_,
   {{0x3f858964,0x656bbe34,0x394d91b4,0xa91d85f3}},	//   tolu_, migh, rkes_, božn,
   {{0x69c5004c,0x753d0063,0x394d99fa,0x7c29e815}},	//   _othe, ejsz, skes_, _irer,
   {{0x44293fef,0x644bb4c6,0x27ffda1d,0x7bc42d7d}},	//   _ara_, lygi, stun_, _stiu,
   {{0x44291c66,0xe1f0803f,0x6e210510,0x3f85aed6}},	//   _bra_, _رسم_, _álbu, solu_,
   {{0xf7708fd3,0x7d09e816,0x998480f7,0x69c50e5a}},	//   _کان_, _mbes, _النو, _athe,
   {{0x44296817,0x60dbaf25,0xbea5a118,0x656be818}},	//   _dra_, laum, _калк, high,
   {{0x29d38012,0xc5d5835f,0x44294ccd,0xfaa61269}},	//   nţa_, _тіль, _era_, раво,
   {{0x44291f65,0x92d600c8,0x90c60a41,0x1c461cf4}},	//   _fra_, হলে_, рбае, _вним,
   {{0x656ba802,0x657d0019,0x29124357,0x44296819}},	// [5b00] digh, érhe, reya_, _gra_,
   {{0x2000681a,0x7d09cc58,0x7f43e81b,0x27edb3b8}},	//   rtii_, _abes, _jonq, iren_,
   {{0x27ed8352,0x2000681c,0x26da3eb4,0x67020aed}},	//   hren_, stii_, rapo_, र्षक_,
   {{0x44290a8e,0x0c2689b0,0xa37b0187,0xe7ef016f}},	//   _yra_, имен, rsõe, _चमचा_,
   {{0x4ada18b8,0xa37b03a7,0x9f520009,0x6b4b0074}},	//   _बजाव, ssõe, ttyä_, _sügi,
   {{0x27e0681d,0x27ede81e,0x7d09836a,0x69dc804a}},	//   msin_, dren_, _ebes, _ærek,
   {{0x6d560065,0x27ede81f,0x27e005b2,0x7c2991d3}},	//   _olya, eren_, lsin_, _erer,
   {{0xa01b0009,0x6d59e820,0xdb1600ff,0xf1269d1f}},	//   _työt, chwa, _quyê, рько,
   {{0x27e06821,0xdce98499,0x27ede822,0x06da80ab}},	//   nsin_, _sjeć, gren_, _দাবি,
   {{0x27e0347f,0x6d561061,0x26d800d7,0x44294cc0}},	//   isin_, _alya, _jero_, _rra_,
   {{0xe8fae823,0x27e0083a,0x27ed9d94,0xdb16001c}},	//   _але_, hsin_, aren_, _tuyê,
   {{0x44296824,0x99758364,0xa2ca8894,0x69ca82af}},	//   _pra_, _лучш, _स्त्, mpfe,
   {{0xae438077,0x69c5148f,0x442680b9,0x6b5001ec}},	//   مپیو, _sthe, nvo_, _tägl,
   {{0x656be825,0x4429079f,0x4426c6f0,0x83870048}},	//   zigh, _vra_, ivo_, рыме,
   {{0xa3b88768,0xdcfb8289,0x7d1f01b9,0x99671b56}},	//   _घूस_, _ukuć, _taqs, атал,
   {{0x44296826,0x4426803a,0x6d446827,0x5d843df2}},	//   _tra_, kvo_, _goia, _ولول,
   {{0xd6db0073,0x60cd6828,0x26d83e1b,0x61ee55d0}},	// [5b10] вте_, rbam, _bero_, arbl,
   {{0x26d805e4,0xbf0201a2,0x2be0800c,0x2d788267}},	//   _cero_, र्लभ_, _निजा, učen_,
   {{0x6d59e829,0x69c5682a,0x4426847f,0xa3d30072}},	//   thwa, _uthe, evo_, हीर_,
   {{0xa2cb0076,0x27ede82b,0x6d4403a8,0x27e0682c}},	//   _त्त्, yren_, _xoia, bsin_,
   {{0x26d8682d,0x442982ba,0x2fc68282,0x27e05675}},	//   _fero_, ía_, _ntog_, csin_,
   {{0x67d4091c,0x6d59e516,0x26d8311f,0xa3e88054}},	//   _фору, shwa, _gero_, _मटर_,
   {{0x21698544,0xa9699935,0x25b8448b,0xa01b15c8}},	//   лики_, лика_, _gurl_, _työs,
   {{0xc692093f,0x27ede82e,0x7d09e82f,0x991580e8}},	//   _זאל_, tren_, _ubes, ські,
   {{0x6569ad15,0x27eda64a,0x60db8e20,0x26d86830}},	//   _imeh, uren_, raum, _yero_,
   {{0x27ed80ad,0x26c10207,0x75209a83,0x33330118}},	//   rren_, ncho_, _zamz, _nnxx_,
   {{0x22958307,0xe81c8105,0xb87b001b,0xaa9580f7}},	//   _الاس, _बैठा_, _sdíl, _الاث,
   {{0x05561056,0x27e00009,0x27ede831,0x8d562850}},	//   стоя, ysin_, pren_, сточ,
   {{0x6c7980be,0xdb0d0144,0x65698870,0x7f43e832}},	//   ראָפ, _atañ, _mmeh, _tonq,
   {{0x66018713,0x2be0816f,0x61f5029a,0x316d9139}},	//   ptlk, _निघा, fuzl, liez_,
   {{0x450d00c8,0x26d80578,0x44269dc1,0xfbd200d5}},	//   ষয়ক_, _rero_, zvo_, _کتب_,
   {{0xf99f6833,0x27e06834,0x26d86835,0x31bc0019}},	//   _chè_, tsin_, _sero_, _víz_,
   {{0x26d86836,0x61431a3b,0x41270698,0x442626ca}},	// [5b20] _pero_, чета, щото_, _éo_,
   {{0x27e05bf6,0xa01b0009,0x7989874c,0x6569a0fd}},	//   rsin_, _pyör, hoew, _ameh,
   {{0x27e039a8,0x26d86837,0x14c8803d,0x869a0087}},	//   ssin_, _vero_, لهای_, утат_,
   {{0x44268ed6,0xdb08826f,0xb5fa80be,0xd5fa80be}},	//   tvo_, _vidí, טלעכ, טפער,
   {{0x2a6e026c,0x307501a1,0x6d988118,0x75208084}},	//   _žfbh_, _дурс, bían, _vamz,
   {{0x8c1b0039,0x2d8d81bc,0x6d9883a8,0xa3da064a}},	//   טוני, _ekee_, cían, डीय_,
   {{0x316d80e7,0x201d810c,0x9f5f8036,0x6d9d0174}},	//   fiez_, _aswi_, ctué_, néac,
   {{0x657b820f,0xa517035a,0xa3d82d92,0x394000b9}},	//   _gjuh, _तसेच_, ाठा_, njis_,
   {{0x25bf0052,0x64a7016f,0x38606838,0xeafa80f7}},	//   _čuli_, _गणेश, nzir_, _مرات_,
   {{0xdbd4256c,0xa91d8088,0xb35680d5,0x161d001b}},	//   _núñe, nožj, _دیتا_, फिचर_,
   {{0xab5b07d0,0xb0b806ae,0x00000000,0x00000000}},	//   nqüe, _अलंग, --, --,
   {{0x9f470a56,0x316de839,0x386000b9,0x06971101}},	//   čné_, ciez_, kzir_, מדים_,
   {{0xa3d30665,0x589680d5,0x25a0683a,0x06e300ab}},	//   हीं_, _اجاز, _dhil_, ন্টি,
   {{0x39468079,0x661c806a,0x386000dd,0x0eba8e11}},	//   _hoos_, ærks, dzir_, _суды_,
   {{0xe5c696d4,0x26de9ab6,0x3946e83b,0x6d988511}},	//   _усло, mato_, _koos_, vían,
   {{0x26dee83c,0x25a02630,0x7a0a811c,0x3946a580}},	//   lato_, _ghil_, _xəta, _joos_,
   {{0x39468069,0x656f683d,0x26c102d6,0x7d0d20f9}},	// [5b30] _moos_, mich, tcho_, _ibas,
   {{0x656f683e,0x26de8dff,0x2d8b0081,0x26c1683f}},	//   lich, nato_, loce_, ucho_,
   {{0x6d98b367,0x26c16840,0x21220326,0xf99f2e93}},	//   rían, rcho_, _fakh_, _thè_,
   {{0x656f6841,0xbcfb03d3,0x2d8b3680,0x7ae8e842}},	//   nich, ciét, noce_, _addt,
   {{0x26deb2db,0x7d0d6843,0xbcfb6844,0xdce601a9}},	//   kato_, _mbas, liés, nikā,
   {{0x656f6845,0xbcfb0019,0xdea4004e,0x752801a9}},	//   hich, gnéz, _کیمی, ēdzi,
   {{0x9f490307,0x7d0d6846,0x656f6847,0x39468f1a}},	//   nraí_, _obas, kich, _boos_,
   {{0x7c2d6848,0x3946e849,0x656f684a,0x57e9a35b}},	//   _orar, _coos_, jich, адим_,
   {{0x5fe2101c,0xa91d803e,0xf8ae8077,0x3946e84b}},	//   _पिछल, ložk, نکه_, _doos_,
   {{0x7d0d2948,0x442d91d3,0x26dee84c,0x8e099f8c}},	//   _abas, _ire_, gato_, анов_,
   {{0xb8ff80c8,0x656f684d,0x6e459982,0xe8d90a2c}},	//   _তা_, fich, ценз, ghị_,
   {{0xdb0d0125,0x63bbdd7b,0x656f684e,0xdce600eb}},	//   _stað, _kuun, gich, fikā,
   {{0x26dee84f,0x66e58ff7,0xbcfb3aef,0x63bb8074}},	//   bato_, _дола, viét, _juun,
   {{0x26de8698,0x63bbaf51,0x78130105,0x7d0d0074}},	//   cato_, _muun, डबैक_, _ebas,
   {{0x9f4900f7,0x6d5d032f,0xed5a20e1,0xa01b0198}},	//   graí_, bhsa, _вой_, _syöp,
   {{0x442d9429,0x68fbe850,0x656f002a,0x3cff81c0}},	//   _ore_, ngud, cich, _ncuv_,
   {{0x6723829b,0x442de851,0xbcfb080d,0xdbd4002a}},	// [5b40] _kanj, _nre_, riét, _túñe,
   {{0x44206852,0x672384bf,0x75246853,0xb3580065}},	//   _isi_, _janj, _haiz, _ایسا_,
   {{0x6723afa4,0x442d873a,0xe61a4543,0xbcfb03b0}},	//   _manj, _are_, рде_, miér,
   {{0x67238867,0x442da051,0x629e0353,0xa01b0009}},	//   _lanj, _bre_, _izpo, _työp,
   {{0x3946e854,0x442dae5a,0x25a6ade0,0x752459ea}},	//   _roos_, _cre_, rmol_, _maiz,
   {{0x394684df,0x442da569,0x656f6855,0x60c4025b}},	//   _soos_, _dre_, zich, lcim,
   {{0x442de856,0x26de8698,0x3946b79f,0x2d78875f}},	//   _ere_, vato_, _poos_, nček_,
   {{0x44206042,0xdb088acf,0x442d9faf,0x26de985b}},	//   _osi_, _didá, _fre_, wato_,
   {{0x6723e857,0xb4e6a13e,0x442d8db7,0x656f1b03}},	//   _banj, पणी_, _gre_, vich,
   {{0x656f0e83,0x68fbe0ad,0x672384b9,0x10370039}},	//   wich, agud, _canj, קטים_,
   {{0x26dee858,0x656f6859,0x6723a598,0xdd9501bb}},	//   rato_, tich, _danj, заны,
   {{0x26dee85a,0x60c4012b,0xe7f38072,0x6d42e85b}},	//   sato_, jcim, _आमचा_, njoa,
   {{0x656f685c,0x26dee85d,0x6d988388,0xaade881f}},	//   rich, pato_, víal, _नजाक,
   {{0x656f685e,0x68e0e85f,0x7c2d0168,0x6d989e31}},	//   sich, lamd, _vrar, díam,
   {{0x44206860,0x752428fa,0xf96b0b69,0x3f8ce861}},	//   _esi_, _faiz, арай_, modu_,
   {{0x9f490013,0xd1380470,0x7c2d411c,0x4cd500ab}},	//   rraí_, оху_, _trar, _থাকু,
   {{0x656d043b,0x7c2d1caa,0x6723e862,0x27f22dfb}},	// [5b50] _imah, _urar, _yanj, gryn_,
   {{0x4e1e8996,0x68e09067,0x442de863,0x75240102}},	//   _बनाई_, hamd, _rre_, _zaiz,
   {{0x63bb83ff,0x7bc99ab8,0x442d8b89,0x672500f1}},	//   _suun, _steu, _sre_, rdhj,
   {{0x442de864,0x3f8cc8a9,0x26dc84c4,0x6d98a790}},	//   _pre_, hodu_, _levo_, bíam,
   {{0x9f400876,0xdb0405e4,0xbcfb00e7,0x6d98818a}},	//   guió_, _guió, chée, cíam,
   {{0x442d8247,0x656d0122,0x777a81c0,0x67ba01c6}},	//   _vre_, _lmah, jntx, _למשק,
   {{0x7de00065,0x56946446,0x656d003d,0x7c26a4c8}},	//   _vásá, _жарт, _omah, _škrt,
   {{0x442dadc2,0x627c012a,0x60dd0668,0xceba80fc}},	//   _tre_, ינונ, _jesm, _baƙo_,
   {{0x60dd156b,0x442de865,0x67238d54,0x6d5b83ca}},	//   _mesm, _ure_, _panj, _ilua,
   {{0xf8b8150e,0x656d01d4,0x60dd5e33,0x6d5b81e9}},	//   _अल्प, _amah, _lesm, _hlua,
   {{0x6723e866,0x44206867,0x26dca3a4,0x6d5b8590}},	//   _vanj, _ssi_, _devo_, _klua,
   {{0x7d19e868,0x670b19eb,0x60dd3937,0x070b2774}},	//   news, स्तक_, _nesm, स्तव_,
   {{0x6723e869,0x752401e2,0x60c4005c,0xbcfb157a}},	//   _tanj, _vaiz, vcim, tiér,
   {{0x44200db7,0x8ccc06ab,0x656d01f6,0xef1881a9}},	//   _vsi_, _थ्रो, _emah, ceļ_,
   {{0xbcfb003e,0xb87b0264,0x60c40669,0x6d9d40a2}},	//   riér, _leíd, tcim, méan,
   {{0x442001e9,0x629e3eeb,0x21675190,0xa96703bc}},	//   _tsi_, _vzpo, писи_, писа_,
   {{0xb4d81094,0x44202678,0x1dd78105,0x46ea0cf9}},	// [5b60] िरी_, _usi_, भीरत, йдан_,
   {{0xf7721ecd,0x60c41577,0xd7ef00f7,0xc2ea0065}},	//   راء_, scim, اكل_, _اعظم_,
   {{0x60c4005c,0x7abb0039,0x395f816d,0x9cca8fe6}},	//   pcim, _לציו, khus_, была_,
   {{0x6d5b832f,0xb4e6816f,0x60dd074c,0xeeeb00ff}},	//   _clua, पणे_, _gesm, _đụng_,
   {{0x395fe86a,0x6d5bccbe,0x6d428009,0x29e80713}},	//   dhus_, _dlua, rjoa, lğa_,
   {{0xa09b03de,0x670300a5,0x6d5b82f1,0xa2948a4c}},	//   _ליכט, _लायक_, _elua, малі,
   {{0x3f8ca1d1,0x3ce2017f,0xc7a30087,0xceba89ab}},	//   vodu_, kakv_, _чирк, _saƙo_,
   {{0x6d5b808c,0xdb0401df,0x3f8c809a,0x6d498197}},	//   _glua, _muiñ, wodu_, _goea,
   {{0x68e082b8,0xb4ca8f97,0x36d4bf61,0x3f8ce86b}},	//   ramd, ोरी_, мопр, todu_,
   {{0x3eb88bc5,0xe29281a8,0x23a40338,0x2d83128a}},	//   ørt_, _كذا_, nöjd_, čkem_,
   {{0xe7e88074,0xd6d78198,0x7a0a829a,0x00000000}},	//   _टटका_, чты_, _xətl, --,
   {{0x395fe86c,0xd5b78198,0x23a40338,0x6ecc8bbc}},	//   chus_, ясь_, höjd_, _द्रु,
   {{0x60dd686d,0x1b1f80ab,0x8ca48035,0x2d800176}},	//   _resm, পারে_, _औरफो, _djie_,
   {{0xda20816f,0x2fcb0267,0xa91d976d,0x7c2d8085}},	//   _मनात_, _rtcg_, voži, çirə,
   {{0x60dd1108,0x6e93d532,0xdb04002a,0x62340087}},	//   _pesm, _пишу, _cuiñ, неру,
   {{0x9f4703bb,0xf67b8039,0x656d13fa,0xa3da06a7}},	//   ční_, _לאומ, _umah, डीह_,
   {{0xb8d503eb,0x60dd1e51,0x81bc81a9,0x57b531ad}},	// [5b70] _छः_, _vesm, _krēs, дбат,
   {{0xb8f4023c,0x657d2651,0x64d581cb,0x6d5b8c49}},	//   _स्_, lnsh, दर्श, _slua,
   {{0x6d5b8069,0x6d5a8110,0xdb040333,0x0ea700d4}},	//   _plua, _įtar, _guiñ, केंड,
   {{0x6b4fe03e,0x7f94823e,0xa91d81d6,0x5c759aed}},	//   _løgt, màqu, poži, млет,
   {{0x69da82a6,0x45270264,0x2bdd864a,0x6b500338}},	//   _awte, যাপক_, _नौशा, _vägv,
   {{0x97351e5c,0x883a01c6,0xe7871a1f,0x20090084}},	//   _تکرا, _ותשו, _хумо, mtai_,
   {{0x6fd5823c,0xc9a982de,0x395fadfb,0x225480e1}},	//   _मौजू, овке_, thus_, _čaká_,
   {{0x2129059c,0x394b009f,0x6727686e,0x17c99cf4}},	//   ndah_, _jocs_, _hajj, огии_,
   {{0x200916d5,0x395f90a9,0x7bcd01e9,0xf53f0aa2}},	//   ntai_, rhus_, _ntau, rmål_,
   {{0x2d8f84c4,0xf53f035f,0x2d92051e,0x395f8bbd}},	//   loge_, smål_, _skye_, shus_,
   {{0x7bcd36a5,0x7ae38d88,0x395fe86f,0x67276870}},	//   _atau, mant, phus_, _majj,
   {{0x200901e2,0xa2cb0075,0x61f500d2,0x26c5802a}},	//   ktai_, तुस्, drzl, sclo_,
   {{0x21296871,0x26c7ae42,0x6b548362,0x660d80c3}},	//   ddah_, _tfno_, _bàgh, _ćaku,
   {{0xfaa60729,0x21290748,0x5eb780ab,0x2d99657a}},	//   даго, edah_, _আজকে, alse_,
   {{0x6dbe01ac,0xeb97087e,0xe0df01e4,0xdb040333}},	//   _vďak, фир_, _beò_, _quiñ,
   {{0x7ae3e872,0x29e8029a,0x2d1c816f,0x61ee806a}},	//   hant, rğa_, _नसेल_, _æble,
   {{0x62856873,0x490f801b,0x67276874,0xd00717c8}},	// [5b80] _exho, थ्यो_, _bajj, мете_,
   {{0x7ae392b9,0x7c246875,0x6d46011f,0x2d789024}},	//   jant, _isir, ljka, nčev_,
   {{0x4432003e,0x67276876,0x5b5701c6,0x394b574b}},	//   _hry_, _dajj, _חייב_, _focs_,
   {{0x4432079f,0x6e239c4f,0x2b008054,0xb4ca9344}},	//   _kry_, _msnb, _राहु_, ोरे_,
   {{0x68e40739,0x7ae3bf19,0x7c83a4dc,0x6c1a9dd2}},	//   maid, fant, куше, تتاح_,
   {{0x68e46877,0xf8bf11b9,0x7c2404cd,0x6aa582f1}},	//   laid, _jaén_, _msir, गे्र,
   {{0x7d0402a5,0x61fc6878,0x6f1a81a1,0x7bdb9a1a}},	//   _ocis, nurl, vetc, _ewuu,
   {{0xbea32dc1,0x290032db,0x68e412be,0x2d8f86a5}},	//   _раск, ngia_, naid, coge_,
   {{0x7ae3e879,0x02cf9299,0xdb088198,0x7306b6f4}},	//   bant, _स्वभ, _pidä, _опаз,
   {{0x68e42ab6,0xb3568077,0xddc90087,0x61fc687a}},	//   haid, _زیبا_, _înţe, kurl,
   {{0x7bc0b5bf,0x7c24687b,0x36f70039,0x7bcd1831}},	//   _humu, _asir, וצים_, _stau,
   {{0x7bc09f73,0xc0a9817e,0x44322c15,0x61fc687c}},	//   _kumu, _کامل_, _bry_, durl,
   {{0x7bc08010,0x68e40014,0xa3da016f,0xe043a4dd}},	//   _jumu, daid, डील_, _инци,
   {{0xfe6f9125,0x289b8051,0x7bc0a2fe,0x4424c060}},	//   ادی_, _וידא, _mumu, _msm_,
   {{0x443202ec,0x7c2455fa,0x68e4687d,0x7bc0a3a8}},	//   _ery_, _esir, faid, _lumu,
   {{0x7ae3e87e,0x68e4687f,0xbcfb0013,0x29000098}},	//   zant, gaid, bhéa, ggia_,
   {{0x7d1d6880,0x7ae3e881,0xc05b035f,0x4432009a}},	// [5b90] mess, yant, ців_, _gry_,
   {{0x20096882,0x7d1d2c4d,0x628501e9,0xdce9911b}},	//   rtai_, less, _txho, _rjeđ,
   {{0xb905150b,0x2009206c,0xfad60051,0x8aa71bd8}},	//   _না_, stai_, _אותך_, _юрид,
   {{0x68e46883,0x7bc0e884,0xe51000ff,0x67270c2e}},	//   caid, _bumu, _lặng_, _wajj,
   {{0xa3d3016f,0x67276885,0x4424e886,0x0c7580d7}},	//   हीच_, _tajj, _csm_, رگرد,
   {{0xe510001c,0x7bc08077,0xfaa5b0af,0x27e96887}},	//   _nặng_, _dumu, нало, msan_,
   {{0x27e92a37,0x41b589e0,0xb87b016a,0x7d1d6888}},	//   lsan_, нсит, _edít, kess,
   {{0xd2b80051,0x34959957,0x4424c5e4,0x27e96889}},	//   ולות_, _забр, _fsm_, osan_,
   {{0x27e9637f,0x7d1d03ff,0x7bc0c408,0xa2ca8128}},	//   nsan_, dess, _gumu, _स्क्,
   {{0x27e95af6,0x6b50016d,0xd7098009,0x6d59e88a}},	//   isan_, _lägr, чное_, lkwa,
   {{0x7bc0ca71,0x7d1d340f,0x6dac83bf,0xcf9204de}},	//   _zumu, fess, _işar, רטי_,
   {{0x27e9688b,0x7ae1a453,0x26070665,0x90e7826a}},	//   ksan_, _helt, _हमनी_, _آسان,
   {{0x7ae18f52,0x649a13d7,0x6d4d00b9,0x6d598041}},	//   _kelt, ятор_, _doaa, ikwa,
   {{0x61fc0082,0x6b5487e2,0xdb1c0201,0x68e4022e}},	//   turl, _pàgi, _özün, waid,
   {{0x2d960b9c,0x68e40739,0x69c183ba,0x6d59e88c}},	//   _прис, taid, _jule, kkwa,
   {{0x7d1d688d,0x60c9cb4f,0xdb01a4e4,0x64401bf3}},	//   cess, ncem, _kiló, ämis,
   {{0x68e40219,0x69c1e88e,0x27e902a3,0x6d598041}},	// [5ba0] raid, _lule, gsan_, dkwa,
   {{0x68e4688f,0x6d59e890,0x6d5d03ed,0x1aea0264}},	//   said, ekwa, ërav, ঞ্জে_,
   {{0x7bc0c4fc,0xaadb0051,0x27e9404f,0x44248abf}},	//   _sumu, _מחיר, asan_, _ssm_,
   {{0x9f471ded,0x27e90079,0x7bc0809c,0xac869d28}},	//   čná_, bsan_, _pumu, нгел,
   {{0x3d120b86,0xdca38aac,0xb87b0073,0xe50527ec}},	//   ध्ये_, гаци, _veíc, ष्टि_,
   {{0x69c1e891,0x6562d38e,0x7d1d6892,0xf48782e3}},	//   _bule, shoh, zess, رانی,
   {{0x7ae18370,0x752980b9,0x69c1e893,0x1e950256}},	//   _delt, _faez, _cule, _артр,
   {{0x7bc0e894,0xd90e815b,0x69c1e895,0x44220573}},	//   _tumu, صیت_, _dule, kwk_,
   {{0x7ae1e3f8,0x7d1d385e,0x442480ee,0x7c248059}},	//   _felt, vess, _usm_, çird,
   {{0x7d028118,0x7c22e896,0x7ae1e897,0x7d1d6898}},	//   lgos, mwor, _gelt, wess,
   {{0x26c7005c,0x1600809a,0x6dba8197,0x69c804e8}},	//   žnog_, लंधर_, _aċar, ídel,
   {{0x7d02e899,0x63ba803a,0x27e902a3,0x7a0a8201}},	//   ngos, _hitn, ysan_, _nəti,
   {{0xf4840abe,0xe5100028,0x69c182af,0x27e93145}},	//   гурн, _tặng_, _zule, xsan_,
   {{0xdbc78006,0x5b240b79,0xb4bb0180,0x6f1e0140}},	//   _tööt, льса, _کاغذ_, jepc,
   {{0xd0560201,0x7d1d26d1,0xf1a73341,0x399a8168}},	//   mayə, pess, еран, tësh_,
   {{0x7c229328,0x673c06c4,0xceba8326,0x63ba9c99}},	//   kwor, _anrj, _naƙi_, _litn,
   {{0x442f1ca8,0x6b50016d,0x399a8168,0x7d02e89a}},	// [5bb0] _ég_, _vägr, rësh_, dgos,
   {{0x27e940ac,0x7f4e01c0,0x2d84b7bc,0xd0560085}},	//   rsan_, _cobq, _ajme_, nayə,
   {{0x7ae7179d,0xceba8300,0xf74801a8,0x6d59890d}},	//   majt, _baƙi_, علمي_, tkwa,
   {{0x7ae1e89b,0x442f84c3,0x7a0a8201,0x9f400020}},	//   _selt, tvg_, _gəti, frió_,
   {{0x63ba803a,0x6d59800b,0xd0560085,0x7c22e89c}},	//   _bitn, rkwa, kayə, gwor,
   {{0x629a8831,0xe2999a0b,0x7ae7689d,0x69c1e89e}},	//   _byto, мал_, najt, _pule,
   {{0x7ae1b12d,0xc33404de,0x38693db4,0xee840198}},	//   _velt, טוס_, lzar_, _быто,
   {{0x7ae1e89f,0x9f403673,0xdb17002a,0x6ecd00d4}},	//   _welt, brió_, _dixé, दुरु,
   {{0x212b68a0,0x386968a1,0x7c228358,0x7ae70619}},	//   _mach_, nzar_, cwor, kajt,
   {{0x69c1a4da,0x25a9011e,0x63ba809c,0x7ae70796}},	//   _tule, _ahal_, _gitn, jajt,
   {{0x39158077,0xa2ca9053,0xdb01ca40,0x799bb0e5}},	//   _لواز, _स्ट्, _filò, pluw,
   {{0x212b1769,0x2019061b,0x25a968a2,0x2d7880c3}},	//   _nach_, _opsi_, _chal_, lčer_,
   {{0x0d8307a1,0x6e270338,0x644fe8a3,0x63ba89c4}},	//   рлян, _lsjb, _àcid, _yitn,
   {{0x93fa804c,0x987a80be,0x386900dd,0x7ae71924}},	//   ולשי, _קאסט, dzar_, gajt,
   {{0xe2970468,0x212b0114,0x27ff8009,0x200d8afc}},	//   вар_, _bach_, luun_, ltei_,
   {{0x212b68a4,0x399a8168,0x25a901b9,0x68e2802a}},	//   _cach_, tësi_, _ghal_, _xeod,
   {{0xf5770013,0x200de0ac,0x8c464c6f,0x7ae737b0}},	// [5bc0] _جميع_, ntei_, _репе, bajt,
   {{0x93fb0158,0x4438827f,0x212b68a5,0x7bfb0039}},	//   _קליי, _čr_, _each_, _קפיצ,
   {{0x212b281f,0xb87b0333,0x3869016a,0x63bae8a6}},	//   _fach_, _veía, azar_, _ritn,
   {{0x212b1523,0x63ba803a,0x7c228367,0x27ff8009}},	//   _gach_, _sitn, twor, kuun_,
   {{0xa3dd816f,0x0b8a8abe,0x61eabcc0,0x938a867c}},	//   थील_, мски_, wsfl, мска_,
   {{0x67138f97,0x9f401d4e,0x61ea848d,0x629a839c}},	//   त्मक_, rrió_, tsfl, _pyto,
   {{0xf50696cf,0x212b0101,0x63baa461,0xd5b285ff}},	//   _изво, _yach_, _vitn, _نفس_,
   {{0xdb09a47e,0xf98f80f7,0x2d540187,0xdb1703a8}},	//   _dueñ, يبي_, _mães_, _vixé,
   {{0xdefa8162,0xc17304de,0x6dac8085,0x290680b9}},	//   мын_, יחה_, _uşaq, _vcoa_,
   {{0x63ba8cfa,0x7d1601d0,0x5ba78012,0x473386d2}},	//   _uitn, _abys, _акум_, аньс,
   {{0xb9088a49,0x38692856,0x0f5701c6,0x6b7bab7b}},	//   _বা_, zzar_, דיים_, _קרבנ,
   {{0xdced026c,0x7bc468a7,0x6d988118,0x9f4d802a}},	//   _tmač, _buiu, mías, rreá_,
   {{0x7ae70b48,0x212b68a8,0x7bc418ad,0x06e800ab}},	//   tajt, _rach_, _cuiu, _পানি,
   {{0x27f980e1,0x69c30061,0x212b68a9,0x7bc468a7}},	//   ásne_, _ének, _sach_, _duiu,
   {{0xda780656,0xb87b0032,0x31c400c4,0x2d540187}},	//   вят_, _adíp, иств, _cães_,
   {{0x386968aa,0x3f9ed07f,0x65664bee,0x99640012}},	//   tzar_, lltu_, chkh, атул,
   {{0x212b38ab,0x394902f1,0x7ae70968,0x6ca40162}},	// [5bd0] _vach_, rjas_, pajt, _врэж,
   {{0x442968ab,0xdb1a820f,0x38694e13,0xf77012c5}},	//   _isa_, _ditë, rzar_, يال_,
   {{0x3a8407ac,0x733a00be,0x212b68ac,0xed5980c3}},	//   _выяв, _װערס, _tach_, _liže_,
   {{0x6d5d68ad,0x6d98a3be,0x38690144,0x867b81c6}},	//   nksa, días, pzar_, ורבו,
   {{0xdb09ab70,0xed598052,0x752d2d15,0x7ae50006}},	//   _sueñ, _niže_, _maaz, _keht,
   {{0x4209aa28,0x69c500b8,0xb464804a,0x3d0882f1}},	//   енко_, _kuhe, шкіл, _हाथे_,
   {{0xe296bf61,0x69c502f1,0x291f8c53,0xdb019f1c}},	//   лаш_, _juhe, teua_, _uhlí,
   {{0x4429043d,0x7ae51453,0x69c5130e,0xc8798087}},	//   _osa_, _leht, _muhe, laşi_,
   {{0x7d098a03,0x69c503ed,0x7ae502f9,0xdce28965}},	//   _ices, _luhe, _oeht, lioğ,
   {{0x7c29e8ae,0xed59812b,0x200de8af,0x7ae501d0}},	//   _iser, _diže_, rtei_, _neht,
   {{0x442968b0,0x200d895d,0x394f8106,0x1d0a0081}},	//   _asa_, stei_, _togs_, нени_,
   {{0x25624ff4,0xd76382e3,0x200de8b1,0xaca38133}},	//   _bóla_, انگی, ptei_, _nrịa,
   {{0xff53803d,0xe72ec652,0x60dbe8b2,0xe8d9019d}},	//   _پخش_, _ле_, mbum, akị_,
   {{0x752f0063,0x27ed8ed0,0x60dbe8b3,0x69c568b4}},	//   adcz, msen_, lbum, _buhe,
   {{0x4429040e,0x27ed8f06,0x6721e408,0x6b5daeef}},	//   _esa_, lsen_, melj, _règl,
   {{0x69c508cf,0x660182a3,0x6d5d1647,0x98a0005c}},	//   _duhe, mulk, cksa, ndić_,
   {{0x27edd7dd,0x43761597,0xa067013a,0x999e0019}},	// [5be0] nsen_, _бунт, гата_, ítő_,
   {{0x7d09e8b5,0x27ed95ec,0x6459809a,0x324604ae}},	//   _aces, isen_, dywi, _беог,
   {{0x2776893f,0x7c29e8b6,0x670688fd,0x68e982c4}},	//   נגען_, _aser, _शासक_, kaed,
   {{0x27edc156,0xd9460aac,0x98a00042,0x7d098118}},	//   ksen_, _семи, jdić_, _cces,
   {{0x5ee300c8,0x7c298019,0x4d7b00be,0xbebc80eb}},	//   _পারে, _cser, ערנע, ldīt,
   {{0x53348676,0x67218025,0x27ed8aaa,0x6be380f7}},	//   рект, jelj, dsen_, حكوم,
   {{0x6721e8b7,0x7c29e8b8,0x3d050d38,0x96660470}},	//   delj, _eser, _वाले_, _скве,
   {{0x68e9e8b9,0x63be68ba,0x6d989d64,0xaca42e3b}},	//   gaed, _lipn, rías, _akọw,
   {{0xa3cb80cf,0x68e601a1,0xb6e685e9,0x6d40bce1}},	//   _रूप_, _mekd, люнк, _inma,
   {{0x66e40af3,0x25620019,0x75228118,0x656401f8}},	//   गरिक_, _róla_, leoz, _alih,
   {{0x49068f99,0x3eb8e8bb,0x6601808e,0x98a0026c}},	//   _مواق, ärt_, gulk, bdić_,
   {{0x69c568bc,0xdd9501e5,0xafe6c11c,0x27ed9433}},	//   _ruhe, рамы, _бодл, bsen_,
   {{0x6d5d1614,0xb99396a5,0xc99380f7,0x442690ab}},	//   rksa, _النب, _النظ, nwo_,
   {{0x69c50364,0x0703009a,0x442968bd,0xdcef0087}},	//   _puhe, _लाइव_, _vsa_, fică,
   {{0x60cd093d,0x6459809a,0x69c500f1,0xdb1ae8be}},	//   tcam, zywi, _quhe, _cité,
   {{0x442901c5,0x2608035a,0x7aea82af,0x29ca8028}},	//   _tsa_, ांनी_, haft, _mùa_,
   {{0x442968bf,0x60cd1ee8,0x7ae568c0,0x9f40224e}},	// [5bf0] _usa_, rcam, _teht, ksiä_,
   {{0x4426e7cf,0xa3da1834,0x6e2a826c,0x69c543a4}},	//   dwo_, डीओ_, _ksfb, _tuhe,
   {{0x7aeae8c1,0x57a42361,0xe4d58290,0x539c01c6}},	//   daft, сшта, لقاد, _איזו,
   {{0x60c29281,0x89da007c,0x7c299fe7,0x6459866f}},	//   _ngom, _שחרי, _pser, tywi,
   {{0x1aee80c8,0x8c459b02,0x705801e5,0x29190118}},	//   চ্ছে_, реле, _баяр_, _ibsa_,
   {{0x6459e8c2,0x6d4085e4,0xb60600cd,0x60c29fbb}},	//   rywi, _enma, _bišć, _agom,
   {{0xdb0180f7,0x29190267,0x06e380ab,0x27ede8c3}},	//   _chlá, _kbsa_, _মালি, wsen_,
   {{0x44268578,0x7d09876c,0x7c2984b9,0xaca3026b}},	//   bwo_, _uces, _tser, _ajọf,
   {{0x84678698,0xdb0d0118,0x98a000ce,0x27ed8456}},	//   _съве, _luañ, rdić_, usen_,
   {{0xee39952a,0x27ed9da3,0x6601e8c4,0xf77188ca}},	//   вно_, rsen_, tulk, تاب_,
   {{0x27ed977a,0x3ea5816c,0x2ca90085,0x67218968}},	//   ssen_, ринг, _azad_, relj,
   {{0xa3a985e8,0x27ed9c70,0x51849444,0xc9849b06}},	//   _गीत_, psen_, _луча, _лучи,
   {{0x6721881d,0x6601a419,0x452700ab,0xa3b1016f}},	//   pelj, sulk, যাংক_, _ओळख_,
   {{0x394dc684,0x68e668c5,0xb4e50105,0xdb1ac068}},	//   ljes_, _sekd, _पड़ी_, _pité,
   {{0x09e6035f,0xa3da0540,0xc7c8801c,0x2d8b00e7}},	//   робн, डीज_, _tốc_, ébec_,
   {{0x629e026f,0x395f8110,0x394d88b2,0x61ee2b11}},	//   _vypo, nkus_, njes_, rsbl,

   {{0x629e0063,0x386d9fd1,0x3fc8004e,0x395f9d70}},	// [5c00] _wypo, nzer_, ادری_, ikus_,
   {{0x629e5ad3,0x13cc80ab,0x386ddd73,0xe0df0176}},	//   _typo, রীড়, izer_, _anòd_,
   {{0x394daa76,0x395f8074,0x6d988118,0x7626072a}},	//   kjes_, kkus_, fíap, рмез,
   {{0xf1bf0142,0x44268063,0xe45a8364,0x61fc8f06}},	//   _giá_, two_, кже_, _årli,
   {{0x394dc9a1,0xac07cd44,0xd24f02e3,0x386d80f3}},	//   djes_, инца_, _فنی_, jzer_,
   {{0x4426e8c6,0x60c2847f,0x2ca000b9,0x395f81a9}},	//   rwo_, _sgom, _myid_, ekus_,
   {{0x661c1c89,0x7aeae8c7,0x25bf8087,0x46aa0074}},	//   _uprk, raft, _fiul_, _करिह,
   {{0x6d40abf7,0xb6060267,0x394db09f,0xed57a55e}},	//   _unma, _višć, gjes_, _кос_,
   {{0xed57af0c,0x7f9d80e7,0x20120198,0x777a8cdb}},	//   _тот_, hèqu, ntyi_, titx,
   {{0xc3068061,0x38170039,0x200b809f,0x394d81ca}},	//   _خبرو, סקים_, àcia_, ajes_,
   {{0x56948d0f,0xed5980c3,0x777aad11,0xb87b0144}},	//   сант, _hiža_, ritx, _reím,
   {{0x60c28435,0xdb17002a,0xdb1e0580,0x69c8e8c8}},	//   _ugom, _vixí, _hipè, _iude,
   {{0xd007a72b,0x80dd80c8,0xb7d49c2c,0x69c8a0b3}},	//   _вече_, _যাচ্, _اقتب, _hude,
   {{0x69c88102,0x200480eb,0x93880198,0x2717128a}},	//   _kude, mumi_, асса_, _mění_,
   {{0x69c88012,0x2004bfff,0x7ae8e8c9,0x2b099008}},	//   _jude, lumi_, _medt, _सासु_,
   {{0x69c8e8ca,0xeeeb00ff,0xd5430032,0x7ae8aa92}},	//   _mude, _đựng_, _dẹ́b, _ledt,
   {{0x657d68cb,0xb4e303db,0x2d9968cc,0x2004e8cd}},	// [5c10] mish, धरी_, mose_, numi_,
   {{0x2d9968ce,0x69c885f8,0x7c2d68cf,0x657d28eb}},	//   lose_, _oude, _isar, lish,
   {{0x20049090,0x645d0039,0xcf9383de,0xa1950c99}},	//   humi_, lysi, קטע_, _ганч,
   {{0x2d9902a5,0x2004e8d0,0x657d35e9,0xe57080f7}},	//   nose_, kumi_, nish, وطن_,
   {{0x20048341,0x68ed275c,0x3d088105,0xa6be80ab}},	//   jumi_, maad, _हारे_, োরিয়,
   {{0x657d3845,0x68ed275c,0xb5c90875,0x2004e8d1}},	//   hish, laad, _موسم_, dumi_,
   {{0x657d3b1f,0x394d95ca,0x7d0d11b9,0xd5bb98d1}},	//   kish, tjes_, _ocas, _аса_,
   {{0x386de8d2,0x68ed4621,0x7d0d0388,0x290968d3}},	//   tzer_, naad, _ncas, ngaa_,
   {{0x25621220,0x2d990511,0x657d13a2,0x394d80f1}},	//   _sólo_, dose_, dish, rjes_,
   {{0x394daa76,0x395fe8d4,0x7d0d68d5,0x69c883a7}},	//   sjes_, skus_, _acas, _fude,
   {{0x386d8065,0x7c2d68d6,0x68ed68d7,0x394d9696}},	//   szer_, _asar, kaad, pjes_,
   {{0x657d02a0,0x7a7a8158,0x645d68d8,0x20120009}},	//   gish, _גרעס, fysi, ytyi_,
   {{0x7d1be8d9,0x7bc18e01,0x68ed32a1,0x69c881ec}},	//   _mbus, _kilu, daad, _zude,
   {{0x1dcf89a3,0x660507d5,0x6d4b0247,0xb47a80be}},	//   _संपत, kuhk, _ògan, אָלי,
   {{0x657d3b1f,0x7bc194f0,0x7d1b8a40,0x69c88509}},	//   bish, _milu, _obus, _xude,
   {{0x442d820f,0x7c3b999b,0x66050b20,0x68ed68da}},	//   _ose_, _orur, duhk, gaad,
   {{0x69d7011e,0x442d8091,0xef1a09a0,0x6d44076d}},	// [5c20] _etxe, _nse_, лма_, _inia,
   {{0x6d440282,0x7bc1b66f,0xed5996f2,0x9f4001a8}},	//   _hnia, _nilu, _riža_, lsiú_,
   {{0x442de8db,0x6d562b17,0xb3bb0039,0x6605010b}},	//   _ase_, _koya, _תמיכ, guhk,
   {{0x69c8e8dc,0xdb1b807b,0x6d5668dd,0xbcfb00f7}},	//   _rude, _stuð, _joya, théi,
   {{0x69c8b799,0x6d5610e1,0x69dc14fb,0x9f4001a8}},	//   _sude, _moya, lpre, isiú_,
   {{0x636b0459,0x660520d5,0x657d13a2,0x442068de}},	//   _günd, buhk, zish, _mpi_,
   {{0x657d1ba4,0x442021ba,0x7ae880e8,0xdb088118}},	//   yish, _lpi_, _vedt, _sidó,
   {{0xf1268cde,0x44202328,0x6d5668df,0x2d9901df}},	//   сько, _opi_, _noya, xose_,
   {{0xa49484c0,0xdce9a43e,0x96ea81d9,0x657d68e0}},	//   _بیشت, _smeć, льна_, vish,
   {{0x2004e8e1,0x543b8158,0x160c0665,0x7bc1e8e2}},	//   rumi_, _געמא, _हमार_, _gilu,
   {{0x657d68cb,0xa3e481fe,0x442009ca,0x69c88364}},	//   tish, भीर_, _api_, _uude,
   {{0xd567140b,0x69dc68e3,0x2d990110,0x6b5d8722}},	//   стоп, dpre, uose_, _règi,
   {{0x657d68e4,0x6d565d2b,0x9743825b,0x7d0d68e5}},	//   rish, _doya, _šćep, _vcas,
   {{0x657d68e6,0x68ed68e7,0x645d68e8,0x69dc68e9}},	//   sish, waad, rysi, fpre,
   {{0x44200205,0x657d0010,0x69dc1400,0xa77b8039}},	//   _epi_, pish, gpre, _תרופ,
   {{0x7c2d03c3,0x657d00f1,0x44201142,0x636b0074}},	//   _tsar, qish, _fpi_, _sünd,
   {{0xb8d1101b,0x68ed2722,0x7c2d68ea,0x7aee0079}},	// [5c30] _ओर_, raad, _usar, babt,
   {{0x66050877,0x442de8eb,0x68ed68ec,0x80d91299}},	//   tuhk, _rse_, saad, _फ्रे,
   {{0x656b8c41,0x65628088,0x63a3816b,0x442de8ed}},	//   thgh, fkoh, vlnn, _sse_,
   {{0x442d820f,0xd126826a,0x9c39a1a7,0xe7ed0540}},	//   _pse_, _غم_, ипет_, _चौथा_,
   {{0xe3b18277,0x7bc98051,0x6aa18114,0x44200122}},	//   ورت_, _queu, _sylf, _xpi_,
   {{0x442da588,0x31b38526,0xc1ed02f1,0x7d1b82f7}},	//   _vse_, ुद्ध, _जबाब_, _wbus,
   {{0x27e68324,0x81cb00c8,0x636b03bf,0x3e4e811c}},	//   _awon_, রীর_, _güne, bəti_,
   {{0x442d8069,0x7d1baaac,0xc7c8801c,0x27ffd2f7}},	//   _tse_, _ubus, _vốn_, trun_,
   {{0x442d8051,0x7c3be8ee,0x7d0481a8,0x69c2811b}},	//   _use_, _urur, óise, _dioe,
   {{0x6d5668ef,0x2d8b0019,0x69dc02d5,0x70c61834}},	//   _soya, ében_, ypre, _वल्ल,
   {{0xda02800f,0x69dc68f0,0xc7c88129,0x27e6a1ce}},	//   रूआत_, xpre, _uốn_, _ewon_,
   {{0x80d90540,0x69dc007a,0x261a82f1,0x69c280e5}},	//   _फ्ले, vpre, _बहरी_, _gioe,
   {{0x6d5603d3,0x333301b9,0x9f35804a,0x00000000}},	//   _voya, _baxx_, _меді, --,
   {{0x437534fd,0xf99f0032,0x7989bf6f,0x69c28cdb}},	//   пуст, _akè_, lnew, _zioe,
   {{0xa3cb800f,0x65699295,0x6d5668f1,0x06e800ab}},	//   _रूस_, _oleh, _toya, _পালি,
   {{0x44203fa5,0xe0da1f97,0x7aee1801,0x6d44201f}},	//   _tpi_, рва_, sabt, _unia,
   {{0x69dc68f2,0x46ea0088,0x98a3153d,0x88bd809a}},	// [5c40] spre, идан_, дите, ześn,
   {{0xbf878104,0x7c248059,0x81df80ab,0x799b80f3}},	//   _điện_, çirm, _তিন_, houw,
   {{0x2018802e,0x316d8019,0x644100eb,0xdd8f003d}},	//   ării_, khez_, ālie, _سوی_,
   {{0xcbd580c8,0x96da01fe,0x68eb803a,0xdce40503}},	//   _হয়েছ, _प्रॉ, _negd, _olič,
   {{0xead493cd,0x656280f1,0x7989e8f3,0xc2f380ab}},	//   поль, rkoh, dnew, চ্ছি_,
   {{0x47c30698,0x65628100,0x69c302be,0x9c8305b9}},	//   _обяв, skoh, _éner, _účel,
   {{0xdce4026c,0xe1ef80f7,0x291d838a,0xf96a802e}},	//   _alič, نسي_, _bbwa_, ирий_,
   {{0xdced1c89,0x387f00d2,0x6b9c2175,0xf99f01e8}},	//   _imać, _žuri_, horg, _xkè_,
   {{0x6da390ee,0x6b9c68f4,0x386039a8,0xe5a39e4e}},	//   _цита, korg, nyir_, _цити,
   {{0x25620125,0x636b6094,0xdea38326,0x25a6e8f5}},	//   _fólk_, _münc, _hanƙ, llol_,
   {{0xe8a715fb,0x799b838e,0xdce43cf6,0xe80c0ad5}},	//   _खर्च, bouw, _amiđ, िंडा_,
   {{0x69dae8f6,0x316d8036,0xd1308180,0xe45f0198}},	//   _itte, chez_, _سمت_, työ_,
   {{0xd5b82d5d,0xbcfb0019,0x6b9c68f7,0x1ae20264}},	//   юсь_, bkén, forg, _বাড়া,
   {{0xa3b08063,0x7980914c,0x39468144,0xdea380fc}},	//   _टीम_, limw, _hnos_, _lanƙ,
   {{0x2d878019,0x0eba8084,0xda34014c,0x7ed39f31}},	//   ének_, _туды_, меры, _غزوا,
   {{0x3495177f,0x6608e35f,0xd5cf86ae,0x26c701d6}},	//   _найр, mudk, _संतज, ľnom_,
   {{0x6b9c0bcb,0xb4d70074,0x656f00f7,0xc6f909c7}},	// [5c50] borg, िडी_, mhch, йнах_,
   {{0xd6db11b1,0x672882fd,0x69daa442,0x6b9c047f}},	//   рта_, nedj, _otte, corg,
   {{0xcb1204de,0xdea38326,0x79808a5a,0x6569b038}},	//   _אלי_, _banƙ, kimw, _pleh,
   {{0x8d74915f,0xa6e300ab,0xf653825f,0x7bcd05ee}},	//   وانا, _পাওয়, וצע_, _kuau,
   {{0x69dae8f8,0x636b0214,0xa91d8390,0x67289e5e}},	//   _atte, _günc, niže, kedj,
   {{0x3946956b,0x6728856f,0x3c1e80eb,0xab29813a}},	//   _anos_, jedj, dāvā_, сока_,
   {{0xdce4003a,0x66088057,0x1df801bb,0x7afa007b}},	//   _slič, judk, _меры_, ótti,
   {{0x657b823d,0x6b9c0a0f,0x3f8168f9,0x32078690}},	//   _umuh, zorg, lihu_, runy_,
   {{0x4439e8fa,0x02a813d9,0x69da97ab,0xa91d8fda}},	//   _és_, _गर्न, _ette, jiže,
   {{0x3ced81e9,0x443fd920,0x7989e8fb,0x316d8019}},	//   _heev_, _iru_, snew, shez_,
   {{0x63702a9c,0x443f826f,0x6da61631,0x6b9c10b9}},	//   _häng, _hru_, зина, vorg,
   {{0x2d9d809a,0x3f810267,0x69ca0187,0x7bc500fc}},	//   nowe_, hihu_, _éfei, _aihu,
   {{0x6b9c68fc,0xdce40904,0x7bc53976,0x160d00d4}},	//   torg, _ulič, _bihu, ांडर_,
   {{0x637068fd,0x69da8448,0x26c70024,0x2d8b3328}},	//   _mäng, _ytte, žnoj_, ance_,
   {{0x63702a9c,0x7bc50057,0x2d9de8fe,0xae1f8424}},	//   _läng, _dihu, kowe_, _बहिन_,
   {{0x3946160a,0x9f471ded,0x443faf10,0x29d1877f}},	//   ños_, čný_, _oru_, _máa_,
   {{0x2d8268ff,0x2d9d809a,0x443f84b7,0x200924df}},	// [5c60] mike_, dowe_, _nru_, guai_,
   {{0x2d826900,0x161f98e6,0x7bc56901,0x7c246902}},	//   like_, _बहार_, _gihu, _ipir,
   {{0x443fe903,0x7bdb8365,0x3860036e,0x38660bda}},	//   _aru_, _atuu, syir_, šor_,
   {{0x3ced8069,0xed59801b,0xe80c01a2,0x200900ee}},	//   _ceev_, _což_, िंदा_, buai_,
   {{0xe8030063,0xdce60029,0x68e46904,0x3ced8282}},	//   _लिया_, dokļ, mbid, _deev_,
   {{0x27e01e92,0xdb1a84c3,0x88bd809a,0x68e4011e}},	//   mpin_, _bitá, reśl, lbid,
   {{0x443f87ca,0xfce6842f,0x2d9d9111,0xed59826c}},	//   _eru_, _ново, bowe_, _fož_,
   {{0x63701bd7,0x636b0201,0x68e46905,0x443f84e1}},	//   _händ, _müna, nbid, _fru_,
   {{0x63700004,0x69c66906,0x16040054,0x68e46907}},	//   _känd, _mike, शंकर_, ibid,
   {{0x29d1ce75,0x69c66908,0x644098d5,0x138a81a8}},	//   _fáa_, _like, _irmi, _اخرى_,
   {{0x69c6025d,0xaadb8051,0x2d821cd8,0x672884a8}},	//   _oike, _החבר, fike_, redj,
   {{0x394684c9,0x63701bd7,0x2c208063,0x6440905e}},	//   _unos_, _länd, _यहां_, _krmi,
   {{0x98d2819d,0x63700338,0x9f520216,0x2b5a0580}},	//   _dịtụ, _oänd, nuyó_, _bopc_,
   {{0x69c66909,0xddda8019,0x7fb8803d,0x395906ab}},	//   _aike, sztő, _بهتر_, _soss_,
   {{0x395901e0,0x99670254,0x321802c4,0x7c2403ed}},	//   _poss_, птал, gtry_, _epir,
   {{0x3f9e9d19,0x200907d5,0x44249b7d,0x26ca04be}},	//   lotu_, tuai_, _opm_, _agbo_,
   {{0xa2bcab38,0x69c6059c,0x3015014c,0x3f8164a6}},	// [5c70] षेत्, _dike, ьдар, tihu_,
   {{0x3ced8069,0x3f9e81a9,0x29038084,0x69c6232f}},	//   _seev_, notu_, ėjai_, _eike,
   {{0x7bdb81d8,0x20090393,0x6440e90a,0x63703ee0}},	//   _stuu, suai_, _armi, _säng,
   {{0x443fdb35,0x644080b9,0x26ca6042,0x3f9e84e8}},	//   _pru_, _brmi, _egbo_, hotu_,
   {{0x98ab0012,0x2d9dde51,0xa15602f6,0x240980e8}},	//   _dacă_, rowe_, _חברה_, інки_,
   {{0x7c948077,0x656d690b,0x2d9d809a,0x8c4299a8}},	//   رشنا, _llah, sowe_, теше,
   {{0x656d08b3,0x3ced81e9,0x98ab0087,0x2d9d8035}},	//   _olah, _teev_, _facă_, powe_,
   {{0x636f8bc5,0x443fe90c,0x9f520216,0x798d690d}},	//   _sønd, _tru_, buyó_, nnaw,
   {{0x443fb7c3,0x2d820052,0x63700364,0x6d499997}},	//   _uru_, vike_, _häne, _inea,
   {{0x656d02e7,0x798d2881,0xd00e853d,0x9e65d946}},	//   _alah, hnaw, گلی_, двод,
   {{0x442f831d,0x656d4a84,0xa2a48105,0x2004af2f}},	//   lwg_, _blah, _चुप्, armi_,
   {{0x443236e7,0x6d5b8036,0xd00e9190,0xb33c8372}},	//   _psy_, _joua, دلی_, _ikħa,
   {{0xef0e964f,0x2eaa0a0d,0x2d8223f2,0xe6aa0a0d}},	//   _им_, _कर्त, rike_, _कर्ज,
   {{0x7c248086,0x69c6690e,0x366994d6,0x8e858abe}},	//   çiri, _sike, _мало_, _огле,
   {{0x69c634c3,0x6fd580c8,0xfaa32f20,0xbcfb3df7}},	//   _pike, _দিয়ে, варо, rhér,
   {{0x6b83e90f,0x140d8996,0x6370016d,0x68382610}},	//   hing, _समूह_, _sänd, júdá,
   {{0xb4ea0128,0x321814e3,0xbcfb0036,0x6e2901a1}},	// [5c80] यरी_, stry_, phér, _ćeba,
   {{0x69c61b03,0x6b83e910,0x68e43e1b,0x656d0824}},	//   _wike, jing, sbid, _zlah,
   {{0x6b83e911,0x2fc7b017,0x637004fd,0x4424b081}},	//   ding, _ming_, _vänd, _spm_,
   {{0xc486c166,0x9f520661,0x973c8669,0x27e00e20}},	//   млек, tuyó_, moće, ppin_,
   {{0xd24f8077,0x6370016d,0x6b83e912,0x69d781df}},	//   ینه_, _tänd, fing, íxen,
   {{0x6b83e913,0x2fc7e914,0x06e800ab,0x7c2dae21}},	//   ging, _ning_, _পাকি, çara,
   {{0x3f9e803a,0x2eee9142,0xb87b0118,0x7f5c1243}},	//   votu_, _reff_, _feís, _iorq,
   {{0x3834b385,0xed439285,0x2fc7808e,0x7f5c4b30}},	//   енир, _инсп, _aing_, _horq,
   {{0x4424810a,0x26ca812b,0xc2f400ab,0xdce60084}},	//   _upm_, žbom_, _জানি_, likė,
   {{0x6b83e915,0xf41400c8,0x2fc786cb,0x69de0904}},	//   cing, িবার_, _cing_, _otpe,
   {{0xe0da9c74,0x2fc7b6bc,0x3f9edcb0,0xc9568009}},	//   _две_, _ding_, rotu_, _отды,
   {{0x7bc894ff,0xc7c880ff,0x1bf58074,0x7afe07b6}},	//   _hidu, _lối_, ुंचल_, _adpt,
   {{0x7bc8e916,0x9f40009f,0xb87b0019,0xe73a846e}},	//   _kidu, nsió_, _leír, _мед_,
   {{0xb4af2c26,0x2fc7a64a,0xa91d80c3,0x5694a8ca}},	//   _करी_, _ging_, miža, _палт,
   {{0xc7c8801c,0x3d0f8105,0xa2a480bc,0x7bc8e917}},	//   _nối_, _डाले_, _चुम्, _midu,
   {{0x6b839f50,0x69da0013,0x2fc7801c,0x798d4387}},	//   zing, ítea, _zing_, unaw,
   {{0x46d2800f,0xfe7000d7,0x442f822c,0xe50d82f1}},	// [5c90] _सलाह, یدم_, xwg_, हलसि_,
   {{0x6d49a536,0x673a816d,0xc7c880ff,0x63620187}},	//   _snea, ndtj, _bối_, _bônu,
   {{0xdb1a8364,0x6b83e918,0xc33203de,0xfc3f0216}},	//   _mitä, ving, _גוי_, lví_,
   {{0xceb3812a,0x46df000d,0x6b83e919,0xa4d580e8}},	//   דיע_, _प्रह, wing, ході,
   {{0xd0068b76,0xa91d82a5,0x7bc8e91a,0x7f5c1b05}},	//   _حل_, jiža, _bidu, _forq,
   {{0x6738882c,0x442f8428,0xe1f0081b,0xc5f88ec3}},	//   _navj, rwg_, _حسی_, ksē_,
   {{0xc6a40c6e,0x7bc8e91b,0x4ea4014c,0x213967b2}},	//   _арти, _didu, _арта, _kash_,
   {{0x2fc78288,0x6b83828d,0x261883d3,0xb4af016f}},	//   _sing_, sing, déo_, _करू_,
   {{0x7bc8ae31,0x6b8385d1,0xed59812b,0x160d016f}},	//   _fidu, ping, _niži_, ांवर_,
   {{0x81e500c8,0x636b691c,0xa3d4a967,0x7bc88bb1}},	//   _নিন_, _sünn, _संत_, _gidu,
   {{0xa29f0f1b,0xe61693bf,0x2fc7db1e,0x7af50f3e}},	//   _खुल्, ндэ_, _ving_, dazt,
   {{0x20028084,0xc692007c,0x224600c3,0xa91d8140}},	//   škia_, ראט_, _čok_, biža,
   {{0x2fc7e91d,0xf53981ac,0x2d8f8c41,0xa2c786ce}},	//   _ting_, _mať_, inge_, ाशक्,
   {{0x2fc78362,0x7af50cdb,0x29038084,0xbcfb04e8}},	//   _uing_, gazt, ėjau_, hkéh,
   {{0x3f859142,0xdce9817f,0xeb971073,0x41b61092}},	//   milu_, _aleč, хир_, есат,
   {{0x673882ce,0xdce98699,0x3f85e91e,0xc7c880ff}},	//   _zavj, _omeđ, lilu_, _rối_,
   {{0x7f5c10dd,0x75244aff,0xa3cb8c69,0x7af5011b}},	// [5ca0] _porq, _ibiz, _रंग_, bazt,
   {{0x212db536,0xdce60110,0xe3b2066e,0x31691fe7}},	//   heeh_, tikė, _حرب_, akaz_,
   {{0xe8ac912a,0x7bc88330,0x69d78118,0x69de0687}},	//   _चर्च, _ridu, íxel, _utpe,
   {{0xd91000d5,0x64440406,0xd6e800ab,0x7bc8e91f}},	//   _خیر_, _krii, _পাওয, _sidu,
   {{0xd467aae3,0xf53980e1,0x68f630ac,0xd90d09a7}},	//   нице_, _dať_, mayd, _ذیل_,
   {{0x9f40009f,0xc7c88028,0x68f66920,0x7c3600b9}},	//   rsió_, _tối_, layd, _msyr,
   {{0x9f4007e2,0x7bc89482,0xf9c6ab27,0x3f85811a}},	//   ssió_, _vidu, нщин, dilu_,
   {{0x673882fd,0x64a6c8ff,0xbcfb027f,0xdca6e921}},	//   _savj, _заба, ckéh, _заби,
   {{0x59d2101b,0xdb1a825d,0x7bc89a6e,0xb4af0740}},	//   _दूसर, _pitä, _tidu, _करे_,
   {{0x261880e7,0x752444a7,0xed598140,0x7bdf816a}},	//   téo_, _abiz, _riži_, íque,
   {{0x7c3600ee,0x64441698,0x00ca917e,0x752405ee}},	//   _asyr, _arii, _елек_, _bbiz,
   {{0xa91d812b,0xfc3f03bb,0xe4a71bd8,0x68f66922}},	//   ližn, tví_, ерго, jayd,
   {{0x3f85e923,0x68f60079,0x69da0019,0xb4fb02f1}},	//   bilu_, dayd, íten, ्लौप_,
   {{0x636b02bb,0xafdb5ff1,0x75243e3e,0x65b6128a}},	//   _günl, _brøn, _ebiz, váhe,
   {{0xb5a7035f,0x3da71240,0xdcfb8353,0x7af5011e}},	//   _прий, _приб, _smuč, razt,
   {{0x195801e5,0x644420e5,0x68f66924,0x291202ec}},	//   насы_, _frii, gayd, ggya_,
   {{0x6d4d6925,0x64440915,0x31690326,0x20980fe6}},	// [5cb0] _inaa, _grii, rkaz_, екты_,
   {{0x44296926,0x81bc8029,0xa91d8132,0x69b31344}},	//   _ipa_, _spēl, jižn, _आठवी,
   {{0xafdb0b40,0xdce98668,0x21390168,0x6d4d198b}},	//   _grøn, _smeđ, _tash_, _knaa,
   {{0x753d0065,0x3f8580d2,0x80a203bb,0x2d8fe927}},	//   ndsz, zilu_, _कुवे, unge_,
   {{0x44296928,0xb4af3918,0xaacc8d86,0xf0d281bc}},	//   _jpa_, _करो_, ाशंक, _rịpọ,
   {{0xbcfb026f,0x996c81d0,0x395d9b7d,0xb4af03db}},	//   skéh, měř_, _sows_, _करै_,
   {{0x2d878264,0xe29681f3,0x6d4d45ed,0x533801c6}},	//   énes_, каш_, _onaa, גנון_,
   {{0x200de929,0x6d4d0365,0xe7a9066f,0x752f066f}},	//   tuei_, _nnaa, कतकप, jecz,
   {{0x44295dc8,0x26c701d6,0x63748980,0xa3d5804a}},	//   _npa_, ľnou_, _bànd, _розч,
   {{0x6d4d692a,0x7c29bed3,0x2003836f,0x753bacbd}},	//   _anaa, _iper, čji_, _hauz,
   {{0x4429028a,0x39158676,0x13e68a49,0xfce607c8}},	//   _apa_, _амер, _নিয়, коно,
   {{0x200901e2,0x44290fd2,0xd2568039,0x6444692b}},	//   krai_, _bpa_, _בשעה_, _prii,
   {{0x68e9e92c,0x200de92d,0xe72e8195,0x753b8c53}},	//   mbed, quei_, _ке_, _mauz,
   {{0x63a3e92e,0x7c29d854,0x76438573,0x4429692f}},	//   nonn, _mper, _trny, _dpa_,
   {{0x69cba5d3,0xd2990558,0x561300ab,0xcb1283c8}},	//   _kige, етті_, সবুক_, ילם_,
   {{0x63a3b79c,0x973c80d2,0x644402f1,0x1c460103}},	//   honn, moća, _trii, _аним,
   {{0x63a3b84d,0x2fca0748,0x69cb8c03,0x41d211be}},	// [5cc0] konn, _pibg_, _mige, _दूरस,
   {{0x69cbe930,0x63a3e931,0x68f6080a,0xafdb004a}},	//   _lige, jonn, sayd, _trøn,
   {{0x7c29bff8,0x81dc00c8,0x63a3e932,0x200912ae}},	//   _aper, _ঠিক_, donn, arai_,
   {{0x69cbe933,0x753b8012,0x598327ee,0x7c868dae}},	//   _nige, _cauz, _влюб, куле,
   {{0xed59811f,0x753b811b,0xf48780d7,0x68e9e934}},	//   _nižu_, _dauz, پانی, dbed,
   {{0x63a38d35,0x752f009a,0x973c8267,0x2d87e935}},	//   gonn, zecz, koća, éner_,
   {{0x753b978f,0x69cbb294,0xa91d811a,0xc7c88129}},	//   _fauz, _bige, rižn, _mốt_,
   {{0x673c043d,0x753b811e,0x68e98c30,0xd90e8180}},	//   _harj, _gauz, gbed, زیت_,
   {{0xb4259e7b,0x673c20ec,0x61e90042,0x34a78171}},	//   _معلو, _karj, ćeli, _авто_,
   {{0x69cbe936,0x753b803b,0x63a382be,0x44296937}},	//   _eige, _zauz, conn, _rpa_,
   {{0x752f009a,0x69cbe938,0x3eaa806a,0x69da01d0}},	//   tecz, _fige, æbt_, ítel,
   {{0x7982809a,0x69cbe939,0x2912821e,0xeeeb0129}},	//   _umow, _gige, _øya_, _đọng_,
   {{0x6442a314,0x94a824b6,0x61e200d2,0xc4580198}},	//   nvoi, втра_, _čola, виях_,
   {{0xd90e8986,0xa5c7007b,0x69cbcf77,0x636f84d6}},	//   _ایک_, _bjóð, _zige, _lønn,
   {{0x5fb78051,0xdced693a,0x5ec080ab,0x6b8700f3}},	//   _שהוא_, _hlač, _শ্রে, rijg,
   {{0x63a398e8,0x2009693b,0x69cb8079,0x0eeb2b07}},	//   zonn, trai_, _xige, टर्स_,
   {{0x63a3e93c,0x7ff41ecd,0x69d8693d,0x25a910e1}},	// [5cd0] yonn, لسلا, _éven, _ikal_,
   {{0x68e98eef,0x63700006,0x65b6026f,0x20091a0c}},	//   zbed, _täna, máha, rrai_,
   {{0x63700c3c,0xf41f025d,0x673c0ad4,0x4fc41170}},	//   _känn, ltä_, _darj, рста,
   {{0x65609523,0x63a3b4db,0x5bcba263,0x63700198}},	//   _comh, wonn, ाद्व, _jänn,
   {{0x637008aa,0x63a3e93e,0x65608068,0x69cbe93f}},	//   _männ, tonn, _domh, _rige,
   {{0x69cb805f,0xf41f0009,0x2d84e940,0xed59882c}},	//   _sige, itä_, _emme_, _rižu_,
   {{0x63a3e941,0x69cb8982,0x38696942,0x261c1099}},	//   ronn, _pige, lyar_, cío_,
   {{0xf2df8028,0x63a3e943,0x569441a4,0xdce40904}},	//   _đâu_, sonn, _таст, _ilić,
   {{0x68e9e944,0x60dbe945,0x69cbe946,0x38696947}},	//   rbed, rcum, _vige, nyar_,
   {{0x2608035a,0x25a9059c,0xc2e900c8,0x68e98c1b}},	//   ांची_, _akal_, কৃতি_, sbed,
   {{0x2f5481e5,0x391592c8,0x8f9c0039,0x25a9008e}},	//   ртыс, _مواز, ויזי, _bkal_,
   {{0xed5a1a03,0x5184b1a9,0xc7c880ff,0x6b854e71}},	//   хом_, _куча, _sốt_, _amhg,
   {{0x644f8acf,0x973c803a,0xdced09d1,0xa5c7008b}},	//   _ácid, moćn, _glač, _sjóð,
   {{0xdb1a8feb,0x3dcd80ee,0xe0df04be,0x50b8803d}},	//   _sitú, _liew_, _afò_, _شدند_,
   {{0x412a181f,0xafdb0bc5,0xe297182d,0x637002f1}},	//   ново_, _drøm, гар_, _fänn,
   {{0x973c812b,0x261c0c15,0x673c25ac,0x213f911f}},	//   noćn, vío_, _sarj, nduh_,
   {{0x38690065,0xc7c88104,0x81bc8029,0x6560832f}},	// [5ce0] gyar_, _tốt_, _spēk, _romh,
   {{0x6560e363,0x636f854f,0x261c2d84,0xe0df03ec}},	//   _somh, _sønn, tío_, _efò_,
   {{0x673c6948,0x9d468098,0xdb038187,0x69c0e949}},	//   _varj, лежд, ponê, ymme,
   {{0x64428358,0x261c05e4,0x3869694a,0xdb03e94b}},	//   tvoi, río_, byar_, lonè,
   {{0x673c694c,0x2d9ee94d,0x6442a53a,0x3940008e}},	//   _tarj, _ítem_, uvoi, mdis_,
   {{0x6442e94e,0x7bd6694f,0x39406950,0x261c016a}},	//   rvoi, _muyu, ldis_, pío_,
   {{0xa3d4931d,0xbf100778,0x6560e951,0x7af8888b}},	//   _सूर_, ालीन_, _tomh, ravt,
   {{0xdd92850c,0xdced0517,0xf41f0364,0x6e931c2c}},	//   _اور_, _plač, ytä_, _الفا,
   {{0xd6d08013,0x0443bfdb,0xd37f012b,0x63748722}},	//   يقة_, _летн, šćih_, _cànc,
   {{0x25a9005f,0x7d046952,0x65b66953,0x10370039}},	//   _skal_, _adis, váha, נטים_,
   {{0x4aa41344,0x7bd60326,0x213f80b9,0xb8068beb}},	//   _खुलव, _auyu, bduh_, _शिवम_,
   {{0x1a9b893f,0xf41f0364,0xdced027f,0x7bd60850}},	//   _איבע, ttä_, _tlač, _buyu,
   {{0x637000f2,0x69da8074,0x3940022b,0x7d042e82}},	//   _vänn, _पंडी, ddis_, _ddis,
   {{0x200b8038,0x25a6e954,0x25bb0358,0x7bd60457}},	//   ácie_, hool_, _whql_, _duyu,
   {{0xf41f4a44,0x25a6e955,0x35d90105,0x63700198}},	//   stä_, kool_, _बूढ़, _tänn,
   {{0x810f11be,0x3f98022b,0x210f0035,0x65b6008b}},	//   िलेख_, _ajru_, िलेश_, páha,
   {{0x2ef5095d,0xdce40140,0x7bd645be,0xab87157b}},	// [5cf0] изар, _slić, _guyu, _бунк,
   {{0x7c2d6956,0x26decfee,0x213fe6c6,0x38696957}},	//   _ipar, ncto_, zduh_, ryar_,
   {{0x6dbc0063,0x2cad83ac,0x3869036e,0x63a703ed}},	//   _właś, _syed_, syar_, mojn,
   {{0x4a5a0051,0x8af80201,0x7bd60a76,0x63a700f1}},	//   _סדרו, _şəxs, _yuyu, lojn,
   {{0x78fa004c,0x3dcd887b,0x68ed4b34,0x7989bca7}},	//   _בפרו, _view_, mbad, view,
   {{0x27e91d39,0xfbd0803d,0x63a700f1,0xab298bba}},	//   mpan_, سته_, nojn, тока_,
   {{0xe0d18013,0x2d8b6958,0x798981b0,0xe4e78d8e}},	//   يزة_, kice_, tiew, _бізн,
   {{0x7c2d6959,0x25a6e95a,0xa8059ae2,0x7c3e809a}},	//   _opar, cool_, азил, łpra,
   {{0x2d8b0b91,0x63a7695b,0x23a50023,0x26110105}},	//   dice_, kojn, ओवाद, दूरी_,
   {{0x442dc0c9,0x7989802f,0x7c3bcc08,0x63a70168}},	//   _ipe_, siew, _isur, jojn,
   {{0x201faf07,0x6449807b,0x2d8b5c92,0x63a70168}},	//   stui_, _hrei, fice_, dojn,
   {{0x6da6695c,0xe5a60adb,0xdb038077,0x7bd60590}},	//   рима, рими, doné, _puyu,
   {{0x7d0481a8,0x68ed01b4,0x7d1b8144,0x69d736b5}},	//   óisi, dbad, _mcus, _auxe,
   {{0x442de95d,0x63a7695e,0x27e90420,0xafdb0366}},	//   _mpe_, gojn, dpan_, _trøj,
   {{0x7529a98e,0xdb1a820f,0x0cb2873c,0xdb03e95f}},	//   _obez, _shtë, _जर्म, goné,
   {{0x00e637be,0x2d8b0024,0x68fb8110,0x7bd606cb}},	//   ржан, cice_, naud, _tuyu,
   {{0x68431814,0x69cf100a,0x442d81e9,0x63a70796}},	// [5d00] онта, _dice, _npe_, bojn,
   {{0xc3fb04de,0x93fb007c,0x39400ce9,0x68ed6960}},	//   _שליש, _שליי, sdis_, abad,
   {{0x442de961,0x7afc6962,0x1fb501bb,0x7c3b81bf}},	//   _ape_, mart, сстр, _asur,
   {{0x6449e963,0xe29b0051,0x7763862f,0x61461878}},	//   _brei, _ישיר, _lonx, _тема,
   {{0x6449e964,0x69c46965,0x25a6e966,0x68fbd9ea}},	//   _crei, mmie, rool_, daud,
   {{0x64498e5d,0x200de967,0x69c46968,0x2d8b6969}},	//   _drei, drei_, lmie, zice_,
   {{0x200d8ab3,0x442de96a,0x63748014,0x6449e96b}},	//   erei_, _epe_, _càna, _erei,
   {{0x644991e6,0x7afc696c,0x79961088,0x200d81ec}},	//   _frei, hart, nnyw, frei_,
   {{0x6449d6ee,0x7afc696d,0xa3b6016f,0x2d8b653c}},	//   _grei, kart, जता_, vice_,
   {{0xe5680159,0x6d40e96e,0x7763862f,0x2d8b696f}},	//   _אַ_, _hama, _conx, wice_,
   {{0x6d40e970,0x2d9e82be,0x7afc6971,0x6370016d}},	//   _kama, _êtes_, dart, _vänl,
   {{0x6d40b9e1,0x7af71820,0x68fb8020,0x6d42e972}},	//   _jama, _sext, caud, ndoa,
   {{0x69cf0021,0x6d40e1e9,0x69c40038,0x2d8b083d}},	//   _rice, _mama, dmie, rice_,
   {{0x6d40e973,0xc90f159a,0x7afc6974,0x69cf491a}},	//   _lama, िल्म_, gart, _sice,
   {{0xd90f0416,0x63a73038,0x69cf57b1,0x439452dd}},	//   وید_, rojn, _pice, царс,
   {{0x6d40e975,0x29dc160a,0x63a71001,0x69d7016d}},	//   _nama, _día_, sojn, _vuxe,
   {{0xdefb0364,0x63a7311a,0x7c2280f1,0x27e94a10}},	// [5d10] вые_, pojn, jtor, upan_,
   {{0x7afc4a8c,0x68ed6976,0x7d1b8081,0x69c425dc}},	//   cart, sbad, _scus, amie,
   {{0x20028824,0x6d40ab75,0xd6d80729,0x27e968f2}},	//   ških_, _bama, рту_, span_,
   {{0x6449e977,0x27e956c1,0x2906e978,0xbd1880e8}},	//   _prei, ppan_, _ndoa_, иції_,
   {{0x8c458bc7,0x92d900c8,0x44396979,0x8d748065}},	//   селе, ারী_, nws_, غاما,
   {{0x200daed2,0x083a00be,0xe29996ba,0xa03a00be}},	//   vrei_, _געשל, лал_, _געשפ,
   {{0x7c22c87c,0xf1bf001c,0x6d40e97a,0x27e6833e}},	//   ator, _khá_, _fama, _aton_,
   {{0x6d40e97b,0x7afc697c,0x798d0359,0x27ffe97d}},	//   _gama, zart, niaw, tsun_,
   {{0x7c229b90,0x68fbb195,0x7afc0041,0xb4b615fb}},	//   ctor, raud, yart, _झरे_,
   {{0x8aa7b0fe,0x6d408431,0xfbd08c2a,0x200de97e}},	//   _кред, _zama, _قتل_, rrei_,
   {{0x6d40e97f,0x9a87bbe9,0x27ffe980,0xb8dd80ab}},	//   _yama, _туал, ssun_, _আল_,
   {{0xbc1a01e5,0x29dc04c3,0x6d408079,0x200de981}},	//   лігі_, _ría_, _xama, prei_,
   {{0x7afc6982,0x5f0a016f,0x65b60061,0x644b0144}},	//   tart, ाणम्_, sáho, _ágil,
   {{0x3d1a18b8,0x3f8c8699,0xf1bf0032,0x29dc002a}},	//   _भावे_, cidu_, _ahá_, _pía_,
   {{0x7afc016f,0xf2d280be,0x09e6102f,0xa3d483b7}},	//   rart, לעם_, собн, _सूई_,
   {{0x29dc02ba,0xe8030321,0xf1bf0317,0x69c46983}},	//   _vía_, _लिखा_, _chá_, umie,
   {{0x69c41690,0xf1bf0013,0x386de984,0x75d38087}},	// [5d20] rmie, _dhá_, nyer_, _văzu,
   {{0x7afc1c41,0x29dc2b52,0x395f8074,0x69c46985}},	//   qart, _tía_, hjus_, smie,
   {{0x6d40e986,0x637000f2,0x671e005e,0x386d80f1}},	//   _pama, _länk, _पाठक_, hyer_,
   {{0x7c22b70b,0x6d40b3dc,0x25bfe7ad,0x89360872}},	//   ttor, _qama, _chul_, _اعدا,
   {{0x23658db7,0xcb6aa43b,0x24588a08,0xd5af9a43}},	//   _bolj_, ладе_, раль_, رفه_,
   {{0x6d40bb93,0x98a20110,0xeb9f006a,0x386d8ec9}},	//   _wama, _sakė_, rsøg_, dyer_,
   {{0x6d40e987,0x3f8c8859,0x39420006,0x27e6e988}},	//   _tama, vidu_, _kaks_, _ston_,
   {{0x7a430065,0xf5968013,0x61ea81ec,0x637005ec}},	//   lítá, _الرج, rpfl, _bänk,
   {{0xdefa81e5,0x61ea8192,0x63700338,0x2bb900c2}},	//   лын_, spfl, _vänj, _इठला,
   {{0x8b658307,0xdce0d006,0x200ba706,0x74138b53}},	//   _والم, _momč, ácia_, _روما,
   {{0x3f8ce989,0x68f98197,0xdb01928a,0x63748a2a}},	//   ridu_, _fewd, _uklá, _hàno,
   {{0x7afa9388,0xa1c68256,0x3f8ce98a,0x5fba98b8}},	//   _hett, _убед, sidu_, _उठवल,
   {{0x443907b3,0x39a10110,0xb87b698b,0x07a68293}},	//   uws_, nėse_, _afín, _ладн,
   {{0x69dae98c,0xab840171,0x7afab92e,0x7a430061}},	//   _kute, пуск, _jett, jítá,
   {{0x7afae98d,0xf1bf0028,0x798d0590,0x7de68b53}},	//   _mett, _phá_, tiaw, _استم,
   {{0x92d900c8,0x69da8542,0xdcfb80d2,0x3f8a09c4}},	//   ারে_, _mute, _imuć, _ambu_,
   {{0xa3d485e8,0x69dabf3e,0xc6f96059,0x798d0573}},	// [5d30] _संग_, _lute, инах_, riaw,
   {{0x7afa8cde,0x644d0102,0x798d09ca,0x2d990122}},	//   _nett, _irai, siaw, lnse_,
   {{0x58d530af,0x798d0b99,0x69dae98e,0xdb1a8118}},	//   _монт, piaw, _nute, _litó,
   {{0x644d698f,0x394200b9,0x3f8a2fb9,0x2d994280}},	//   _krai, _gaks_, _embu_, nnse_,
   {{0x69dad5e3,0x7afa8039,0x2365e990,0x68ff0085}},	//   _aute, _bett, _polj_, maqd,
   {{0x7afa86e3,0x69da93c6,0x661d809a,0xc5fb00a0}},	//   _cett, _bute, ński, _معرض_,
   {{0x7afa9eb4,0xdb1e020f,0x63701aff,0xaca3819d}},	//   _dett, _shpë, _sänk, _idọn,
   {{0x212b9385,0x69da80ad,0x644d6991,0x3fe59594}},	//   ých_, _dute, _orai, ожив,
   {{0xb9018e70,0x7d09bb8c,0x776701c0,0x657d00f1}},	//   _दल_, _ides, _kojx, dhsh,
   {{0x2d8f81eb,0x443fd576,0x69dae2fe,0x752d2acc}},	//   lige_, _isu_, _fute, _abaz,
   {{0x69da9e91,0x644d0356,0x3eb9809a,0x752d0197}},	//   _gute, _arai, ęsto_, _bbaz,
   {{0x637004b8,0x2d8fafc2,0x7afa8a0f,0x29d1805c}},	//   _tänk, nige_, _zett, _išao_,
   {{0x69da811e,0x7afae992,0xbcfb0019,0x637d89c4}},	//   _zute, _yett, rkép, _cèng,
   {{0x2d9903b2,0x752d0102,0x289a807c,0x7ae50197}},	//   anse_, _ebaz, _דינא, _cfht,
   {{0x644d6993,0x27edc16b,0x7d099516,0xaa43643f}},	//   _erai, lpen_, _odes, мерл,
   {{0x644d0b6a,0x443f84be,0x7d09e994,0x752d01bc}},	//   _frai, _osu_, _ndes, _gbaz,
   {{0x2d8fc356,0x1f661bbf,0x6d562aac,0x42d60b73}},	// [5d40] dige_, окам, _inya, _міну,
   {{0x7d09bc79,0xdb0385e4,0x6d560069,0x47c300e8}},	//   _ades, foní, _hnya, дбув,
   {{0x7afa86be,0x072181c4,0x443fe995,0x7f4382be}},	//   _rett, _मानव_, _asu_, _manq,
   {{0x7afad1f4,0x7bc1e996,0x7a430065,0x6d440102}},	//   _sett, _ahlu, sítá, _jaia,
   {{0x69dae997,0x6d44011e,0x7afae998,0x636b48fd}},	//   _sute, _maia, _pett, _güns,
   {{0x69dae999,0xafdb005f,0x09b49b91,0x29005df4}},	//   _pute, _prøv, ुष्य, laia_,
   {{0x27ede99a,0x7e2304bd,0x443fe99b,0x26d8007a}},	//   epen_, _одрж, _esu_, _igro_,
   {{0x7afaa7e4,0x2900699c,0x7d0981a1,0x2d8f811f}},	//   _wett, naia_, _gdes, cige_,
   {{0x7f43e99d,0x7afae99e,0xfc03cc43,0xdce98088}},	//   _banq, _tett, _опто, _sleć,
   {{0x6d56699f,0x4426b937,0x69da9917,0xdce9811f}},	//   _anya, mto_, _tute, _pleć,
   {{0x4426e9a0,0x644d69a1,0x657d11c0,0x6d5609ca}},	//   lto_, _srai, thsh, _bnya,
   {{0x4426a0aa,0x644d4fe8,0x6562aea5,0x6d4469a2}},	//   oto_, _prai, njoh, _caia,
   {{0x4426e9a3,0xf746818b,0x2900011b,0x98b90162}},	//   nto_, _медо, daia_, _masă_,
   {{0x44269820,0x644d02be,0x2d8fbc2c,0x657d2407}},	//   ito_, _vrai, zige_, shsh,
   {{0x4426c4ef,0x212900dd,0x644d0428,0x236c0106}},	//   hto_, tfah_, _wrai, ödja_,
   {{0x4426e9a4,0x644d21d6,0x6d440102,0x290069a5}},	//   kto_, _trai, _gaia, gaia_,
   {{0xd6db0f80,0x47d50013,0x2d8fa82e,0x44268038}},	// [5d50] ате_, سيار, vige_, jto_,
   {{0x44269341,0x2d8f874c,0x27e601a8,0x9f4901fa}},	//   dto_, wige_, íona_, gsað_,
   {{0x2d8f9ab8,0x69da0019,0x636b02af,0x95cb8071}},	//   tige_, ítet, _wüns, ауда_,
   {{0xb23a0158,0xdcef00eb,0x98b90087,0x7bc181e4}},	//   _פערז, dicī, _casă_, _shlu,
   {{0x2d8f8422,0x764e031d,0x4426b469,0x61e204a8}},	//   rige_, _erby, gto_, _čoli,
   {{0x2d8fe9a6,0xdb0391b9,0x25a68267,0x63858196}},	//   sige_, poní, čola_, ягла,
   {{0x4426e9a7,0x443f8326,0xef2301a9,0x6440e9a8}},	//   ato_, _wsu_, _ceļš_, _esmi,
   {{0x443f81c0,0x7d09e9a9,0x44268079,0x9d189bf5}},	//   _tsu_, _udes, bto_, _мост_,
   {{0x4426961b,0x2d8de9aa,0x69e18042,0xf8b91305}},	//   cto_, _imee_, _šveđ, _आरोप,
   {{0x27edc16b,0x6d440102,0x63700106,0x68fd6350}},	//   rpen_, _saia, _hänv, _lesd,
   {{0x2f54835f,0x29d18052,0x6d5600dd,0x27edb9ee}},	//   єтьс, _ušao_, _pnya, spen_,
   {{0xb2ba8039,0xd00e82e3,0xdca60adb,0x7aba81c6}},	//   _המער, خلی_, зами, _הצעו,
   {{0x69c9e9ab,0x6d440ece,0xe6b80aed,0x2d8d819d}},	//   mmee, _vaia, _अर्ज, _mmee_,
   {{0xe820800f,0x69c98ebc,0xf99f0032,0x6d4403e4}},	//   _ममता_, lmee, _ajè_, _waia,
   {{0xaacba441,0x637d87fa,0x4426b38d,0xa3d48744}},	//   ाधिक, _gène, zto_, _संघ_,
   {{0x6d561eb7,0xe0da0098,0x44269bbe,0x69c9a7e7}},	//   _unya, сва_, yto_, nmee,
   {{0x68fd1313,0x44269313,0x38c80077,0x68e469ac}},	// [5d60] _desd, xto_, زاری_, rcid,
   {{0x6f018067,0x68e469ad,0xa3bf000d,0x69da2ff3}},	//   nalc, scid, ेषण_, ítes,
   {{0x4426e416,0x29003944,0x657b8609,0x69c9b052}},	//   wto_, paia_, _bluh, kmee,
   {{0x44268ca9,0xe45a80e8,0x21a60162,0x6374846d}},	//   tto_, йже_, _химм, _gànj,
   {{0x4426c87c,0x69de4062,0x6f01a9ad,0x7afe0084}},	//   uto_, _hupe, kalc, _kept,
   {{0x2b45e9ae,0x6f018353,0x69de69af,0xdce080eb}},	//   _calc_, jalc, _kupe, _domā,
   {{0x877b0158,0xdb1e04f0,0x6f0182d4,0x69de69b0}},	//   _פאלי, _hipó, dalc, _jupe,
   {{0x4426def5,0x7afe00d2,0xd90d819f,0x657ba3c3}},	//   pto_, _lept, لیم_, _gluh,
   {{0x6da39e81,0x6f01e9b1,0x7d02e9b2,0x63ae017f}},	//   _чита, falc, maos, kobn,
   {{0x43868277,0x25a01b03,0x3ce681d6,0x69c981b4}},	//   _علاق, _ajil_, lcov_, amee,
   {{0x69c98069,0x6283809a,0x69de69b3,0xe8b90072}},	//   bmee, czno, _nupe, _आर्च,
   {{0x06970051,0x3ce681ac,0x7d02e9b4,0xdced0140}},	//   לדים_, ncov_, naos, _mlać,
   {{0x68fd4134,0x0cab0098,0x94ab15a6,0x69de0706}},	//   _resd, стни_, стна_, _aupe,
   {{0x9a870dca,0x39469f79,0x6f01b360,0x7f589263}},	//   публ, _haos_, calc, _факс_,
   {{0x27e60307,0x82a469b5,0x69de44d3,0xa29505a8}},	//   íonn_, еште, _cupe, фаві,
   {{0xdb0a80f2,0x673ae8bd,0x2d9c8019,0x31978087}},	//   llfä, letj, ével_, tăzi_,
   {{0xa3cc85b3,0x40340af0,0x394680d7,0x52d080ab}},	// [5d70] रगा_, нетс, _maos_, _স্মৃ,
   {{0x656981bf,0xdb039b39,0xdced09d1,0xb88305b9}},	//   _soeh, koná, _blać, vníč,
   {{0x7bdf0713,0xcb1204de,0xb4bd000d,0x68fd241c}},	//   _huqu, _בלי_, _अरु_, _tesd,
   {{0x6fd80540,0x660500f1,0x7afe001b,0x8c3d8085}},	//   _भूकं, rshk, _zept, _axşa,
   {{0xd0068060,0x673a8009,0xf8b1004e,0x661a9f77}},	//   _جل_, ketj, _شکر_, hutk,
   {{0x0721ac5d,0x8c1c0051,0x661a8359,0x65bd016b}},	//   _माधव_, מודי, kutk, kého,
   {{0x6f018db7,0x661a810b,0x7d0d0214,0x394969b6}},	//   valc, jutk, _odas, odas_,
   {{0xeeeb0104,0x7d0d6816,0x7d02b3ae,0x63700198}},	//   _động_, _ndas, caos, _hänt,
   {{0x62838117,0xfc3086e2,0x69c9a71e,0xb8e585fc}},	//   szno, _محل_, rmee, _एर_,
   {{0x7d0d5a1f,0x378980e8,0x673a806a,0x69c9d7fb}},	//   _adas, ібно_, getj, smee,
   {{0x6da605c2,0x7afe69b7,0x63a4d675,0xe5a63915}},	//   дина, _rept, éine, дини,
   {{0xcb09073a,0x7bdf0228,0xed5a36a2,0x823487d2}},	//   _כל_, _buqu, цом_, _سرما,
   {{0x39492bed,0x7bd70118,0x673a928d,0x63ae00e1}},	//   ddas_, _bixu, betj, tobn,
   {{0x7d0d0006,0x394969b8,0x661a8057,0x7bd7002a}},	//   _edas, edas_, butk, _cixu,
   {{0x661abefe,0x7bdd80e5,0x636f9277,0x2327047f}},	//   cutk, _èsuf, _høns, ьори_,
   {{0x291fe9b9,0x7bd70980,0x636f8366,0x7bdf69ba}},	//   ngua_, _eixu, _køns, _fuqu,
   {{0x3ce680e1,0xdb1e023e,0xdced0088,0x6fd8064a}},	// [5d80] vcov_, _dipò, _slać, _भूखं,
   {{0xdced003a,0x2be1800f,0x644469bb,0x636f8aa2}},	//   _plać, _पढ़ा, _isii, _møns,
   {{0xdb1a8061,0x7d02a13c,0x636f83ba,0xe6bb903e}},	//   _kitö, taos, _løns, _उरोज,
   {{0x6d91816b,0xdb1e0118,0x395902a6,0xa3dd0074}},	//   sťan, _tipó, _gnss_, _तूँ_,
   {{0x7bdf0079,0xe8f70b79,0x3ce6e9bc,0x394680d7}},	//   _xuqu, _юля_, rcov_, _raos_,
   {{0x3ce6a732,0x68f65ff1,0x7643808e,0x53338226}},	//   scov_, lbyd, _osny, вешт,
   {{0x3946e9bd,0x63700106,0x673a807a,0xd25081bd}},	//   _paos_, _häns, vetj, انب_,
   {{0xd91083f8,0x637000f2,0x3d1a0441,0x212069be}},	//   ایش_, _käns, _भागे_, ngih_,
   {{0xb4bd1551,0xa3dd18b8,0x673ab4c8,0x63748980}},	//   _अरे_, _तूं_, tetj, _làni,
   {{0x7d00bc37,0x6370016d,0x661a8ca1,0x3e4c81d0}},	//   _hems, _mäns, tutk, _pět_,
   {{0x63701aff,0x3946e83a,0x7643808e,0x64444a65}},	//   _läns, _taos_, _csny, _asii,
   {{0x661ae9bf,0x7d008088,0x2b5a0162,0x673ae9c0}},	//   rutk, _jems, _anpc_, setj,
   {{0x29049ffb,0x071e06a7,0x321c80e1,0x68f669c1}},	//   mama_, _पांव_, luvy_, dbyd,
   {{0x2904e9c2,0x661ab31b,0xdb0704e8,0x7d0083ed}},	//   lama_, putk, pojí, _lems,
   {{0xd8488028,0x63702b16,0x03200105,0x64440009}},	//   _họ_, _ränt, _बारह_, _esii,
   {{0xf77003f8,0x21200077,0x7bdf05ee,0x2fd80362}},	//   یال_, ggih_, _tuqu, _airg_,
   {{0xe8940364,0x39494166,0xb9070fea,0x2486817f}},	// [5d90] вать, rdas_, _पल_, jzom_,
   {{0x2904bb9c,0xd84890ab,0x753d0019,0x394969c3}},	//   hama_, _mọ_, lesz, sdas_,
   {{0x2904e9c4,0xd848877f,0x637000f2,0x68f6010c}},	//   kama_, _lọ_, _vänt, bbyd,
   {{0x29d1827f,0x3eb80370,0x2a7601c6,0xcdd983de}},	//   _však_, _dyrt_, _נערך_, פֿער,
   {{0xd848882e,0xc9160039,0xb60704b7,0xe800801b}},	//   _nọ_, _אחרת_, _suġġ, लीमा_,
   {{0x8c1c007c,0x59bf00d4,0xb87b0032,0x442900ee}},	//   קווי, ्षवर, _agíg, _mqa_,
   {{0x628704b7,0x6f050101,0x442b02f7,0x6d1f05fc}},	//   nzjo, mahc, htc_, _भांग_,
   {{0xd848c823,0x3f9e80eb,0x7dde80eb,0x291f8c93}},	//   _bọ_, entu_, _mūsd, ugua_,
   {{0x4f95a4b6,0x442901c5,0x65948f25,0xaca381bc}},	//   ерну, _nqa_, _рату, _mpịa,
   {{0x9e6585d3,0x60c28b80,0x80c481a2,0x6d4ba2b7}},	//   евод, _dzom, ाइजे, ldga,
   {{0x7c3669c5,0xa3cc8105,0xc7b20039,0xf1db4497}},	//   _spyr, रगर_, רבי_, _मंगन,
   {{0x2904803a,0xf2df8104,0xc3290051,0x656d0388}},	//   cama_, _đây_, _לו_, _coah,
   {{0x61e1a6e6,0x7c2bc0dd,0x636f83ba,0xb4e0064a}},	//   _hull, ntgr, _uøns, _तली_,
   {{0x61e1e9c6,0x69c6020f,0x68e9a564,0xbea586d2}},	//   _kull, _shke, lced, _палк,
   {{0x61e190f4,0xfaa30110,0x69d9b22c,0x6f0500dd}},	//   _jull, гаро, _kiwe, dahc,
   {{0x61e1e9c7,0xe9d701cf,0x61430258,0x98a000c3}},	//   _mull, екс_, леса, nfić_,
   {{0x7d0639b5,0x61e18bce,0x68f62835,0x7d0094cf}},	// [5da0] maks, _lull, rbyd, _rems,
   {{0x7d064857,0x2904e9c8,0x6d5be728,0x637000f2}},	//   laks, zama_, _anua, _väns,
   {{0x290488a7,0x61e1c87c,0x20090057,0xb87b046d}},	//   yama_, _null, asai_, _agíd,
   {{0x84e68221,0x2ac6801b,0x69d9e9c9,0x32180748}},	//   ходж, _líbí_, _niwe, mrry_,
   {{0xee49801c,0x61e1e9ca,0x6d498428,0xdb03862c}},	//   _lẽ_, _aull, _daea, konä,
   {{0x53349016,0x7d060406,0x753d009a,0xd848e9cb}},	//   тект, haks, zesz, _rọ_,
   {{0xd848d920,0x2d805d0a,0x60c28019,0x81e200ab}},	//   _sọ_, _olie_, _szom, নীর_,
   {{0x61e1e9cc,0xd6570039,0xaca48135,0x7d065536}},	//   _dull, _אילת_, _arụp, jaks,
   {{0x62873836,0x64a38190,0x69d9e9cd,0x753d0019}},	//   zzjo, _бата, _diwe, vesz,
   {{0x61e1870b,0x2904c5ad,0x75228065,0x6d628024}},	//   _full, sama_, lgoz, štač,
   {{0x61e18e5d,0x3eb895f8,0x9d191240,0xe0da8073}},	//   _gull, ært_, монт_, _еве_,
   {{0x29020025,0x7522a7cb,0x7bda815d,0x68e98081}},	//   _neka_, ngoz, _hitu, cced,
   {{0x7bdad08e,0x753d100b,0x61e18a0f,0x79840010}},	//   _kitu, resz, _zull, dhiw,
   {{0x2d801b03,0x69d99fa4,0x7bda8041,0x9f400037}},	//   _elie_, _ziwe, _jitu, ppiù_,
   {{0x61e187f4,0x7bdae9ce,0x6d960029,0x290203df}},	//   _xull, _mitu, mšan, _beka_,
   {{0x661e0057,0xdd9107d2,0xb6bb8039,0x7d0669cf}},	//   dupk, _خوب_, _מצוי, caks,
   {{0x69cd0bc5,0xe1340162,0x3dc902d5,0x7bdaccc6}},	// [5db0] rmae, ынты, _ihaw_, _oitu,
   {{0xf7730b76,0x20093521,0x6da41487,0xf53f016d}},	//   دار_, rsai_, nđan, leå_,
   {{0x3dc9022c,0xcf9380be,0x661e00dd,0x6d9180e1}},	//   _khaw_, נטע_, gupk, sťam,
   {{0x798469d0,0x7bda826b,0x5c759ed5,0x7c2bae23}},	//   chiw, _aitu, клет, ttgr,
   {{0x61e1aedb,0x04459aeb,0x8c45d94d,0x7bdadc00}},	//   _sull, телн, теле, _bitu,
   {{0x7bda8df1,0x6d960353,0x7d066698,0x9f9401ec}},	//   _citu, jšan, zaks, mäß_,
   {{0x7bda95ee,0x85bb8bbe,0xfebb026a,0x61e1811c}},	//   _ditu, _فارس_, _راست_, _qull,
   {{0x2055d7f5,0xb4e01251,0x61e1e9d1,0x27ef80b9}},	//   втор, _तले_, _vull, _ptgn_,
   {{0xee498104,0x7bdae9d2,0xf7718872,0x7d062d5d}},	//   _sẽ_, _fitu, لاد_, vaks,
   {{0x61e1c97c,0x7bda8959,0x7655009a,0x6d9601a9}},	//   _tull, _gitu, _krzy, gšan,
   {{0x7d060665,0x3ea5cfe6,0xbea58b26,0xab84af84}},	//   taks, тинг, танк, _сутк,
   {{0xa3e64c4b,0x3dc901e9,0x7bdabc7d,0xb90680ab}},	//   _बंद_, _chaw_, _zitu, _বড়_,
   {{0xe8188d38,0x7d060341,0x290269d3,0x394de9d4}},	//   _दिया_, raks, _reka_, mdes_,
   {{0xc8838afe,0x394de9d5,0x290269d6,0x27e2026c}},	//   ığı_, ldes_, _seka_, _rukn_,
   {{0x7d0638e0,0x79842947,0x7bce0168,0x69dc8061}},	//   paks, thiw, rmbu, _éret,
   {{0x320a2c15,0xaad384c5,0xdb071e51,0x3cb30870}},	//   rsby_, धेयक, rojá, ụzụ_,
   {{0x6f039e92,0x1b1700c8,0x394de9d7,0xdb1a8009}},	// [5dc0] _kenc, দ্ধে_, ides_, _yhtä,
   {{0x798420fd,0x7d044d5d,0x1acc80ab,0x2902074b}},	//   shiw, _heis, রুয়া, _weka_,
   {{0x6f03e9d8,0x290269d9,0x7d040a4c,0x213f808e}},	//   _menc, _teka_, _keis, keuh_,
   {{0x6b8182af,0x394de9da,0xdb0a804a,0x7d041fe7}},	//   _allg, jdes_, llfø, _jeis,
   {{0x3d07853e,0x7bdae9db,0xdb0a85e4,0x394dd2f5}},	//   हणजे_, _pitu, sofí, ddes_,
   {{0xf6510019,0x39403139,0x7d043858,0x66e60251}},	//   جئے_, leis_, _leis, _јова,
   {{0x7bdae9dc,0x79a68f9c,0x76550035,0xcb1301c6}},	//   _vitu, крие, _grzy, בלו_,
   {{0x2902808b,0x394de9dd,0x32538081,0x7bda8db1}},	//   úka_, gdes_, рвър, _witu,
   {{0xf9931a15,0xa3b22490,0xebe6835f,0x8c43d068}},	//   ירה_, टका_, _розп, _кете,
   {{0xd378e9de,0x394d8722,0x394001e4,0x6f0396d6}},	//   _biće_, ades_, heis_, _cenc,
   {{0x7d0402af,0x82668077,0x6d962585,0x6f03e9df}},	//   _beis, _جهان, ršan, _denc,
   {{0xac190c8e,0xceb30051,0x7d0411cd,0x614684ae}},	//   ному_, יית_, _ceis, _једа,
   {{0x7d0420ee,0x394001ca,0x6d9600eb,0x2616864a}},	//   _deis, deis_, pšan, पूजी_,
   {{0x394b4467,0x6f03e9e0,0xd37881a1,0x7dde81a9}},	//   _sacs_, _genc, _fiće_, _bīst,
   {{0xdcfb803a,0x9e348364,0x2d9969e1,0x7982bbc2}},	//   _sluč, _сейч, éres_, _klow,
   {{0x7d0435b1,0x3dc9076d,0xdcfb80c3,0x6f03e9e2}},	//   _geis, _uhaw_, _pluč, _zenc,
   {{0x2d990665,0x6d5f69e3,0x08552252,0xd5b901a9}},	// [5dd0] mise_, _inqa, ываю, stās_,
   {{0x76550d38,0x7d0469e4,0x2d99138e,0x9f4d841c}},	//   _przy, _zeis, lise_, mpeã_,
   {{0x39402d84,0x2d9969e5,0x6d96011f,0xb924019d}},	//   beis_, oise_, kšal, _jesụ_,
   {{0x2d9969e6,0x39401820,0xa97900be,0x6d9602d4}},	//   nise_, ceis_, _נאָכ, jšal,
   {{0xa2d58a27,0x394d8711,0x68ed0df6,0xe4ff128a}},	//   येन्, vdes_, mcad, _štěň,
   {{0x2d9969e7,0x447c00be,0x61e5005d,0x69dd69e8}},	//   hise_, ונדע, _kuhl, _hise,
   {{0x69dd2015,0x6f03e9e9,0xdb07007b,0x61e50009}},	//   _kise, _renc, lljó, _juhl,
   {{0x6f03e9ea,0x394de9eb,0x61e52899,0xca748196}},	//   _senc, udes_, _muhl, рушы,
   {{0x6f0395bd,0x7d0469ec,0x2d9969ed,0x3f858114}},	//   _penc, _reis, dise_, thlu_,
   {{0x69dd0573,0x7d0469ee,0xd3788067,0x6d5f01b9}},	//   _lise, _seis, _piće_, _anqa,
   {{0xf7718077,0x69dd3917,0x2d993374,0x7d0469ef}},	//   لاگ_, _oise, fise_, _peis,
   {{0x69dd4f57,0x78a48b89,0x63ad80f7,0x7de881d0}},	//   _nise, _žive, éanf, _těsn,
   {{0x394056cf,0x7d0469f0,0x442f8362,0x1b0680ab}},	//   veis_, _veis, ntg_, _রাতে_,
   {{0xade30af3,0x7d0402af,0x69dd4280,0x68fb8aa2}},	//   गदान_, _weis, _aise, lbud,
   {{0x7d0469f1,0x69dd69f2,0x81e580ab,0x2d9969f3}},	//   _teis, _bise, বীর_, bise_,
   {{0x644985db,0x2d9969f4,0x69dd69f5,0xdebc0326}},	//   _osei, cise_, _cise, _garƙ,
   {{0x07a60071,0x6e21e9f6,0x394069f7,0x200d9243}},	// [5de0] гаан, lulb, reis_, nsei_,
   {{0x44220886,0x69dd14cf,0x7dda801b,0x68ed69f8}},	//   muk_, _eise, _půso, acad,
   {{0x7c3bc73f,0x7bde02c4,0x394003cd,0x4b7b03de}},	//   _apur, _iipu, peis_, _נאטו,
   {{0x69dd150f,0xc4868009,0xac0a95fc,0x1a9b03de}},	//   _gise, ллек, енда_, _טייע,
   {{0x44223533,0x7bde4d77,0x68fb9f7f,0x6b98be54}},	//   nuk_, _kipu, dbud, tivg,
   {{0x66e3108d,0xdee30705,0x7c3b826c,0x2d9969f9}},	//   _гора, _гори, _dpur, zise_,
   {{0x442200d7,0xb4db0722,0x442f8122,0x6374e9fa}},	//   huk_, ndàr, atg_, _bànr,
   {{0x636b0a0b,0x7bde00e4,0x44220dc6,0x661a84e8}},	//   _düny, _lipu, kuk_, vrtk,
   {{0x442269fb,0x7f4e01c0,0xc17304de,0x656081a8}},	//   juk_, _kabq, מחה_, _inmh,
   {{0x2d9969fc,0x4422028a,0x3f9a010b,0x7bde69fd}},	//   wise_, duk_, nipu_, _nipu,
   {{0x7c22e9fe,0x06d780ab,0x2d9969ff,0x63b56a00}},	//   luor, _দ্বি, tise_, vozn,
   {{0x443b010c,0x61e50850,0x44222ecc,0x7bde1fe7}},	//   _ppq_, _ruhl, fuk_, _aipu,
   {{0x2d996a01,0x69dd6a02,0x7bde0133,0x68e28135}},	//   rise_, _rise, _bipu, _igod,
   {{0x2d992899,0x69dd6a03,0x09bf06bf,0x7bde0573}},	//   sise_, _sise, ्ष्य, _cipu,
   {{0xf1a70a08,0x7bde08b3,0xf0b08117,0x637d810c}},	//   гран, _dipu, _دیکھ, _bènj,
   {{0x443b008e,0xeeeb00ff,0xd5a48019,0x2e139459}},	//   _tpq_, _đống_, _رہ_, _ابوح,
   {{0x69dd6a04,0x44226a05,0x6d42ea06,0x200f0019}},	// [5df0] _vise, cuk_, deoa, égi_,
   {{0xe8ff03d3,0x78bd026f,0x7bde6a07,0xe71900f7}},	//   _août_, _vysv, _gipu, ئيات_,
   {{0x7f4e0952,0xdced2752,0x4fc40150,0xe7ea0035}},	//   _dabq, _hlađ, сста, _झूठा_,
   {{0xe8ff00e7,0xdced012b,0xe8df019d,0x71472361}},	//   _coût_, _klađ, _klọb_, _схож,
   {{0x27e6ea08,0xab29a4dc,0x7c228037,0x23299c74}},	//   _nuon_, вола_, guor, воли_,
   {{0xdced003a,0xe2999c9b,0x3f83012b,0xaa1584bd}},	//   _mlađ, кал_, _ulju_, афиј,
   {{0x4422358b,0x442fea09,0x25a90144,0x45d5862c}},	//   zuk_, stg_, _ojal_, _вовс,
   {{0x44220967,0x27e6d736,0x200d8074,0xe8ff00e7}},	//   yuk_, _buon_, tsei_, _goût_,
   {{0x77858049,0x7c8790ef,0x64498364,0x68fb9277}},	//   илиз, _суве, _usei, rbud,
   {{0x7d0bea0a,0x6c848013,0x25a90006,0x47599156}},	//   lags, _الكم, _ajal_, трия_,
   {{0x3915826a,0x8d6604fa,0x7bde3855,0x200d8152}},	//   _نواز, авне, _ripu, ssei_,
   {{0x44221dda,0x38608052,0x7d0bb097,0x200d8162}},	//   tuk_, _šire_, nags, psei_,
   {{0x0c230656,0x6e218420,0x26050072,0x660b8084}},	//   омян, sulb, हीती_, _šokė,
   {{0x68e2ea0b,0x44221600,0x6a864bc3,0x7d0b807b}},	//   _zgod, ruk_, алга, hags,
   {{0x44220393,0xe2970037,0xf8bf077f,0xd19600a9}},	//   suk_, аар_, _ayé_, ашањ,
   {{0x44220397,0xd378ad16,0x394f9407,0xe9df1b9c}},	//   puk_, _mića_, _jags_, _ciú_,
   {{0xe0da2ce0,0x55bb0051,0x7bde6a0c,0x7d0ba20d}},	// [5e00] тва_, _במקו, _tipu, dags,
   {{0x6fc200e1,0x7c228198,0x7f4e01b4,0xdced0609}},	//   môck, vuor, _qabq, _imaġ,
   {{0xdd8f0077,0xe9df16a5,0x6f0708ae,0x81ab8264}},	//   _روی_, _fiú_, _dejc, _গঠন_,
   {{0x1636893f,0x2bb4023c,0x26170105,0x3f9a6a0d}},	//   ינער_, ंकवा, _पटरी_, sipu_,
   {{0x6c54be32,0x9346c39b,0xd4038a0e,0xcb6aa109}},	//   склу, инде, оящи, каде_,
   {{0xd378805c,0xa6ca07b6,0xe45703de,0x5bb7902a}},	//   _bića_, _алга_, יינט_, алія_,
   {{0x80db00ab,0x6d960390,0xe81e06f0,0x7d0bbaab}},	//   যুদ্, ršaj, यंका_, bags,
   {{0x26ca0904,0x39526a0e,0x316d83ed,0x6379026b}},	//   _izbo_, ndys_, gjez_, _hìnt,
   {{0xab668389,0x394fa459,0x2cbf9341,0x7c2280e5}},	//   _квал, _dags_, _gyud_, quor,
   {{0x10370039,0x1be10fce,0xd3788088,0x25a91388}},	//   סטים_, _गूगल_, _fića_, _sjal_,
   {{0xdceb2e1e,0xdced192c,0x628e0bcf,0x9a6a8250}},	//   šiča, _slađ, jzbo, _جمال_,
   {{0x63b8ea0f,0xd5b80cde,0x68e2abfe,0xd6d78084}},	//   lovn, ися_, _ugod, шты_,
   {{0x28d28e70,0x0f1100ab,0x7d160114,0x8fa682ac}},	//   देशि, স্টঃ_, _ddys, _каде,
   {{0x2cad04b7,0x798600fc,0xa3cc864a,0x61e881f6}},	//   ħed_, _alkw, रगट_, _kudl,
   {{0xb3458073,0xdce0801b,0xda780081,0xdcef89d1}},	//   leçã, _pomě, аят_, _šeče,
   {{0x7de18029,0x63b887dd,0x3f986838,0x61e88197}},	//   _vēst, hovn, _amru_, _mudl,
   {{0x63b88ee1,0x0f150221,0x6b9c44cf,0x26c53887}},	// [5e10] kovn, ймаю, birg, _šlo_,
   {{0x7d1d8117,0xeeeb0104,0x644d6a10,0x5eab00c8}},	//   _össz, _đồng_, _isai, _করবে,
   {{0xd6db0698,0x7d0b9614,0xdfd80098,0x6f07128a}},	//   тта_, tags, рът_, _vejc,
   {{0xe945003d,0x25a6ea11,0xb6d980be,0x3ed983de}},	//   _اردی, gnol_, אַנט, אַנא,
   {{0xe81e0ee6,0xa3ae15bc,0xf0d281bc,0x7d0b90b9}},	//   _पिया_, _कदम_, _dịkọ, rags,
   {{0x7f850013,0xd3788024,0x63b8807a,0xdb0380e7}},	//   _السن, _pića_, govn, onné,
   {{0x752d002e,0x7989805d,0x7d0b97ea,0x799b808e}},	//   _ocaz, thew, pags, tiuw,
   {{0xe81889a3,0x2129078a,0x78a486c2,0x016580a9}},	//   _दिशा_, ngah_, _živa, скио,
   {{0xa3b7131d,0x2d9d8435,0x628e00b9,0x79898a53}},	//   जवा_, miwe_, zzbo, rhew,
   {{0x63b88a56,0x23748013,0x2d9db051,0xab748013}},	//   covn, _والح, liwe_, _والإ,
   {{0xd90f8986,0x7d098359,0x1d0a1354,0x394f86f3}},	//   _ہیں_, _kees, лени_, _tags_,
   {{0x645be5d1,0x443f861b,0x7d09c3d4,0xaca380ff}},	//   _krui, _kpu_, _jees, _ngừn,
   {{0x7d0998ce,0x2b1b83bb,0xe739b6de,0x753bea12}},	//   _mees, _नयाँ_, _бел_, _mbuz,
   {{0xf1b9ea13,0x7d099dd7,0x443fe75a,0xd8d681c6}},	//   loš_, _lees, _mpu_, _פוסט_,
   {{0xa2bb0fce,0x15f5845b,0x25a6831d,0x2d9db845}},	//   _शुद्, _استح, ynol_, kiwe_,
   {{0x69cf6a14,0x7d0980eb,0x2d8b026f,0x21296a15}},	//   _chce, _nees, chce_, ggah_,
   {{0xf1df81ce,0xa06701f3,0x6564009c,0x443fe3e5}},	// [5e20] _पूछन, бата_, _inih, _npu_,
   {{0x753bea16,0x4b260112,0x6d466a17,0x9b4612c8}},	//   _abuz, _умов, leka, _اندو,
   {{0x6564003e,0x7d09ea18,0xe61a34d2,0xf1b98140}},	//   _knih, _bees, уде_, koš_,
   {{0x645b94cc,0x10a61e0b,0x7d098579,0xe818816f}},	//   _brui, _гимн, _cees, _दिला_,
   {{0x29006a19,0x63b8a01b,0xe3bf05e4,0x61e88bb1}},	//   mbia_, tovn, luña_, _sudl,
   {{0x645b9581,0x6d466a1a,0xdd92853d,0x3f98017f}},	//   _drui, heka, _کور_, _umru_,
   {{0x3ce98289,0x63b88a56,0x7d09838e,0x443f80ee}},	//   žava_, rovn, _fees, _epu_,
   {{0x6d460025,0x7d09ea1b,0xb3458073,0xf1b98088}},	//   jeka, _gees, teçã, goš_,
   {{0x645bea1c,0x63b8812b,0x61e8b419,0xc95301c6}},	//   _grui, povn, _wudl, למה_,
   {{0x69c40352,0xb34583a7,0x752d0087,0x61e88ec9}},	//   hlie, reçã, _scaz, _tudl,
   {{0x7d098ef2,0xdceb3f13,0x69c45ed5,0x61fc026c}},	//   _yees, žičn, klie, jprl,
   {{0x443f80b9,0x65760144,0x290dd794,0xd3788140}},	//   _ypu_, _coyh, caea_, _kićo_,
   {{0x4426803b,0x69c46a1d,0xb4e9154b,0x7c2634e6}},	//   nuo_, dlie, _बली_, gukr,
   {{0x2d9dea1e,0xd3788390,0xf41f0198,0x69c40901}},	//   ziwe_, _mićo_, rrä_, elie,
   {{0x6d466a1f,0x3f9eea20,0x60c290e4,0x98b001b9}},	//   beka, mitu_, _hyom, _ħaġa_,
   {{0x3f9ead06,0x69c40698,0x644d6a21,0x6440808e}},	//   litu_, glie, _tsai, _opmi,
   {{0x644d6a22,0x7d0f6a23,0x61e2aba3,0x442681bc}},	// [5e30] _usai, macs, _miol, juo_,
   {{0x44268d46,0x3f9ee5c7,0x7d09ea24,0x32110035}},	//   duo_, nitu_, _sees, pszy_,
   {{0x69c44e81,0x29000081,0x2d9d8435,0x9f40008b}},	//   blie, bbia_, tiwe_, rpið_,
   {{0xd6d8291d,0x7d0f02a3,0x44268a54,0x05c9090f}},	//   сту_, nacs, fuo_, रतिब,
   {{0x60c28065,0x4426ea25,0x78a4826f,0x2d9d82a0}},	//   _nyom, guo_, _živn, riwe_,
   {{0x6d460c5a,0x7d0992eb,0xe81e27ec,0x2d9dbe9d}},	//   zeka, _wees, _पिता_, siwe_,
   {{0x3f9ed5f0,0x2d820bc5,0x290b0b80,0x1dc9016f}},	//   ditu_, ykke_, _keca_, रतात,
   {{0xa3e90935,0x4426ea26,0x753baaac,0x798d0cf4}},	//   यदा_, buo_, _ubuz, nhaw,
   {{0xf1b98b67,0x61e2ea27,0x44268568,0x52fb001b}},	//   roš_, _diol, cuo_, ्राउ_,
   {{0x3f9e8ee2,0x69c40029,0x6d464db2,0xf1b9a98e}},	//   gitu_, zlie, weka, soš_,
   {{0x27e30586,0x6d462ced,0xa119880b,0x798d4eb5}},	//   _mijn_, teka, _نقاط_, khaw,
   {{0x27e300f3,0x69d08424,0x798d01e9,0x2bee081f}},	//   _lijn_, _डीपी, jhaw, _इंदू_,
   {{0x6d463c86,0x98c78013,0x3f9ec995,0xef0ecd44}},	//   reka, _اغان, bitu_, _ом_,
   {{0x7c26246f,0x2b47823e,0x3f9eb937,0x29190609}},	//   rukr, nenc_, citu_, _adsa_,
   {{0x44268135,0x7d0f6a28,0x290b201d,0x6d461af9}},	//   zuo_, bacs, _beca_, peka,
   {{0xe3bf07f4,0xddc3017a,0x290b1f79,0xe8fa0f25}},	//   ruña_, _общи, _ceca_, рла_,
   {{0x290b6a29,0x387f89e1,0x386d8118,0xb4c88c28}},	// [5e40] _deca_, nyur_, nxer_, _उरे_,
   {{0x290002d6,0x69c46a2a,0x291900e4,0xbc6a9190}},	//   sbia_, slie, _edsa_, یمان_,
   {{0xdb18820f,0x69c40add,0xfa6a0329,0x290b076b}},	//   sovë, plie, _танк_, _feca_,
   {{0x4426ea2b,0x2e3a80be,0x63bc03d5,0x302a1ff8}},	//   tuo_, יגענ, lorn, _комп_,
   {{0x973c8024,0x27e300f3,0xdb18a620,0x2019816b}},	//   liće, _fijn_, lové, ásil_,
   {{0x44269caf,0x63bc6a2c,0xd7c5016f,0x925a80f7}},	//   ruo_, norn, वतःच, لشعر_,
   {{0x63ad8307,0x973c8668,0xdb18cb44,0x3f9ea4c8}},	//   éana, niće, nové, vitu_,
   {{0x27e31dea,0x63bc0c8d,0xb4e9052a,0x3ea70144}},	//   _zijn_, horn, _बले_, únte_,
   {{0x44268998,0x973c80d2,0xd90d80d7,0x3f9eea2d}},	//   quo_, hiće, ایه_, titu_,
   {{0x47349c74,0x60c28010,0x3dc6ea2e,0xdfd080f7}},	//   чнос, _vyom, llow_, عيد_,
   {{0x63bc2d32,0x3f9eea2f,0x973c8289,0xddc90084}},	//   dorn, ritu_, jiće, rydž,
   {{0x973c81dd,0x7d028cfa,0xdb18816b,0x9c1301bc}},	//   diće, nbos, dové, _jọgb,
   {{0x9ccb0084,0x290b6a30,0x160a0072,0xe7ea00c2}},	//   рына_, _reca_, हीतर_, _झूला_,
   {{0x63bc27f8,0x3dc6808e,0x798d0362,0xdceb81f4}},	//   gorn, hlow_, whaw, _čičo,
   {{0xd3788d11,0x973c84a8,0x27e3623b,0x4422286c}},	//   _moć_, giće, _rijn_, ark_,
   {{0xdb18816d,0x442201f4,0x3f8a11ec,0xf7709abb}},	//   llvä, brk_, _albu_, _تاچ_,
   {{0x63bc408c,0x27e300f3,0x12e70048,0x290b6664}},	// [5e50] born, _pijn_, _мінг, _veca_,
   {{0xd3788025,0x798d43c6,0x973c9487,0x2bd2063a}},	//   _noć_, shaw, biće, _दीपा,
   {{0x78a48db7,0x6e288db7,0xc332010f,0x6d96011f}},	//   _živl, nudb, _אוי_, ršav,
   {{0xf1a71fec,0x3dc6e35f,0xb8d100ab,0x27e300f3}},	//   _фрон, glow_, _ওর_, _wijn_,
   {{0xdfdb0698,0xe3b004c0,0x6d9602a5,0x661d809a}},	//   _във_, _سری_, pšav, ąski,
   {{0x39496725,0x9f4300f1,0x8cce0ee6,0x7d0d46ff}},	//   leas_, _mijë_, _सरसो, _leas,
   {{0xa91b007b,0xd3788369,0x7d02ab81,0xb5a792c0}},	//   _alþi, _doć_, bbos, _драй,
   {{0x63bc21f8,0xdb038e15,0x98af82a5,0x386d8722}},	//   zorn, tonó, šače_, txer_,
   {{0x3dd20114,0x637d80d7,0x973c8bcf,0x7d1b9267}},	//   _rhyw_, _bènt, ziće, _idus,
   {{0x39490cac,0x63bc1042,0xdb038333,0x6e288267}},	//   heas_, xorn, ronó, fudb,
   {{0xa2bb2296,0x98ab83bf,0x6d960668,0x637d810c}},	//   _शुल्, ıcı_, kšat, _dènt,
   {{0x973c803b,0x7d0d6a31,0x7c2480f7,0xdb0381a8}},	//   viće, _ceas, áirg, inní,
   {{0xd1b884c0,0x7d0d0046,0x39496a32,0x7bc70267}},	//   _بالا_, _deas, deas_, flju,
   {{0x27ff8077,0xff5187d2,0xdb18826f,0x973c8289}},	//   mpun_, _سخت_, tové, tiće,
   {{0x7d1b803a,0x63bc6a33,0x67210009,0x69d0864a}},	//   _odus, rorn, _öljy, _डीडी,
   {{0x973c81dd,0x31660b5a,0xdb18816b,0x7d0d4e3a}},	//   riće, ñoz_, rové, _geas,
   {{0xa2a28bb8,0xef1a0596,0x27ff9ade,0x1dc900d4}},	// [5e60] _केन्, йма_, npun_, रतरत,
   {{0x6d564001,0x98a68668,0xdb0a816d,0x7d1bea34}},	//   _haya, šiće_, llfö, _adus,
   {{0x7d0d6a35,0xee3a36b8,0x27ff87d5,0xdd8f803d}},	//   _yeas, сне_, hpun_, گون_,
   {{0x394924de,0x27ff90e1,0x63ad81a8,0xdd9980e8}},	//   ceas_, kpun_, éann, оші_,
   {{0x6d566a36,0x29126a37,0xdd8f8829,0xd37880c3}},	//   _maya, maya_, دون_, _poć_,
   {{0x6d560587,0x29126a38,0x7d1b8009,0xa3b200d4}},	//   _laya, laya_, _edus, टकट_,
   {{0x61e6050b,0xdb03823e,0x9c13019d,0x6da400c3}},	//   _kikl, tonò, _tọgb, nđas,
   {{0x29122c96,0x7de8800d,0x637d89c4,0x7bc18338}},	//   naya_, _měst, _bèns, _eklu,
   {{0x61e61e18,0x7d0d0039,0xdb03ea39,0xdcfb85f3}},	//   _mikl, _reas, ronò, _sluć,
   {{0x1b0f8a49,0x2912480e,0xdcfb8024,0xe7be0d72}},	//   _সাথে_, haya_, _pluć, ्तिप,
   {{0x6d56335d,0x7bc7003a,0x64443516,0xb3471243}},	//   _baya, vlju, _apii, _liçõ,
   {{0x29120397,0x6d560079,0x61e6572e,0xb7d78065}},	//   jaya_, _caya, _nikl, _ہونا_,
   {{0x6d56431f,0x6fbe2a9e,0x29121ade,0x6e28ea3a}},	//   _daya, ्तां, daya_, sudb,
   {{0x7dda801b,0x9f4303ed,0xe3bf0118,0x237a00e5}},	//   _zůst, _vijë_, ruño_, _copj_,
   {{0x7d0d14f2,0x6d408289,0x20070668,0x39490834}},	//   _teas, _obma, ćnim_, teas_,
   {{0x29126a3b,0x25a228d2,0x5eab00ab,0x31c40073}},	//   gaya_, cikl_, _করলে, есув,
   {{0x39496a3c,0x78a4a3c3,0x61e66a3d,0xdb1ae935}},	// [5e70] reas_, _živj, _dikl, _aktí,
   {{0x39496a3e,0x443959b2,0x442b1498,0x6d566a3f}},	//   seas_, mts_, muc_, _zaya,
   {{0x29124d7e,0x6d566a40,0x443913a0,0x394905e4}},	//   baya_, _yaya, lts_, peas_,
   {{0x29124aa0,0x7ddf189e,0x210082d4,0x6d5640ac}},	//   caya_, _būsi, nčič_, _xaya,
   {{0x44390b39,0x442b6a41,0x63adad84,0x657d0168}},	//   nts_, nuc_, éano, ërhy,
   {{0x44391098,0x6f1c0118,0x69d8047f,0xbb428081}},	//   its_, _gdrc, _èver, вешк,
   {{0x44396a42,0x6d86002a,0x442b5b1c,0xdce89238}},	//   hts_, _sóam, huc_, _çoğa,
   {{0x44390029,0xdb1c00f1,0x27ffbcba,0x8065a20b}},	//   kts_, torë, tpun_, движ,
   {{0x349489c7,0x27ff8867,0x6d4b8057,0x442b02a5}},	//   _затр, upun_, mega, juc_,
   {{0x29126a43,0x27ff87d5,0x442b6a44,0x6d598417}},	//   zaya_, rpun_, duc_, ldwa,
   {{0x63a3b5aa,0x29126a45,0x25a20115,0x44395a20}},	//   minn, yaya_, tikl_, ets_,
   {{0x63a3ea46,0x6d4bea47,0x7c248024,0x64a601e5}},	//   linn, nega, šire, дама,
   {{0x6d560f03,0x61e66a48,0xe72e846e,0x7c2bb9d2}},	//   _vaya, _rikl, _ие_, nugr,
   {{0x69c9a5ac,0xa3cd81c4,0x6d4bea49,0xa3bf81c4}},	//   llee, रति_, hega, ीति_,
   {{0x0caa823c,0x29125bfd,0x6d564a93,0x28e006b7}},	//   _कश्म, taya_, _taya, पेनि,
   {{0x63a3ea4a,0x6d4bea4b,0x69db8216,0x69c9ea4c}},	//   hinn, jega, nmue, nlee,
   {{0xb906053e,0x44390051,0x6d4bea27,0x63a3ea4d}},	// [5e80] _पण_, cts_, dega, kinn,
   {{0x29126a4e,0x78a48d11,0x63a3ea4f,0x65699ade}},	//   saya_, _živk, jinn, _aneh,
   {{0x27e7ea50,0x63a3ea51,0x69c9d072,0x27ef8106}},	//   _minn_, dinn, klee, _lugn_,
   {{0x27e7ea52,0x290fea53,0x3ea70013,0x6d4bea54}},	//   _linn_, _nega_, únta_, gega,
   {{0x6f0e01c5,0x63a3d95a,0x6aa6b6a6,0xc7b98061}},	//   _tebc, finn, गप्र, tről_,
   {{0xf626038c,0x290f8074,0x69c2dfa8,0x6f1c08ae}},	//   _одго, _aega_, _skoe, _udrc,
   {{0x6d4bea55,0xd2578a14,0xe5a68b9c,0x13398019}},	//   bega, дцы_, _живи, ستوں_,
   {{0x290f8052,0xd90d80d5,0xdb1c016d,0xaca4819d}},	//   _cega_, میم_, llrä, _asụp,
   {{0x290fea56,0x274a8009,0x63a38ed4,0x27e78219}},	//   _dega_, очно_, binn, _binn_,
   {{0x27e78cac,0x61fe005c,0xdb150019,0xfc67803d}},	//   _cinn_, _otpl, kozá, _تخفی,
   {{0xd12f8f2f,0x69c9e0a6,0xdce08029,0xe5350678}},	//   _их_, blee, _tomē, нень,
   {{0x4426ea57,0x27e78125,0x38698503,0x4439251b}},	//   oro_, _einn_, _šare_, tts_,
   {{0x20070024,0x27e7821e,0x5c7402c7,0x61fe02d7}},	//   ćnik_, _finn_, влят, _atpl,
   {{0x4426956b,0x443959d0,0xcf2680d7,0xf8ad8019}},	//   iro_, rts_, _آرشي, _چکی_,
   {{0x44396a58,0xeb9180be,0x44268428,0x7d0d81fa}},	//   sts_, אָן_, hro_, ðask,
   {{0xd378811f,0xdce4016b,0x63a3ea59,0xceb3807c}},	//   _dići_, _znič, zinn, _שיק_,
   {{0x629a00e1,0x777c0168,0x90990081,0x2e388118}},	// [5e90] útor, _borx, чват_, léf_,
   {{0x69c0ea5a,0x657bbca4,0x2d9f80b9,0x6d4b8365}},	//   home, _souh, _smue_, wega,
   {{0x69c0b1ea,0x63a3da22,0x4426a7e1,0x6d4b9044}},	//   kome, vinn, ero_, tega,
   {{0x63a39c67,0x4426ea5b,0x69c08035,0xdb1c03c9}},	//   winn, fro_, jome, voré,
   {{0x69c0ea5c,0x290f9686,0x777c03a8,0x69c981ed}},	//   dome, _rega_, _forx, vlee,
   {{0x290fea5d,0x42558767,0x6d4bcb36,0x7c39951e}},	//   _sega_, етит, sega, rtwr,
   {{0x63a3ea5e,0x4426ea5f,0x6d4b8359,0x290f84f0}},	//   rinn, aro_, pega, _pega_,
   {{0x27e7ea60,0x3cf90035,0x6569b73a,0x973c8140}},	//   _sinn_, ंडों_, _uneh, vića,
   {{0x69c9d4e9,0x20198019,0xb7bd802e,0x63a3a88c}},	//   rlee, ési_, luţi, pinn,
   {{0x2007005c,0x290f81bc,0x69c9cef4,0x39591690}},	//   ćnih_, _wega_, slee, _lass_,
   {{0x290f8db7,0x27e79bcd,0xaa9580f7,0xd13181a8}},	//   _tega_, _vinn_, _ثلاث, _مما_,
   {{0x69c0a602,0xdb0a003e,0xceb202f6,0x6a538201}},	//   come, čník, ריט_, _nəfə,
   {{0x394d8006,0xd378817f,0x27e7ea61,0xa2838019}},	//   mees_, _sići_, _tinn_, _سیکو,
   {{0x33d50d13,0xe51f81a2,0x394d81b0,0x399183a8}},	//   віст, मृति_, lees_, _dáse_,
   {{0x6da6117e,0x1a6602e3,0x3243062c,0xfb8501e2}},	//   _пика, ریحی_, лерг, тыўн,
   {{0x394dce81,0x7989c650,0xdb152825,0x4426ea62}},	//   nees_, nkew, rozá, yro_,
   {{0x3959034a,0xf992893f,0x1f660470,0xe3b207d2}},	// [5ea0] _dass_, ארן_, нкам, _مرد_,
   {{0xdb18ea63,0x44268073,0xdc3b0039,0x69c093fa}},	//   toví, vro_, _צעיר, zome,
   {{0x7dca808b,0x3959048d,0x69c0ea64,0x61fe1c02}},	//   lýsi, _fass_, yome, _utpl,
   {{0x4426e486,0x39596a65,0xf6510019,0x69c08118}},	//   tro_, _gass_, گئے_, xome,
   {{0x4426ea66,0x69c0ea67,0xdceb011f,0x7dd60118}},	//   uro_, vome, šića, cáse,
   {{0xdb18801b,0x69c0d85b,0xb7bd8087,0x9f478168}},	//   poví, wome, buţi, _dinë_,
   {{0x1c1c823c,0x394d867f,0xc33303de,0x60e58085}},	//   _निकल_, fees_, אוו_, ərmə,
   {{0xd25981e2,0x394006ab,0xdb03810c,0x2b5a1670}},	//   ьці_, nfis_, hinè, _lapc_,
   {{0xdcef803a,0xcfa68758,0xf9930039,0xd84e81bc}},	//   _šeće, ешни, טרה_, _gọlf_,
   {{0x69c0a943,0x25a6d8b5,0x6d444a8b,0x661c08ae}},	//   some, liol_, _abia, _kvrk,
   {{0x69c086d4,0x6456178f,0x394da833,0x6d44026c}},	//   pome, _asyi, bees_, _bbia,
   {{0xceb3004c,0x394dea68,0x25a6c380,0xac19054c}},	//   טית_, cees_, niol_, мому_,
   {{0xa3bd109b,0x6fcb0192,0xdb1c0428,0x39596a69}},	//   इकल_, büch, gorï, _rass_,
   {{0x6fcb02af,0x6a538201,0x25a68114,0x69c6000b}},	//   rück, _səfə, hiol_, _akke,
   {{0x2d9903d3,0x1c1d0074,0x7ddf0110,0xdb0a9727}},	//   ères_, _भटकल_, _būst, lofó,
   {{0x6298803b,0xdb038168,0xf1a40a4c,0x2b5a07f1}},	//   izvo, tinë, грун, _eapc_,
   {{0x656d6a6a,0x25a6831d,0x6d4f178f,0x2bd2009a}},	// [5eb0] _inah, diol_, meca, _दीवा,
   {{0x7dd66a6b,0x69c60125,0x6d4f0063,0x6d5d2d24}},	//   ráse, _ekke, leca, ldsa,
   {{0x1b0f80ab,0x765a01ac,0xf770045b,0x7c2f3fb7}},	//   _সালে_, _štyr, حاق_, lucr,
   {{0xe821823c,0x6d5d0d1a,0x6d4f6a6c,0x63a73002}},	//   _मिला_, ndsa, neca, lijn,
   {{0x76550d38,0xf8d50105,0xbde5826b,0x2fd900f7}},	//   _wszy, _दरिय, _abèé, _يوجد_,
   {{0xfaa59988,0xe6136a6d,0x63a744dc,0x394d81b0}},	//   кало, _مشر_, nijn, wees_,
   {{0x25a682e6,0xbd0580e7,0x69cd0114,0x41b5a634}},	//   biol_, _créé, olae, ксит,
   {{0x6d4f02fd,0x63a72db6,0x290901b4,0x25a6ea6e}},	//   jeca, hijn, nbaa_, ciol_,
   {{0xdd948196,0x6d4f40fc,0xc8db8361,0x6594802e}},	//   _саты, deca, मेंट, _сату,
   {{0xfd4d8028,0x656d6a6f,0xd378825b,0x66e581a4}},	//   _ngoạ, _anah, _biću_, копа,
   {{0x9f47801b,0x63a7016b,0x6d5bea70,0x6fcb01ec}},	//   _jiné_, dijn, _kaua, rüch,
   {{0xe5a61e58,0x7bc3ea71,0xdb03c906,0xb33c81b9}},	//   тими, lonu, diné, _imħa,
   {{0x6d5b80f6,0x399a8158,0x69cd031d,0x1fb58b5b}},	//   _maua, _קינד, dlae, _искр,
   {{0x6d5bea72,0xd37881f4,0x7bc3ea73,0x63a763b9}},	//   _laua, _fiću_, nonu, gijn,
   {{0xc3328bea,0x442fea74,0xdb18ea75,0x6d4f3656}},	//   יום_, hug_, nová, beca,
   {{0x38608503,0x3a25008b,0x6449c224,0xdb1c36af}},	//   _širi_, álpa_, _opei, morí,
   {{0x61ebea76,0x09e3176e,0xdb1883fb,0xdb1c3a88}},	// [5ec0] _migl, ротн, hová, lorí,
   {{0x386044df,0xcfb500c8,0xe0d71a18,0xdb18801b}},	//   rvir_, _জীবন, тву_, ková,
   {{0xe9da04ae,0xdb1c157a,0x1fb50615,0xe3b22452}},	//   _око_, norí, устр, _مرگ_,
   {{0x5bcaa3e7,0xdb1883fb,0x2d800036,0x8ab701c6}},	//   ित्व, dová, _joie_, _יהיו_,
   {{0x7bc3ea77,0x25a68114,0x6449802a,0x6d5bea78}},	//   fonu, riol_, _cpei, _daua,
   {{0xdceb1123,0xd7030098,0x661aa86c,0x7bc3c844}},	//   žićn, _взри, ystk, gonu,
   {{0x5ee000c8,0x61ebea79,0xa6e000ab,0xdb1c16f3}},	//   _প্রে, _bigl, _প্রয়, jorí,
   {{0x442f833e,0xdb1c6a7a,0x69d9831d,0x2fc78637}},	//   bug_, dorí, _chwe, _akng_,
   {{0x6d4f00d2,0x61eb80d2,0xdb348bca,0xbcfb0036}},	//   veca, _digl, _مذاک, ndée,
   {{0x656d016b,0x81d800ab,0xd3788390,0x2d926a7b}},	//   _snah, াদি_, _piću_, _alye_,
   {{0xdb1c160a,0x7f5c4b51,0x6d4f6a7c,0x61eb8098}},	//   gorí, _marq, teca, _figl,
   {{0x891a87d2,0x661aea7d,0x63a76a7e,0x61eb81e8}},	//   _آغاز_, rstk, wijn, _gigl,
   {{0x2019800d,0x6dbc94ce,0xae068cfd,0x5f76803d}},	//   ásit_, mčad, वीजन_, _لاغر,
   {{0x8fa39056,0xdb0700f1,0xdb03a746,0x2d9202d6}},	//   _каче, mijë, tiné, _elye_,
   {{0x248d1874,0x7c2f3653,0x442f81ec,0x63a748d2}},	//   šem_, sucr, zug_, rijn,
   {{0x7bc3ea7f,0x6dbc825b,0x656d6a80,0xe5c400e8}},	//   zonu, nčad, _unah, _всьо,
   {{0x98a20201,0x3dc9049f,0x7bc38059,0xdb18801b}},	// [5ed0] _bakı_, _ikaw_, yonu, zová,
   {{0x2fc75ea9,0x3b5512b2,0x24840198,0x7f5c6a81}},	//   ông_, _скор, ämme_, _carq,
   {{0xa2a2835a,0xd00684c0,0x6449ea82,0xcf9380be}},	//   _केल्, _گل_, _spei, סטע_,
   {{0xdb1881d0,0x7bc8810c,0x6dbc81a1,0x442fea83}},	//   vová, _akdu, jčad, tug_,
   {{0xd006803f,0x7c24803b,0xa3b80077,0xfc3f6a84}},	//   _دل_, širn, _سایر_, ntí_,
   {{0x442fde6e,0x61ebea85,0xdb1c0693,0xdb189bff}},	//   rug_, _sigl, yorí, tová,
   {{0x442fea86,0x05bb8c48,0x61eb80e5,0xa9a5a8c5}},	//   sug_, _قدرت_, _pigl, ликд,
   {{0xdb18800d,0x2fc780b9,0x61fe816b,0x386681a3}},	//   rová, _skng_, ípla, _bror_,
   {{0xdb1881d0,0x61ebd750,0x7bc3ea87,0xf94a03de}},	//   sová, _vigl, ponu, געפֿ,
   {{0xdb1c28f4,0x2d9900f3,0x68fbd561,0xdb1881d0}},	//   torí, ëren_, scud, pová,
   {{0x6f1505a4,0x386692bf,0x1bec82f1,0x61ebea88}},	//   _mezc, _eror_, _छूटल_, _tigl,
   {{0x3ce98052,0xed5700e8,0x6b81cfbe,0x78b981c0}},	//   žavu_, гою_, _holg, _txwv,
   {{0x711a804c,0xdb1c05e4,0x2d805834,0xf7459612}},	//   _נוספ, sorí, _voie_, _бело,
   {{0xf77387bd,0x395fea89,0xe739859d,0x6dbc8b80}},	//   _خاص_, ldus_, _чек_, pčag,
   {{0x395d8282,0x6b81b183,0x442b0635,0x69c41a0c}},	//   _kaws_, _molg, arc_, toie,
   {{0x395fdd4a,0x798d2277,0x7d198035,0x6d4e136f}},	//   ndus_, gkaw, jaws, íhač,
   {{0x7f5c2755,0xdb018019,0xa3e38327,0x38660174}},	// [5ee0] _parq, _emlé, नगा_, íor_,
   {{0xe3b21a3e,0x7d160079,0xe7370088,0xb8cc02f1}},	//   _درب_, _heys, леу_, _कइ_,
   {{0x11d609a7,0x6fd00338,0x798d0326,0x7c2b8299}},	//   _متحد, läck, bkaw, ergr,
   {{0x7bda80f1,0x7f5c0079,0xa80602d0,0xc51699ed}},	//   _shtu, _warq, ttığ, ابات,
   {{0xd8760250,0x395f831d,0x7f5c00e5,0x7d166a8a}},	//   _صاحب, ddus_, _tarq, _meys,
   {{0x6b818511,0x7c24817f,0x39525d7e,0x9326803d}},	//   _colg, širo, leys_, ارشن,
   {{0x6b81ea8b,0x2d9c80e7,0x2611807a,0x3d0b8072}},	//   _dolg, èves_, jšo_, ारखे_,
   {{0x2bdb11bc,0x31606a8c,0x395dea8d,0xa8060214}},	//   _मीना, ndiz_, _caws_, ptığ,
   {{0x6b81ea8e,0x395d81e9,0xa3c4000d,0x5b368872}},	//   _folg, _daws_, एका_, _معار,
   {{0xa2bf86b7,0xa8570039,0x973c8042,0x75240f3e}},	//   _लुक्, נייה_, mićk, _adiz,
   {{0x9f4a00f7,0xd6d084a3,0x3f6381e5,0x35b5148d}},	//   _cibé_, تقد_, стыб, ибор,
   {{0x3866904a,0xd6d781bb,0x386080d2,0x6d468106}},	//   _tror_, ыты_, _širu_, _ökad,
   {{0x98a38676,0x5b270c73,0xe4a7018b,0x5eab00ab}},	//   _лице, льва, урно, _করছে,
   {{0x75246a8f,0x44200110,0xbe8680d5,0xfc3f6a90}},	//   _ediz, _dvi_, _مجبو, rtí_,
   {{0xfc3f0626,0xdcfb800d,0x6f1aea91,0x44202147}},	//   stí_, _souč, matc, _evi_,
   {{0x19580196,0x7d160bde,0x6f1aea92,0x6fd03ede}},	//   ласы_, _geys, latc, läch,
   {{0x798d6a93,0x2d9900f7,0x0f150c4f,0x97152fc0}},	// [5ef0] rkaw, mhse_, имаю, имац,
   {{0x6fd001ec,0x973c826c,0x644d0637,0x7d198122}},	//   näch, dićk, _ipai, waws,
   {{0xb8cc0403,0xb87b07d0,0x941f8085,0x644e007a}},	//   _के_, _egíp, ərək_, čniš,
   {{0x6b818257,0x7bc76a94,0x29f8011f,0xa2bf90f7}},	//   _solg, loju, _očaj_, _लुग्,
   {{0xf41f0364,0x6d5f02a3,0x58870196,0x395d81e9}},	//   nsä_, _maqa, _сына, _raws_,
   {{0x20090393,0x395dad02,0x6a85853b,0x7bc72585}},	//   mpai_, _saws_, илла, noju,
   {{0x6b8198db,0x395dbf33,0x2fc580c9,0x52758012}},	//   _volg, _paws_, volg_, рулу,
   {{0x91fc80eb,0xaca38133,0x395dd012,0xd18580e5}},	//   _grām, _agụn, _qaws_, рлий,
   {{0x3f83012b,0x5d8496a5,0x395fea95,0x20096a96}},	//   _koju_, _القل, rdus_, npai_,
   {{0x6f1a9502,0x44200267,0xdb1c6935,0x20548081}},	//   gatc, _rvi_, korá, стър,
   {{0x44200025,0x6d5f6a97,0x7bc76a98,0x3f8329b4}},	//   _svi_, _baqa, doju, _moju_,
   {{0x61ef5b31,0x629c0353,0x8afc809a,0x657d0168}},	//   _nicl, vzro, _wnęt, gjsh,
   {{0x6d498013,0x290d8010,0x7d09002a,0x3952062c}},	//   _mbea, mbea_, ñesa, veys_,
   {{0xdee59628,0x66e59f0d,0x6fd000f2,0x61ef4564}},	//   _коли, _кола, räck, _aicl,
   {{0x6d5f19ea,0x629c007d,0x644d0102,0xf53f006a}},	//   _faqa, uzro, _epai, rnår_,
   {{0xd1321921,0x2d990192,0x6026004a,0x66761190}},	//   تمر_, chse_, идба, یدار,
   {{0x7dd60065,0x3f83011f,0x7bc74f68,0x80dd80d4}},	// [5f00] láso, _boju_, boju, _परफे,
   {{0xdb1c002a,0x6d49802a,0x753b802e,0x973c8503}},	//   borá, _abea, _acuz, vićk,
   {{0xed5a835f,0x6d5f3c69,0xee3a6a99,0x7641ea9a}},	//   кож_, _yaqa, тне_, ntly,
   {{0x973c842b,0x6d498362,0x61ef1a25,0x3998826b}},	//   tićk, _cbea, _gicl, _kése_,
   {{0x61e46a9b,0x63aaea9c,0x6d498706,0x3f830091}},	//   mmil, tifn, _dbea, _foju_,
   {{0xbcfb00f7,0xb4d69094,0x7dd60019,0x61e4391a}},	//   idéa, _हरी_, káso, lmil,
   {{0x2b4707d9,0x7ddd0019,0xd25080f7,0x443f8609}},	//   _önce_, lése, سنة_, _equ_,
   {{0x61e46a9d,0x63aa80dd,0x7dd60061,0x39918032}},	//   nmil, sifn, dáso, _dáso_,
   {{0x973c856f,0x7df38087,0x290001ca,0x61e4008b}},	//   lići, _măsu, icia_, imil,
   {{0x2d84ea9e,0x63ad80f7,0x6d5f6a9f,0x656081a8}},	//   _home_, éant, _saqa, _hamh,
   {{0xa3e3873c,0x290001ac,0x2d84a2b1,0x61e46aa0}},	//   नगर_, kcia_, _kome_, kmil,
   {{0x6560b3d6,0x61e402a5,0x7c2d8042,0x656280f1}},	//   _jamh, jmil, šare, ndoh,
   {{0x64429413,0x7bc72f42,0x2d84812b,0x94a82fcd}},	//   ntoi, toju, _mome_, атра_,
   {{0x29003bda,0xc0a9845b,0x2d848390,0x2484016d}},	//   ecia_, _حامل_, _lome_, ämma_,
   {{0xf41f4a44,0xdced003a,0xf1a700c5,0x79a71287}},	//   ssä_, _inač, аран, арае,
   {{0x2d84eaa1,0x80dd836d,0x3d10809a,0x973c82a5}},	//   _nome_, _परमे, ारों_, dići,
   {{0x7d1d4a79,0xc10400f7,0x6f18822c,0x7bc76aa2}},	// [5f10] mass, توقي, _kevc, poju,
   {{0xe7190013,0xe733045b,0x9951826f,0x68f5801b}},	//   ايات_, تصر_, _máš_, ězdi,
   {{0x212682a5,0x6f188214,0x2d84eaa3,0x973c8140}},	//   _odoh_, _mevc, _bome_, gići,
   {{0x29000098,0x2d84eaa4,0x7d1d27f6,0xd256007c}},	//   ccia_, _come_, nass, _פשרה_,
   {{0x9951803e,0x7dd60019,0x6560a360,0xe81600c2}},	//   _náš_, záso, _damh, दीदा_,
   {{0x2bbb8013,0x7d1d6aa5,0xdb0aa53a,0x212680d7}},	//   خاصة_, hass, nifè, _adoh_,
   {{0xd6e500c8,0xfee500c8,0x06e500c8,0xe69500f7}},	//   _প্রয, _প্রধ, _প্রি, _الأد,
   {{0xd2b80bea,0x7dd88038,0x78b800d2,0x753b8380}},	//   ילות_, písa, šavš, _ucuz,
   {{0xf8a98077,0x6442eaa6,0x60068a14,0x7d1d50a4}},	//   دگاه_, ctoi, бным_, dass,
   {{0x7dd60065,0x2919209d,0x25a90859,0x6f1881a1}},	//   táso, _lesa_, _amal_, _cevc,
   {{0x201f8073,0x7ddd0061,0x7d1d6aa7,0xdce401a1}},	//   ssui_, zése, fass, _knić,
   {{0xceb2010f,0x29196aa8,0x7d1d6aa9,0x442feaaa}},	//   ליי_, _nesa_, gass, org_,
   {{0x515a8039,0xa5c701fa,0x7c2902d4,0x7ddd0118}},	//   _תכנו, _slóð, šern, xése,
   {{0x39988118,0x799b8326,0x394b07b6,0x69c4819d}},	//   _vése_, lhuw, _abcs_, ịstị_,
   {{0xe2973058,0x29196aab,0xf8bf16f0,0x69966aac}},	//   бар_, _besa_, _axé_, брах,
   {{0xc2433a46,0x7ddd0019,0xe9df0028,0x973c807d}},	//   янск, tése, _chú_, vići,
   {{0xe0da29b3,0x29003888,0x291903d2,0x4ca600c8}},	// [5f20] ува_, rcia_, _desa_, _গুরু,
   {{0x6560eaad,0xe47b0051,0x2d848051,0x29000098}},	//   _samh, _עריכ, _some_, scia_,
   {{0x44220370,0xc7d68039,0xdb038722,0x2e238214}},	//   lsk_, צועי_, dinà, nıf_,
   {{0x4a5b0051,0xdb1c1b32,0x631480ab,0x291909ca}},	//   _עדכו, forç, _সাইট_, _gesa_,
   {{0x44223b6a,0xfe678077,0x628e6aae,0x996c81d0}},	//   nsk_, _کد_, lybo, těž_,
   {{0x6442eaaf,0xd00f04c1,0x973c8115,0x7d1d0061}},	//   rtoi, _سلف_, pići, zass,
   {{0x2d84803a,0x6442ae17,0x7d046ab0,0xf3f1eab1}},	//   _tome_, stoi, _ofis, _dị_,
   {{0xed5a835f,0x7d1d02df,0x6f1e1c32,0x65608c41}},	//   _щоб_, xass, lapc, _uamh,
   {{0x7d1d63da,0x628e016b,0x6f1882d4,0xdb1c0980}},	//   vass, hybo, _pevc, corç,
   {{0x99518a56,0x7d046ab2,0x7d028098,0x7c2d84a8}},	//   _váš_, _afis, lcos, šarc,
   {{0xf8d5146d,0x59c81a42,0x63ae01b4,0x7ddd0061}},	//   _दर्प, लवार, dibn, vésb,
   {{0x4424bca5,0x7d02eab3,0x628e6ab4,0x799b80f3}},	//   _kvm_, ncos, dybo, chuw,
   {{0x29196ab5,0xdb03b573,0x6f1e0019,0x3ced02f1}},	//   _resa_, liná, kapc, äev_,
   {{0x7d0435e4,0x7c240110,0x29190168,0x7df38087}},	//   _efis, _dvir, _sesa_, _păst,
   {{0x29193dbc,0xe9df001c,0x1b1d80ab,0xdb0384e8}},	//   _pesa_, _phú_, _নামে_, niná,
   {{0x7d1d0372,0x61faeab6,0x26dc8858,0x7c228d23}},	//   qass, _mutl, _izvo_, ksor,
   {{0x79860133,0x442480f3,0x9f940198,0xf8bf0216}},	// [5f30] _dokw, _nvm_, kää_, _edén_,
   {{0x32550bba,0x1ae380ab,0x6fdd80e7,0x7c229a47}},	//   _двор, নুয়া, pèce, dsor,
   {{0xe9df1c1d,0xd6db6ab7,0xdb0383f2,0x9f4781d0}},	//   _thú_, ута_, jiná, _jiná_,
   {{0xdb03936f,0xfe7000f7,0x3cd59cf4,0x9b450019}},	//   diná, عدل_, ожес, _انھو,
   {{0x442fb6b5,0x7c2284dc,0x913a00be,0x61fa81a1}},	//   urg_, gsor, _דערק, _autl,
   {{0x61faa3ca,0x7e620035,0xdb03ca84,0x42098ff7}},	//   _butl, łopa, finá, анко_,
   {{0xdb03827f,0xe2998973,0x3869622d,0x65958071}},	//   giná, рай_, lvar_, _даву,
   {{0x80dd82a8,0xe8f9b606,0x44226ab8,0x7d02eab9}},	//   _परदे, шли_, ysk_, ccos,
   {{0x2eb90e5b,0x7529eaba,0x38690085,0x7c22eabb}},	//   _आशुत, _idez, nvar_, csor,
   {{0x6dbc812b,0x6d4d6abc,0x7d1b94cf,0x80c600ab}},	//   nčan, _abaa, _heus, লেক্,
   {{0x7c240025,0x98b98182,0x61fa80d2,0xbcfb0118}},	//   _svir, ısı_, _gutl, rdén,
   {{0x3cf08105,0x442204dc,0x24ea16d9,0xe29483de}},	//   ुँचे_, tsk_, имни_, _צװײ_,
   {{0x44246abd,0x764508f9,0x628e0428,0x7d1be554}},	//   ém_, hthy, wybo, _meus,
   {{0x69cf6abe,0x4422021e,0x628e0110,0xf8bf0032}},	//   _akce, rsk_, tybo, _adéo_,
   {{0x79866abf,0x394908dc,0x6f1e026c,0x7d0401b9}},	//   _pokw, ffas_, vapc, _tfis,
   {{0x7c24805c,0xbcfb6ac0,0x63ae0359,0x7d042767}},	//   širi, ndél, sibn, _ufis,
   {{0xef1a6ac1,0x3f879a4c,0x386957a5,0xe7aa01cf}},	// [5f40] има_, _konu_, gvar_, авал_,
   {{0xafdb06be,0x2d82025b,0x65646ac2,0x75298d19}},	//   _spør, ljke_, _haih, _adez,
   {{0x9f940364,0x2b580da8,0x442481a1,0x2eee016d}},	//   vää_, merc_, _svm_, äff_,
   {{0xdb03826f,0x442481bb,0x2d8216f2,0x893612c8}},	//   viná, _pvm_, njke_, _بعدا,
   {{0x9f94025d,0x65643adf,0x64465c71,0x7d1beac3}},	//   tää_, _maih, ntki, _deus,
   {{0x7c22bde4,0x7d02a634,0x752981bc,0x65640198}},	//   rsor, scos, _edez, _laih,
   {{0xd6270652,0x7bcad2ed,0x644602f1,0x9f940198}},	//   _море_, rofu, htki, rää_,
   {{0x6f1c056f,0x9f940364,0x81d800c8,0x6eca86ab}},	//   _herc, sää_, াদক_, _सुषु,
   {{0xb9028dd2,0xa3da009a,0x46cf86ae,0x9f94156e}},	//   _धर_, ़ता_, _सुबह, pää_,
   {{0x7dd65fcf,0x39988077,0x3f98808b,0xff988eef}},	//   lásh, _désa_, óru_, ској_,
   {{0x6f1c10b6,0x614685e9,0x65642a58,0x4efb00be}},	//   _merc, _межа, _baih, יליג,
   {{0x65640362,0xdced0372,0xbcfb1a25,0x386d1075}},	//   _caih, _jlaħ, rdéo, _šerm_,
   {{0x656435e4,0x7b671cf4,0x6eca8b49,0x61e2eac4}},	//   _daih, отве, _सुरु, _ihol,
   {{0xa0078060,0x76450114,0x7763823e,0x8c48899b}},	//   _بقول_, ythy, _ganx, mağı,
   {{0x6dbc803a,0x8f9b84de,0x92681612,0x61e2eac5}},	//   včan, _דיגי, орта_, _khol,
   {{0x60f911e9,0x65c4038c,0x1a9b83de,0x2bdb0305}},	//   сная_, _обја, בילע, _मीरा,
   {{0xbcfb6ac6,0x6f1c2a72,0x7d1bb1d2,0x61e2a884}},	// [5f50] ndém, _berc, _reus, _mhol,
   {{0x6f1c1fa7,0xe94509d7,0xdfd10013,0x7d1bd41d}},	//   _cerc, _کردی, ريا_, _seus,
   {{0x44396ac7,0xd5758c8e,0x38691da3,0x3ea70032}},	//   lus_, зуль, svar_, ànt_,
   {{0x753d6ac8,0x76450114,0xdce083bf,0xbc681190}},	//   ngsz, rthy, _almı, _امین_,
   {{0x6dbc811f,0x6f1c0114,0x3d0a86a7,0x7d1b802a}},	//   pčan, _ferc, ाड़े_, _veus,
   {{0xf1bf07ca,0x2d9db845,0x61e2eac9,0x291f804f}},	//   _hjá_, shwe_, _ahol, waua_,
   {{0x6fd4823e,0x6fba380a,0x69c4833b,0xdced0609}},	//   càci, ्वरू, čien, _flaħ,
   {{0xd24e9168,0x7763b050,0x6dbc8968,0x98ab07c0}},	//   اني_, _sanx, nčal, _hacı_,
   {{0x44395ba9,0xa3bd03bb,0x25adeaca,0x65640b20}},	//   jus_, ेका_, _imel_, _raih,
   {{0x44396acb,0xee39a7d4,0x61e2eacc,0x25bf81a3}},	//   dus_, бно_, _ehol, _hjul_,
   {{0x59bd0a0d,0xb90180ab,0x44396acd,0x2b580037}},	//   ्कार, _দল_, eus_, verc_,
   {{0x6d59eace,0x61e2eacf,0x995181d6,0xdb150061}},	//   newa, _ghol, _báť_, kozó,
   {{0xea000104,0x65640364,0x61e995ce,0x8c4882bb}},	//   _biết_, _vaih, mmel, cağı,
   {{0x61e9ead0,0x24441a62,0x291d804f,0xf1bf04be}},	//   lmel, röm_, _hewa_, _ajá_,
   {{0x64460d38,0x6721803b,0xf7708bca,0x443901e2}},	//   stki, malj, _جان_, aus_,
   {{0x61e9d625,0xe8fa34fd,0x6f1c6ad1,0xf2d283de}},	//   nmel, сла_, _serc, געל_,
   {{0x6f1c0ca9,0x6d59ead2,0x21200b50,0x671f800f}},	// [5f60] _perc, dewa, raih_, _मजाक_,
   {{0x25adbd87,0x7c26614e,0xea00001c,0x61e9e647}},	//   _amel_, mskr, _giết_, hmel,
   {{0x6d59a350,0xd90d0019,0x212000b9,0x61e9ead3}},	//   fewa, _چیف_, paih_, kmel,
   {{0x7dd65084,0x7bce6ad4,0x7e62009a,0x6d59b747}},	//   fási, lobu, łopo, gewa,
   {{0x7c2612fa,0x938ac3e8,0x0b8a8098,0x6b88ead5}},	//   nskr, йска_, йски_, _podg,
   {{0x61e2ead6,0x25ad8ad4,0x5334b9d0,0x7bce01f6}},	//   _shol, _emel_, фект, nobu,
   {{0x6721ba10,0x9f478009,0x61e2ead7,0x6d59ead8}},	//   dalj, _minä_, _phol, bewa,
   {{0x291d8a73,0x6d59e6f3,0x8c4685fa,0x8c4887c0}},	//   _cewa_, cewa, _небе, tağı,
   {{0x7df40012,0x291d81da,0xdb0a80f7,0x64a3b312}},	//   _răsp, _dewa_, lifí, _зата,
   {{0x4439677d,0x7c262e3d,0x08e900ab,0x9f9d077f}},	//   vus_, dskr, টুকু_, yìí_,
   {{0x44396ad9,0x61e2eada,0xe5350110,0x3f8a0bb1}},	//   wus_, _thol, мень, _mobu_,
   {{0x7c24811f,0x3f9e820f,0xa2cd0eb4,0xa44b816b}},	//   širu, shtu_, _दुष्, lášť_,
   {{0x7c266adb,0x6721a5dd,0xf09f026b,0x69cd03a8}},	//   gskr, balj, _afàn_, voae,
   {{0x200beadc,0xf1bf0125,0x4426a76a,0xdeb4c792}},	//   ície_, _sjá_, iso_, _облы,
   {{0xea000104,0x44396add,0x15ec83b7,0x7ac41f0d}},	//   _viết_, sus_, जगार_, есте,
   {{0x61fe66e7,0x4426eade,0xdb0a9727,0x7c265050}},	//   _dupl, kso_, difí, bskr,
   {{0xa2cd090f,0xea000028,0x91fc8029,0x752d011e}},	// [5f70] _दुर्, _tiết_, _krās, _idaz,
   {{0x44296adf,0x4c9c0039,0x7bce1e12,0xade10074}},	//   _iva_, _לבחו, cobu, _गीतन_,
   {{0x44290cde,0x3f8a026f,0xb81e80a5,0x44268114}},	//   _hva_, _dobu_, _मौसम_, eso_,
   {{0xdb1acb0e,0x672180d2,0x4429021e,0xf53f00e8}},	//   _októ, zalj, _kva_, ngå_,
   {{0x291deae0,0xf8c1123a,0x6e3aeae1,0x4426bf60}},	//   _rewa_, _एशिय, hutb, gso_,
   {{0x6d599142,0x291d8458,0x6dbcb351,0x44295bef}},	//   sewa, _sewa_, nčaj, _mva_,
   {{0x752d007d,0xbe880012,0x442682ec,0x61e9eae2}},	//   _odaz, _есте_, aso_, tmel,
   {{0x44290025,0xd9e3050d,0x7d04a62c,0xdb18816b}},	//   _ova_, _कीमत_, ñist, mový,
   {{0xdb18826f,0x7c2480f7,0xf53f013c,0x4426eae3}},	//   lový, áirt, dgå_, cso_,
   {{0x61e9eae4,0x91fc81a9,0x7c29eae5,0x7c2604dc}},	//   smel, _prāt, _iver, vskr,
   {{0x44292f21,0x7c29eae6,0x6721df13,0xdb1c01ac}},	//   _ava_, _hver, ralj, porú,
   {{0x67218052,0x61368059,0x9f478009,0x262781a1}},	//   salj, rülü, _sinä_, rđo_,
   {{0x61fe5373,0x6fbf016f,0x893480f7,0x4c830098}},	//   _supl, ्वां, _أعما, вляв,
   {{0x99808038,0xdb18826f,0x28e28c28,0x9fb58201}},	//   čiť_, kový, _परति, dəçi_,
   {{0xaa430037,0xdb18816b,0x386d9b90,0x0eac064a}},	//   керл, jový, lver_, _टेंड,
   {{0x7c29eae7,0x442682a3,0xe9da1a8c,0x3f8a005c}},	//   _over, yso_, іка_, _sobu_,
   {{0x7984085c,0x1f66012f,0x44294226,0xd54901a8}},	// [5f80] rjiw, мкам, _gva_, _رجيم_,
   {{0x1b1800ab,0x7d09826b,0xe8de00c2,0x61fe0198}},	//   _তাকে_, _afes, _मरीच, _tupl,
   {{0xdfcf0307,0x9f5f87e2,0x7c29b3b0,0x386d8257}},	//   جيل_, rquè_, _aver, hver_,
   {{0x4426eae8,0xe57a8fe6,0x6fd48980,0x7c298799}},	//   tso_, юзе_, làct, _bver,
   {{0x4426c3e8,0xa3e306b7,0x4197003d,0x045a80f7}},	//   uso_, _फीड_, _آشپز, تجات_,
   {{0x7c2981ac,0xa3a8809a,0x7d09e387,0xdb1883c1}},	//   _dver, खों_, _efes, bový,
   {{0x4426dc51,0x7c298051,0x394dc2ae,0x6fdd823e}},	//   sso_, _ever, ffes_, tècn,
   {{0x6d44022c,0x32538098,0x386d0267,0xd91a804a}},	//   _ncia, твър, _šeri_, цьк_,
   {{0x660da02e,0x7c2981b9,0x6dbc80e1,0x798b8326}},	//   _čaka, _gver, yčaj, _dogw,
   {{0x83fd8019,0x7dd8ba88,0xada40035,0x39950338}},	//   _erős, dísi, óźni, _påsk_,
   {{0x7c2981ac,0x3869826c,0x6fd4823e,0xa3cb8072}},	//   _zver, _šart_, dàct, ळकर_,
   {{0x5693a4b6,0x6e3a8711,0x6d4400e5,0x4ad200c2}},	//   тают, rutb, _ccia, _दुधव,
   {{0x2edb023c,0xdb050307,0xf8e2890a,0x50e28778}},	//   _भर्त, _amhá, _परिय, _परिष,
   {{0x21249a2f,0x237a03a7,0x6d440609,0x69c2e03e}},	//   lamh_, _cnpj_, _ecia, _hjoe,
   {{0xe2f810ac,0xb90c01bc,0xdce281d6,0x00000000}},	//   дері_, _ọbịb, jkoľ, --,
   {{0x21248af9,0x75208065,0x44292dc6,0xd5b8053b}},	//   namh_, _nemz, _tva_, _осы_,
   {{0xa3ce9d2a,0x6d5d3332,0xb4dd8d86,0x4429191f}},	// [5f90] रवा_, mesa, _डरे_, _uva_,
   {{0xdb18803e,0xd6db1b6f,0x399c01fa,0x7c2989ed}},	//   tový, оте_, _vísa_, _rver,
   {{0x7c298687,0x63b5007a,0x19951edc,0xfbdf0187}},	//   _sver, mizn, _заня, ntêm_,
   {{0x6d5d6ae9,0x68e2eaea,0xdb18826f,0x9f5fd705}},	//   nesa, _ozod, rový, rqué_,
   {{0x61ed5b1a,0x802712dc,0x7dd602b7,0xdb18816b}},	//   mmal, _ترجم, mást, sový,
   {{0x61ed5451,0x6d5d5721,0xd7c900d7,0xdb1884e8}},	//   lmal, hesa, _روزه_, pový,
   {{0x6d5d293f,0xd90f87d2,0xf99f06c0,0x61ed6aeb}},	//   kesa, لیا_, _klè_, omal,
   {{0x6d5d142f,0x9f59027f,0x61ed6aec,0x2d9900f3}},	//   jesa, _musí_, nmal, jkse_,
   {{0x386d83d3,0x7c29eaed,0xa2d60f12,0x6d5d1142}},	//   uver_, _uver, _मुन्, desa,
   {{0x6d446aee,0x7520bec8,0x2d990cfa,0x6569eaef}},	//   _scia, _zemz, ekse_, _haeh,
   {{0x7d04cc4c,0xc7a881a8,0x386deaf0,0x81d60264}},	//   žise, بديل_, sver_, িগত_,
   {{0xb8e58a49,0x7dd8a56c,0x6569de9b,0x3991970b}},	//   _এর_, tísi, _jaeh, _pásu_,
   {{0xdb070009,0xbdf98065,0x61ed01a9,0x7c3d02f1}},	//   kijä, _کرتا_, dmal, gusr,
   {{0x7dd8816a,0x69db8168,0xf99f6af1,0xa066898d}},	//   rísi, llue, _alè_, _чаша_,
   {{0x6d5d0890,0x8f9a810f,0x21764e98,0x6fd4809f}},	//   besa, _מיסי, нуар, ràct,
   {{0x6d5d6af2,0x61ed2022,0x600a1a1f,0x443dafb9}},	//   cesa, gmal, знам_, kuw_,
   {{0x26de003a,0x39406af3,0x3fe6546b,0x63b56af4}},	// [5fa0] _što_, rgis_, ежав, bizn,
   {{0x63b50503,0x2d9f8009,0x657b82c4,0x443d81ed}},	//   cizn, _alue_, _anuh, duw_,
   {{0x7520826c,0x443d81ed,0x2d9feaf5,0xdee60198}},	//   _pemz, euw_, _blue_, хожи,
   {{0x9426c11c,0x9f5d8077,0x61bd0519,0x7dd60118}},	//   емде, _duwé_, ्कृष, cást,
   {{0x20040087,0x6569808e,0x7dd60061,0xc9536af6}},	//   _îmi_, _daeh, láss, _גמר_,
   {{0x9f58020f,0xaa669ac9,0xa3c0150e,0x69c2c1e6}},	//   _mirë_, етик, ंचि_, _sjoe,
   {{0xdee314b7,0x66e30251,0x9f580168,0xa2d6123a}},	//   _бори, _бора, _lirë_, _मुम्,
   {{0xea000104,0x20026af7,0xdcf60176,0x244981fa}},	//   _nhật_, _kuki_, _anyč, búm_,
   {{0xa3c0035a,0xdced0d26,0x82fa804e,0x6d5d6af8}},	//   ंचा_, _inać, _فراز_, vesa,
   {{0xa3c78076,0x27f886db,0x200beaf9,0x999f80eb}},	//   _उदय_, örn_, ícia_, ārši_,
   {{0xdd91136d,0x7054803d,0x61ed6afa,0x63b52803}},	//   لود_, رنگا, ymal, vizn,
   {{0x6d428102,0x7afe002a,0x29d70722,0x69dbeafb}},	//   ngoa, _agpt, nçat_, clue,
   {{0x2002026c,0x2d99465e,0x6d4f010c,0x19b783de}},	//   _nuki_, rkse_, rfca, _אפאר_,
   {{0xcf2680f7,0x27e78362,0x0ce1064a,0x2d84048d}},	//   _أرشي, _ghnn_, _नरीम, ömer_,
   {{0xdb0e2d84,0x7cf683bf,0x66738154,0x20026afc}},	//   cibí, _yürü, _مدير, _auki_,
   {{0x26db84de,0x3f8e804f,0x2002550b,0x250900d7}},	//   _מקומ, _hofu_, _buki_, _غربی_,
   {{0x7d0d20f9,0x69c0da20,0x7dd64f2d,0xdb1503ed}},	// [5fb0] _ifas, inme, rást, nizë,
   {{0x200f0029,0x200201a1,0x7c2d1de0,0xab840249}},	//   īgi_, _duki_, _ivar, _буюк,
   {{0x7c2d6afd,0x4fc40544,0x44390176,0x394683a8}},	//   _hvar, уста, lrs_, _ocos_,
   {{0x7c2d0558,0xdce08dba,0x442b6afe,0x200200fc}},	//   _kvar, _samā, osc_, _fuki_,
   {{0x7d0d499e,0x84eb80c2,0x7c2d02a6,0xc8af8a27}},	//   _mfas, जेंट_, _jvar, _जेंट,
   {{0x7cf6817b,0x443d85ee,0x6d42811b,0x644beaff}},	//   _sürü, ruw_, agoa, rtgi,
   {{0x660deb00,0x6569808e,0xdb0a807b,0xdce40b80}},	//   _čako, _taeh, kifæ, _raič,
   {{0x44390301,0xa3e30105,0x96f81a1f,0x644b890d}},	//   krs_, _फीस_, _чест_, ptgi,
   {{0x29d70187,0x442b0035,0x44396b01,0x7dd60061}},	//   lças_, jsc_, jrs_, záss,
   {{0x8aa78463,0x02a78951,0x7d0d6b02,0x93e00105}},	//   _пред, _прем, _afas, _खींच_,
   {{0x44394918,0x7c2d20ec,0x29d70073,0x6da60676}},	//   ers_, _avar, nças_, вина,
   {{0xaad50105,0x7bc5008e,0xdb0e1727,0x2d9617c7}},	//   _धड़क, _ajhu, ribí, трос,
   {{0xb87b0065,0x7c2bd062,0xfc3f6b03,0x5fd10af3}},	//   _szín, nsgr, guí_, तकाल,
   {{0x33d50160,0x395f9aad,0x6a4a8085,0x7d0d6b04}},	//   гіст, leus_, _səfi, _efas,
   {{0x25e3023c,0xea000028,0x7c2d26a3,0x9f430118}},	//   _टीवी_, _thật_, _evar, _lijó_,
   {{0x442d8025,0x316d8866,0x7dd8c530,0x20025830}},	//   _ove_, ndez_, níst, _puki_,
   {{0x6d566b05,0x7c2d67ca,0x316d9e31,0xa3e49261}},	// [5fc0] _ibya, _gvar, idez_, नतम_,
   {{0x4420026b,0xdced02a5,0x672381bf,0x6603c1b5}},	//   _iwi_, _snać, _jenj, _kunk,
   {{0x6723845c,0x442002f7,0x75246b06,0x395f8198}},	//   _menj, _hwi_, _keiz, keus_,
   {{0x66038eb9,0x44205f4e,0xdd99821e,0x6723eb07}},	//   _munk, _kwi_, нші_, _lenj,
   {{0x395feb08,0x7dd8eb09,0xcfaa12dc,0x6d42eb0a}},	//   deus_, díst, _قاسم_, rgoa,
   {{0x442d9117,0x39468087,0x6dbc81a1,0x9f43026b}},	//   _dve_, _scos_, jčav, _dijó_,
   {{0x6603eb0b,0x395f87f1,0x26068072,0x6d566b0c}},	//   _nunk, feus_, _संधी_, _obya,
   {{0x7dd8eb0d,0x7524290a,0x2d9c80eb,0xd13080f7}},	//   gíst, _neiz, īves_, حمة_,
   {{0xf1b30bea,0x4fd49354,0x44206b0e,0x69c0ae8a}},	//   יסה_, лжит, _nwi_, rnme,
   {{0x29d726e2,0x6603eb0f,0xdb1ad619,0x9989811a}},	//   nçar_, _bunk, _aktö, čaš_,
   {{0x7c2d6b10,0xa3d602a8,0xdd950791,0x65950087}},	//   _svar, िकन_, ганы, гану,
   {{0x236ceb11,0x6603eb12,0x25a6eb13,0x443900eb}},	//   _hadj_, _dunk, nhol_, trs_,
   {{0x443906e3,0x4fc69b4f,0x7ddd0077,0x3866802e}},	//   urs_, _иска, nési, _usor_,
   {{0xc0e38652,0x4420031d,0x09bd0651,0x6d560c56}},	//   _точк, _dwi_, ्क्य, _ebya,
   {{0x75fa801b,0x6fddae07,0x66039037,0x7ddd00e7}},	//   _různ, dèch, _gunk, hési,
   {{0x7c2d8132,0x7c2d6b14,0x39a41819,0x7d0d0a5a}},	//   šari, _tvar, ашув, _ufas,
   {{0xfc3f46da,0xdb1c6b15,0x1075076a,0x66038326}},	// [5fd0] quí_, goró, ылаю, _zunk,
   {{0x2d538324,0x67288b67,0x660384b9,0x63b88267}},	//   _ṣe_, nadj, _yunk, jivn,
   {{0x442d803a,0xdfd80098,0x7c2beb16,0xd6db01cf}},	//   _sve_, тът_, wsgr, фта_,
   {{0x7dd8eb17,0x6728eb18,0xf65383c8,0x7c2ba03c}},	//   xíst, hadj, יצע_, tsgr,
   {{0x656d6b19,0x21290812,0x395f87f1,0x40841073}},	//   _maah, maah_, veus_, _курб,
   {{0xdd03884a,0x63b89ea3,0x21295de3,0xbcfb0019}},	//   ırıl, givn, laah_, ldés,
   {{0x61fd6b1a,0x672381b9,0x395f91ce,0x425281a8}},	//   _kisl, _renj, teus_, منور,
   {{0x45d5817a,0x67238590,0x200b8073,0x25a6eb1b}},	//   _собс, _senj, ício_, chol_,
   {{0x316db043,0x75246b1c,0x672395bd,0x6603eb1d}},	//   rdez_, _reiz, _penj, _sunk,
   {{0x6728b6a4,0x6603eb1e,0x21296b1f,0x395fe8a3}},	//   gadj, _punk, haah_, seus_,
   {{0x656d02a3,0x442002d6,0x395feb20,0x6723eb21}},	//   _baah, _swi_, peus_, _venj,
   {{0x8aa48002,0x2d9d81b9,0x399c016b,0xe81e923a}},	//   _труд, nkwe_, _písm_, _मौका_,
   {{0x69d98135,0xa3c00006,0x656d0079,0x21290748}},	//   _ikwe, ंचल_, _daah, daah_,
   {{0xd00e9301,0xf1b9a847,0x61fd6a3e,0x660385a3}},	//   _على_, liš_, _aisl, _tunk,
   {{0xfaa30c73,0x32058051,0x15f5a2d5,0x44202651}},	//   баро, _july_, ेदार_, _wwi_,
   {{0x2fd8010b,0x290d8087,0x7641c8dc,0xd2e41199}},	//   _skrg_, ncea_, muly, _गरीब_,
   {{0xa2da835a,0x57ea067c,0x316000eb,0x6a4a8085}},	// [5fe0] _पुन्, едам_, reiz_, _həft,
   {{0x6d498c6e,0x61fd51af,0xf8bf0ba4,0x336624c1}},	//   _acea, _eisl, _adés_, _свог,
   {{0x29d72761,0x69d9eb22,0x2d80115b,0x25a68114}},	//   rçar_, _okwe, _knie_, thol_,
   {{0x6d460458,0x6dbc816b,0x69d99292,0xdb1c172b}},	//   ngka, jčat, _nkwe, poró,
   {{0x69c44a2e,0x63b8a9c7,0x2d800063,0xa3ab02f1}},	//   mnie, tivn, _mnie_, _खतम_,
   {{0x69c46b23,0x7641eb24,0x437600be,0x0a6a891c}},	//   lnie, kuly, רײַן_, ерии_,
   {{0x63b8c2ab,0xbcfb3e3d,0x25a6eb25,0x645b9f29}},	//   rivn, ndér, phol_, _epui,
   {{0x38348468,0x7bc3eb26,0x6d498013,0xc0348dc7}},	//   анир, annu, _gcea, аниј,
   {{0xfce39033,0xf9930039,0x80dc80ab,0x320582c4}},	//   _гото, מרה_, মেন্, _euly_,
   {{0x69d9882e,0x385780f7,0x656d6b27,0xbcfb6b28}},	//   _ekwe, اشيد_, _saah, zdés,
   {{0x67288b67,0x69c426fa,0xf1b98796,0x2d920041}},	//   radj, knie, biš_, _boye_,
   {{0xceb30039,0x69c46b29,0x67288b80,0xf1b9811f}},	//   מית_, jnie, sadj, ciš_,
   {{0x69c43256,0x7bd56b2a,0x589692c8,0xa3c0016f}},	//   dnie, tozu, _حجاز, ंचं_,
   {{0x765c6b2b,0x6d460282,0x69c41a28,0x7f968866}},	//   _opry, agka, enie, _pâqu,
   {{0x61fd6b2c,0x212915e8,0x6dbcc94f,0xea0000ff}},	//   _pisl, taah_, nčas, _phạt_,
   {{0x69c46b2d,0xb115174a,0x391530fe,0x80d300ab}},	//   gnie, рмаш, рмар, _দৃষ্,
   {{0xa3e485e8,0xbcfb0065,0x60f92252,0x644d0748}},	// [5ff0] नता_, rdés, тная_, _uqai,
   {{0x3f9e969e,0xb4c31299,0x6d49c544,0x9f4101a8}},	//   nktu_, ्थी_, _scea, lmhú_,
   {{0x69c4118c,0x6dbc826f,0x645be762,0x62670199}},	//   bnie, jčas, _spui, _صادق,
   {{0x7bdaeb2e,0x61fd0010,0x6dbc8259,0x531402e3}},	//   _aktu, _uisl, dčas, _پذیر,
   {{0x6dbc83f2,0x8b258a0e,0xa5c5826b,0x7a1181a9}},	//   včat, адле, _atóè, _māte,
   {{0x6fdd8722,0xd7f8028e,0x0ed0016f,0x69d9bb6e}},	//   pèci, _бус_, _तुकड, _skwe,
   {{0xa3d60076,0xfe09801c,0xaadb06a7,0x98bf88ae}},	//   िकत_, _mắc_, _मुमक, rguč_,
   {{0x798d2112,0xfe0980ff,0x34958256,0x2006eb2f}},	//   njaw, _lắc_, _кабр, _buoi_,
   {{0x0cd9803d,0xf09200be,0x290d8087,0x78ad02d6}},	//   _شارژ_, ַנט_, rcea_, nzav,
   {{0x69c44a2e,0x81bc8029,0x442feb30,0x7641eb31}},	//   znie, _svēt, msg_, tuly,
   {{0x6dbc84a8,0xf1b9d3f5,0xdee5971c,0x672701b9}},	//   mčar, piš_, рони, _mejj,
   {{0x58d58698,0x69d9afb1,0x287581bb,0x66070267}},	//   _коет, _ukwe, _выкр, _mujk,
   {{0x69d603d3,0xef0e9c3b,0x2d920247,0x69c400eb}},	//   voye, _мм_, _voye_, vnie,
   {{0x69c40063,0x6dbcaa06,0xb92b00ff,0x78ad0619}},	//   wnie, nčar, _thuỷ_, dzav,
   {{0x69c41a23,0xa2d6023c,0x412a0225,0x69d61dd8}},	//   tnie, _मुश्, ково_, toye,
   {{0x7c2f429c,0x798d00ee,0x2d806b32,0xe1ff07f1}},	//   bscr, gjaw, _unie_, _ció_,

   {{0x69c46b33,0x7d0400b4,0x316f808e,0x216724c1}},	// [6000] rnie, _igis, _magz_, шити_,
   {{0x69c40029,0x998d0796,0x61e481b9,0xef171bc6}},	//   snie, češ_, ċili, иму_,
   {{0x63bc003a,0x672704b7,0xe8e283eb,0x69c42fbe}},	//   mirn, _dejj, _पर्च, pnie,
   {{0x1e568158,0xe1ff001c,0x7c2400b4,0x6b818176}},	//   ישער_, _gió_, _kwir, _anlg,
   {{0x2ca08307,0x7ddd5f17,0x9f4f81ca,0x629c0706}},	//   áid_, mést, _jugó_, lyro,
   {{0xd25a80c4,0x63bc6b34,0x7c24150f,0x3998808b}},	//   вци_, nirn, _mwir, _lést_,
   {{0x20068098,0xfe6788ca,0x27ff047f,0xf1a6eb35}},	//   _suoi_, _بد_, _èuna_, ирин,
   {{0x63bc0867,0x20068698,0xa2da835a,0x7c2f2651}},	//   hirn, _puoi_, _पुण्, yscr,
   {{0xbee6035a,0x200682be,0x63bc6b36,0x629c2bed}},	//   _करुन_, _quoi_, kirn, hyro,
   {{0x20068098,0x47348ada,0x7bc8826c,0x7d046b37}},	//   _vuoi_, щнос, _ujdu, _agis,
   {{0x442481c5,0x78ad6b38,0xc98682eb,0x21268034}},	//   _hwm_, zzav, _вули, _teoh_,
   {{0x99808a8e,0x2006eb39,0xfe098028,0x44248069}},	//   čių_, _tuoi_, _sắc_, _kwm_,
   {{0xa2da9513,0xb4c301d0,0x6ce7021e,0xe1ff0144}},	//   _पुत्, ्थे_, ріне, _rió_,
   {{0xbee6035a,0x09b1035a,0x69c802be,0x7c2f01a8}},	//   _करून_, ीच्य, éden, rscr,
   {{0x442481e9,0xff178039,0x79828039,0x7ddd03a8}},	//   _lwm_, _דקות_, _know, fést,
   {{0x7bd8eb3a,0x4efb8039,0x78ad023e,0x9f4f8144}},	//   hovu, _בלוג, tzav, _fugó_,
   {{0x63bc3be8,0x798d085c,0x7c240114,0x64400722}},	// [6010] birn, rjaw, _gwir, àmit,
   {{0x78ad0052,0x63bc632f,0xed5980c3,0x9f58026b}},	//   rzav, cirn, _sbž_, _firí_,
   {{0x41d6800f,0x27e984b9,0xdb188198,0x17f801a8}},	//   डकास, _ɗan_, invä, شركة_,
   {{0xeef784de,0x7bc702d4,0x3dc6aacd,0x3cee06ae}},	//   במבר_, lnju, gnow_, _घरमे_,
   {{0x65a6007b,0x6600dbaa,0x4424eb3b,0x3d0f801b}},	//   _jóha, _dimk, _cwm_, ाडौं_,
   {{0xdcfb811f,0xfc3f0013,0x9cd80039,0x39496b3c}},	//   _unuč, irí_, בודה_, lgas_,
   {{0x52758087,0x3869553d,0x356b9e0b,0x926481a8}},	//   сулу, lwar_, _иран_, قديم,
   {{0x39496b3d,0x4424822c,0x63bc0669,0x26c980d2}},	//   ngas_, _fwm_, zirn, _ćao_,
   {{0x386900fc,0x79828122,0x629c0035,0xa2e4052a}},	//   nwar_, _dnow, zyro, _गर्ज_,
   {{0x6d4d01a1,0xf8b201c6,0x7c2d826c,0xfc3f07f1}},	//   _acaa, פשי_, šars, drí_,
   {{0x9f47809f,0xdce08668,0x63bc0796,0xb8fe99eb}},	//   _sinó_, _pamć, virn, _दु_,
   {{0xcb090039,0x44248282,0x6d4d038a,0x629c1c17}},	//   _טל_, _ywm_, _ccaa, vyro,
   {{0x291f8010,0x442481e9,0xfc3f023e,0x63bc6b3e}},	//   mbua_, _xwm_, grí_, tirn,
   {{0x38691ad9,0x629c1ca7,0xdb1880e7,0x3cdc052a}},	//   dwar_, tyro, tivé, _गुणे_,
   {{0x4ad205b3,0x68e30201,0xd29900e8,0x61ef0267}},	//   _दुखव, əndi, атті_, _bhcl,
   {{0x09060f04,0xdb1880e7,0xa06a3312,0x39496b3f}},	//   спан, rivé, лаба_, ggas_,
   {{0xea000104,0xa3d799a1,0x249d81c0,0xeb9a6b40}},	// [6020] _nhất_, सवा_, jywm_, _бип_,
   {{0x69dd054f,0x6446130e,0x6d5b80dd,0x6609017f}},	//   _ekse, muki, _abua, _čekr,
   {{0x6446230e,0xe29a272f,0x3dc68197,0x60cf1727}},	//   luki, _сан_, tnow_, _excm,
   {{0x44248282,0x998600f7,0x3f8303f7,0x7ddd0061}},	//   _pwm_, _الحو, _enju_, lésr,
   {{0xea000028,0x64466b41,0x61e45485,0xa3bc02f1}},	//   _chất_, nuki, mlil, _आगा_,
   {{0x61e46b42,0x44248069,0x2a6c841c,0x29de0428}},	//   llil, _vwm_, _psdb_, rïau_,
   {{0x6e96003f,0x320206cb,0x7bd8eb43,0x7bde0870}},	//   _الزا, _kiky_, rovu, _mkpu,
   {{0xd90e80d5,0x61e460eb,0x6446405d,0x4814d1e6}},	//   ریت_, nlil, kuki, омис,
   {{0xa01b01ec,0x64460c2e,0x7bde0870,0x7bd8ab8c}},	//   _eröf, juki, _okpu, povu,
   {{0x64466b44,0x61e46b45,0xc32280ab,0x7bde0135}},	//   duki, hlil, _নাকি_, _nkpu,
   {{0x8c0000c8,0xdb18816d,0x2120026c,0x11d6b2de}},	//   ্ঠান_, rnvä, kbih_, _людя,
   {{0x69c80019,0xc6930039,0x7bde0133,0xfc3f01ac}},	//   édel, לאת_, _akpu, trí_,
   {{0xe8948e02,0x2120026c,0x2ec40a27,0x64460f45}},	//   _фаль, dbih_, वपुत, guki,
   {{0x7ddd0061,0x58f781c6,0x18378e82,0x68e2a77c}},	//   téss, _המדע_, _פאול_, _iyod,
   {{0xf1a71c74,0x0f578bea,0xfe09801c,0x39490573}},	//   бран, _היום_, _hắn_, tgas_,
   {{0x61e402b8,0x64466b46,0x7bde0135,0x39490110}},	//   glil, buki, _ekpu, ugas_,
   {{0xa2da8b6f,0x752f009a,0x23ab806a,0x752980b9}},	// [6030] _पुस्, macz, _høje_, _reez,
   {{0x386904b9,0xb17b016d,0x6d5b80dd,0x394915d0}},	//   rwar_, _skåd, _sbua, sgas_,
   {{0x61e46b47,0x38692fe3,0x2120026c,0x9f5812d0}},	//   blil, swar_, bbih_, _dirà_,
   {{0x752f0063,0xcd2b803d,0x85300326,0x69dd02f1}},	//   nacz, اسان_, _koɗa, _ukse,
   {{0x6738973d,0x212b1670,0x27ff01e8,0x7ae1806f}},	//   _odvj, _iech_, _èuno_, _sylt,
   {{0x80dc800f,0xe2998012,0x212b0713,0x6566405b}},	//   _पड़े, иал_, _hech_, zekh,
   {{0x64466b48,0x68e2d556,0x65666b49,0x539c03de}},	//   zuki, _ayod, yekh, ריוו,
   {{0x200b0052,0xea000028,0xfe09801c,0xdb1c0168}},	//   _kuci_, _thất_, _bắn_, tirë,
   {{0xb4e80105,0x9f4700ff,0x660a81ec,0xaadb0fb2}},	//   _भरे_, _điên_, _aufk, _मुसक,
   {{0x53349445,0x25a96b4a,0x200b00fe,0x6d4a83bf}},	//   _неут, _alal_, _muci_, ılaş,
   {{0x20033059,0x02a7c060,0xdb1c0168,0x93888951}},	//   _miji_, _урам, sirë, _уста_,
   {{0x64466b4b,0x82d680be,0x20190074,0xe9df42aa}},	//   tuki, _וועג_, _otsi_, _nkú_,
   {{0x22478019,0xfe09801c,0x2019022c,0x92e600ab}},	//   lunk_, _gắn_, _ntsi_, _ফলে_,
   {{0xbea59927,0x98a20029,0x64463190,0xb6a5ad94}},	//   _малк, _nekā_, ruki, _милл,
   {{0x752f009a,0x69c9eb4c,0x61e46b4d,0x212b0620}},	//   bacz, onee, tlil, _bech_,
   {{0x69c9c695,0x62878036,0xdce4011f,0x6446393c}},	//   nnee, _àjou, _naić, puki,
   {{0x212b22b3,0x20030590,0x200b010b,0xe9d705e9}},	// [6040] _dech_, _biji_, _cuci_, іку_,
   {{0x200302a5,0x21200239,0x69c9e7fd,0x200b315a}},	//   _ciji_, sbih_, hnee, _duci_,
   {{0xa6ca00f7,0x2247eb4e,0x20190198,0x21200267}},	//   جوال_, junk_, _etsi_, pbih_,
   {{0xed5a90fc,0xa2da800c,0x69c981c0,0xa01b016d}},	//   род_, _पुष्, jnee, _bröd,
   {{0xdb153f90,0xb87b0019,0x0b8a8188,0x7986499e}},	//   lizá, _szív, иски_, _inkw,
   {{0x660418c5,0xdce0801b,0x7bdc48ac,0xfe0980ff}},	//   _liik, _zamě, noru, _rắn_,
   {{0xdb153add,0xada68198,0xe5a685fa,0xa2da8054}},	//   nizá, _давл, _диви, _पुश्,
   {{0x8c469d20,0xf1268d8e,0xa9c380e8,0x69c9eb4f}},	//   _мебе, цько, дськ, gnee,
   {{0x80dc00c8,0x7522a7ce,0xa2da824c,0x180482f1}},	//   _মৃত্, mboz, _पुर्, रदेव_,
   {{0x6d40008b,0x69c98df6,0x9178846d,0x752f0035}},	//   óman, anee, _fé̟_, wacz,
   {{0x3f980a20,0xf09f6b50,0x7a1181a9,0x69c98069}},	//   _moru_, _ngàn_, _tāta, bnee,
   {{0xdced0503,0xd83f016b,0x79860133,0xfe09827d}},	//   _snađ, íčku_, _nnkw, _tắn_,
   {{0xf76f8077,0x66040057,0x69c08009,0xb87b026b}},	//   رای_, _diik, mime, _ayín,
   {{0xbebc8029,0x212b010c,0xfbbca8d7,0x200b005c}},	//   rbīb, _sech_, ्चिम, _ruci_,
   {{0x200b0587,0x6d4b8186,0xda780ada,0xdce0801b}},	//   _suci_, ygga, оят_, _pamě,
   {{0x3015002d,0xdb18928c,0x20030077,0x7ddd0144}},	//   здар, diví, _siji_, césp,
   {{0x9abc84b7,0x3f980965,0x22478061,0x6ab8864a}},	// [6050] _deċi, _boru_, zunk_, ेपुर,
   {{0xa2d60a3a,0x442904be,0x7bdc6b51,0x5ba71a1f}},	//   _मुक्, _iwa_, coru, _фриз,
   {{0x752d0abf,0x69c0eb52,0xa2da847d,0x69c98a5b}},	//   _keaz, kime, _पुल्, ynee,
   {{0x44296b53,0x671b1995,0x69c0eb54,0x48c900ab}},	//   _kwa_, _प्रक_, jime, _শরীর,
   {{0x6442a202,0x69c98069,0x442906c4,0x3f980102}},	//   groi, vnee, _jwa_, _foru_,
   {{0x44294c12,0xb09a0039,0x22478019,0x3f980289}},	//   _mwa_, _הישר, tunk_, _goru_,
   {{0x69c0c8ec,0x44296421,0x3f89801c,0xe29993bd}},	//   fime, _lwa_, _đau_, сай_,
   {{0x44293977,0x7bdc6b55,0xa2ce04c5,0x22478061}},	//   _owa_, zoru, _सशस्, runk_,
   {{0x7bdc0179,0xdb0e0331,0x2019820f,0x442934d6}},	//   yoru, ribú, ësi_, _nwa_,
   {{0x69c9eb56,0x7c29eb57,0xb113019d,0x9c138133}},	//   snee, _iwer, _tụwa, họkw,
   {{0x69c0eb58,0x67219e0f,0x7bdc18ad,0x7a3081a8}},	//   bime, rblj, voru, _vótá,
   {{0x69c09092,0x7c29bb0a,0x44296b59,0xf09f00ff}},	//   cime, _kwer, _bwa_, _ngào_,
   {{0x7bdc0012,0x66040364,0x44296101,0xb88681fa}},	//   toru, _viik, _cwa_, rtíð,
   {{0x44290773,0xf771990c,0x394d99fa,0xaca3eab1}},	//   _dwa_, _سات_, lges_, _ngọn,
   {{0x753b803a,0xa2d60b6f,0x6da61fee,0x44296b5a}},	//   _oduz, _मुख्, _ника, _ewa_,
   {{0x7d760277,0x7d09829b,0x44290247,0xaca3819d}},	//   _رابط, _nges, _fwa_, _agọn,
   {{0x7c298a2c,0x6ed40105,0x661b0279,0xb9288133}},	// [6060] _nwer, _बुजु, _čuka, _agwụ_,
   {{0x7d09b516,0xe4570158,0xfe098028,0x69c0c789}},	//   _ages, _צייט_, _lắm_, zime,
   {{0xfe050086,0xdfcf0013,0x3f980125,0x386d81ec}},	//   _üçün_, ديل_, _voru_, hwer_,
   {{0x248006c4,0xfe0980ff,0x7c29eb5b,0x69c0eb5c}},	//   _krim_, _nắm_, _bwer, xime,
   {{0x65762651,0xdca385c2,0x3f980054,0x394deb5d}},	//   _mayh, наци, _toru_, dges_,
   {{0x7fd60d13,0x6442971c,0x7c299412,0xdbd6826b}},	//   _хімі, rroi, _dwer, _bùáy,
   {{0x69c0cd8b,0x7c298135,0x27f701d0,0x89d884a3}},	//   time, _ewer, řené_, يوتر_,
   {{0x394d84d6,0xfe0980ff,0x386d80b9,0x9f5c8216}},	//   gges_, _cắm_, fwer_, _viví_,
   {{0x752d1b79,0x7c29ae82,0x8c439033,0xb87b0019}},	//   _reaz, _gwer, _пете, _nyíl,
   {{0x442902a0,0x7648843b,0xb113019d,0x2c5e80eb}},	//   _rwa_, tudy, _hụta, rādā_,
   {{0x45d50003,0x442906c0,0x6b88813c,0xd7f88087}},	//   донс, _swa_, _indg, rmă_,
   {{0x442903ec,0x6b9a8129,0x7ae50198,0x24806b5e}},	//   _pwa_, _hotg, _ryht, _brim_,
   {{0x61e284b7,0xdb018118,0x2480023e,0xb1130133}},	//   _ikol, _illá, _crim_, _mụta,
   {{0x083b8051,0x75ff0029,0xb4bd1834,0x442906c0}},	//   _פעול, _mūzi, _आधी_, _vwa_,
   {{0xdb0aeb5f,0xb91a0a2c,0xcfc400ab,0xd6cfb2de}},	//   lifó, _ọtụt, ্তান, _чт_,
   {{0xf77309d7,0x44292f9e,0x61e284b7,0x24800748}},	//   کار_, _twa_, _jkol, _frim_,
   {{0xa3dc816f,0x44296b60,0x661c00c3,0x24806b61}},	// [6070] ठवा_, _uwa_, _atrk, _grim_,
   {{0xdefb0198,0xedc583ca,0x7c298a03,0x61e2822b}},	//   бые_, लच्छ, _rwer, _lkol,
   {{0x7c29eb62,0xdb0183a8,0x363401a8,0xf7702105}},	//   _swer, _ollá, فرنس, داق_,
   {{0x25a68a84,0x6d4f6b63,0x61e28365,0x23490fd3}},	//   gkol_, ngca, _nkol, _اسکی_,
   {{0x69cd00d2,0x76430061,0xeb9980af,0x65608362}},	//   mnae, ányb, жил_, _dbmh,
   {{0xfe09801c,0x61e291ad,0xbd05826b,0xa2e58162}},	//   _sắm_, _akol, _apéé, молд,
   {{0x394d8813,0x386deb64,0x61e28609,0xe3b081a8}},	//   tges_, wwer_, _bkol, درن_,
   {{0x69cd6b65,0x2360a6d5,0x394deb66,0x7d09e1cf}},	//   nnae, đija_, uges_, _uges,
   {{0xbf0583dd,0x394deb67,0x386d81ed,0x50b599bb}},	//   रश्न_, rges_, uwer_, ьску,
   {{0xee39c898,0x6615826f,0xdb018019,0x7999810c}},	//   оно_, ízko, _ellá, _woww,
   {{0x7bc3eb68,0x644beb69,0x9d46117c,0x0f58010f}},	//   minu, lugi, менд, ליזם_,
   {{0x2d890333,0x9f45aaa5,0x656b80e5,0x386d80e4}},	//   _cnae_, illé_, negh, pwer_,
   {{0xe73980a9,0x61fb8365,0x69cd0bda,0x6459eb6a}},	//   _дел_, mmul, dnae, ntwi,
   {{0x61e98006,0x61fb8087,0x7bc3eb6b,0x68e60a53}},	//   llel, lmul, ninu, _rykd,
   {{0xea000028,0x4adb0105,0x09e610ca,0x25bf8087}},	//   _chết_, _मुआव, довн, _omul_,
   {{0x61e9b240,0x7bc384a7,0x200783e4,0x644b9f37}},	//   nlel, hinu, _hini_, kugi,
   {{0x2007eb6c,0x91e31697,0x09e3102a,0xdb1c0144}},	// [6080] _kini_, тоте, тотн, lirí,
   {{0x6281d9ab,0xdfcf0013,0x2007eb6d,0x68e60110}},	//   _orlo, ليق_, _jini_, _vykd,
   {{0x7e5624b6,0x7bc393bd,0x200feb6e,0xb1130870}},	//   ьтац, dinu, _lugi_, _pụta,
   {{0x644beb6f,0xea000028,0x26138073,0x645981bc}},	//   fugi, _đặc_, _mão_, ftwi,
   {{0x4ac38076,0x3ea60029,0x61e9829b,0x6281eb70}},	//   _वेबव, ņot_, dlel, _arlo,
   {{0x61e2a6e5,0x20078ca2,0x6ac98107,0xbf9b0036}},	//   _skol, _nini_, िपूर, _quêt,
   {{0x261399b9,0x661c02ce,0x79960069,0x644b8084}},	//   _não_, _utrk, ojyw, augi,
   {{0x2007eb71,0x30a6869b,0x200feb72,0x61fb809c}},	//   _aini_, дров, _bugi_, gmul,
   {{0x20079953,0xa3c00a61,0xc05a80e8,0xe11281bc}},	//   _bini_, ूचा_, цій_, _bụrị,
   {{0x200785f5,0xb4aa8b9f,0x6b88813c,0x61e284b7}},	//   _cini_, खनी_, _undg, _wkol,
   {{0x2007eb73,0x7c22eb74,0x26138187,0xdb1c3673}},	//   _dini_, lpor, _cão_, girí,
   {{0x61e2eb75,0x2007eb76,0x26138187,0xf64f8019}},	//   _ukol, _eini_, _dão_, گئی_,
   {{0x2007eb77,0x7c22eb78,0x61e08122,0xd90f003d}},	//   _fini_, npor, moml, یید_,
   {{0x2007eb79,0x09c7016f,0xf1bf007b,0xdb1c0333}},	//   _gini_, रच्य, _smá_, birí,
   {{0x69cd0052,0xdb1c0333,0xa2784543,0x9f4e826b}},	//   tnae, cirí, мбру_, _fifò_,
   {{0x260710c5,0x250900d5,0x2007eb7a,0x7bc3e8b1}},	//   _सूची_, _عربی_, _zini_, zinu,
   {{0x2007829b,0x656b8087,0x7d0d6b7b,0x7bc3eb7c}},	// [6090] _yini_, vegh, _igas, yinu,
   {{0x7c229807,0xc8088104,0x69cd0699,0x656b882e}},	//   dpor, _bởi_, snae, wegh,
   {{0x2bdd86bf,0x656b8133,0x61e0eb7d,0x20ca816f}},	//   यवसा, tegh, koml, ापुढ,
   {{0x7c2d6b7e,0x3f9c8639,0x4439010c,0x644bb00e}},	//   _kwar, _lovu_, oss_, tugi,
   {{0x7c22b55d,0x628a063e,0x7d0d0122,0x44396b7f}},	//   gpor, _àfor, _mgas, nss_,
   {{0x3f9c803a,0x200f8b20,0x7c2d0435,0xe6670656}},	//   _novu_, _rugi_, _mwar, _отбо,
   {{0xc8088028,0x38668091,0x61fbeb80,0x2ca98267}},	//   _gởi_, _apor_, tmul, šad_,
   {{0x20078393,0x7d0d255a,0x2bdd86bf,0x443900eb}},	//   _sini_, _ngas, यवहा, kss_,
   {{0x26138003,0x31790063,0x2007eb81,0x61e9ae55}},	//   _são_, _masz_, _pini_, rlel,
   {{0x442db623,0x7d0d6b82,0x61fb9430,0x61e98f09}},	//   _iwe_, _agas, smul, slel,
   {{0x2007eb83,0x6609eb84,0x3f9c8858,0x7d0d019d}},	//   _vini_, _kiek, _dovu_, _bgas,
   {{0xb17b108c,0x26138073,0x200782d6,0x442deb85}},	//   _skån, _vão_, _wini_, _kwe_,
   {{0xa8a795e4,0x2007c068,0x442d8247,0x5e56803d}},	//   _تصاو, _tini_, _jwe_, ولیس_,
   {{0x6609ad38,0x7c2d05ad,0x26138073,0x442da542}},	//   _liek, _dwar, _tão_, _mwe_,
   {{0x36668098,0x80ec00ab,0x387f807b,0x442d98b7}},	//   _защо_, _কলেজ_, lvur_, _lwe_,
   {{0x6609eb86,0x442deb87,0x3f9c8024,0x15e812c6}},	//   _niek, _owe_, _zovu_, _टीचर_,
   {{0xa0675c51,0x7c2d6b88,0x18670847,0x656402a0}},	// [60a0] ната_, _gwar, нати_, _ibih,
   {{0x44206b89,0x5c5b010f,0x7d1beb8a,0xf99f010c}},	//   _iti_, _צדיק, _afus, _hièl_,
   {{0x7c2d4b06,0x442002f7,0x34a880c2,0x660989ff}},	//   _zwar, _hti_, कन्द, _biek,
   {{0x7c22d006,0x442dc6b0,0x6609809a,0x14c8803d}},	//   tpor, _bwe_, _ciek, وهای_,
   {{0xfb0b0102,0xb4aa8063,0x660990e1,0x442de911}},	//   _óëñ_, खने_, _diek, _cwe_,
   {{0x442d8205,0xa01b016d,0x7c22b60b,0xa3d60a74}},	//   _dwe_, _krön, rpor, िकट_,
   {{0x442de7fc,0x38668808,0x92948110,0x69058201}},	//   _ewe_, _spor_, тайц, ərdə,
   {{0x44206b8b,0xd13080f7,0xdee31b56,0x44393117}},	//   _oti_, جمة_, _соси, yss_,
   {{0x442046b0,0xa3e001ab,0x442dc168,0x6d408085}},	//   _nti_, तवा_, _gwe_, _idma,
   {{0x66098a0f,0x316003ac,0x200a10fe,0x7c2d00b4}},	//   _ziek, hfiz_, _jibi_, _rwar,
   {{0x44206b8c,0x7c2d6b8d,0xb907916e,0xffb700be}},	//   _ati_, _swar, _मु_, גליש_,
   {{0x7bc181ac,0x7173803d,0xf41f016d,0xdd12061c}},	//   _zmlu, _مهما, nväg_, rüşm,
   {{0x07a6b4d5,0x69c10036,0x499b81c6,0x38668824}},	//   _падн, èlem, _משאב, _upor_,
   {{0x44396b8e,0x3872031d,0x61e60609,0x3f9cc778}},	//   rss_, dwyr_, _akkl, _uovu_,
   {{0x6d40803a,0x44206b8f,0xa785803d,0x81c900ab}},	//   _odma, _eti_, _جشنو, _লীগ_,
   {{0x7d0d4aff,0x7c2d18e3,0x443b01c0,0x200a00fc}},	//   _ugas, _twar, _tvq_, _aibi_,
   {{0x656f6b90,0x7ddd0019,0x7c2d6b91,0x38720114}},	// [60b0] mech, kész, _uwar, gwyr_,
   {{0x6609df1b,0xdb018009,0x6d40e54f,0x200a047f}},	//   _siek, _yllä, _adma, _cibi_,
   {{0x6609ca2e,0xa01b00f2,0x7bc70f27,0x645d6b92}},	//   _piek, _grön, miju, ltsi,
   {{0x7bc76b93,0x657d6b94,0xdb1c02b7,0x656f1c32}},	//   liju, ndsh, mirá, nech,
   {{0x21291e92,0x645d6b95,0x6ac9824c,0x61ed6b96}},	//   mbah_, ntsi, िप्र, mlal,
   {{0x200a0179,0x61ed49da,0x7bc76b97,0x64a2a2f7}},	//   _gibi_, llal, niju, раша,
   {{0x22568288,0x644f0661,0x248480ee,0x6609eb98}},	//   نلود_, huci, _ermm_, _tiek,
   {{0x645d0074,0x9f4100f1,0x61ed0cf4,0x644f1aa1}},	//   ktsi, kohë_, nlal, kuci,
   {{0x442deb99,0x644f0042,0x645d377f,0x4439877f}},	//   _uwe_, juci, jtsi, _ìs_,
   {{0x61ed029b,0x81d700ab,0x657beb9a,0xa283803d}},	//   hlal, িতি_, _hauh, _میتو,
   {{0x656f6b9b,0x273c001b,0x6285022c,0x212900dd}},	//   fech, lání_, _nrho, kbah_,
   {{0x2d9fa6f2,0xdb1c0511,0x657beb9c,0x645d11e6}},	//   _joue_, dirá, _jauh, ftsi,
   {{0x81d700c8,0x61ed005d,0x853a8039,0x273c001b}},	//   িতা_, dlal, וגרי, nání_,
   {{0x8fa28ce6,0xf7458811,0x2d990168,0x657beb9d}},	//   _ваше, _реко, ajse_, _lauh,
   {{0x645d4ca0,0xdb1c6b9e,0x39988061,0x62850144}},	//   atsi, girá, _rész_, _crho,
   {{0x61ed6b9f,0x200a6ba0,0x656f2a5d,0x44206b7c}},	//   glal, _sibi_, cech, _tti_,
   {{0x644f2e3c,0x26170073,0x44203f3b,0x2d5a0353}},	// [60c0] cuci, _aço_, _uti_, _všeč_,
   {{0x273c000d,0x61ed212b,0xdb1c05e4,0x3872031d}},	//   dání_, alal, birá, rwyr_,
   {{0x1dc62120,0x2129674b,0x25a00573,0x7ddd0019}},	//   _लगात, bbah_, _koil_, vész,
   {{0x290f8072,0x71a628fb,0xe9a60b5b,0x200a010c}},	//   _ngga_, _рамз, _рамп, _wibi_,
   {{0x200a130c,0x779100d5,0x2d9f8473,0xf41f0106}},	//   _tibi_, _گیلا, _doue_, rväg_,
   {{0x656f0063,0x61e40198,0xf41f0338,0x69c28cab}},	//   zech, loil, sväg_, _smoe,
   {{0x645b8cf7,0x644f0035,0x877b03de,0x7ddd0061}},	//   _equi, zuci, _קאלי, rész,
   {{0x28c70aad,0x80e080ab,0x16770039,0x68eb835f}},	//   _रेडि, _পৃষ্, _בגלל_, _bygd,
   {{0x656f6ba1,0x394200ee,0x645d6ba2,0x6da3a432}},	//   vech, _mdks_, xtsi, _тита,
   {{0xaadb01ce,0xdce400ce,0x644f042b,0x656f6ba3}},	//   _मुझक, _naiđ, vuci, wech,
   {{0xe5351a97,0xdd9107bd,0x777c6ba4,0x4426c696}},	//   лень, مود_, _marx, lpo_,
   {{0x23698024,0xa01b016d,0xb5a72c18,0x6846a351}},	//   đaje_, _bröl, трой, _анда,
   {{0x656f6ba5,0xceb88063,0x4426eba6,0x5c741676}},	//   rech, szę_, npo_, алят,
   {{0x4426840e,0x645d6ba7,0x656f6ba8,0xdb1c4218}},	//   ipo_, rtsi, sech, tirá,
   {{0x656f6ba9,0x764f8063,0x21290b50,0x644f036e}},	//   pech, ącyc, tbah_, suci,
   {{0x1e978051,0x7bc701e2,0x44268135,0xdb1c0511}},	//   _יכול_, siju, kpo_, rirá,
   {{0x61ed0483,0x657b8009,0x7bc70110,0x2d9f8036}},	// [60d0] rlal, _rauh, piju, _roue_,
   {{0x273c03bb,0x76430019,0x21290748,0x2ca40106}},	//   vání_, ányo, sbah_, ämde_,
   {{0x660d6baa,0xe45f0009,0xdbdc807b,0x212901a1}},	//   _kiak, ltö_, _ráðh, pbah_,
   {{0x79951bbf,0xa439908d,0x61e401a8,0x7d0901a9}},	//   _симф, езду_, coil, _tīrī,
   {{0x660d022e,0x4426820d,0x798f04ee,0x754485a8}},	//   _miak, gpo_, _incw, рніз,
   {{0x273c01d0,0x60cd80c3,0xfe0a027d,0xdce40372}},	//   rání_, _žamo, _hắt_, _jniġ,
   {{0x657bebab,0x68eb806a,0x75f60061,0x4426ebac}},	//   _tauh, _sygd, háza, apo_,
   {{0x75f6003e,0x16199094,0x387900ee,0x77ad83a8}},	//   káza, _नंबर_, _kssr_, _púxo,
   {{0xfe0a0028,0x76b3811c,0x60099afd,0x7bc56bad}},	//   _mắt_, məyə, нним_, _omhu,
   {{0x777c07e2,0xe8f68196,0x443fe4fe,0x53b7816f}},	//   _xarx, ылы_, _ivu_, _अतिश,
   {{0xada601a1,0x6da600b3,0x660d054a,0xadc3801c}},	//   ганл, гина, _biak, _giản,
   {{0x644be018,0x7bc50706,0x660d00e5,0x63a18061}},	//   orgi, _amhu, _ciak, _holn,
   {{0x660d0397,0x443d82f7,0x61e46bae,0xa7859dd2}},	//   _diak, nsw_, voil, _مشغو,
   {{0xb88283c1,0x317f811b,0xc2f68264,0x69c9a43a}},	//   čítk, lduz_, _চলতি_, liee,
   {{0xd94611b3,0xfe0a0028,0xa01b00f2,0x63a1afc7}},	//   леви, _bắt_, _dröm, _moln,
   {{0x443f8025,0xfe0a001c,0x660d0420,0x317febaf}},	//   _ovu_, _cắt_, _giak, nduz_,
   {{0xbfa3077f,0xe9d730b4,0x1f660b79,0x75f60333}},	// [60e0] _àwọn_, укт_, лкам, cáza,
   {{0x7c240850,0x777c01b4,0x6b561133,0x649701c6}},	//   _itir, _qarx, _стих, _עדיף_,
   {{0xaac39344,0x4d4a8be2,0xc8f081a2,0x2b5a02d6}},	//   _वेलक, епен_, _चर्म_, _icpc_,
   {{0x35e59138,0x63a18362,0x3879010c,0xfe0a0129}},	//   аців, _aoln, _fssr_, _gắt_,
   {{0x777c6bb0,0x69c66bb1,0x4426c8ba,0x4c94954f}},	//   _tarx, _imke, upo_, рилс,
   {{0x66e60767,0x44320355,0xdb08802a,0xdee6110e}},	//   _бога, _mwy_, _aldá, _боги,
   {{0x63a1a0d9,0x27ea0748,0x443fb232,0x644ba510}},	//   _doln, _ikbn_, _evu_, argi,
   {{0x44268698,0xdb08816d,0x7c2400fe,0x6d4400f7}},	//   ppo_, _omdö, _otir, _ndia,
   {{0x63a199ba,0x7c240314,0x661b0088,0x661504e8}},	//   _foln, _ntir, _čuki, _zuzk,
   {{0x4424e8a7,0x6d444733,0x660d09ca,0x66028326}},	//   _itm_, _adia, _siak, lmok,
   {{0x7c246bb2,0x051680ab,0xb2269229,0x4432026b}},	//   _atir, ারীর_, _смел, _awy_,
   {{0xac192a28,0x38601a4c,0x7bcac349,0xe9da80e8}},	//   кому_, ktir_, lifu, _яке_,
   {{0x4424ebb3,0xdb1e15a0,0xe973803d,0x6d440428}},	//   _jtm_, _empí, _دهند, _ddia,
   {{0xfe0a001c,0x44320114,0x69c80036,0x46b40072}},	//   _sắt_, _dwy_, èden, ंनाह,
   {{0x7c240085,0x171b80be,0xe45f0009,0x6235548e}},	//   _etir, _אווע, stö_, ребу,
   {{0x1619835a,0x4432031d,0x38600b97,0x75f64a84}},	//   _नंतर_, _fwy_, ftir_, lázn,
   {{0x98170154,0x7bca8309,0x2a7a01a1,0x200e8300}},	// [60f0] ابرا, kifu, _espb_, _kifi_,
   {{0xd6db4d44,0x62889f29,0x7bca8010,0xd101000c}},	//   нте_, _ordo, jifu, लेषण_,
   {{0x443f8052,0xd6db0ddc,0xfe0a001c,0x38600748}},	//   _svu_, хта_, _tắt_, atir_,
   {{0x63a18b81,0x24891b59,0x673aebb4,0x00000000}},	//   _soln, _kram_, hatj, --,
   {{0x63a1a9a8,0x6288ebb5,0x22838214,0x493a0039}},	//   _poln, _ardo, _sık_, _בגרו,
   {{0x62888042,0x8c1c03de,0x443fcb97,0x7bca8c6f}},	//   _brdo, עווי, _vvu_, gifu,
   {{0xe2998c07,0x63a19bff,0x5b580051,0xea0000ff}},	//   тай_, _voln, אשון_, _chặt_,
   {{0x63a1809a,0x62838b80,0x200e930c,0x48fc001b}},	//   _woln, rvno, _aifi_, लेको_,
   {{0xa91d8067,0x6288ebb6,0x24890069,0x69c9cca0}},	//   jdže, _erdo, _nram_, riee,
   {{0x69c981b0,0xb06880f7,0x3f810077,0x9e6581e2}},	//   siee, اصيل_, ndhu_, авод,
   {{0xf772004c,0x2c1d80c8,0x75f884c3,0x7bfa8158}},	//   חקי_, _নিয়ে_, líza, _ספעצ,
   {{0x24896bb7,0x6933804e,0x44320114,0x4424b793}},	//   _bram_, _اکثر, _pwy_, _ytm_,
   {{0x200e84be,0xd1b8803d,0x75f883a8,0xb4c003b7}},	//   _fifi_, _حالا_, níza, ंछे_,
   {{0xf77196a5,0xbcfb007b,0xa01b0106,0x24896bb8}},	//   _ذات_, mfél, _tröj, _dram_,
   {{0x24892031,0x6569ebb9,0xdb250019,0xa01b18b6}},	//   _eram_, _obeh, ásár, _frök,
   {{0x38603a2a,0x24892c9f,0x13d286ab,0x31260048}},	//   ttir_, _fram_, _तद्भ, рдаг,
   {{0xfbdf0548,0xa3e58074,0x2d920870,0x00830037}},	// [6100] guês_, नवा_, _inye_, олто,
   {{0xee0e81ab,0x6d5bebba,0x320f816b,0xf77201a8}},	//   िद्ध_, _acua, _ligy_, غاء_,
   {{0x38606bbb,0x2fc780dd,0x660286cb,0xdb1e0580}},	//   stir_, _mmng_, tmok, _impà,
   {{0x38606bbc,0x9325003d,0x75f64a84,0xb8cc0264}},	//   ptir_, _پرین, zázn, _কই_,
   {{0x69d66bbd,0x2722801b,0x6e29007a,0x66028cf9}},	//   mnye, nční_, _čebe, rmok,
   {{0x051680c8,0x6d5bb928,0x81d700ab,0x2a6ca45f}},	//   ারের_, _ecua, িতঃ_, _ppdb_,
   {{0x2d96885f,0x7bcaebbe,0x2d920a2c,0xa59680e8}},	//   _крас, rifu, _onye_, _кращ,
   {{0x2369803b,0xdca6a373,0x69d6200a,0x7bca805d}},	//   đaja_, _каби, nnye, sifu,
   {{0x442480ee,0x673a8019,0x73768fe6,0x62830118}},	//   _utm_, tatj, _выех, _ánov,
   {{0x07b88307,0x2d926210,0x8146804e,0x69d600ee}},	//   اهدة_, _anye_, _چنان, hnye,
   {{0x2d8004df,0x2486813c,0xc2248065,0x673aebbf}},	//   _baie_, lvom_, _اکتو, ratj,
   {{0x58868a8e,0x200e9532,0x2fc782f7,0xc8c79e5c}},	//   _выка, _wifi_, _emng_, اوین_,
   {{0xa3ca901c,0x2d800748,0x3a2600c3,0x2d920176}},	//   _लगा_, _daie_, _čopa_, _dnye_,
   {{0x2d92580c,0x9f58489c,0xa91d80ce,0xfd1f01e8}},	//   _enye_, _miró_, rdže, scì_,
   {{0x31c7076a,0xf9c70098,0x19950098,0xdb018036}},	//   асав, ащан, бавя, _colè,
   {{0x2486803a,0xbf0700d4,0x4e1d0105,0x391513bd}},	//   kvom_, _वृषभ_, _बंबई_, смар,
   {{0xa3d6853e,0xd7aa8fd5,0x4059053d,0x3dc902c4}},	// [6110] ाचा_, _चकाच, طلاح_, _imaw_,
   {{0x753d0117,0x2fc70104,0xdf3900f7,0x2d80011b}},	//   lasz, òng_, اكات_, _zaie_,
   {{0x75158307,0x3f810dab,0x39468084,0x3ea74dcc}},	//   مواض, rdhu_, _odos_, ânt_,
   {{0x241981bb,0xb99500f7,0xdb1e002a,0xbcfb0061}},	//   годы_, _الحب, _impá, yfél,
   {{0xb8cc00c8,0x320f8326,0x2d588087,0x629a01d6}},	//   _কে_, _rigy_, ричь_, ätov,
   {{0x6738920e,0x75f881df,0x3946ebc0,0xfe0a001c}},	//   _nevj, ríza, _ados_, _lắp_,
   {{0xe1ff0028,0xdb01ebc1,0x21390168,0x753d6546}},	//   _khó_, _kolé, _kesh_, kasz,
   {{0x2249803b,0x20110010,0x69cd031d,0x63a501ec}},	//   čak_, _hizi_, niae, _lohn,
   {{0xdb01887a,0x78ad410c,0x9f59041c,0x0dc88bc7}},	//   _molé, nyav, _fusô_, _тури_,
   {{0x3fb780c8,0xbcfb007b,0x20196bc2,0x291f8511}},	//   ীক্ষ, rfél, _musi_, scua_,
   {{0xbebc8029,0x66e5961a,0x20190f33,0x6b9c8722}},	//   ecīb, сона, _lusi_, _òrga,
   {{0x6d59a73c,0x75f61307,0xe1ff4823,0x6b818079}},	//   ngwa, rázo, _nhó_, _halg,
   {{0x3f69831f,0x69cd0114,0xdb0186c0,0xb0c706a7}},	//   _било_, diae, _solè, _रेलग,
   {{0x6b818074,0xe1ff046d,0xdb018722,0x272281d0}},	//   _jalg, _ahó_, _polè, rční_,
   {{0x6b81ebc3,0x2d9200ee,0x2d800162,0x213903ed}},	//   _malg, _tnye_, _taie_, _besh_,
   {{0x2019190d,0xe1ff00ff,0xdb01ebc4,0x69cd4c7e}},	//   _busi_, _chó_, _colé, giae,
   {{0x20115dbe,0x69d66bc5,0x21200214,0x442b0144}},	// [6120] _bizi_, rnye, rcih_, cpc_,
   {{0x6b818feb,0x61e98c0b,0xc49b01c6,0x2a69866f}},	//   _nalg, hoel, _עשית, łaby_,
   {{0x6b7b0f60,0x20110214,0x7bce01f6,0x0e66072f}},	//   _גרינ, _dizi_, mibu, скен,
   {{0x24868ee0,0x20196bc6,0x7e4b0019,0x395d8326}},	//   tvom_, _fusi_, اسلہ_, _ncws_,
   {{0x61e9838e,0x201910e1,0xeb108105,0x9f5801e8}},	//   doel, _gusi_, ाश्त_, _dirò_,
   {{0x6b8182e6,0x2011061b,0xf99f0247,0x2d809e51}},	//   _calg, _gizi_, _chèf_, žie_,
   {{0xb28691e9,0x75240102,0xe7dd016f,0x7d160114}},	//   сылк, _ofiz, _मदतप, _ogys,
   {{0x75d69a3e,0x7bce0a4f,0x61e98102,0x7984697f}},	//   _ايرا, hibu, goel, ndiw,
   {{0xf48483f8,0xa3c90b3b,0xa3e82c17,0x3ce001c0}},	//   _بازی, लोड_, यका_, _nxiv_,
   {{0x310483b7,0xfe0a001c,0x2fca0042,0x6b81dc04}},	//   शेषः_, _sắp_, _jmbg_, _galg,
   {{0x7bdf82be,0x63a509f4,0xbcfb016b,0xe21696a5}},	//   éque, _rohn, rfém, _طباع,
   {{0xd6d7ebc7,0x8cb52714,0x64428009,0x604181bc}},	//   сть_, उनलो, osoi, _ịmer,
   {{0xac1903c7,0xb0c7131d,0x753d6546,0x6ce70048}},	//   рогу_, _रेंग, rasz, сіне,
   {{0x7d160065,0x442b0953,0x69da00e7,0x9f5800f7}},	//   _egys, rpc_, éten, _bhrí_,
   {{0x7f3b8159,0x20190475,0x753d0019,0xe1ff001c}},	//   _געוו, _susi_, pasz, _phó_,
   {{0x38350160,0x63a50352,0xdcfb9c89,0x23ab806a}},	//   жнар, _wohn, _sauč, _højt_,
   {{0x270e8086,0xdb05020f,0xa91dde9f,0x69cd0355}},	// [6130] lən_, _kohë, ndža, riae,
   {{0x4429280a,0x161d00d4,0x78ad038a,0x61e9ba5d}},	//   _ita_, _बंदर_, ryav, zoel,
   {{0x163b0013,0xb8f022bd,0x270e8085,0xdcfb9487}},	//   اسطة_, _वे_, nən_, _vauč,
   {{0x4ac3816f,0x2011004f,0x20196bc8,0x7afa6237}},	//   _वेगव, _wizi_, _tusi_, ütte,
   {{0xa3bd4d54,0x04679240,0x201903ff,0x61e983b2}},	//   _आता_, стем, _uusi_, voel,
   {{0x1ae280ab,0x270e8085,0x62830118,0x75228037}},	//   গেছে_, kən_, _ános, acoz,
   {{0x6b81ebc9,0x61e99c2b,0xb16e008b,0x9f580037}},	//   _valg, toel, _þýði, _tirò_,
   {{0x270e8086,0x44296bca,0x7bce2acc,0x6b81c9a6}},	//   dən_, _ota_, zibu, _walg,
   {{0x44296bcb,0x98a0017f,0x9f458198,0x7bce3364}},	//   _nta_, rbić_, yllä_, yibu,
   {{0x7c2982a0,0x3e7a8029,0x656d43f1,0x20118019}},	//   _iter, _būt_, _abah, özi_,
   {{0x44296bcc,0x753b8a0f,0xd9fb016f,0xa3d686ab}},	//   _ata_, _keuz, ्षात_, ाचर_,
   {{0x7c2983bb,0x3f831600,0x960400d4,0xa50a0073}},	//   _kter, _laju_, रगेट_, иена_,
   {{0x7bce6bcd,0xf7459285,0x7641e2aa,0xccfa0221}},	//   tibu, _дело, ssly, рхні_,
   {{0xf8078cd0,0x7643808e,0x248d8b80,0x69dd0140}},	//   _учен, _tvny, _mrem_, _ajse,
   {{0x44296bce,0x9c870efc,0x316900ee,0x201f8144}},	//   _eta_, _počí, ffaz_, lqui_,
   {{0x7c29a4c2,0x3ce010af,0x753bdc47,0x7bce34e7}},	//   _oter, _txiv_, _neuz, sibu,
   {{0xa2ca03bb,0x3f830867,0x7c29ebcf,0x201fbdb4}},	// [6140] _हेर्, _baju_, _nter, nqui_,
   {{0x3f85805d,0x46f60098,0x24800214,0x75f601d0}},	//   ndlu_, очет, _isim_, kázk,
   {{0x69cb8b3c,0x7c29ebd0,0xe29a0f27,0xdd1c816b}},	//   _omge, _ater, _тан_, rážo,
   {{0xf53f0bc5,0x213f810b,0x44290711,0x7c2989d1}},	//   lkår_, jauh_, _yta_, _bter,
   {{0xac0aaf63,0x240a9b8b,0xdca38dc9,0x270e8085}},	//   анда_, анди_, маци, zən_,
   {{0x270e8201,0x7522b9c8,0xa01b016d,0xdb0501b3}},	//   yən_, scoz, _pröv, _bohè,
   {{0x64429de9,0x248d87f1,0x96631bc6,0x3f85ae82}},	//   ssoi, _erem_, _окре, ddlu_,
   {{0x2480003a,0x394009b2,0x248d8b40,0xdd92803d}},	//   _osim_, nais_, _frem_, _تور_,
   {{0x673c059c,0x248d807a,0x28d00ec5,0x6010046d}},	//   _kerj, _grem_, _सेमि, _gómì,
   {{0x39402081,0x661c6bd1,0x2d84ebd2,0xa91d826c}},	//   hais_, _kurk, _hame_, rdža,
   {{0x39402393,0x248041ae,0x2d84ebd3,0x673c6bd4}},	//   kais_, _asim_, _kame_, _merj,
   {{0x63a8a1e7,0x69da0065,0x270e8201,0x39400df1}},	//   _hodn, étel, rən_, jais_,
   {{0x270e8201,0x442902f7,0x7c298609,0x39405566}},	//   sən_, _qta_, _xter, dais_,
   {{0x673c4203,0x63a881a1,0xd0078087,0x98a382ee}},	//   _nerj, _jodn, _дече_, _циље,
   {{0x63a8bf13,0xd13b0098,0x24800009,0xf1a70705}},	//   _modn, иха_, _esim_, оран,
   {{0x2d84ebd5,0x224d6bd6,0x2d8500eb,0x656d211a}},	//   _name_, ček_, ēles_, _ubah,
   {{0x673c14ff,0x44296bd7,0x661c00ad,0x2bdba2bd}},	// [6150] _berj, _uta_, _aurk, _बदला,
   {{0xf7730872,0x59ca8105,0x656080f7,0xc72b00e8}},	//   بار_, ़ोतर, _acmh, ріал_,
   {{0x661c494f,0x248d8bda,0x673c643a,0x2d84d42f}},	//   _curk, _srem_, _derj, _bame_,
   {{0x7c298358,0x7e9b8051,0x394009b2,0x427a00be}},	//   _pter, יסבו, cais_, _פארג,
   {{0xc86405a5,0x506404fa,0xdb170118,0xa3d6816f}},	//   _отри, _отра, _alxé, ाचं_,
   {{0x32096bd8,0xd0fa0b04,0x447c00be,0x248d8087}},	//   lmay_, ्धरण_, ינדע, _vrem_,
   {{0x61e48353,0x661c048d,0xb113019d,0x63a8816b}},	//   čiln, _gurk, _bụga, _dodn,
   {{0x75f6003e,0x32091a08,0x2d848039,0x248debd9}},	//   rázk, nmay_, _game_, _trem_,
   {{0xdb1e0009,0xc21b8424,0xb3678098,0x661c00fe}},	//   _ympä, _पूरब_, _мъжк, _zurk,
   {{0x6d5d0079,0x2d84ebda,0x39402744,0xaec59bf5}},	//   egsa, _zame_, zais_, збол,
   {{0xe9df0324,0x25a90118,0xdb01816b,0x3f85808e}},	//   _ojú_, _boal_, _kolí, rdlu_,
   {{0x6281ebdb,0x69cb90f6,0xdb1c00f7,0x24800d56}},	//   _islo, _umge, mhré, _psim_,
   {{0x39406bdc,0x6b85635f,0x60020187,0x6459d099}},	//   vais_, _bahg, lôme, nuwi,
   {{0xe81f0816,0xe9df501c,0x2c641e5e,0x201d82d5}},	//   _बढ़ा_, _ajú_, röd_, _iuwi_,
   {{0x39406bdd,0x60020187,0x8f9a81c6,0x3af50198}},	//   tais_, nôme, _ליסי, дятс,
   {{0x248001e9,0x673c01b9,0x201d83f8,0x3209033e}},	//   _tsim_, _serj, _kuwi_, gmay_,
   {{0x673c6bde,0x24800748,0x61f605ee,0x55bb01c6}},	// [6160] _perj, _usim_, rlyl, _למקו,
   {{0x2d84ebdf,0x39400e37,0xdee66be0,0x32090079}},	//   _same_, sais_, пози, amay_,
   {{0x64466be1,0x673c6be2,0xa01b016d,0xdb01b673}},	//   lski, _verj, _brös, _bolí,
   {{0x63a88353,0x271901d0,0x320901b4,0x6002041c}},	//   _sodn, třní_, cmay_, dôme,
   {{0x673c5847,0xc95304de,0xa2d40a74,0x645980e4}},	//   _terj, _אמר_, णपक्, guwi,
   {{0x64466be3,0x60d68084,0x60c40234,0x79860a03}},	//   iski, _žymo, mzim, _hakw,
   {{0x63a8905e,0xdee3196f,0xdb018825,0xd35700be}},	//   _vodn, _зори, _folí, ליסי_,
   {{0xcb130051,0xa01b0004,0x61e482d4,0x63a88035}},	//   עלה_, _tröt, čilo, _wodn,
   {{0x60c46be4,0x79866be5,0x5ea980ab,0x1b1b8264}},	//   nzim, _makw, _ছেলে, _নজরে_,
   {{0x25a90500,0x66046be6,0x9178826b,0x60021243}},	//   _soal_, _ahik, _bẹ́_, lômb,
   {{0xb8f39880,0x32090637,0x66041d26,0x79861b7d}},	//   _हे_, ymay_, _bhik, _oakw,
   {{0x66046be7,0x79862d23,0xd5bb1cd0,0x1a9b80be}},	//   _chik, _nakw, ссо_, _ליבע,
   {{0xafdb0aa2,0xdcef0087,0x64466be8,0x660464cd}},	//   _svøm, decă, gski, _dhik,
   {{0x60c46be9,0xa01b0338,0x7f4196f0,0xea000129}},	//   dzim, _orör, calq, _đạc_,
   {{0x61ed6bea,0x79866beb,0x2b4c826c,0xd37800e8}},	//   toal, _bakw, _mddc_, ччя_,
   {{0x521428a7,0x65bf020f,0x777a8102,0x765a83f7}},	//   едст, _bëhe, letx, muty,
   {{0x28c70076,0x79866bec,0x320940a5,0x6d4d5d34}},	// [6170] _रेखि, _dakw, rmay_, _idaa,
   {{0x7c2d00b4,0xdb01816a,0x32093f6f,0x61ed6bed}},	//   _itar, _solí, smay_, soal,
   {{0x4fc41b56,0xf77001a8,0x752d8333,0x1a650061}},	//   хста, طال_, ñazo, _تیزی_,
   {{0xf6501e7b,0x6459809c,0x25a9807b,0x79863b0a}},	//   ائل_, tuwi, ðal_, _gakw,
   {{0x69c0931a,0x8ccd809a,0xf3ff0187,0xdb01ebee}},	//   dhme, _देशो, ntão_, _volí,
   {{0x38696bef,0x7986664a,0x765a818c,0xeb969a1f}},	//   mtar_, _zakw, kuty, диш_,
   {{0xf7720039,0x79866bf0,0xa01b1614,0xdb0502df}},	//   _שקל_, _yakw, _trös, _ilhó,
   {{0xdb08a2a2,0x3a2c8118,0x69c0822b,0x64466bf1}},	//   _modè, _dtdp_, ghme, yski,
   {{0x7c2d02a0,0x69dbebf2,0x7d1bebf3,0xc5e99d6a}},	//   _ntar, rnue, _igus, टकीय_,
   {{0x442debf4,0x6604020f,0x64464be1,0x38693a50}},	//   _ite_, _shik, vski, itar_,
   {{0x6281a997,0x7c2d2557,0x6446009a,0x90e782e3}},	//   _uslo, _atar, wski, _کسان,
   {{0x6446003a,0xe9458077,0xd7f88087,0x38693613}},	//   tski, _آرای, ală_, ktar_,
   {{0xb4b84c4b,0x644601bb,0xdb1e002a,0x201d876d}},	//   चने_, uski, _impú, _uuwi_,
   {{0x79866bf5,0xee39b0bb,0x395fd929,0x38696bf6}},	//   _sakw, _днк_, lgus_, dtar_,
   {{0x644606b1,0x386903a7,0xca752b97,0x7c2d6bf7}},	//   sski, etar_, нуты, _etar,
   {{0x64460289,0x386929fb,0x395febf8,0x7d1bebf9}},	//   pski, ftar_, ngus_, _ngus,
   {{0x60c4003b,0xa0670819,0x386900f7,0x18671132}},	// [6180] uzim, мата_, gtar_, мати_,
   {{0x7d1bd800,0xe45703c8,0x798621ee,0x69cf355b}},	//   _agus, _קייט_, _wakw, _emce,
   {{0x442dd38e,0x3f87ebfa,0x44206bfb,0x79866bfc}},	//   _ate_, _manu_, _hui_, _takw,
   {{0x44202e04,0x89361125,0x3f878032,0x442d80b9}},	//   _kui_, _تعدا, _lanu_, _bte_,
   {{0x75e803bf,0x7989ebfd,0x44200036,0x0c7a99ed}},	//   mızd, ddew, _jui_, تصاب_,
   {{0x28c709a3,0x44200681,0x7529ebfe,0x442debff}},	//   _रेटि, _mui_, _efez, _dte_,
   {{0x4420401c,0x442dec00,0xfd6500ff,0x69c0adc8}},	//   _lui_, _ete_, _chuố, thme,
   {{0x31600380,0x442003d3,0x3f8782a3,0x75e803bf}},	//   ngiz_, _oui_, _aanu_, nızd,
   {{0xf4d900c8,0x6d40ec01,0x30148cdf,0x6e2d8279}},	//   _সর্ব, _iema, ндир, _čaba,
   {{0x2018082e,0x6d40ec02,0x69c0ec03,0x909b03c8}},	//   _jiri_, _hema, shme, קסיק,
   {{0x6d408458,0x20186c04,0x05c28996,0x0f570039}},	//   _kema, _miri_, _शताब, ויים_,
   {{0x6d40ec05,0x25a6ec06,0xa3d684e5,0x20186c07}},	//   _jema, njol_, ाचक_, _liri_,
   {{0x6d40845c,0x44200698,0xf9c782e3,0x39448110}},	//   _mema, _cui_, _تحلی, mams_,
   {{0xf3ff00a9,0xa3c90063,0x6d40878a,0xb3458073}},	//   rtão_, लों_, _lema, maçã,
   {{0xb34580a9,0xf3ff00a9,0xf1b280a5,0xd6cf99bb}},	//   laçã, stão_, _जवान, _рт_,
   {{0x23698e78,0x386903e5,0x44206c08,0x39448110}},	//   đaji_, ttar_, _fui_, nams_,
   {{0x7c20b605,0x20186c09,0xb3458073,0x5f952c99}},	// [6190] _numr, _biri_, naçã, ниат,
   {{0x645d6c0a,0x38696c0b,0x20181e92,0xdbd68406}},	//   musi, rtar_, _ciri_, _jään,
   {{0x6449ec0c,0x20186c0d,0x5d558425,0x6d409a29}},	//   _svei, _diri_, екет, _bema,
   {{0x62856c0e,0x38696c0f,0x3f870024,0x3944989e}},	//   _isho, ptar_, žnu_, jams_,
   {{0x6d40df5f,0x3944a5d6,0x645d19b0,0x1c008074}},	//   _dema, dams_, nusi, _लीहल_,
   {{0x7bd53033,0x657d39c9,0xb34583a7,0x3a210101}},	//   nizu, hesh, daçã, _kuhp_,
   {{0x645d022e,0x387f80b9,0x63a80106,0xadc38129}},	//   husi, wwur_, ödni, _giến,
   {{0x6d40844e,0x657d1cec,0x20185854,0x645d2cc7}},	//   _gema, jesh, _ziri_, kusi,
   {{0xe0d9920c,0xb3458073,0x657d3fd9,0x20180f50}},	//   яви_, gaçã, desh, _yiri_,
   {{0xfd650028,0x3fcd80ab,0x75f88e14,0x60068150}},	//   _thuố, রক্ষ, vízi, нным_,
   {{0x4420526f,0xf1bf303b,0xf77200be,0x6285227d}},	//   _sui_, _olá_, נקט_, _nsho,
   {{0x4420002e,0x3219052a,0x6d40ec10,0x394481a9}},	//   _pui_, _nisy_, _xema, cams_,
   {{0x44206c11,0xb34580a9,0x7fd5b941,0x645d6c12}},	//   _qui_, caçã, _пікі, gusi,
   {{0xdee5c46e,0x61fba465,0x44200104,0x66e59db0}},	//   _поли, llul, _vui_, _пола,
   {{0x61e90025,0x645d0a8e,0xe2971b78,0xf770819f}},	//   čeln, ausi, нар_, _خان_,
   {{0x20180a54,0x645d41b5,0x63738059,0x44206c13}},	//   _siri_, busi, lını, _tui_,
   {{0x6d46330d,0x6285657b,0x6d40960c,0x394fc6c8}},	// [61a0] maka, _esho, _rema, _mdgs_,
   {{0x04790077,0x7d042ae1,0x6373817b,0x61fb805d}},	//   _کلیک_, _izis, nını, hlul,
   {{0xb34580a9,0x6d408812,0x2018007a,0x61460294}},	//   zaçã, _pema, _viri_, _пена,
   {{0x10a60ada,0x201802a6,0x291d882e,0xadc380ff}},	//   _зимн, _wiri_, _ngwa_, _viến,
   {{0x25ad837a,0x6373880a,0xb3458187,0x20186c14}},	//   _doel_, kını, xaçã, _tiri_,
   {{0xf09f0142,0x69d62ae8,0x6d460c9e,0xadc38104}},	//   _ngày_, liye, haka, _tiến,
   {{0x6d40ec15,0x6d461868,0x39448df1,0x657d0c53}},	//   _tema, kaka, tams_, yesh,
   {{0x6d46111f,0xb34580a9,0x7bc381ac,0xdbd68009}},	//   jaka, taçã, ahnu, _sään,
   {{0x6d461ffe,0x657d6c16,0x61e2a371,0x3944989e}},	//   daka, vesh, _vjol, rams_,
   {{0xb3458003,0x7bc3c7e9,0x645d1202,0x3dc0076d}},	//   raçã, chnu, vusi, _aliw_,
   {{0x657d6c17,0xd6da835f,0x6d46427a,0xd3378039}},	//   tesh, яти_, faka, _נראה_,
   {{0x6d4638b6,0xa3cc83b7,0xb34583a7,0x6562d42f}},	//   gaka, शोर_, paçã, ngoh,
   {{0x69d63a59,0x7afa854f,0x6ad91107,0x6373861c}},	//   diye, _hytt, णप्र, bını,
   {{0xbcfb03d3,0xf99f6833,0x7d04009a,0x657d6c18}},	//   ffér, _chèn_, _dzis, sesh,
   {{0x645d6c19,0xda780ac8,0x657d122b,0x7d040316}},	//   susi, нят_, pesh, _ezis,
   {{0x657d2909,0x69c438ef,0xceb38039,0x61e94a31}},	//   qesh, ghie, _תיק_, čelo,
   {{0x3f8a00a4,0x7afa8aa2,0x2129008e,0x25ad8bfd}},	// [61b0] _babu_, _lytt, rcah_, _roel_,
   {{0x628501c5,0x320d80b9,0x752d00fc,0x6002041c}},	//   _tsho, zmey_, _hfaz, tôma,
   {{0x7afa821e,0x69d66c1a,0x628535d7,0x394203ba}},	//   _nytt, biye, _usho, _feks_,
   {{0x69c41c38,0x6373861c,0x69d6313f,0x3eae0106}},	//   chie, zını, ciye, äfta_,
   {{0x25ad90f4,0x637383bf,0xc86700e8,0x7dc600a2}},	//   _voel_, yını, _ятни, _fósf,
   {{0x6d466c1b,0x7afa8370,0xa91da040,0x823400d7}},	//   zaka, _bytt, mdži, _جریا,
   {{0xa91d8110,0xda62b2de,0x68fc8085,0x61fbec1c}},	//   ldži, авщи, ərdi, tlul,
   {{0x798d6c1d,0x25bf80ee,0xa224803d,0xdce405a2}},	//   ndaw, _ulul_, دروه, _ubić,
   {{0x63738059,0xa91d8110,0x61fbec1e,0xa3d100c2}},	//   tını, ndži, rlul, वफा_,
   {{0x6d4629d2,0x69d65759,0x661b8009,0xddc900d2}},	//   waka, ziye, _hiuk, _ćošk,
   {{0x63738a0b,0x6d466c1f,0x644d3621,0xed5a1bf5}},	//   rını, taka, _avai, мон_,
   {{0x63738a0b,0x2369803a,0x69d60079,0x443f81bc}},	//   sını, đaju_, xiye, _kwu_,
   {{0x6d4620a7,0xc8d001fe,0x798d42da,0xdb1c007b}},	//   raka, _सेंट, ddaw, firð,
   {{0x69e3856f,0x799d0039,0x386dec20,0x661baf84}},	//   šteđ, _answ, mter_, _liuk,
   {{0x6d461904,0x3f8a0274,0x43430098,0x60c98214}},	//   paka, _rabu_, ресв, lzem,
   {{0x3f8a6c21,0x798d0bb1,0x75f60061,0x644ba4d0}},	//   _sabu_, gdaw, rázs, ksgi,
   {{0x386dc6df,0x7bc18364,0x69d66c22,0xbcfb04e8}},	// [61c0] nter_, _ollu, riye, sfér,
   {{0x44320e35,0x386dec23,0x69d66c24,0x798bcbe9}},	//   _ity_, iter_, siye, _lagw,
   {{0x386d8613,0xbcfb6c25,0x69c41532,0x644d00eb}},	//   hter_, ngén, phie, _zvai,
   {{0x386dec26,0x66098a54,0x7afa81a3,0x798baeb5}},	//   kter_, _chek, _rytt, _nagw,
   {{0x672300d2,0x3f8a6c27,0x661b9295,0x386dba4d}},	//   žnja, _tabu_, _diuk, jter_,
   {{0xa3cc809a,0xa3c20075,0x38601a34,0x60c9b091}},	//   शों_, ंसि_, muir_, dzem,
   {{0xe9e6b385,0x443f815e,0x38602272,0x798bb364}},	//   кцио, _ewu_, luir_, _bagw,
   {{0x386d8bfa,0xdb050118,0xe1ef92c5,0x661b8122}},	//   fter_, _johá, يسي_, _giuk,
   {{0x386dc8b8,0xbc6a936d,0x38600531,0xa3c24a2f}},	//   gter_, _زمان_, nuir_, ंसा_,
   {{0x61ed9148,0x7afa8009,0x2cc4880a,0xdb0881ac}},	//   čala, _tytt, ırdı_, _hodí,
   {{0x443200f1,0x06d580ab,0xa91d8110,0x644d0612}},	//   _aty_, _সুবি, zdži, _svai,
   {{0x4424e301,0x6e239a34,0x798b838a,0x7c241581}},	//   _kum_, _dunb, _gagw, _buir,
   {{0x386da7a7,0x7c240068,0x442496b2,0x6d440102}},	//   cter_, _cuir, _jum_, _deia,
   {{0x442482ec,0x386049b1,0x9f9a0074,0x452880ab}},	//   _mum_, duir_, _jääb_, মরিক_,
   {{0x4424aa57,0xac180258,0x24182252,0x69c2a580}},	//   _lum_, тору_, торы_, _kloe,
   {{0x201c822e,0x11d90013,0x31c42be1,0x7c240014}},	//   _hivi_, روءة_, асув, _fuir,
   {{0x4424ec28,0xa91d8110,0x7bd8b1f8,0x201ca88c}},	// [61d0] _num_, udži, kivu, _kivi_,
   {{0x6609d6db,0xdb1a8c1d,0x69c28114,0xa91dec29}},	//   _shek, _altí, _lloe, rdži,
   {{0xa91dd200,0xa3c2097d,0xd7f848ac,0x60c9ec2a}},	//   leže, ्फर_, тут_, zzem,
   {{0x38601115,0x1eea026a,0x644b816d,0x386d8b64}},	//   buir_, رونی_, tsgi, yter_,
   {{0x44248c6e,0x386dec2b,0x33d58a18,0xad9b04c3}},	//   _cum_, xter_, лікт, clúe,
   {{0x4424b97f,0x3949038e,0xadc3801c,0x60c9b29a}},	//   _dum_, laas_, _thắn, vzem,
   {{0x69c290f4,0x4424e475,0x6609ec2c,0xb3648098}},	//   _bloe, _eum_, _thek, ръчк,
   {{0x386d806f,0x2489003b,0xceb200be,0x60c9b2be}},	//   tter_, _osam_, _פין_, tzem,
   {{0x386d83d3,0x44248014,0x6e23c552,0x6d444952}},	//   uter_, _gum_, _sunb, _reia,
   {{0x798b84df,0xee3995b5,0x7bc1ec2d,0x60c9dcb0}},	//   _wagw, нно_, _ullu, rzem,
   {{0x4424834a,0x24893bde,0xb8fa8f0a,0x61e92cf6}},	//   _zum_, _asam_, _डे_, čelj,
   {{0xb2ba8158,0xf41f0009,0x64a60071,0xaee38032}},	//   _אמער, yvät_, гама, _aiṣi,
   {{0x7c2420e6,0x3a258b3c,0x394902a3,0x4424ec2e}},	//   _quir, _hulp_, daas_, _xum_,
   {{0x7052845a,0xf745ec2f,0xa0668adb,0x3f81111b}},	//   _انوا, _секо, _саша_, jehu_,
   {{0xfc3f04c3,0xdb0503b0,0x248900eb,0x656982f7}},	//   rxía_, _pohá, _esam_, _oceh,
   {{0x201c80d2,0x05662432,0x39490079,0x7c240090}},	//   _zivi_, _свин, gaas_, _tuir,
   {{0xbcfb6c30,0x98a30103,0x600a017d,0x44326911}},	// [61e0] ngél, бите, енам_, _uty_,
   {{0xb8dc0a27,0x44249db6,0x351b0051,0x2d826c31}},	//   _अथ_, _rum_, _אופנ, leke_,
   {{0x44248a64,0xdb08ec32,0xfc3f0118,0x39496c33}},	//   _sum_, _podí, nxín_, baas_,
   {{0x2d82082e,0x6566416a,0x6ce6a183,0x7dc60118}},	//   neke_, ngkh, ліле, _fóse,
   {{0x7bd8995d,0x61e44811,0x7e61915b,0x320001c0}},	//   tivu, mnil, hulp, mliy_,
   {{0x61e42840,0x2d826c34,0xa91d8669,0x69c29699}},	//   lnil, heke_, ndžu, _sloe,
   {{0x69c2c734,0x2d826c35,0x201cec36,0x79808545}},	//   _ploe, keke_, _rivi_, temw,
   {{0x61e46c37,0x48aabd00,0x2d82120e,0x7bd883a0}},	//   nnil, етом_, jeke_, sivu,
   {{0x69c28b3c,0x442480ee,0x61e467e5,0x76aa8085}},	//   _vloe, _uum_, inil, məyi,
   {{0x53b8863a,0x76aa8085,0x61e46c38,0x307780f7}},	//   _अविश, ləyi, hnil, احية_,
   {{0x7413845b,0x200280eb,0x201cec39,0xa91d84c4}},	//   _اولا, ēki_, _vivi_, veže,
   {{0xb11301bc,0x61e4016b,0x25a00036,0xdcf6011c}},	//   _bụla, jnil, _cnil_, _qayğ,
   {{0xdfda8098,0x201cec3a,0xa91d8968,0x5c741afd}},	//   _пък_, _tivi_, teže, блят,
   {{0x39490079,0x00000000,0x00000000,0x00000000}},	//   waas_, --, --, --,
   {{0x3949270d,0x2d820234,0x539b8039,0x7e618e65}},	//   taas_, beke_, עילו, culp,
   {{0xa91d807a,0x248901c5,0x61e46c3b,0xf99f00ff}},	//   seže, _tsam_, gnil, _thèm_,
   {{0x361c0051,0x3f8e8b67,0x06b200ab,0x24890187}},	// [61f0] _אוהד, _kafu_, _টেলি, _usam_,
   {{0xb4c1053e,0x44393885,0x600b02d0,0x39496c3c}},	//   ंनी_, mps_, küme, saas_,
   {{0x6723012b,0xa3c2009a,0x370750cd,0x4439360b}},	//   žnjo, ंसर_, учав, lps_,
   {{0x645db032,0x39468088,0x29e82828,0xe80b8fd5}},	//   _åsik, _neos_, lğan_, _सीना_,
   {{0x64a5981d,0xdca5b929,0xdcfd0110,0x7e61811b}},	//   рала, рали, kesč, zulp,
   {{0x4255867c,0x44390722,0x644f0834,0x2d8201f6}},	//   атит, ips_, isci, zeke_,
   {{0xdce9803a,0x02d88ec5,0xadc3827d,0xfbb801c6}},	//   _obeć, _भेदभ, _chản, רפות_,
   {{0x3946bfe4,0x020580a9,0x76aa8085,0x645d026c}},	//   _ceos_, јзин, cəyi, krsi,
   {{0x6d4bcd16,0x798f0358,0x394687b6,0x3f8e8c2e}},	//   maga, _macw, _deos_, _bafu_,
   {{0x6d4bc517,0x2d826c3d,0x660d6c3e,0x61e40968}},	//   laga, weke_, _ahak, znil,
   {{0x2d826c3f,0x660d3419,0x61e46c40,0x645d115b}},	//   teke_, _bhak, ynil, ersi,
   {{0x6d4bec41,0x6b838c90,0x660d022e,0x58d98b33}},	//   naga, leng, _chak, _идея_,
   {{0xe72e8ae7,0x2d82130e,0x660d6c42,0x7e61be34}},	//   _ме_, reke_, _dhak, sulp,
   {{0x6b83ec43,0x6d4ba66f,0x60cd1a23,0x2d8206a0}},	//   neng, haga, dzam, seke_,
   {{0x6d4bec44,0x2bb88697,0x2d823c15,0x645d1bad}},	//   kaga, _अवसा, peke_, arsi,
   {{0xdb1c03b0,0x7bc526f7,0x6b83c461,0x61e40087}},	//   nkré, _elhu, heng, unil,
   {{0x6b839f37,0x75240435,0x798f0079,0x78a9802a}},	// [6200] keng, _igiz, _dacw, nxev,
   {{0xe80b83db,0x6b83ec45,0xf41f0106,0xeb9a0256}},	//   _सीमा_, jeng, svär_, _рио_,
   {{0x7bdc674a,0x76aa8201,0x6d4bec46,0xa5268071}},	//   miru, təyi, faga, амед,
   {{0x6d4be37f,0xed5a9c56,0x644409b6,0x25a08216}},	//   gaga, тод_, _kwii, ñil_,
   {{0x69c98079,0x67238968,0x39468661,0x69c66c47}},	//   dhee, _ognj, _reos_, _ilke,
   {{0x6b83ec48,0x7bdc6c49,0x35a80d86,0x78bb8216}},	//   geng, niru, गाड़, dyuv,
   {{0x6d4b94ec,0xdee3002e,0x237a00b9,0x6e270300}},	//   baga, _дори, _mbpj_, _gujb,
   {{0x6d4bec4a,0x3f8e804f,0x7524005d,0x69c98bfd}},	//   caga, _safu_, _ngiz, ghee,
   {{0xdb088efc,0x6b83ec4b,0x387201a3,0x2d97816b}},	//   _dodá, beng, ntyr_, ádež_,
   {{0x645d05f5,0x61e90754,0x7524227d,0x6b8381d4}},	//   vrsi, čeli, _agiz, ceng,
   {{0x6e20822e,0x7c3600f1,0x7bdc6c4c,0x37a793bf}},	//   _kimb, _atyr, diru, ртын_,
   {{0x6e20ec4d,0x6602a833,0x69c9a895,0xaadb81c6}},	//   _jimb, nlok, chee, _בחבר,
   {{0xb4c10063,0xb3b401ab,0x76430019,0x6e20ec4e}},	//   ंने_, ुसंख, ányz, _mimb,
   {{0x660d6c4f,0x75244eae,0x6d4bec50,0x6602805d}},	//   _whak, _egiz, zaga, hlok,
   {{0x6d4be088,0x88e880ab,0xd6278b30,0x6e20826c}},	//   yaga, _পরিক, _које_, _oimb,
   {{0xa91dec51,0x44396c52,0x6e20c998,0x6b838555}},	//   leža, pps_, _nimb, zeng,
   {{0x6b83ec53,0x6602d003,0x7bdc0deb,0xad9b002a}},	// [6210] yeng, dlok, biru, clúa,
   {{0xc60f8935,0x60cd6c54,0x6d4bec55,0x960f824c}},	//   िष्य_, rzam, waga, िष्ट_,
   {{0x6d4bccde,0xb8fe0d38,0x6e20ec56,0x6b839fd9}},	//   taga, _थे_, _bimb, veng,
   {{0x44296c57,0x6b83ec58,0xb113019d,0x656d01e0}},	//   _kua_, weng, _jụka, _jcah,
   {{0x6d4bec59,0x44296c5a,0x6e20c3c6,0x24f881bb}},	//   raga, _jua_, _dimb, анцы_,
   {{0x44296c5b,0x6d4bccde,0x442107dd,0xa91db7a2}},	//   _mua_, saga, _jih_, ježa,
   {{0x6d4b82e8,0x0d678698,0x5b7c0051,0xb5a78056}},	//   paga, _възм, דרוא, _край,
   {{0x6b838c6f,0x2bd988d4,0x6e20ec5c,0x7bdc215c}},	//   seng, _भगवा, _gimb, ziru,
   {{0x44290307,0x6b83ec5d,0x3f9100d2,0x69c9ad66}},	//   _nua_, peng, _kazu_, rhee,
   {{0x69c9ec5e,0x248d84b7,0xdb1c170b,0x656d0db1}},	//   shee, _isem_, skré, _acah,
   {{0x7c360e51,0xb4e783eb,0x7c2996f3,0x44296c5f}},	//   _styr, _पशु_, _huer, _aua_,
   {{0xc329010f,0x3f91017f,0x44296c60,0x44216c61}},	//   _טו_, _lazu_, _bua_, _aih_,
   {{0x442105f5,0x44295b4e,0x248d83bb,0x213f859c}},	//   _bih_, _cua_, _jsem_, mbuh_,
   {{0x44296c62,0x7c2985b4,0xf7718019,0x44211705}},	//   _dua_, _muer, _رات_, _cih_,
   {{0xdd11003e,0x657b80fa,0x442938be,0x44216c63}},	//   _výšk, _obuh, _eua_, _dih_,
   {{0xe80b946d,0x7bdc6116,0x7c2981b0,0xb11301bc}},	//   _सीता_, siru, _ouer, _gụka,
   {{0x44290057,0x0ce280c8,0x6e208d02,0x3e71dfcf}},	// [6220] _gua_, _বর্ত, _rimb, lát_,
   {{0xbb860013,0x442161f3,0x657bd8c1,0xab6627ee}},	//   _الدي, _gih_, _abuh, _увол,
   {{0x3f910352,0x38720bc5,0x2d926c64,0x600203a7}},	//   _dazu_, styr_, _kaye_, nômi,
   {{0x237f003a,0x4429022c,0xa2d1064a,0x7c298865}},	//   đuje_, _yua_, _डेट्, _buer,
   {{0x3f91012b,0x7c2985b4,0x89d88077,0x6602a240}},	//   _fazu_, _cuer, یوتر_, rlok,
   {{0x7c29ec65,0x3f8582fd,0x2d92434e,0x6e208010}},	//   _duer, jelu_, _laye_, _wimb,
   {{0x69a49513,0x3e718065,0x3f85ec66,0xe80b959a}},	//   काली, ját_, delu_, _सीधा_,
   {{0x7c299220,0x2d923bef,0x38349878,0x2fc78637}},	//   _fuer, _naye_, онир, _alng_,
   {{0xdce41487,0x8c439b62,0x2fc7808e,0x25a48144}},	//   _obiđ, _нете, _blng_, _inml_,
   {{0x44296c67,0x7c2f82be,0xb7fa0b04,0x2d9210ab}},	//   _rua_, _écra, ्तिम_, _aaye_,
   {{0x44292017,0xd3378051,0x38603c76,0x3e718019}},	//   _sua_, _הרבה_, hrir_, gát_,
   {{0x44296c57,0xceb30051,0x4421035a,0x6fc0016d}},	//   _pua_, לית_, _sih_, _böck,
   {{0x44290104,0x3f85ec68,0xa91d895e,0xdb018176}},	//   _qua_, belu_, ležn, _anlè,
   {{0x4429001c,0x3e71a825,0xd9b30035,0xa3be83db}},	//   _vua_, bát_, ीस्ट, ँघट_,
   {{0x44216c69,0x69d9831d,0xd5bb0098,0x3f910035}},	//   _vih_, _ymwe, _бсп_, _razu_,
   {{0x44296c6a,0x463b8158,0x2d9203ec,0x38605705}},	//   _tua_, _געהע, _gaye_, frir_,
   {{0x7bc88afe,0x4421003a,0xb3eb0013,0x6d4f3f81}},	// [6230] _oldu, _tih_, _معدل_, maca,
   {{0x6d4f332f,0x2fc7001c,0x6aa88035,0x29024302}},	//   laca, óng_, _कपूर, _dyka_,
   {{0x6fc00352,0x7c29ec6b,0xa91d82ce,0x2d924650}},	//   _möch, _suer, ježn, _yaye_,
   {{0x6d4f521f,0x7c29ec6c,0x7bc8ec6d,0x29d38087}},	//   naca, _puer, _aldu, nţat_,
   {{0x7c298510,0x99801010,0x6d49ec6e,0x7bc68196}},	//   _quer, lmiş_, _veea, _įkur,
   {{0xeb999bbf,0x248d8353,0x6d4f117d,0x3dc90114}},	//   рик_, _vsem_, haca, _llaw_,
   {{0x998003bf,0x6d4f3156,0x853000fc,0x2d99816a}},	//   nmiş_, kaca, _haɗe, _óseo_,
   {{0x3e718065,0x6d4f0503,0x7c299f10,0xa6b200ab}},	//   vát_, jaca, _tuer, _টেকট,
   {{0x6d4f6c6f,0x6e2a81ec,0x2d9252a5,0x7c21ec70}},	//   daca, _aufb, _raye_, _tilr,
   {{0xeb9b89d7,0x3e718019,0x290380eb,0x2d926c71}},	//   _حضرت_, tát_, āja_, _saye_,
   {{0x6b9c8da1,0x59c90eed,0x28d99513,0x85ea1677}},	//   _órga, रसार, _बेरि, идов_,
   {{0x3e7183b0,0x6d4f6c72,0x69d9c668,0x3f85d66b}},	//   rát_, gaca, _umwe, selu_,
   {{0x7d0d0063,0x3e71ec73,0xb8fe80ab,0x2fc780dd}},	//   _czas, sát_, _দু_, _tlng_,
   {{0xa3ac8076,0x386002be,0xe7398226,0x2d926c74}},	//   गाय_, vrir_, _тек_, _waye_,
   {{0xdde90077,0x61e9ec75,0x7d0d41b5,0x394b5433}},	//   _گروه_, onel, _ezas, _becs_,
   {{0x6d4f155e,0x3e5581a9,0x394b07f1,0x3dc90428}},	//   caca, māt_, _cecs_, _glaw_,
   {{0x20c98778,0x186a028b,0xf8c9b2df,0x3e5580eb}},	// [6240] िनिध, рази_, िनिय, lāt_,
   {{0x61e98352,0x62819699,0x869a2d01,0x853009ab}},	//   hnel, _oplo, итет_, _daɗe,
   {{0x3e558029,0x628181e9,0x61e98110,0x61fbec76}},	//   nāt_, _nplo, knel, koul,
   {{0xa3c2000f,0x98a6199a,0xc8c980d4,0x7e7e8106}},	//   ंसक_, _диме, िनाट, _äppe,
   {{0x69c404b7,0x61e98279,0x61fb9c9f,0x64c48035}},	//   mkie, dnel, doul, वनेश,
   {{0xd25a90ca,0x69c46c77,0x629e011f,0x3e5581a9}},	//   аци_, lkie, _krpo, kāt_,
   {{0x6d4f0459,0x04fc80c8,0x6fc4858d,0x61fb93ff}},	//   yaca, েশের_, _dòcl, foul,
   {{0x69c46c78,0x61e98aa2,0xa91d807a,0x6e3888ae}},	//   nkie, gnel, režn, _rtvb,
   {{0x7d043e3d,0x224980d2,0xc2130039,0x628181a1}},	//   _nyis, ćaka_, והה_, _eplo,
   {{0x61e9802e,0xdd0901ac,0xc07b00be,0x69df1cd8}},	//   anel, _pôži, סטיש, ziqe,
   {{0x69c43473,0x7d046c79,0x6d4f6064,0xc9070105}},	//   kkie, _ayis, taca, _शर्म_,
   {{0x6d42ec7a,0x6e240362,0x61fbec7b,0x7dc6026b}},	//   nboa, _ciib, coul, _dóso,
   {{0x6e240d92,0x61e0d43f,0x69c40035,0x7d040a03}},	//   _diib, miml, dkie, _cyis,
   {{0x60cc8182,0x61e0880a,0x69c400eb,0x39590115}},	//   ılmı, liml, ekie, _sdss_,
   {{0x656b919b,0x2e4a8081,0x69cd6c7c,0x7dc607f1}},	//   yggh, _тяло_, thae, _góso,
   {{0x61e0803a,0x99800182,0x225e03c1,0x3c2f0192}},	//   niml, rmiş_, átka_, _tüv_,
   {{0x7d0d0ce7,0x657f01c5,0x69cd6c7d,0xfb2700d7}},	// [6250] _uzas, _ibqh, rhae, _وردپ,
   {{0xdb188125,0xdb21826f,0x61e0ec7e,0x7bce0799}},	//   mkvæ, _štít, himl, chbu,
   {{0x7c2d123d,0x61e0880a,0x6d4d00dd,0x68e481d0}},	//   _huar, kiml, _keaa, _židl,
   {{0x69c46c7f,0xb17b04e1,0xb50f06a7,0x60c0c6a7}},	//   ckie, _småf, _सराय_, kymm,
   {{0x62818db7,0x7c2d0590,0x18350158,0x69dd01b9}},	//   _splo, _juar, _מאָל_, _imse,
   {{0x443b0a84,0x764701c0,0x38690168,0x7c2d6c80}},	//   _mtq_, _twjy, muar_, _muar,
   {{0x38696c81,0x7c2d6c82,0xe7fa0054,0xf1bf001c}},	//   luar_, _luar, ्तरा_, _giác_,
   {{0x3e75016d,0xdb1e00e7,0x7a1c0176,0x61e98493}},	//   måt_, _impô, _pōti, unel,
   {{0x61fbec83,0xa3b88019,0x75298314,0x3e750b81}},	//   roul, _ڈالر_, _igez, låt_,
   {{0x69c43a4a,0x7c3bec84,0x200586d8,0x61e9be67}},	//   zkie, _itur, ulli_, snel,
   {{0x6281ec85,0x61fbec86,0xbea59652,0x69dd12af}},	//   _uplo, poul, чанк, _omse,
   {{0x3869020f,0x442d88b3,0x3eb8816d,0x44259272}},	//   kuar_, _kue_, ärta_, _hil_,
   {{0x7c2d3fe2,0x442d8264,0x386900f1,0xa0a58071}},	//   _cuar, _jue_, juar_, _халд,
   {{0x69dd031d,0x442589da,0x7c2d6c87,0x38690168}},	//   _amse, _jil_, _duar, duar_,
   {{0x442d8364,0xfaa320a3,0xa3ac816f,0xf09f026b}},	//   _lue_, наро, गात_, _arà_,
   {{0x442581cd,0x7c3b83bf,0x7529829b,0xba230d45}},	//   _lil_, _otur, _ngez, едск,
   {{0x69c4149d,0x7c2d0ca9,0x2d8002f7,0x7c2500fc}},	// [6260] rkie, _guar, _ibie_, _fihr,
   {{0x69c4002f,0x61e08059,0x6d5b8ad4,0x7d0497ad}},	//   skie, ziml, _adua, üism,
   {{0x6d42ec88,0x7c3b81bf,0x3bbb0039,0x61e0880a}},	//   tboa, _atur, _המיד, yiml,
   {{0x4425831d,0x38691832,0x600b02d0,0xf09f0037}},	//   _ail_, buar_, lüml, _frà_,
   {{0x4425ec89,0x7bde0a84,0x2a6a119b,0x61e08380}},	//   _bil_, _kmpu, lubb_, viml,
   {{0x69cbc2cf,0x442dec8a,0xa91d817f,0x6d428f3e}},	//   _alge, _due_, režl, sboa,
   {{0x4425c31f,0x249f807b,0x7bde00dd,0x61e081cc}},	//   _dil_, _erum_, _mmpu, timl,
   {{0x442d9220,0x89d8ce5c,0x44258046,0x11d880f7}},	//   _fue_, توبر_, _eil_, توبة_,
   {{0x64498355,0x442d816f,0x4425c951,0x7dc60207}},	//   _gwei, _gue_, _fil_, _cósm,
   {{0x69c5820f,0x30138196,0x61e087d9,0xbfaa94ed}},	//   ëher, ндыр, siml, стие_,
   {{0x3869020f,0x7c2d0500,0x644982af,0xfbb00107}},	//   zuar_, _suar, _zwei, ञानम,
   {{0x7c25311a,0xd6d79e2f,0x63ba8087,0x2ca01823}},	//   _sihr, яты_, _hotn, _brid_,
   {{0x44259238,0x8fa6c711,0x629c6c8b,0x7c2d213b}},	//   _yil_, _наде, evro, _quar,
   {{0xe10b8158,0x649210d3,0x442581b4,0x481380e8}},	//   _פּאָ, džić, _xil_, _зміс,
   {{0x63ba8353,0x7c250198,0xfc3f6b15,0x7c2d0326}},	//   _motn, _vihr, spí_, _wuar,
   {{0x386908cf,0x7c2d0cb5,0x63ba8035,0x225f0267}},	//   tuar_, _tuar, _lotn, čuk_,
   {{0x290f04b8,0x2d8b6c8c,0x7bde0118,0x600b1238}},	// [6270] åga_, mece_, _fmpu, büml,
   {{0x442dec8d,0x386908cf,0x2d8b03cd,0x290701a9}},	//   _rue_, ruar_, lece_, āna_,
   {{0x38692c3d,0x7c3bd475,0xf55991cc,0xfe788110}},	//   suar_, _stur, قلاب_, ntį_,
   {{0x2d9905f8,0x21670364,0x69dd6c8e,0x2d8b2b49}},	//   ndse_, _этог, _umse, nece_,
   {{0x61ed0087,0x53d102f1,0x3869273e,0x63ba80d9}},	//   mnal, _हताश, quar_, _botn,
   {{0x442d82be,0xfe788110,0x32093f81,0x3e750106}},	//   _vue_, ktį_, llay_, påt_,
   {{0x4425805f,0x994d01ac,0x6e2e26f4,0xdb188106}},	//   _vil_, _môžu_, _gubb, jkvä,
   {{0x442581d8,0x61ed6c8f,0xa2b505e8,0x63a8813c}},	//   _wil_, nnal, _उपन्, _endn,
   {{0x442595f8,0x2d8b05c5,0x16dd39a1,0x7c3bb13e}},	//   _til_, dece_, _मधुब, _utur,
   {{0x600697ae,0x4425ec90,0x628549e9,0x2d991412}},	//   мным_, _uil_, _opho, edse_,
   {{0xd1758196,0x6285022c,0x320900e4,0x59758048}},	//   _жылы, _npho, klay_, _жылу,
   {{0xfce61ff8,0x2ca0011a,0x9f458037,0xdb1c128a}},	//   домо, _prid_, golò_, jkrá,
   {{0xb886807b,0xdcfb8024,0x32096c91,0xdbd787b8}},	//   rsíð, _obuč, dlay_, pääs,
   {{0x660e01ac,0x39520039,0x853000fc,0x225e1e51}},	//   _ďaku, ways_, _daɗa, átko_,
   {{0xe29733ba,0x628e00f3,0xdb188106,0xab270e63}},	//   мар_, uwbo, ckvä, дора_,
   {{0x61ed4bc7,0x320955cd,0x2ca004b7,0xb6868065}},	//   gnal, glay_, _trid_, _کھیل_,
   {{0x66040870,0x62856c92,0x629c1384,0xed598140}},	// [6280] _ikik, _epho, svro, _možd_,
   {{0x6e2e4806,0x77fa0076,0xbcfb5207,0x7e7b298e}},	//   _pubb, ्तेक_, rgét, _ćupr,
   {{0x32094336,0x3dcdabf7,0xb9050441,0xef1881a9}},	//   blay_, _blew_, _भे_, beļu_,
   {{0xa91d807a,0x7f4e0363,0x85300326,0xdb1c04e8}},	//   režj, _webq, _yaɗa, ckrá,
   {{0x6d460748,0x63ba807a,0xc95304de,0x61e46c93}},	//   ibka, _potn, _שמש_, miil,
   {{0xdb2181ac,0x1ae980ab,0x61e46c94,0x3dc6b07c}},	//   _štát, য়েছে_, liil, skow_,
   {{0xa93487ac,0xf1a9816f,0xbcfb00d7,0x2d99067f}},	//   нейш, कांन, ngér, ydse_,
   {{0xa9c3835f,0xa3ac800f,0x61e40e68,0xdb01ec95}},	//   вськ, गाह_, niil, _polò,
   {{0x2d8b0098,0x60d62651,0x3f981fb2,0x92be8264}},	//   vece_, nzym, _karu_, ঁছে_,
   {{0x8c4381ae,0x66046c96,0x853009ab,0x6442ec97}},	//   _рефе, _akik, _raɗa, mpoi,
   {{0x61e40079,0x61ed6c98,0x6442ec99,0xdd9115a9}},	//   kiil, ynal, lpoi, هود_,
   {{0xfe788110,0xdb188106,0xa3ac8072,0x2bbe8072}},	//   rtį_, rkvä, गाव_, ्सवा,
   {{0x2d8b28d5,0x657d4ee2,0x61ed05b7,0x61e40e68}},	//   rece_, rfsh, vnal, diil,
   {{0xab840ac8,0x2d8b0796,0x660423f1,0x80d901a2}},	//   куск, sece_, _ekik, _नेगे,
   {{0x53341194,0x3f8c82a5,0x61e46c9a,0x7bc7007b}},	//   тест, medu_, fiil, rkju,
   {{0x3e788019,0xdb1a83a7,0x6604008e,0x68290bcf}},	//   mét_, _potê, _gkik, _ažda,
   {{0x3f980fc7,0x3209151e,0x2aff0e88,0x752d5a5e}},	// [6290] _baru_, rlay_, _शुरु_, _igaz,
   {{0xed59803a,0xb4cb146d,0xdb1c007b,0x32096c9b}},	//   _može_, लनी_, skrá, slay_,
   {{0x61e460d9,0x3f984ccf,0x6285114a,0x7982809a}},	//   biil, _daru_, _upho, _obow,
   {{0x25a985e4,0x61e4002e,0x644d6c9c,0xafdb128d}},	//   ñal_, ciil, _kwai, _stød,
   {{0x7c289eb4,0x3f9804b9,0xed59816b,0x394f867f}},	//   _bidr, _faru_, _nože_, _regs_,
   {{0x3f8c86d3,0x7c28c3e0,0x394fec9d,0x79828915}},	//   jedu_, _cidr, _segs_, _abow,
   {{0xf220800f,0x3e788019,0x79829a1a,0x45d5804a}},	//   मगढ़_, jét_, _bbow, _зовс,
   {{0xa91d9c17,0x752d2ce6,0xed59811f,0x6010016d}},	//   leži, _ngaz, _bože_, nämn,
   {{0xb4be035a,0x60258012,0xed598b80,0xdb1a83ec}},	//   _इथे_, ндиа, _vožd_, _lotè,
   {{0x443f9dda,0x7c288267,0x752d3b4e,0xdce9ad16}},	//   _itu_, _gidr, _agaz, _ubeđ,
   {{0x2bac816f,0x7d0982f7,0x3e788019,0xd5e60993}},	//   चारा, _hyes, gét_, ежни,
   {{0x20010041,0x58d58bc7,0x443fdd05,0x644d1a1a}},	//   hohi_, _поет, _ktu_, _bwai,
   {{0x3f8c82ee,0x3156810f,0x2d9e001b,0x707580be}},	//   bedu_, _ניסן_, ěte_, _נײַע_,
   {{0x443f80f6,0x6e298352,0x69c99e3b,0x799980fc}},	//   _mtu_, _lieb, lkee, _haww,
   {{0x61e423e6,0x386d80e7,0x78a281d0,0x7d099a1a}},	//   tiil, luer_, _zrov, _lyes,
   {{0x443f8a2c,0x3f986c9e,0x6e29809a,0x692604ae}},	//   _otu_, _saru_, _nieb, емба,
   {{0x443f8069,0x61e4002e,0x644d031d,0x7d099e01}},	// [62a0] _ntu_, riil, _gwai, _nyes,
   {{0x61e4510f,0x60d60063,0xe47b0039,0x752d0289}},	//   siil, rzym, _צריכ, _zgaz,
   {{0x443fdbaa,0xf1bf0028,0xd9100bca,0x61e4002e}},	//   _atu_, _giáo_, _چیز_, piil,
   {{0xd91004c0,0x644281e0,0x3f982acb,0x6e29809a}},	//   _نیز_, tpoi, _waru_, _cieb,
   {{0x63be0503,0xdca38aac,0xdb08b3f7,0x3f986c9f}},	//   _kopn, лаци, _indé, _taru_,
   {{0x44321220,0xdb1a83a7,0x7d09eca0,0x443feca1}},	//   _muy_, _hoté, _dyes, _dtu_,
   {{0x644287f4,0xfe67803f,0x443f8870,0x7c28b9ef}},	//   spoi, _حد_, _etu_, _vidr,
   {{0x7dc6256c,0x69c99384,0x3e788061,0x799b8122}},	//   _fósi, gkee, vét_, gduw,
   {{0x386d9b0d,0x63ab801b,0x443f8b99,0x3f8c811f}},	//   guer_, ální, _gtu_, tedu_,
   {{0x3e788019,0xdefa8071,0x629c81d0,0xdb1ab68c}},	//   tét_, зым_, _šrou, _loté,
   {{0x3f8ceca2,0x644d6ca3,0x7999eca4,0x69c981b4}},	//   redu_, _swai, _faww, bkee,
   {{0x78a2eca5,0x44320039,0xdce08085,0x3e78eca6}},	//   _trov, _buy_, _hamı, rét_,
   {{0xb4cb0063,0x61e2946f,0x3e788019,0x94a8141e}},	//   लने_, _imol, sét_, нтра_,
   {{0x7bcaa06e,0x4432001c,0x6fe680e7,0xdb08816a}},	//   nkfu, _duy_, _décè, _andé,
   {{0xd6cfbe56,0x44321142,0x6602a2b2,0xa91deca7}},	//   _ст_, _euy_, kook, veži,
   {{0x6440a8d2,0x6b9a81a9,0x9b1781c6,0x660282f1}},	//   _otmi, _latg, תחלה_, jook,
   {{0x765a81e2,0x644d2a58,0x6e29eca8,0xb6068369}},	// [62b0] lsty, _uwai, _rieb, _mošć,
   {{0x7c2f83d3,0x6e29eca9,0x69c9811b,0x6288998b}},	//   _écri, _sieb, zkee, _opdo,
   {{0x61e2ecaa,0xf653190c,0x64448012,0x443fecab}},	//   _omol, ائط_, ţiil, _stu_,
   {{0xcb1204de,0x248901bc,0x37040073,0x41a52594}},	//   _כלי_, _kpam_, учув, _ऑफिस,
   {{0x62888110,0x248900b9,0xa3ac852a,0xeb999cf4}},	//   _apdo, _jpam_, गां_, дил_,
   {{0xf1bf001c,0x39496cac,0xdb1703a8,0x765aacf5}},	//   _hoá_, lbas_, _loxí, ksty,
   {{0x64409010,0x6b9a831d,0x386d810c,0xbe1200ab}},	//   _etmi, _datg, wuer_, _সংসদ_,
   {{0x765a9da3,0x386d8866,0x56942e8c,0x799981b9}},	//   dsty, tuer_, _щаст, _qaww,
   {{0x69c982b5,0x24890282,0x443fecad,0x25ad8162}},	//   rkee, _npam_, _utu_, _inel_,
   {{0xf3ff0073,0xee3990bc,0x2d8fecae,0x69c985d1}},	//   drão_, мно_, lege_, skee,
   {{0x9d4618b0,0x4432001c,0x248900b9,0x7e7e8106}},	//   кенд, _suy_, _apam_, _äppl,
   {{0x44326caf,0x38692353,0xb6068042,0xdb170118}},	//   _puy_, krar_, _gošć, _coxí,
   {{0x386d85ce,0x44320028,0x320da651,0x39490858}},	//   quer_, _quy_, mley_, dbas_,
   {{0x38690186,0x39491972,0xd705a4c7,0x5f058237}},	//   drar_, ebas_, _изли, _изла,
   {{0x2d9b00f1,0x62888118,0xa6ec0264,0x63be01fa}},	//   _faqe_, _xpdo, _কর্ম_, _vopn,
   {{0x25bf802e,0x44320028,0xa3be00d4,0x78a90b67}},	//   _noul_, _tuy_, _आवक_, _ševa,
   {{0xf1bf001c,0x63be6cb0,0x31721ca2,0x2d8f80b4}},	// [62c0] _giám_, _topn, rgyz_, dege_,
   {{0x46a622a0,0x25ad8317,0x7bd501ec,0x64466cb1}},	//   казв, _anel_, chzu, mpki,
   {{0x39491606,0xe57a8a8e,0x25bf83ec,0x6b9a81ec}},	//   bbas_, дзе_, _boul_, _ratg,
   {{0xceb28451,0x8c46934e,0x600fdff1,0x0446a5a4}},	//   ייב_, веде, dømm, ведн,
   {{0xdb1c12d2,0xdf74003d,0x25bf8176,0x2c0e8072}},	//   skrä, _مگاب, _doul_, ितलं_,
   {{0xf7430d69,0x765aecb2,0x25adcc23,0x2b580362}},	//   _веро, ysty, _enel_, narc_,
   {{0x37e30153,0x25bf83ec,0x66e60fe6,0x6b9a80ff}},	//   _торг, _foul_, _рова, _vatg,
   {{0xa2b50c78,0x2b580c5e,0x200780ce,0x320decb3}},	//   _उपस्, harc_, _akni_, gley_,
   {{0x1426b1a9,0x2ecaa402,0xa06784bd,0x0c26d2dd}},	//   _адам, ान्त, вања_, _аман,
   {{0x78a62d72,0xb4ce95bc,0x0eeaa361,0x765abfe3}},	//   _mrkv, शनी_, дьми_, tsty,
   {{0xdb01806a,0xa01b0106,0x765a8e11,0x442c90ba}},	//   _anlæ, _spök, usty, _iid_,
   {{0x61469240,0x25ad0118,0x25bf1434,0x32068122}},	//   _реда, ñel_, ðul_, _ukoy_,
   {{0x7d16009a,0x765a84fe,0xed59850b,0x442c8833}},	//   _czys, ssty, _joža_, _kid_,
   {{0xf3ff0187,0x4ea6802e,0x38695c3b,0x6fc48980}},	//   rrão_, _ариа, vrar_, _còct,
   {{0x442cecb4,0xf2c42c18,0x3e7c000d,0x59b68ebf}},	//   _mid_, астн, jít_, _आचार,
   {{0x442cecb5,0x38693a50,0xa3cf06af,0x3204ecb6}},	//   _lid_, trar_, _शतक_, nomy_,
   {{0x78a6003a,0x3f9cecb7,0x39496cb8,0x21f704b7}},	// [62d0] _crkv, _kavu_, rbas_, għha_,
   {{0x38696cb9,0x6fcd8acf,0x25ad8613,0x442c831d}},	//   rrar_, _núcl, _snel_, _nid_,
   {{0x25bfecba,0x2d8fecbb,0x69dc8110,0xc33204de}},	//   _poul_, tege_, _įren, _לוי_,
   {{0x6e2d4a6b,0x38696cbc,0xb87b002a,0x3f9c81f4}},	//   _jiab, prar_, _oxíx, _lavu_,
   {{0x442ca59e,0x645d0009,0x50f432de,0x2d8fecbd}},	//   _bid_, nssi, _взят, rege_,
   {{0x442c8079,0x2d8fecbe,0x799d6cbf,0x69cd00b9}},	//   _cid_, sege_, _hasw, lkae,
   {{0x36d51d59,0x442c8039,0x799d1400,0x7d0d48dc}},	//   _совр, _did_, _kasw, _lyas,
   {{0x2c1a02f1,0x442cecc0,0x600f8257,0x6e2d6cc1}},	//   _मीनू_, _eid_, rømm, _niab,
   {{0x44f58a14,0x320d8295,0x442c84b7,0x6d59ecc2}},	//   _спас, rley_, _fid_, mawa,
   {{0x6d59e03b,0x320d8e35,0x442cecc3,0xdb08802a}},	//   lawa, sley_, _gid_, _codó,
   {{0xc7d60039,0x7f55157a,0x645d5915,0x7d0d1267}},	//   רותי_, _mezq, essi, _ayas,
   {{0x6d598c9e,0x8c460c66,0x6e2d00e5,0x799d6cad}},	//   nawa, леме, _ciab, _nasw,
   {{0x7bc180ee,0x40798158,0x61e9ec78,0x1ae10264}},	//   _kolu, _נאַװ, miel, _খুলে_,
   {{0x61e9ecc4,0x6d59e973,0xadc380ff,0x387f8168}},	//   liel, hawa, _khẳn, mtur_,
   {{0x35a60037,0x6d59ecc5,0xada60037,0x2005ecc6}},	//   _байг, kawa, _байл, moli_,
   {{0xdb019918,0x6d59ecc7,0x61e9ecc8,0xa2a48aed}},	//   _inlä, jawa, niel, कित्,
   {{0x6d59ecc9,0xa06719dc,0x60c989ca,0x7d16009a}},	// [62e0] dawa, лата_, nyem, _uzys,
   {{0x66066cca,0x2005eccb,0x7bc18d4e,0x61e9eccc}},	//   lokk, noli_, _nolu, hiel,
   {{0x6d5609ca,0x61e9eccd,0x25b7003d,0x6da68bba}},	//   _keya, kiel, _شهید_, лижа,
   {{0x442cecce,0x661bba87,0x6d59eccf,0x2005ecd0}},	//   _sid_, _chuk, gawa, holi_,
   {{0x100385b3,0x7bc1d963,0x387f820f,0x6d56470a}},	//   रकाश_, _bolu, jtur_, _meya,
   {{0xafe62150,0xa3de809a,0x6609a9cf,0x7bc1ab56}},	//   _согл, दों_, _ekek, _colu,
   {{0x442cecd1,0x61e9cfc2,0xadc3801c,0x66063855}},	//   _vid_, fiel, _chẳn, kokk,
   {{0x3f9c8029,0x6564020f,0xb3a481c4,0x61e9809a}},	//   _savu_, _ndih, _गोरख, giel,
   {{0x442c8082,0xdca3bdc3,0xdb018004,0x6e2d6cd2}},	//   _tid_, _лати, _anlä, _riab,
   {{0x2005d86b,0x987b0158,0xa09700be,0xdb01ecd3}},	//   goli_, עריק, נדיק_, _polô,
   {{0xe5b511e9,0x61e9ecd4,0x6d561d43,0x387fecd5}},	//   айны, biel, _beya, atur_,
   {{0x61e9ecd6,0xd6d78153,0x60c9e230,0x645d4da0}},	//   ciel, уть_, byem, tssi,
   {{0x7bc1ecd7,0xb4c10540,0x1c160074,0xdb1ae935}},	//   _yolu, ूने_, _दीहल_, _motí,
   {{0x20058698,0x6d59854e,0x645d156e,0x6b9e69df}},	//   coli_, zawa, rssi, _capg,
   {{0x799d1b77,0x45d51287,0x6d59d282,0xcb378039}},	//   _pasw, _войс, yawa, ראלי_,
   {{0xdb1aa6e2,0x660611ee,0x29d881a8,0x6d56276a}},	//   _notí, cokk, _déag_, _geya,
   {{0x6e350052,0xac9501a1,0x9f5505da,0xb4ce83ca}},	// [62f0] _suzb, _тапш, ивач, शनो_,
   {{0xdefb025d,0x61e98920,0x661b86df,0x629aecd8}},	//   ные_, ziel, _shuk, _osto,
   {{0xa3d89513,0x6d59cb14,0x799d1f72,0x7bc1ecd9}},	//   ासन_, tawa, _tasw, _rolu,
   {{0xdb1a802a,0x6e22d411,0x387fc214,0x200589d8}},	//   _cotí, gmob, ytur_, zoli_,
   {{0x7bc18289,0x6d59c5ad,0x2d89010c,0x2005836a}},	//   _polu, rawa, _mbae_, yoli_,
   {{0x6d59885c,0x03a59814,0x61e9ecda,0x6e35017f}},	//   sawa, рико, wiel, _tuzb,
   {{0x2005ecdb,0x6d5995d0,0x2919026c,0x661becdc}},	//   voli_, pawa, _hzsa_, _thuk,
   {{0x387fa87a,0xc9a988cc,0x7bc1d8c6,0x60c996fb}},	//   ttur_, твие_, _wolu, tyem,
   {{0xa9228698,0x61e9d1cc,0x7bc1ecdd,0x20059ab6}},	//   одъл, riel, _tolu, toli_,
   {{0x387fa445,0x61e9ecde,0xadc3801c,0xb17b0502}},	//   rtur_, siel, _thẳn, _smål,
   {{0x387f8125,0x612b85c5,0x2005ecdf,0x61e9ece0}},	//   stur_, _bölü, roli_, piel,
   {{0xa2c413e5,0xa3b38697,0xb2ba8039,0x29d881a8}},	//   रहस्, टाव_, _במער, _céad_,
   {{0x4b2300c8,0x7c38011f,0x2005a012,0x66066ce1}},	//   _ব্লগ_, _čvrs, poli_, rokk,
   {{0x394d9031,0xb6a5835f,0x629a831d,0x78a4047f}},	//   lbes_, _викл, _ysto, vviv,
   {{0x39460511,0xe7fb0697,0x76439235,0x6d565c96}},	//   ñoso_, ्वना_, _utny, _teya,
   {{0xb14619bb,0x213f8748,0x386d80e7,0xf2d280be}},	//   рнал, ncuh_, orer_, קען_,
   {{0x6b9e026b,0xaca48133,0xe73a49cb,0x64446ce2}},	// [6300] _tapg, _kwụp, вез_, _utii,
   {{0x82360077,0x657b808e,0x25a02bf7,0x3cf1016b}},	//   _پردا, _acuh, _hail_, šová_,
   {{0x386d82af,0xed5ae29e,0x25a06ce3,0x248dece4}},	//   hrer_, вое_, _kail_, _apem_,
   {{0xa2a49c6f,0x386d8aa2,0x32ee8085,0x629a8115}},	//   किस्, krer_, _rəy_, _rsto,
   {{0x25a01706,0x386d8366,0x61e162a2,0x2d9f82f9}},	//   _mail_, jrer_, ëlle, _daue_,
   {{0xaa66ac87,0x3860032f,0x386d8257,0x7fd505a8}},	//   атик, msir_, drer_, _лісі,
   {{0x15f80076,0x1606023c,0xfe06142d,0x4e063ef1}},	//   ीवार_, रवार_, रवास_, रवाई_,
   {{0x394001bf,0x386d83a7,0x61f6694a,0x629a8419}},	//   ncis_, frer_, nnyl, _vsto,
   {{0xb9c38013,0xdb1a8073,0x38606ce5,0x80b097ba}},	//   تقيي, _botã, nsir_, जमें,
   {{0x4ea6b3ba,0x386002be,0x1ae6891e,0x3d1b83b7}},	//   арма, isir_, _козм, _बरते_,
   {{0x35ab81ce,0x386dbd81,0x2ca907b6,0x0737025f}},	//   _घोड़, arer_, _srad_, יאים_,
   {{0x386d87e2,0xb33c84b7,0x29188085,0x25a00229}},	//   brer_, _waħd, əran_, _cail_,
   {{0x25a06ce6,0xb33c81b9,0x224601a1,0x386d8866}},	//   _dail_, _taħd, _čoka_, crer_,
   {{0x25a00122,0xf99f08f9,0xdb1e0286,0x3940290a}},	//   _eail_, _saè_, _copï, ecis_,
   {{0x9b5817c8,0x9f5e019d,0x29d88174,0x25a00833}},	//   рист_, _ótù_, _téad_, _fail_,
   {{0x386010e1,0xdce08176,0xb33c82a6,0xed598af8}},	//   fsir_, _admč, _jaħb, _rožo_,
   {{0x660d491f,0x7afe1727,0x2ca96ce7,0x7a358084}},	// [6310] _ikak, _expt, _urad_, _ište,
   {{0xd7591dd2,0xf773006b,0x6ab6bdb1,0x53990ac8}},	//   الات_, تار_, _अपूर, _своя_,
   {{0x248d8609,0x6fcd81a8,0x853000fc,0x29070035}},	//   _spem_, _dúch, _raɗi, łna_,
   {{0x237f003a,0x6d5d24e2,0xf2d200be,0x386d821e}},	//   đuju_, nasa, _זעט_, yrer_,
   {{0x64a5814c,0xdff891be,0x7bc50006,0x61ed0198}},	//   сала, ुवाद_, _kohu, mial,
   {{0x82340416,0x386d8036,0xf677003d,0xf77881b9}},	//   _دریا, vrer_, _پاسخ, jgħ_,
   {{0x6d5d0d1f,0x7a35803b,0xdcfb803b,0xf21c000f}},	//   kasa, _ošte, _obuć, _भीड़_,
   {{0x96f81505,0x7bc53d5c,0xadc3801c,0x82f80039}},	//   _тест_, _lohu, _thằn, יצוב_,
   {{0x60cd31d8,0x6d5d6ce8,0xe73996dd,0x394dbdf9}},	//   nyam, dasa, леп_, rbes_,
   {{0x386dae89,0x660d359e,0x61ed6ce9,0x60100009}},	//   rrer_, _akak, hial, tämi,
   {{0xee36802e,0xed5a29e4,0x61ed0ff9,0x6d5d1d0c}},	//   йнэ_, лон_, kial, fasa,
   {{0xfbc9073a,0x63a1a4d3,0x60cd0365,0xed5981d0}},	//   _את_, _haln, kyam, _jež_,
   {{0x61ed6cea,0x63a18df1,0x22818019,0x7bc503c1}},	//   dial, _kaln, lók_, _bohu,
   {{0x434338a6,0x60cd02e9,0x660d24bb,0x69db82df}},	//   зерв, dyam, _ekak, lhue,
   {{0xc3328bea,0x15f781a2,0xa3e9123a,0x91dbb497}},	//   לום_, ंचार_, _मगर_, _बताई,
   {{0xed5983bb,0xa22a1541,0x61ed4c23,0x463a80be}},	//   _než_, ужба_, gial, _געקע,
   {{0x39593c37,0x6c8600f7,0xdb0501ec,0x39406ceb}},	// [6320] _dess_, _الخم, _anhä, rcis_,
   {{0x3860008e,0x63a180e4,0x66da0190,0x6eca811c}},	//   rsir_, _naln, льер_, bəbd,
   {{0x38606cec,0xdb1e026f,0x61ed336e,0x3e6382d0}},	//   ssir_, _kopí, bial, nıt_,
   {{0x629e003a,0x250b8416,0xed5a81a8,0x22818061}},	//   _ispo, گرمی_, اشات_, dók_,
   {{0x77940077,0x78ad81a1,0xed59895e,0x69db83ed}},	//   _ویرا, _šavn, _dež_, dhue,
   {{0x25a09234,0x6d5d5db6,0x628381f4,0xf99f0077}},	//   žil_, zasa, ftno, _akèh_,
   {{0x6d5d6ced,0x69c66cee,0xdb1aa56c,0x6da69e0b}},	//   yasa, _koke, _botá, _лива,
   {{0x853009ab,0x66f701c6,0x69c634a4,0x26cc8196}},	//   _haɗu, _המלא_, _joke, vydo_,
   {{0xa3d8853e,0x6d5d2d38,0x69c60110,0x637d026b}},	//   ासद_, vasa, _moke, _bàǹ,
   {{0x61ed6cef,0x629e0052,0x660d079f,0x2281807b}},	//   zial, _ospo, _skak, bók_,
   {{0x66fa053f,0x9f5eecf0,0x79960706,0xd36f81a8}},	//   ्थिक_, gotá_, keyw, _أهم_,
   {{0xca37810f,0x2bd10c28,0x69dbc612,0x7bc802f1}},	//   _הנאה_, हस्थ, chue, ödun,
   {{0x6d5d0859,0x63a19010,0x629e03f2,0x7a35ca31}},	//   rasa, _yaln, _aspo, _všte,
   {{0x6d5d6cf1,0x3959329d,0x69c08da8,0x8fa3828b}},	//   sasa, _sess_, ljme, _наче,
   {{0x61ed1532,0xd7f88087,0x69c61235,0xcf2680f7}},	//   tial, mnă_, _boke, _ارشي,
   {{0x7a358a20,0x69c639e3,0x60cd197c,0x98a4861c}},	//   _ušte, _coke, tyam, lamı_,
   {{0x629e6cf2,0xa2b5016f,0x35f8026a,0x7bc56cf3}},	// [6330] _espo, _उपक्, _درود_, _tohu,
   {{0x61ed6cf4,0x67eb04b7,0x60cd0314,0xd6db0012}},	//   sial, rżjo, ryam, лте_,
   {{0xa9350d8e,0x61ed24a2,0x3d3e81bc,0x6e9947ef}},	//   _менш, pial, _ịwa_, рвер_,
   {{0x443b0168,0x44336cf5,0xdb019243,0x69c61502}},	//   _kuq_, _hix_, _falê, _goke,
   {{0xd7fb035f,0xa87900be,0xa5bd8110,0x853009ab}},	//   _був_, _דאָר, _siųs, _faɗu,
   {{0x22818065,0x3e638459,0x78ad811f,0x69c6113b}},	//   tók_, yıt_, _šavo, _zoke,
   {{0x657a8013,0x41e0103e,0xdb1aa18d,0x6eca811c}},	//   úchá, _नतमस, _potá, həbb,
   {{0x62838503,0x644b816d,0x49c9917e,0x3cff81c0}},	//   rtno, ppgi, рлин_, _txuv_,
   {{0x62838f20,0xf77180a0,0x63a1ecf6,0x69db8580}},	//   stno, واد_, _taln, rhue,
   {{0x9e659383,0x443301ec,0x1665a361,0xf1bf01a8}},	//   овод, _nix_, овом, _fhág_,
   {{0x6d5b8e60,0x7c3b9306,0xdb1aa99b,0x224601f4}},	//   _keua, _huur, _totá, _čoko_,
   {{0x8c3d8214,0xd7f88087,0x7c3becf7,0x44333df9}},	//   _arşi, ană_, _kuur, _aix_,
   {{0x7c3b98c5,0x395fecf8,0x443302a6,0xdffb1299}},	//   _juur, maus_, _bix_, ्वाद_,
   {{0x395f82f8,0x69c60a5b,0x7c3bad7e,0xa3e40035}},	//   laus_, _soke, _muur, पों_,
   {{0xfaa3433f,0x443300e7,0x2fc7cb66,0xf09f0032}},	//   маро, _dix_, _iong_, _asà_,
   {{0x443b3086,0x6d5ba0b9,0x395fecf9,0x7bdc0079}},	//   _fuq_, _neua, naus_, shru,
   {{0x2fc79882,0xdfd20624,0x57ea1652,0x629e009a}},	// [6340] _kong_, وير_, адам_, _wspo,
   {{0x2fc79384,0x395fa7f2,0x65698091,0x6e3b0699}},	//   _jong_, haus_, _adeh, _čubr,
   {{0x2fc7ecfa,0x6449ecfb,0x35af0fea,0x69d9be3e}},	//   _mong_, _atei, _जोड़, _olwe,
   {{0x7c3bb1e9,0x2fc7d71e,0x395f827e,0x2cad93c2}},	//   _buur, _long_, jaus_, _bred_,
   {{0x2cad802e,0xdb018168,0x395f8084,0x7de40061}},	//   _cred_, _falë, daus_, lőss,
   {{0x44336cfc,0xe0fb0039,0x7c3b82b5,0x66e609ea}},	//   _xix_, _כלכל, _duur, _дога,
   {{0x98a48059,0x291d80b9,0x9f4580e5,0x7c218706}},	//   vamı_, _azwa_, dilà_, _dhlr,
   {{0x395f8110,0xe57785a8,0x224602d4,0xb33c822b}},	//   gaus_, _мзс_, _čokl_, _daħa,
   {{0xdfd08013,0x7c3b82a3,0x2cadecfd,0x6e3c0102}},	//   فية_, _guur, _gred_, _hurb,
   {{0x6e3c153e,0x2fc7801c,0xd7f88087,0xa5bb018a}},	//   _kurb, _cong_, ună_, rmóm,
   {{0xdefa8071,0x2fc7d5fe,0x2ca04824,0x2127001c}},	//   рып_, _dong_, _asid_, ̀nh_,
   {{0x395fa732,0x6e3c6cfe,0x4433329e,0x7bc8ecff}},	//   caus_, _murb, _six_, _hodu,
   {{0x7bc88006,0x2fc7ed00,0x6fda0072,0xd7da0072}},	//   _kodu, _fong_, णसां, णसाच,
   {{0xfc3f2d84,0x2fc7821e,0x61ed80e1,0xa3b383eb}},	//   svío_, _gong_, ďale, टाए_,
   {{0x38668a38,0x69d80110,0x200cc886,0x6fcd8388}},	//   _hvor_, _įver, modi_, _cúcu,
   {{0x25a48a84,0x2fc7bba4,0x248684ef,0x39448118}},	//   _naml_, _zong_, ktom_, ncms_,
   {{0x25a68355,0x2d99108a,0x2fc7c2af,0xdcfd00eb}},	// [6350] ddol_, mese_, _yong_, resē,
   {{0x6e3c6d01,0x2a78151e,0x7bc8b656,0x2fc7801c}},	//   _burb, burb_, _nodu, _xong_,
   {{0x7c3baa4a,0x64498e5d,0xfdff11bc,0x2cad8289}},	//   _suur, _stei, _उदास_, _sred_,
   {{0x2cadca41,0x6e3c6d02,0xee3805a8,0x1a9a00be}},	//   _pred_, _durb, іні_, _פירע,
   {{0x2fc70104,0x63a501e0,0x200cb059,0x395f8d15}},	//   ưng_, _kahn, kodi_, vaus_,
   {{0xe0198105,0xfaa5998e,0x7bc8802e,0x7c3b837a}},	//   _नींद_, зако, _codu, _vuur,
   {{0x7bc88052,0x2fc7ed03,0x6e3c6d04,0x63a56d05}},	//   _dodu, _rong_, _gurb, _mahn,
   {{0x249f81e9,0x7c3b9ec1,0x2fc78039,0x24868069}},	//   _tsum_, _tuur, _song_, btom_,
   {{0x2d996d06,0x2fc7ed07,0xb4ea016f,0x2cad920e}},	//   dese_, _pong_, _मधे_, _ured_,
   {{0xb4d78592,0x200cad23,0xa3e786a7,0x78af0140}},	//   ानी_, godi_, मोश_, _mrcv,
   {{0x2d9948ec,0xf77200be,0x2fc780ff,0x395f8198}},	//   fese_, עקט_, _vong_, paus_,
   {{0x2fc783f8,0x2d9958c6,0xa3e78f21,0xe8df8133}},	//   _wong_, gese_, मोर_, nrịa_,
   {{0x621a812a,0x61fb802e,0x63a56d08,0xb9c481a8}},	//   _פונק, mnul, _bahn, _تقني,
   {{0x8fa58d46,0xc87983bf,0xe1ff026b,0x63a5023e}},	//   _хаке, muş_, _ajó_, _cahn,
   {{0x2d99698b,0xc879c64a,0x25a6c84d,0x8c1a81c6}},	//   bese_, luş_, ydol_, מושי,
   {{0x61fbe7e5,0xdb0181b3,0xdddc8699,0x9f4c8388}},	//   nnul, _valè, _sprž, vidé_,
   {{0x7f5c07e2,0x910300e5,0xdce981a1,0x395ddb21}},	// [6360] _perq, епте, _oceđ, _mews_,
   {{0x2b8f8214,0x004681bc,0x7bd50192,0x7b070061}},	//   nıcı_, _jụụ_, ckzu, érté,
   {{0x6e3c12b5,0x61460258,0xe357010f,0x61fbd006}},	//   _qurb, _нена, _משיח_, knul,
   {{0x395da8eb,0xdb01e935,0x200c812b,0x63a547e9}},	//   _news_, _galé, zodi_, _zahn,
   {{0x7bc8ed09,0xc1730051,0x29370158,0x78a908ae}},	//   _podu, _אחר_, _מאכן_, _ševv,
   {{0x69c44129,0x6e3c6d0a,0x2d990c2e,0x261c8216}},	//   ljie, _turb, zese_, cíon_,
   {{0x200c803b,0x80d100c8,0x29d88013,0x395d8609}},	//   vodi_, _সেপ্, _déan_, _bews_,
   {{0x6da39628,0x3f9a009a,0x2d9901df,0x61fb85f3}},	//   _писа, lepu_, xese_, gnul,
   {{0x2d9923a5,0x200ced0b,0x290280f1,0x68e44593}},	//   vese_, todi_, çka_, nzid,
   {{0xf1bf0104,0xfaa691a8,0x6e2426e9,0x2d996d0c}},	//   _khác_, _назо, _ahib, wese_,
   {{0xf119023c,0x2d996d0d,0xadf383dd,0x63a5579b}},	//   _दर्द_, tese_, _आगमन_, _rahn,
   {{0x26c28289,0x67e0016d,0x63a51266,0x69c401b9}},	//   ćko_, _höjd, _sahn, jjie,
   {{0x2d996d0e,0x6e2402a3,0x80d100ab,0x69c46d0f}},	//   rese_, _dhib, _সেন্, djie,
   {{0x2d996d10,0x3f9a02ce,0xdb01b6b5,0x78a2ed11}},	//   sese_, jepu_, _salé, _isov,
   {{0x3a294731,0x2d996d12,0xba0806a7,0x05dd83ca}},	//   tmap_, pese_, वकूफ_, _मतलब,
   {{0x6e24051e,0x5a340652,0xc2c401a8,0x067b9101}},	//   _ghib, енст, ريقي, _הנהל,
   {{0x628704b7,0x63a56d13,0x7e7a839c,0x7a0181a9}},	// [6370] stjo, _tahn, lutp, nēta,
   {{0x660f1230,0x3014326c,0xe9e2809a,0x61fb812b}},	//   lock, едур, leźć_, znul,
   {{0x3a296d14,0xdb1e00e1,0x3a3e8748,0x61fbed15}},	//   pmap_, _topá, _nutp_, ynul,
   {{0xfe700154,0x78a28289,0xe81d0006,0xf1bf00ff}},	//   ادل_, _osov, _बीरा_, _giáp_,
   {{0xb4d7cb1d,0x0db880f7,0x61fb8904,0x2b8f807e}},	//   ाने_, ثالث_, vnul, yıcı_,
   {{0xa3e7809a,0x660f048d,0x9c8703fb,0xb17b12f1}},	//   मों_, hock, _začí, _blåg,
   {{0x61fb82a5,0x660f2fc7,0x6d460106,0x2b5e8122}},	//   tnul, kock, ycka, _detc_,
   {{0x656d17d5,0x61fbda6f,0x60103d02,0x2003b2b2}},	//   _ndah, unul, lämp, čjim_,
   {{0x61fbdc72,0x644d0282,0x2b8f8457,0x753b8135}},	//   rnul, _ntai, tıcı_, _iguz,
   {{0x6e246d16,0x79828300,0x26288087,0x656d6d17}},	//   _shib, _ecow, _uşor_, _adah,
   {{0x443f822e,0x69dd0aa2,0x9f840074,0x7d160009}},	//   _huu_, _olse, _töö_, _syys,
   {{0x443fed18,0x9f4781a8,0x3eb88338,0x645b8176}},	//   _kuu_, _imní_, årta_, _kwui,
   {{0x443fed19,0x4425ed1a,0x60106d1b,0x67e00106}},	//   _juu_, _khl_, kämp, _höje,
   {{0xe7879bd8,0x443fc561,0x69cbb17a,0x644d01a8}},	//   _худо, _muu_, _hoge, _dtai,
   {{0x160d8e70,0x69cbed1c,0x69c46d1d,0xfebb803d}},	//   िकार_, _koge, tjie, _داشت_,
   {{0xed59811f,0x1de20a27,0x753bed1e,0x7d04011b}},	//   _kožu_, _पतित, _nguz, _txis,
   {{0x69cb87b3,0x6b9300f2,0x3eb101ec,0x2007007a}},	// [6380] _moge, ädgå, _arzt_, čnin_,
   {{0x249703f8,0x69cbd11f,0xb17b6d1f,0x69c4067f}},	//   _کنید_, _loge, _småt, sjie,
   {{0x6b9c6d20,0x67e0016d,0x69c404b7,0x29d880f7}},	//   merg, _nöje, pjie, _béal_,
   {{0x69cb8ae1,0x443f8079,0xdc488133,0x93bc80ff}},	//   _noge, _buu_, _aṅụ_, _chăn,
   {{0xdca3ad01,0x249a8416,0x8c4393f1,0x95880110}},	//   каци, تخاب_, вече, _grąž,
   {{0xdb08ab43,0x753bbe39,0xa91d8110,0xe73a1acf}},	//   _indú, _eguz, igžd, _фев_,
   {{0x69cbed21,0x645d81b9,0xdced0380,0xb17b0646}},	//   _boge, _ħsie, _ocağ, _flåd,
   {{0x78a285f5,0x69cbed22,0x6b9c6d23,0xdb1a81d6}},	//   _psov, _coge, herg, _kotú,
   {{0x7a35c979,0x645b8300,0xfc3f008b,0x60f8a7ee}},	//   _ešto, _gwui, rvík_, яния_,
   {{0x6d4481ac,0xb8e6925f,0x291880eb,0x7a0180eb}},	//   žiad, _उप_, āra_, rēta,
   {{0x644d0427,0x6440ed24,0x78ad00fe,0x656d008e}},	//   _stai, _humi, zvav, _pdah,
   {{0x6440ed25,0x7bde02f7,0x69cbd53d,0x2cb20114}},	//   _kumi, _alpu, _goge, _bryd_,
   {{0x3a2680f2,0x443f0028,0x7c84117e,0xa3b38a0d}},	//   _ihop_, êu_, куре, _जोड_,
   {{0x6440a0a8,0x63a88a20,0x69cbed26,0x660f6d27}},	//   _mumi, _jadn, _zoge, sock,
   {{0x6440c617,0x69cbed28,0x9e0731ad,0xa195004a}},	//   _lumi, _yoge, _очил, навч,
   {{0xb0d28a27,0x656d2ff4,0xdb1a8174,0x2cb26d29}},	//   _तथाग, _udah, _botú, _fryd_,
   {{0x92c100c8,0x644093bf,0x9be700e8,0x7c3719ea}},	// [6390] ্ছে_, _numi, _жінк, _tixr,
   {{0xf77007bd,0x25a900c9,0x443f8101,0x6b9c0748}},	//   لام_, _haal_, _ruu_, cerg,
   {{0xb4d781d0,0x25a92fb7,0x4425808e,0x443fed2a}},	//   ान्_, _kaal_, _rhl_, _suu_,
   {{0x6440e708,0x69dd20fb,0x443fe0f9,0x44258106}},	//   _bumi, _ulse, _puu_, _shl_,
   {{0x6440ed2b,0xf3ff0073,0x25a96d2c,0x63a88079}},	//   _cumi, nsão_, _maal_, _badn,
   {{0x7afc8052,0x6440b0f2,0x69cbed2d,0x3869608d}},	//   _žrta, _dumi, _soge, msar_,
   {{0x443f8079,0x59d300bc,0x93bc80ff,0xb60603c1}},	//   _wuu_, _सवार, _thăn, _hláš,
   {{0x6440ed2e,0x29dc0118,0x443fb93c,0xb606016b}},	//   _fumi, _lían_, _tuu_, _kláš,
   {{0x39490207,0xe8f99bd8,0x69cbed2f,0x386946fb}},	//   icas_, яли_, _voge, nsar_,
   {{0x38690073,0xeb90845b,0x2d9ded30,0x394900b9}},	//   isar_, _نظم_, lewe_, hcas_,
   {{0x25a96d31,0x644081ec,0x9f4c8e6f,0x628a81ed}},	//   _baal_, _zumi, cidí_, ctfo,
   {{0x63a88e3f,0xed57035f,0x2d9d80b4,0xa95480e8}},	//   _zadn, ною_, newe_, _акці,
   {{0x522c8158,0x67d5948d,0xdb068019,0x25a96118}},	//   _וואַ, _поду, ümöl, _daal_,
   {{0xdb0181df,0x7bc700f1,0xc0588180,0xbf1f0072}},	//   _lalí, gjju, _آشنا_, _भरून_,
   {{0x6b9c09ff,0xb7da81c6,0xcb1280be,0x59d382f1}},	//   rerg, _מקסי, ָלן_, _तवार,
   {{0xe9df01a8,0x25a96d32,0x672385f3,0x6b9c6d33}},	//   _clú_, _gaal_, _iznj, serg,
   {{0x34b300f7,0x6566005d,0x66040135,0x69c0816f}},	// [63a0] _مميز, makh, _ijik, वाती,
   {{0x64408886,0x75243072,0x25a901ed,0x65663785}},	//   _rumi, _iziz, _zaal_, lakh,
   {{0x63a890e8,0x24460028,0xee3a45c8,0xdb01826f}},	//   _radn, _hôm_, чне_, _balí,
   {{0x7ddf020f,0xafdb0b40,0x6440809c,0xdb018118}},	//   _kësa, _støt, _pumi, _calí,
   {{0x443a6d34,0xf1bf001c,0x211e80d4,0x61f602d0}},	//   _kip_, _khán_, _परेश_, miyl,
   {{0x628aed35,0x3a26885e,0x443a6d36,0xfaa6c543}},	//   ttfo, _shop_, _jip_, ешин,
   {{0xed5a8abe,0x2d96a5a4,0x63a8df2c,0x764e2205}},	//   _нов_, _прас, _vadn, _utby,
   {{0x6440b7f0,0x61f66d37,0xdb01823e,0xf1e000d4}},	//   _tumi, niyl, _galí, नसिन,
   {{0x7e7e2d9d,0x628a82fe,0x65660a84,0x2bd1052a}},	//   lupp, stfo, dakh, _सकला,
   {{0x443a08c4,0x39490388,0x66040091,0x25a96d38}},	//   _nip_, zcas_, _ajik, _saal_,
   {{0x752423e3,0x7e7e28c0,0x11d680e8,0x59e0150e}},	//   _aziz, nupp, _підр, नसार,
   {{0x7c2e6d39,0x7c3a8db7,0x6d4002a5,0x78a60140}},	//   embr, _hitr, žman, _oskv,
   {{0x61e43fab,0x99e98019,0x660401a1,0x68fb00e1}},	//   dhil, _تعلق_, _djik, _ľudo,
   {{0xf8b3812a,0xf3ff0073,0x443a3503,0x66040870}},	//   _תשס_, rsão_, _cip_, _ejik,
   {{0xf3ff00a9,0x25a928ac,0x3f9e9bb9,0xdce98353}},	//   ssão_, _taal_, metu_, _rdeč,
   {{0x7c3aed3a,0x61e46d3b,0x38696d3c,0xda10923a}},	//   _litr, ghil, tsar_, ावित_,
   {{0x39490510,0xc4c48065,0x209817ae,0x38696d3d}},	// [63b0] rcas_, _اے_, нкты_, usar_,
   {{0x7c3aed3e,0x251c0158,0x661d1808,0x3949436a}},	//   _nitr, _צוזא, llsk, scas_,
   {{0xf7700c3b,0x98141e44,0x386946fb,0x2d9d80b4}},	//   صال_, ابقا, ssar_, tewe_,
   {{0x61e401ed,0x38696d3f,0x7c3abb32,0x3a3900e5}},	//   chil, psar_, _aitr, _uisp_,
   {{0xdca5c22b,0x64a59a11,0x2d9dbcf8,0xdb01816a}},	//   тали, тала, rewe_, _valí,
   {{0x3f9e8499,0x69cf0052,0x65660234,0xe2998be4}},	//   jetu_, _hoce, zakh, дак_,
   {{0x7c3a911f,0x9ad381bc,0x3f9e811b,0xdb05016a}},	//   _ditr, _bịak, detu_, _inhó,
   {{0x69cf0bfe,0x65958071,0xf4858019,0x6d4d1a1a}},	//   _joce, _шабу, _لائی, _nfaa,
   {{0x7c3a8b50,0x3c24016d,0xdb018187,0x6d598737}},	//   _fitr, höva_, _balã, mbwa,
   {{0x6d4d4953,0x69cf01a9,0x7c3a8bb1,0xd00e80a0}},	//   _afaa, _loce, _gitr, يلي_,
   {{0x656610e1,0xba74815b,0x442080fc,0x443a22b8}},	//   takh, _مانت, ɓi_, _rip_,
   {{0x7d1b9a1a,0x11f9803d,0xdd9982d6,0x7c3aed40}},	//   _kyus, _کوچک_, _akňz_, _zitr,
   {{0x65660393,0xe0ce8c9b,0x60c4022b,0xf1bf00ff}},	//   rakh, _тв_, xxim, _phán_,
   {{0x6566277c,0x2eb58d9e,0x6b83ed41,0xe81986a7}},	//   sakh, _асис, ngng, _नीचा_,
   {{0x61e4005d,0xf1bf0129,0x61f63dc5,0xdee581cf}},	//   thil, _cháo_, tiyl, _шоки,
   {{0x244600ff,0xdb08810c,0x6e3b8b57,0x69c9ed42}},	//   _tôm_, _dadè, _niub, njee,
   {{0xa0670381,0x69cf6d43,0x7d1bc068,0xdb1a8247}},	// [63c0] ката_, _doce, _nyus, _entè,
   {{0x7643bfb6,0xafdb005f,0x61e46d44,0x3fe36d45}},	//   _kuny, _stør, shil, ажув,
   {{0x7c3a81c1,0x61e4029b,0x26dc05b9,0x7d098388}},	//   _ritr, phil, ávo_, _axes,
   {{0x6e29e210,0x76438f45,0x973c81dd,0x3f9ebb76}},	//   _cheb, _muny, meće, zetu_,
   {{0xdb1aed46,0xdd8f915f,0x6e3bed47,0x973c8503}},	//   _inté, تون_, _diub, leće,
   {{0xdb0e0125,0x65646d48,0x387fc65e,0x57e08035}},	//   _þjón, _leih, duur_, _फतेह,
   {{0x3f9e805c,0x628e26f4,0x7d098144,0x973c8699}},	//   vetu_, ntbo, _exes, neće,
   {{0x6e3bed49,0x7c3a809a,0x798432a8,0x7bdc01f7}},	//   _giub, _witr, ngiw, hkru,
   {{0x64a3c600,0x3f9e803b,0x7c3aed4a,0x3014c060}},	//   _ката, tetu_, _titr, лдир,
   {{0xdefa8a14,0xa3e68fea,0x7c3a8cfa,0x236780d2}},	//   дым_, _पति_, _uitr, canj_,
   {{0xdef487ac,0xddc90e78,0x973c8052,0x628e6d4b}},	//   упны, rudž, jeće, jtbo,
   {{0x7643e37a,0x973c8024,0x3f9ed9ab,0xe0da84ae}},	//   _duny, deće, setu_, _ове_,
   {{0xa3e6901b,0x661d016d,0x628e24fe,0x7643808e}},	//   _पता_, rlsk, etbo, _euny,
   {{0xdb01c96a,0x20180101,0x6602ed4c,0xdb1aed4d}},	//   _halá, _nkri_, hnok, _anté,
   {{0x56949485,0x7643ed4e,0x6d4086c0,0xd6cf8254}},	//   _сайт, _guny, _ogma, _тт_,
   {{0x29188214,0x66028019,0x6d4082c4,0x1f3781c6}},	//   ğraf_, jnok, _ngma, _ברור_,
   {{0x69cf0baf,0x62342031,0x201e80e5,0x764380fc}},	// [63d0] _voce, рету, olti_, _zuny,
   {{0xb8cb101b,0xa5bb0013,0xdefb0009,0xdb1abdb4}},	//   _कई_, slód, мые_, _enté,
   {{0xf773810f,0x2367ed4f,0x6d4080dd,0x628e09c4}},	//   שקע_, vanj_, _bgma, ctbo,
   {{0x20180247,0xf1bf001c,0x7ddf00f1,0x98650065}},	//   _ekri_, _khám_, _mëso, _میرے_,
   {{0xdb050118,0x7a050084,0x629aa7a1,0x7a2581fa}},	//   _mahí, lėto, _apto, jóta,
   {{0xe50405e8,0x61e2ed50,0x7a358110,0xa3b38fcc}},	//   रपति_, _alol, _išti, _जोश_,
   {{0xe2998221,0x23679a54,0xfb8481e2,0xdb01ed51}},	//   хай_, ranj_, рычн, _balá,
   {{0x387fa464,0xf8a99cd0,0xa3b39199,0x2367826c}},	//   tuur_, евик_, _जोर_, sanj_,
   {{0x2367ed52,0x69c9953c,0xdb01b240,0x7643e871}},	//   panj_, rjee, _dalá, _suny,
   {{0xab4a011b,0x68e98d38,0x76439a6e,0x973c8289}},	//   _kaмe, rzed, _puny, zeće,
   {{0x200704c4,0xe3b0936d,0xdb05275e,0xa2d580f7}},	//   čnih_, _برق_, _bahí, _حيات,
   {{0x261903d3,0xdb01ed53,0x2d890580,0x8d760174}},	//   déos_, _galá, _ccae_, دادا,
   {{0x2245ed54,0x973c825b,0xe1f98084,0x236581f4}},	//   _hulk_, veće, mių_, _kelj_,
   {{0xe1f98a8e,0x394ded55,0x656401ec,0x386ded56}},	//   lių_, lces_, _weih, mser_,
   {{0xe2972e78,0x386d8370,0x973c803b,0x7bdc1c2b}},	//   лар_, lser_, teće, rkru,
   {{0xe1f98a8e,0x394d9098,0x601d8722,0x98a620e1}},	//   nių_, nces_, dèmi, либе,
   {{0x973c805c,0x628e0687,0xa6ca6a6d,0xa9260523}},	// [63e0] reće, stbo, کوال_, удал,
   {{0xd8488104,0x25bf8012,0x973c8279,0xa3b38d86}},	//   _học_, _anul_, seće, _जोल_,
   {{0xe1f981e2,0xb8cb2490,0xe57a8ab2,0x973c81a1}},	//   kių_, _कै_, езе_, peće,
   {{0xc27b093f,0x25ad8355,0x386d84d6,0x9ad381bc}},	//   _ארטי, _cael_, kser_, _pịnk,
   {{0x386d813c,0x7c3e6d57,0xd84880ff,0x23658176}},	//   jser_, _kipr, _mọc_, _belj_,
   {{0x386d813c,0xdb01ed58,0xd848801c,0x394ded59}},	//   dser_, _salá, _lọc_, eces_,
   {{0xdb01936f,0xdee6002e,0x291d810c,0x386ded5a}},	//   _palá, _сови, _aywa_, eser_,
   {{0xdd928277,0x25ad8355,0xef171a0b,0xaca4819d}},	//   _دور_, _gael_, _смс_, _atụp,
   {{0xdfd08013,0x2edc800d,0x69dc064a,0xa507b21a}},	//   قية_, मन्त, _नवनी, _бета_,
   {{0x08978307,0x749b810f,0x189780f7,0xb4e08105}},	//   اضيع_, _אימפ, اضية_, दनी_,
   {{0xdb018117,0x6c338013,0xe1f98110,0x3a2032b6}},	//   _talá, _افلا, bių_, klip_,
   {{0x394ddf70,0x6146828b,0x443e81c6,0xd8488129}},	//   cces_, _седа, _hit_, _cọc_,
   {{0xd84880ff,0x3a2002d5,0x443ea6ad,0xf8a886ae}},	//   _dọc_, dlip_, _kit_, _कनिय,
   {{0x9f34a183,0x7c3e17d6,0xdce0875f,0x25ad001b}},	//   _келі, _cipr, _nemč, žel_,
   {{0x443eed5b,0x7c3e0397,0xda780656,0x2d890118}},	//   _mit_, _dipr, лят_, _tcae_,
   {{0xf1bf00ff,0x3f980609,0x7a0181a9,0xf99f0176}},	//   _thám_, _abru_, vētk, _ejèn_,
   {{0x7c3e002a,0x2ca93b06,0x6e2d2cde,0x2bc79a4d}},	// [63f0] _fipr, _usad_, _ihab, लामा,
   {{0x443eed5c,0x7c3e0bb1,0x1e0d8035,0x316682f9}},	//   _nit_, _gipr, िक्ष_, _leoz_,
   {{0x6e2d6d5d,0xa19521e2,0x6d5d02ed,0x6d4f00e5}},	//   _khab, _канч, obsa, occa,
   {{0x443eed5e,0x386da1c3,0x6595bd85,0x0dc8988f}},	//   _ait_, yser_, раду, лучи_,
   {{0xe1f981e2,0xd2640029,0x442c8ad4,0x6b658084}},	//   vių_, _viņš_, _bhd_, акла,
   {{0xeb999bbf,0x987a00be,0xa87a03c8,0xd7e4004a}},	//   тик_, _באשט, _באשר, _лісо,
   {{0x443e93c7,0x67e004b8,0xfa340bca,0x3cfc009a}},	//   _dit_, _möjl, _خرید, _लेने_,
   {{0x386dc71c,0x25bf8012,0x443e821e,0x4095aee8}},	//   tser_, _unul_, _eit_, арот,
   {{0xe1f98a8e,0x68ed02ba,0xdb1a82ba,0xe450987e}},	//   rių_, nzad, _botó, _فضل_,
   {{0x386d92f1,0xe1f981e2,0x2cb88277,0x9989017b}},	//   rser_, sių_, _حافظ_, ylaş_,
   {{0xed5a45c8,0x63a3cf2d,0x7c3e6d5f,0xa2b88beb}},	//   кон_, menn, _ripr, ्मण्,
   {{0x6283ed60,0x63a3ed61,0x443e8613,0x6e2d6d62}},	//   muno, lenn, _zit_, _chab,
   {{0x660980f1,0xdb1aed63,0x6e2d68e7,0x6283af15}},	//   _mjek, _fotó, _dhab, luno,
   {{0x6609920e,0xdb01855a,0x61e98ed0,0x656b8135}},	//   _ljek, _calç, lhel, hagh,
   {{0x661bc7c2,0xa96a0098,0x76475767,0x6fc900d4}},	//   _okuk, кива_, _nujy, रानं,
   {{0x63a3ed64,0x6e2d0ad0,0x65bb0364,0x61e9ed65}},	//   henn, _ghab, _vähä, nhel,

   {{0x63a3ed66,0x60db8737,0x6283ed67,0x973c8a20}},	// [6400] kenn, nyum, huno, meća,
   {{0x65bb0364,0x2f5627d6,0x63a3ed68,0x628389b6}},	//   _tähä, ртас, jenn, kuno,
   {{0xd37b0451,0x5b7b0051,0x63a3abde,0x61e9eb49}},	//   _בריט, _בריא, denn, khel,
   {{0x62838420,0x629e2e31,0xdcf60214,0x7bc182c4}},	//   duno, _ippo, _hayı, _anlu,
   {{0xdcf607d9,0x63a3831d,0x61e9d964,0x61fb8087}},	//   _kayı, fenn, dhel, diul,
   {{0x6609ed69,0x3eaa00dd,0x75298088,0x3e6800d7}},	//   _ejek, _tsbt_, _dzez, _مجری_,
   {{0x443eed6a,0x6283ed6b,0xdcf6017b,0xdce6026f}},	//   _vit_, guno, _mayı, dakč,
   {{0x973c82fd,0x98b20214,0x91fc80eb,0x6609821e}},	//   jeća, layı_, _avār, _gjek,
   {{0x443eed6c,0xc7c6cb1e,0x4fc689a8,0xfce38dae}},	//   _tit_, асни, асна, _дото,
   {{0x443e933a,0x6e2d6d6d,0x6d44549c,0x629e252a}},	//   _uit_, _shab, _agia, _oppo,
   {{0x09e68160,0x6283802e,0x6e2d06e7,0x61e9829b}},	//   _кожн, cuno, _phab, bhel,
   {{0x5183997d,0x61fb8087,0x6e2d5794,0x6d446b72}},	//   _душа, ciul, _qhab, _cgia,
   {{0x629e6d6e,0x53470eef,0x3eb981a9,0xdcf6007e}},	//   _appo, ихва, āsta_, _bayı,
   {{0x764086c0,0x6e22805d,0x6d440102,0x26f78180}},	//   _limy, hlob, _egia, اریخ_,
   {{0x6e2d0013,0x25b00198,0x99674bf2,0x9f5e81a8}},	//   _thab, öllä_, итал, nntí_,
   {{0x68ed6d6f,0x827780be,0x31c400e8,0xf1bf00ff}},	//   tzad, יעלע_, осув, _khái_,
   {{0x63a3ed70,0x7c9500f7,0x7767022c,0x656bed71}},	// [6410] yenn, _الخص, _pejx, vagh,
   {{0x3d1a809a,0xdb1abaf4,0x68ed6d72,0x7a0180eb}},	//   _बड़े_, _antí, rzad, rēti,
   {{0x656b8870,0xdb0512d2,0xf77000f7,0x95cb8009}},	//   tagh, _anhö, باق_, куда_,
   {{0x3618835f,0x63a3ed73,0x261c8020,0xdcf602d0}},	//   ацію_, wenn, díos_, _zayı,
   {{0xdcf60459,0x656bed74,0x66099351,0x22b580eb}},	//   _yayı, ragh, _vjek, _sāk_,
   {{0x656bb57c,0x261c8511,0xdb0501d0,0x2bc7864a}},	//   sagh, fíos_, _zahá, लाधा,
   {{0x61e9829b,0x656b91c2,0x63a3ed75,0x66098343}},	//   thel, pagh, renn, _tjek,
   {{0x63a3ed76,0x62838ff9,0xc6920158,0x661b805d}},	//   senn, runo, _מאל_, _ukuk,
   {{0x973c803b,0x6283ed77,0x61e9ed78,0x20d5a22c}},	//   veća, suno, rhel, сійс,
   {{0x61e9eb49,0xddc9026c,0x59c5801b,0x261c8118}},	//   shel, grdž, वाहर, bíos_,
   {{0xee3a091e,0x7ddf020f,0x61e9829b,0x38ca803d}},	//   лно_, _kësh, phel, نایی_,
   {{0x6441a022,0xdcf602bb,0xd12e853d,0x682901d0}},	//   _hili, _sayı, ظمی_, _vždy,
   {{0x6441ed79,0x49b896a5,0x60c484b7,0xdea18019}},	//   _kili, _خالد_, _ġimg, _کیجی,
   {{0xf8b68051,0xb05b1bd7,0xdcf60201,0x6441d5c2}},	//   _לפני_, _kräf, _qayı, _jili,
   {{0x973c8bda,0x6449802a,0xd8488135,0x12b800ab}},	//   lećn, _luei, _jọn_, ীন্দ,
   {{0x6441ed7a,0xa5bb062f,0x68ec8182,0x7989ed7b}},	//   _lili, llón, _öldü, ngew,
   {{0x644180f7,0x249f81c0,0xb4db0722,0xdce40084}},	// [6420] _oili, _npum_, scàr, _keič,
   {{0x6441b5b7,0x7640ed7c,0xe0df02d6,0xd12f1f31}},	//   _nili, _simy, _afòs_, رمل_,
   {{0x6d448110,0x6e22ed7d,0xdb08802a,0x3cfc0035}},	//   žiam, tlob, _padí, _लेते_,
   {{0x261c8693,0x6441ed7e,0x798980f3,0xdfd26a6d}},	//   víos_, _aili, jgew, _کيس_,
   {{0x6441c51e,0x7ddf020f,0x973c82ce,0xa13600f7}},	//   _bili, _dësh, jećn, _دردش,
   {{0x6441ed7f,0x62810207,0x741680ab,0x69c2c27b}},	//   _cili, álog, াষ্ট_, _snoe,
   {{0xf99f0242,0x764082c4,0xddc90b80,0xb7b5819d}},	//   _akèy_, _timy, vrdž, kọb,
   {{0x6441ed80,0x6281005c,0xf1bf001c,0x9054864f}},	//   _eili, šlog, _phái_, овиц,
   {{0x8b969cd0,0x6441ed81,0xdd1703db,0xa3b3ac07}},	//   _греч, _fili, _धुंध_, _जोक_,
   {{0x64419a13,0x6569890d,0xd848826b,0x6abc8e06}},	//   _gili, _zeeh, _fọn_, _árfo,
   {{0xd848801c,0x501b0039,0xf41f0106,0x200b9243}},	//   _gọn_, רויו, ktär_, écia_,
   {{0x6441822e,0xdb1a80a9,0xf1bf0028,0x387f8239}},	//   _zili, _entã, _thái_, brur_,
   {{0x999f880a,0x64418d6a,0x24868267,0x394680e4}},	//   lmuş_, _yili, nuom_, _igos_,
   {{0x6441ed82,0x7ddf00f1,0xa5bb2564,0xf64f8061}},	//   _xili, _mësi, clón, بئی_,
   {{0x81ab80c8,0x999f88c5,0x7a358084,0x201a5d0b}},	//   খার_, nmuş_, _ištr, dopi_,
   {{0x22420019,0x2a8e8085,0xd25781c6,0xb33c8197}},	//   _cikk_, _həbs_, משלה_, _jaħq,
   {{0x656f6d83,0x7a0881d0,0x02a5db64,0x4fd51073}},	// [6430] mach, větl, _खन्न, ожат,
   {{0x656f0af9,0x752d0289,0x6449887a,0xe9df00f7}},	//   lach, _izaz, _ruei, _siúd_,
   {{0x543c0158,0x39469cdf,0x7bc56d84,0x2242035f}},	//   _געזא, _ogos_, _inhu, _fikk_,
   {{0x656f2969,0x63a76d85,0x224200e8,0x249f80b9}},	//   nach, lejn, _gikk_, _ppum_,
   {{0x61ed178e,0x6449907f,0x7a35805c,0x7ddf00f1}},	//   mhal, _quei, _oštr, _vësh,
   {{0x6441ed86,0x61ed6d87,0x656f6d88,0xdb03ed89}},	//   _qili, lhal, hach, lené,
   {{0xdce982ee,0x6441c4f7,0x973c8289,0x79898e61}},	//   _odeć, _vili, dećo, tgew,
   {{0x61ed0558,0x64418a07,0x65949501,0x32096d8a}},	//   nhal, _wili, _насу, nnay_,
   {{0x656f6d8b,0x7989b864,0x2cad8051,0x395fab47}},	//   dach, rgew, _used_, rbus_,
   {{0xb05b00f2,0x660d0074,0x7989a389,0x973c8904}},	//   _träf, _ajak, sgew, rećn,
   {{0x46f59194,0x61ed005d,0x63a71d1a,0x752d2cde}},	//   ючит, khal, dejn, _azaz,
   {{0x656f1e2c,0xfbc90051,0xb33c81b9,0xd848819d}},	//   gach, _בת_, _taħr, _kọl_,
   {{0x61ed3caa,0x3e480214,0x6830016d,0x660d6d8c}},	//   dhal, _işte_, läde, _djak,
   {{0xdee598a2,0x3160323e,0x66e59662,0x8af70085}},	//   _моли, wbiz_, _мола, ğənn,
   {{0x656f6d8d,0xed5a0698,0xc7448154,0x25a68681}},	//   bach, _кой_, _عضوي, yeol_,
   {{0x61ed6d8e,0x660d00f1,0x32093e4c,0xb22605a8}},	//   ghal, _gjak, gnay_, імал,
   {{0x6fdf80e7,0x68300192,0x201a1502,0x6d4481d6}},	// [6440] _pêch, häde, topi_, žiak,
   {{0xb4e61c6f,0x62870264,0x320901b4,0x63a701d0}},	//   पनी_, bujo, anay_, cejn,
   {{0x44446d8f,0x61ed029b,0x7e670282,0x614626ab}},	//   _ii_, bhal, _cwjp, _мена,
   {{0x44446d90,0x2486826c,0xdb0883c1,0xb05b0106}},	//   _hi_, tuom_, _nadá, _bräd,
   {{0x44446d91,0x69c6591b,0xdb1e256c,0xad9b00f7}},	//   _ki_, _inke, _topó, liúc,
   {{0x44446d92,0x2ca991dd,0x61e43cf0,0xd848819d}},	//   _ji_, çada_, lkil, _dọl_,
   {{0x26cc020f,0xb05b12d2,0x68300106,0x656f6d93}},	//   _çdo_, _präg, rädd, yach,
   {{0x44446d94,0x672e02fd,0xdb089f28,0x999f807e}},	//   _li_, _izbj, _cadá, rmuş_,
   {{0x656289ca,0xb05b0106,0x61e400dd,0x63a70168}},	//   mboh, _gräd, ikil, yejn,
   {{0x44446d95,0xc7b8a997,0x656f6d96,0x109b0039}},	//   _ni_, kođe_, wach, סביב,
   {{0xb05b1b57,0x245080ff,0xf1bf00ff,0x656f46ff}},	//   _träg, _hàm_, _khát_, tach,
   {{0x69a181fe,0x2fd80c64,0x752400b4,0x76440326}},	//   _कॉपी, _lorg_, _byiz, _ciiy,
   {{0xf7728019,0xdb03816b,0x75240314,0x6723838a}},	//   _ہاں_, vené, _cyiz, _eynj,
   {{0x656f0c64,0x6b9b005c,0x62876d97,0xdb08826f}},	//   sach, đugo, tujo, _zadá,
   {{0x44446d98,0x24508142,0x656f6d99,0x61ed6d9a}},	//   _di_, _làm_, pach, thal,
   {{0x44446d9b,0x244f0179,0x63a7311a,0x62870bcf}},	//   _ei_, _tüm_, sejn, rujo,
   {{0x44446d9c,0x61ed2fc2,0x2fd86d9d,0x32096d9e}},	// [6450] _fi_, rhal, _borg_, rnay_,
   {{0x44446d9f,0x69c65303,0x61ed6da0,0x32096c9b}},	//   _gi_, _enke, shal, snay_,
   {{0x61ed6da1,0x656d0458,0x644d0834,0x2fd800ee}},	//   phal, _keah, _huai, _dorg_,
   {{0x29dc160a,0x44446da2,0x64452c8c,0xdb1e0722}},	//   _días_, _zi_, _hihi, _topò,
   {{0x4444280a,0x69cea714,0xe7bc8b84,0x64456ce2}},	//   _yi_, थानी, ्ञाप, _kihi,
   {{0x444401cd,0xf8bf6da3,0x656d0706,0x493a0039}},	//   _xi_, _iré_, _leah, _לגרו,
   {{0x81b480c8,0x4cd380c8,0x64456da4,0x644d008c}},	//   ঞান_, _দেখু, _mihi, _luai,
   {{0x798d6da5,0xb05b00f2,0x2fd80a0f,0x5fc90540}},	//   ngaw, _träd, _zorg_, रावल,
   {{0x644d2ab6,0xd84881bc,0xdb088061,0xafdb004a}},	//   _nuai, _fọm_, _vadá, _støy,
   {{0x1e858ff7,0x764402a3,0xf1b980d2,0x7ddf00f1}},	//   плом, _siiy, doše_, _mësu,
   {{0x44442c63,0x61fd20cb,0xdb1a8187,0x98ab861c}},	//   _ri_, _omsl, _botõ, ımız_,
   {{0x644d1a2f,0x20016da6,0xd1b89e09,0xcfe9803d}},	//   _buai, hihi_, _وانا_, _گفته_,
   {{0x44440205,0x644d0068,0xf1b9817f,0x6445433e}},	//   _pi_, _cuai, goše_, _bihi,
   {{0x644d0083,0x69d98039,0xf99f0032,0x225a00b9}},	//   _duai, _howe, _abè_, _ptpk_,
   {{0x44440082,0x644532bb,0x61e43dc5,0xab2a604d}},	//   _vi_, _dihi, tkil, сова_,
   {{0x44444080,0x644d003c,0xad9b0013,0x29dc01df}},	//   _wi_, _fuai, riúc, _rías_,
   {{0x44446da7,0x61e46da8,0x98a30758,0x7a2592ca}},	// [6460] _ti_, rkil, ните, góti,
   {{0x644504a7,0x44446da9,0x29dc03a8,0xaabd8f1b}},	//   _gihi, _ui_, _pías_, ्माक,
   {{0xf1bf6daa,0xf8bf10ab,0xba760481,0x998da384}},	//   _phát_, _eré_, _عادت, zmeš_,
   {{0x29dc05e4,0x69d9edab,0x2cbfa2b7,0x645b8362}},	//   _vías_, _nowe, _brud_, _btui,
   {{0x644502a3,0x200120d5,0x649a9232,0x657b8122}},	//   _yihi, bihi_, стер_, _dduh,
   {{0x38600590,0x660bc70f,0x9f5e80f1,0x657b8133}},	//   mpir_, angk, ritë_, _eduh,
   {{0x6fc901fe,0x69d9edac,0xa3cd016f,0x46a30b69}},	//   रारं, _bowe, ळात_, _парв,
   {{0x9f5eedad,0x2d9f8133,0x3a2200ee,0x69d9edae}},	//   mité_, _gbue_, _jkkp_, _cowe,
   {{0x9f5eedaf,0x3cfc18b8,0x764e26e9,0x69d9ec7c}},	//   lité_, _लेले_, _huby, _dowe,
   {{0xb4d88b6f,0x6602edb0,0x656d2651,0x644d0c49}},	//   ाही_, liok, _seah, _ruai,
   {{0x47348987,0x2ab5877f,0x644d032f,0xbcfb0b4c}},	//   ьнос, rùbá_, _suai, gbén,
   {{0x7bdac8d8,0x69d98573,0x63aa807b,0x973c88ae}},	//   _hotu, _gowe, lefn, lećk,
   {{0xd7e68d13,0x644d0073,0x7bda84b9,0x44210101}},	//   _ніко, _quai, _kotu, _pkh_,
   {{0x493b8bea,0x764e0247,0x69d98a0f,0x63aa807b}},	//   _הגדו, _ouby, _zowe, nefn,
   {{0x7bdaedb1,0x201eedb2,0x628a84b9,0x661d665b}},	//   _motu, moti_, nufo, posk,
   {{0x644d0cac,0xf8bf5496,0x82341ec9,0x9f5e80e7}},	//   _tuai, _pré_, فرقا, dité_,
   {{0x798d01b0,0x2c2700e8,0x64456db3,0x6d404169}},	// [6470] rgaw, _ньог, _tihi, žmar,
   {{0x44270013,0x7bdaedb4,0x201ead77,0x9f47826f}},	//   _ón_, _notu, noti_, _plné_,
   {{0x20016db5,0x645beb64,0x0ef9001b,0x63aa8114}},	//   rihi_, _stui, ्पेस_, defn,
   {{0x7bc8edb6,0x764e07cd,0x20012650,0x2ca98187}},	//   _andu, _duby, sihi_, çado_,
   {{0xee38835f,0x3e4c800d,0x69d9edb7,0x6283831d}},	//   їні_, _děti_, _rowe, wrno,
   {{0x69d9c4e0,0x0fe780ab,0xfaa5d2e4,0x7a050084}},	//   _sowe, _পদ্ধ, дако, rėtu,
   {{0x9f5eedb8,0x69d9eb5d,0x201e9202,0x7528009a}},	//   cité_, _powe, doti_, ędzi,
   {{0x24808024,0xceb2010f,0x60c4edb9,0x200c82f1}},	//   šima_, _ביל_, _šima, endi_,
   {{0xf8a9803d,0x6b9c031d,0xdb03b87a,0x645b82c4}},	//   تگاه_, yfrg, mení, _utui,
   {{0xdb03a825,0x201eedba,0xb95b0032,0x69d9913b}},	//   lení, goti_, _bnìk, _wowe,
   {{0x3a296dbb,0xe7f50321,0xff5601c6,0x69d9edbc}},	//   klap_, _इतना_, ובתך_, _towe,
   {{0xf3e90bea,0x2d8f8077,0x200c80e5,0xfb1a80be}},	//   _דף_, ngge_, andi_, _וועמ,
   {{0x6d44bbe2,0x3a29228a,0x518490ac,0xee371273}},	//   žiav, dlap_, _чуха, ьню_,
   {{0x33d50112,0x67d4a457,0xf77180a0,0x6602811b}},	//   ніст, _почу, _شات_, ziok,
   {{0x04431814,0x8c43153d,0x320d8e35,0xef1f8085}},	//   терн, тере, oney_, şüb_,
   {{0x9f5e83d3,0x3d19116e,0x764e0314,0xad9b01a8}},	//   vité_, _युके_, _ruby, liún,
   {{0xd378803b,0xd7c9035a,0x765c6dbd,0x6e2402a0}},	// [6480] _hoće_, रांच, _stry, _ikib,
   {{0xdfa600f7,0xdee602ee,0x66e65d17,0x9f5eb997}},	//   بحري, мози, моза, tité_,
   {{0x86c60013,0x386007f1,0x644f8144,0x4e02005e}},	//   بيان, spir_, _écij, _लगाई_,
   {{0x9f5e83d3,0x452a8758,0x7bdaaac4,0xad9b01a8}},	//   rité_, ожен_, _sotu, hiún,
   {{0x3ead003a,0xa3b2101c,0x68ed809a,0xb4d89344}},	//   _ćete_, _ऐसा_, _żadn, ाहे_,
   {{0x660284cd,0x2d8f847f,0xd25a80c4,0x320dacfe}},	//   siok, agge_, оци_, eney_,
   {{0x160e2b00,0x7bdaa501,0x765c6dbe,0xf7432523}},	//   ाचार_, _votu, _utry, _аеро,
   {{0x628a80b9,0x2d95c020,0x6298dd7e,0x80b50035}},	//   rufo, _прус, rtvo, _उनमे,
   {{0x629884a8,0x7bda8790,0x68e46dbf,0x628ac877}},	//   stvo, _totu, nyid, sufo,
   {{0x6e240590,0x7bc8edc0,0x973c80d2,0xa5c70118}},	//   _akib, _undu, leći, _opóñ,
   {{0xd8488028,0x3c24016d,0xdd950084,0x68e42eec}},	//   _mọi_, hövs_, наны, hyid,
   {{0x6e3621aa,0x6d448110,0x7c2aa6cd,0x2366026c}},	//   _chyb, žiau, llfr, _đoja_,
   {{0x201e8010,0xdb01826f,0x6448d206,0xdb0e6dc1}},	//   poti_, _malý, _kidi, ndbæ,
   {{0x6e240c56,0xdf0a814c,0xd7c881a8,0x7a138087}},	//   _ekib, _мэйл_, _روعه_, măta,
   {{0x6448edc2,0x60c2b937,0xf1b98088,0x2d8f8370}},	//   _midi, _hrom, loša_, ygge_,
   {{0x1de3000c,0x60c287dd,0x973c805c,0x8cc60beb}},	//   _पवित, _krom, jeći, ामखो,
   {{0x973c803a,0x60f91006,0x7a138087,0xdb03936f}},	// [6490] deći, чная_, năta, vení,
   {{0x3a296dc3,0x2486c315,0x5fc91a42,0xceeb0199}},	//   slap_, drom_, राइल, يران_,
   {{0x9f4c8144,0xb17b6dc4,0xf4148264,0xdb0397a8}},	//   lidó_, _blåt, িতার_, tení,
   {{0x6448edc5,0x60c2edc6,0x68300106,0x7bde808b}},	//   _aidi, _orom, räda, öpun,
   {{0x6448b3d6,0xb4e981d2,0x7ae38114,0xd469999a}},	//   _bidi, मने_, wynt, чиле_,
   {{0xc6a73e32,0x644881b4,0x69dd6dc7,0xdb03816b}},	//   _орби, _cidi, _hose, sení,
   {{0xd8488028,0x6d4d02a3,0x69dd6dc8,0x387e01a9}},	//   _gọi_, _ogaa, _kose, _ātri_,
   {{0x69dd6dc9,0x60c2c08d,0x6d4d6dca,0xc7b882a5}},	//   _jose, _brom, _ngaa, vođa_,
   {{0x6448edcb,0x69dd6dcc,0x7a258125,0xa5bb00f7}},	//   _fidi, _mose, dótt, clói,
   {{0x60c2edcd,0x6d4d25d5,0x6448edce,0x6e246dcf}},	//   _drom, _agaa, _gidi, _skib,
   {{0x66e58048,0xad9b00f7,0xd62a29ba,0x60c2c761}},	//   хона, riún, зоне_, _erom,
   {{0x69dd6dd0,0xad9b0013,0xd3788a20,0x7c2502a3}},	//   _nose, siún, _voće_, _akhr,
   {{0x764980b9,0x61e9c05b,0x8cc2850a,0xe8eed2eb}},	//   _miey, mkel, लियो, _сл_,
   {{0x973c8289,0xe51082f1,0x764980b9,0x6e3d1151}},	//   zeći, ़पति_, _liey, amsb,
   {{0x2005edd1,0xf1d3853f,0xf1bf0104,0x161f88fd}},	//   mili_, थापन, _pháp_, यकार_,
   {{0xf2d28159,0x61e99699,0x69dd39b0,0x3ebe007b}},	//   נען_, nkel, _cose, _átti_,
   {{0x69dd3178,0xa84a1a05,0x045700f7,0xb4e9852a}},	// [64a0] _dose, سلام_, _كلية_, मनो_,
   {{0x660614c7,0xb17b0687,0x5fb783eb,0x61ef0144}},	//   likk, _blås, _असफल, _elcl,
   {{0x69cbc695,0x61e9affb,0x69dd6dd2,0x0d8682a4}},	//   _onge, kkel, _fose, елен,
   {{0x6606288c,0x63ae6dd3,0x628e6884,0x7ae13445}},	//   nikk, lebn, mubo, älte,
   {{0x2005ba90,0x628e6dd4,0x7bde6dd5,0x6448edd6}},	//   kili_, lubo, _kopu, _pidi,
   {{0x69cbc70e,0x031f0b85,0x2005dd98,0x2480edd7}},	//   _ange, _मुँह_, jili_, šimo_,
   {{0x6448c0dc,0x66066dd8,0x628e177c,0x69cb82f7}},	//   _vidi, kikk, nubo, _bnge,
   {{0xe643abe0,0x7bde0009,0x629c6dd9,0x7e9b0039}},	//   _бесп, _lopu, itro, _מסלו,
   {{0x644884b8,0x8c958160,0xdb01edda,0x6c8688ca}},	//   _tidi, _архі, _baló, _سلام,
   {{0x69cbeddb,0x200587d9,0x6e22bf60,0x628e005d}},	//   _enge, gili_, loob, kubo,
   {{0x211a95e4,0x031f000f,0x66061da3,0x629c0088}},	//   _کتاب_, _मुंह_, fikk, jtro,
   {{0x61e98b2f,0x629c6ddc,0x628e00fc,0xc33381c6}},	//   ckel, dtro, dubo, _עוף_,
   {{0x2005cda3,0x37e68ab5,0x7a25807b,0xafe68878}},	//   bili_, _подг, rótt, _подл,
   {{0x69dd5fd5,0xb05b6ddd,0x63ae02af,0xdb018144}},	//   _sose, _brän, gebn, _galó,
   {{0xdeef905c,0x660602ec,0xdbc78074,0x09c500ab}},	//   _сы_, bikk, _töös, _একবা,
   {{0xf1a681fe,0x3cfc0006,0xb05b1614,0x59a680d4}},	//   _कॉमन, _लेके_, _drän, _कॉमर,
   {{0x6e228079,0x764980b9,0x9f5e816a,0x41b8864a}},	// [64b0] doob, _riey, hití_, _आसनस,
   {{0xa0c400f7,0x7c25036e,0xf7700124,0xdb08826b}},	//   ديكو, _ukhr, مام_, _dadú,
   {{0x44230025,0x63a9003b,0xb05b016d,0x57a40110}},	//   moj_, đend, _grän, ышта,
   {{0xaf3401a8,0x75298176,0x127a03de,0x2b1a01d0}},	//   اركت, _pyez, _קארע, _मुटु_,
   {{0x44258681,0x973c8904,0xb4bd8c28,0x672a807b}},	//   _pkl_, meću, ेमे_, _lyfj,
   {{0x4423003a,0x03a58c6e,0xed158065,0x63baabc7}},	//   noj_, тико, _یہاں_, _catn,
   {{0x61e9edde,0xb5a7876a,0x9f34021e,0xdea4003d}},	//   tkel, _прай, _бері, _میلی,
   {{0x2005eddf,0x44236de0,0xdb018333,0x63ae050a}},	//   wili_, hoj_, _saló, zebn,
   {{0x4423003a,0x61e9a315,0x6d4480e1,0x80c44c4b}},	//   koj_, rkel, žiar, रिये,
   {{0x4423003a,0x61e98f52,0x63ba81fa,0x6606037a}},	//   joj_, skel, _gatn, wikk,
   {{0x2005ede1,0x66060558,0xdb01ec73,0x63ae027f}},	//   rili_, tikk, _való, vebn,
   {{0x3ddf8a0f,0x7a13802e,0x63ba80ee,0xdce0801b}},	//   _jouw_, măto, _zatn, _nemě,
   {{0x66062ccc,0xf41f2bf5,0x63ae001b,0x7a138087}},	//   rikk, rrän_, tebn, lăto,
   {{0x629c139a,0x66066de2,0x628e0461,0x3ddf8a53}},	//   ttro, sikk, tubo, _louw_,
   {{0x23271cf8,0xab27235b,0x3dcd8b99,0xe29738a6}},	//   вори_, вора_, _onew_, кар_,
   {{0x629c17c5,0x212b000d,0x628e018e,0x7c23ede3}},	//   rtro, _bych_, rubo, honr,
   {{0x4423135a,0x660409ae,0x7bde6a77,0x25bd831d}},	// [64c0] boj_, _imik, _topu, ddwl_,
   {{0xb05b04b8,0x98a31e58,0x629c6de4,0xdb1c0168}},	//   _trän, рифе, ptro, ndrë,
   {{0x224b04b8,0x63ba8025,0xc815035f,0x6e2290b5}},	//   _fick_, _ratn, уєть, toob,
   {{0x224b04b8,0x63ba8668,0x7c2e203c,0x98b181d0}},	//   _gick_, _satn, llbr, íběh_,
   {{0x63baede5,0x6fc90361,0x2b060321,0x224002f1}},	//   _patn, राखं, _हेतु_, mmik_,
   {{0x3a26883b,0x22406de6,0xdce081d0,0xdb07128a}},	//   _skop_, lmik_, _země, zejí,
   {{0xfba41094,0x63baac9f,0x7a138087,0x660456df}},	//   ख्यम, _vatn, găto, _omik,
   {{0xada689c7,0xbbdf0b86,0xa9348e11,0x44236de7}},	//   _шабл, _नक्क, лейш, zoj_,
   {{0xdb1a80f1,0x63baede8,0xdca680a9,0x1c468791}},	//   _katë, _tatn, _јази, _анам,
   {{0x66040065,0x1da51130,0xef1f82d0,0x44236de9}},	//   _amik, ग्नत, ğün_, xoj_,
   {{0x7a13802e,0x2ca900b9,0xadc3826b,0xef1f8380}},	//   căto, _spad_, _ajẹn, şün_,
   {{0x6f030073,0x3a268267,0x2489edea,0x7e7a94cf}},	//   únci, _ukop_, šame_, rstp,
   {{0x5c070098,0x6fb681a8,0xf8b68107,0xdb070216}},	//   вява, _لمشا, _अनिय, rejí,
   {{0xdb1a80f1,0xdb07001b,0x66040a40,0x443a02d0}},	//   _natë, sejí, _emik, _chp_,
   {{0x44236deb,0x9b580703,0x9f5eab31,0xaad28bb8}},	//   roj_, тист_, mità_, थमिक,
   {{0xed598025,0x9f5ec806,0x6616020f,0x442300f1}},	//   _kaže_, lità_, _gjyk, soj_,
   {{0x973c82a5,0x442324c8,0x6d5d0061,0x10178019}},	// [64d0] reću, poj_, mcsa, _سکیں_,
   {{0x9f5e81c1,0x224b1a34,0x973c85a2,0x25ff090f}},	//   nità_, _wick_, seću, शोरी_,
   {{0xdb0387e2,0xdb1a8168,0x212b0428,0xf7702239}},	//   menç, _datë, _wych_, زال_,
   {{0x212b0dee,0xed58835f,0xdb03c021,0x7c3a9611}},	//   _tych_, вої_, lenç, _ahtr,
   {{0x69cf0a1e,0x61ed20e5,0xdca5a623,0xb05b05ec}},	//   _ince, mkal, уали, _kräm,
   {{0x59d100c2,0x7a138162,0x32093597,0x0c248a4c}},	//   हावर, tăto, liay_, амін,
   {{0x9f5eab31,0xa2c0809a,0x36d40c4f,0x3ddf890d}},	//   dità_, विष्, _корр, _touw_,
   {{0x61ed6dec,0xd3788e78,0xdb1aeded,0x7c23d69f}},	//   nkal, _voća_, _matè, sonr,
   {{0x7a138087,0x6e3b8234,0x61ed6dee,0x37758190}},	//   săto, _ihub, ikal, лынс,
   {{0x7982edef,0xe8f69e4a,0x660400c3,0xa2c083dd}},	//   _edow, уль_, _smik, विश्,
   {{0x764d016f,0xb99580f7,0x61ed6df0,0x752d0d4e}},	//   _biay, _ملاب, kkal, _ayaz,
   {{0x7655009a,0x2459801c,0x61ed1279,0x3a24edf1}},	//   _muzy, _kèm_, jkal, comp_,
   {{0xe0cecaac,0x764d1abb,0x61ed27f7,0x2d9e0035}},	//   _ув_, _diay, dkal, ęte_,
   {{0x9f5e8698,0x61ed6df2,0x2d9e01d0,0xdb1a8242}},	//   cità_, ekal, řte_, _batè,
   {{0x65798372,0xf8bf0019,0xdb1a8580,0x3eb981a9}},	//   kawh, _szép_, _catè, āsts_,
   {{0x61ed1066,0x764d5411,0x69db816a,0x6e298133}},	//   gkal, _giay, njue, _nkeb,
   {{0x68e98867,0xb05b00f2,0x22406df3,0x3eaa00b9}},	// [64e0] nyed, _främ, rmik_, _spbt_,
   {{0xb8dc39a1,0xdb038073,0x67f2007b,0x6e3b82a0}},	//   _आन_, cenç, _bæja, _ahub,
   {{0xa2e61289,0x7d1b81df,0xd84881bc,0xbd8a81a8}},	//   _сонд, _axus, _kọr_, فنان_,
   {{0x7c3a820f,0x61ed0668,0x64566df4,0xed5ab00b}},	//   _shtr, ckal, _kuyi, ход_,
   {{0x645604b9,0xa3a900d4,0x6e3bedf5,0x63be0061}},	//   _juyi, _गॉड_, _dhub, _kapn,
   {{0x63a48267,0xdb1a8061,0x69a1836d,0x64561c83}},	//   đino, _haté, क्सी, _muyi,
   {{0x9f5eac2f,0x60c46df6,0xe73722b1,0xdb1aa1e6}},	//   vità_, lvim, _бер_, _katé,
   {{0x24800025,0x6e3b8c93,0xbc7680d7,0x245983ec}},	//   _ovim_, _ghub, _مهرب, _fèm_,
   {{0xdb1aedf7,0x9f5eae7c,0x26c7edf8,0x463b80be}},	//   _maté, tità_, _arno_, _טעלע,
   {{0x52768a08,0x26c7801b,0x09e10d14,0xed5984a8}},	//   _буду, _brno_, _नव्य, _važe_,
   {{0x9f5ead9d,0x25fb84e5,0x26c7803b,0x29dc0d76}},	//   rità_, लोकी_, _crno_, _díaz_,
   {{0x64566df9,0x9f5e8081,0xdb0a83a7,0x244f0609}},	//   _buyi, sità_, nefí, _ażma_,
   {{0xdb038073,0xcd07395b,0x55073d85,0xae0401cb}},	//   tenç, учни, учна, शोधन_,
   {{0x61e28006,0x6c5425f1,0xab9504ae,0xdb1a8f33}},	//   _hool, скру, јављ, _patè,
   {{0xc4c4edfa,0xdb03edfb,0x61ed67f4,0xdb1a80e1}},	//   _کے_, renç, tkal, _baté,
   {{0x67388499,0xdb1a83d3,0xdb0383a7,0x777aedfc}},	//   _izvj, _caté, senç, latx,
   {{0xb60681f4,0x6e3be350,0x9f4a07f1,0x478b1958}},	// [64f0] _mašć, _rhub, _albà_, есем_,
   {{0x61ed6dfd,0x6e3bd742,0x61e2edfe,0xad9b01a8}},	//   skal, _shub, _lool, diúi,
   {{0x6579833e,0x1dc6809a,0x60c40110,0xb05b28c0}},	//   tawh, _रोहत, avim, _kräk,
   {{0x63be026f,0x61e2af9c,0x777a8cdb,0x70950048}},	//   _zapn, _nool, hatx, _камф,
   {{0x6aba8012,0xad9b00f7,0x6579edff,0x66f38085}},	//   _astf, giúi, rawh, rəkə,
   {{0x3206820d,0x62658878,0x3f830b67,0x68fb811c}},	//   _amoy_, авка, _udju_, vzud,
   {{0x61e2e8da,0x69c080f3,0x6e3bcbe8,0x25a9016b}},	//   _bool, fdme, _thub, _obal_,
   {{0x09e58256,0x245986c0,0x61e2e491,0x9f5e84e8}},	//   роин, _tèm_, _cool, vitá_,
   {{0x61e2ee00,0xad9b01a8,0x20548048,0x660bee01}},	//   _dool, ciúi, йтэр, migk,
   {{0x25a900dd,0xdb03a88c,0x59d3801b,0x660b9887}},	//   _abal_, tenä, थाहर, ligk,
   {{0x24800025,0x02d989d7,0x61e2ee02,0x3255a4b6}},	//   _svim_, _جواب_, _fool, _твер,
   {{0x6cc601e5,0x660bb6c3,0x78b98069,0x61e2ee03}},	//   айма, nigk, _tswv, _gool,
   {{0x442789f8,0x7ae101ec,0xf8a982f1,0x200b8036}},	//   oon_, ältn, _कहिय, écis_,
   {{0x4427ee04,0xdb1a92ca,0x1ef980f7,0x69a18aed}},	//   non_, _saté, _لعبة_, क्री,
   {{0xab2a0db3,0xdb01801b,0xdb1a8825,0x232a0ae7}},	//   това_, _oblí, _paté, тови_,
   {{0x4427ee05,0x60c40025,0x24809b49,0x61e28079}},	//   hon_, tvim, šimi_, _xool,
   {{0xa80614ef,0xdfd200a0,0x422300e8,0x660b8192}},	// [6500] азал, يير_, ідув, digk,
   {{0x4427b3c2,0x6443809a,0x387f80b9,0x60c46e06}},	//   jon_, jmni, isur_, rvim,
   {{0x25bfee07,0xdfcf0c3b,0x71a625f5,0x69c081b4}},	//   _baul_, ظيم_, _канз, ydme,
   {{0x6da6a55e,0xad9b00f7,0xe5a6802e,0x387fd273}},	//   рида, tiúi, риди, ksur_,
   {{0xa3cb00d4,0x62818711,0x61e284a2,0x248080f7}},	//   _रोड_, _avlo, _rool, éim_,
   {{0x44279ff4,0x61e2aa4a,0xad9b01a8,0x628e0299}},	//   gon_, _sool, riúi, orbo,
   {{0x66e60987,0x81b900c8,0xad9b00f7,0x660bee08}},	//   _това, চার_, siúi, bigk,
   {{0x9874818b,0x25bf859e,0x30a6c166,0x24899cef}},	//   блиц, _gaul_, аров, šama_,
   {{0x4427ee09,0xdfd08013,0x25a90362,0xf1bf001c}},	//   bon_, كية_, _rbal_, _cháy_,
   {{0x200780b9,0x4427b40d,0x57f48284,0xb60584e8}},	//   _cmni_, con_, спот, _višň,
   {{0xdefa8196,0x8f7b010f,0x2019809f,0x61e2dba3}},	//   тып_, כניק, ésia_, _tool,
   {{0x98a69821,0x10a69033,0x28c90f1b,0xf99f06c4}},	//   _виде, _видн, रिमि, _amèn_,
   {{0x442cdf12,0x443ec8ed,0x69fb83de,0x00d78fd3}},	//   _kkd_, _kht_, _בלאק, _نبوت_,
   {{0x9989009a,0x26fc00ab,0x442c80c3,0xf3ff041c}},	//   znań_, _এখনো_, _jkd_, rpão_,
   {{0x7ac41383,0xf8b680c2,0xf2c40ada,0x200cee0a}},	//   осте, _अनुप, остн, midi_,
   {{0x4427a5cf,0x33f40106,0x443ec77a,0x7bda2bac}},	//   zon_, _växa_, _lht_, ötur,
   {{0x4427c525,0x657d6e0b,0x6e2d00b4,0x80d100d4}},	// [6510] yon_, mash, _ikab, समें,
   {{0x657d51e3,0xb767044f,0x3866808e,0x28c902f1}},	//   lash, ртай, _mtor_, रिबि,
   {{0x4427b524,0x63b50353,0x660b82af,0x656f026f}},	//   von_, mezn, tigk, obch,
   {{0x63b51640,0x59a68076,0x200c822e,0x657d265a}},	//   lezn, _कॉलर, hidi_, nash,
   {{0xd49b8c6e,0x443e80cd,0x9f439931,0x442c8683}},	//   тре_, _bht_, ójú_, _bkd_,
   {{0x657d61a9,0x200c85ee,0x660b81ec,0xdd118197}},	//   hash, jidi_, sigk, _iżża,
   {{0x657d3818,0x68ed63d8,0x443e81e0,0xd90f8065}},	//   kash, lyad, _dht_, ڈیا_,
   {{0x4427ee0c,0xdb1aee0d,0x657d00f1,0x68ed0079}},	//   son_, _antó, jash, oyad,
   {{0x68ed6e0e,0x657d6e0f,0x6609ee10,0x4427b398}},	//   nyad, dash, _imek, pon_,
   {{0x753b803b,0x31790065,0x6e2d1eda,0x44278079}},	//   _izuz, _lesz_, _akab, qon_,
   {{0x657d0578,0x387fee11,0x7980819d,0x7bc1ee12}},	//   fash, ssur_, _ịweb, _ialu,
   {{0x7bc1abc8,0x7c3e020f,0xdb1a84c3,0x657d3bfa}},	//   _halu, _shpr, _entó, gash,
   {{0x66098135,0x661bee13,0x200cee14,0x61fb8b81}},	//   _mmek, _mjuk, bidi_, mhul,
   {{0xe29a0791,0x7bc1ee15,0x200c8b57,0xe7088065}},	//   лаг_, _jalu, cidi_, اتین_,
   {{0x6e95a6fc,0x657d6e16,0x7bc19e0a,0x2ba9835a}},	//   _العا, bash, _malu, च्या,
   {{0x80c40076,0x7bc19083,0x661bea55,0x628e0106}},	//   रिले, _lalu, _njuk, rrbo,
   {{0x6143104b,0x63b5007a,0x7a138087,0xc862819d}},	// [6520] зета, bezn, găti, _kọọd,
   {{0x7bc1aeb5,0x66098010,0x2f560972,0xdb1c3673}},	//   _nalu, _amek, стас, ldrí,
   {{0x442a6e17,0x61fb91e8,0x5b5700be,0xd37894ce}},	//   mob_, khul, _לייב_, _reć_,
   {{0xdb1c11b9,0x442a6e18,0x200c8010,0xd719047d}},	//   ndrí, lob_, zidi_, _दशरथ_,
   {{0x7bc1b787,0x61fbec3d,0x6281001b,0x68ed0079}},	//   _balu, dhul, álov, cyad,
   {{0x6609ee19,0x7bc185ae,0x29000010,0x657d0314}},	//   _emek, _calu, mzia_, zash,
   {{0xd378803a,0x38668082,0x200c8698,0x657d61a9}},	//   _već_, _stor_, vidi_, yash,
   {{0xada3872f,0x442a01e9,0x61fbee1a,0x63b51660}},	//   _насл, hob_, ghul, zezn,
   {{0x29006e1b,0x78a401e8,0x442c826c,0xc86281bc}},	//   nzia_, ntiv, _tkd_, _bọọd,
   {{0x6e2d013c,0x657d43fb,0x442a4327,0x7bc18662}},	//   _skab, wash, job_, _galu,
   {{0x657d51b1,0x5f38835f,0x200cee1c,0x6e4581fa}},	//   tash, рпня_, ridi_, _útbú,
   {{0x7bc1b6e0,0x61fb9cd9,0x61e600eb,0x60c485f3}},	//   _zalu, chul, _nokl, _šimu,
   {{0x657d6e1d,0x69c404b7,0xd90e8bca,0x2d996e1e}},	//   rash, ddie, _سید_, rgse_,
   {{0x63a90025,0x657d03c3,0x6d561ef0,0xb05b00f2}},	//   đeno, sash, _egya, _kräv,
   {{0x6fd205b3,0xec340cde,0x63b56e1f,0xcfa9803d}},	//   साईं, їнсь, rezn, _خانم_,
   {{0x245d0104,0x6e2d313e,0xf1b980eb,0x657d4e3f}},	//   _tìm_, _ukab, toši_, qash,
   {{0x660f003e,0x7c97006b,0x998900c3,0x69c2810c}},	// [6530] mick, _اشعا, glaš_, _maoe,
   {{0xd5a5016f,0x661b8687,0xa8a417ae,0x1da5140d}},	//   ग्रज, _sjuk, ярск, ग्रत,
   {{0x76b901e5,0x29006e20,0x68ed3e63,0x41c403dd}},	//   рлер_, azia_, syad, _लोकस,
   {{0x660f0a56,0x7bc1ee21,0xd2468077,0x99990110}},	//   nick, _salu, _زن_, _visų_,
   {{0x78a46e22,0x7bc1d104,0xdb18806a,0xd1268591}},	//   ctiv, _palu, ndvæ, _آم_,
   {{0xdfdb0698,0x660f47e9,0x2489ee23,0x547c03de}},	//   _съм_, hick, šamo_, נטוו,
   {{0x7bc1bbf6,0x61fb805d,0x7bc381ec,0xdb1e0187}},	//   _valu, thul, rdnu, _papé,
   {{0x7bc1ee24,0xa5f897ae,0x6609804f,0x6b8885ee}},	//   _walu, _лесу_, _umek, _eddg,
   {{0x2aa18063,0x442a0282,0x660f026f,0x7bc1ee25}},	//   sób_, yob_, dick, _talu,
   {{0x6e2b8b4c,0x61fba7fd,0xdb1aee26,0x600982de}},	//   logb, shul, _zatí, рном_,
   {{0xe7399289,0x660f003e,0x623595ac,0xb05b0106}},	//   рен_, fick, _дежу, _gräv,
   {{0x660f003e,0x58d58323,0x9f4581d0,0xc862819d}},	//   gick, _моет, chlý_, _wọọd,
   {{0x442a6e27,0xc0e58be2,0x6283da41,0xb05b0192}},	//   tob_, _фолк, lsno, _kräu,
   {{0x386dee28,0x61e62f2c,0xdce981d6,0x2b4081d0}},	//   mper_, _sokl, _oceľ, řice_,
   {{0x60c9ee29,0x660f443a,0xf8bf2da6,0xfbd281c6}},	//   lvem, bick, _asé_, ותם_,
   {{0x78a46e2a,0x6d560065,0x2900011e,0xbcfb00f7}},	//   ttiv, _ugya, tzia_, scéa,
   {{0x98a31e25,0x69c46e2b,0x27e78247,0x600a3d85}},	// [6540] мите, rdie, _konn_, анам_,
   {{0x69c42d38,0x25adee2c,0x290001ac,0xdb1aee2d}},	//   sdie, _abel_, rzia_, _satí,
   {{0x91e61264,0xbcfb6e2e,0xdb1aee2f,0x27e78242}},	//   _доне, ncén, _patí, _monn_,
   {{0x645ba4e2,0x5eac00ab,0x386d80b9,0xad9b01a8}},	//   _buui, ছিলে, kper_, liúr,
   {{0x6441803c,0xa3b6800f,0xa01b0125,0x5046002e}},	//   _bhli, ज़ल_, _kvöl, _мемб,
   {{0x660f07df,0x6562856f,0x326690f8,0x6441ee30}},	//   zick, scoh, отив, _chli,
   {{0xfc3f02ba,0xa2bda3e7,0x2bcb001b,0x64418c49}},	//   ntía_, _वैद्, ायता, _dhli,
   {{0xd378803a,0xab5c80eb,0x48aa968a,0x9874d7f5}},	//   _moći_, _daļa, атом_, плиц,
   {{0x27e7bb35,0xb7bc8029,0x660f42c4,0x41a6a263}},	//   _bonn_, loģi, vick, क्षस,
   {{0x274a8676,0xc6a69814,0xb4d692ee,0x765c6230}},	//   ично_, орми, िमी_, _kury,
   {{0x660f0a56,0xd3788025,0x1f5b010f,0x27e7bdb9}},	//   tick, _noći_, ידיא, _donn_,
   {{0x765c6e31,0x27e7808e,0x3dc6a0dd,0xc7b88503}},	//   _mury, _eonn_, ndow_, vođu_,
   {{0x660f0a56,0xf8ad8077,0x27e7bdb9,0x2ca6d6d3}},	//   rick, _یکی_, _fonn_, ntod_,
   {{0x660f003e,0x3dc4822c,0x63b8ee32,0x7980c8dc}},	//   sick, _lamw_, nevn, lamw,
   {{0xc1ee823c,0x3d118063,0x660f026f,0x320b0037}},	//   _जवाब_, _देने_, pick, ахан_,
   {{0xd378803a,0x2ca68420,0x91fc81a9,0xb05b0338}},	//   _doći_, ktod_, _stāj, _orät,
   {{0xdcfb805c,0x27e78247,0xf8bc809a,0x7a138162}},	// [6550] _iduć, _yonn_, ्टिय, cătu,
   {{0x63b8ee33,0x7980823d,0x765c02a0,0x2cbf8101}},	//   jevn, hamw, _bury, _rsud_,
   {{0xd6db12a0,0xdb150065,0xa2cc016f,0x7bd76e34}},	//   шта_, kezé, हिण्, _inxu,
   {{0xa91d8052,0x6281003a,0x64418c41,0x386d81a3}},	//   laže, šlos, _shli, yper_,
   {{0x7bc5058e,0x9f4c81a8,0x660d42df,0xb7b5819d}},	//   _kahu, ghdú_, _mmak, kọp,
   {{0x22496e35,0x26ce802a,0x395909d1,0xa91d9874}},	//   lmak_, _orfo_, _hgss_, naže,
   {{0x7bc53489,0xdb1a8722,0x058781a1,0x660d6e36}},	//   _mahu, _catà, _муам, _omak,
   {{0xe9d98785,0x40958cd0,0xdb1c3b65,0x3f816e37}},	//   ски_, прот, ndrá, lahu_,
   {{0x63a90025,0x6283856c,0xfbcb1905,0xb05b0192}},	//   đenj, ssno, ायाम, _träu,
   {{0x660d44a5,0x7bc535bf,0x3f81000e,0x386d8b2b}},	//   _amak, _nahu, nahu_, rper_,
   {{0xdb0aaa9c,0x386dc9e9,0xed5a6e38,0xf529025f}},	//   gefä, sper_, йон_, _עץ_,
   {{0xd1318013,0x2d9dbc4c,0x224900d2,0x386d97af}},	//   _كما_, ngwe_, jmak_, pper_,
   {{0x3f81026c,0x7bc502a0,0xf1b9811a,0x27e78e20}},	//   kahu_, _bahu, meš_, _tonn_,
   {{0xdb1a8065,0xa91d856f,0x660d6e39,0x33d51138}},	//   _hatá, ražd, _emak, міст,
   {{0x7bc56e3a,0x34b8a123,0x0f7a8039,0x6b9c008e}},	//   _dahu, _इन्द, _הרצל, rgrg,
   {{0x09e312a0,0xdddcb7bc,0x63b88da8,0xfc3f0511}},	//   носн, _ovrš, zevn, rtía_,
   {{0x2d826e3b,0x765c0cc0,0xfc3f05e4,0xa3bd881f}},	// [6560] make_, _sury, stía_, ेया_,
   {{0x2d821110,0xfc3f00f7,0x7bc56901,0x9ce70019}},	//   lake_, ltín_, _gahu, _روپے_,
   {{0x4444003a,0x41bd835a,0xf1bd8b86,0x59bd800c}},	//   _ih_, ्यास, ्यान, ्यार,
   {{0xfc3f6e3c,0xdb1aa18d,0x7bc56e3d,0xa3a9886a}},	//   ntín_, _natá, _zahu, ग्स_,
   {{0x7bc5550b,0x63b885b9,0xb4d682f1,0xf1b9d9c6}},	//   _yahu, tevn, िमे_, deš_,
   {{0x62988a8e,0x69c66e3e,0x2d825ef3,0x443803ac}},	//   tuvo, _hake, hake_, nlr_,
   {{0x80c41053,0x44446e3f,0x69c6155f,0x2d8203f8}},	//   रिके, _mh_, _kake, kake_,
   {{0x69c66e40,0xdb1e0038,0xdb1a8510,0x44440252}},	//   _jake, _napí, _catá, _lh_,
   {{0xfc648077,0x6b569381,0x69c60e9e,0x7c2e3377}},	//   _آخری, _فضائ, _make, kobr,
   {{0x6d408341,0x660d6e41,0x1dda8076,0xdb03826f}},	//   _izma, _smak, णावत, lený,
   {{0xdd950a14,0x7bc50074,0x69c6151e,0x659515ac}},	//   маны, _rahu, _oake, ману,
   {{0x44446e42,0xdb1e023e,0x7bc543cc,0xaac29834}},	//   _ah_, _capí, _sahu, _वैयक,
   {{0x44446e43,0x7bc54a7c,0x7c2e0118,0x76560300}},	//   _bh_, _pahu, fobr, _diyy,
   {{0x444406f6,0x7c2e0052,0x41da852a,0x60c2ee44}},	//   _ch_, gobr, भावस, _isom,
   {{0x69c66e45,0x44440046,0xa91d8289,0x883b8051}},	//   _bake, _dh_, raže, _התגו,
   {{0x44446e46,0x69c60642,0x2486ac15,0xa7fb06a5}},	//   _eh_, _cake, ksom_, _muñe,
   {{0x7bc5048f,0x3f81578e,0x44446e47,0xdb03826f}},	// [6570] _tahu, tahu_, _fh_, dený,
   {{0xd6db0d0e,0xa3d40beb,0xdb1e03f2,0x60c280b8}},	//   йте_, _सोप_, _zapí, _msom,
   {{0x69c66e48,0xdddc8503,0xb05b2a93,0xe9df001c}},	//   _fake, _svrš, _präs, _chúc_,
   {{0x661d38b9,0x3f81003e,0xe9df0028,0x645701df}},	//   nnsk, sahu_, _giúp_, _hixi,
   {{0x4444201f,0x64a58ddc,0x6287240c,0x661d0412}},	//   _yh_, фала, lsjo, insk,
   {{0x44446e49,0x69c60a0f,0x2d826e4a,0x3d11816f}},	//   _xh_, _zake, zake_, _देणे_,
   {{0xea000028,0xdb03803e,0xddcd009a,0xd3788024}},	//   _hoạt_, bený, _miał, _noću_,
   {{0xa3d405fc,0x7c2e2786,0xdb03ee4b,0x661d2454}},	//   _सोन_, zobr, menü, jnsk,
   {{0x34949448,0x2d8dee4c,0x9f4780f1,0x3a2d85f8}},	//   _патр, _idee_, _tonë_, roep_,
   {{0x2d82022e,0x6287035f,0x764404b9,0xdb1e0187}},	//   wake_, ksjo, _shiy, _japã,
   {{0x4ac180d4,0x2d826e4d,0xdb1e2b95,0x3d118c69}},	//   _शनिव, take_, _papí, _देते_,
   {{0x661d0aa2,0x645708f1,0xa3a98c78,0x60cd00ce}},	//   gnsk, _aixi, ग्र_, kvam,
   {{0x69d9ee4e,0x7c2e6e4f,0x2d825964,0x69c625ac}},	//   _inwe, tobr, rake_, _rake,
   {{0x6b83859e,0x69c63575,0x2d826e50,0x661d01ac}},	//   nang, _sake, sake_, ansk,
   {{0x69c66e51,0x2d826e52,0xdb03c0a2,0xfaa32d34}},	//   _pake, pake_, menó, каро,
   {{0x6b83bf73,0x69c9ee53,0x645f00f1,0x7c2e1400}},	//   hang, ndee, _fuqi, sobr,
   {{0x78a9b050,0x6b83a133,0x2fc788b3,0x61ebae02}},	// [6580] ntev, kang, _kang_, _mogl,
   {{0x26d1003a,0x6b83bdd4,0x6d5bb9ef,0xe9df001c}},	//   _brzo_, jang, _agua, _phúc_,
   {{0x2fc78681,0x6b83c3ce,0x69d9ee54,0x78a9ee55}},	//   _mang_, dang, _onwe, htev,
   {{0x61eb8022,0xdd8f845b,0x63bc2a92,0x2fc7843c}},	//   _nogl, لوم_, lern, _lang_,
   {{0x442e9e12,0x2d800006,0xdb098efc,0x6b83aaf6}},	//   tof_, _meie_, čnýc, fang,
   {{0x2fc7ee56,0x63bc6e57,0x24868687,0x69d9ac22}},	//   _nang_, nern, rsom_, _anwe,
   {{0x9f5e820f,0x96630607,0x998901ac,0x61ebb0dc}},	//   shtë_, _аксе, slať_, _bogl,
   {{0x63a9003b,0x442eee58,0x61eb81a7,0x80b280ab}},	//   đeni, sof_, _cogl, জিস্,
   {{0x6b83ee59,0x6d40ee5a,0x63bc0f06,0xdb1a8187}},	//   bang, _uzma, kern, _antô,
   {{0x63bc3e55,0x69d98a2c,0x629c6e5b,0x6b83ee5c}},	//   jern, _enwe, kuro, cang,
   {{0x7bdaee5d,0x61ebee5e,0xdb0e00f2,0xa5bb04c3}},	//   _intu, _fogl, nebä, olóx,
   {{0x72169381,0x61eb831d,0x629c0114,0x2fc78114}},	//   _غذائ, _gogl, duro, _eang_,
   {{0x7bc8ee5f,0xe9f780e8,0x79840010,0x661d06b1}},	//   _kadu, _інші_, daiw, rnsk,
   {{0x63bc29e3,0x7bc88ad4,0xf8bc8105,0x2fc7c6df}},	//   gern, _jadu, ्टीप, _gang_,
   {{0x64576e60,0x62a2826f,0xa3b0816f,0xa3e69513}},	//   _vixi, _útoč, ट्य_, _बचन_,
   {{0x645702a3,0xa91d825b,0xf1bf0019,0x6b838a40}},	//   _wixi, laža, _akár_, zang,
   {{0x2fc79dda,0x63bc6e61,0x628701cd,0x90990098}},	// [6590] _yang_, bern, ssjo, яват_,
   {{0x60cd2e56,0x6d5bee62,0x60c900cd,0xf1d803eb}},	//   rvam, _sgua, _šems, डाउन,
   {{0xa3e2a8d7,0x20130201,0x629c072a,0x44316e63}},	//   धान_, rixi_, curo, moz_,
   {{0x6b83d87a,0x7bdaee64,0x7bc88032,0x44316e65}},	//   wang, _antu, _aadu, loz_,
   {{0x6b83b167,0x7bc89caa,0x7bda80dd,0x61eb8796}},	//   tang, _badu, _bntu, _rogl,
   {{0x61ebc50d,0x7bc88b57,0x22469142,0x44315024}},	//   _sogl, _cadu, _ahok_, noz_,
   {{0x6b8399a2,0xeab18065,0x6b7c0051,0xe2998c07}},	//   rang, اعت_, חרונ, чай_,
   {{0x44310065,0xdb1c0073,0x2fc7ee66,0x201ed9c2}},	//   hoz_, ferê, _sang_, enti_,
   {{0x6b83ee67,0x69c985f8,0x61ebc4e9,0x2fc784d2}},	//   pang, rdee, _vogl, _pang_,
   {{0xe3b083f8,0x7bc880eb,0x443101ca,0x78a9ee68}},	//   _نرم_, _gadu, joz_, rtev,
   {{0x6811801b,0x61ebee69,0x2ca900ee,0xc95980a0}},	//   vědě, _togl, _aqad_, _فلاش_,
   {{0x6b81ba79,0x7bc88025,0x91fc80eb,0xdb1e026f}},	//   _helg, _zadu, _stāv, _napá,
   {{0x5184902a,0x6b8183ca,0x2fc7ee6a,0x7bc8d99c}},	//   _руха, _kelg, _tang_, _yadu,
   {{0x2fc7816f,0x224d93f4,0x629c6e6b,0xe1ff6e6c}},	//   _uang_, lmek_, turo, _aló_,
   {{0x63bc6e6d,0x2d800074,0x3f8581d0,0xdce40609}},	//   rern, _teie_, malu_, _ddiġ,
   {{0x3f858867,0xe1f981e2,0x63bc0f96,0x224d8214}},	//   lalu_, nkų_, sern, nmek_,
   {{0x63ad803a,0x63bc6e6e,0xf8c8801c,0x629c6e6f}},	// [65a0] đanj, pern, _xứ_, suro,
   {{0x3f85825b,0xdb018207,0x44310511,0xd9bd86de}},	//   nalu_, _eclé, coz_, ्युट,
   {{0x22591da3,0x539b0039,0x6602bb1c,0xc0498129}},	//   _fisk_, _ציטו, thok, _sườn_,
   {{0xf5398038,0x7bc8ee70,0x9ccaa252,0x9f5c86c4}},	//   _byť_, _sadu, зыка_, _elvè_,
   {{0x6b81ee71,0x3f85ee72,0x201e8198,0x3ebf0b67}},	//   _belg, kalu_, ynti_, _ćute_,
   {{0x3f8580d2,0x6b8183a8,0x66028abd,0xc049801c}},	//   jalu_, _celg, shok, _vườn_,
   {{0xd9bd8996,0x3f85ee73,0x6b818333,0x9f47826f}},	//   ्यूट, dalu_, _delg, _plný_,
   {{0x3d118074,0x44316e74,0xdb1c6e75,0x68e455d8}},	//   _देवे_, zoz_, terê, oxid,
   {{0xdfd08307,0x80bc835a,0xc8c939a1,0xbddb00e7}},	//   لية_, ्टें, रिएट, llèg,
   {{0x7bda9dda,0x6e246e76,0xa2e696ba,0x201eee77}},	//   _untu, _ajib, _позд, unti_,
   {{0xa3cb0ebf,0x44311b89,0xa3df016f,0x290b8cd4}},	//   _रोग_, voz_, णास_, úcar_,
   {{0x63a50352,0x645acf84,0xe9df026b,0xf8c880ff}},	//   _schn, _hiti, _ahún_, _tứ_,
   {{0x645aee78,0x3f85da50,0x44316e79,0x6e245de3}},	//   _kiti, balu_, toz_, _djib,
   {{0x6d440d38,0x6e24019d,0x645aa09c,0xbcfb6e7a}},	//   _dzia, _ejib, _jiti, ncéi,
   {{0x645aee7b,0xed598253,0x2fdf026c,0x03d781c6}},	//   _miti, _važi_, _đug_, עולם_,
   {{0xa3b08076,0x644e6e7c,0x28b786a7,0x7522139c}},	//   ट्त_, ambi, _अहमि, _žoze,
   {{0xab871525,0x0841046d,0x21390168,0x645aee7d}},	// [65b0] _пунк, _adìẹ_, _qysh_, _oiti,
   {{0x63ad90d3,0x6e3d0840,0xa91d80ce,0x9f5e8216}},	//   đank, llsb, kažn, mitó_,
   {{0x22591d1a,0xa7fb0511,0x9f5e8661,0xa91d8968}},	//   _tisk_, _cuña, litó_, jažn,
   {{0x6b818310,0xdd958196,0x2eee016d,0x7afa04d6}},	//   _selg, тады, äffa_, øtte,
   {{0x69dd1429,0x645ad283,0x3d1183ca,0x629881ed}},	//   _inse, _biti, _देशे_, ervo,
   {{0x741591cc,0xdb1c6e7e,0x3fcb80ab,0x645ae53c}},	//   ضوعا, ferè, _লক্ষ, _citi,
   {{0x645a8587,0xe9d18013,0x78ad6e7f,0x6b81c43d}},	//   _diti, لغة_, ltav, _velg,
   {{0x3f85ee80,0xe1f98110,0x645a81a8,0xe4e780e8}},	//   walu_, ukų_, _eiti, _пізн,
   {{0x224de5fc,0x78ad0f52,0x6b81ee81,0x645aee82}},	//   rmek_, ntav, _telg, _fiti,
   {{0x24558077,0x3f830683,0x645a833e,0x765b8420}},	//   _شناس, _jeju_, _giti, _hiuy,
   {{0x69dd6e83,0x248d8b40,0x78ad2889,0x6d440019}},	//   _onse, _hvem_, htav, _szia,
   {{0x61ef39a5,0x78ad2dab,0x2612176d,0x645aee84}},	//   _nocl, ktav, pšom_, _ziti,
   {{0x64488009,0x61e985f3,0xb6060032,0x78ad0168}},	//   _yhdi, mjel, _aráà, jtav,
   {{0x69dd4808,0x61e9ee85,0xd3720154,0x69cb97ab}},	//   _anse, ljel, شهر_, _hage,
   {{0x69cb81bf,0x3a2001e0,0x66d7819d,0x9f47816b}},	//   _kage, tnip_, _ịko, _koní_,
   {{0x61fb91e8,0x61e9b86a,0xba2325f2,0x3eaa801b}},	//   nkul, njel, адск, žití_,
   {{0xed598025,0x229b077f,0x3eb800dd,0x59a683dd}},	// [65c0] _kažu_, tàkì_, _sprt_, क्टर,
   {{0x69cbd1fa,0x09cd80c8,0x61e9ee86,0xa7fb0511}},	//   _lage, িউটা, hjel, _puña,
   {{0x0d868c40,0xa3df035a,0x61fbee87,0x248d802e}},	//   влен, णार_, kkul, _avem_,
   {{0x645aee88,0xa2d58bb8,0xc1bd8ebf,0x61ef6c51}},	//   _siti, भिन्, ्योग, _gocl,
   {{0x61e9830b,0x645a8205,0xdca3a39a,0xe5a3ee89}},	//   djel, _piti, иаци, ричи,
   {{0xdb1c5728,0x628a84dc,0xa7fb0118,0x7982808e}},	//   terè, tsfo, _tuña, _seow,
   {{0xdee3395b,0x645aee8a,0x69cb9f99,0x66e324b2}},	//   _кори, _viti, _bage, _кора,
   {{0x61e9bbbc,0xa91d8b67,0x628a9c2b,0x61fb8637}},	//   gjel, gažo, rsfo, gkul,
   {{0x69cbd303,0x6e2281bc,0x91fc80eb,0x38ab806a}},	//   _dage, mnob, _stās, gør_,
   {{0xdb188e14,0x2d849916,0x61fbee8b,0x9f5e8388}},	//   leví, _heme_, akul, vitó_,
   {{0x25df01ab,0x69cbb7c0,0x61e9b409,0x656d6e8c}},	//   गाली_, _fage, bjel, _pfah,
   {{0xa3cb1551,0x69cbee8d,0x61e9911b,0x60c40dc5}},	//   _रोज_, _gage, cjel, kwim,
   {{0x69c09790,0xa3e68105,0x2d84ee8e,0xe89497d4}},	//   meme, _बचा_, _meme_, _саль,
   {{0x69c0ee8f,0xac242aeb,0x69cbee90,0x200584e8}},	//   leme, афск, _zage, chli_,
   {{0xdeef93cd,0xe8e08028,0x9f5eb893,0x69cb820c}},	//   _ты_, _đội_, sitó_, _yage,
   {{0x78ad025d,0x63ad8025,0xd9e5800f,0x0f578039}},	//   ttav, đani, कायत_, _ביום_,
   {{0xc4c48065,0x5184065c,0xa91d817f,0x57b51df3}},	// [65d0] _بے_, руса, jažl, лбат,
   {{0xb8cb0105,0xcbbd80ab,0x673c2c9f,0x7649ee91}},	//   _गम_, _ইচ্ছ, _byrj, _shey,
   {{0xcf938158,0xa3d68744,0xf7700591,0x7c351b39}},	//   שטע_, ियन_, تاق_, mozr,
   {{0x69dd0352,0xa3b08e00,0x69c0c29e,0x3a2682f7}},	//   _unse, ट्स_, jeme, _njop_,
   {{0xe9df10ab,0x69c0ee92,0xa91d826f,0x6aba808e}},	//   _inú_, deme, važo, _aptf,
   {{0x69cbee93,0xdb056e94,0x30da00be,0xb4fc01c6}},	//   _sage, _aché, _אַלע, ופדי,
   {{0xdb1c0020,0x69cb9850,0x39468118,0x61e9ee95}},	//   teré, _page, _azos_, tjel,
   {{0x69c09412,0xf1da8076,0xb05b016d,0x683d8722}},	//   geme, भागन, _osäk, mèdi,
   {{0x61e9ee96,0x20559d7b,0x28c90aed,0x69cbee97}},	//   rjel, лтор, रिटि, _vage,
   {{0x61fbee98,0xdb052e07,0xa7fb1f88,0x248980eb}},	//   skul, _tchè, _muño, šams_,
   {{0x69cbee99,0x61e9920e,0x69c0cb31,0x92000032}},	//   _tage, pjel, beme, _bọ́,
   {{0x69c0c395,0x8afa83c8,0x2005ee9a,0xcf4982d0}},	//   ceme, _אלעז, shli_, _ışık_,
   {{0x81cc0a49,0xa7fb0144,0xa3df307c,0x92000032}},	//   লাম_, _nuño, णां_, _dọ́,
   {{0x409280f7,0x3a3f92a5,0x7bce0216,0xd91a9101}},	//   _الور, llup_, udbu, _אונל,
   {{0x9987017f,0xab27618f,0x3ea102f1,0x60c400b9}},	//   _šiša_, гора_, juht_, wwim,
   {{0x316dee9b,0xa3d406ae,0x9200026b,0xf3f18032}},	//   ncez_, _सोर_, _gọ́, _lọ_,
   {{0xc0e30396,0x6604022e,0xb1463ea4,0xa3d6825e}},	// [65e0] ботк, _ilik, унал, ियम_,
   {{0x69c0ee9c,0x2d8496c9,0x3a396e9d,0xdee62109}},	//   zeme, _seme_, _eksp_, лози,
   {{0x69c0b144,0x645e02c4,0x81cc0264,0xdb15016a}},	//   yeme, _iipi, লাব_, pezá,
   {{0x69c087e2,0xc9760277,0x0caa8652,0x94aa9878}},	//   xeme, _حادث, етки_, етка_,
   {{0x645e022e,0x22406e9e,0x628e03d9,0x69c0a527}},	//   _kipi, mlik_, lsbo, veme,
   {{0xa91d80d2,0x2240374d,0x443a025b,0xdb055c76}},	//   gažm, llik_, _jkp_, _sché,
   {{0x66042b16,0x443a107a,0xd25a838d,0x69c0ad10}},	//   _olik, _mkp_, нци_, teme,
   {{0x22403770,0x201a6516,0x79866210,0x777a81c0}},	//   nlik_, lipi_, _jekw, wbtx,
   {{0x224001b0,0xdd8f8a47,0x79860135,0x2df781c6}},	//   ilik_, _رول_, _mekw, _עצמך_,
   {{0x69c0cf7a,0x78a0ee9f,0x224020d8,0x79860133}},	//   seme, rumv, hlik_, _lekw,
   {{0x10370051,0x22406ea0,0x69c0c507,0xf1bf00e1}},	//   רטים_, klik_, peme, ššie_,
   {{0xa3b0c183,0x25a6eea1,0x628e20e5,0x0f570039}},	//   ट्र_, ngol_, dsbo, טיים_,
   {{0x22406ea2,0x645e165c,0x25a907f1,0x628e1c2b}},	//   dlik_, _bipi, _vcal_, esbo,
   {{0x66046ea3,0x443a03ac,0x2240657a,0x60000106}},	//   _elik, _ckp_, elik_, _sömn,
   {{0x645e059e,0x3ffb8158,0x22406ea4,0x66042d24}},	//   _dipi, _אפגע, flik_, _flik,
   {{0xdb0aeea5,0x6fa70540,0x22406ea6,0xa7fb0661}},	//   lefó, _चाहू, glik_, _puño,
   {{0x48151052,0x80df00d4,0x30153c6c,0x2d8b1620}},	// [65f0] амас, नमें, адар, mace_,
   {{0x645e6ea7,0x64468084,0x2d8b6ea8,0xdb0a8118}},	//   _gipi, _ūkin, lace_, nefó,
   {{0xf7700bbe,0x22406ea9,0x764d6eaa,0xdb0a81ec}},	//   سال_, blik_, _khay, gefü,
   {{0x8f3783c8,0xe51686ae,0x79861384,0x248d3887}},	//   נטאג_, _देहि_, _gekw, šemu_,
   {{0x26d838c3,0xfce59170,0xa2bd9305,0x6385b07d}},	//   _erro_, роло, _वैज्, агла,
   {{0x69cf2797,0xb09a0051,0x201a3076,0x61ed29a8}},	//   _hace, _בישר, cipi_, ljal,
   {{0x2d8b6eab,0x69cf42e9,0x6d9c80e1,0x5fce109b}},	//   kace_, _kace, _sťaž, _होटल,
   {{0x61ed6eac,0xe9d99485,0x69cf4267,0xe516a64d}},	//   njal, тки_, _jace, _देवि_,
   {{0x97c59be4,0xade400d4,0x38af07c0,0xdb038036}},	//   айпе, गासन_, nür_, igné,
   {{0x764d02c1,0x66042e02,0x22400182,0x998d8063}},	//   _ahay, _slik, zlik_, wień_,
   {{0x66040d38,0xb4de2ba6,0xf7459541,0xa3e2902e}},	//   _plik, णम्_, рено, धार_,
   {{0x69cf2d84,0x645e6ead,0x7bc3eeae,0x2d8b6eaf}},	//   _nace, _sipi, lenu, gace_,
   {{0x6e3b8010,0x32090079,0x7986022b,0x9f4a00e1}},	//   _mkub, dhay_, _rekw, _robí_,
   {{0x38af0059,0x7bc38074,0x656f047f,0x79866eb0}},	//   dür_, nenu, acch, _sekw,
   {{0x6e3bc7c2,0x68fb8747,0x645e0010,0x7e6701c0}},	//   _okub, lyud, _vipi, _nujp,
   {{0x6926344f,0x38af419b,0x69cf6eb1,0x628e31c3}},	//   амба, für_, _cace, rsbo,
   {{0xe8f721e2,0x22403770,0x65640578,0xdb1c4218}},	// [6600] алт_, rlik_, _igih, merí,
   {{0xdb1c040e,0x224013d6,0x60048247,0x32090079}},	//   lerí, slik_, _kòma, ahay_,
   {{0xa3e98768,0x69cf6eb2,0x0566a8ca,0x32460329}},	//   यान_, _face, авен, _венг,
   {{0x44386eb3,0x61ed4af7,0x320903ec,0xdb1c05e4}},	//   lor_, cjal, chay_, nerí,
   {{0xfbe2800d,0x25a687f1,0x0cd48d0e,0x8cd90ad5}},	//   पालम, rgol_, солю, मियो,
   {{0x69c46eb4,0x2d8b001b,0x7bc3eeb5,0x2c6b8b40}},	//   leie, zace_, genu, _død_,
   {{0x44208052,0x3f98808b,0x6b8a9c2b,0xdb1c0187}},	//   đi_, órum_, rafg, lerâ,
   {{0x44386eb6,0xada38a94,0xdb1c0876,0x69cf01df}},	//   hor_, _масл, jerí, _xace,
   {{0x44386eb7,0xdb1c0a96,0xed579b1c,0x2d8b1620}},	//   kor_, derí, _вот_, vace_,
   {{0xdefa9006,0x61ed4635,0x764d5d1a,0x7e60eeb8}},	//   вым_, zjal, _shay, _himp,
   {{0xdb1c1986,0x2d8b01d0,0x4fd900be,0x7e60eeb9}},	//   ferí, tace_, אַרד, _kimp,
   {{0xa5bb3f85,0x7e6081b9,0x80a70035,0x7af78338}},	//   cnól, _jimp, टूडे, äxte,
   {{0x7e60859c,0x61e2e97e,0x2d8b205c,0x614381f3}},	//   _mimp, _inol, race_, _деца,
   {{0x4438337b,0x69cf6eba,0xa3e98107,0x7c38eebb}},	//   gor_, _sace, याय_, novr,
   {{0x69cf6ebc,0xd8388db7,0x2d8b4921,0xa3ae946d}},	//   _pace, moč_, pace_, _कान_,
   {{0xdb1c05e4,0x3f8c8e2e,0x20180010,0x3f879ffb}},	//   cerí, ladu_, _amri_, _zenu_,
   {{0xa3d68f85,0x661d6ebd,0xa3e98f0a,0x3f87a767}},	// [6610] िया_, misk, याम_, _yenu_,
   {{0x320902a3,0x6e29eebe,0x38af080a,0x6e3beebf}},	//   shay_, _sjeb, rür_, _skub,
   {{0xe8e08028,0xb5fd817f,0xf1b98253,0xa3bc82f1}},	//   _đời_, _liše, liše_, ेजन_,
   {{0x661d6ec0,0x201800f1,0xb7c600eb,0xd6d86ec1}},	//   nisk, _emri_, _apģē, шту_,
   {{0x3d1195a7,0x81d580c8,0xf1b98253,0xd838807a}},	//   _देखे_, _সকল_, niše_, koč_,
   {{0x5f09852a,0x7c388da8,0x798d25d5,0x00f604de}},	//   ानम्_, govr, laaw, _המשך_,
   {{0x5694243b,0xdb1c0e1b,0xa91d8084,0xe2a89f33}},	//   _март, yerí, maži, لاين_,
   {{0x6e3b91e8,0x290d80ad,0x00858544,0xa3d903b7}},	//   _ukub, tzea_, блио, _ठोस_,
   {{0x7bc3b932,0xfc3f12c9,0x4438448e,0x03c78009}},	//   penu, ntís_, yor_, _всем,
   {{0xa3ae853e,0x63ad8025,0xf1b980d2,0x44386ec2}},	//   _काय_, đans, diše_, xor_,
   {{0xdb1c02ba,0x3f878036,0x798d6ec3,0x44f98264}},	//   terí, _venu_, kaaw, _অধিক_,
   {{0x661d0bfa,0x6443eec4,0x83fc8024,0x44386ec5}},	//   gisk, llni, _viđe, wor_,
   {{0xa3ae8a43,0x44384e1b,0xa91d9024,0x44278083}},	//   _काम_, tor_, kaži, onn_,
   {{0x2d9e1bac,0xd9e581ab,0xdd998176,0x9f430032}},	//   şte_, कावत_, _blňk_, _dojú_,
   {{0x4427bf0f,0x09e611b3,0x4438251b,0xdb1c6ec6}},	//   inn_, бовн, ror_, derã,
   {{0xc332804c,0x63bb0025,0x661d1a28,0x3ea58957}},	//   פון_, đuna, cisk, mult_,
   {{0x44386ec7,0xe0da0a14,0xf1b9826c,0x69c45d84}},	// [6620] por_, ыва_, ciše_, reie,
   {{0xa91da655,0x7e690353,0x25ad8087,0x69c46ec8}},	//   gaži, _čepr, _acel_, seie,
   {{0x6abe2459,0x3ea58006,0x7e6091d6,0x8d1a803d}},	//   _uppf, nult_, _pimp, گزار_,
   {{0x6da6846e,0xad9b00f7,0xdb1c0722,0x60c98518}},	//   сида, thúi, merà, kwem,
   {{0x7c388025,0x78a40e67,0x91a6826b,0xb87b0032}},	//   tovr, quiv, _ako̟_, _aríf,
   {{0x3ea5a637,0x661d6ec9,0x6d40826f,0x20180010}},	//   kult_, zisk, _vyma, _umri_,
   {{0x7e60eeca,0x6d40809a,0xbea31c56,0xd2508077}},	//   _timp, _wyma, _нарк, ونت_,
   {{0x44278af9,0x30a69f7d,0xa074ac18,0x187495a6}},	//   ann_, бров, огич, огия,
   {{0xd8388d26,0x661d6ecb,0x050a00ab,0x3f8a01a1}},	//   toč_, visk, রপুর_, _kebu_,
   {{0xb5fd803b,0xf1b9803a,0x661d009a,0x224f8118}},	//   _više, više_, wisk, _ehgk_,
   {{0x661d4705,0x44270459,0x50d684c0,0x28cf000c}},	//   tisk, _ın_, _گزار, _सैनि,
   {{0xf1b98503,0xd838807a,0xa2d5952c,0x6f0901d0}},	//   tiše_, soč_, भिर्, _řeck,
   {{0x661d6ecc,0x2ca69acd,0xdddb189e,0x05aa01d0}},	//   risk, nuod_, lptū, _कारब,
   {{0x661d02d7,0x3f8a00d2,0xf1b984a8,0x443e8d89}},	//   sisk, _nebu_, riše_, _jkt_,
   {{0xa3e9853e,0x201e973d,0xdb1a82af,0x6602eecd}},	//   यात_, miti_, _natü, kkok,
   {{0x201eeece,0x26df0052,0xdb1a8061,0x7a3e8168}},	//   liti_, _čuo_, _ható, pëtu,
   {{0x443eeecf,0x3f8a005c,0xa5bb2fe5,0x44279106}},	// [6630] _okt_, _bebu_, riód, ynn_,
   {{0xb7673592,0x261b8074,0xfc3f0899,0x3f6718a3}},	//   стай, _मगही_, buía_, стаб,
   {{0x3f8a21e3,0x6e2d026c,0xb87b3e92,0xfc3f023e}},	//   _debu_, _kjab, _oríg, stís_,
   {{0x7afa22a8,0xa9c70077,0x7bd544c2,0x442c812b}},	//   ätte, _ازدو, ldzu, _ajd_,
   {{0x69a2800f,0x201eeed0,0xd49bca48,0xa91d8110}},	//   _गाजी, kiti_, уре_, paži,
   {{0x201e80ce,0x3eb30706,0x3f8a1600,0xdb188198}},	//   jiti_, ptxt_, _gebu_, kevä,
   {{0x59da9d2a,0x81cc00c8,0x442781e4,0x93fc00be}},	//   _मोहर, লার_, rnn_, רלוי,
   {{0xdb1c037d,0x4095940b,0x1dd90576,0xdb1a8032}},	//   nerá, орот, _बोलत, _aató,
   {{0x6609aaaa,0x201e8010,0x661beed1,0x7bc712ae}},	//   _ilek, fiti_, _imuk, keju,
   {{0xdb1a87a3,0x39438029,0x2d8f91e6,0x2ca080f7}},	//   _cató, ājs_, lage_, áide_,
   {{0x65c61287,0xa3d6a120,0x1dd5016f,0xbddb253a}},	//   обна, ियर_, धयंत, rlèn,
   {{0x26dc8067,0xed5a013a,0xd5aa016f,0x361600e8}},	//   _drvo_, ион_, _काळज, ієнт,
   {{0xdb1c6ed2,0x6609eed3,0x89378872,0x67d5a432}},	//   derá, _mlek, _اعضا, _моду,
   {{0x201e82a5,0xdb1c0722,0x2d8f80e8,0xbddb0036}},	//   citi_, terà, hage_, llèl,
   {{0x66098006,0xdd920117,0x8c431a3b,0xe363035f}},	//   _olek, _ہوں_, фере, дкри,
   {{0x91e30d9e,0x66098870,0x3a290061,0xdb1c3ad6}},	//   мосе, _nlek, gnap_, gerá,
   {{0x2bb2090a,0x2d8feed4,0x81cc00ab,0xa7fb016a}},	// [6640] _जापा, dage_, লাল_, _zuñi,
   {{0x661b9f37,0x39420084,0xdfa601a8,0x7f8c83de}},	//   _amuk, _vyks_, تحري, ָנאַ,
   {{0x06ca1287,0x15fe0076,0xdb1c08a4,0x6609a16f}},	//   ргей_, _उकार_, berá, _blek,
   {{0x201e812b,0x3f8a027f,0xdb1c4218,0x7c3c0c43}},	//   ziti_, _webu_, cerá, lorr,
   {{0x61e65a98,0x660280a4,0xb12480ab,0x3f8a059e}},	//   _inkl, rkok, _পর্ব_, _tebu_,
   {{0xe7ae8ebf,0x60048362,0x661bb4e7,0x38b43ede}},	//   ज्ञप, _còml, _emuk, mär_,
   {{0x38b40884,0x3d1a8063,0xe8e08028,0xdb1a86a5}},	//   lär_, _मेरे_, _đối_, _rató,
   {{0x443e82f7,0x201e803d,0x7c3c0cdb,0x2d8f9de9}},	//   _wkt_, witi_, horr, cage_,
   {{0x201e803a,0x6d4410af,0x7c3c6ed5,0x38b46ed6}},	//   titi_, _nyia, korr, när_,
   {{0xdb1c0a56,0x2d82067b,0x6e2d2dc4,0xb8f282f1}},	//   zerá, ebke_, _sjab, _हई_,
   {{0x443c824a,0x7c3c6ed7,0x38b40106,0xdb1aeed8}},	//   mov_, dorr, här_, _obté,
   {{0xae1609a3,0x443ceed9,0x200ceeda,0x78b60110}},	//   दोलन_, lov_, shdi_, ktyv,
   {{0xdb1c016a,0x7bc73855,0xdb18b750,0x7c3c6edb}},	//   verá, teju, sevä, forr,
   {{0x443ceedc,0x61e60e3b,0xdb056edd,0x7c3c0102}},	//   nov_, _ankl, _achá, gorr,
   {{0x2d8f82be,0x7bc72c3a,0xf1b982ce,0xa2a2864a}},	//   yage_, reju, liša_, _गिफ्,
   {{0x38b400f2,0xceeb003d,0x200a6ede,0x7bc76edf}},	//   fär_, یران_, _albi_, seju,
   {{0x443ceee0,0x7c3c1a01,0xf1b9842b,0xb5fd8b67}},	// [6650] kov_, borr, niša_, _niša,
   {{0xd6db0ae7,0x61e61c02,0x443c8038,0x661beee1}},	//   ите_, _enkl, jov_, _smuk,
   {{0x2d8feee2,0xa3e9912a,0x443ceee3,0x6609858f}},	//   tage_, यास_, dov_, _plek,
   {{0xd2468b76,0x38b400f2,0x24890a0f,0xe9df001c}},	//   _سن_, bär_, _kwam_, _chút_,
   {{0xd12680f7,0x2d8feee4,0x600d8020,0x27f86ee5}},	//   _أم_, rage_, _húme, _forn_,
   {{0x798beee6,0x2d8feee7,0x60cd24d4,0x64472800}},	//   _segw, sage_, mwam, nlji,
   {{0x27e980ff,0x2c5d82d6,0x60c297c9,0x6e3d106f}},	//   _đan_, _jňdi_, _apom, kosb,
   {{0x661b82a0,0xa3e98424,0x83fc812b,0x7c3c0fe0}},	//   _umuk, याह_, _viđa, zorr,
   {{0x7e640009,0x443ceee8,0xd24e84a3,0x64470796}},	//   _riip, bov_, دني_, klji,
   {{0x443ceee9,0x798bbdd9,0x2a6c81a1,0x62956546}},	//   cov_, _wegw, _fudb_, kszo,
   {{0xb8f2af80,0xe7398185,0x24893932,0x26158038}},	//   _है_, сен_, _awam_, sťou_,
   {{0xa3e985b3,0xbddb03d3,0x60cd1eb7,0x629565d4}},	//   याव_, blèm, kwam, dszo,
   {{0x7c3c6eea,0xa8798158,0x5fac016f,0x998d8035}},	//   torr, _פאַר, _चालल, zieś_,
   {{0x387fb6a1,0x987a810f,0x600d8118,0x64470353}},	//   mpur_, _האסט, _búme, glji,
   {{0x63bc8214,0x91e61e0b,0x09e600e8,0x61f981e0}},	//   _örne, пове, повн, _kowl,
   {{0x443ceeeb,0xfc3f0d76,0x78b60009,0x249f00eb}},	//   zov_, quín_, ttyv, šuma_,
   {{0x78a98020,0x7e7b2752,0x7c3c6eec,0xdb0a83a7}},	// [6660] nuev, _čupa, porr, lefô,
   {{0x443c8069,0x81cc00c8,0x13a80416,0xa3d403a4}},	//   xov_, লাই_, _بندی_, _सोच_,
   {{0xe9df0028,0x443c875f,0x290000b9,0x78b60198}},	//   _phút_, vov_, syia_, styv,
   {{0xe7e28074,0x2bca213e,0xb5fd811f,0x7d0682f1}},	//   _कोना_, ाजवा, _piša, _üksk,
   {{0x443ca007,0xe516eeed,0xdd8f8199,0x79846eee}},	//   tov_, _देखि_, اوه_, mbiw,
   {{0xb5fd811f,0x25bfc7c7,0xf1b99024,0xa7fb6c65}},	//   _viša, _ebul_, viša_, _buñu,
   {{0x443ceee3,0x60c2c1a2,0x6458c13a,0x78a40a53}},	//   rov_, _spom, rmvi, lriv,
   {{0x443ca3fa,0x30a68a7c,0xb5fd807a,0x64471809}},	//   sov_, пров, _hišn, zlji,
   {{0x61f982c1,0x443c886f,0xb5fd812b,0x3ebf025b}},	//   _dowl, pov_, _kišn, _ćuti_,
   {{0xdb1e05a4,0x6e98997d,0xdcef01a9,0x779280b7}},	//   _japó, овор_, sacī, ریبا,
   {{0xa3e980cf,0x6f01831d,0xbb4a9368,0x61f9eeef}},	//   यार_, gylc, _الان_, _fowl,
   {{0x6e22b673,0x6a168872,0x60cd0035,0x61f981b9}},	//   niob, _عبار, ywam, _gowl,
   {{0x7e6e022c,0x35470c99,0x78a98144,0x6e3d0061}},	//   _lubp, яхов, cuev, rosb,
   {{0x78a403a6,0x2bb2016f,0x394682c4,0x62950061}},	//   driv, _जाणा, _iyos_, tszo,
   {{0x9f5800f1,0x7ac41b2f,0x897a0135,0x60cd0300}},	//   _dorë_, нсте, _ọgụg, wwam,
   {{0x7afa016d,0x3ce04b57,0x6447007a,0x60cd6ef0}},	//   ätta, _friv_, slji, twam,
   {{0x69340db6,0x62950019,0xe1340048,0x660d5c7d}},	// [6670] енту, sszo, енты, _ilak,
   {{0xb87b01ac,0xf7701a43,0xdb1e2564,0x60cd020c}},	//   _príb, هام_, _capó, rwam,
   {{0x2bb22594,0x6d41017b,0xdb1c01ec,0x59f90098}},	//   _जाता, şlad, gerä, _деня_,
   {{0xe0df0028,0x78a46b47,0x44236ef1,0x64418ffe}},	//   _trò_, briv, lij_, _skli,
   {{0x78a41621,0x660d6ef2,0xa3ae8105,0x20cd025b}},	//   criv, _mlak, _काश_, _uži_,
   {{0xe9df0174,0xb4ad81d2,0x44230e8b,0xce6b060a}},	//   _thús_, _कमी_, nij_, _град_,
   {{0x80db0592,0x660d003a,0xa3ae9a8f,0x394696fb}},	//   निवे, _olak, _कार_, _ayos_,
   {{0x44230069,0x2ca08267,0xdb1c041c,0x00e59da6}},	//   hij_, šida_, serç, джин,
   {{0x9f5e8013,0x81cf80ab,0x200e0084,0xdcfb80d7}},	//   chtú_, শাল_, škių_, _ارزش_,
   {{0x660d6ef3,0x22493be7,0xdb1e01df,0xb5fd8668}},	//   _alak, hlak_, _xapó, _kišo,
   {{0xe5a60dc8,0x6da618f6,0x660d5c47,0x60c48029}},	//   мини, мина, _blak, _ģime,
   {{0x3f9c826c,0x387feef4,0xb8050264,0x63ad8326}},	//   _edvu_, ppur_, োচিত_, ɗana,
   {{0x224902d5,0x44236ef5,0x21010110,0x2bb202f1}},	//   dlak_, fij_, nčią_, _जादा,
   {{0xb05b00f2,0x660d23e3,0x442301c8,0x9f580242}},	//   _spän, _elak, gij_, _forè_,
   {{0x81b480ab,0xbb430b69,0x3f85eef6,0xa3ae86ae}},	//   _ছোট_, верк, mblu_, कलत_,
   {{0x78a40012,0xa3e982b4,0x3cee835a,0xc332836b}},	//   triv, याँ_, _आपले_, דול_,
   {{0xa3ae9094,0x7e7c005c,0x442344fe,0x2bae816f}},	// [6680] _काल_, _strp, bij_, _घाला,
   {{0x44230db7,0xa5bb04c3,0x60048014,0x7d02804f}},	//   cij_, nión, _còmh, vyos,
   {{0x44441dea,0xb5fd8301,0x216a0652,0x22494068}},	//   _ik_, _višn, _мини_, blak_,
   {{0x78a4003b,0xe9d9809a,0xa3e60beb,0x7bc1eef7}},	//   priv, jdź_, फाक_, _ablu,
   {{0xa3e9c5d2,0x44446ef8,0x09bc80c8,0x6e229e73}},	//   यां_, _kk_, _অফলা, riob,
   {{0xfc3f062f,0x44446ef9,0x7d02b5bf,0x6aaae628}},	//   oría_, _jk_, ryos, tuff,
   {{0xb87b6efa,0x2bc00519,0x7e7c1b4e,0xa067572f}},	//   _tríc, श्या, _utrp, _цара_,
   {{0x4444363b,0x6aaa9c03,0x44232d0e,0x3f8e8b80}},	//   _lk_, ruff, zij_, _sefu_,
   {{0xb5fd8025,0x6aaae554,0x2d86eefb,0xfa1c027d}},	//   _mišl, suff, mboe_, _đất_,
   {{0x44446efc,0x22496efd,0x76444c22,0xa3e9eefe}},	//   _nk_, zlak_, _akiy, याः_,
   {{0xe8e08028,0x2fd85aae,0xf8ab0fea,0x7c3d81fa}},	//   _đổi_, _marg_, _चम्प, _ísra,
   {{0x44446eff,0xfc3f05b4,0x2fd83978,0xb5fd8279}},	//   _ak_, dría_, _larg_, _nišl,
   {{0x44236f00,0x7afa00f2,0xfc3f0333,0x224909ff}},	//   tij_, ättn, ería_, vlak_,
   {{0xa5bb4d67,0x3fd900ab,0x68e28019,0xfc3f0333}},	//   ción, _দক্ষ, _irod, fría_,
   {{0x44446f01,0x44232d0e,0xfc3f05e4,0x27ed001c}},	//   _dk_, rij_, gría_, _đen_,
   {{0x444426e6,0xb5fd826c,0x7bd70079,0xa3e58beb}},	//   _ek_, _rišo, _waxu, _बोन_,
   {{0xdb0502af,0xa3ae8744,0xfc3f0511,0x22496f02}},	// [6690] _schä, कला_, aría_, rlak_,
   {{0xfc3f05a4,0xb87b2d84,0x68e2ef03,0xb5fd811a}},	//   bría_, _cría, _mrod, _pišo,
   {{0x23d98af3,0xdb1c032b,0x2904951e,0x60048722}},	//   _योगद, terå, hyma_, _còmi,
   {{0x68e2d744,0x1cb98013,0xa01b1252,0x78a2027f}},	//   _orod, كاتب_, _stöd, šova,
   {{0x629aef04,0xe00e835a,0x2fd80314,0xdb0983fb}},	//   _avto, िसाद_, _farg_, čníc,
   {{0xa5bb04c3,0x44446f05,0xe9d9809a,0x2fd8627b}},	//   xión, _xk_, wdź_, _garg_,
   {{0x4429803a,0x7c23b8bc,0xbb429a1f,0xaad8001b}},	//   đa_, rinr, лешк, डिएक,
   {{0x68e2812b,0xe7d7d2c3,0x656d6f06,0x200eac77}},	//   _brod, _भोजप, _ngah, _alfi_,
   {{0xa5bb0118,0x61fd6f07,0x78ad6f08,0x44211997}},	//   tión, _mosl, nuav, _omh_,
   {{0x6445022c,0xb5fdb351,0x61fd1254,0x656d00b4}},	//   _nkhi, _mišm, _losl, _agah,
   {{0xf6260951,0x68e2bcc0,0x99918019,0x3f910102}},	//   едно, _erod, őző_, _mezu_,
   {{0x444435b6,0x644514ec,0xa5bb062f,0x61fd0029}},	//   _sk_, _akhi, sión, _nosl,
   {{0x8fa5bd2e,0x78ad1aef,0x657b8db1,0x68e2ef09}},	//   _зале, juav, _mfuh, _grod,
   {{0x7e698df1,0x69d9ef0a,0xfc3f05e4,0xb5fd817f}},	//   _liep, _hawe, tría_, _sišl,
   {{0x42560f13,0xa5bb2b49,0x69d9ef0b,0x48bf00ab}},	//   етат, gnós, _kawe, উটোর,
   {{0xe7ed85b3,0x7e69809a,0x78bb81e2,0x69dbd69d}},	//   जावा_, _niep, otuv, ndue,
   {{0x78bbef0c,0x98a30103,0x16c8140d,0x656d80e1}},	// [66a0] ntuv, лите, रब्ब, ľahl,
   {{0x7d060009,0x69d98114,0x657b819d,0x44440039}},	//   myks, _lawe, _afuh, _uk_,
   {{0xa3e988fd,0x39ea1927,0xb4e892ce,0x7bce03af}},	//   याई_, _едно_, यम्_, mebu,
   {{0x69d9ef0d,0x186a11d2,0x32090358,0x7bdc0c42}},	//   _nawe, _нами_, ckay_, ldru,
   {{0x7e6980c9,0x2fd806da,0x2d92395d,0xdb15016a}},	//   _diep, _targ_, _meye_, bezó,
   {{0x7bdc6f0e,0x6e260a0f,0x229a80eb,0x6298ef0f}},	//   ndru, hikb, tīk_, tsvo,
   {{0x68e28503,0x69d9e765,0xada6bba1,0xe805016f}},	//   _srod, _bawe, _павл, _शकता_,
   {{0x20bd8063,0xd25787ac,0x7bce6f10,0x6298844e}},	//   ्बंध, нцы_, hebu, rsvo,
   {{0x7bce6f11,0x600d88f1,0x24800069,0xe3b282e3}},	//   kebu, _súma, _ntim_, _مرا_,
   {{0x25a00886,0x61eba227,0x76428079,0x4c9b8039}},	//   _adil_, _engl, looy, _משמע,
   {{0x8f34879e,0x91e68a7c,0xddc78353,0x442109da}},	//   тенц, _поже, _hujš, _rmh_,
   {{0x7bdaef12,0xa5bb0207,0x68e29c6d,0x69d9ef13}},	//   _hatu, ciól, _trod, _gawe,
   {{0x7bdac77f,0x68e2809a,0x61fd6f14,0xb87b6f15}},	//   _katu, _urod, _rosl, _arín,
   {{0x7bda8057,0x25a0016a,0x7bce6f16,0x69d9ef17}},	//   _jatu, _edil_, gebu, _zawe,
   {{0x7bdaef18,0x8ff78bca,0x53340190,0x69d99fa4}},	//   _matu, _سرور_, герт, _yawe,
   {{0x7bdaef19,0x80ca00ab,0xfc3f0118,0x799648ce}},	//   _latu, রিন্, crín_, gayw,
   {{0x7e69ef1a,0x97a72312,0x32090079,0x9c390081}},	// [66b0] _riep, ерел, rkay_, _опит_,
   {{0x60db00d2,0x320906c0,0xc02e801c,0x442100b9}},	//   _šums, skay_, _điệu_, _umh_,
   {{0x7e69ef1b,0x4fc40110,0x2d92022e,0x69cd6f1c}},	//   _piep, ыста, _yeye_, peae,
   {{0xc8a91513,0x78bb8110,0x7bdaeb6e,0xa64782e3}},	//   _छटपट, ytuv, _aatu, رخان,
   {{0x7bda8559,0x3f910042,0x629a016b,0xddc08087}},	//   _batu, _tezu_, átov, _simţ,
   {{0x7bda8d6d,0x99dd801b,0x69d98077,0xfaa59a3d}},	//   _catu, plňk, _sawe, вако,
   {{0xf7718bca,0x629a070d,0x7e69b846,0x764281b4}},	//   یاد_, štov, _tiep, booy,
   {{0xb5fdef1d,0xf99f0247,0x7c2715e8,0x7bce009a}},	//   _mišk, _elèv_, hijr, zebu,
   {{0x69db811e,0x7bdaef1e,0x290b81ac,0x78bb97ae}},	//   rdue, _fatu, áca_, utuv,
   {{0xa2a98cce,0x7bdaef1f,0x78bb9482,0x69d980b8}},	//   _टिप्, _gatu, rtuv, _wawe,
   {{0x4427ef20,0x6443a591,0x78bb8b0c,0xb5fd8279}},	//   min_, moni, stuv, _nišk,
   {{0x644385e7,0x7d060364,0x442780ef,0x61ebef21}},	//   loni, tyks, lin_, _ungl,
   {{0x64438006,0xed57035f,0x44278ad0,0x51848329}},	//   ooni, кою_, oin_, _суха,
   {{0x4427ef22,0x6443ef23,0x8fa58bba,0xb87b6f24}},	//   nin_, noni, _раке, _prín,
   {{0x7bdc044e,0xb5fd8353,0xae1f102e,0x78a9b5ca}},	//   rdru, _višj, मोहन_, lrev,
   {{0x7bce04bf,0x6443ef25,0xb87b00f7,0x7ae5012b}},	//   sebu, honi, _crío, _drht,
   {{0x4427ef26,0xf992893f,0x41271927,0x6443a3f2}},	// [66c0] kin_, ירן_, вото_, koni,
   {{0x6443b086,0x4427ef27,0x6d5600b9,0xb87b01a8}},	//   joni, jin_, _izya, _trín,
   {{0x78a98a0f,0x76428079,0xb87b1f28,0xaad080c2}},	//   hrev, tooy, _frío, _थैंक,
   {{0xf53f0bbd,0x225f8748,0x6ea488af,0x78a9a86c}},	//   mgår_, jmuk_, _किसु, krev,
   {{0x4427ef28,0xa3ae8074,0x764281b4,0xcd7703de}},	//   fin_, कलल_, rooy, דענק_,
   {{0x625307fa,0x78a9a895,0xe1f98110,0xc44880d7}},	//   nçon, drev, ejų_, ریان_,
   {{0x3cee8063,0x224d808e,0xd25a89a0,0xf53f004a}},	//   _आपके_, flek_, мци_, ngår_,
   {{0x7bda822e,0x44278068,0xc3330158,0x76428079}},	//   _watu, ain_, יוו_, qooy,
   {{0x4427ef29,0xdfd08307,0xd83a8084,0x6443ef2a}},	//   bin_, مية_, дэн_, boni,
   {{0x44278a73,0xad1b8051,0x224def2b,0x212bef2c}},	//   cin_, _חומר, alek_, úcha_,
   {{0xa3c81513,0x645a8214,0x201980f1,0x224da1ba}},	//   ोजन_, _ihti, ësia_, blek_,
   {{0x78a98646,0xf53f006a,0xe7e28c28,0xd3788390}},	//   brev, dgår_, _कोरा_, _daće_,
   {{0x78a980a9,0x660085f5,0xf1b38039,0xd01ab07d}},	//   crev, _momk, _כסף_, _офк_,
   {{0xb5fda588,0x9f589931,0x3cf5816f,0xa3a404ae}},	//   _pišk, óró_, ्हते_, ијск,
   {{0x2bc49cfa,0xdb2307d9,0xb87b0013,0x442d003a}},	//   ल्या, _ürün, _prío, đe_,
   {{0x9f5c8a56,0x5a340cd0,0xb5fd80ce,0x6443bf3e}},	//   _nové_, анст, _višk, zoni,
   {{0x4427ef2d,0x2d996f2e,0x99555bc1,0x9f58046d}},	// [66d0] yin_, mase_, укац, _dorí_,
   {{0x4427ef2f,0x44273803,0x6d4d6f30,0x2bc48105}},	//   xin_, _ön_, _iyaa, ल्मा,
   {{0x4427ef31,0x6d4d008e,0x62670eca,0x2a6001c0}},	//   vin_, _hyaa, _لاحق, bmib_,
   {{0x6443ef32,0x4427b68b,0x2af2001b,0x6d4d0c2e}},	//   woni, win_, ीहरु_, _kyaa,
   {{0x2bc0053f,0x44278e79,0x61ef426a,0x62818267}},	//   श्वा, tin_, _incl, _stlo,
   {{0xe7e280c2,0x2d996f33,0x1c4485a8,0x4427ef34}},	//   _कोला_, hase_, анім, uin_,
   {{0x44278788,0x69dd6f35,0x6443b228,0x63b501a9}},	//   rin_, _kase, roni, igzn,
   {{0x4427a808,0x645aef36,0xe0d996cf,0xda13001b}},	//   sin_, _ehti, еви_, ठसित_,
   {{0x69dd6f37,0x44279b8e,0x224da25f,0x6d4d3536}},	//   _mase, pin_, rlek_, _nyaa,
   {{0x69dd6f38,0x4427c8ae,0x7d048364,0x224def39}},	//   _lase, qin_, äise, slek_,
   {{0x6d4d02a3,0x61ef5433,0x765b8028,0x63b8016d}},	//   _ayaa, _oncl, _khuy, _övni,
   {{0x69dd00fa,0x6d4105c5,0x7c250013,0xb87b01ac}},	//   _nase, ğlan, _amhr, _príl,
   {{0x6d410182,0xa0a58084,0xe8eeb631,0x10a5891e}},	//   şlan, _салд, _ул_, _силн,
   {{0x4425d990,0x61ef1726,0xb87b01ca,0x6d4d02c4}},	//   _jml_, _ancl, _crím, _dyaa,
   {{0x69dd4e8e,0xdceb81b9,0x2fc782c4,0x62533800}},	//   _base, bagħ, _ibng_, rçon,
   {{0xb5fb6f3a,0xceb28051,0x61fbef3b,0x7e6d336b}},	//   rmác, _היה_, njul, _giap,
   {{0x57ea0254,0x76460084,0x62530866,0x6d4d03f7}},	// [66e0] ндам_, moky, pçon, _gyaa,
   {{0x67160a14,0xb90c8032,0x61fbef3c,0x7649cf3d}},	//   льеф, _aimọ_, hjul, _akey,
   {{0x2c6f04b7,0x55e690ca,0x2ca0006a,0x7bde09da}},	//   _iżda_, ложб, _hvid_, _iapu,
   {{0x765b8142,0x442a6f3d,0x69dd6f3e,0x7bde6f3f}},	//   _chuy, lib_, _gase, _hapu,
   {{0x7bde55c8,0xa4268e02,0x7bc381ec,0x80d386a7}},	//   _kapu, лькл, ffnu, _बैले,
   {{0x442a6f40,0x69dd6f41,0x2d9904c3,0xf74615ac}},	//   nib_, _zase, zase_, _бего,
   {{0x7bde4371,0x68e412bd,0x0cb13420,0x69dd1167}},	//   _mapu, lvid, _जम्म, _yase,
   {{0x2d994e65,0x69c41f10,0x7bde5412,0x442a6f42}},	//   xase_, nfie, _lapu, hib_,
   {{0x68e451d1,0x442a6f43,0x48149bbf,0x13b6803d}},	//   nvid, kib_, имис, _مصاح,
   {{0x7e6d1a6e,0x442a6078,0xa3ae800f,0xd07381a8}},	//   _siap, jib_, _काट_, حديث,
   {{0x2d994b8d,0x6306b06f,0x6fc6035a,0x442a2c96}},	//   tase_, _حوال, र्यं, dib_,
   {{0x90e68f24,0xb5fd8805,0x7bde02d5,0x3f9a01bc}},	//   _مستن, _piši, _aapu, hapu_,
   {{0x2d996f44,0xa3e9835a,0x2ed11250,0x69dd17ab}},	//   rase_, याच_, _सन्त, _rase,
   {{0x68e40395,0x7bde6f45,0x2d99002a,0xb5fd8353}},	//   dvid, _capu, sase_, _viši,
   {{0x3a291a6e,0x2d991c77,0x7bde0057,0x179784de}},	//   tiap_, pase_, _dapu, _גדול_,
   {{0x69dd2e9c,0x59df27cf,0xb5fd8968,0x2bc48035}},	//   _qase, _पोखर, _tiši, ल्ता,
   {{0x442a6f46,0x69dd4bf2,0xaca3801c,0x290f24ec}},	// [66f0] bib_, _vase, _trứn, ága_,
   {{0xf1b9b899,0x69dd427a,0x3a2900dd,0x7bde00d7}},	//   riši_, _wase, siap_, _gapu,
   {{0xa3ae82f1,0x69dd6f47,0x76b9002e,0x09ac80ab}},	//   _काज_, _tase, тлер_, ক্যা,
   {{0x7bc8ef48,0x3ce90082,0xf1b9a847,0x64476f49}},	//   _abdu, _krav_, piši_, loji,
   {{0x798d4857,0x44258358,0x563800be,0x7ae381c0}},	//   mbaw, _pml_, נאדע_, wvnt,
   {{0x64470bb6,0x3ce900d2,0xb5fdad16,0xab298993}},	//   noji, _mrav_, _nišv, кола_,
   {{0x765b801c,0x3d958a7c,0x628508ae,0xf10d852a}},	//   _thuy, _вибр, _jtho, िन्द_,
   {{0x442a1086,0x64470010,0x0205a829,0x212b8187}},	//   zib_, hoji, рзин, úcho_,
   {{0x20030025,0x442a3c5a,0x3ce901c0,0x64476f4a}},	//   _koji_, yib_, _nrav_, koji,
   {{0x442a6f4b,0xb87b01ac,0x644700a4,0x600982de}},	//   xib_, _príj, joji, тном_,
   {{0xe7399927,0x64471d81,0x7bde3855,0x6285022c}},	//   тен_, doji, _rapu, _ntho,
   {{0x25e603dd,0x200303ac,0x6e2b846d,0x60168187}},	//   _जोशी_, _loji_, nigb, _câmb,
   {{0x7bde048c,0x32020efc,0x62856f4c,0x76464b41}},	//   _papu, _roky_, _atho, roky,
   {{0x78ad2a06,0x92d780ab,0x64475eca,0xd3788bda}},	//   drav, ামী_, goji, _kaća_,
   {{0x442a6f4d,0xeb97117e,0xe2970087,0x7bde18d5}},	//   rib_, рис_, иар_, _vapu,
   {{0x442a6f4e,0x660f11ee,0x224b008e,0x99dd816b}},	//   sib_, ckck, _ckck_, plňu,
   {{0x69c4212f,0x3ce928cd,0x2ca00052,0xa3d5e5a5}},	// [6700] rfie, _grav_, _uvid_, िजा_,
   {{0x8fa610f8,0x68e4186c,0x64476f4f,0x07a611b1}},	//   раже, rvid, coji, ражн,
   {{0x81cb0a49,0x6b9c0e56,0x23fb04de,0x799b876d}},	//   লয়_, marg, _ספטמ, kauw,
   {{0x3f9a6f50,0x38710088,0x68e408dc,0x1a9b03de}},	//   sapu_, _žorž_, pvid, _ביטע,
   {{0xf1b981dd,0x2ca080f7,0x78ad0ba3,0x59df0075}},	//   nišu_, éid_, crav, _पोटर,
   {{0x66e60698,0xdb1c0019,0x8aa6b0ed,0xfaa69ad3}},	//   _кога, kerü, арид, ашин,
   {{0xbea31c60,0x7c2aac15,0x28ac03eb,0xc7a32489}},	//   _марк, rifr, _चिडि, _фиск,
   {{0x6b9c085c,0x3f9802f7,0x4aa780d4,0xc4868ae7}},	//   harg, _heru_, _गिरव, _влак,
   {{0x6b9c1adb,0x6447004f,0x9a6781a8,0xc9148264}},	//   karg, yoji, جميل_, াপ্ত_,
   {{0x6016802e,0xf806a55e,0x66040362,0x3f980326}},	//   _sâmb, рчин, _aoik, _jeru_,
   {{0x08570051,0xd6d78278,0x6d41017b,0xb87b00e1}},	//   שבים_, атя_, ğlam, _prík,
   {{0x3ce90db7,0x47dc80ab,0x6d41017b,0xf1b98b80}},	//   _prav_, বাধী, şlam, fišu_,
   {{0x64476f51,0x0ca48035,0x6b9c6f52,0x66040f3e}},	//   toji, _ऑटोम, farg, _doik,
   {{0x224b008e,0x78a281a1,0x6b9c4c1b,0xddc401a1}},	//   _skck_, _ivov, garg, _viiš,
   {{0xda78001e,0xbebc8029,0xdb1c6f53,0x99dd826f}},	//   ият_, dzīg, deró, plňt,
   {{0x78ad6f54,0x52141cf4,0x200304b9,0x3ce92472}},	//   trav, одст, _soji_, _trav_,
   {{0x6b9c0876,0x798d1067,0x64476f55,0x443a00b9}},	// [6710] barg, rbaw, poji, _fjp_,
   {{0x6b9c1f9e,0x96da83bb,0x3ea706a5,0xb5fd816b}},	//   carg, _बनाउ, ánto_, _lišt,
   {{0xfc3f04c3,0x8ae4035f,0x62856f56,0x9f5803a8}},	//   buír_, _діял, _utho, _porá_,
   {{0xb5fd803a,0x7d0b816d,0x26c10176,0x09ac80ab}},	//   _ništ, tygs, rtho_, ক্তা,
   {{0x26c1010c,0xdb1c016a,0xd37880c3,0x2249011b}},	//   stho_, beró, _saća_, moak_,
   {{0xda78826f,0xb87b0118,0x7982826b,0x5fc603eb}},	//   _buď_, _asíg, _afow, र्दल,
   {{0x9f5c87f1,0x60cf09c4,0x9f580c1d,0x7a3e8ec3}},	//   _boví_, _hpcm, _torá_, zīte,
   {{0xe9d9a39c,0x7c28c5a7,0xb5fd817f,0x22490102}},	//   уки_, _emdr, _pišu, noak_,
   {{0x6e29ba87,0x600def57,0x2bc4816f,0x7bc70267}},	//   _imeb, _húmi, ल्हा, kfju,
   {{0x4394b306,0x764d5e54,0xaffe80ff,0x2d9db4e7}},	//   _маус, _akay, _phướ, lawe_,
   {{0x224900ad,0xb5fb0065,0x66040364,0x2eb68aec}},	//   koak_, rmán, _poik, _अमृत,
   {{0xf4090451,0x645e020f,0x6b9c003d,0xa01b18b6}},	//   _אפ_, _shpi, warg, _stöl,
   {{0x308580f7,0x66040198,0x443a008e,0x6e298135}},	//   _التف, _voik, _pjp_, _mmeb,
   {{0xf1b98da8,0xaffe801c,0x2d9d80b4,0x16040072}},	//   rišu_, _thướ, hawe_, _लवकर_,
   {{0xfc3f01df,0x2d9de8fe,0x6b9c6f58,0x22491fe7}},	//   tuír_, kawe_, rarg, foak_,
   {{0x3f98105a,0xf1b98042,0x6b9c16b5,0x22490102}},	//   _seru_, pišu_, sarg, goak_,
   {{0x51560991,0x1b2000ab,0x6b9c6f59,0xfc3f03a8}},	// [6720] ству, _মুখে_, parg, ruír_,
   {{0x3cfb04de,0x6e29ef5a,0x3a2d80ff,0xfc3f03a8}},	//   _עלינ, _ameb, hiep_, suír_,
   {{0x3f986f5b,0x3879026c,0x6d5bae58,0xe9ff80ff}},	//   _veru_, _eusr_, _azua, _ngắm_,
   {{0x7c2e6f5c,0xe5a38adb,0xceb28158,0xb05b2669}},	//   libr, зици, ליב_, _spät,
   {{0xdd998038,0x69d60214,0x6e3b8390,0xa5bb0825}},	//   _deň_, meye, _djub, miót,
   {{0x69cb8352,0x69d60214,0x61e46f5d,0x6e3bb065}},	//   _abge, leye, ldil, _ejub,
   {{0x8ae6804a,0x81e18264,0xb05b062c,0x8cda066f}},	//   сілл, দান_, _epäs, _पैसो,
   {{0x61e46f5e,0x69d66f5f,0x8f370833,0xb5fb01fa}},	//   ndil, neye, _האלו_, gmál,
   {{0xdb0502af,0xd90e815b,0x7c2e008e,0x79998197}},	//   _schü, عیت_, kibr, _deww,
   {{0x4734a523,0x765f0168,0x22490102,0xa2088380}},	//   жнос, _shqy, zoak_, ılış_,
   {{0x661d00f1,0x60c40406,0x601683a7,0x644aef60}},	//   ërko, htim, _câma, mofi,
   {{0x442edfe7,0x0f570039,0x63a8808e,0x6b9aef61}},	//   lif_, מיים_, _hddn, _hetg,
   {{0x60c400f1,0x61e46f62,0x7bd56f63,0xdb05010c}},	//   jtim, ddil, tezu, _idhé,
   {{0x4adc9d2a,0xdb0500f1,0x9f5e80f1,0x4e93803d}},	//   _मनाव, _udhë, njtë_, _کشور,
   {{0x3f9e8778,0x1dc8ef64,0x60c40110,0x6b9aef65}},	//   matu_, रभात, etim, _metg,
   {{0x53340991,0x3f9e811e,0x60c40168,0x644aef66}},	//   чест, latu_, ftim, hofi,
   {{0x60c46f67,0x625330e0,0x22490102,0x61e294f2}},	// [6730] gtim, nçoi, roak_, _maol,
   {{0x3f9eef68,0x24890748,0x61e2ef69,0x22490102}},	//   natu_, _itam_, _laol, soak_,
   {{0x7ac71e16,0xa3e21a42,0x442ecc3f,0x69d62c5a}},	//   _успе, _नोट_, dif_, beye,
   {{0x3f9ea084,0xdebb83c8,0x6aa1007b,0x3f8101e4}},	//   hatu_, רמאל, álfu, schu_,
   {{0x3f9e811e,0xcc340065,0x644a84b9,0x789302e3}},	//   katu_, _ذریع, fofi, _ریاض,
   {{0x2bc4800d,0xd7fb00a9,0xdb0500e7,0x644a8428}},	//   ल्ला, _сум_, _adhé, gofi,
   {{0x61e2ef6a,0xdc380158,0xb4d61e3c,0x3f9e811e}},	//   _baol, זאגט_, _सन्_, datu_,
   {{0x20c28125,0x6e29ef6b,0x61e28c41,0x80a9d7f5}},	//   fði_, _umeb, _caol, авив_,
   {{0x20c28125,0xb5fb0375,0x644aef6c,0x248901c0}},	//   gði_, rmál, bofi, _ntam_,
   {{0xbebc8029,0xd82580e8,0x3f9eef6d,0x764bacfe}},	//   dzīb, ідни, gatu_, logy,
   {{0x61e28f35,0x09c380c8,0xee3a1c64,0x02d987d2}},	//   _faol, ্যবা, ино_, _خواب_,
   {{0x92b4804e,0x61e281a8,0x69c912c6,0x3cedef6e}},	//   _رحما, _gaol, _हॉली, _krev_,
   {{0x8fa5975e,0x95561baf,0x3f9eef6f,0xdb0a8106}},	//   _дале, تخدا, batu_, uffö,
   {{0xf1bf0e1b,0xdb1c007b,0x3f9eef70,0x69c9844e}},	//   _acá_, ferð, catu_, lfee,
   {{0xdb1c0125,0xcb6a5a2f,0x69d60214,0xe7e29a8f}},	//   gerð, раве_, teye, _कोटा_,
   {{0x60c46f71,0x661d0865,0x20078102,0xe9da0dc7}},	//   ttim, chsk, _honi_, јка_,
   {{0x20078e80,0xd910026a,0xe8fa0721,0x69d66f72}},	// [6740] _koni_, ریس_, шла_, reye,
   {{0x2f5600ae,0xe29a0b30,0x998901ac,0x7afa0106}},	//   отес, _као_, vnať_, ätts,
   {{0x764baf31,0x20078198,0x69d603ec,0x25bf8362}},	//   fogy, _moni_, peye, _bcul_,
   {{0x2007b83f,0x60c46f73,0x3ced8370,0x3f9ee2d1}},	//   _loni_, ptim, _brev_, zatu_,
   {{0x973c8024,0x64a3974a,0x16b6825e,0x68e9c96c}},	//   maće, дача, _अम्ब, jved,
   {{0x973c8024,0x70d900be,0xdb1c007b,0xb87b00e1}},	//   laće, _פֿרו, rfræ, _prív,
   {{0x644aef74,0x61e2ef75,0x69c9dd7e,0x6b9a9c2b}},	//   rofi, _paol, ffee, _vetg,
   {{0x30a69631,0x9f5c8efc,0x3f9eef76,0x6b9a8cfa}},	//   оров, _nová_, watu_, _wetg,
   {{0x3f9eef77,0xdcf88065,0x644a804f,0xd7fabb78}},	//   tatu_, _دہشت_, pofi, аун_,
   {{0x20c287ca,0x2018c308,0xaaab0424,0x973c8bda}},	//   rði_, óri_, _छिलक, haće,
   {{0x3f9eef78,0x09ac80c8,0x8f7b012a,0xdb188006}},	//   ratu_, ক্ষা, יניק, tevõ,
   {{0x3f9eef79,0x7e7c32e6,0xdb1c007b,0x973c8b67}},	//   satu_, _murp, verð, jaće,
   {{0x3f9eb0aa,0x9ccb0196,0x973c8088,0x91368019}},	//   patu_, шына_, daće, _براؤ,
   {{0x224982a5,0x68fb0722,0x3ceb852a,0x7bd882f1}},	//   čake_, _àudi, चिते_, nevu,
   {{0x442c8915,0x799f0d92,0x5fb78039,0x764bb9d2}},	//   _mmd_, taqw, _והוא_, yogy,
   {{0x20078668,0x25a90102,0x973c812b,0xe1ff002a}},	//   _zoni_, _udal_, gaće, _riós_,
   {{0x7afa016d,0xa01b016d,0x64400018,0x442c8176}},	// [6750] ättr, _utök, émic, _omd_,
   {{0x6aa10125,0x478b0fbf,0x2007008b,0x7bd881d0}},	//   álfs, рсам_, ðni_, jevu,
   {{0x44310459,0x7bd8eb8e,0x80a703eb,0xb87b0580}},	//   miz_, devu, _चिके, _arít,
   {{0x3f9ca4ca,0xb87b026b,0x3cfd822c,0x27e30326}},	//   _levu_, _brít, txwv_, _wajn_,
   {{0x443eb3ae,0xb5fd8115,0xe0df0037,0xb4c902f1}},	//   _bjt_, _dišp, _usò_, _ईहो_,
   {{0x443138d1,0x7bd8ef7a,0x68e9ae91,0x69c98299}},	//   niz_, gevu, vved, wfee,
   {{0x4ea4321a,0x659581e2,0x60d9007e,0x7e7c0cdb}},	//   _орта, _наву, şamı, _gurp,
   {{0x2007b374,0xdce8809a,0x44310102,0xb87b008b}},	//   _soni_, _śląs, hiz_, _frít,
   {{0x44316f7b,0x69c9b1b0,0xe8f68fe6,0xb87b0032}},	//   kiz_, rfee, злы_, _irís,
   {{0x87259056,0x6e2d0dbb,0x799d2fa4,0x660980c9}},	//   змож, _amab, _lesw, _hoek,
   {{0x6c6a8117,0x661b83cf,0x44316f7c,0x660998c7}},	//   _اللہ_, _kluk, diz_, _koek,
   {{0x82378019,0x6609c80b,0x2a6901c0,0x3ebe004a}},	//   _برطا, _joek, jmab_, _åtte_,
   {{0x317a810f,0x973c8024,0x44316f7d,0xa3df816f}},	//   _האנד, vaće, fiz_, _तसा_,
   {{0x201eb2b9,0x44313006,0x6609a723,0x6e2d3e3e}},	//   chti_, giz_, _loek, _emab,
   {{0x661bef7e,0x6b630103,0xdce603bf,0xa3cd8c9a}},	//   _oluk, екра, rakı, ष्य_,
   {{0x3ce00282,0x78a46f7f,0x661b838a,0x15460225}},	//   _tsiv_, tsiv, _nluk, _нейм,
   {{0x973c8052,0x799d01ec,0x7e7c231e,0xfc3f11a9}},	// [6760] raće, _desw, _surp, grís_,
   {{0xa3cd83b7,0xddc9b46a,0x600d8ece,0x6d5604b9}},	//   ष्म_, _rieš, _túmu, _iyya,
   {{0x660990f4,0x224dcef4,0x973c812b,0x442c88f9}},	//   _boek, koek_, paće, _rmd_,
   {{0xddc9b481,0x25a20748,0x644e0f2a,0xb87b6f80}},	//   _pieš, nakl_, lobi, _prít,
   {{0x20170065,0x01c380ab,0xd90d21d7,0x224d8769}},	//   áció_, ্যাদ, _پیل_, doek_,
   {{0x7e7c6f81,0xddc981e2,0x61e60214,0x661b8074}},	//   _turp, _vieš, _hakl, _eluk,
   {{0x60120789,0x61e66f4a,0x661b8d23,0x290003a8}},	//   _næmi, _kakl, _fluk, lxia_,
   {{0xddc98029,0x2d8081ac,0x44316f82,0x644e03df}},	//   _tieš, žieb_, ziz_, hobi,
   {{0xdfd08307,0x76438065,0x61e66f83,0x44315984}},	//   نية_, énye, _makl, yiz_,
   {{0x66098586,0x251b810f,0x644e012b,0xe1ff001c}},	//   _zoek, _הומא, jobi, _khóc_,
   {{0x224dd4e9,0x644e23fa,0x6d560300,0x7e760122}},	//   boek_, dobi, _ayya, _biyp,
   {{0xa3cd8b3b,0xcb13893f,0xf27b8051,0x8afb8039}},	//   ष्ठ_, _אלע_, _הראש, _להבי,
   {{0x44316f84,0xa9c58077,0x2ca6820d,0x63bc8106}},	//   tiz_, _آزمو, nsod_, _örns,
   {{0x9a871d27,0x68e2b2ca,0x7e6416fb,0xb34723b4}},	//   зуал, _isod, _ehip, _naçõ,
   {{0x4431521d,0x25a23b76,0xdb1c03e6,0x268a81a8}},	//   riz_, bakl_, ngrè, _اختي_,
   {{0x44310182,0x6e2d6f85,0x61e60140,0x7f3b83de}},	//   siz_, _umab, _cakl, _לעוו,
   {{0x61e6003a,0x200a6f86,0x443101ca,0xb95b0032}},	// [6770] _dakl, _bobi_, piz_, _abìr,
   {{0x224d8a0f,0x6609ef87,0xdb1a9727,0x200a52ea}},	//   zoek_, _soek, _actí, _cobi_,
   {{0xb87b35d5,0x2ca90ae1,0x3ea70065,0x200a393a}},	//   _prís, _hvad_, ént_, _dobi_,
   {{0x3a203ba4,0x61e600b9,0x5d358019,0x9f4a041c}},	//   chip_, _gakl, وفائ, _robô_,
   {{0x629aed25,0xdb1c016d,0xe8eb01a8,0x200a033a}},	//   _awto, rfrå, _ارجو_, _fobi_,
   {{0x61e607dd,0xa3cd0beb,0xdb1c0711,0x76438061}},	//   _zakl, रभि_, sfrå, ényb,
   {{0x66098b3c,0x61e60214,0x6281026f,0x68e2ef88}},	//   _toek, _yakl, íloh, _asod,
   {{0x601f80e7,0xf99f0242,0x6e3d0bfd,0x201c862c}},	//   _même, _alèz_, jnsb, _alvi_,
   {{0x68e28019,0x6820016d,0x224def89,0x25adef8a}},	//   _csod, _född, roek_, _idel_,
   {{0x44318201,0x6e3d2651,0x224def8b,0xdb050118}},	//   _öz_, ensb, soek_, _adhí,
   {{0x63a3a09d,0x644e10d3,0xa3cd83dd,0x1f6580e8}},	//   mann, vobi, ष्ण_, ьком,
   {{0xd12e9125,0xcb128051,0x320b0035,0xf99f0176}},	//   امی_, _שלא_, _nocy_, _elèz_,
   {{0xfd59846d,0x61e9ef8c,0x63a38037,0x00000000}},	//   _agbẹ, mdel, oann, --,
   {{0xb4ce0df4,0x61e98370,0x61e66f8d,0xddcd0087}},	//   _रही_, ldel, _sakl, _piaţ,
   {{0x60c9ab11,0x69cd4c75,0x61e6658d,0x63a38359}},	//   ltem, ffae, _pakl, iann,
   {{0x27e787ca,0x2d9f8352,0x644e6f8e,0xddcd002e}},	//   _hann_, _neue_, sobi, _viaţ,
   {{0x27e7834a,0x63a39203,0x61e994d1,0x600a0fbf}},	// [6780] _kann_, kann, idel, онам_,
   {{0x60c98ca5,0xb87b01ac,0x63a3ef8f,0x61e98009}},	//   item, _prír, jann, hdel,
   {{0x63a3ef90,0xdb050352,0x7659831d,0x27e791e6}},	//   dann, _schö, flwy, _mann_,
   {{0x61e9ef91,0x6b670019,0x60c986c0,0xa3c80b6f}},	//   jdel, ségé, ktem, ोजक_,
   {{0x61e98422,0x3cfa8063,0x200a6f92,0x63a3ef93}},	//   ddel, ्हें_, _tobi_, fann,
   {{0x7bdc6f94,0xb5fb00f7,0x61e99254,0xb4de8074}},	//   neru, rmái, edel, _तनी_,
   {{0x59e20c28,0x61e9dcaf,0x2a7e9a83,0x25a000e7}},	//   _पसार, fdel, _qutb_, _oeil_,
   {{0xe1ff0028,0x7bdc6f95,0x31620282,0x63a3dc10}},	//   _khóa_, heru, _kzkz_, aann,
   {{0x63a3ef96,0x27e7ef97,0x301484fa,0xada38196}},	//   bann, _bann_, едпр, _шатл,
   {{0x2249803b,0x63a3a360,0x682046c0,0x7bdc1ffb}},	//   čaka_, cann, _föde, jeru,
   {{0x27e7834a,0x7bdc6f98,0x741380d5,0x80bd80c8}},	//   _dann_, deru, _جولا, ্টগ্,
   {{0xd378803a,0xa01b016d,0x200581c0,0x25a04e71}},	//   _naći_, _utöv, ajli_, _ceil_,
   {{0x60c982be,0xadc380ff,0xb87b4558,0x27e78e20}},	//   ctem, _hoản, _asín, _fann_,
   {{0x201980f1,0xe72f803d,0xe6300085,0x27e7e818}},	//   ësit_, اصی_, _təşə, _gann_,
   {{0x6adcdb64,0x450700c8,0x81e180ab,0x2a668282}},	//   _मनोर, _লেখক_, দার_, _khob_,
   {{0x63a3ef99,0x69c09c99,0x25a05d7e,0x68ed8140}},	//   zann, ngme, _geil_, _šadi,
   {{0x7bdc148e,0xee3f003e,0x30bc80c8,0x48bc80ab}},	// [6790] beru, mný_, _অনুস, _অনুর,
   {{0xee3f003e,0x61e99c5a,0x7bdc0efa,0x9c380198}},	//   lný_, zdel, ceru, _опыт_,
   {{0x61e9ef9a,0x68ed4631,0xb2751662,0x53350012}},	//   ydel, svad, _плош, _чент,
   {{0x7ae508cf,0xee3f003e,0x63a3985b,0x61e98144}},	//   _isht, nný_, wann, xdel,
   {{0x63a3ef9b,0x2ca98013,0x682000f2,0x24f98a41}},	//   tann, éad_, _söde, янды_,
   {{0xc7ce8104,0x6b65945a,0x660d08f2,0x200502f1}},	//   _sống_, нкла, _loak, _õli_,
   {{0xe7e585b3,0x27e7ef9c,0xee3f026f,0x7bc500b8}},	//   _कसबा_, _rann_, kný_, _mchu,
   {{0x63a3ef9b,0x60c985a7,0x2a66822c,0x27e7c814}},	//   sann, ttem, _chob_, _sann_,
   {{0xb4ce1499,0xee3f0775,0x61e987b3,0x2919cece}},	//   _रहे_, dný_, rdel, ása_,
   {{0x60c9ef52,0x24806f9d,0xddc981ac,0x7bc56f9e}},	//   rtem, _ruim_, _dieť, _nchu,
   {{0x69d00076,0x98ab87d9,0x27e7ef9f,0x24800090}},	//   ड्डी, ğlık_, _vann_, _suim_,
   {{0xfbc90051,0x27e781ec,0xc7ce8028,0x7bdc58c6}},	//   _לת_, _wann_, _uống_, weru,
   {{0x9f4788cf,0x27e786c0,0x7bdc6fa0,0x973c8052}},	//   _kanë_, _tann_, teru, raća,
   {{0x9f4788cf,0x25a00352,0x6281e2ae,0x33d5035f}},	//   _janë_, _weil_, _kulo, кіст,
   {{0x78a9809f,0xee3f0efc,0x25a06fa1,0x7bdc6fa2}},	//   lsev, bný_, _teil_, reru,
   {{0xb87b0038,0x62818365,0x798980a4,0x91e36fa3}},	//   _príp, _mulo, ncew, лосе,
   {{0x7ae508cf,0x39462379,0x6d410459,0x6e3b0039}},	// [67a0] _esht, ços_, şlar, _מתקד,
   {{0x57e748ac,0x78a9efa4,0x6564132e,0x7bdc03ed}},	//   ндум_, isev, _izih, qeru,
   {{0x28ac0aed,0x6e228234,0x44446fa5,0x2cbd81ed}},	//   _चिकि, thob, _ij_, euwd_,
   {{0x25a08307,0xa01b016d,0x2a790748,0xb87b57cb}},	//   úil_, _stöt, _gisb_, _tríp,
   {{0x22406fa6,0x98b880eb,0xb97b0039,0xb608816b}},	//   mnik_, ārī_, _מרכז, _nešť,
   {{0x2240391c,0x6e228578,0x6281b926,0xee3f016b}},	//   lnik_, shob, _bulo, zný_,
   {{0x2bd22441,0x6281a1df,0x6e2280f7,0x63a1efa7}},	//   द्या, _culo, phob, _deln,
   {{0xfce694d6,0x6281820d,0x63a18074,0x58d48e97}},	//   _побо, _dulo, _eeln, воит,
   {{0xee3f0efc,0xc05a81e2,0xdd8f8bbe,0xd7f080f7}},	//   vný_, зін_, _طول_, لكة_,
   {{0x764404b9,0x22403603,0x62818326,0x38678362}},	//   _ajiy, hnik_, _fulo, _chnr_,
   {{0xee3f003e,0xe297b1a9,0xdd950048,0x65952aa8}},	//   tný_, _зах_, каны, кану,
   {{0x444435b6,0x7bc56fa8,0x3946efa9,0x5fc70072}},	//   _aj_, _schu, _txos_, _लाभल,
   {{0xee3f027f,0x60168187,0xba2981a8,0x444400ed}},	//   rný_, _lâmi, _تسلم_, _bj_,
   {{0xee3f026f,0x7a2302f1,0x65640140,0x9be42183}},	//   sný_, _mõte, _dzih, ліск,
   {{0xee3f026f,0x2456007b,0x973c8289,0x81c500ab}},	//   pný_, væmt_, maćo, _এসব_,
   {{0x444403a6,0xb5fb2755,0xa75b81c6,0x9b58004a}},	//   _ej_, gmát, _מדור, хист_,
   {{0x200eafe3,0x9f5c81ac,0x26d8100a,0x3ebe804a}},	// [67b0] _kofi_, _novú_, _apro_, lutt_,
   {{0xb9090d86,0x7bc5022e,0x29070067,0x66199d31}},	//   _मन_, _uchu, ćna_, wkwk,
   {{0xf3ff8142,0x7ae5020f,0x22400353,0xdb0380f1}},	//   _đã_, _usht, bnik_, ranë,
   {{0x63a71024,0x2b0e001b,0x6281efaa,0xee38804a}},	//   lajn, ठहरु_, _rulo, ннє_,
   {{0xfce594d6,0x6281cbe4,0x61fd6fab,0x63a196b5}},	//   толо, _sulo, _insl, _peln,
   {{0xe3b384c0,0x62818ec9,0x29360158,0xd7208054}},	//   ارش_, _pulo, _יארן_, मनाथ_,
   {{0x81ea8a49,0x44335582,0x4421008e,0x60cd66b7}},	//   মান_, _mmx_, _mlh_, ltam,
   {{0x78a98406,0x32090e35,0x63a18299,0xdb1c22c9}},	//   tsev, njay_, _weln, rfrø,
   {{0xe3b39381,0x9f43001b,0x5c758a2e,0x60cd05d8}},	//   _مرض_, _mají_, _алат, ntam,
   {{0x6281efac,0x22403b00,0x78a98508,0x60cd1243}},	//   _tulo, znik_, rsev, itam,
   {{0x63a70165,0x444403a7,0xb5fb001b,0x61ed489b}},	//   dajn, _rj_, klád, kdal,
   {{0x60cd6fad,0x4421054e,0x61ed6fae,0x9f47efaf}},	//   ktam, _alh_, jdal, _jané_,
   {{0x61ed6fb0,0x442107d5,0xd3788b67,0xdb0384e8}},	//   ddal, _blh_, _daću_, dané,
   {{0x320f8986,0x22400063,0x63a70805,0x212900dd}},	//   _hogy_, wnik_, gajn, dzah_,
   {{0xe80505e8,0x03a31429,0xfe460087,0x44331867}},	//   राना_, рисо, _инко, _dmx_,
   {{0xc24312a0,0x61ed6611,0x61eb9d73,0xdb038661}},	//   анск, gdal, _jagl, gané,
   {{0x444402a5,0x61ebefb1,0x6d5b81e9,0x60cd13d2}},	// [67c0] _tj_, _magl, _nyua, gtam,
   {{0xa01b505b,0x22406fb2,0xb5fb2755,0x224d012b}},	//   _stör, snik_, smát, čeka_,
   {{0x36890071,0x22400988,0x3d65053d,0x6fd38035}},	//   есін_, pnik_, _لطیف, ब्यू,
   {{0x44385d13,0x61eb977c,0x7c21ac02,0x6820016d}},	//   lir_, _nagl, _allr, _döda,
   {{0x60cd05dc,0x44380013,0x7e7b885c,0x9f47816b}},	//   ctam, oir_, _diup, _dané_,
   {{0x44386fb3,0xa7da03f8,0x69c46fb4,0x93bc8162}},	//   nir_, _توسط_, lgie, _slăb,
   {{0x02a38a41,0xaa58bd00,0x61ebefb5,0x62349a20}},	//   арым, нику_, _bagl, леку,
   {{0xe3b2803d,0x261403a7,0x61ebc8fe,0xdbdf808b}},	//   _چرا_, _mãos_, _cagl, síðu,
   {{0xfce3825d,0x44386fb6,0x61ebefb7,0x48c280c8}},	//   _кото, kir_, _dagl, ্ট্র,
   {{0xd7f79006,0x61ed6fb8,0xb5fb0019,0x44385c04}},	//   вую_, zdal, ymás, jir_,
   {{0x44386fb9,0x81d78a49,0x61ed0182,0x61eb95f8}},	//   dir_, ায়_, ydal, _fagl,
   {{0x7c38a218,0x442100dd,0x61ebc11c,0x200e80fc}},	//   livr, _slh_, _gagl, _wofi_,
   {{0xdfd48071,0x67d48bda,0xdb03826f,0x9f4701ac}},	//   _болы, _болу, vané, ľné_,
   {{0x9f470a56,0x44382c9f,0x61e08214,0xdfd081a8}},	//   žné_, gir_, leml, _طيب_,
   {{0x2bd203eb,0xd8389024,0xfbd201d0,0x23d2097d}},	//   द्धा, mič_, द्धम, द्धद,
   {{0x60cd30b9,0x69c46fba,0x4438125b,0x63a70b80}},	//   ttam, ggie, air_, sajn,
   {{0x44386fbb,0x60c0a0e5,0xe7cf8bb8,0x61ed6fbc}},	// [67d0] bir_, numm, त्वप, rdal,
   {{0x4438040e,0xb5fb2ff3,0x2bd20bc2,0x661d0cab}},	//   cir_, slád, द्दा, lksk,
   {{0x60cd2c13,0x64556fbd,0xd371003d,0x12bd80ab}},	//   stam, mozi, _دهد_, _আন্দ,
   {{0x60cd002e,0x60c0e82c,0x69df0234,0x661d074d}},	//   ptam, kumm, qeqe, nksk,
   {{0xe8df0104,0x60c0efbe,0x91ba0039,0xa8a400a9}},	//   _thực_, jumm, _אמרי, _врск,
   {{0x61ebcac4,0xcb6992bc,0xbfb80077,0x60c0efbf}},	//   _sagl, нале_, _لطفا_, dumm,
   {{0x61ebaca0,0x7e7b9600,0x7bc3812b,0x2484808e}},	//   _pagl, _tiup, rgnu, _eumm_,
   {{0x44386fc0,0x62856fc1,0x93bc8087,0x3eda00be}},	//   zir_, _muho, _plăc, _אַמא,
   {{0x44380201,0x6012013c,0x645534e6,0xe1ff0028}},	//   yir_, _kæmp, kozi, _nhóm_,
   {{0x44386fc2,0x63a501ac,0xdb018b4c,0x61eba833}},	//   xir_, _nehn, _lelé, _wagl,
   {{0xe5a60e8e,0x61ebefc3,0x35a632d7,0x6da61878}},	//   лини, _tagl, ланг, лина,
   {{0x44386fc4,0xdb018036,0xe8f581a8,0x60c0efc5}},	//   wir_, _relè, _مستخ, bumm,
   {{0x44383236,0x518481e5,0x78ad0b67,0xd838a454}},	//   tir_, _туха, jsav, bič_,
   {{0x64556fc6,0x62852b78,0xd91a80be,0x201100ce}},	//   gozi, _buho, _רוסל, _nozi_,
   {{0x44386fc7,0x6443b476,0xdb018019,0xe6d20424}},	//   rir_, inni, _belé, _सहेज,
   {{0x44386fc8,0xe7cf835a,0x69c40029,0xdb019e4f}},	//   sir_, त्रप, ugie, _celé,
   {{0x6e2427c1,0x9f5c86c4,0x64553be0,0x78ad2dc2}},	// [67e0] _ilib, _anvè_, bozi, gsav,
   {{0xdb01efc9,0x225f9ade,0x69c40d35,0x2484852a}},	//   _telè, hluk_, sgie, _rumm_,
   {{0x225fefca,0x20116fcb,0x09b000ab,0xdb018019}},	//   kluk_, _dozi_, ঙ্গা, _felé,
   {{0xe1ff00f7,0x6443809a,0x175680be,0x52d700be}},	//   _gnó_, enni, אסער_, _גוטע_,
   {{0x7a3e81a9,0x7642efcc,0x649a8878,0x9f5807b6}},	//   nūte, rnoy, хтер_, _poró_,
   {{0x6e2407e2,0x26c1569b,0x2a606fcd,0x998defce}},	//   _llib, buho_, llib_, vieš_,
   {{0xd838efcf,0x81e700ab,0x6e246fd0,0xa5bb0c83}},	//   vič_, পার_, _olib, rióz,
   {{0x611a00eb,0x64438717,0x521481cf,0x7afa0198}},	//   _tālā, anni, рдит, ätty,
   {{0x61e0895e,0x02e1101c,0x463b8158,0x68ed826c}},	//   reml, _पन्न, _נעמע, _šadr,
   {{0x6e246fd1,0x60c0b17d,0x6a65efd2,0x61e0b4e6}},	//   _alib, rumm, rófa, seml,
   {{0x60c0a88c,0xb33c84b7,0x645aefd3,0xd838bed2}},	//   summ, _ieħo, _ikti, rič_,
   {{0xd10402a8,0x10a682df,0x98a680a9,0x6e2400f7}},	//   रमाण_, _бидн, _биде, _clib,
   {{0x62850988,0x661d2b11,0x81ea8264,0xd838877b}},	//   _suho, rksk, মাদ_, pič_,
   {{0x6e2455a7,0x6285050b,0xa2ab8072,0x6298890d}},	//   _elib, _puho, ींच्, opvo,
   {{0x443f0025,0x501b84de,0xfe70053d,0x656f9e51}},	//   đu_, _אוגו, تدی_, _úchv,
   {{0x3ce901c5,0x973c8754,0x78ad6fd4,0x64556fd5}},	//   _tsav_, haćk, tsav, sozi,
   {{0xbf1d03b7,0x645511ec,0x6443efd6,0x20116fd7}},	// [67f0] पन्न_, pozi, ynni, _pozi_,
   {{0x201ea985,0x62856fd8,0x27ee808b,0x225fefd9}},	//   nkti_, _tuho, _jafn_, zluk_,
   {{0xdb01840e,0x78ad52ed,0xb87b6935,0xd6db0e11}},	//   _telé, ssav, _kríz, эта_,
   {{0x7afa013c,0x6448b11a,0xeef784de,0x51840088}},	//   ætte, _ajdi, טמבר_, _гура,
   {{0xfaf88db5,0x2bd20bb3,0x225f80d2,0x7e6d1f8d}},	//   _arī_, द्वा, vluk_, _mhap,
   {{0x7bc7008b,0x27ee807b,0x3dc981b9,0x6443862c}},	//   ngju, _nafn_, żaw_, unni,
   {{0xdb1c12ca,0xa3498098,0x1b498098,0x44fd0264}},	//   ográ, ъзка_, ъзки_, ুনিক_,
   {{0xe1ff8333,0x4b3801c6,0x61ef10ba,0xdb1c6776}},	//   ñó_, טרול_, _jacl, ngrá,
   {{0x61ef6fda,0x2d9da5d3,0xdb038333,0xd9458c40}},	//   _macl, mbwe_, maní, репи,
   {{0xaaae816f,0x7e6d0135,0x66db8009,0x1bab8019}},	//   _टिचक, _ahap, _näkö, _سائٹ_,
   {{0x43848013,0xbb8480f7,0xb87b3c40,0x4e198d86}},	//   _المق, _المي, _epíg, _दवाई_,
   {{0x7e6d254b,0x1c038beb,0x6a658333,0xdddc9c50}},	//   _chap, लावल_, mófo, _kurš,
   {{0xe0c000c8,0x59678081,0x7e6d003d,0x98b88162}},	//   _উন্ন, _съжа, _dhap, ără_,
   {{0x7bc7008b,0xe7878c0e,0x6d5f0168,0x557683de}},	//   ggju, _судо, _dyqa, יערן_,
   {{0xfaa60396,0x765ba1e4,0x4425efdb,0x26c7023e}},	//   рабо, _okuy, _mll_, ànol_,
   {{0xc48605c2,0xceb8809a,0x2fd800b9,0x61ef0362}},	//   _клик, rzęt_, _sbrg_, _cacl,

   {{0xfce60e6b,0xddc980eb,0x2d8080e1,0xdb03bdff}},	// [6800] _топо, _biež, žiek_, daní,
   {{0x442581c0,0x7a230074,0xb5fb016b,0x2c7c0032}},	//   _nll_, _võta, plác, _dádì_,
   {{0x0d869d38,0x3bbb0039,0x61ef0014,0x69d982ec}},	//   ален, _במיד, _facl, _obwe,
   {{0x4425804c,0x9f5c83cb,0x3a290a0f,0x2bd201cb}},	//   _all_, _nový_, chap_, द्रा,
   {{0x61e46fdc,0x9d2480ab,0xdb0a948c,0x261787b6}},	//   meil, বপ্ন_, ngfö, _aços_,
   {{0x18a30972,0x7c3c00dd,0x65698267,0x69d981ec}},	//   _фарм, nirr, _dzeh, _abwe,
   {{0x7f436fdd,0x442580dd,0xdb03c530,0x7aed8035}},	//   _держ, _dll_, baní, łatn,
   {{0x4425809f,0x78a28247,0xb95b026b,0x61e40009}},	//   _ell_, _pwov, _abìy, neil,
   {{0x973c803b,0x2d8482c4,0x9f47816b,0x2aac826b}},	//   maći, _igme_, _daní_, _bóbá_,
   {{0x61e46fde,0x92d580c8,0x201e989e,0x973c811f}},	//   heil, িয়ে_, ukti_, laći,
   {{0x61e40009,0x442a00f7,0x7bda81c0,0x09e695e0}},	//   keil, dhb_, _ibtu, _воен,
   {{0x443ca0b3,0x7e62a720,0xd5e4027d,0xdb18be43}},	//   liv_, nlop, _phí, rgvä,
   {{0xb8948307,0x40948307,0x61e46fdf,0x60c41148}},	//   _التع, _التر, deil, juim,
   {{0x645881dd,0x6288ae5d,0xbebc8029,0xb4d71199}},	//   novi, _kudo, dzīv, _सही_,
   {{0xf1a70be2,0x63a893cf,0xdb1a85e4,0x61e40114}},	//   иран, _medn, _actú, feil,
   {{0x7e6d2997,0x443cefe0,0x63a89602,0x6288efe1}},	//   _uhap, hiv_, _ledn, _mudo,
   {{0x64588289,0x60c42db0,0x443cc076,0x7bdabf85}},	// [6810] kovi, guim, kiv_, _obtu,
   {{0x9f47001b,0x6e3d6fe2,0x6458bc59,0x7e6281ed}},	//   žní_, lisb, jovi, elop,
   {{0xa18707ac,0x6447003b,0x248901c5,0xcfe180ab}},	//   _выгл, mnji, _huam_, বাচন,
   {{0x24894290,0xd2468a47,0xdb050019,0x068410ac}},	//   _kuam_, _رن_, _nehé, ігін,
   {{0x9ce7a678,0x7afa82d0,0x65608114,0x63a8efe3}},	//   рцел, _artt, _cymh, _bedn,
   {{0x6288efe4,0xdb03baa8,0xb4e78740,0x24890069}},	//   _budo, saní, _बनी_, _muam_,
   {{0x248901e9,0x6013001b,0x200304b9,0x99848084}},	//   _luam_, _výmě, _inji_, jimų_,
   {{0xa2d88076,0x09f980f7,0x765b8234,0xddc4007a}},	//   _महर्, افظة_, _ukuy, _ohiš,
   {{0x6458825b,0x7659809a,0x248901c0,0x2baa150e}},	//   bovi, mowy, _nuam_, करमा,
   {{0x6458a912,0x998d81ac,0x4425dd46,0x6447011f}},	//   covi, dieť_, _ull_, jnji,
   {{0x628882a3,0xdb050019,0x62970069,0x26d3011b}},	//   _gudo, _fehé, _ntxo, ntxo_,
   {{0x81b180c8,0x08f9826a,0xddc9a3b3,0xb87b0118}},	//   ঞ্জ_, _مرتب_, _nież, _eríx,
   {{0x61e46fe5,0x248901c5,0xee370c5c,0xd7c70424}},	//   veil, _cuam_, сня_, _लांच,
   {{0x61e402af,0x24890168,0x64470b80,0x68e99e59}},	//   weil, _duam_, gnji, mwed,
   {{0xff5391fb,0x81ea80c8,0x4e958bbe,0x61e46fe6}},	//   _بخش_, মার_, _اشتر, teil,
   {{0xbb431ba8,0x645880d2,0x69c9d030,0x26c5efe7}},	//   ческ, zovi, ngee, mulo_,
   {{0xe8fa01bb,0x61e46fe8,0x7e628247,0xf653007c}},	// [6820] ыла_, reil, vlop, _מצה_,
   {{0x443c81e9,0x61e4386d,0x60c46762,0xf20986a7}},	//   xiv_, seil, ruim, वाड़_,
   {{0x63a8cd10,0x645880d2,0xd00f1e09,0x443cefe9}},	//   _redn, vovi, علم_, viv_,
   {{0x63a8efea,0x452aa34e,0xa5bb00f7,0x601683a7}},	//   _sedn, лжен_, thói, _lâmp,
   {{0x27e59f4d,0x98a0009a,0x7e629412,0x973c9487}},	//   keln_, dzić_, rlop, raći,
   {{0x26c59fa2,0x9cd70039,0x69c98079,0x68e9d2c1}},	//   kulo_, מונה_, egee, dwed,
   {{0x443c8082,0x8bf200c8,0x63a88db7,0x66042e5d}},	//   riv_, ঞাপন_, _vedn, _onik,
   {{0xae0c81fe,0x4c868dbd,0x443c96eb,0xe45f5619}},	//   _सचिन_, _глав, siv_, ntör_,
   {{0x6458803b,0x0f2081fe,0xdca39dc4,0x63a88353}},	//   povi, मन्स_, _нати, _tedn,
   {{0x6288efeb,0x24890069,0x27e5aa93,0x660448d5}},	//   _tudo, _ruam_, geln_, _anik,
   {{0x81043420,0xe45f5619,0x24896fec,0x66166fed}},	//   रमुख_, ktör_, _suam_, _boyk,
   {{0x24890069,0xde590b73,0x99848110,0xe1ff00ff}},	//   _puam_, рамі_, rimų_, _thói_,
   {{0x6e3d24d0,0x27e592d2,0x64470253,0xb8d3803d}},	//   risb, beln_, tnji, _فتوش,
   {{0x66046fee,0x26c5efef,0x24890069,0x7d1d2176}},	//   _enik, bulo_, _vuam_, ryss,
   {{0x752f0d38,0x26c59f9e,0xa3cd8c78,0x629c2b4c}},	//   szcz, culo_, ष्ट_, gpro,
   {{0x248901c5,0x6447007d,0x999926e8,0x6e4400a9}},	//   _tuam_, snji, ркат_, _нејз,
   {{0x301512b2,0x63ae010b,0x7c3aa3f9,0xb4e78fcc}},	// [6830] одар, babn, _omtr, _बने_,
   {{0x656d4d7c,0x2cb4001b,0xdced00fe,0x2baa0072}},	//   _izah, řadí_, _ugađ, करणा,
   {{0xdb019f9e,0x7659809a,0xb87b1727,0x4f6b16dd}},	//   _pelí, towy, _apíc, ушам_,
   {{0xe3b88182,0x3e7b01e2,0x9f4a0122,0x68e98114}},	//   _adı_, _būti_, _babâ_, ywed,
   {{0xa509a6c8,0x63858251,0x7659809a,0x22490061}},	//   рела_, огла, rowy, mnak_,
   {{0x22490019,0x973c9487,0x27e585ec,0x2a6f808e}},	//   lnak_, laću, xeln_, _shgb_,
   {{0x8c1c294d,0x6d4103bf,0xdb07001b,0x2bdb6ff0}},	//   רווי, ğlay, kají, म्या,
   {{0x6d411010,0x7c28a4f1,0x22490065,0x3ced81e9}},	//   şlay, _eldr, nnak_, _tsev_,
   {{0x69c9c897,0xb5fb02b7,0x224926f7,0x26c5b364}},	//   rgee, tlán, inak_, wulo_,
   {{0x6e298904,0x764d6ff1,0x225d9142,0x68e98e8a}},	//   _hleb, _ajay, _wkwk_, rwed,
   {{0x22490065,0x6e29eff2,0x656d6ff3,0x9b58846e}},	//   knak_, _kleb, _azah, _лифт_,
   {{0x443a0e60,0xb5fb6ff4,0x63ae010b,0xceb203c8}},	//   _smp_, slán, wabn, ויט_,
   {{0x22492a8e,0x63ae0239,0x2eee826c,0xf1bf026f}},	//   dnak_, tabn, _esff_, _plán_,
   {{0x26c5eff5,0xaadd8af3,0x656d3cba,0x02dd8aed}},	//   pulo_, _महाक, _dzah, _महाभ,
   {{0x63ae2588,0x366a0fbb,0x6e3b82ec,0x656d01f6}},	//   rabn, _како_, _omub, _ezah,
   {{0x443a1b1d,0x9fa3007b,0x3a3f8359,0x22490019}},	//   _wmp_, _síðu_, niup_, gnak_,
   {{0x1005000d,0x6440063e,0xe7aa0b5b,0x7bdc807b}},	// [6840] रांश_, émis, ивал_, _örug,
   {{0x6e29b5d5,0x629c04b7,0x69cf0098,0x443a6ff6}},	//   _aleb, ppro, _ecce, _ump_,
   {{0x46ea1092,0x06ea0087,0x9f510176,0x1c0386ae}},	//   рден_, рмек_, _jazè_, लाईल_,
   {{0x05668193,0xcbc680ab,0x645c231e,0xd49abedc}},	//   овен, _এসেছ, lori, арк_,
   {{0xe8f7117c,0x6e229142,0x6ec08c28,0x9f4700e1}},	//   _для_, rkob, _विभु, ľná_,
   {{0x9f47003e,0x6e29be39,0x628300e7,0x7c83aaf7}},	//   žná_, _eleb, _énor, муще,
   {{0xa3dc0fce,0xb4c70424,0x60d60a14,0xdb03eff7}},	//   ण्य_, _उम्_, ltym, taná,
   {{0x201800ad,0x645c6ff8,0xa2cb0576,0xb33c8372}},	//   _hori_, hori, तंत्, _jeħi,
   {{0xdb03b87a,0xfdee0035,0x60d6505e,0xdb0701d0}},	//   raná, ज़नस_, ntym, vají,
   {{0x22490019,0xd01a917e,0x60d60084,0x4734afc0}},	//   znak_, рфи_, itym, знос,
   {{0x645c380f,0x20186ff9,0x224913f4,0xe297ace0}},	//   dori, _mori_, ynak_, _дах_,
   {{0x2018077f,0x46db83eb,0x629aeffa,0x65640314}},	//   _lori_, _बहरह, _itto, _byih,
   {{0x61f60428,0x65640a03,0x20a90054,0x938b047f}},	//   ddyl, _cyih, _चौंध, исва_,
   {{0x20186ffb,0x9faf080a,0x7a230074,0x9f34a183}},	//   _nori_, _işçi_, _võtm, _нелі,
   {{0x22490019,0xb024801c,0x644a81a8,0x973c8267}},	//   tnak_, _giườ, infi, taću,
   {{0x786f8aa2,0x224002d5,0x2abb8e82,0xddeb00d7}},	//   røve, giik_, ימלא, _ضربه_,
   {{0x20186ffc,0x765d1ae0,0x69dd2362,0x224912de}},	// [6850] _bori_, mosy, _vbse, rnak_,
   {{0x629a8698,0x22491403,0xe6168353,0x68e2826c}},	//   _otto, snak_, _čišč, _mpod,
   {{0x98ac00eb,0x20186ffd,0x2ca90326,0x199502a9}},	//   ālās_, _dori_, _hwad_, _наня,
   {{0xdb03da08,0x69cf047f,0x765d074d,0x2ca90326}},	//   lanç, _ucce, nosy, _kwad_,
   {{0x629ad268,0xeb999300,0x64a5976e,0x2018047f}},	//   _atto, бил_, чала, _fori_,
   {{0x9f4301ac,0xdb0391dd,0x3e72026f,0x320682c4}},	//   _majú_, nanç, máte_, _anoy_,
   {{0x68e2957a,0x68ed600e,0x765d6ffe,0x3a3f90e1}},	//   _apod, lwad, kosy, tiup_,
   {{0x6e3b82a0,0x69cd6fff,0x290d8102,0x68e28f35}},	//   _umub, ngae, txea_, _bpod,
   {{0xa3dc0bb8,0x645c7000,0x629a9793,0x20187001}},	//   ण्ड_, yori, _etto, _yori_,
   {{0x25ad9afa,0xe8df0028,0x645c7002,0xb87b0061}},	//   _heel_, _chức_, xori, _zsír,
   {{0xf1cb04e5,0x961d8029,0xdb0383a7,0x25ad9316}},	//   िलान, _ziņa, danç, _keel_,
   {{0xfe72045b,0xfce6035f,0x765d1066,0x68ed7003}},	//   عدد_, помо, gosy, kwad,
   {{0x2bd2885d,0x645c0888,0xc1048013,0x25ad82a3}},	//   _सामा, tori, _يومي, _meel_,
   {{0xa09a9bb3,0x5fc7035a,0x3e72026f,0xa7fc8059}},	//   _היסט, _लागल, dáte_, nlıl,
   {{0x2007f004,0x2018130c,0x765d076d,0x645c00ef}},	//   _inni_, _rori_, bosy, rori,
   {{0x645c7005,0x1dc6035a,0x20187006,0x3e7b0029}},	//   sori, _वाटत, _sori_, _būtu_,
   {{0x2018632b,0x2edb9051,0xdd9982d6,0x22407007}},	// [6860] _pori_, _बहुत, _enňk_, riik_,
   {{0x645c0085,0xdb0383a7,0x61e9a8a9,0x60d67008}},	//   qori, canç, heel, rtym,
   {{0x60d60fe6,0x9f4a5084,0x61e9eb92,0xdb0e010c}},	//   stym, _babá_, keel, kabé,
   {{0xd6cf1a3e,0x6820016d,0xdd8f99ed,0x25ad81b4}},	//   طقه_, _nödv, هوم_, _ceel_,
   {{0x25ad90f4,0x61e9838e,0xd5af8154,0x68ed4038}},	//   _deel_, deel, افه_, cwad,
   {{0x7bce7009,0x961d8029,0x02a6b631,0x7bdc0087}},	//   ngbu, _viņa, прим, nfru,
   {{0x68e286b9,0x66e335d9,0x6286700a,0x61e981bc}},	//   _spod, _пора, _kiko, feel,
   {{0x20078698,0xa9c3835f,0x8cc485fb,0x25adf00b}},	//   _anni_, нськ, _रिपो, _geel_,
   {{0x6286700c,0x60c9baef,0x1dc6016f,0x248590b6}},	//   _miko, guem, _वाजत, _film_,
   {{0x60c40013,0x2018807b,0x2cb7801b,0x6b669fe8}},	//   irim, ðri_, ředí_, _екза,
   {{0xfaa395e3,0x61e9b1e9,0x443e842b,0xe1ff00f7}},	//   _захо, beel, _imt_, _mhór_,
   {{0x60c4700d,0x61e9ac6a,0x7c3e2449,0x998206c4}},	//   krim, ceel, _ampr, _ankō_,
   {{0xe8df0028,0xdb0502ba,0x5c070ba7,0xdb0387d0}},	//   _thức_, _vehí, пява, tanç,
   {{0x3cef8105,0x68fb03a7,0x62860009,0x60c44333}},	//   _इनसे_, _áudi, _aiko, drim,
   {{0x7e8683bb,0xdb03f00e,0x62864afb,0x60c40006}},	//   íspě, ranç, _biko, erim,
   {{0x6286700f,0x7d009581,0x3f98274a,0xb87b026b}},	//   _ciko, _orms, _afru_, _asíp,
   {{0x628629fb,0xa6ae80ab,0x60c47010,0x442c8039}},	// [6870] _diko, _কমিট, grim, _old_,
   {{0x44ef5f29,0xd7f8802e,0x68ed7011,0xb87b535a}},	//   _iż_, ndă_, rwad, _epín,
   {{0x6e2d3b4a,0x6a65a755,0x62867012,0x9f45801b}},	//   _klab, sófi, _fiko, telé_,
   {{0x1dad0e18,0x62867013,0x3f8a0135,0xd77412c8}},	//   चरित, _giko, _egbu_, رالع,
   {{0x25ad80bd,0x248d80a9,0x442cbd70,0x61e99eb6}},	//   _veel_, _quem_, _bld_, veel,
   {{0x61e9f014,0x2a693d06,0xb95b0032,0x6f010187}},	//   weel, llab_, _adìg, _álco,
   {{0xe3b08d4a,0x6e2d7015,0x61e9f016,0x25adf017}},	//   اره_, _olab, teel, _teel_,
   {{0x09e080c8,0x02dd901c,0x3ede8870,0x442c90cc}},	//   _মোবা, _महीन, _chọọ_, _eld_,
   {{0x4900000d,0x61e9f018,0xdb0e0548,0xf1bf026b}},	//   रियो_, reel, rabé, _alák_,
   {{0xb8d59499,0xa5bb0125,0x8afc809a,0x386300ee}},	//   _जब_, skól, _częs, _jkjr_,
   {{0x6e2d7019,0x2a69701a,0xe0200105,0x661bf01b}},	//   _blab, klab_, _मकसद_, _kouk,
   {{0x1b168a49,0x6443f01c,0x661b8009,0x4427836e}},	//   _থেকে_, lini, _jouk, lkn_,
   {{0x6286701d,0x60c9a7c4,0xb4bb86a7,0x64438090}},	//   _riko, quem, _आटो_, oini,
   {{0x7afc003b,0x6443f01e,0x6286701f,0x224d8019}},	//   tvrt, nini, _siko, lnek_,
   {{0xa3df89c2,0xe2970071,0x62867020,0x660983df}},	//   ध्य_, дас_, _piko, _onek,
   {{0x7bdc1986,0x2a6901c0,0x224d8019,0xe1f98110}},	//   sfru, glab_, nnek_, ndų_,
   {{0x6443f021,0xd94310bf,0x2bdb2f52,0x614311a8}},	// [6880] kini, вети, म्हा, вета,
   {{0x6443c9c5,0x6609aad0,0x2bd28526,0x60c47022}},	//   jini, _anek, _साधा, rrim,
   {{0x6443f023,0x224d8065,0x2a697024,0x62867025}},	//   dini, knek_, blab_, _tiko,
   {{0x81e280c8,0xf54f082e,0xb33c84b7,0x7afc818a}},	//   _ফোন_, pụta_, _meħt, _árti,
   {{0xdb0aa564,0xa7fc83bf,0x05b606a7,0x224d8061}},	//   rafí, rmız, _अजनब, dnek_,
   {{0x6443ea71,0xdb0a85e4,0xe3b8880a,0x442780dd}},	//   gini, safí, _alır_, gkn_,
   {{0xbddb009f,0x644e0d35,0x7e6406c0,0xb5fb6ed8}},	//   dièn, inbi, _okip, noác,
   {{0xf2d3004c,0x26d8008e,0xaca40091,0x7d00808e}},	//   דעה_, _iqro_, _afọw, _trms,
   {{0x64439fd9,0x961d8029,0x442780ee,0xdfd081a8}},	//   bini, _ziņo, bkn_, هية_,
   {{0xdb0192d2,0x629e003b,0x3f14ac18,0x29020088}},	//   _belä, _otpo, едос, _mrka_,
   {{0x3eb88117,0x6e2d08f9,0xd7f88162,0xb5fb01a8}},	//   ért_, _plab, rdă_, llái,
   {{0x26c7005c,0xa5f90009,0x644e7026,0x290257a5}},	//   šnog_, чему_, enbi, _orka_,
   {{0x26c5f027,0xdb088207,0xdd318085,0xa7fc82d0}},	//   arlo_, _medí, _məşh, nlık,
   {{0xe94789a7,0xbddb0722,0x7a3100e8,0x69d58061}},	//   _ترمی, cièn, _måte, őzet,
   {{0x7a313c37,0x98a38110,0x29023156,0xe7f3816f}},	//   _låte, ąją_, _arka_, _असता_,
   {{0x6443b987,0x290208ae,0x90990098,0x3e5600eb}},	//   zini, _brka_, зват_, tāte_,
   {{0x64438850,0x26ccaae0,0x61e2e0f1,0x27f8416f}},	// [6890] yini, ludo_, _mbol, _barn_,
   {{0xe3c600c8,0x661bf028,0x224d8019,0x27f87029}},	//   শ্বব, _souk, znek_, _carn_,
   {{0x6443f02a,0x661bf02b,0x61e284c4,0x201c8144}},	//   vini, _pouk, _obol, _movi_,
   {{0x63b50289,0x290202a5,0x2bdb0aed,0x6443f02c}},	//   lazn, _frka_, म्रा, wini,
   {{0x6443f02d,0xeb998e8e,0x290200d2,0xdb088bd3}},	//   tini, пил_, _grka_, _dedí,
   {{0x201c8289,0x36d50391,0x6820016d,0x7640df2f}},	//   _novi_, _погр, _döds, _emmy,
   {{0x6443b7d0,0x224d8019,0x4427836e,0x661b8009}},	//   rini, tnek_, rkn_, _touk,
   {{0x6443f02e,0x442780ee,0x6609b131,0x999f81d6}},	//   sini, skn_, _unek, knuť_,
   {{0x63b5003e,0xa3c10076,0x6443f02f,0x25bfb5e4}},	//   kazn, ुला_, pini, _idul_,
   {{0x7e642461,0x61ed0083,0x63b506b9,0x6443829b}},	//   _skip, heal, jazn, qini,
   {{0xfe460cb1,0xbddb009f,0x366a02a4,0x201c8267}},	//   енно, rièn, зано_, _dovi_,
   {{0xed5a1594,0x6ec086bf,0x60cd004f,0xd5ed0129}},	//   зом_, _विरु, kuam, _phá,
   {{0x61ed68a7,0x61fb8057,0x63b50968,0x2d8403ca}},	//   deal, mdul, fazn, äme_,
   {{0x09ba035a,0x61f9ba08,0x60dbd562,0x68320366}},	//   ेल्य, _hawl, mtum, _kæde,
   {{0x80c20076,0x26cc8207,0x91e61d20,0x60dbf030}},	//   _लिहे, cudo_, нове, ltum,
   {{0x61fbbd6b,0x3a294603,0x2bdf8519,0xed5a08b0}},	//   ndul, gkap_, प्ता, _ной_,
   {{0x63b50052,0x60cd4e11,0x2bd29199,0x6832006a}},	// [68a0] bazn, guam, सलमा, _læde,
   {{0x25dc1a42,0x76465acf,0x3c2b8aa2,0x6c340019}},	//   ग्री_, liky, _søvn_, _شہزا,
   {{0xf09f139a,0x60db837b,0x7d04255e,0x2bc99299}},	//   _età_, htum, _hris, _राजा,
   {{0x7d047031,0xa3d289a3,0x321d809a,0x29020da8}},	//   _kris, _वाह_, _nowy_, _trka_,
   {{0xc3c909a7,0x27f87032,0x61fbf033,0x26cc87b6}},	//   _عظیم_, _tarn_, ddul, zudo_,
   {{0xf1bf016b,0x7d04004f,0xa7fc82d0,0x61e28037}},	//   _zdá_, _mris, rlık, _sbol,
   {{0x2bd3016f,0x201c8037,0x78a40037,0xa3df8a27}},	//   _तासा, _rovi_, lpiv, ध्ध_,
   {{0x7d047034,0x93bc8087,0x28c74a2f,0x998d8035}},	//   _oris, _alăt, _लिमि, cież_,
   {{0x29029dc5,0x61f982a3,0x60dbf035,0x2900023e}},	//   íka_, _dawl, gtum, nvia_,
   {{0x81c900c8,0x26cc8548,0xdb06802e,0x7e62cbfe}},	//   ল্প_, tudo_, ămân, loop,
   {{0x28c28996,0x61fbf036,0x6f03992c,0x2ca000b9}},	//   _शिवि, bdul, _crnc, _atid_,
   {{0x26c2812b,0x61e2ae0b,0x6d5180c3,0x0ae981a8}},	//   čko_, _ubol, škaš, _تركي_,
   {{0x7a230074,0x645a026f,0x63b50f09,0x9f4e826b}},	//   _mõtt, čtin, tazn, _dafá_,
   {{0xaad4800f,0x7d0418f4,0x998d8035,0x3e7204e8}},	//   _धमाक, _dris, zież_, ráta_,
   {{0x7d046799,0x63b521d1,0xf09f01e8,0x2cea2776}},	//   _eris, razn, _stà_, टबॉल_,
   {{0xfd268028,0xa3d60740,0x7d04288b,0x60cd7037}},	//   _đình_, _हाथ_, _fris, tuam,
   {{0x660d7038,0x865c0039,0xb5fb041c,0xf09f00e5}},	// [68b0] _inak, _מדהי, fláv, _qtà_,
   {{0x61ed05ae,0x3a297039,0x6820016d,0x60cd2b6a}},	//   seal, skap_, _södr, ruam,
   {{0xdcfd0459,0xa3d6142d,0x6447204b,0xc5d59138}},	//   ması, _हात_, miji, віль,
   {{0x6447703a,0xdcfd07c0,0x7a3e9247,0x660d0580}},	//   liji, lası, būti, _jnak,
   {{0x3e5600eb,0x60cd00e5,0x68323ea6,0x660d6cc1}},	//   nāta_, quam, _sæde, _mnak,
   {{0x64473086,0xdcfd0059,0x3e878032,0x661f03ed}},	//   niji, nası, _bìtì_, _loqk,
   {{0x660d0025,0xdce40063,0x2bd2800d,0x61f9c635}},	//   _onak, _dzię, _सारा, _pawl,
   {{0x05d880d4,0x60dba6b2,0x6824823e,0x61fbf03b}},	//   _डायब, ttum, _mòdu, udul,
   {{0x212b8a65,0x3495ac60,0xdcfd1010,0x61fb93ec}},	//   ách_, _разр, kası, rdul,
   {{0x60dbf03c,0x7c2af03d,0x644728b8,0x4ae206a7}},	//   rtum, ckfr, jiji, _पहलव,
   {{0x34d18c78,0x2ca0056f,0x764629d1,0x47c700ab}},	//   _समुद, _stid_, tiky, র্থী,
   {{0x270101e2,0xddc280d2,0xbbaa1130,0x9f5802d6}},	//   _mėn_, ološ, कर्क, _darè_,
   {{0x9f5808cf,0xdcfd2353,0xdb0e703e,0xee372380}},	//   _parë_, fası, rabí, тня_,
   {{0x660d703f,0x628b82c4,0x64477040,0x290000e5}},	//   _enak, _higo, giji, vvia_,
   {{0x2bd31905,0x628ba1bb,0x9cff80ab,0xc7d69101}},	//   _तारा, _kigo, ্নয়ন_, _יוסי_,
   {{0x29007041,0x628bf042,0xdb0880e1,0xc3329101}},	//   tvia_, _jigo, _jedá, בול_,
   {{0x7bc1803a,0xf1b28158,0x64472a0b,0xddc28289}},	// [68c0] _odlu, יסן_, biji, jloš,
   {{0x25e301ce,0x628b8110,0x9f580388,0x290028ff}},	//   ट्ठी_, _ligo, _haré_, rvia_,
   {{0x4444512a,0x99990065,0xbddb13ff,0xfaa60a18}},	//   _im_, _első_, zièm, _шано,
   {{0xdb08826f,0x78bb87b8,0xdb018061,0x471a80be}},	//   _nedá, ksuv, _felú, וועג,
   {{0x7e62e13e,0x7a230006,0xbddb00e7,0x9f430388}},	//   roop, _võtt, xièm, _bajó_,
   {{0x07a33407,0x628b8101,0x8fa326c8,0x682d80e1}},	//   _варн, _aigo, _варе, _súdn,
   {{0xf746110b,0x628bf043,0x779100d5,0x4444037e}},	//   _рево, _bigo, _ایما, _mm_,
   {{0x60f89ba8,0xf506838d,0xda09a441,0xa3e28540}},	//   ения_, _избо, वागत_, _फॉर_,
   {{0x444469dd,0xdcfd0201,0x628bf044,0xfbb800ab}},	//   _om_, yası, _digo, _জানত,
   {{0x6e2084a1,0x660d0257,0x88bd809a,0x76447045}},	//   _homb, _snak, myśl, _amiy,
   {{0x64470503,0x61e61f07,0x7a310711,0x60c9816a}},	//   viji, _obkl, _låta, arem,
   {{0x444448d9,0x291180f7,0x6e20861b,0xc0aa92c8}},	//   _am_, ónaí_, _jomb, _قاتل_,
   {{0xdd1188c5,0x9f5103a8,0x78700106,0xdcfd061c}},	//   _müşa, _mazá_, tävl, tası,
   {{0x09cb23e7,0x628be1e5,0x76447046,0x22988061}},	//   िल्य, _zigo, _emiy, _kék_,
   {{0x64477047,0xdcfd0182,0x6e2081b0,0x44440252}},	//   riji, rası, _oomb, _dm_,
   {{0x44447048,0x6e20f049,0xe5e90009,0x79a40009}},	//   _em_, _nomb, ämää, ируе,
   {{0x4444704a,0xb3d28540,0xa3d2f04b,0x7d0288ae}},	// [68d0] _fm_, _सांख, वला_, jvos,
   {{0x63b88353,0x7d0280d2,0x534725f5,0x2ca6be34}},	//   javn, dvos, _ахма, dpod_,
   {{0x63b8803b,0xdb05016d,0x58841e2f,0x425500b7}},	//   davn, _behå, рыта, _مندر,
   {{0xdb0700e1,0x13b80264,0xdb01816a,0x29068106}},	//   kajú, _জায়, _telú, _oroa_,
   {{0x4444704c,0x44212e9c,0x6e20f04d,0x4433008e}},	//   _ym_, _koh_, _domb, _klx_,
   {{0x60c9803b,0x27fc8b40,0x44215f0b,0x2249011b}},	//   vrem, _navn_, _joh_, liak_,
   {{0xe816835a,0x6e208176,0xf41402f6,0x212900dd}},	//   ताना_, _fomb, יפס_, lyah_,
   {{0xe8f999dc,0x22491d19,0x61fd4f6d,0x44215a84}},	//   ели_, niak_, _jasl, _loh_,
   {{0xb5fb1389,0x21290b50,0x656d5830,0x60c981b3}},	//   hlás, nyah_, _nyah, urem,
   {{0x6e2086a0,0x60c9ceae,0xa2cac183,0xef19c5c8}},	//   _zomb, rrem, संख्, емо_,
   {{0x44441cdf,0x656d09ca,0xe7f60770,0x2249011e}},	//   _rm_, _ayah, ीयता_, kiak_,
   {{0x61fd036f,0x64a663aa,0xdca60294,0xe80a009a}},	//   _nasl, лама, лами, _होना_,
   {{0x44440c6b,0x37e58a7c,0xf1b9a847,0x7a358511}},	//   _pm_, _болг, maš_, _cáte,
   {{0xf1b9f04e,0x9f058077,0xdb018aa2,0x44440de4}},	//   laš_, _موتو, _belø, _qm_,
   {{0x4421704f,0x61fd38ad,0x60dd0609,0x22490fe0}},	//   _doh_, _basl, _aqsm, fiak_,
   {{0x63b8807d,0xe811800f,0x2249011e,0x44217050}},	//   zavn, ़ावा_, giak_, _eoh_,
   {{0xeb1f8076,0x6e20bacd,0x443300ee,0xf1bf046d}},	// [68e0] बहुत_, _romb, _flx_, _alás_,
   {{0x44447051,0xe73a24c4,0x44217052,0xe8f701e5}},	//   _um_, нез_, _goh_, ылу_,
   {{0x0dcaad94,0xb5fb0207,0x22490fe0,0x6e20f053}},	//   елей_, clás, biak_, _pomb,
   {{0xed5a825d,0xe1f20277,0x7e7bf054,0x7d0281f4}},	//   ное_, _اسد_, _chup, tvos,
   {{0x44217055,0xe816801b,0xa92801d0,0x7e7bf056}},	//   _yoh_, तामा_, _držá, _dhup,
   {{0x7e69819d,0xdb0700e1,0x7d028e6c,0x6e20836a}},	//   _ekep, vajú, rvos, _womb,
   {{0x78a2b8da,0xd6ae80c8,0x533491d2,0x05d4016f}},	//   _stov, _কম্প, рейт, _थांब,
   {{0x48aa80e2,0x2906ee2d,0xf7530199,0x69d67057}},	//   нтом_, _proa_, _انفج, ngye,
   {{0x38348328,0x2611816f,0x7c21823e,0x25fdbd25}},	//   инир, णारी_, _folr, _रोटी_,
   {{0xe45f016d,0x2249011e,0xf1a4909b,0x7c2182c4}},	//   tröm_, ziak_, _ग्रन, _golr,
   {{0x9b938307,0x33938013,0x44210587,0xab938013}},	//   _المت, _المز, _roh_, _المغ,
   {{0x21291600,0x7a35801b,0x2cb20114,0x4421475a}},	//   yyah_, _páte, _bwyd_, _soh_,
   {{0x4421489b,0xf09f026b,0x78a2f058,0x349513d1}},	//   _poh_, _aràn_, _utov, рагр,
   {{0xb4e50063,0x61fd4ac4,0x9f5c8168,0xe09e819d}},	//   _नही_, _sasl, _javë_, _gọọ_,
   {{0x0cd185e8,0x61fd4865,0x28c7035a,0xf8bf000d}},	//   _सम्म, _pasl, _लिहि, _své_,
   {{0x53341056,0xb5fb0019,0x442100d7,0x229180c3}},	//   щест, rlás, _woh_, _uške_,
   {{0x7bdaf059,0x224900ad,0x68f6031d,0x44211a9a}},	// [68f0] _octu, riak_, gwyd, _toh_,
   {{0x7e69ab11,0x25fd835a,0xf1bf00f7,0x22495912}},	//   _skep, _रोजी_, _clár_, siak_,
   {{0xf1b98353,0x2129010b,0x81cc80ab,0x224942d8}},	//   ljše_, syah_, শ্য_, piak_,
   {{0x61fd00f7,0xddc28035,0x7c219da3,0xd5fb827d}},	//   _uasl, mnoś, _solr, _khủ,
   {{0xddc28063,0x7c21f05a,0x21290359,0x644a854e}},	//   lnoś, _polr, qyah_, fifi,
   {{0x628f00ee,0xd90e0065,0x60cd09c4,0x644af05b}},	//   _hico, _کیے_, mram, gifi,
   {{0xf1b9811f,0xf99180f7,0x60cd0174,0xff040081}},	//   taš_, يبة_, lram, _лятн,
   {{0x60cd0081,0x6d5b81c5,0x26c380e1,0x26d30118}},	//   oram, _txua, ájom_, muxo_,
   {{0x20558628,0x26cc85b4,0xa3d600a5,0x661d01a1}},	//   итор, erdo_, _हाल_, djsk,
   {{0x2001003d,0x644af05c,0xe3b0803d,0x764b84a7}},	//   ndhi_, cifi, _فرم_, ligy,
   {{0x2bab835a,0x60cd705d,0x2bdc1299,0x69a690a1}},	//   _घ्या, hram, _बाबा, _ट्वी,
   {{0x7d0988e7,0x81cc80ab,0xddc2809a,0x7bc5705e}},	//   _kres, শ্ব_, dnoś, _adhu,
   {{0x60cd1069,0x9f4c8081,0x99838084,0xe09e81bc}},	//   jram, ledì_, ėjų_, _tọọ_,
   {{0x69cb3f85,0x62972828,0x26cc80d2,0x4fa59a1f}},	//   ógen, _buxo, brdo_, _тикв,
   {{0x61e4627e,0x290f00f2,0xae1e000f,0x9f4c8081}},	//   tfil, ågan_, _बचपन_, nedì_,
   {{0x60cd705f,0x644af060,0x98a28110,0xc33284de}},	//   fram, zifi, šką_, קון_,
   {{0xdb03803e,0x628f7061,0x9f4701ac,0xada900f7}},	// [6900] vaný, _dico, ľný_, _صديق_,
   {{0x68f6676b,0x644ab1fc,0x9f47026f,0xf09f00ff}},	//   rwyd, xifi, žný_, _tràn_,
   {{0x628f7062,0x91e64e9a,0x103680be,0x09e61e47}},	//   _fico, _коне, סטעם_, _конн,
   {{0xa3d6000f,0x2011004f,0x0e66b5aa,0x270580eb}},	//   _हाँ_, _enzi_, шкен, _mēn_,
   {{0x25a99e86,0x644aa52a,0x7afa826c,0x7d09c383}},	//   ñala_, tifi, _sstt, _cres,
   {{0x63bc211b,0x0ec581fe,0x26d301df,0x3e7c826f}},	//   narn, _विंड, buxo_, díte_,
   {{0x764b809c,0x15e780d4,0xb5fb04e8,0xdb1e1e51}},	//   bigy, _टॉवर_, kláp, _odpí,
   {{0xe80a113d,0x628f023e,0xdb088338,0x62830037}},	//   _होता_, _xico, _nedå, _ènot,
   {{0x1da72296,0xa3d6064d,0xd01080f7,0x64a39ede}},	//   _क्षत, हला_, كلة_, _мата,
   {{0x6600f063,0x63bc19f3,0x69a68361,0x44e090ab}},	//   _hamk, jarn, _ट्री, mò_,
   {{0x63bc2aae,0x645a89da,0x44e09b84,0x44e280ff}},	//   darn, _ijti, lò_, _hư_,
   {{0x60cd0182,0x6602f064,0x6600f065,0x6e244f0d}},	//   yram, ndok, _jamk, _coib,
   {{0x628f0698,0x40969506,0x62840063,0x44e0f066}},	//   _rico, _трет, dmio, nò_,
   {{0x63bc18b6,0xddc28063,0x78a903bf,0xcfcc00ab}},	//   garn, tnoś, _çevi, র্তন,
   {{0x78a6008b,0xdddd0035,0x6e36286c,0x8ff78019}},	//   _atkv, rosł, _flyb, _ضرور_,
   {{0x80c20321,0x0dcb32de,0xddc28035,0xdce98b67}},	//   _लिखे, _руки_, rnoś, _uzeć,
   {{0x5fdd901b,0x63b70201,0x51874ecc,0x9f581c94}},	// [6910] _मामल, _texn, рува, _darí_,
   {{0x60cd2755,0x9f4786a5,0x7d0980f1,0x44e0c2ff}},	//   rram, _ganó_, _rres, dò_,
   {{0xfbdc035a,0xf7700277,0x7d0982a5,0x7a358b4c}},	//   _बातम, وام_, _sres, _láta,
   {{0x60c285f5,0x9f4c8081,0x7a3c8019,0x6600808e}},	//   _ovom, vedì_, _hétf, _camk,
   {{0xaca38028,0x44e2801c,0x60cd0201,0x6600982f}},	//   _trọn, _cư_, qram, _damk,
   {{0x26d301df,0x2291826c,0xdb050edd,0x7d09c9b5}},	//   puxo_, _aška_, _behø, _vres,
   {{0x9725003d,0xad9d809a,0xa3dc0f12,0x7a2a026f}},	//   _افزو, _paźd, ण्ट_, _výtv,
   {{0xe1f980ae,0x61e90074,0xb87b0118,0x3e7c816b}},	//   уги_, _öeld, _epít, títe_,
   {{0x63bc09da,0x7649a30e,0x7d09f067,0x44e080e5}},	//   yarn, _imey, _ures, cò_,
   {{0x7e6d7068,0x6600809a,0x60c2824a,0x2bdc03eb}},	//   _akap, _zamk, _dvom, _बाधा,
   {{0x78a98db7,0x3e7c803e,0x6e240013,0x6fd8816f}},	//   spev, síte_, _poib, _मारू,
   {{0x63bc3bde,0x44259104,0xdb150e93,0x80ad00ab}},	//   warn, _hol_, gazí, _চিন্,
   {{0x4425f069,0x682d88f1,0x998580f7,0x224de2e4}},	//   _kol_, _lúdi, _الشو, miek_,
   {{0x53a30791,0x224df06a,0x03a320e2,0x7e6d706b}},	//   зарб, liek_, зиро, _ekap,
   {{0x63bc706c,0x09a900ab,0x8c4320e1,0x7c25408c}},	//   rarn, _ওয়া, чере, _dohr,
   {{0x224df06d,0x9f45839c,0x442590b6,0x7a2a01fa}},	//   niek_, relä_, _lol_, _nýtt,
   {{0xdb188073,0x19b901e2,0x4fea1777,0x7a2e8014}},	// [6920] ravé, русь_, лман_, _dùth,
   {{0x66008125,0xdb018019,0x80cf8526,0x9588009a}},	//   _samk, _belü, _दिने, _ciąż,
   {{0xd9f9835a,0x93fb0158,0x644e706e,0x44e2801c}},	//   ्यात_, _גליי, mibi, _sư_,
   {{0x0d86884b,0x44e0946f,0x05ba9a05,0x6d03f06f}},	//   блен, tò_, ادات_, लिंग_,
   {{0x4425f070,0xe8df0028,0x6fd8800f,0x290b01a1}},	//   _bol_, _phục_, _मालू, _grca_,
   {{0x4425f071,0x68e40082,0x6fd5035f,0xa0a321d2}},	//   _col_, mtid, _місц, _хард,
   {{0x60c28052,0x4425f072,0x68e41af9,0xc5ed80c8}},	//   _svom, _dol_, ltid, ওয়া_,
   {{0x44e28104,0x644e448e,0x5fa4016f,0x644d8036}},	//   _tư_, hibi, खुरल, éair,
   {{0x644e6d7c,0x55548065,0xdced005c,0xa5078b02}},	//   kibi, _بھار, _izać, _лета_,
   {{0x7e6d088b,0xa3d28d14,0x644e1aa3,0x3202016b}},	//   _skap, _वाट_, jibi, _laky_,
   {{0x644e13d4,0xb05b0106,0x68e402f1,0xc7b301c6}},	//   dibi, _ovän, htid, הבת_,
   {{0x90e68077,0x60c280d2,0x68e40074,0xdb1c3211}},	//   _هستن, _tvom, ktid, parê,
   {{0x44259010,0x412a835f,0x7e93802e,0x6018a60a}},	//   _yol_, _щодо_, _săpt, _воля_,
   {{0x629aa11f,0x3a268b3c,0x80a4803d,0x394001a9}},	//   _kuto, _hoop_, _همچن, dzis_,
   {{0x3a2685f8,0xa3e086b7,0x4ea68523,0xf1b9807a}},	//   _koop_, _थान_, _урла, ljša_,
   {{0x63bae06b,0x629aa13a,0xb4e88105,0x7a358718}},	//   _letn, _muto, _बहू_, _látn,
   {{0x644e7073,0x3207001b,0xf1b9807a,0x629e816b}},	// [6930] bibi, ěny_, njša_, ípoj,
   {{0x644e160a,0x629af074,0x224db17a,0x7d0d7075}},	//   cibi, _outo, ziek_, _iras,
   {{0x2baf0dbc,0x4425831e,0xe7ea816f,0x3ea703b2}},	//   _ज्या, _rol_, ज्या_, ënt_,
   {{0x25e1023c,0x7bc8f076,0x9f5801e8,0xed51803d}},	//   _काफी_, _addu, _darà_, وپا_,
   {{0x4425f077,0x68e408f1,0x25e113e5,0x224d80e1}},	//   _pol_, ctid, _कानी_, viek_,
   {{0x9f587078,0x63ba807d,0x629af079,0xdb1c1b57}},	//   _farà_, _cetn, _buto, rgrö,
   {{0x224de46c,0xdb018073,0xdb1c707a,0x3a2682df}},	//   tiek_, _reló, varë, _boop_,
   {{0x4425ad33,0x2003295f,0x7d0d707b,0x644e707c}},	//   _wol_, _haji_, _oras, zibi,
   {{0xdb1c020f,0x224d811e,0x2003707d,0x3a26874c}},	//   tarë, riek_, _kaji_, _doop_,
   {{0x9f5805a4,0x224d9c7b,0x442583a7,0x20030010}},	//   _hará_, siek_, _uol_, _jaji_,
   {{0x7d0d4851,0x2003022e,0x629af07e,0x644e047f}},	//   _aras, _maji_, _guto, vibi,
   {{0x7d0d16cc,0x76598355,0x68e412cf,0x29188174}},	//   _bras, nnwy, ytid, ófaí_,
   {{0x1ddb0853,0x61e9db51,0x2be084c5,0xe81c000d}},	//   _भारत, mfel, _नामा, नामा_,
   {{0x7d0d4f82,0x69dbd7cb,0xdb1c11a9,0x61e98357}},	//   _dras, lgue, laré, lfel,
   {{0x644e707f,0x7d0d1611,0x26c7012b,0xe8168c2d}},	//   ribi, _eras, šnoj_, तारा_,
   {{0x644e1598,0x61e9c2f9,0x69dbb425,0x68e47080}},	//   sibi, nfel, ngue, ttid,
   {{0x9f580698,0x7a358298,0x7a380118,0x602581d0}},	// [6940] _sarà_, _láto, _cíta, _témě,
   {{0x9f58146f,0x20034d78,0x2005f081,0x39400162}},	//   _aará_, _caji_, ndli_, rzis_,
   {{0x6604025d,0xbddb03d3,0x63ba8bc5,0x3202001b}},	//   _kaik, mièr, _retn, _taky_,
   {{0xac9719f7,0xbddb02be,0x0caa891d,0x61e980f3}},	//   _دنیا_, lièr, атки_, jfel,
   {{0xb05b00f2,0x66047082,0x9f582b49,0xdb170118}},	//   _kväl, _maik, _dará_, _rexé,
   {{0x66043ffd,0x629a8289,0x48f90158,0x7bdc7083}},	//   _laik, _puto, _פּרא, ngru,
   {{0x752f0063,0x3f980a20,0x443a7084,0x7a3c8019}},	//   zycz, _igru_, _mlp_, _léte,
   {{0x61e98065,0x1cba9381,0x66042ad0,0x80ad00ab}},	//   gfel, _نائب_, _naik, _চিত্,
   {{0x60c434e7,0x7bdc238a,0x320281ac,0x3e72016b}},	//   nsim, kgru, ľky_, nátu_,
   {{0x3202803e,0xdb1a820f,0x7b1680f7,0x59dc816f}},	//   žky_, _jetë, _وظائ, _यावर,
   {{0x91e6c1c7,0x907b0451,0xe7e20076,0x660436a5}},	//   _може, שטיי, _पानप, _baik,
   {{0x7d0d7085,0x752f0d38,0x98b20063,0xdb1a80f1}},	//   _pras, tycz, czyć_, _letë,
   {{0x3ce6886f,0x08fa826a,0x66040110,0x7bdc01ec}},	//   ntov_, _خراب_, _daik, fgru,
   {{0xe80a65a5,0xdb08813c,0x7a3c82be,0x7d0d00f1}},	//   _होला_, _bedø, _déte, _vras,
   {{0x7c28c6bb,0x443a0358,0x628281e9,0x20037086}},	//   _modr, _dlp_, _khoo, _raji_,
   {{0x7d0d370b,0xdb188125,0x3ce6886f,0xaca30133}},	//   _tras, javí, ktov_, _ahụg,
   {{0x7c3a8698,0xdb1885b4,0x7bdc002a,0x60c4009c}},	// [6950] _oltr, daví, bgru, gsim,
   {{0x69c0f087,0x7c288029,0x6282f088,0x38a08014}},	//   hame, _nodr, _lhoo, _mòr_,
   {{0xe7e285e8,0x69c0d983,0x660403f8,0x629a0019}},	//   _खाना_, kame, _yaik, ítot,
   {{0x7c3af089,0x69c0ceb9,0x6e228019,0x3e5600eb}},	//   _altr, jame, gjob, tāti_,
   {{0x7ec020b1,0x03a59e58,0x7c28efd9,0x43d40180}},	//   _pápá, пило, _bodr, _عزیز,
   {{0xf1bf04c3,0x7c288162,0x96d3064a,0xb09a01c6}},	//   _xoán_, _codr, _डिपॉ, _לישר,
   {{0x68f903bf,0x7c289f1c,0x69c0eb5e,0x9f5c816b}},	//   şadı, _dodr, fame, _baví_,
   {{0x69c09092,0x6e229b9c,0x3cff81c0,0x62828039}},	//   game, cjob, _tsuv_, _choo,
   {{0xc3cb803f,0x69dba01d,0x62828079,0x61e9a6e1}},	//   _نظام_, rgue, _dhoo, rfel,
   {{0x61e991d9,0x66040077,0x68fb87d5,0x764d2c1d}},	//   sfel, _saik, rwud, _amay,
   {{0x660403ff,0x69c0f08a,0xfd4d0028,0xdb238077}},	//   _paik, bame, _triệ, _توضی,
   {{0x7c2880f3,0x20038ee1,0xb05b0106,0x62828362}},	//   _zodr, žji_, _sväl, _ghoo,
   {{0x66042bef,0xbddb02be,0xf1b98353,0xc19a8039}},	//   _vaik, tièr, ljšo_, _השני,
   {{0xb068845b,0xf745840d,0x2bdc0072,0x44e41743}},	//   _وصول_, _нело, _बाळा, rö_,
   {{0x660407ac,0x7bdc0456,0xbddb00e7,0xd9e28105}},	//   _taik, rgru, rièr, क्कत_,
   {{0x7bdc04fe,0xee3f026f,0x60c461bf,0x160b80d4}},	//   sgru, chý_, tsim, _सोलर_,
   {{0x60c401e2,0xf1bf0028,0xdb15708b,0x6f0e08ae}},	// [6960] usim, _toán_, razá, _srbc,
   {{0x3e72003e,0x88bd80c8,0x6e3b8136,0xa3d61513}},	//   rátu_, _আমাক, _alub, _हाट_,
   {{0x60c448fe,0x7c288c52,0xdb1a88cf,0x9f5807e2}},	//   ssim, _rodr, _vetë, _març_,
   {{0x69c0d1f1,0x7c28f08c,0x0d868436,0x6aa30511}},	//   xame, _sodr, плен, _énfa,
   {{0x60c401b9,0xdb18816b,0x6e229375,0x629e708d}},	//   qsim, raví, rjob, _hupo,
   {{0x29024a6e,0x044395b9,0x26c58110,0x68e48009}},	//   _iska_, нечн, kslo_, _äidi,
   {{0xd9f98bf5,0x628281c5,0x78a9017b,0x3ce6886f}},	//   ्यंत_, _phoo, _çevr, stov_,
   {{0x7584804e,0x224000e4,0x3ce6a3fa,0xaf5b01c6}},	//   _قیام, nhik_, ptov_, _הכלכ,
   {{0xa3dd000f,0x629e15d0,0x26da708e,0x3e5600eb}},	//   _डाल_, _lupo, lupo_, nātu_,
   {{0x4734a0a9,0xdefa97ae,0x645c708f,0x69cbb110}},	//   днос, бым_, jnri, _edge,
   {{0x69c0f090,0x628281c5,0x290ff091,0x5fdd93ba}},	//   pame, _thoo, _erga_, _मारल,
   {{0x0f570039,0x6b7b80be,0x290202f1,0xc1e38c69}},	//   ליים_, _פראנ, _oska_, _गायब_,
   {{0x94058085,0x290f85f3,0x786f983d,0x6382f092}},	//   _ailə_, _grga_, røvr, _fíní,
   {{0xa3dd0072,0x629e038a,0x26da02c4,0x8aa71501}},	//   _डाळ_, _bupo, kupo_, зрад,
   {{0x7b64171c,0x629e393d,0x2d800870,0x63be008e}},	//   етте, _cupo, _ezie_, _depn,
   {{0x764d7093,0x20184077,0xeb3b83de,0x645c0901}},	//   _umay, _anri_, זעלש, anri,
   {{0x236d009a,0x320680e4,0xa3d60072,0x2007041c}},	// [6970] łej_, _maoy_, _हाच_, ônio_,
   {{0x80cf816f,0xb60680c3,0x638707bc,0x6e29f094}},	//   _दिसे, _lešć, géné, _soeb,
   {{0xf1dc835a,0xfbd2036b,0x48f91e3c,0x26c7000d}},	//   _यांन, _בתי_, _उनको_, éno_,
   {{0xb8d30a49,0x224002d6,0xcf9380be,0xdd918829}},	//   _টি_, chik_, גטע_, نوا_,
   {{0xfce595b1,0xdb018019,0xf1bf0118,0xa3b9864a}},	//   фоло, _jelö, _joám_, चरल_,
   {{0x61e2f095,0x3e480019,0xdb1703a8,0x61ed7096}},	//   _acol, lőtt_, _lexí, lfal,
   {{0xdcfb817f,0x753c8085,0x6e29910f,0xb60680c3}},	//   _izuč, _ərzi, _toeb, _bešć,
   {{0x5f9400e9,0x394d07ca,0x61ed10f6,0x6e3b809a}},	//   _чист, _þess_, nfal, _ulub,
   {{0x7fd5a22c,0xa3dd016f,0xa4d480e8,0x6289f097}},	//   міні, डला_, _поті, rmeo,
   {{0xb02480ff,0x80dc8035,0xb5fb0216,0x2c760366}},	//   _phườ, पढ़े, zoát, pædi_,
   {{0x7bc3f098,0xfe708019,0xfbe300ab,0xf771bdf2}},	//   manu, _شدہ_, য়াত, ضاد_,
   {{0x200b8610,0xddc2877b,0x7bc3f099,0x26c58110}},	//   ści_, zlož, lanu, rslo_,
   {{0x32095857,0x7a359c32,0x290380eb,0x61ed709a}},	//   dday_, _látk, ājas_, dfal,
   {{0xb0248028,0x61ed1849,0x765d02f7,0xe29a57f5}},	//   _thườ, efal, ansy, жав_,
   {{0xeb970b5b,0xe7e28770,0x03a326c8,0xa2e3709b}},	//   дир_, _खाता_, тисо, корд,
   {{0xed5a07c4,0x7bc3f09c,0x25bf898b,0x2007f09d}},	//   _мой_, hanu, _neul_, _hani_,
   {{0xdb1c36c0,0x2007f09e,0x68e9f09f,0xf77884b7}},	// [6980] marí, _kani_, nted, mgħa_,
   {{0xdb1c1727,0x7a38009f,0x7a3c80e7,0x32090079}},	//   larí, _títo, _méta, aday_,
   {{0x8c1b0159,0x2007f0a0,0x441b0158,0x49ba0b8c}},	//   _וויי, _mani_, _וויס, _واحد_,
   {{0x60db8e05,0x68e987d9,0x2ca00006,0xdb1c2d84}},	//   kuum, kted, _kuid_, narí,
   {{0x25e309a3,0x6e3d00f1,0x7bc3bcb5,0x68e9f0a1}},	//   ट्टी_, ërbi, fanu, jted,
   {{0x2ca070a2,0x2007a767,0x7bc3f0a3,0x2ca9d1d1}},	//   _muid_, _nani_, ganu, íada_,
   {{0x5f030139,0x160e05e8,0xae0e085d,0xddc691b3}},	//   _изра, ियार_, ियान_, _обви,
   {{0x38a470a4,0x7d042f10,0x2be0816f,0xdb1c1e3a}},	//   _kör_, _osis, _नावा, jarí,
   {{0x2007f0a5,0x7bc382a0,0xdb1701df,0xdb1c3eb3}},	//   _bani_, banu, _rexí, darí,
   {{0x25e1053e,0x7a358064,0x7a3c83d3,0x2007f0a6}},	//   _काही_, _láth, _déta, _cani_,
   {{0x9343917e,0x38a4016d,0x320970a7,0x61fbe8a7}},	//   _инфе, _lör_, yday_, beul,
   {{0x442ca950,0xdb1c3eb3,0x32090079,0x99800084}},	//   _hod_, garí, xday_, nkių_,
   {{0x442c803a,0x2ca00ad0,0x7a310370,0x68e99916}},	//   _kod_, _cuid_, _mått, cted,
   {{0x2007c8d8,0x2ca006cb,0x32090079,0x628602d5}},	//   _gani_, _duid_, wday_, _ahko,
   {{0x442cf0a8,0x7d0470a9,0x61ed3c25,0xc1088028}},	//   _mod_, _esis, tfal, _hỗ_,
   {{0x442cf0aa,0x38a400f2,0x7c3e383a,0xdb1c05e4}},	//   _lod_, _bör_, _elpr, carí,
   {{0x20078214,0xf09f001c,0x261c1199,0x764289e1}},	// [6990] _yani_, _quà_, यारी_, dhoy,
   {{0xe61089d7,0x25bf82be,0x61ed4327,0x47d080ab}},	//   یشن_, _seul_, sfal, ত্রী,
   {{0x64556cd7,0x249f8176,0x2cad8b40,0x2ca000f3}},	//   mizi, _suum_, _sted_, _zuid_,
   {{0x38a470ab,0x80cf816f,0x32090079,0x7bc3b22c}},	//   _för_, _दिले, qday_, wanu,
   {{0x38a404b8,0x442c8355,0x7bc3dd21,0x6e2d0bb1}},	//   _gör_, _bod_, tanu, _moab,
   {{0xd3788063,0x6385dfc2,0xdb85802e,0xe299f0ac}},	//   _być_, нгла, нгли, пак_,
   {{0x2be0853f,0x442ca92f,0x7bc3f0ad,0x2ba70c28}},	//   _नारा, _dod_, ranu, _खलना,
   {{0x200780a4,0x68e99e01,0x645518e9,0x443ef0ae}},	//   _sani_, tted, hizi, _elt_,
   {{0x442c8355,0x64550883,0xdb1c08a4,0x661b9ffc}},	//   _fod_, kizi, varí, _inuk,
   {{0x44e9aa44,0x68e9f0af,0x442c8a85,0x9bf48103}},	//   mú_, rted, _god_, _изуч,
   {{0x68e984c6,0x645570b0,0xdb1c3aa8,0x2007911b}},	//   sted, dizi, tarí, _vani_,
   {{0x20078a73,0x2bb8116e,0xa3ab8fcc,0xdd1282d0}},	//   _wani_, अर्थ, कुर_, nüşt,
   {{0x7bc18812,0x2007f0b1,0x645570b2,0x442cf0b3}},	//   _kelu, _tani_, fizi, _yod_,
   {{0x628608cf,0x38a4016d,0xdb1c1f9e,0x645522eb}},	//   _shko, _rör_, sarí, gizi,
   {{0x6d460063,0xe80a0063,0x7bc1a87c,0x60c9ad2d}},	//   szka, _होगा_, _melu, lsem,
   {{0x7bc1ca10,0x7d041827,0xdb260065,0x629980dd}},	//   _lelu, _tsis, _épít, _jiwo,
   {{0x69c46bc0,0xe0da1367,0x44e9f0b4,0x645570b5}},	// [69a0] raie, ява_, jú_, bizi,
   {{0x64550249,0x661bf0b6,0x60c9a314,0x7bc1e86f}},	//   cizi, _anuk, isem, _nelu,
   {{0x6443f0b7,0x66098708,0xe7e28424,0x671f8701}},	//   dhni, _baek, _खासा_, यमिक_,
   {{0x7a35d084,0xdb1e70b8,0x442cf0b9,0x60c9a88c}},	//   _fáti, _repè, _sod_, ksem,
   {{0x7bc193b8,0xd250803d,0x62980036,0xdb1c385e}},	//   _belu, ینت_, _évoq, barã,
   {{0xa3ab9513,0xdee602de,0xa2a489c8,0x66e628b4}},	//   कुल_, _поги, _चंद्, _пога,
   {{0x7bc1895e,0x81e980c8,0x25e10bb8,0x442cf0ba}},	//   _delu, য়ন_, _काली_, _vod_,
   {{0x6fdd80d4,0x62998041,0x998900e1,0x6455373d}},	//   _माउं, _ciwo, skať_, zizi,
   {{0x200a2778,0x0d868b30,0x7bc1f0bb,0xe21380f7}},	//   _kabi_, _члан, _felu, طبيع,
   {{0x7bc185f8,0x63b3826f,0x6e2d002a,0x64a3a8ff}},	//   _gelu, čení, _soab, _сафа,
   {{0x8ad68eca,0x60c9956e,0x085701c6,0x998d80c3}},	//   _ستائ, asem, תבים_, rkeš_,
   {{0x200a70bc,0x11e980f7,0x2f5b007c,0x7bc1f0bd}},	//   _labi_, _يعني_, לדינ, _zelu,
   {{0x645570be,0x6aa1bcba,0xe0d480be,0xda6f8019}},	//   tizi, _zulf, _סײַ_, _اُن_,
   {{0x200a70bf,0x7e640242,0xdb1ad437,0xda1e86ae}},	//   _nabi_, _ejip, _letí, भावत_,
   {{0x64551917,0xb05b0338,0xdb1c16dc,0x3e641238}},	//   rizi, _kväv, garà, sıta_,
   {{0x64556fc6,0xa3dd000f,0x26de826f,0x2d84826c}},	//   sizi, _डाक_, muto_, _ozme_,
   {{0x26def0c0,0xdb1c0187,0xa3e092c6,0x628d3f70}},	// [69b0] luto_, tarã, थला_, rmao,
   {{0x7e7d2e99,0xd2510416,0x44e981ac,0xb881801b}},	//   llsp, _چند_, vú_, _říze,
   {{0xd6db1367,0x26def0c1,0x7bc770c2,0xdced0024}},	//   ята_, nuto_, maju, _izađ,
   {{0xdb0504b8,0x7bc1a75b,0x7bc70abf,0x60c9b487}},	//   _behö, _selu, laju, ysem,
   {{0x78a28021,0x7bc1a853,0xdb1c04ab,0x64438c41}},	//   _nuov, _pelu, mará, thni,
   {{0x200a637f,0x2ef500c4,0x6299f0c3,0x44e9c315}},	//   _gabi_, _изгр, _siwo, rú_,
   {{0x68ed0510,0x26def0c4,0x44e9d2b7,0xf1b98353}},	//   ltad, juto_, sú_, ljši_,
   {{0x26de8003,0x60c9f0c5,0x661b8289,0x6443f0c6}},	//   duto_, tsem, _unuk, shni,
   {{0x3949256c,0xe664919d,0x7bc1ad26,0xdb0502af}},	//   nzas_, _стро, _telu, _gehö,
   {{0xe7398188,0x60c99922,0x68ed0ece,0x7bc700d2}},	//   део_, rsem, itad, jaju,
   {{0x60c9f0c7,0x7bc70025,0x9f458388,0x68ed70c8}},	//   ssem, daju, veló_, htad,
   {{0xed5a3d00,0x68ed70c9,0x657b816f,0xdb1c70ca}},	//   дом_, ktad, _kyuh, jará,
   {{0xdb1c70cb,0xc692807c,0xda1e8035,0x26def0cc}},	//   dará, יאט_, भारत_, auto_,
   {{0x26def0cd,0x98798158,0x307980be,0x09ca0072}},	//   buto_, _קאַט, _קאַנ, िण्य,
   {{0x200a1ce9,0x39490144,0xfaa60dae,0xf8bf21ce}},	//   _rabi_, ezas_, табо, _awé_,
   {{0x200a02b8,0x68ed70ce,0xdb1c1ee8,0x3b0700a9}},	//   _sabi_, ftad, gará, њето_,
   {{0x65698168,0x64418198,0xe9df046d,0x68ed70cf}},	// [69c0] _nxeh, _olli, _amús_, gtad,
   {{0x7a3846da,0x161a13e5,0x2d9f8362,0x25adf0d0}},	//   _míti, धाकर_, _ague_, _afel_,
   {{0x7a380125,0x290f016d,0x657ba9cf,0x394927aa}},	//   _líti, ågar_, _ayuh, azas_,
   {{0xee3a8160,0x75d38013,0x947380d5,0xe9a6013a}},	//   ьне_, ليما, یدوا, _шамп,
   {{0x200a70d1,0x68ed11b9,0xd4e38009,0x200c831d}},	//   _tabi_, ctad, ающи, yddi_,
   {{0x61e407d9,0x07a6038c,0x5c7385e9,0x7d028559}},	//   lgil, _јавн, аліт, rwos,
   {{0x78a2f0d2,0x7a358177,0x15f40054,0x969681e5}},	//   _suov, _látu, ेजार_, _араш,
   {{0x61e44e1a,0x26de8081,0xd7e2001b,0x2281807b}},	//   ngil, vuto_, _पाँच, sókn_,
   {{0x2d848052,0x7e6281f4,0x7a3803f2,0x64a6865c}},	//   _uzme_, mnop, _cíti, _раза,
   {{0x26def0d3,0xdb1c05e4,0x7eb881a1,0x9f458037}},	//   tuto_, zará, нгос_, velò_,
   {{0x7bc70025,0xa3e7f0d4,0x2bdc1094,0x481500be}},	//   vaju, _भात_, _बाजा, אַרן_,
   {{0xf1e10996,0xf7730039,0x7d164acd,0xd00b00ab}},	//   _फाइन, יקת_, _brys, রায়_,
   {{0xe0469b56,0x0fe2016f,0x320b49d1,0x26de9a1a}},	//   _инди, _पांढ, _racy_, suto_,
   {{0x7a358e14,0x7e62f0d5,0x26dece4e,0x6458875e}},	//   _dátu, hnop, puto_, nivi,
   {{0x7bc75478,0xdb1c70d6,0xe81f95bc,0x82a42cab}},	//   raju, tará, बारा_, иште,
   {{0x68ed70d7,0xcbe300c8,0x7bc7002e,0x1fcb001b}},	//   ttad, য়েছ, saju, ाण्ड,
   {{0xdb1c2b74,0x68e084a7,0x6458b855,0x3a2902f7}},	// [69d0] rará, numd, kivi, rjap_,
   {{0x1621053e,0x394902ba,0xdb1c188b,0x6e3d4533}},	//   यावर_, rzas_, sará, lksb,
   {{0x660d70d8,0xdb1c4365,0x53354e1f,0x657b9600}},	//   _kaak, pará, _сент, _syuh,
   {{0xe7ff0321,0xb90900ab,0x2ca482f7,0xaee3026b}},	//   _उसका_, _মন_, _bumd_, _aiṣa,
   {{0xd1268bbe,0x660d70d9,0x58d40698,0x89da036b}},	//   _ام_, _maak, _коят, _אחרי,
   {{0x660d29b2,0x7a359f04,0x2a668122,0x69c681fa}},	//   _laak, _látt, _ajob_, ðken,
   {{0x629d4997,0x7a380187,0xed59807a,0x7bc570da}},	//   _kiso, _síti, _težo_, _mehu,
   {{0x200170db,0x660d4735,0x7a35807b,0x629d23c5}},	//   lehi_, _naak, _nátt, _jiso,
   {{0x629d651a,0x68e0be5b,0x3d94ad9c,0xe81f92c6}},	//   _miso, gumd, _витр, बाला_,
   {{0x7659864c,0x7b088009,0x7a380548,0x7bc570dc}},	//   liwy, ästä, _víti, _nehu,
   {{0x8eb2803d,0x660d0365,0xe2030072,0x7a359b9c}},	//   یمیش, _baak, _लसूण_, _bátt,
   {{0x60cd362c,0x7d1670dd,0x20cf00eb,0x68e0adac}},	//   ksam, _prys, kļi_, bumd,
   {{0x7bc503b2,0x61e403bf,0x7d0982f9,0xee37002e}},	//   _behu, vgil, _jses, уня_,
   {{0xd0068381,0x60dbaf1a,0x629d70de,0x7d1601b0}},	//   _беше_, mrum, _aiso, _vrys,
   {{0x60dbf0df,0xdea1815b,0xcb672e87,0x7bc50168}},	//   lrum, _دیجی, гаре_, _dehu,
   {{0x41b53ba1,0x7d161670,0x645880fa,0x629d0d56}},	//   исут, _trys, zivi, _ciso,
   {{0xdb1a8207,0x7644022e,0x60cd1066,0x7e62805c}},	// [69e0] _metá, _iliy, gsam, vnop,
   {{0x660d70e0,0xdb1a816b,0x7bc506a8,0x629d0114}},	//   _zaak, _letá, _gehu, _eiso,
   {{0x444470e1,0x7d09f0e2,0x6458f0e3,0x7a358019}},	//   _il_, _ases, vivi, _játs,
   {{0x64a695e3,0x5d6a8009,0xb05b00e1,0x629d0314}},	//   гада, нием_, _svät, _giso,
   {{0x444415f8,0x81e98a49,0x7bc501bf,0x7a358061}},	//   _kl_, য়া_, _yehu, _láts,
   {{0x444470e4,0x07a304db,0x69c670e5,0x83f882a4}},	//   _jl_, _гарн, _heke, текс_,
   {{0x69c670e6,0xb5fb001b,0x76441a1a,0xa3d50072}},	//   _keke, dnán, _oliy, हणत_,
   {{0x6458f0e7,0x5a349878,0xdd0881ac,0x444470e8}},	//   sivi, рнит, môže, _ll_,
   {{0x444470e9,0xb05b016d,0xdb1a802a,0x660d2d66}},	//   _ol_, _tvät, _detá, _raak,
   {{0x444470ea,0x764470eb,0x660d1ec1,0x68e0817b}},	//   _nl_, _aliy, _saak, rumd,
   {{0x764406c0,0x2a7f822c,0x049381a8,0x7bca81f6}},	//   _bliy, blub_, _اللح, mafu,
   {{0x69c670ec,0x7bc5010b,0xdb08816d,0x7bcaefff}},	//   _neke, _sehu, _bedö, lafu,
   {{0x44445a98,0x60dbbc77,0x629d70ed,0x3c398205}},	//   _bl_, crum, _riso, _sèvi_,
   {{0x7bcaadaf,0x660d276a,0x764470ee,0x9f5e80e7}},	//   nafu, _waak, _eliy, heté_,
   {{0x69c64ca3,0x629d6478,0x43950c6c,0xe2f810ac}},	//   _beke, _piso, равс, лері_,
   {{0x444470ef,0xf127025d,0x200ef0f0,0x78a610d3}},	//   _el_, льзо, _hafi_, _bukv,
   {{0xd49b6fdd,0x44443086,0x7bcaafb9,0x69c670f1}},	// [69f0] _про_, _fl_, kafu, _deke,
   {{0x444470f2,0x60cd6078,0xee3f001b,0x629d018e}},	//   _gl_, rsam, lký_, _wiso,
   {{0x200e80a4,0x69c61464,0x629d4a31,0xa2a48d86}},	//   _mafi_, _feke, _tiso, _चूल्,
   {{0x69c60574,0x2001059e,0x60cd70f3,0xb5fb01d0}},	//   _geke, sehi_, psam, znán,
   {{0x1d098d31,0xa5099017,0xb05b0338,0x7bcaf0f4}},	//   тели_, тела_, _dvär, fafu,
   {{0x69c60613,0x7bcaabea,0xab5c80eb,0x200e80ee}},	//   _zeke, gafu, _ceļo, _nafi_,
   {{0xb5fb001b,0x645700b9,0x249e8176,0x290b0580}},	//   vnán, _mmxi, _ditm_, _hsca_,
   {{0xa3e78665,0xd5f98158,0x6eaa064a,0xe8f988ed}},	//   _भाव_, _שפּר, _जंतु, вли_,
   {{0x7a3c80e7,0xdb1e02b7,0x681b00eb,0x7bcaca7d}},	//   _méth, _repí, _tādē, bafu,
   {{0xb4c18076,0xb8fd800f,0x60dbcd61,0x200eb827}},	//   ंठी_, _तट_, rrum, _cafi_,
   {{0xb5fb02ba,0x3f69a00d,0x69cf8333,0x200e9325}},	//   rnán, тино_, óces, _dafi_,
   {{0x44210104,0x7ae3bb81,0x64451aa3,0x60db9bc8}},	//   _anh_, munt, _alhi, prum,
   {{0x444470f5,0x69c61543,0x64a61330,0x44330039}},	//   _pl_, _reke, рага, _box_,
   {{0x7e6982fd,0x69c670f6,0x998480f7,0x93460d46}},	//   _ljep, _seke, _الهو, анге,
   {{0x69c62851,0x7e7b85e7,0x42560328,0x7ae3f0f7}},	//   _peke, _okup, атат, nunt,
   {{0xee3f0a56,0xc2433e1c,0x76440a6c,0x200e8041}},	//   cký_, онск, _uliy, _zafi_,
   {{0x444470f8,0xe29722be,0x2fc7f0f9,0x61ebcfc7}},	// [6a00] _tl_, рат_, _keng_, _mcgl,
   {{0x44441717,0x3ea78613,0x7ae39413,0x69c60a0f}},	//   _ul_, _kunt_, kunt, _weke,
   {{0xeaf4853e,0x69c606dc,0x645c70fa,0x7ae3b009}},	//   _आहेत_, _teke, miri, junt,
   {{0x645c6601,0x320f8065,0x7e6994ce,0x13a8026a}},	//   liri, _nagy_, _cjep, _جنگی_,
   {{0x7bcaf0fb,0xcfaa006b,0x44330085,0x9f5e8036}},	//   tafu, _لازم_, _yox_, reté_,
   {{0x645c1f37,0x2fc78077,0x67210699,0x394d80eb}},	//   niri, _neng_, _šlje, dzes_,
   {{0x7ae3df98,0xa3e78054,0x68e428a9,0xb05b016d}},	//   gunt, _भार_, luid, _tvär,
   {{0x7a380510,0x645c51a0,0xfb198065,0x200ef0fc}},	//   _títu, hiri, اروں_, _safi_,
   {{0x645c70fd,0xe8df0104,0xfbc604e5,0x68e41493}},	//   kiri, _việc_, वराम, nuid,
   {{0x645c70fe,0x7ae3f0ff,0x7a3c82be,0x249e83ac}},	//   jiri, bunt, _méti, _uitm_,
   {{0x645c7100,0x2fc7f101,0xcb679c9b,0x2d8000ee}},	//   diri, _deng_, _кафе_, _ayie_,
   {{0x8c3c87d9,0xe7ea9513,0x60c2c227,0xd6d80264}},	//   _diğe, ज्जा_, _twom, _সহায,
   {{0x7bc89a6e,0x645c7102,0x443300b9,0x261c05fc}},	//   _kedu, firi, _pox_, याजी_,
   {{0x645c6163,0xee3f0400,0xe0fb8039,0x2fc7f103}},	//   giri, ský_, _סלול, _geng_,
   {{0x224903f8,0xeaf4816f,0x224685e6,0x31c7157b}},	//   thak_, _आहोत_, _klok_, исав,
   {{0x645c00f7,0x7bc897cf,0x3ea002c4,0x3e72016b}},	//   airi, _ledu, _giit_, káty_,
   {{0xe29f1ca8,0x645c2ac2,0x765d6105,0x224932bb}},	// [6a10] _við_, biri, misy, rhak_,
   {{0x7e7b836f,0x2fc70104,0x765d7104,0x645c5e8c}},	//   _skup, úng_, lisy, ciri,
   {{0x261c1880,0x7ae381df,0x2246978f,0x81de80ab}},	//   याची_, xunt, _olok_, দ্য_,
   {{0x32048063,0x765d0247,0x68e44701,0x7d0d0326}},	//   jemy_, nisy, buid, _ksas,
   {{0xb4c18076,0x7bc8f105,0x38c9004e,0x68e40333}},	//   ंठे_, _bedu, _حاجی_, cuid,
   {{0x7ae3f106,0xfaa582cb,0x2246ad1f,0x1cb80039}},	//   tunt, бако, _alok_, סלול_,
   {{0x25e8035a,0x8b948098,0xdb15016a,0x2ca902c4}},	//   _झाली_, оръч, mazó, _luad_,
   {{0x7ae3f107,0x7e7bf108,0x3ea780f2,0x2fc7e86a}},	//   runt, _ukup, _runt_, _seng_,
   {{0x3ea78c6e,0x320f8117,0x20111b86,0x26de9966}},	//   _sunt_, _vagy_, _kazi_, erto_,
   {{0x3ea7f109,0x7bc8f10a,0x22468ad4,0x3ea00074}},	//   _punt_, _gedu, _elok_, _siit_,
   {{0x394d8065,0x2246f10b,0x2011710c,0xa3ac923a}},	//   szes_, _flok_, _mazi_, _गलत_,
   {{0x29093a87,0x7bd704c3,0x7d1b9de0,0x2ca90239}},	//   kwaa_, _adxu, _krus, _buad_,
   {{0x645c6c09,0xba748013,0xa8a7a902,0x2fc7f10d}},	//   tiri, _بالت, _трек, _teng_,
   {{0x61e98b11,0x81ae80ab,0xaf49845b,0x3dd804b7}},	//   lgel, করণ_, _مشعل_, _żewġ_,
   {{0x2005a7bf,0x7d0d0d6a,0x765d25e3,0x28ddc32e}},	//   meli_, _esas, bisy, _मिडि,
   {{0x61e98ded,0x645c710e,0x68e42755,0x2005f10f}},	//   ngel, siri, tuid, leli_,
   {{0x645c7110,0x20113b3a,0x6e247111,0xdb170118}},	// [6a20] piri, _bazi_, _inib, _xexú,
   {{0xdb1507f4,0x66062f6b,0x68e47112,0x2240067f}},	//   gazó, lekk, ruid, skik_,
   {{0x7afe2459,0x7d1bf113,0xb5fb016b,0x61f63a79}},	//   _uppt, _arus, znám, pfyl,
   {{0x7bc8f114,0x7bce7115,0x80d893f5,0x7a3cf116}},	//   _sedu, labu, _मिले, _hétv,
   {{0x7bc8c81e,0x2005d398,0x644a80f7,0x61e981b4}},	//   _pedu, keli_, thfi, dgel,
   {{0x200582ce,0x7bce4a70,0x765d142a,0x3e72027f}},	//   jeli_, nabu, zisy, ráty_,
   {{0x6e247117,0x753d009a,0x61e9f118,0x66e30a42}},	//   _onib, zysz, fgel, _нора,
   {{0x2618057a,0x61e9bdac,0x9f58047f,0x7bce6812}},	//   _बोली_, ggel, _farò_, habu,
   {{0x7bce4982,0x765d7119,0x7bc88359,0x7d1bf11a}},	//   kabu, visy, _tedu, _grus,
   {{0x6b81b8b9,0x2005e1bf,0x7bce005d,0x27178129}},	//   _fylg, geli_, jabu, _băn_,
   {{0x43868064,0x907b012a,0x765d0247,0x28dde5a5}},	//   _الاق, רטיי, tisy, _मिथि,
   {{0xdb1a8198,0x2ca900b9,0xf99f010c,0x3f8281a9}},	//   _vetä, _puad_, _kaèt_, āku_,
   {{0xb9968013,0x765d6924,0x91e382c7,0xdb1e002a}},	//   _الشب, risy, _хоче, _repá,
   {{0x765d10c1,0x26de8353,0x9f5ef11b,0x2005f11c}},	//   sisy, prto_, letí_, celi_,
   {{0x765d711d,0xa3d0b064,0x66062c9f,0x9f4ca4fe}},	//   pisy, _वजन_, bekk, redó_,
   {{0x62840698,0x2aa8148d,0x2909004f,0x7f8381a8}},	//   glio, стро_, twaa_, _علين,
   {{0x51871507,0x38351b06,0x7bce4a7d,0x621b83de}},	// [6a30] сува, онар, babu, נומק,
   {{0x6aa28706,0x7d1b83ed,0x9998002e,0x81ae8264}},	//   _liof, _rrus, скут_, করি_,
   {{0xdb15711e,0x7d1b8042,0xdcfb816b,0x9f58047f}},	//   razó, _srus, _vyuč, _sarò_,
   {{0x2005b4e6,0x6448811e,0x20112767,0xceb380be}},	//   zeli_, _aldi, _wazi_, ליע_,
   {{0x2005805d,0x7ae71b49,0x7e6d43a4,0x61e9826c}},	//   yeli_, lujt, _mjap, vgel,
   {{0x42d98750,0x987900be,0x26c28390,0x20059598}},	//   афия_, _כאָט, ćkoj_, xeli_,
   {{0x61e98c72,0xa3b886a7,0xfd4a18b2,0xa2299cf2}},	//   tgel, चड़_, _bulọ, ижка_,
   {{0xe0d980ae,0x8c0980c8,0x2005a767,0x6448e6f5}},	//   ави_, লাইন_, weli_, _eldi,
   {{0x61e9f11f,0x2d99c372,0x7bce22eb,0xdb18816b}},	//   rgel, _àse_, yabu, mavý,
   {{0x7ae77120,0x61e9f121,0x6e367122,0xd7660065}},	//   kujt, sgel, _soyb, _انہی,
   {{0x81de80c8,0x61e9998b,0x6443809a,0x61fd0831}},	//   দ্ধ_, pgel, mkni, _obsl,
   {{0x27178104,0x4425973d,0x64438082,0x7ae7026f}},	//   _văn_, _hnl_, lkni, dujt,
   {{0xa5bb0125,0x7bce0542,0x66064356,0xe8ee8b69}},	//   tjór, tabu, rekk, _юл_,
   {{0xf7459814,0x64438bbd,0x2d8d8010,0x66062872}},	//   _мело, nkni, _mzee_, sekk,
   {{0xa3e7901b,0x7bce7123,0x69cb8057,0x4911800d}},	//   _भाई_, rabu, _kege, तिको_,
   {{0x6e2467c0,0x7bce206d,0xa2cc80d4,0x69cb8eb9}},	//   _unib, sabu, _सबस्, _jege,
   {{0x69cbea04,0x7bce2488,0xb33c822b,0x62847124}},	// [6a40] _mege, pabu, _agħl, rlio,
   {{0x61ef1ad0,0x69cbce6c,0xb90203ca,0x6721011f}},	//   _eccl, _lege, _धि_, _šlja,
   {{0xeda682de,0x62842f37,0x1eda00f7,0xdb0500ff}},	//   ошло, plio, شباب_, _nghè,
   {{0x69cbf125,0x5efa8158,0x0d86c504,0x5bb4b731}},	//   _nege, יפעד, олен, ुर्व,
   {{0xc27b0051,0x764280dd,0x2c0f016f,0xb33c8197}},	//   _כרטי, rkoy, ायचं_, _egħl,
   {{0x764984be,0x2bbf1a4d,0x8cdbaa90,0x442587f1}},	//   _eley, ्रया, _निरो, _cnl_,
   {{0x68f60a53,0x2d8d85ee,0x7649f126,0x290f82ed}},	//   ltyd, _ezee_, _fley, _asga_,
   {{0x7649807b,0xb95b0091,0x26d88298,0x4425be43}},	//   _gley, _adìy, árom_, _enl_,
   {{0xed5a8003,0x69cbf127,0x2bbf0d14,0x661d807b}},	//   _тоа_, _dege, ्रमा, _óska,
   {{0x644380f2,0xdced080a,0x290f8037,0x291d8176}},	//   ckni, _ayağ, _dsga_, _drwa_,
   {{0xc7b30051,0x3eb88168,0x41aa1b91,0xd7f88162}},	//   ובת_, ërt_, कशास, rfă_,
   {{0x69cb8c1b,0x8b65ce5c,0xdb1f237b,0x78a389e7}},	//   _gege, _عالم, ðvík, _einv,
   {{0xb5fb00f7,0xa06a84ae,0x225787d2,0xb86582e3}},	//   nnái, _када_, _بلند_, _کانو,
   {{0x7ae72365,0x61ef0122,0x69cbf128,0xaaa986a7}},	//   tujt, _sccl, _zege, _चूँक,
   {{0x3a268cab,0xd25b0a9f,0xb5fb0061,0x69cb8314}},	//   _knop_, аца_, riáb, _yege,
   {{0x7ae72950,0x42db80be,0xdb1a8144,0x78a3890d}},	//   rujt, יקלע, _betú, _zinv,
   {{0x37ab1182,0x25a90074,0x7ae7467b,0xc69400be}},	// [6a50] атен_, _igal_, sujt, _קאפ_,
   {{0x7ae7136f,0x7a3c8061,0xb33c822b,0x7bde8144}},	//   pujt, _kéts, _agħm, ópul,
   {{0x7649f129,0xaaa98105,0x64800009,0xb5fb4315}},	//   _pley, _चूंक, röit, ciác,
   {{0x9f58007b,0x8f9b8039,0x2d9984e8,0xdb05027d}},	//   _varð_, ביבי, _úsek_, _nghé,
   {{0x69cb87b3,0x5184012f,0x44258087,0xc984002e}},	//   _rege, _жура, _pnl_, _жури,
   {{0x69cbf12a,0x61ed712b,0x7e7d712c,0x78ab80c3}},	//   _sege, lgal, hosp, _rugv,
   {{0x64438bfa,0x81ce00c8,0xfe7392dc,0x224df12d}},	//   rkni, _রাত_, _قدر_, thek_,
   {{0x765b82a0,0x6443d42a,0xefc8001c,0x00c98e8e}},	//   _umuy, skni, _đỉnh_, блик_,
   {{0x7e7d6783,0x7a3c8125,0x225fcdb7,0xddc4017f}},	//   dosp, _rétt, riuk_, _njiš,
   {{0xa2dc123a,0x69cb9cd9,0x25a9002a,0x25b6175d}},	//   _फिल्, _wege, _agal_, ूर्ण,
   {{0x69cbf12e,0x2cad8609,0x224dee2c,0x2019928a}},	//   _tege, _hued_, phek_, ěsi_,
   {{0x3ea400f2,0x63b5009a,0xaca3801c,0x291d8035}},	//   ömt_, eczn, _trồn, _trwa_,
   {{0x61ed712f,0x78a382a6,0xe16781a8,0xed598bcf}},	//   dgal, _tinv, _بداي, _težu_,
   {{0x25a97130,0xe1ff0091,0xd47980be,0x78a3808e}},	//   _egal_, _abó_, מאָל, _uinv,
   {{0xd00e8307,0x68e98c0b,0x8b23199a,0x7e6b82d5}},	//   _إلى_, lued, ндре, kngp,
   {{0xcb12893f,0x61ed7131,0x9f96807c,0x57568039}},	//   עלן_, ggal, _צדקה_, _מבצע_,
   {{0xdb1c0e15,0x80a63945,0x9abc82a6,0xb5fb15d8}},	// [6a60] mbrí, سمان, _irċe, siác,
   {{0x61ed0365,0x6f0388ae,0x3ea4e8b1,0x68f61a29}},	//   agal, _kpnc, _simt_, rtyd,
   {{0x645e4fb4,0x443a4300,0xe4570158,0x8cb20540}},	//   _impi, _iop_, _זייט_, _इंडो,
   {{0xe1ff077f,0x7a3c8019,0x3a390639,0x2d848661}},	//   _gbó_, _létr, _gosp_, _pyme_,
   {{0x69c47132,0x2ca58cb4,0x443a3e02,0xdb1c00f7}},	//   mbie, _bild_, _kop_, ibrí,
   {{0x69c47133,0xb5fb00f7,0x7d040c2e,0xe81b82f1}},	//   lbie, rnái, _mpis, _भोला_,
   {{0x443a02ee,0x6ada06a7,0x60230071,0xaab89190}},	//   _mop_, _बटोर, _ядра, زگار_,
   {{0x7d047134,0x68e407a3,0x69c435cd,0x443a0129}},	//   _opis, orid, nbie, _lop_,
   {{0x63b50063,0xfce39232,0x588681e5,0x68e98114}},	//   yczn, _пото, зына, gued,
   {{0x645d8110,0x7e6285fe,0x68e41581,0xbc639033}},	//   _įsig, liop, irid, _звук,
   {{0x68e47135,0x7a3c80e7,0xa2b14a21,0xb914819d}},	//   hrid, _détr, _आंध्, _yadị_,
   {{0x645e2307,0x648d80f7,0x68e43ca5,0x69c4051c}},	//   _ampi, núin, krid, jbie,
   {{0x6d42f136,0x7aea93c2,0x69c47137,0x51839bf5}},	//   nyoa, luft, dbie, _пуша,
   {{0x2ca51e18,0x7e62f138,0x69c4413a,0x9f580216}},	//   öld_, hiop, ebie, _abrí_,
   {{0xb5fb003e,0x1dcc8b84,0x61ed2b47,0xd5cc9b91}},	//   dnáv, ारात, tgal, ाराज,
   {{0x81de80c8,0x7c3af139,0x61ed713a,0x62340073}},	//   দ্র_, _lotr, ugal, несу,
   {{0x61ed713b,0x68e4713c,0x7c28dbdf,0x3eae82f7}},	// [6a70] rgal, grid, _ondr, _huft_,
   {{0x7c3af13d,0x37ab1537,0x61ed110a,0x3014002e}},	//   _notr, стан_, sgal, ндур,
   {{0x69c44271,0x442b801c,0x68e402f1,0x212b8129}},	//   bbie, _đc_, arid, ̣ch_,
   {{0x7c288082,0x28dd946d,0x7c3a8229,0xf2d200be}},	//   _andr, _मिलि, _aotr, _בעט_,
   {{0x2ab187a3,0x26d868b7,0xa3b1131d,0x1c22009a}},	//   _sáb_, _evro_, _ओला_, माचल_,
   {{0x6282f13e,0x7c3a8493,0xd7f81860,0x05748180}},	//   _akoo, _cotr, _нус_, راند,
   {{0x69cf059c,0xfbd080f7,0x764d21e8,0x2ca5806a}},	//   _kece, اته_, _olay, _vild_,
   {{0x7c28a46a,0x7e628706,0x69cf0079,0x2fce8176}},	//   _endr, ciop, _jece, _aefg_,
   {{0x61fba445,0x2cad8074,0x7a3cb6b5,0x7c3adf69}},	//   rful, _uued_, _pétr, _fotr,
   {{0x09aa1344,0x764d713f,0xddc280fe,0xefc80104}},	//   _कल्य, _alay, mnoš, _định_,
   {{0x69dd2b0d,0x7d04054f,0x6e3bcb57,0x443a7140}},	//   _odse, _spis, _koub, _rop_,
   {{0x69cf2d12,0xb5fb026f,0x2b4f8214,0x443a5e75}},	//   _nece, znáv, ımcı_, _sop_,
   {{0x205595e0,0x68e9a3a5,0x6e3b8bb1,0x629b80e5}},	//   _откр, qued, _moub, mmuo,
   {{0x69dd5990,0x7d040353,0x6e3bf141,0x6289f142}},	//   _adse, _vpis, _loub, lleo,
   {{0xdca30f2f,0x7d040063,0x64a30a8e,0xddcb005c}},	//   тари, _wpis, тара, žišn,
   {{0x7ae10065,0xd0480086,0x69cf7143,0x2a6ddeb2}},	//   álta, ələr, _cece, nneb_,
   {{0x443a7144,0x7d04003a,0x78a70a0f,0xda6515a9}},	// [6a80] _top_, _upis, _bijv, رافي,
   {{0xb8f64e8f,0xddc2805c,0x69c47145,0x645e4008}},	//   _सब_, dnoš, sbie, _umpi,
   {{0x6e3b9c9f,0x6289f146,0x69cf64a5,0xe61ab9df}},	//   _boub, kleo, _fece, жде_,
   {{0xa3d0823c,0x69cf7147,0x7c288359,0x93ee0bb8}},	//   _वजह_, _gece, _sndr, _जाँच_,
   {{0x6da3a4dd,0xc8798380,0xb33c8372,0xe5a39092}},	//   вица, luşu_, _igħi, вици,
   {{0x6282879f,0xf1bf8e15,0x7e629aef,0xdb072578}},	//   _skoo, ñán_, siop, rbjö,
   {{0x7c3a86e3,0x161985b3,0x6289831d,0xdb1c3bdd}},	//   _votr, _नोकर_, fleo, maró,
   {{0x201870bf,0x37e300ab,0x41e68221,0xb33c84b7}},	//   _hari_, ন্দর, фіка, _jgħi,
   {{0x93ee023c,0x95839401,0x3f878079,0x6282808e}},	//   _जांच_, _алте, _aynu_, _vkoo,
   {{0x201835a3,0x7c288bcb,0x47348fe7,0xdb1c01a8}},	//   _jari_, _undr, енос, naró,
   {{0x764d7148,0x2bbf04c5,0x26d88866,0x9b468c3b}},	//   _play, ्रसा, éro_, _تناو,
   {{0x20187149,0x81e400ab,0x21298267,0xbddb00e7}},	//   _lari_, প্ত_, _šahe_, thèq,
   {{0xdc3a02bb,0x6280e30c,0x981380d7,0x25ad07dd}},	//   _açıl, momo, ربیا, želo_,
   {{0x6280bf45,0x2018130e,0xb5fb016a,0x28b5064a}},	//   lomo, _nari_, cián, _अंबि,
   {{0x200cc3f0,0x69cf3e92,0xd6cf98ed,0x8aa73941}},	//   medi_, _pece, _шт_, драд,
   {{0x764d0010,0x1da71834,0xdb1200f7,0x2018020d}},	//   _ulay, _गणपत, ógái, _aari_,
   {{0x20180f69,0x69cf158d,0x6e3b89b2,0xb33c8197}},	// [6a90] _bari_, _vece, _roub, _dgħi,
   {{0x20180393,0x6e3b800d,0xdfd10013,0x26000006}},	//   _cari_, _soub, ايا_, ष्ठी_,
   {{0x20181dda,0x6280acf2,0x3ea95a84,0xb8d619a1}},	//   _dari_, komo, _kiat_, _चू_,
   {{0xb05b1bd7,0xb93500a9,0x69dd006a,0x2bbf0aed}},	//   _städ, _земј, _udse, ्रवा,
   {{0x6280d2fa,0x2018714a,0x3ce6f14b,0xe3a51190}},	//   domo, _fari_, grov_, _تشکی,
   {{0x201848d8,0x200c82fd,0x3ea90877,0xf8bf714c}},	//   _gari_, jedi_, _liat_, _crée_,
   {{0x27f8026f,0xe78446ca,0x6e3b9f5a,0x68ed6d53}},	//   žený_, _ауто, _toub, luad,
   {{0xe9d99e16,0x3ea9059c,0x62808110,0x201800b4}},	//   чки_, _niat_, gomo, _zari_,
   {{0x20180578,0x5c75860a,0x9f5e8009,0x629b8110}},	//   _yari_, _злат, hetä_, rmuo,
   {{0x1bee05b3,0xc05200be,0xb5fb016b,0x271e8609}},	//   _जाइल_, ָזט_, znát, _bċn_,
   {{0x6289f14d,0xb5fb0c83,0x22b8714e,0x7bd5714f}},	//   pleo, rián, _očka_, dazu,
   {{0xf772010f,0xf6521a05,0x248582c4,0xee373941}},	//   רקט_, ائد_, _hklm_, еню_,
   {{0x61d68039,0x200cb426,0xe1ff007b,0xb7d58032}},	//   _נוסף_, bedi_, _ljós_, _aṣer,
   {{0x68ed2755,0x200cf150,0x6f150035,0x26dc01d6}},	//   duad, cedi_, _oszc, ávok_,
   {{0xf8bf3ac8,0xa3c2823c,0x20184bac,0xaca3819d}},	//   _até_, ूरत_, _rari_, _apịn,
   {{0xc3328bea,0x2cbf80d2,0xf2d280be,0x629c8037}},	//   נון_, _otud_, טעל_, _èrot,
   {{0x2018010a,0x66040a6d,0x26d881ac,0x68ed3009}},	// [6aa0] _pari_, _ibik, árov_, guad,
   {{0x6d466321,0xb4fb0051,0x7e661a9a,0x20187151}},	//   myka, _צפיי, likp, _qari_,
   {{0x20180a45,0x6d460190,0xb33c81b9,0x75240088}},	//   _vari_, lyka, _tgħi, _hriz,
   {{0x3ce6e3db,0xee3ab2a7,0x201802a0,0x6723817f}},	//   trov_, яне_, _wari_, _mrnj,
   {{0x7c3e0988,0x68ed02ba,0x6280f152,0xb5fb7153}},	//   _kopr, cuad, vomo, onár,
   {{0x28b51094,0x7c3e00eb,0x60c41269,0x2bfba776}},	//   _अंति, _jopr, mpim, ल्लू_,
   {{0x6fd6823c,0x68fbee2d,0x6280d288,0xe8e000ff}},	//   _मजबू, etud, tomo, _ruột_,
   {{0xd257dc6f,0xdff00b85,0x69d62c81,0x98c68fbf}},	//   ець_, _चाँद_, naye, нсол,
   {{0x68fbbd8b,0x50669597,0xc8668ff7,0x998004b7}},	//   gtud, етна, етни, jjiż_,
   {{0x6280c056,0x66040121,0x672380d2,0x3ea97154}},	//   somo, _abik, _brnj, _siat_,
   {{0x442c8ae1,0x200cbc1e,0x69d67155,0x6280f156}},	//   _ind_, redi_, kaye, pomo,
   {{0xb5fb03b0,0x2120003a,0x200c9a54,0x443e8039}},	//   ciál, kvih_, sedi_, _hot_,
   {{0x443ea588,0x200cc4bd,0x38b600b2,0x5c070098}},	//   _kot_, pedi_, _nær_, нява,
   {{0x62867157,0x31578158,0xddc9920e,0x7c3e2546}},	//   _akko, _אידן_, _mješ, _copr,
   {{0x443ef158,0x7c3e26ef,0x7bd53b3a,0xc4c48117}},	//   _mot_, _dopr, razu, _گے_,
   {{0x69d63a0f,0x98a7026c,0x443e824d,0xdb1a8168}},	//   gaye, _điđa_, _lot_, _aftë,
   {{0x60f91006,0x442c8355,0x660f003e,0x6ca71ff3}},	// [6ab0] ьная_, _ond_, meck, _прож,
   {{0x443e804c,0x28e20076,0x661d7159,0x660f4ea7}},	//   _not_, _पिरि, ldsk, leck,
   {{0xbbbf0bb8,0x68ed05ee,0x69d6715a,0xe8020006}},	//   ्रीक, suad, baye, _रउरा_,
   {{0x442cf15b,0x661d1da3,0x660f026f,0x38b6715c}},	//   _and_, ndsk, neck, _fær_,
   {{0xed588cde,0x68ed715d,0x442c82f7,0x38b6007b}},	//   ної_, quad, _bnd_, _gær_,
   {{0xe522715e,0x442cf15f,0x7e66026c,0x660f490d}},	//   मिति_, _cnd_, zikp, heck,
   {{0x998d8bcf,0x6f150035,0xa7fc811c,0x443ef160}},	//   dješ_, _uszc, hnıs, _dot_,
   {{0x442c8039,0x68fba181,0x78aa8037,0x661d184e}},	//   _end_, ttud, _aifv, jdsk,
   {{0xb5fb1c32,0x443ef161,0x660f1d78,0x442c8362}},	//   riál, _fot_, deck, _fnd_,
   {{0x6e2d7162,0x661bf163,0x68fbf164,0x7d09f165}},	//   _anab, _hauk, rtud, _ipes,
   {{0xdddb801b,0x661b8f52,0xaca30133,0xdb1c007b}},	//   _zkuš, _kauk, _chọg, jarð,
   {{0x7c3e7166,0x2f548e86,0x6723f167,0x661badab}},	//   _sopr, утьс, _vrnj, _jauk,
   {{0x69c99a2b,0x0d990fe6,0x443e8176,0x9599143d}},	//   mbee, етры_, _yot_, етру_,
   {{0x661bf168,0xe73184c0,0x69c98079,0x69d61c54}},	//   _lauk, _نصب_, lbee, waye,
   {{0xe739835f,0x38b6286c,0xdb1c008b,0xaca3019d}},	//   _цей_, _sær_, garð, _ghọg,
   {{0x26c5a755,0x661bf169,0x69c9b44c,0x628d716a}},	//   mplo_, _nauk, nbee, glao,
   {{0x69d63869,0xa3c1886a,0x7aee30e8,0x7c3e0214}},	// [6ac0] raye, ंडा_, subt, _topr,
   {{0xddc982fd,0x0b460002,0x69d6716b,0x38b60b40}},	//   _rješ, _анон, saye, _vær_,
   {{0x7d0983a7,0x68e9831d,0x443ef16c,0xdddb8796}},	//   _apes, hred, _rot_, _skuš,
   {{0x443ef16d,0x38b6716e,0xddc9920e,0x60db87b8}},	//   _sot_, _tær_, _pješ, ksum,
   {{0x661bf16f,0x443e9603,0x9cb380f7,0x68e9f170}},	//   _dauk, _pot_, لمنت, jred,
   {{0xddc9920e,0x8d5b0039,0xddc2816b,0x7d090315}},	//   _vješ, וכני, dnoť, çesi,
   {{0x443ebcb6,0xdb1a8c52,0x442c801c,0x68e9f171}},	//   _vot_, _retó, _vnd_, ered,
   {{0x68e9aaae,0x69c9d559,0xddc98d26,0xf2d301c6}},	//   fred, gbee, _tješ, בעה_,
   {{0x660f7172,0x6fd6823c,0x6da39a4e,0xd0108013}},	//   veck, _मजदू, _вита, ملة_,
   {{0x442cf173,0x6e2d04b8,0x67210024,0x7054804e}},	//   _und_, _snab, _šlji, اندا,
   {{0x660f1f1c,0x1df901bb,0x7640c8ce,0x7bd8f174}},	//   teck, нены_, _komy, mavu,
   {{0xe8022714,0x26f2800f,0x68e993c2,0xc8e200d4}},	//   र्ता_, _अमीर_, bred, _पिंट,
   {{0x660f632e,0x2cac81e0,0x3dd780ab,0xb884001b}},	//   reck, _kidd_, _হামল, _zvíř,
   {{0x7bd8cb31,0x1dc318b1,0x26d88061,0x60cd82d0}},	//   navu, _व्रत, áros_, _çama,
   {{0xe5c71ca4,0x07f789d7,0x7e64008e,0xa3d4016f}},	//   _испо, _شروع_, _fmip, _हजर_,
   {{0x35f50b87,0x2c6d026c,0x201c8061,0xf8bf1abb}},	//   _спир, džde_, _havi_, _aréa_,
   {{0x51871507,0x7bd8f175,0x201ca847,0x661b8a41}},	// [6ad0] тува, kavu, _kavi_, _rauk,
   {{0x201c80ce,0x661bd511,0xdbcd007b,0x75228259}},	//   _javi_, _sauk, _góðu, dvoz,
   {{0x7d09f176,0x61e29f1c,0x661ba6a8,0x97a75e2d}},	//   _spes, _odol, _pauk, трал,
   {{0x60c2f177,0x201c8247,0x7bca81c0,0x61e2f178}},	//   _otom, _lavi_, ebfu, _ndol,
   {{0xf1bf077f,0x66d90032,0x752280c3,0x76408f39}},	//   _ifá_, _bùká, gvoz, _domy,
   {{0x68e98289,0x61e2f179,0x291904b7,0x7bd8f17a}},	//   vred, _adol, _issa_, gavu,
   {{0x60c2f17b,0x9f3400e8,0x8c428ada,0x661bb195}},	//   _atom, _кері, сеще, _tauk,
   {{0x60dbd3d7,0x2126808e,0x76408176,0xe81b82f1}},	//   tsum, _broh_, _gomy, _भोजा_,
   {{0x69c9bd43,0x201c803b,0x39491400,0x7fd58a4c}},	//   rbee, _bavi_, nyas_, ліні,
   {{0xf4849cfd,0x0495803f,0x2a6901e9,0x201c847f}},	//   _кухн, _صلاح, hiab_, _cavi_,
   {{0x68e9935a,0x60dbe82c,0x201c82df,0x212689c4}},	//   sred, ssum, _davi_, _eroh_,
   {{0x29195e35,0x6441b60b,0x3949566a,0x21268192}},	//   _ossa_, _holi, kyas_, _froh_,
   {{0x3ead822b,0x28dd9130,0x62581b9c,0x49dac787}},	//   _miet_, _मिटि, _híog, _سانگ_,
   {{0xfbe580c8,0x64418866,0x3eadaae9,0xfba5036d}},	//   প্রত, _joli, _liet_, _गृहम,
   {{0x91e6220b,0x09e62a28,0x2919333e,0x3ce90072}},	//   лове, ловн, _assa_, _जिथे_,
   {{0x3ead9dea,0x42552c87,0x6441e0a2,0x7bd8b98b}},	//   _niet_, атут, _loli, zavu,
   {{0x0e9b0039,0x7bd8f17c,0x2d8d819d,0x9e650e06}},	// [6ae0] _אשקל, yavu, _nyee_, _خاون,
   {{0x6441f17d,0x69cb008b,0x201cf17e,0x25bf8326}},	//   _noli, ðger, _xavi_, _aful_,
   {{0x291929b3,0x93fb00be,0x7640809a,0x224d8019}},	//   _essa_, _אליי, _pomy, kkek_,
   {{0x201c011f,0xd01c80ab,0x64418326,0xdb1c05ec}},	//   žvi_, তায়_, _aoli, rbrä,
   {{0x6441928d,0x6602ae55,0x044690ca,0xa0760198}},	//   _boli, rfok, ледн, _бывш,
   {{0x224d808e,0x61f60114,0x29004778,0x644e717f}},	//   ekek_, lgyl, mtia_, nkbi,
   {{0x7bd8f180,0x3d1609c8,0x29000722,0x9696f181}},	//   ravu, _पैसे_, ltia_, _браш,
   {{0x3eada796,0x77910416,0x6441b83e,0x998907c0}},	//   _giet_, _بیما, _eoli, ndaş_,
   {{0x29002894,0xa2bb0f0f,0x286a9e4e,0xd7fac792}},	//   ntia_, _शून्, ерно_, нун_,
   {{0x0d759006,0x3ead8a0f,0x29006555,0x64a68791}},	//   _тыся, _ziet_, itia_, _саза,
   {{0xa3c181fe,0x29000198,0xde5900e8,0x201c867f}},	//   ंडर_, htia_, вані_, _vavi_,
   {{0x22421786,0x2a69022c,0xe7e0801b,0x644e0299}},	//   _nokk_, xiab_, _गएका_, ekbi,
   {{0x60c2f182,0x80b002f1,0xf992bdf2,0x201cf183}},	//   _utom, _अंगे, _ابا_, _tavi_,
   {{0x2a6681c0,0x6441ce90,0x6458f184,0x29190f3e}},	//   _hmob_, _xoli, nhvi, _rssa_,
   {{0x56950698,0xce950098,0x7ac4004a,0x2d840192}},	//   _какт, _какъ, йсте, ümer_,
   {{0x1fdd00ba,0x7ae85675,0xea019029,0x26def185}},	//   मण्ड, ádta, _đẫy_, msto_,
   {{0x52d18b9f,0x3f980267,0x19580a14,0x3eaddb99}},	// [6af0] _सब्स, _azru_, гаты_, _riet_,
   {{0x7d0d3308,0x2a6901c5,0x26dec7f8,0x3eadf186}},	//   _ipas, siab_, osto_, _siet_,
   {{0x64418aa8,0xdb1e0510,0x3ead8cfa,0x29007187}},	//   _roli, _depó, _piet_, atia_,
   {{0x2bbf0778,0x6441b110,0x51870992,0x7d0d01bc}},	//   ्रका, _soli, _буга, _kpas,
   {{0xa3c1800f,0x2900002e,0x3ead801c,0x62580473}},	//   ंडल_, ctia_, _viet_, _díod,
   {{0x26ded154,0x80c380c8,0x68ed01e4,0x6721192c}},	//   ksto_, _শিল্, mrad, _šlju,
   {{0x64418b5d,0x7bd70118,0x68ed7188,0x26deb351}},	//   _voli, _mexu, lrad, jsto_,
   {{0xc245a72f,0x7bd75203,0x69cd0683,0x68ed0c41}},	//   рник, _lexu, nbae, orad,
   {{0x68ed7189,0x6441f18a,0xe0d68a7f,0x26dea591}},	//   nrad, _toli, авы_, esto_,
   {{0x7d1bf18b,0x7e6b83ba,0xaf059be4,0x6fe001d0}},	//   _isus, ligp, апол, mácí,
   {{0x68ed0775,0xd37180f7,0x7d0d2b91,0xfb15826a}},	//   hrad, _بها_, _apas, _خواج,
   {{0x68ed1e50,0xd13180f7,0x7529bb19,0x76598114}},	//   krad, _وما_, _krez, nhwy,
   {{0x68ed24c8,0x463a83de,0x528481a8,0xb0640799}},	//   jrad, דערע, _النك, nmäß,
   {{0x8fa5a2f7,0xb05b2a9c,0x752981dd,0x7e6b820d}},	//   _кале, _stän, _mrez, higp,
   {{0x05d581fe,0x6609f18c,0xdb1e718d,0x7e6b8bb1}},	//   दराब, _obek, _repó, kigp,
   {{0xbbd1800d,0x290030b9,0x68ed718e,0x212d0267}},	//   हरुक, ttia_, frad, _šeha_,
   {{0x68ed2921,0x7d1b8146,0xe3b20829,0x98e601a8}},	// [6b00] grad, _nsus, _ورد_, شكاو,
   {{0x60c982be,0x69db82af,0x2900718f,0xdb1e03ec}},	//   ipem, haue, rtia_, _depò,
   {{0x44440698,0x7d1bdbaa,0x7bdc35c5,0x7529f190}},	//   _io_, _asus, maru, _arez,
   {{0x7529c14d,0x7bc1b28d,0x8f9a8039,0x3ced011f}},	//   _brez, _aflu, דיעי, ševe_,
   {{0x444457aa,0x6aa40682,0x68910065,0xbbd1800d}},	//   _ko_, mmif, _کیلئ, हरूक,
   {{0x26de8079,0x24078162,0x3ce9009a,0xd90d003d}},	//   ysto_, инчи_, _जिसे_, _سیم_,
   {{0x44447191,0x66e3626d,0xdb1a8019,0x7529f192}},	//   _mo_, _мора, _letö, _erez,
   {{0x44447193,0x3ce9803b,0x7659ae3e,0x7bdc44f8}},	//   _lo_, šava_, chwy, haru,
   {{0x44446e42,0x7bdc7194,0x7529f195,0x7aee007a}},	//   _oo_, karu, _grez, hrbt,
   {{0x44442d12,0x6609afb0,0xb8fe901b,0x7bdc06df}},	//   _no_, _zbek, _तब_, jaru,
   {{0x7d0d0289,0x7bd701df,0x68ed0450,0x61e60259}},	//   _spas, _rexu, zrad, _odkl,
   {{0x444407e1,0x6e20d008,0xf76f9e7b,0xe1ff0118}},	//   _ao_, _jamb, باً_, _amón_,
   {{0x44447196,0x6e20f197,0x7d0281f9,0x7bdc47f9}},	//   _bo_, _mamb, ntos, faru,
   {{0x6e20f198,0x44440039,0x7bdc7199,0x7c8712b2}},	//   _lamb, _co_, garu, руме,
   {{0x4444004c,0x883b8039,0xc5d780ab,0x6fcc8a27}},	//   _do_, _בתגו, _হাসপ, _द्यू,
   {{0x6e20aa7e,0x44444ae9,0x09aa80ab,0x0f5781c6}},	//   _namb, _eo_, _গ্যা, _כיום_,
   {{0x4444719a,0x7bdc412b,0x7d0d719b,0x69cd00ee}},	// [6b10] _fo_, baru, _upas, rbae,
   {{0x44441301,0x752980f1,0xd7f88087,0x7bdc0087}},	//   _go_, _rrez, ngă_, caru,
   {{0x4ea781e5,0xd12699f7,0x6e20f19c,0x68ed016d}},	//   арда, _کم_, _bamb, srad,
   {{0x4444719d,0x68ed43d5,0x6e22af3c,0x6e209b90}},	//   _zo_, prad, gdob, _camb,
   {{0x4444719e,0x6e20f19f,0xf8bf0c83,0xe7f00105}},	//   _yo_, _damb, _krém_, _चाचा_,
   {{0x444471a0,0x44210074,0x3eb821a4,0x7529ad0e}},	//   _xo_, _jah_, _furt_, _vrez,
   {{0x44213ff5,0x644571a1,0x03a58198,0x69db89af}},	//   _mah_, _mohi, щико, taue,
   {{0x6e20845f,0x4421059c,0xe8f993b4,0xeb780039}},	//   _gamb, _lah_, гли_, יעוץ_,
   {{0x7e69f1a2,0x0fd9827e,0x69dbc9b6,0x7bdc0a5a}},	//   _imep, льны_, raue, yaru,
   {{0x4421016f,0x69dbf1a3,0xdb1c71a4,0xf1bf128a}},	//   _nah_, saue, scré, _znát_,
   {{0x444471a5,0x9b958013,0xab9580f7,0x6e20b9d1}},	//   _ro_, _الات, _الاغ, _yamb,
   {{0x44441965,0xb05b04b8,0x60c9f1a6,0x7bdc210f}},	//   _so_, _stäl, ppem, waru,
   {{0x442171a7,0x7e698135,0x69d9867f,0x644571a8}},	//   _bah_, _mmep, _iewe, _bohi,
   {{0x6e228d26,0x442100d7,0x7e7b811f,0x69d989c4}},	//   zdob, _cah_, _ljup, _hewe,
   {{0x444471a9,0x442114ff,0x7d028065,0x7bdc298b}},	//   _vo_, _dah_, ztos, raru,
   {{0x444471aa,0x7bdc1d60,0xe1f98110,0xc3328039}},	//   _wo_, saru, ngų_, הול_,
   {{0x444471ab,0x6e208b50,0x394dba85,0x3eb8081a}},	// [6b20] _to_, _ramb, nyes_, _surt_,
   {{0x69d9879f,0xd12f0f99,0x7e69804f,0xe73a1f2f}},	//   _lewe, عمل_, _amep, лез_,
   {{0x6e20f1ac,0xbc680065,0xfa6a084b,0xb5fb0907}},	//   _pamb, _مجھے_, _банк_, riáv,
   {{0x7d02f1ad,0x291d8247,0x6e2290dc,0x212b00c3}},	//   ttos, _oswa_, udob, _frch_,
   {{0xd6258307,0x6e22f1ae,0x4421016f,0x7e7b8687}},	//   تعلي, rdob, _yah_, _djup,
   {{0x70560277,0x7d02f1af,0x6f1301df,0x68460d9d}},	//   _انسا, rtos, ñecí, _унга,
   {{0x69d98df3,0xa3d90305,0x7d02a038,0xa6f280ab}},	//   _bewe, ारत_, stos, _জন্ম_,
   {{0x69d9816f,0x3ce9009a,0xd25781bb,0xa3e800d4}},	//   _cewe, _जिले_, йцы_, मृत_,
   {{0xdfd08307,0xed508117,0x69d99d3a,0x6fe2800d}},	//   وية_, _تھا_, _dewe, jící,
   {{0x2bcf886a,0xd7f8802e,0x3ea68bb1,0x3ea071b0}},	//   _स्पा, ugă_, lmot_, _ahit_,
   {{0xe2ca8021,0x20028063,0x3aeb804e,0x3ea00362}},	//   _след_, ęki_, _مبنی_, _bhit_,
   {{0x69d9905d,0x442171b1,0x644500dd,0x291a89a7}},	//   _gewe, _sah_, _sohi, _مقصد_,
   {{0x7bdaf1b2,0xa9679285,0xb05b00f2,0x442171b3}},	//   _ketu, _лица_, _stäm, _pah_,
   {{0x7af500ad,0x645c237e,0x3a22019d,0xe9478065}},	//   tuzt, ghri, _aakp_, _درمی,
   {{0x7bdaf1b4,0xb8659a3e,0x2246c897,0x78a90037}},	//   _metu, _بانو, _kook_, _èevi,
   {{0x442171b5,0x7bdaf1b6,0x78ba001b,0x2bcf81a2}},	//   _wah_, _letu, _čtvr, _स्ना,
   {{0x442171b7,0x644571b8,0x31342361,0x625801a8}},	// [6b30] _tah_, _tohi, петр, _síoc,
   {{0x645c415a,0x7bdaf1b9,0x2246b29e,0x261380ff}},	//   chri, _netu, _look_, _ảo_,
   {{0x625cc803,0xe1f98084,0x38ad00c3,0x752d04e8}},	//   _géog, ygų_, _hžrk_, _hraz,
   {{0x3e721601,0x752d06c0,0x9f5e8144,0x395f80b9}},	//   pšte_, _kraz, letó_, yzus_,
   {{0x7bdaf1ba,0x8c45a772,0x660d58c6,0x22be81bc}},	//   _betu, желе, _mbak, _ọkpa_,
   {{0x7bdae928,0x752d0696,0x69d9dbce,0x386a0239}},	//   _cetu, _mraz, _sewe, _gmbr_,
   {{0x7bdaf1bb,0x44d68063,0xda598568,0x22468039}},	//   _detu, ał_, ириш_, _book_,
   {{0xe1f98110,0x752d00df,0x7e69804f,0x69df0168}},	//   ugų_, _oraz, _umep, naqe,
   {{0x212bf1bc,0x7bdaf1bd,0x60cd6200,0x2a6df1be}},	//   ích_, _fetu, npam, rieb_,
   {{0x7bdaf1bf,0x660d2948,0x60cd385e,0x69d9b9d2}},	//   _getu, _abak, ipam, _wewe,
   {{0xe80b0e70,0x2bcf801b,0x752d71c0,0xa5bb1427}},	//   स्या_, _स्या, _araz, rdón,
   {{0xd02200ab,0x68ee88c5,0xf5061fa0,0x59a9064a}},	//   নায়_, ündü, озмо, कधार,
   {{0x80c38a49,0x645c34f7,0x37e59d59,0x2bc68b6f}},	//   _শিক্, thri, _долг, रुवा,
   {{0x2bcf9094,0x61fbf1c1,0xe1ff0118,0xf1b283c8}},	//   _स्मा, lgul, _acó_, _חסד_,
   {{0x69df0168,0x3ea0519c,0x752d71c2,0x645c008b}},	//   faqe, _thit_, _eraz, rhri,
   {{0x61fbb59e,0x3ced01dd,0x660d0135,0x49ca03a7}},	//   ngul, ševa_, _gbak, рлан_,
   {{0x752d71c3,0x645c71c4,0x3d19800d,0x60cd3097}},	// [6b40] _graz, phri, _मैले_, gpam,
   {{0xd378826c,0x320901b4,0xb5fb0118,0x7d040372}},	//   _heće_, afay_, siát, _iqis,
   {{0x2bd01880,0xef1a1330,0x6e2402b8,0x7bda879a}},	//   _त्या, рме_, _kaib, _retu,
   {{0x7bdabdd4,0xb5fb56ca,0x1ea984a3,0xb87b008b}},	//   _setu, chád, ماني_, _hvíl,
   {{0x7bda859c,0x6e242277,0x224690c7,0x290403ed}},	//   _petu, _maib, _rook_, _ëma_,
   {{0x68e40448,0x6e243d5c,0x98a6801b,0xc1d2816f}},	//   msid, _laib, _proč_, सर्ग,
   {{0xd25a9cf8,0x7bdaf1c5,0x68e420e5,0x2246820d}},	//   ици_, _vetu, lsid, _pook_,
   {{0xd378803a,0x61fb82ec,0x6e240c61,0x69c40cf7}},	//   _neće_, ggul, _naib, ncie,
   {{0x68e471c6,0x7bdaef0b,0xdddd00e1,0x22b581a9}},	//   nsid, _tetu, nosť, _sākt_,
   {{0x224690e4,0x31af880a,0x2904f1c7,0x61fbda6f}},	//   _wook_, _sözü_, rtma_, agul,
   {{0x38170051,0x6e2471c8,0xa3d912ee,0xd7bb03c8}},	//   חקים_, _baib, ारस_, יציר,
   {{0x752d71c9,0x644883c1,0x6e240834,0x6fd68072}},	//   _praz, _hodi, _caib, _मजकू,
   {{0x61e08457,0x6e24051e,0x6448c24d,0xa3be8a27}},	//   maml, _daib, _kodi, _इला_,
   {{0x6448cedd,0xd14980d5,0xd00f80f7,0xc1d30c2d}},	//   _jodi, _دشمن_, _لله_, तर्ग,
   {{0x9f470182,0x6448bf19,0x68e42b6a,0x926b041c}},	//   ünü_, _modi, esid, араа_,
   {{0xddc407d9,0xa75b8039,0x95cb00a9,0x21290353}},	//   _iliş, _כדור, _тука_, tvah_,
   {{0x50f50364,0xb5fb71ca,0x69df0168,0x68e471cb}},	// [6b50] язат, siás, raqe, gsid,
   {{0x6448a2cb,0xf72b0790,0xb5fd8267,0xb5fb247a}},	//   _nodi, ицей_, _imši, ciár,
   {{0x87e40009,0xe3d880ab,0xdefb01e5,0x501b8039}},	//   ьюте, _সাংব, рыз_, שובו,
   {{0x69c40c9f,0x645ad2d4,0x64488706,0x60cd71cc}},	//   ccie, _alti, _aodi, ppam,
   {{0x672e00f2,0x2600035a,0x7c2502d0,0x28dad845}},	//   _erbj, ष्टी_, _kahr, _मौलि,
   {{0x7c250352,0x6448bed7,0x645500f3,0x2bc6801b}},	//   _jahr, _codi, nkzi, रुला,
   {{0x69dd0812,0x64488025,0xd6c30077,0x999900e1}},	//   _kese, _dodi, _آمری, _dosť_,
   {{0x625800f7,0x6aa2f1cd,0x6448808e,0x61e0df72}},	//   _líon, _chof, _eodi, gaml,
   {{0x2bcf90c5,0x69dd4134,0xe80b053f,0x6e240307}},	//   _स्था, _mese, स्था_, _raib,
   {{0x6448803a,0x7c2521f8,0x6e2471ce,0x7e6d6df4}},	//   _godi, _nahr, _saib, _amap,
   {{0xe7bc8424,0x69c4009a,0xb5fb0187,0x44258197}},	//   ोड़प, ycie, viár, _ial_,
   {{0x64438289,0x4425f1cf,0x69dd71d0,0xe80b0aad}},	//   ljni, _hal_, _nese, स्ता_,
   {{0xd378803b,0x7c2505a3,0x4425f1d1,0x4a9a83c8}},	//   _veće_, _bahr, _kal_, _פינג,
   {{0xdb1c71d2,0xddc98582,0xb042801c,0x78b500d2}},	//   scrí, _njež, _thưở, _nizv,
   {{0x4425f1d3,0x69dd3a10,0x765bf1d4,0x42561ceb}},	//   _mal_, _bese, _oluy, птат,
   {{0xb21b065d,0x78b500eb,0x69dd71d5,0x69c400eb}},	//   _skær, _aizv, _cese, ucie,
   {{0x7c250352,0x69c471d6,0xddc982ce,0x672e01a1}},	// [6b60] _fahr, rcie, _bjež, _srbj,
   {{0xb4d81880,0x68e40d1a,0x69c45268,0x3979035f}},	//   ाठी_, rsid, scie, істю_,
   {{0x68e471d7,0x69dd71d8,0x61eb812b,0x3bbb0039}},	//   ssid, _fese, _odgl, _למיד,
   {{0x6448f1d9,0x69dd3761,0x7c2503cb,0x442581b4}},	//   _sodi, _gese, _zahr, _aal_,
   {{0x7bde085c,0x27e15e5e,0x225ff1da,0x61e08380}},	//   _kepu, bahn_, dhuk_, vaml,
   {{0x4425f1db,0x7bde1083,0x6aa2f1dc,0x6448b4ed}},	//   _cal_, _jepu, _shof, _qodi,
   {{0x4425f1dd,0x765b8216,0x7bde01bc,0xdb1c646a}},	//   _dal_, _fluy, _mepu, mbró,
   {{0x201a0968,0x7bde71de,0x22b800c3,0x9f58041c}},	//   lepi_, _lepu, _učku_, _ecrã_,
   {{0xd90e9125,0x61eb03a8,0x4425d665,0x6448b7eb}},	//   ایت_, ógli, _fal_, _todi,
   {{0x4425f1df,0x645ac75b,0x61e0ab33,0xe786bf21}},	//   _gal_, _ulti, saml, зумо,
   {{0xd9a9020e,0x09db80ab,0x21270129,0x6abe018e}},	//   _कण्ट, _ধারা, ̉nh_, _nupf,
   {{0x4425f0ba,0x7c250b67,0x61e0829a,0x225ff1e0}},	//   _zal_, _sahr, qaml, chuk_,
   {{0x69dd71e1,0x09aa80c8,0x4425ea7b,0x7c2500b9}},	//   _rese, _গ্রা, _yal_, _pahr,
   {{0x69dd0cbb,0x3ced02a5,0x201a02ce,0x44258be9}},	//   _sese, ševo_, jepi_, _xal_,
   {{0x7bde71e2,0x69dd059e,0x78b541ae,0x9f628009}},	//   _depu, _pese, _rizv, ävän_,
   {{0x7c2502af,0xdddbb7bc,0xd5c103eb,0x7e6d5e6b}},	//   _wahr, _skuž, _एलिज, _umap,
   {{0x69dd71e3,0xda1e249a,0x66e2826b,0x644124a1}},	// [6b70] _vese, _पसरत_, _fíká, ölis,
   {{0x69dd09af,0x7bde03b2,0x2fc7001c,0x3a2689c4}},	//   _wese, _gepu, ùng_, _laop_,
   {{0xddc9ac14,0xe71900f7,0xc05383c8,0x69dd2353}},	//   _vjež, تيات_, עזע_, _tese,
   {{0x4425ed0f,0x2a601b03,0x7e7d71e4,0xa3cf816f}},	//   _sal_, chib_, nnsp, वुन_,
   {{0xf1ab0077,0x5184053b,0x3ce681a1,0xece8804a}},	//   _داده_, _зура, gsov_, зділ_,
   {{0x5fe1159a,0x442581b9,0x224b00ee,0x201a71e5}},	//   _फ़िल, _qal_, _hock_, cepi_,
   {{0x4425c76a,0x29090198,0x224b2e3d,0x64438338}},	//   _val_, ltaa_, _kock_, rjni,
   {{0x5694bd2e,0x3a290642,0xddc41be7,0xf8bf08f9}},	//   _заст, ndap_, _omiš, _kué_,
   {{0x29091e3b,0x4425c951,0x44278101,0x7c878162}},	//   ntaa_, _tal_, pdn_, _еуже,
   {{0xaec596c7,0xb95b026b,0x2a6000b9,0x6fdd12c6}},	//   мбол, _afìk, zhib_, यरिं,
   {{0x29090009,0x7bde71e6,0x3ce90176,0xcb558290}},	//   htaa_, _repu, _avav_, _تناظ,
   {{0x7bde01f1,0x2a60377f,0x1ee78065,0x2cbf8074}},	//   _sepu, xhib_, _ہوتی_, _kuud_,
   {{0x625800f7,0x7bde3775,0x25df02f1,0x2d8471e7}},	//   _díol, _pepu, _कजरी_, çme_,
   {{0x78600065,0x2cbf8074,0x68fbb3fd,0x3940022c}},	//   _köve, _muud_, muud, vxis_,
   {{0x41d1853e,0xa3e58fd5,0x2cbff1e8,0xa3c59a42}},	//   _सभास, _भजन_, _luud_, _एलन_,
   {{0x09b180ab,0xe80b15bc,0x7bde0133,0xcb1281c6}},	//   _ট্যা, स्सा_, _wepu, כלל_,
   {{0x7bde0458,0x68fbf1e9,0xf8bf0216,0x201a5a6a}},	// [6b80] _tepu, nuud, _cué_, tepi_,
   {{0x2a6020d8,0x39428009,0xd37885f3,0xa3d91c9d}},	//   shib_, äksi_, _leća_, ारः_,
   {{0x78600019,0xdb1c00f7,0xb6c50d8e,0x201a71ea}},	//   _növe, rbró, есій, repi_,
   {{0x90c60e12,0xe8020327,0x201a2d26,0x7afc38ad}},	//   _обме, र्जा_, sepi_, murt,
   {{0x61e427a5,0x92d600c8,0x443a09da,0x69d671eb}},	//   mail, _সময়_, _knp_, mbye,
   {{0x13e200c8,0x3ddf80f3,0x61e471ec,0xa6e2007b}},	//   _বাড়, _eeuw_, lail, æðsl,
   {{0x60c40168,0xe80306a7,0x645d8084,0x62580174}},	//   lqim, _लाता_, _įsit, _líom,
   {{0x61e41581,0x30ea8fdd,0xc7a30ada,0x69d603ec}},	//   nail, офон_, _риск, nbye,
   {{0x2bcfa263,0x60c20013,0x6723820f,0x2cbf82a3}},	//   _स्वा, íomh, _asnj, _guud_,
   {{0x7afc71ed,0x61e414f2,0xe8020778,0x66044f5a}},	//   kurt, hail, र्चा_, _acik,
   {{0x61e471ee,0x7c3af1ef,0x60c400f1,0xe810016f}},	//   kail, _intr, hqim, ठ्या_,
   {{0x443a1be2,0x7afc6b76,0x7c2892cf,0x7e629345}},	//   _anp_, durt, _hadr, nhop,
   {{0x506697f9,0x6846b0bb,0x224b01c6,0x68fb81b4}},	//   _отка, _онда, _rock_, cuud,
   {{0x7c2895f2,0xe57180be,0x7c2af1f0,0x6d42802a}},	//   _jadr, אַל_, ndfr, ixoa,
   {{0x7afc5488,0x61e471f1,0xc61400ab,0x7c2895c1}},	//   gurt, fail, িয়া_, _madr,
   {{0x2909025d,0x61e410a8,0x78600201,0xe80203eb}},	//   ttaa_, gail, _növb, र्घा_,
   {{0xf8bf1220,0xa3cf913d,0x661d0069,0x7c3af1f2}},	// [6b90] _qué_, वुड_, mesk, _ontr,
   {{0x5c740554,0x29091e3b,0xd9bb88fd,0x7afc6897}},	//   _альт, rtaa_, _उल्ट, burt,
   {{0x2909025d,0x0c740dd0,0x8bd60051,0x83350158}},	//   staa_, _جديد, _אותו_, _װאָס_,
   {{0x28df90be,0x7c3af1f3,0x61e40cb5,0x68f671f4}},	//   पीडि, _antr, cail, bryd,
   {{0x7c28a715,0x644e02d4,0x6aad08dc,0xe50481a8}},	//   _badr, žniš, mmaf, نبوي,
   {{0x7c28f1f5,0x03a5a001,0xfe10001c,0xd37885a2}},	//   _cadr, нило, _nắng_, _seća_,
   {{0x661d043d,0x60cf71f6,0xd37880c3,0x7c28d637}},	//   kesk, _htcm, _peća_, _dadr,
   {{0x7c3acb86,0x7e6284e8,0xe8100c28,0x659581d9}},	//   _entr, chop, ठ्ठा_, _забу,
   {{0xd378803a,0x59c18105,0xf1b9911b,0x395981fa}},	//   _veća_, शखबर, ješe_, áss_,
   {{0x62580013,0x61e4011e,0x1cb88077,0x20010081}},	//   _ríom, zail, _قالب_, nghi_,
   {{0xe7399289,0xbcfb0065,0x68fb83ff,0xe3b38b76}},	//   чен_, szél, suud, _شرط_,
   {{0x661d48c1,0x6e2982f7,0x3f9981a9,0x443a71f7}},	//   gesk, _jaeb, āsu_, _snp_,
   {{0x61e471f8,0xee371cfd,0xdddb9a1a,0xc7b880c3}},	//   vail, хня_, _aluŋ, veđe_,
   {{0x7afc71f9,0xe0068740,0xfe1000ff,0x629b8114}},	//   turt, _शायद_, _gắng_, lluo,
   {{0x1e960b9c,0x61e448ab,0xa69619e6,0x68e9ac15}},	//   _прир, tail, _приј, lsed,
   {{0x3dda00ab,0x69c9c42b,0x2bd02a90,0x68f671fa}},	//   _থাকল, ncee, _त्रा, tryd,
   {{0x61e471fb,0xe8fa09c7,0x6a830be2,0x68e9983d}},	// [6ba0] rail, яла_, улта, nsed,
   {{0xb8820efc,0x7afc71fc,0x61e40102,0x2bcf8540}},	//   _čísl, purt, sail, _स्ला,
   {{0x91e61957,0x69cbf1fd,0xe61a84a9,0xdfcf00f7}},	//   _поне, _ofge, зде_, صين_,
   {{0x7c28803a,0x98a0017f,0x69c981c0,0xfce6a7ee}},	//   _sadr, kvić_, jcee, еодо,
   {{0x7e62816d,0x6e298101,0xd469004e,0xad9b016a}},	//   rhop, _daeb, _رحیم_, lfúr,
   {{0x68e99108,0x69cba468,0x8c4391c7,0x7c28e710}},	//   dsed, _afge, лече, _qadr,
   {{0xc79501e2,0x8fa31a1f,0x645890c9,0x4f953548}},	//   _арты, _баре, rkvi, _арту,
   {{0x179b03c8,0x5a349354,0xa50aa2f7,0x7c288326}},	//   _זילב, тнит, _неба_, _wadr,
   {{0x81e500c8,0xe0cf80d5,0x661d1474,0x98a000c3}},	//   _নাম_, یزی_, vesk, gvić_,
   {{0x473485c2,0xbc6a8c3b,0x66028061,0x6e29838a}},	//   внос, _عمان_, lgok, _zaeb,
   {{0x81df8a49,0x1df911e9,0x661d71fe,0x45d50389}},	//   _তার_, мены_, tesk, конс,
   {{0x6602829b,0xea018028,0xff7b04de,0xd3788267}},	//   ngok, _đầy_, לטימ, _hećo_,
   {{0xfe6e0bca,0x661d71ff,0xa32080c2,0x78b8822b}},	//   تگو_, resk, _मनुज_, _tivv,
   {{0xb5fb5cbc,0x661d286c,0x212688f9,0x61e2b6ca}},	//   chán, sesk, _isoh_, _heol,
   {{0x938847de,0x60c28364,0xfaa714bc,0xab952e9f}},	//   еста_, _huom, ешан, тиві,
   {{0x201ef200,0x60c2f201,0x66e701d0,0x998681d6}},	//   leti_, _kuom, _léká, _množ_,
   {{0x2cff8aed,0x60c28198,0xddc98493,0x62808123}},	// [6bb0] _ईमेल_, _juom, _aleş, inmo,
   {{0x201ef202,0x61e2b278,0x6e3bf203,0x3b55002e}},	//   neti_, _leol, _snub, _акор,
   {{0x3ea93a00,0x20010081,0x60c28198,0xf41201c6}},	//   _khat_, rghi_, _luom, _דפי_,
   {{0xa3d90076,0xfb1a0986,0xd5758c5c,0x201ef204}},	//   ारक_, _کریں_, куль, heti_,
   {{0x60c281e2,0x5a341d1f,0xddc9f205,0x3a2b0037}},	//   _nuom, _снят, _eleş, _iacp_,
   {{0x2249003b,0x201ed449,0x3ea900e4,0x6e298c93}},	//   ljak_, jeti_, _lhat_, _waeb,
   {{0xf8bf0036,0xe7840705,0x21268176,0x2bac863a}},	//   _trés_, _буто, _asoh_, टेला,
   {{0x5f941982,0x3ea9001c,0x68e9f206,0x61e281a8}},	//   _сист, _nhat_, tsed, _ceol,
   {{0x69c981ed,0x60c28037,0x201ef207,0xd24e95a9}},	//   rcee, _cuom, feti_, تني_,
   {{0x68e98867,0x857499bb,0x60c28110,0x69c98299}},	//   rsed, _слух, _duom, scee,
   {{0xf7718277,0x2608800d,0x68e991b4,0x200b809a}},	//   شاد_, _हामी_, ssed, ęci_,
   {{0x26c3005c,0x27e304b7,0x3ea937cd,0x3ce98115}},	//   _mujo_, _lejn_, _chat_, šavu_,
   {{0xceb2893f,0x201ef208,0x26c30264,0x26fe0321}},	//   ייט_, beti_, _lujo_, _उम्र_,
   {{0x5ed200c8,0x201ef209,0x64a60196,0x68ff011c}},	//   _হিসে, ceti_, тага, duqd,
   {{0xfe0a0740,0x160a016f,0x09e627d4,0xe29a004a}},	//   _वापस_, _वापर_, ковн, дав_,
   {{0xc3328039,0x61e281df,0x2c6d0267,0xc0b981d0}},	//   סון_, _xeol, dždu_, řádá,
   {{0xe2971dba,0x290ddf7c,0x27e304b7,0xad9b04c3}},	// [6bc0] тат_, ntea_, _bejn_, lgún,
   {{0xb21b0ae1,0xb05b3cac,0xa2a2015c,0x291902d5}},	//   _hjæl, _stär, _कीर्, _dpsa_,
   {{0xe813835a,0xb8e90424,0x7c3e0102,0x645c720a}},	//   त्या_, _लू_, _inpr, mkri,
   {{0x201ef20b,0x75360035,0x3ce00242,0xc6088e1b}},	//   zeti_, _kryz, _kwiv_, _রোজা_,
   {{0x27e301cd,0x61e28114,0x201e8c12,0x2d8f006a}},	//   _fejn_, _reol, yeti_, _øget_,
   {{0x61e2f20c,0x645c5fff,0x201e0ede,0x2900004f}},	//   _seol, nkri, _úti_, muia_,
   {{0x60c2825d,0x201ef20d,0x290d8144,0xf743498a}},	//   _suom, veti_, etea_, _керо,
   {{0x3ced0289,0x753600b9,0x78bc0009,0xc7b8911b}},	//   ševi_, _oryz, _hirv, jeđa_,
   {{0x201ef20e,0xfe918077,0x6280816d,0x30a6a9e4}},	//   teti_, _اینج, rnmo, кров,
   {{0xea01801c,0x27e304b7,0xb42587d2,0x3dc002c4}},	//   _đấy_, _xejn_, _معمو, _agiw_,
   {{0x442caab6,0xadc3826b,0xb5fb00f7,0x3ea900ff}},	//   _iad_, _abẹn, bhál, _phat_,
   {{0x442cbca7,0x60c2a252,0xb87b007b,0x7c3e0edc}},	//   _had_, _tuom, _hvít, _anpr,
   {{0x442cee51,0x201ef20f,0x06e282f1,0xd0480085}},	//   _kad_, peti_, _कौरव_, şlər,
   {{0x3ea9004c,0xd0109a05,0x491783c8,0x442cf210}},	//   _what_, _طلب_, _סקול_, _jad_,
   {{0x3ea9073a,0x7ac4072a,0xa3208006,0xefb08077}},	//   _that_, исте, _मनोज_, _دیدگ,
   {{0x442c813c,0x7c3e6011,0x75360035,0xb113819d}},	//   _lad_, _enpr, _fryz, _mụnw,
   {{0x443ef211,0x30150037,0x2d8f00e7,0xdddb9123}},	// [6bd0] _ont_, лдар, _âge_, _njuš,
   {{0x443e80ee,0xf1b9adab,0xc05801e2,0x442e8144}},	//   _nnt_, neša_, кіх_, jdf_,
   {{0x6e2d18d0,0x2bd90ebf,0x290d8102,0x442e8114}},	//   _kaab, _ब्या, ztea_, ddf_,
   {{0x442c82c1,0x443eaad0,0x765d06c0,0x29000087}},	//   _aad_, _ant_, nksy, buia_,
   {{0x6e2d49a3,0x442cc9f6,0xa5bb0333,0x76880380}},	//   _maab, _bad_, cdót, nıya,
   {{0x442c84f9,0x81df80c8,0x443e88f1,0x260881ce}},	//   _cad_, _তাই_, _cnt_, _हाथी_,
   {{0xeb968d9e,0xe299c875,0x68ed15d0,0xaca301bc}},	//   лиш_, нак_, lsad, _nkọg,
   {{0x0b1680f7,0x645c7212,0xb87b0118,0x78bc07c0}},	//   اقية_, zkri, _evít, _zirv,
   {{0x68ed7213,0x442c861f,0x6abd04c7,0x3e6201a8}},	//   nsad, _fad_, _misf, _nóta_,
   {{0x290d8c76,0x442cf214,0xb21b013c,0xe8f681bb}},	//   rtea_, _gad_, _sjæl, ыль_,
   {{0x290d8c76,0x6e2d0e05,0xfc309ec9,0x29000010}},	//   stea_, _baab, _بحق_, zuia_,
   {{0x6abd1c8e,0x290d8087,0x98ad807a,0x68ed0687}},	//   _nisf, ptea_, mveč_, ksad,
   {{0x09b180ab,0x69dbf215,0x6d59f216,0x6e2d5d34}},	//   _ট্রা, mbue, nywa, _daab,
   {{0x68ed0079,0x69dbec4c,0x442c81b4,0x68fb85fe}},	//   dsad, lbue, _xad_, mrud,
   {{0x66098052,0x645c5625,0xe739802e,0x7c2e7217}},	//   _ocek, rkri, _чей_, rdbr,
   {{0x645c120b,0x78bc3aba,0x6e2d2695,0xe29709b1}},	//   skri, _sirv, _gaab, гас_,
   {{0x6abd1d4e,0x68fbbd70,0x7e64648d,0x386300dd}},	// [6be0] _disf, nrud, _ilip, _bljr_,
   {{0x7bc18199,0x61e9f218,0x20c980ff,0x29000087}},	//   _nglu, hael, _múi_, ruia_,
   {{0x7e6439f6,0xddc9c6a8,0xb87b3dce,0x68fbc8df}},	//   _klip, _smeš, _avís, hrud,
   {{0xe813a441,0x68ed0079,0x7bc1bdb4,0xb87b01d0}},	//   त्ता_, bsad, _aglu, _svít,
   {{0x2900256c,0x442cf219,0x68fbf21a,0x24f68f80}},	//   quia_, _pad_, jrud, учер,
   {{0x7bdc13ca,0x61e64ac6,0xac188e1d,0x273384be}},	//   nbru, _hekl, току_, _ẹni_,
   {{0x442cf21b,0x260500cf,0x1fb50009,0x2c160c28}},	//   _vad_, _वाली_, _встр, द्यं_,
   {{0x442ca221,0x32548e0b,0x61e6007a,0x61e9f21c}},	//   _wad_, рвир, _jekl, gael,
   {{0x442cf21d,0x61e60029,0xddc9ab0d,0x20180573}},	//   _tad_, _mekl, _umeš, _kbri_,
   {{0xdefaabef,0x7e64721e,0x6e2d1c0a,0x7d028110}},	//   ным_, _alip, _saab, muos,
   {{0xb8cba336,0x60c60e59,0xf8c8801c,0x6e2d2f53}},	//   _की_, _lukm, _bức_, _paab,
   {{0x6e2d0079,0x6e9500e8,0x69dd807b,0x68fbf21f}},	//   _qaab, риму, ðset, brud,
   {{0x22938013,0x550701e2,0x6284009a,0x249a008e}},	//   _النس, ычна, dnio, _bkpm_,
   {{0x6e2d0ec8,0x7e640234,0x3e6201a8,0x5b271273}},	//   _waab, _elip, _vóta_, льба,
   {{0x61e60808,0x309b8051,0x6f01816a,0x6e2d5de3}},	//   _bekl, _רשומ, culc, _taab,
   {{0x60c64e7e,0x68ed7220,0x20180eba,0x7d028e11}},	//   _bukm, tsad, _abri_, kuos,
   {{0x61e67221,0x9875214a,0x7bdc1031,0x201805ee}},	// [6bf0] _dekl, алац, bbru, _bbri_,
   {{0x68ed6a23,0x09d185e8,0x7e64026c,0x2c663c82}},	//   rsad, _सभ्य, _zlip, _pôde_,
   {{0x68ed7222,0x97a714f6,0x6d59aa6d,0x7e640198}},	//   ssad, урал, wywa, _ylip,
   {{0x44234b72,0x61e604eb,0x3ced056f,0xa49b009f}},	//   lej_, _gekl, ševu_, ctòr,
   {{0xd126990c,0x68ed0df6,0x58870d15,0x68e28326}},	//   _بم_, qsad, _быва, _nwod,
   {{0x44237223,0xa8790158,0xc484a22c,0x69c29142}},	//   nej_, _יאָר, блік, _agoe,
   {{0xfd580133,0x6d598035,0x68e28915,0x9f51861c}},	//   _braụ, sywa, _awod, üzü_,
   {{0x44236806,0x7f840013,0x2ce500d4,0x68fbf224}},	//   hej_, _الفن, _कबूल_, trud,
   {{0x44237225,0x61e9f226,0x7d1b80d2,0x394901df}},	//   kej_, rael, _upus, nxas_,
   {{0x44235a65,0x7ae7940b,0x39497227,0xf8c88028}},	//   jej_, _бюдж, ixas_, _sức_,
   {{0x8fa580e9,0x366a0729,0x44237228,0x62847229}},	//   ране, вано_, dej_, ynio,
   {{0xed5a00bf,0x20c9801c,0x443100eb,0x249a00b9}},	//   вом_, _túi_, edz_, _skpm_,
   {{0xc0e587eb,0x9f430388,0xf8bf09c4,0xa69681c6}},	//   _толк, _dejé_, _asém_, שכרה_,
   {{0x61e6722a,0x224d807a,0x6f01ad3d,0x38ab8aa2}},	//   _sekl, ljek_, pulc, føre_,
   {{0x46a61cf5,0xeb9a143d,0x78600086,0xf8c88028}},	//   _какв, тив_, _dövl, _tức_,
   {{0x7bdc2bdf,0x76880214,0x7e6461f4,0xf8c880ff}},	//   sbru, mıyo, _ulip, _hứa_,

   {{0x44231683,0x76880214,0x6f1c026f,0x6296722b}},	// [6c00] bej_, lıyo, _sprc, royo,
   {{0xa49b07e2,0x26c7f22c,0x4423722d,0x27e786c0}},	//   stòr, _kuno_, cej_, _jenn_,
   {{0x27e7a4f1,0x76880214,0x61e6722e,0x7c23dfff}},	//   _menn_, nıyo, _tekl, denr,
   {{0xed5a95b9,0x27e798e8,0x6441848d,0x3ebf9495}},	//   кое_, _lenn_, _anli, _ciut_,
   {{0xe53484cf,0x3ebf81bc,0x26c78365,0x1bd48081}},	//   сель, _diut_, _luno_, боля,
   {{0x7c23f22f,0x2d579d7b,0x76880214,0x7d02f230}},	//   genr, ришь_, kıyo, ruos,
   {{0x2480d006,0xaa668d9e,0xb5fb027f,0x26c7f231}},	//   đim_, итик, nkác, _nuno_,
   {{0x44237232,0x68e28247,0xd2578009,0xe8138aed}},	//   zej_, _pwod, ицы_, त्सा_,
   {{0x26da0198,0x48aa9594,0x29120c8b,0x7c23c830}},	//   lppo_, ктом_, ntya_, benr,
   {{0x2a6920d5,0xd7aa00d4,0xb5fb00f7,0x32ca801c}},	//   zhab_, _कराच, mhái, _tùy_,
   {{0x44237233,0x27e78352,0x50b780f7,0x224de310}},	//   vej_, _denn_, جديد_, bjek_,
   {{0x44230d38,0x6f03009f,0x2a69377f,0x625801a8}},	//   wej_, ànci, xhab_, _míos,
   {{0x44230eb0,0x2a668122,0x249849f6,0x768802d0}},	//   tej_, _ilob_, form_, mıyl,
   {{0x290480eb,0x2a6681c5,0xb87b0032,0x25a904e8}},	//   muma_, _hlob_, _awín, _vzal_,
   {{0xeabf0021,0xdb580364,0x4423086f,0x29048418}},	//   _più_, ают_, rej_, luma_,
   {{0xe81905fc,0x44234235,0xd7bb8039,0x7afa1e18}},	//   न्ना_, sej_, _בצור, átta,
   {{0xe8138beb,0x442301b9,0x7e7d07b8,0x3ebf851e}},	// [6c10] त्वा_, pej_, misp, _riut_,
   {{0x1c16016f,0x2a69008e,0x6ecb00d4,0xb5fb01a8}},	//   द्दल_, shab_, _तंदु, dhái,
   {{0x2c008540,0x29049ffb,0x92950048,0xc5d5a22c}},	//   _राजू_, huma_, _ганц, біль,
   {{0x2904f234,0x7e7d3c86,0xf2d20039,0x625801a8}},	//   kuma_, nisp, _מעט_, _díos,
   {{0x61ed6302,0x29048029,0x224d8499,0x51842f07}},	//   maal, juma_, vjek_, _дура,
   {{0x61ed44bb,0xa3be08fd,0x2904f235,0x7e7d7236}},	//   laal, ुँच_, duma_, hisp,
   {{0x212900b9,0x7ebf01a9,0x7c23c90d,0x27e7821e}},	//   lwah_, _rūpn, renr, _renn_,
   {{0xb5fb0307,0x569481e2,0x7c23f237,0x61ed62e3}},	//   bhái, _даст, senr, naal,
   {{0x2904f238,0xb5fb7239,0x7e7d12ab,0x661bc998}},	//   guma_, chái, disp, _ibuk,
   {{0x44238117,0x753b80ad,0xb8ff8665,0x61ed723a}},	//   _új_, _iruz, _तऽ_, haal,
   {{0x2bdd8c78,0x61ed2f39,0x5434826a,0x21291600}},	//   _न्या, kaal, _برقر, hwah_,
   {{0x27e7834a,0x21293932,0xb5fb016b,0x6b7a80be}},	//   _wenn_, kwah_, vkác, _גרענ,
   {{0xd378803a,0x61ed3e6e,0x1e3a80be,0x9f478168}},	//   _reći_, daal, אגרא, _kenë_,
   {{0x320902c1,0xa3d317ba,0x629d2992,0x9f4780f1}},	//   egay_, हुल_, _akso, _jenë_,
   {{0x661bf23b,0xd378a8d2,0x7e7d0333,0x935922f7}},	//   _obuk, _peći_, bisp, арту_,
   {{0x61ed0962,0xe81383eb,0x753b90d3,0x575681c6}},	//   gaal, त्रा_, _oruz, _לבצע_,
   {{0xd3788025,0x2f118019,0x39460187,0xddcd09d1}},	// [6c20] _veći_, lág_, ãos_, _umaš,
   {{0x7d060364,0x29120019,0x62580174,0x661bf23c}},	//   muks, rtya_, _píos, _abuk,
   {{0x4444723d,0x61ed723e,0x2904caff,0xa3b4000c}},	//   _in_, baal, zuma_, जेश_,
   {{0x290481d3,0x4444723f,0xb5fb01a8,0x69da0087}},	//   yuma_, _hn_, thái, _ştef,
   {{0x4444417c,0xc0b28028,0x8936045b,0x7d060ff9}},	//   _kn_, _cười_, _اعجا, nuks,
   {{0x2904b4e7,0xa3d8001b,0x7e7d34e6,0x661bf240}},	//   vuma_, ाडि_, zisp, _ebuk,
   {{0x907b00be,0x2a66822c,0xf99f08f9,0x753bf241}},	//   _עטלי, _plob_, _acèh_, _eruz,
   {{0x60f882bc,0x2904a27d,0x29007242,0xb5fb36e5}},	//   ания_, tuma_, oria_, phái,
   {{0x4444073a,0xc05a8a18,0x26ca0733,0x76880457}},	//   _on_, гін_, _hubo_, rıyl,
   {{0x44445aca,0x7d067243,0x2ef4828b,0x76880457}},	//   _nn_, duks, озор, sıyl,
   {{0xa09b010f,0x6aa40059,0x61ed0ef2,0x889b03c8}},	//   רייט, klif, yaal, רביי,
   {{0x44447244,0x2904c612,0xe1ff026b,0x6d5d0198}},	//   _an_, puma_, _alón_, tysa,
   {{0x7e7d36da,0xa3cf8006,0xe8190c87,0x249e80b9}},	//   risp, वुक_, न्डा_, _kktm_,
   {{0x26d81ee1,0x92d400c8,0x81e500c8,0x5ed900c8}},	//   _otro_, _হয়ে_, _নাই_, _ডিসে,
   {{0xa3d8000f,0x21290239,0xa87b81c6,0xf3f18129}},	//   ाड़_, wwah_, _תאור, _học_,
   {{0x2bd903eb,0x6aa40a2b,0x7d067245,0xe5c72955}},	//   _ब्रा, glif, buks, _уско,
   {{0x61ed1572,0x7e628fb0,0x44442dc8,0x2900385e}},	// [6c30] raal, dkop, _fn_, gria_,
   {{0x61ed25a5,0x44447246,0x69d90540,0x9f4782d6}},	//   saal, _gn_, _फ्री, _benè_,
   {{0x61ed1699,0x290064a5,0x37ab02ee,0x8a19002e}},	//   paal, aria_, утан_, _конс_,
   {{0xa3ae000f,0x61ed02a3,0x29004a24,0x753b8503}},	//   _औरत_, qaal, bria_, _pruz,
   {{0x44447247,0x2f118019,0x81c380ab,0x672e006a}},	//   _yn_, zág_, ্রম_, _esbj,
   {{0x9f47820f,0x6ab381cb,0x58d4402c,0xb5fb016b}},	//   _qenë_, ुद्र, _хорт, cháv,
   {{0x64572651,0xb1138133,0xae0a0074,0xfcb281d6}},	//   _moxi, _tụkw, _वालन_, úšať_,
   {{0xe8f9a0a9,0xd378803b,0x661bb046,0x9f43001b}},	//   али_, _neću_, _ubuk, _její_,
   {{0x26ca173d,0x44330144,0x753b8314,0x7e7bf248}},	//   _zubo_, _oax_, _uruz, _imup,
   {{0x2bd9159a,0xe3b38277,0x6aa47249,0xef198eef}},	//   _ब्ला, _فرض_, zlif, амо_,
   {{0xbba803bb,0x81e880c8,0x7e69f24a,0xf626006d}},	//   _गरेक, _বার_, _klep, одно,
   {{0xa3bf03b7,0x7d06025d,0x3cf0800f,0x9f4a03a7}},	//   ेशन_, tuks, ुंचे_, _bebê_,
   {{0x2f118065,0x4444724b,0x4427e673,0x44331b44}},	//   ság_, _pn_, oen_, _bax_,
   {{0x66e59289,0xe7398767,0x7d06724c,0x645702df}},	//   _дока, _век_, ruks, _coxi,
   {{0x44440104,0xa3b40063,0x60cb807b,0x765629cf}},	//   _vn_, जें_, _hugm, _toyy,
   {{0x4427f24d,0x2900724e,0x6289f24f,0xf1d186a7}},	//   hen_, tria_, nneo, _हलफन,
   {{0x61ebf250,0x60cb8bda,0x26ca6e07,0xbcfb0019}},	// [6c40] _megl, _jugm, _subo_, szér,
   {{0x290000ad,0x61ebf251,0x4433008e,0x394d8722}},	//   rria_, _legl, _gax_, ixes_,
   {{0xbc6a0bca,0x25ad826c,0xe5c68c9d,0xa3188105}},	//   _ممکن_, _azel_, осло, _दहेज_,
   {{0x290019ae,0x61460993,0x4427a4ab,0x60c3808e}},	//   pria_, _дема, een_, _linm,
   {{0x4427e53b,0x7e62b5cd,0xff0a00c8,0xa2b90cf0}},	//   fen_, rkop, রবেশ_, ्दर्,
   {{0x4427d7d8,0x66e6272b,0xe819000d,0xdee60a7c}},	//   gen_, _мога, न्दा_, _моги,
   {{0x61ebf252,0x26d803ba,0x25adf253,0x7e6286aa}},	//   _begl, _utro_, _ezel_, pkop,
   {{0x60c38ad0,0x41e68221,0x2c6b8257,0xf99f0176}},	//   _ainm, ціка, _røde_, _abèy_,
   {{0x4427acc0,0x61eb8698,0x3fc8826a,0x2c6b806a}},	//   ben_, _degl, یدگی_, _søde_,
   {{0x4427f254,0x60cb90d3,0x7e69826f,0x7d0282f7}},	//   cen_, _dugm, _zlep, mros,
   {{0xd838807a,0x60c3a050,0x7bc88bb1,0x7d02a126}},	//   joče_, _dinm, _igdu, lros,
   {{0x60c390f6,0x3ea682f7,0x62898cb5,0x44337255}},	//   _einm, nlot_, cneo, _sax_,
   {{0xd378805c,0x3ea0008e,0x6280f256,0x60cb8bb1}},	//   _veću_, _dkit_, mimo, _gugm,
   {{0x35cc83b7,0x7d029243,0x2717128a,0x9f45f257}},	//   ़खड़, iros, něná_, balà_,
   {{0xd8388353,0x7c277258,0x2122008e,0x3ea682c4}},	//   goče_, rejr, _apkh_, klot_,
   {{0x4427f259,0x26c4b495,0x478985a8,0x2605016f}},	//   zen_, _nimo_, _усім_, _वाटी_,
   {{0x4427d3e3,0x1ad680ab,0xf4e580ab,0x3eb92385}},	// [6c50] yen_, সওয়া, _নম্ব, mmst_,
   {{0x4427f25a,0x6280f25b,0x442710ab,0x7e698e20}},	//   xen_, himo, _ún_, _slep,
   {{0x442781ed,0x26c48032,0xc5d8819d,0xd5d881bc}},	//   ven_, _bimo_, _ịrụb, _ịrụr,
   {{0x4427f25c,0xa3dd98a4,0x1daf0072,0xb5fb03c1}},	//   wen_, थुन_, _घरात, chát,
   {{0x61e20693,0xb3bd00ab,0x26c482c4,0xa5bb0e06}},	//   ñole, _অভিজ, _dimo_, deók,
   {{0x4427f25d,0x61ebf25e,0x224680b9,0x25ad82d4}},	//   uen_, _segl, _anok_, _vzel_,
   {{0x61eb805c,0x29090009,0x60c383ec,0x7d02f25f}},	//   _pegl, luaa_, _rinm, aros,
   {{0x6d5c8201,0x78600019,0x60c3f260,0x394d8722}},	//   _əraz, _rövi, _sinm, txes_,
   {{0x4427f261,0x13a80aed,0xe8068778,0xa3eb0fea}},	//   pen_, _गर्भ, _शाखा_, मरा_,
   {{0x9f4587e2,0xe5c486cf,0x442780f1,0x3ea07262}},	//   talà_, _істо, qen_, _skit_,
   {{0x62808333,0x38ab8366,0x786d808b,0xf745a8b4}},	//   bimo, børn_, _núve, чено,
   {{0x628085e4,0x60cbb3df,0x316000b9,0xb5fb128a}},	//   cimo, _tugm, yyiz_, skán,
   {{0x80de8264,0x09e28264,0x3ce90362,0xe79a928a}},	//   _মিথ্, _যাচা, _cwav_, _měří,
   {{0xc1728051,0x6ab432df,0x3e62007b,0xf1b982ce}},	//   _אחד_, ंग्र, _móti_, ješi_,
   {{0x09e612ea,0x22590609,0xbb43498a,0x07a28087}},	//   зобн, _bosk_, нерк, _пашн,
   {{0x32d18142,0x49ca0b79,0x9f458511,0x3ea00637}},	//   _máy_, слан_, calá_, _ukit_,
   {{0x7af50019,0x648908ae,0xb5fb1e18,0xe7f280c2}},	// [6c60] aszt, džif, rhát, _आजमा_,
   {{0x44e9809a,0x628094e6,0x26c4f263,0x6e3601b4}},	//   dź_, zimo, _simo_, _hayb,
   {{0xa7fc87d9,0x6e360214,0xd00f0124,0x212df264}},	//   kkın, _kayb, الم_, hweh_,
   {{0x442a28d7,0x8ca4866f,0x93250061,0x9f431a25}},	//   leb_, _चीजो, _کرین, _dejà_,
   {{0x64a69d38,0x61e47265,0xe8194102,0x6280c63a}},	//   пада, mbil, न्हा_, vimo,
   {{0x44387266,0x442a2339,0x3ea6c01e,0x260886a7}},	//   ndr_, neb_, slot_, _हाकी_,
   {{0x6280a755,0x3ea6f267,0x26c4f268,0x9f5881cc}},	//   timo, plot_, _timo_, ürü_,
   {{0x442a7269,0x1dbe016f,0x46a3bce9,0x752400c3}},	//   heb_, ोशात, _засв, _opiz,
   {{0x62808558,0xb21b00e8,0x61e4047f,0x442a64d4}},	//   rimo, _kjær, ibil, keb_,
   {{0x6d408ece,0x6280b033,0x442a06ec,0x645a0198}},	//   _irma, simo, jeb_, ötil,
   {{0x1faa03a4,0x9f4a2018,0x6e364050,0x442a0114}},	//   _करोड, _bebé_, _bayb, deb_,
   {{0x7c2acacd,0x645adfbc,0x200281cc,0xfb878061}},	//   lefr, _hoti, şki_, _عدلی,
   {{0x645a825d,0x44380088,0x61e42924,0x2fca010c}},	//   _koti, fdr_, dbil, _ogbg_,
   {{0x27e98104,0x91bb8039,0xfd65826b,0x442a726a}},	//   _đang_, _המדי, _aisọ, geb_,
   {{0x752402a5,0x8557003d,0x644886cb,0xe81001a2}},	//   _epiz, زیگر_, _mndi, ालना_,
   {{0x6d40f26b,0x645af26c,0xfbdf8028,0x61e4429d}},	//   _orma, _loti, _đêm_, gbil,
   {{0xd49b0c8e,0xa3cc9664,0x6448d7d9,0x44380115}},	// [6c70] _грн_, रखा_, _ondi, bdr_,
   {{0x645af26d,0x61e41bb7,0xb5fb726e,0x2f150338}},	//   _noti, abil, chár, tåg_,
   {{0x61e401cd,0x06e080c8,0x6d40938e,0x7c2ac2ae}},	//   bbil, _ভিডি, _arma, defr,
   {{0x6448f26f,0x6d4080dd,0x645a8362,0x2bd901d0}},	//   _andi, _brma, _aoti, बुरा,
   {{0xc7b88025,0x645af270,0x2f150106,0x628d08ae}},	//   među_, _boti, såg_, mnao,
   {{0xdfc68013,0x7c2af271,0x6aa2826b,0x03a59170}},	//   _لي_, gefr, _akof, мило,
   {{0xff0407ac,0x645acbe1,0x65628122,0xe0df0706}},	//   _пятн, _doti, ayoh, _bròg_,
   {{0xe0d9c898,0xac778077,0x4421284c,0x442a009a}},	//   ови_, _کارش, _lbh_, zeb_,
   {{0x645aa7da,0x442130dc,0xa7fc807e,0x320d8713}},	//   _foti, _obh_, rkın, rgey_,
   {{0x7e6d0065,0xa3bf17ba,0x68ed81b9,0x60c703ec}},	//   _alap, ेशा_, _ħadd, _jijm,
   {{0x752f009a,0xa2cd06a7,0x752400c3,0x61e41277}},	//   ewcz, _दूल्, _spiz, ybil,
   {{0x6e3602a3,0x645a80f1,0x68f60114,0x60c7090d}},	//   _qayb, _zoti, ysyd, _lijm,
   {{0x442a7272,0x20188722,0x7e6d2e0b,0x38b40799}},	//   teb_, òric_, _dlap, läre_,
   {{0x6aa983a6,0x4e0a0105,0x60c700f3,0x645a82df}},	//   llef, _वाकई_, _nijm, _xoti,
   {{0x61e459b2,0x442a5c3c,0x64890267,0x6e3601e0}},	//   tbil, reb_, džid, _tayb,
   {{0x442a7273,0x4cdd00ab,0x60cf00c3,0x7d0b8122}},	//   seb_, _বিরু, _bucm, kugs,
   {{0x61e47274,0x8ffa003f,0x6e2b9931,0xfaa315fc}},	// [6c80] rbil, قرار_, degb, тато,
   {{0x61e43ede,0x68f62783,0x76498176,0x9c8704e8}},	//   sbil, rsyd, _aney, _vyčí,
   {{0x69cbf275,0x765bd4ae,0x68eb81c0,0x38b40106}},	//   _ogge, _bouy, _lwgd, värd_,
   {{0x0d868ea6,0x9f47800d,0x645a8790,0xdee31630}},	//   млен, _není_, _soti, тоци,
   {{0xb90300c8,0xdddb81a1,0x28af10c5,0x6aa3041c}},	//   _নয়_, _fjuž, _जीवि, _ênfa,
   {{0x69d982b5,0x69cbf276,0x7b4008ae,0x6aa28123}},	//   _afwe, _agge, pćuć, _skof,
   {{0x645ad04b,0x765b86c0,0x6562aa0f,0xd83882d4}},	//   _voti, _fouy, syoh, joča_,
   {{0x32b78013,0xd25080f7,0xfe4387b6,0x7c2a8c54}},	//   ودية_, انة_, _инсо, sefr,
   {{0x6d40f277,0x645a9517,0x442a83a8,0x64400ec3}},	//   _urma, _toti, _ºb_, ēmij,
   {{0x6448f278,0x7e6d3e67,0x0c239a1f,0x15f89055}},	//   _undi, _slap, _имун, ुलकर_,
   {{0xd8388353,0xd9ee0361,0xf4140264,0x765bf279}},	//   goča_, जरात_, াজার_, _youy,
   {{0x4ad20076,0xa40e8d86,0x442100b9,0x940e82f1}},	//   _दूधव, _साँप_, _sbh_, _साँच_,
   {{0x1613852a,0x9f410174,0xb17d81d6,0x63a480fc}},	//   ण्टर_, rbhé_, saťr, ƙins,
   {{0x212683ac,0x26cef27a,0x5fd286ae,0x80d580ab}},	//   _ipoh_, _tufo_, _सलिल, _দিচ্,
   {{0x20198086,0x3d0881ce,0x260f8105,0xdeef8162}},	//   əsi_, _समझे_, _डाली_, _шы_,
   {{0x6aa0901f,0x442100b9,0x7e6d4be8,0xb5fb016b}},	//   nomf, _wbh_, _ulap, cháp,
   {{0xa40e8b9f,0x61e205e4,0x4421051e,0x940e8074}},	// [6c90] _सांप_, ñola, _tbh_, _सांच_,
   {{0xa7fc82d0,0x44210174,0x37ab31ad,0x765b86c4}},	//   kkım, _ubh_, отен_, _souy,
   {{0x61ef57ce,0x6aa0b4e6,0x91c003b7,0x45dc81bc}},	//   _tecl, komf, लेबै, _ịpụ_,
   {{0xd7df2418,0x7bda8125,0x645e80f2,0x5fdf2263}},	//   _प्रच, _aftu, öpin, _प्रल,
   {{0x6e2bb240,0x2a690b99,0xd5fb819d,0x26c9727b}},	//   regb, mkab_, _akụ, _miao_,
   {{0x7d0bf27c,0x26c900fc,0xa3d30054,0x947580d7}},	//   rugs, _liao_, हुच_, رگذا,
   {{0x765b8247,0x2489812b,0xfaa58811,0xa7fc82d0}},	//   _touy, đam_, нако, rkıl,
   {{0xa3b40701,0x2a694794,0x3a3902d6,0x26c9010c}},	//   जेट_, nkab_, _jasp_, _niao_,
   {{0x26d881df,0x9f478144,0x3a3907b6,0x9f4a026b}},	//   íron_, _vení_, _masp_, _lebì_,
   {{0x26d10234,0x6aa9a176,0x6913811f,0x6eca81d0}},	//   _kuzo_, slef, jžeš, _संखु,
   {{0x201887e2,0x2a690074,0x25a902f7,0x44ed2142}},	//   òria_, kkab_, _ayal_, ež_,
   {{0x26c9727d,0xd838807a,0x3e62007b,0x49758523}},	//   _ciao_, roča_, _nótt_, _плес,
   {{0x64890267,0x7872006a,0xddc40af8,0xf48400d7}},	//   džib, _hæve, _bliš, ناسی,
   {{0xe1ff3910,0x3a2d8a85,0x00000000,0x00000000}},	//   _adó_, leep_, --, --,
   {{0xd00e8013,0x29191a83,0xe0df394b,0xf1b981a9}},	//   _الى_, _aqsa_, _atò_, rešu_,
   {{0x26c90028,0xe0da32a7,0x09c380ab,0x3d0083eb}},	//   _giao_, зва_, _এ্যা, _रिले_,
   {{0x41271927,0xd5b20829,0x6e2402a0,0x26d1011b}},	// [6ca0] ното_, _حفظ_, _ibib, _auzo_,
   {{0x6d44727e,0x80a62452,0xddc40088,0x26d10144}},	//   _iria, رمان, _gliš, _buzo_,
   {{0xb4be1834,0x3a2db4ec,0xe0df026b,0xdd929e5c}},	//   ेदी_, keep_, _etò_, گوش_,
   {{0xb8f600c8,0xe29a01e5,0x443a727f,0x2bdd8519}},	//   _সব_, _хам_, _hap_, नुसा,
   {{0xe534f280,0x443a7281,0x78600201,0x3a2d8609}},	//   тель, _kap_, _dövr, deep_,
   {{0x443a7282,0x61f67283,0x645e7284,0x3d208305}},	//   _jap_, layl, _jopi, _यहीं_,
   {{0x394003a6,0x443a0039,0x26d1528c,0x645e01e0}},	//   lvis_, _map_, _guzo_, _mopi,
   {{0xada6a8fb,0x443a7285,0x645e7286,0x6d447287}},	//   _забл, _lap_, _lopi, _oria,
   {{0x39407288,0x6d4401c0,0x3ce00282,0x9f4c9e51}},	//   nvis_, _nria, _ntiv_, radí_,
   {{0x443a6457,0x7c2e7289,0x645e00eb,0x5f048fd5}},	//   _nap_, jebr, _nopi, _विद्_,
   {{0x6d44031d,0x61f6728a,0xdef78a8e,0x7f9481e5}},	//   _aria, kayl, ныя_, танх,
   {{0x442ed971,0x63a487d9,0xddc4007a,0x3940728b}},	//   lef_, ğind, _sliš, kvis_,
   {{0x2f188065,0x6d4400a9,0x7c3af28c,0x39400bda}},	//   ség_, _cria, _katr, jvis_,
   {{0x443a728d,0x7c2e044e,0x628290af,0x645e728e}},	//   _cap_, gebr, _hmoo, _copi,
   {{0x083b812a,0x443a237d,0x2ba401ce,0x43940226}},	//   _מעגל, _dap_, _खुदा, гарс,
   {{0x7c3af28f,0x6d447290,0x442ef291,0x26d1026c}},	//   _latr, _fria, hef_, _ruzo_,
   {{0x39400bc5,0x764d275f,0x6d4469a1,0xf807239c}},	// [6cb0] gvis_, _inay, _gria, ечен,
   {{0x7c3a911b,0x2a697292,0x7c2e3f6a,0x6e3d2924}},	//   _natr, skab_, cebr, ldsb,
   {{0x61f67293,0xe8188768,0x3a2d0118,0x442ef294}},	//   bayl, _दाना_, _ºep_, def_,
   {{0xa2d61094,0x6e3d2445,0x78a1ba2d,0x443a16f0}},	//   _मंत्, ndsb, zolv, _zap_,
   {{0x442edefc,0x443a435e,0x64cb9a4d,0x6e3d06a8}},	//   fef_, _yap_, ादेश, idsb,
   {{0x7c3af295,0x6aad7296,0x62828915,0x26d1004f}},	//   _catr, llaf, _amoo, _tuzo_,
   {{0xe299bb34,0x764d0214,0x7c3a8428,0xfbd401c6}},	//   мак_, _onay, _datr, נתק_,
   {{0xc245a3e1,0x7d1d070b,0x60ca8197,0x31258081}},	//   тник, ktss, _aifm, вдиг,
   {{0x38b4016d,0x7c3af297,0x3a2d86a8,0xdb0883c1}},	//   lära_, _fatr, reep_, _vzdá,
   {{0x2903e408,0x764d0a72,0x7c3a81bf,0x6aad01ec}},	//   čja_, _anay, _gatr, hlaf,
   {{0x6e3bf298,0x25c70085,0x68e40102,0x764d0326}},	//   _kaub, ətlə_, zpid, _bnay,
   {{0x6d440038,0x645e0364,0x7d1d46ec,0xf5ec046d}},	//   _pria, _sopi, ftss, _bẹẹ_,
   {{0x61e9f299,0x443a0247,0x645e729a,0xba748591}},	//   mbel, _pap_, _popi, _حالت,
   {{0xab2a0221,0x232a00e8,0x69dd0343,0x68fbf29b}},	//   мога_, моги_, _afse, msud,
   {{0x638301e2,0xf8c88028,0x61f60214,0x889a8039}},	//   агра, _cứu_, tayl, _קבצי,
   {{0x443a6833,0x69dbcf3e,0xf2d280be,0x3940729c}},	//   _wap_, ncue, שען_, tvis_,
   {{0x443a729d,0x645e729e,0x6d440c7b,0x69a22776}},	// [6cc0] _tap_, _topi, _uria, _कुशी,
   {{0x443a2acb,0x68e40102,0x61f606d5,0x61e980ee}},	//   _uap_, rpid, sayl, hbel,
   {{0x8a060fe7,0xa3bf01a2,0xd6d9004a,0x39400082}},	//   _изне, ेशः_, еті_, svis_,
   {{0x7c3ac12f,0x68fbb745,0x9f4c87a3,0x6e3ba09e}},	//   _satr, ksud, nadá_, _caub,
   {{0xdd8f8013,0x786d8722,0xceb304de,0xa2d61a4d}},	//   يوم_, _núvo, ביא_, _मूत्,
   {{0x38b40106,0x68fb97bf,0x61e9dd7e,0x44259867}},	//   bära_, dsud, ebel, _cbl_,
   {{0x442e831d,0x7c3a803a,0x26130768,0x442597c9}},	//   ref_, _vatr, _थाली_, _dbl_,
   {{0x442ef29f,0x61e9d769,0x32638198,0x5a34964f}},	//   sef_, gbel, итыв, унит,
   {{0x28d80e70,0x7c3ad09e,0x7e6080f7,0x9f4c81df}},	//   _भूमि, _tatr, _iomp, dadá_,
   {{0xdefa87ac,0x7e608282,0x3ce6e3e5,0x9f4c823e}},	//   мым_, _homp, mpov_, tadà_,
   {{0x81cb00ab,0xdeb58326,0xe4758162,0xbebd0ec3}},	//   রুপ_, _arzƙ, _сутэ, ntīg,
   {{0x64890a8e,0x09e69d38,0x83fc805c,0x91e680b3}},	//   džia, _родн, _dođe, _роде,
   {{0x39408013,0x6e3d0cd7,0x02be01d0,0xf8c8827d}},	//   _éis_, rdsb, ्दैन, _bứt_,
   {{0xdddb87d9,0x7e60a3e3,0x67d38f51,0xf00b0129}},	//   _oluş, _lomp, _кошу, _đắng_,
   {{0x81e400c8,0x248d0a20,0x47c080ab,0xf8c880ff}},	//   _নয়_, đem_, _শ্রী, _dứt_,
   {{0x764d00b8,0xb5fd8ee0,0x20183944,0x7e60f2a0}},	//   _unay, _koše, _acri_, _nomp,
   {{0x2ba98bb8,0xd759015b,0x3ea909ca,0xc05b0b73}},	// [6cd0] _चुना, کلات_, _ikat_, між_,
   {{0x61e9eb18,0x6e3bd917,0x38b40106,0xb767310c}},	//   zbel, _saub, tära_, ктей,
   {{0x2fc700f2,0x443172a1,0x7529f2a2,0x7eb672a3}},	//   äng_, mez_, _spez, lápa,
   {{0x443107e8,0xacf9ad3a,0x38b98866,0x3946f2a4}},	//   lez_, енду_, mère_, _oros_,
   {{0x7eb645a4,0xfd1f146f,0xb5fdd3f5,0x3946822c}},	//   nápa, ntì_, _noše, _nros_,
   {{0x443172a5,0x6738920e,0x261a0105,0xa3b70fce}},	//   nez_, _osvj, _भाभी_, _जरा_,
   {{0x4fc40c8e,0x6d42802e,0x6e3bf2a6,0x39468114}},	//   _вста, avoa, _taub, _aros_,
   {{0x83fc803b,0x44314385,0x6d4100eb,0x61e9adae}},	//   _rođe, hez_, ālaj, ubel,
   {{0x4425e02f,0x443172a7,0x69dbc9d6,0x3946c8d7}},	//   _tbl_, kez_, rcue, _cros_,
   {{0x61e687d9,0x39468355,0x46e9867c,0x83fc817f}},	//   ıkla, _dros_, ндон_, _pođe,
   {{0x443172a8,0x68e2826c,0x6ec786ae,0x6aa40c93}},	//   dez_, _etod, ़गपु, yoif,
   {{0x83fc8052,0x394680b9,0x38b98036,0xcee88180}},	//   _vođe, _fros_, dère_, کرین_,
   {{0x3946f2a9,0x44315baa,0x91058ba8,0x3ea900dd}},	//   _gros_, fez_, _спле, _dkat_,
   {{0x6abe0ebf,0x443172aa,0x26d189b2,0x38b98036}},	//   ्द्र, gez_, ízos_, fère_,
   {{0x5a960af2,0xe8188074,0x9f4c801b,0x161486a7}},	//   граф, _दाता_, padá_, _डालर_,
   {{0x6d4696f2,0x200321ba,0x648922df,0xa3bb8074}},	//   _škam, _adji_, ržia, _घरन_,
   {{0x291fb86d,0x394672ab,0xe2970087,0xd02601e8}},	// [6ce0] ntua_, íos_, уат_, лмай,
   {{0x64891752,0x7e60f2ac,0x291f8bf0,0x443172ad}},	//   lžin, _somp, itua_, cez_,
   {{0x441b093f,0x141b00be,0x5c3703c8,0xe7e306a7}},	//   _אויס, _אויב, _גרין_, गड़ा_,
   {{0x291f8102,0xbebd00eb,0x23650106,0xfdd280ab}},	//   ktua_, rtīg, älje_, ার্ড,
   {{0x7c3e53d2,0x5bcc864a,0xbebd01a9,0x291f83ed}},	//   _kapr, ाश्व, stīg, jtua_,
   {{0x9f478214,0x2003026c,0xdca380e8,0x64a3af8d}},	//   _genç_, _gdji_, бачи, бача,
   {{0x7c3e2547,0x6fb802f1,0x291d81b9,0x7eb6016b}},	//   _mapr, _अरिं, _aqwa_, zápa,
   {{0x44310d38,0x7c3e0d29,0x224072ae,0x660472af}},	//   zez_, _lapr, ndik_, _ndik,
   {{0xe818ad3b,0xa9c3835f,0x443102be,0x64890b80}},	//   _दादा_, йськ, yez_, džin,
   {{0x660410e1,0x3ea972b0,0xb8dc81a2,0x3ea6c65e}},	//   _adik, _skat_, _आठ_, loot_,
   {{0x443103d3,0x2c1b159a,0xa3d805fc,0x443ef2b1}},	//   vez_, _बाबू_, िशन_, _iat_,
   {{0x443e8367,0x3946f2b2,0x1efb00be,0x38af0214}},	//   _hat_, _tros_, עלכע, türk_,
   {{0x443172b3,0x443ef2b4,0x5c0722a0,0x9c83807a}},	//   tez_, _kat_, лява, _ščit,
   {{0xdfcf8013,0x66040247,0x443ef2b5,0x3ea6f2b6}},	//   _فيه_, _edik, _jat_, hoot_,
   {{0x443e9c02,0xfe148105,0x7c3e0247,0x8cd50f3d}},	//   _mat_, _डांस_, _dapr, _यूरो,
   {{0x443107e8,0x443e8063,0xddc2c67b,0x5a3503a7}},	//   sez_, _lat_, zkoš, јнат,
   {{0x44311ee8,0x443eb23e,0x7c288259,0x20cd0b67}},	// [6cf0] pez_, _oat_, _obdr, _džin_,
   {{0x38b980e7,0x13cc80ab,0x752d0037,0x25ad8176}},	//   père_, রুয়, _ipaz, _ryel_,
   {{0x47350087,0x291f811b,0x63680081,0xf1bf026b}},	//   рнес, ztua_, _бряг_, _gbán_,
   {{0x7c3e7232,0xa3ca81ce,0x4fc40009,0x63a90214}},	//   _zapr, ोशन_, ссуа, ğend,
   {{0x6e3f0372,0xddc2acf6,0x443ef160,0x7c3e02d0}},	//   _maqb, tkoš, _bat_, _yapr,
   {{0x6b65af4f,0xa3d8016f,0x20030b80,0x443e81c6}},	//   икла, िशय_, _udji_, _cat_,
   {{0x443ef2b7,0x61ed72b8,0x224f80ee,0x5c0484cf}},	//   _dat_, obal, _pngk_, сяча,
   {{0x291f9b1c,0x752d0353,0xa3a983dd,0x78720366}},	//   ttua_, _opaz, _गुण_, _jævn,
   {{0xe8f684d9,0xaca381bc,0x6e2982d5,0x291f8198}},	//   алы_, _awụn, _ibeb, utua_,
   {{0xb5fb000d,0x443ecc4e,0x291f9eb8,0x64890110}},	//   cház, _gat_, rtua_, džio,
   {{0x291f8bf0,0x61ed6dd9,0x7c3e42f3,0x3a3d80b9}},	//   stua_, kbal, _rapr, _tawp_,
   {{0xf1c5146d,0x7c3e72b9,0x7872006a,0x5f080424}},	//   वधान, _sapr, _nævn, _हिस्_,
   {{0x61ed2997,0x7c3e72ba,0x61fbf2bb,0x38ab8aa2}},	//   dbal, _papr, maul, ført_,
   {{0x317a83c8,0x443e823e,0x18669da4,0xf745997d}},	//   _באנד, _xat_, _ваши_, _веко,
   {{0x6b6324dc,0x6a78008b,0x68e98687,0xe3631ae2}},	//   окра, _lífe, lped, окри,
   {{0x61fbe69f,0x61ed72bc,0x7c3e2208,0x2ca79384}},	//   naul, gbal, _wapr, hond_,
   {{0x2ca78006,0xa2d672bd,0xe9d70c0e,0x7c3e0e2d}},	// [6d00] kond_, _मूर्, рку_, _tapr,
   {{0x6e29c1b5,0xf00b001c,0xe0df00ff,0x68e98084}},	//   _abeb, _đảng_, _tròn_, iped,
   {{0x21200ee1,0x61ed72be,0x3ea69384,0x6d49bc51}},	//   stih_, bbal, toot_, _area,
   {{0x0bb704de,0x6d49bf88,0x75468e97,0xa116003d}},	//   _כלים_, _brea, инез, _پوست,
   {{0x443ef2bf,0x6d49b64d,0xe81e0105,0x62963963}},	//   _pat_, _crea, _पापा_, mnyo,
   {{0x23ba000f,0x6d49adbc,0x6e29912e,0xb5fb0298}},	//   _इराद, _drea, _ebeb, nkár,
   {{0x443ef2c0,0x2ba9809a,0xe45700be,0x3ea6f2c1}},	//   _vat_, _चुदा, ייסט_, poot_,
   {{0x443e9de4,0x6d498af9,0x629602ec,0x7f3b04de}},	//   _wat_, _frea, nnyo, _בעלו,
   {{0x443e81cd,0xfce39878,0x6d49e7a8,0xd5a511bc}},	//   _tat_, _мото, _grea, _गुंज,
   {{0x26d872c2,0x29000009,0x2ca7dc92,0x61ed04e8}},	//   _kuro_, isia_, cond_, zbal,
   {{0x7640f2c3,0x1df907ac,0xa2d60aad,0x75228065}},	//   _kamy, лены_, _मूल्, ltoz,
   {{0xb5fd9070,0x29000364,0x61fbe8a7,0x26d85642}},	//   _koša, ksia_, caul, _muro_,
   {{0x290021e0,0x61e2d65f,0xb5fd8b80,0x26d80144}},	//   jsia_, _ifol, _joša, _luro_,
   {{0x26d80548,0x7ebd00e7,0xd8388968,0xe0df02d6}},	//   _ouro_, dépe, koči_, _dròl_,
   {{0xbebd0029,0xe2870073,0xd838807a,0x83f80198}},	//   rtīb, аѓан, joči_, ресс_,
   {{0xbebd0029,0x78a8f2c4,0x2ca780f3,0x277781c6}},	//   stīb, lodv, zond_, _כגון_,
   {{0xdebc0039,0xc1b972c5,0x27f872c6,0xf8baa594}},	// [6d10] _במהל, улах_, _bern_, _उठाय,
   {{0x085400e8,0x6296008a,0x06de0264,0xa5bb0144}},	//   овую, anyo, _ডিজি, nfóm,
   {{0xec360051,0x62963f3f,0x2ca78a0f,0x6d498083}},	//   _האתר_, bnyo, vond_, _srea,
   {{0x26d86da3,0x83fc8052,0x6d49f2c7,0x2ca7910f}},	//   _duro_, _rođa, _prea, wond_,
   {{0xf8db0424,0x290072c8,0x2ca7f2c9,0x764082d6}},	//   _बढिय, csia_, tond_, _damy,
   {{0xb5fd8025,0x6d49802e,0xe81e2776,0x27f801ec}},	//   _doša, _vrea, _पाया_, _gern_,
   {{0xe7ed035a,0xa3d817a3,0x2ca783b2,0x26d872ca}},	//   _च्या_, िशत_, rond_, _guro_,
   {{0xeb980039,0x6d49f2cb,0x76408110,0x290dcdad}},	//   ידור_, _trea, _gamy, trea_,
   {{0x61fb9716,0xa2ba3731,0x2ca780e7,0x6d49a86c}},	//   raul, ्षत्, pond_, _urea,
   {{0x2055916b,0x290daf7f,0xcea900be,0xd3a7a6df}},	//   стир, rrea_, _װי_, _креп,
   {{0x61fbf2cc,0xa5bb007b,0xb8fe8006,0xe945803d}},	//   paul, sfól, _दू_, _گرای,
   {{0x644384e1,0x290016a7,0xed5a1f43,0x68e9f2cd}},	//   ldni, ysia_, гом_, pped,
   {{0xdd9204e3,0xe945803d,0x3f8b8035,0x627b8035}},	//   سوس_, _درای, ńcu_, głoś,
   {{0x28db101b,0x9f47b80c,0x64439614,0x6441f2ce}},	//   _बढ़ि, _menú_, ndni, _jali,
   {{0x394b1ed6,0xb5fb36af,0x786dcac0,0x7e6472cf}},	//   _arcs_, rkár, _núvi, _toip,
   {{0x225f8812,0x6441f2d0,0x29002587,0x20cd01a1}},	//   njuk_, _lali, tsia_, _džim_,
   {{0x290072d1,0x26d807f1,0xbebd01a9,0x76408196}},	// [6d20] usia_, _suro_, stīc, _ramy,
   {{0x26d200f6,0x644183f8,0x26d82f15,0x629659d2}},	//   _hiyo_, _nali, _puro_, snyo,
   {{0x6443816d,0x3ead82c4,0xe81e06ae,0x27f8021e}},	//   ddni, _bket_, _पाठा_, _vern_,
   {{0xb5fd8d11,0x6443f2d2,0x9f58020f,0x786d80a9}},	//   _poša, edni, _herë_, _dúvi,
   {{0x78600201,0x64890da8,0x3ead808e,0x9f459c32}},	//   _mövz, džij, _dket_, valý_,
   {{0x75228019,0x6441879a,0x26d872d3,0x6a758144}},	//   rtoz, _cali, _turo_, _ráfa,
   {{0x6441f2d4,0x26d2010c,0x087703de,0x26c00833}},	//   _dali, _oiyo_, _פעלט_, _ohio_,
   {{0x6e968013,0x7d04370f,0xe6968013,0x25ad009a}},	//   _الرا, _ovis, _الرد, żeli_,
   {{0x81aa00c8,0xa3d80466,0x9f5a09b2,0xd7fa9577}},	//   গের_, िशा_, dapé_, лун_,
   {{0x7c658013,0x7d02f2d5,0x6441960c,0x290a8259}},	//   _والل, msos, _gali, čba_,
   {{0x7d04364b,0x26d21d15,0x7d028711,0x26c00362}},	//   _avis, _biyo_, lsos, _bhio_,
   {{0xc3b780be,0x26d20704,0x8f9b025f,0xe0df0362}},	//   _פלאץ_, _ciyo_, ריטי, _sròm_,
   {{0x92d50a49,0x261a09a3,0x98a6872a,0x64419afe}},	//   _হবে_, _भारी_, _лиде, _yali,
   {{0x2a66822c,0x64418be9,0xf4840098,0x9f458216}},	//   _hoob_, _xali, пусн, galó_,
   {{0x25a072d6,0x2a6681c5,0xeabf001c,0x5f93ce98}},	//   _exil_, _koob_, _phù_, _ништ,
   {{0x644386b9,0x7d02a5ac,0x9f5a36b5,0x00000000}},	//   zdni, ksos, capé_, --,
   {{0xb5fd8fda,0x786d81ac,0x6e2d5823,0x2a668282}},	// [6d30] _bošn, _súvi, _ibab, _moob_,
   {{0x442769cb,0x2a66f2d7,0x3eadf2d8,0x81bd80ab}},	//   _ùn_, _loob_, _sket_, _আলম_,
   {{0xeabf00ff,0x6441f2d9,0x656f72da,0x273a81a9}},	//   _thù_, _rali, lych, _jūn_,
   {{0x2a66bf33,0x6d4d1316,0x442cefd3,0x81cb00ab}},	//   _noob_, _kraa, _abd_, রুষ_,
   {{0x6441861b,0xa3cb9a8f,0xed59a2be,0x656f0428}},	//   _pali, रेन_, рол_, nych,
   {{0x61ff029a,0x68ed72db,0x442cabc7,0x644189ac}},	//   laql, mpad, _cbd_, _qali,
   {{0x64418744,0x2a66f2dc,0x64438082,0x8c1c098a}},	//   _vali, _boob_, rdni, אווי,
   {{0x6441a784,0xe9d9f2dd,0x2a6681c5,0x6d4d72de}},	//   _wali, шки_, _coob_, _oraa,
   {{0x2ba980c2,0x6609be39,0x68ed0ff5,0xe0d68a8e}},	//   _चुरा, _idek, npad, овы_,
   {{0xaf0594b8,0x6e2d6df4,0x394941fc,0x26d20010}},	//   опол, _abab, ivas_, _siyo_,
   {{0x2a668282,0x7d093378,0x6609816b,0x7d0472df}},	//   _foob_, šesl, _kdek, _svis,
   {{0x6d4d14d1,0x2a6681b4,0x63ad8850,0xddcd0824}},	//   _braa, _goob_, ğand, _slaš,
   {{0xddcd72e0,0x763a8158,0x2c6b8257,0xb5fd811f}},	//   _plaš, בערג, _født_, _lošo,
   {{0x6d4d05f8,0x7d0480f7,0xdfdb8081,0x6e2d036a}},	//   _draa, áisi, _съд_, _ebab,
   {{0x81b100ab,0xbb4330a4,0xd2520591,0x6d4d4ef6}},	//   টেম_, мерк, ونس_, _eraa,
   {{0x66098135,0x6d4d1eb2,0x6e2d67fc,0x7d040840}},	//   _ndek, _fraa, _gbab, _tvis,
   {{0x6d4d465e,0x25df000f,0x68ed1341,0x2a79008e}},	// [6d40] _graa, _गलती_, gpad, _dlsb_,
   {{0x83fc81a1,0x68e4f2e1,0x1fb6004a,0x6ecca353}},	//   _rođo, _éide, осер, _işbi,
   {{0x44443897,0xe821809a,0x81cb00ab,0x224272e2}},	//   _ia_, _माना_, রুল_, _takk_,
   {{0x44444259,0x61ff0085,0xd62a8371,0x87ac83de}},	//   _ha_, caql, роде_, נשאַ,
   {{0x2a66f2e3,0x764472e4,0x6ef002d6,0x66099a1a}},	//   _roob_, _maiy, _bòbò, _ddek,
   {{0x44444a79,0x443872e5,0x66098133,0x83fc817f}},	//   _ja_, ner_, _edek, _vođo,
   {{0x444472e6,0x443872e7,0x7d02bd06,0x9f4305a4}},	//   _ma_, ier_, ssos, _dejó_,
   {{0x44384946,0x61e472e8,0xfbd30039,0xead38009}},	//   her_, ncil, ותו_, мощь,
   {{0x4438432b,0xa2da8894,0x444472e9,0xe51c06b7}},	//   ker_, _पूर्, _oa_, भूमि_,
   {{0x6d40f2ea,0x7e62803b,0x443872eb,0xddc4399c}},	//   _isma, ljop, jer_, _bliž,
   {{0xb7db03c8,0x7e7d1a34,0x76440041,0x673a81ed}},	//   יקיי, thsp, _baiy, uwtj,
   {{0x444401b4,0x6d4d4897,0x368b11cf,0x39490110}},	//   _aa_, _praa, рсон_, yvas_,
   {{0x444460f8,0x443827c9,0x200a026c,0x1dca84c5}},	//   _ba_, fer_, _odbi_, िधित,
   {{0x444472ec,0x443817db,0x6d4d1afa,0x656f72ed}},	//   _ca_, ger_, _vraa, rych,
   {{0x76440326,0x9f4100e5,0x6d4d1384,0xd8388b80}},	//   _faiy, cchè_, _wraa, meč_,
   {{0x444472ee,0x6d40f2ef,0xd838cb71,0x6d4d2b1b}},	//   _ea_, _osma, leč_, _traa,
   {{0x444472f0,0xe82181ab,0x61ff0201,0xb5fd87dd}},	// [6d50] _fa_, _मामा_, raql, _došl,
   {{0x444472f1,0x7c388052,0x68ed3bfe,0x61e40118}},	//   _ga_, jevr, rpad, acil,
   {{0x442144c0,0x6d408573,0x1eea026a,0x4ea7f2f2}},	//   _ich_, _asma, مولی_, орда,
   {{0x518723b0,0x68ed016d,0x9f4142f0,0x236c0106}},	//   _дуга, ppad, nché_, ädje_,
   {{0x44442beb,0x644504d2,0x73e58698,0x6609820f}},	//   _ya_, _kahi, полз, _vdek,
   {{0x444472f3,0x61fd0775,0xd83882fd,0x644510fe}},	//   _xa_, _hesl, ječ_, _jahi,
   {{0x64451856,0x6d40ce08,0x2001061b,0x290683a8}},	//   _mahi, _esma, mahi_, _avoa_,
   {{0x44386abd,0x60d507d9,0x442101a8,0xb87b016b}},	//   zer_, _hizm, _lch_, _stíh,
   {{0x442170ab,0x44380806,0xc1b9035a,0xdb08801b}},	//   _och_, yer_, _आरोग, _vydá,
   {{0x26dc8a8e,0x443872f4,0x644572f5,0x442154c3}},	//   _buvo_, xer_, _nahi, _nch_,
   {{0x44384a2a,0x444472f6,0xe8218076,0x7e7b803a}},	//   ver_, _ra_, _माठा_, _klup,
   {{0x44444a73,0x44211523,0x44382972,0x9f410698}},	//   _sa_, _ach_, wer_, rchè_,
   {{0x644572f7,0x200142af,0x57b8064a,0x1c200f3d}},	//   _bahi, kahi_, _अर्ह, _बादल_,
   {{0x3cfd8076,0x443872f8,0x2001123c,0x644572f9}},	//   रीये_, uer_, jahi_, _cahi,
   {{0x444472fa,0x443822c3,0x61fd72fb,0xb5fda1f6}},	//   _va_, rer_, _besl, _pošl,
   {{0x444472fc,0xe9da1c45,0x61fd017f,0xd5a70d86}},	//   _wa_, ска_, _cesl, _टुकड़,
   {{0x444472fd,0x6445152b,0x61fd00a2,0x61e467bf}},	// [6d60] _ta_, _fahi, _desl, rcil,
   {{0x4444146a,0xb90411bc,0x8fa60098,0x7e7bf2fe}},	//   _ua_, _पं_, пазе, _alup,
   {{0x25bf8510,0xc2f080ab,0x59b00035,0x7d19890d}},	//   _azul_, _টিভি_, _फ़रवर, euws,
   {{0x61fd6be2,0x64451984,0x0dca8009,0x3e7b00f1}},	//   _gesl, _zahi, блей_, _këta_,
   {{0xa25b0142,0x48e312c0,0x64452bae,0x7c389df8}},	//   _khôn, _появ, _yahi, tevr,
   {{0x25bf80dd,0x91bb0039,0x7e62bb7f,0xb87b0216}},	//   _dzul_, _למכי, sjop, _cuíd,
   {{0x8fa30c40,0x5e969a05,0xd8388353,0x07a30791}},	//   _заре, _فلسط, več_, _зарн,
   {{0x7e7b803a,0x60dd00dd,0xb95480e8,0x26dc8037}},	//   _glup, _yusm, двищ, _ruvo_,
   {{0x6d40b38a,0x7984005d,0x26dc8904,0x2d828106}},	//   _usma, nziw, _suvo_, _åke_,
   {{0x443887ca,0x44e281fa,0x6c8692dc,0x2fd883ba}},	//   _úr_, _ið_, _علام, ørg_,
   {{0x64454e28,0x09b906bf,0xd838e990,0x7bda8420}},	//   _rahi, _आर्य, reč_, _igtu,
   {{0x64453a04,0xd6d78987,0xe821b9a1,0x442172ff}},	//   _sahi, ять_, _माथा_, _sch_,
   {{0x9f412c36,0x64454be4,0x61fd7300,0x20017301}},	//   rché_, _pahi, _resl, yahi_,
   {{0x753d0063,0x6ab51094,0x26dc8693,0x29028110}},	//   rwsz, ंत्र, _tuvo_, škas_,
   {{0x64457302,0x3d12016f,0x2491080a,0xe821ac4c}},	//   _vahi, _तिथे_, rizm_, _माता_,
   {{0x20017303,0x60f911e9,0x64456cad,0x69da0087}},	//   wahi_, жная_, _wahi, _şter,
   {{0x20012547,0xf9930077,0x64454517,0xd2500065}},	// [6d70] tahi_, ربر_, _tahi, ھنے_,
   {{0x201e81e2,0x26c48267,0x61fd0a15,0x3eb92385}},	//   ngti_, _ahmo_, _wesl, llst_,
   {{0x44e2f304,0xb9040076,0x61fd525e,0x7e7b80e7}},	//   _að_, _पू_, _tesl, _plup,
   {{0xa15925f5,0x20015e9d,0xddd08110,0x19590a14}},	//   _даму_, sahi_, _šešt, _дамы_,
   {{0x8c459cf4,0x04459354,0x6d468805,0xb87b002a}},	//   деле, делн, _škar, _puíd,
   {{0x7e7b80b9,0x7eb60061,0x22497305,0xb5fd8619}},	//   _wlup, rápi, ldak_, _košk,
   {{0x7e6985f8,0x9f5ef306,0x9f3400e8,0xb5fd836f}},	//   _toep, baté_, _пері, _jošk,
   {{0xb5fd8db7,0x660d7307,0xcf9200be,0x7e7bf308}},	//   _mošk, _ndak, _סטן_, _ulup,
   {{0x81b58a49,0x08c58328,0x21290812,0x7d0480f7}},	//   ছেন_, мбин, ntah_, áist,
   {{0x660d2140,0x7d0484b7,0x2a7f9705,0xa8899138}},	//   _adak, ġist, shub_, ійна_,
   {{0xa25b00e7,0xaabf14a7,0x628081c0,0xb21b00ec}},	//   _rhôn, ्षाक, bhmo, _klæd,
   {{0x7bc18668,0x21290d8b,0x22492376,0x38b40106}},	//   _izlu, ktah_, jdak_, lärt_,
   {{0xddc08efd,0xe81e1344,0xd945813a,0xd009a903}},	//   _komš, _पाला_, _цели, _деле_,
   {{0xb5fd8503,0x2a7d8069,0x741601ad,0x7afb0b80}},	//   _bošk, _hlwb_, بوسا, ćutn,
   {{0x09e61b5a,0x212922ca,0x394da0ef,0x41eb019d}},	//   добн, etah_, lves_, _ụsọ_,
   {{0xc3328051,0x64890110,0x7d09a442,0x2129358f}},	//   כול_, džiu, _oves, ftah_,
   {{0xa25b0104,0x63a487d9,0x3ced81c5,0xe29702df}},	// [6d80] _thôn, ğini, _ntev_, фат_,
   {{0x6d4423c5,0x63a4c64a,0xa2be06f0,0xb5fb01fa}},	//   _isia, şini, _वीर्, hjál,
   {{0x7d09a127,0xa3b506a7,0x7eb883a8,0x9f5eb6b5}},	//   _aves, _छुप_, lípi, taté_,
   {{0x7c3c0102,0x2007237b,0xdddb81d0,0x386a0428}},	//   lerr, ónir_, _kouř, _wobr_,
   {{0xa3cb890f,0x6489005c,0x9f5eabc6,0x98bd82d6}},	//   रेस_, rživ, raté_, _aswč_,
   {{0x394d8019,0x7c3c1473,0x38b40338,0x6d442b8c}},	//   dves_, nerr, gärt_, _msia,
   {{0x628080f1,0x6489026f,0xf743087e,0x9f5ef309}},	//   thmo, mžit, _иеро, paté_,
   {{0x7c3c579c,0x6d446b88,0xb21b013c,0x7c293378}},	//   herr, _osia, _glæd, đeri,
   {{0x7c3c0bf0,0x14268187,0xa2daa123,0xdb088198}},	//   kerr, _одам, _पंक्, _sydä,
   {{0x6a7c80e7,0x62808168,0x7c3c1832,0x63ad807e}},	//   _défa, shmo, jerr, şana,
   {{0x6d44730a,0x381704de,0x7d09b0fc,0xdb0b07c0}},	//   _asia, וקים_, _zves, ünüz,
   {{0x64488a98,0x443c8982,0x442ef30b,0x787f80e7}},	//   _hadi, lev_, lff_, _rêve,
   {{0x6448927b,0x645a8122,0x7c3c730c,0x63a902d0}},	//   _kadi, _knti, ferr, ğenm,
   {{0x64488be6,0xb5fdddd2,0x442ea651,0x443c8074}},	//   _jadi, _pošk, nff_, nev_,
   {{0xa4d4035f,0x46a70009,0x62810110,0xf8378039}},	//   торі, _ошиб, ūlom, _חנות_,
   {{0xe0df0698,0x83fc812b,0x3204cb72,0x660d730d}},	//   _può_, _dođi, namy_, _udak,
   {{0x7c3c730e,0x443cf30f,0x7eb883a7,0x645a8980}},	// [6d90] berr, kev_, cípi, _onti,
   {{0x3e7b020f,0x443c8805,0x7d1d5880,0x7c3c5f17}},	//   _këto_, jev_, muss, cerr,
   {{0x7d098067,0x21297310,0x7d1d25ac,0xd148801c}},	//   _sves, stah_, luss, _lễ_,
   {{0xb5fd9ded,0xc3320158,0x6aa280f1,0x6e3d4f90}},	//   _koši, _גוט_, _njof, nesb,
   {{0x6448f311,0xe3b8880a,0x7e6d0420,0xb5fd8b80}},	//   _badi, _ayı_, _moap, _joši,
   {{0xdfc695a8,0x645a80dd,0x443c82f1,0x251c0e82}},	//   _مي_, _cnti, gev_, קווא,
   {{0xb5fd811f,0x6448f312,0x1ee700d7,0x6600da41}},	//   _loši, _dadi, _آوری_, _femk,
   {{0x7c3c26f7,0xb1459e25,0x7e6d002e,0x7d1d288c}},	//   zerr, енил, _noap, kuss,
   {{0x7c2521aa,0x81b100c8,0x644884b9,0x9f410013}},	//   _ochr, টের_, _fadi, ichí_,
   {{0x6448f313,0xd1488028,0x7d1d6b8e,0x443c807a}},	//   _gadi, _dễ_, duss, cev_,
   {{0x3ce054ae,0xa3cb83dd,0xe7ee86a7,0x394df314}},	//   _suiv_, रेश_, छड़ा_, sves_,
   {{0x29090009,0x290b0669,0x32048035,0x7c2558f1}},	//   ksaa_, _ovca_, camy_, _achr,
   {{0x7ae1f315,0xb87b03a8,0xa25b0036,0x7d1d7316}},	//   _hult, _xuíc, _chôm, guss,
   {{0x8fa5b6de,0x61e9f317,0x64488be9,0x83fc80fe}},	//   _пале, lcel, _xadi, _pođi,
   {{0x2005f318,0x4256117e,0x7c3c2dfe,0x4425d5e7}},	//   mali_, нтат, rerr, _mcl_,
   {{0x61e9f319,0x7ae1eeb3,0x6d4401c5,0x7c3c09cb}},	//   ncel, _mult, _tsia, serr,
   {{0x443c8086,0x6606731a,0x563700be,0x08c63b78}},	// [6da0] yev_, makk, _טאקע_, ебан,
   {{0x2005f31b,0x6606692e,0x3940009a,0xf1bf0032}},	//   nali_, lakk, rwis_, _abás_,
   {{0xabfb0051,0x66008b99,0xf7721e09,0x7ae181f4}},	//   _מהיר, _pemk, داء_, _nult,
   {{0x6448f31c,0x2005c3fb,0x66061f9f,0x645a80b9}},	//   _sadi, hali_, nakk, _snti,
   {{0x443ca588,0x2005ecc7,0x4abf0076,0x6448f31d}},	//   tev_, kali_, ्षरव, _padi,
   {{0x6296731e,0x2005cfc1,0x7ae1a023,0x44e6001c}},	//   liyo, jali_, _bult, _mô_,
   {{0x443c92f1,0x2005f31f,0x1fb50ddc,0x6448f320}},	//   rev_, dali_, _астр, _vadi,
   {{0xcb130051,0x443c9d6d,0x62967321,0x66062337}},	//   אלה_, sev_, niyo, jakk,
   {{0x6448f322,0x66061b7c,0xada39d24,0x261a016f}},	//   _tadi, dakk, _батл, _भाजी_,
   {{0x2005f323,0xd7f796fe,0x629666e6,0x320480ee}},	//   gali_, ную_, hiyo, samy_,
   {{0xb4cc93e5,0x6296641d,0x660602a6,0x61e9b7f7}},	//   रगी_, kiyo, fakk, bcel,
   {{0x7c2507b4,0x6e22829b,0x7d1d2411,0x290902a3}},	//   _schr, ngob, tuss, ysaa_,
   {{0x44e60104,0x2005f324,0x62963e79,0x44337325}},	//   _cô_, bali_, diyo, _pbx_,
   {{0x20059429,0x6606008e,0xbcfb002a,0x7ae201a1}},	//   cali_, aakk, bxén, _čotr,
   {{0x660662b1,0x7d1d7326,0x39ee0a2c,0xd7f88087}},	//   bakk, suss, _ọzọ_, mbă_,
   {{0xb5fd8390,0x7d1d0c4f,0xb0ec00ab,0x66e50084}},	//   _toši, puss, _ওয়েব_, _dėkl,
   {{0x38b400f2,0x68e2827e,0x51873872,0x320204e8}},	// [6db0] värr_, _juod, хува, _deky_,
   {{0x7c25122e,0x68e28009,0x9f5807f1,0x7d0d17c9}},	//   _uchr, _muod, _berà_, _ivas,
   {{0x62961040,0x29090198,0x26c97327,0x44e60129}},	//   biyo, ssaa_, _khao_, _zô_,
   {{0x2005f108,0x62847328,0x39468baf,0x9f5e80e1}},	//   zali_, chio, _osos_, jatí_,
   {{0xe8218697,0x200582ec,0x272a84be,0x44e600ff}},	//   _माला_, yali_, hùn_, _xô_,
   {{0x76498101,0xd11604de,0x442330b0,0x224b1e78}},	//   _waey, _בקשה_, ngj_, _hack_,
   {{0xa3cb8063,0x7649f329,0xb87b05e4,0x6606028d}},	//   रें_, _taey, _guía, yakk,
   {{0x2005f32a,0xa562803d,0xb4bf008e,0x6a7c8036}},	//   wali_, _چگون, ेषु_, _défo,
   {{0x660645ea,0x200304be,0xe9df157a,0x61e985d8}},	//   vakk, _keji_, _raúl_, rcel,
   {{0x7ebd03d3,0x61e9d268,0x68e28084,0x62966a64}},	//   léph, scel, _duod, ziyo,
   {{0x2005e5b6,0x07a58112,0xf42700c8,0x394685b4}},	//   rali_, танн, য়ার_, _esos_,
   {{0x26c9732b,0xd7f88087,0xfce61ac9,0x44e65f8f}},	//   _chao_, abă_, комо, _pô_,
   {{0x2005b3d9,0xb6a33c10,0x629602d0,0xfd1f00e5}},	//   pali_, риял, viyo, guì_,
   {{0x44e60028,0x2005836a,0x44230789,0x9f580118}},	//   _vô_, qali_, ggj_, _lerá_,
   {{0x224b3c32,0x629607d9,0x628435f6,0x7d0d732c}},	//   _back_, tiyo, thio, _evas,
   {{0x224df32d,0x44e61762,0xb5fd805c,0xcfb700ab}},	//   ndek_, _tô_, _košu, জধান,
   {{0x6296732e,0x9f5807e2,0x290c01a9,0xbcfb002a}},	// [6dc0] riyo, _serà_, _ādas_, nxél,
   {{0x92dc80c8,0x6296732f,0x66047330,0x628401c6}},	//   তীয়_, siyo, _heik, shio,
   {{0x394d0289,0x3a3ff331,0x7d09005c,0x6a78007b}},	//   _šest_, keup_, šest, _lífi,
   {{0x6a7c80e7,0x644e7332,0x9407811c,0x2003026b}},	//   _réfo, ldbi, minə_, _eeji_,
   {{0x6e228242,0x3cfd801b,0x63ad861c,0x66047333}},	//   rgob, रीले_, şanl, _meik,
   {{0x66042c9f,0xdb1a8019,0x644e5426,0x3a268087}},	//   _leik, _aztá, ndbi, _scop_,
   {{0xa0370bea,0xfbd580ab,0x3860cc91,0x02a68087}},	//   _שאלה_, _স্বত, _đir_, крим,
   {{0xeaaf80f7,0x60dc07b8,0x6d5610ed,0x6a78016a}},	//   يعي_, _hirm, _orya, _bífi,
   {{0x60dc7334,0x2498008e,0x63a902d0,0xfce69133}},	//   _kirm, kirm_, ğeni, _розо,
   {{0x68e28364,0xe7ed81d0,0x63a97335,0x00000000}},	//   _vuod, चुला_, şeni, --,
   {{0x7d0d0052,0x25be0201,0x6d567336,0xba268bba}},	//   _svas, ətli_, _arya, _адек,
   {{0x645e0205,0x6f030073,0xc7b304de,0xa3b601ce}},	//   _anpi, ânci, יבת_, _जड़_,
   {{0x40348110,0xbebd00eb,0x3946c6da,0xceb384de}},	//   _белс, ktīv, _usos_, שיר_,
   {{0x628281e9,0x8f54803d,0x66e50110,0xf75480f7}},	//   _hloo, _منتش, _sėkm, _منتج,
   {{0xb5fd803b,0x69c600ad,0x26c90028,0x6d560ec8}},	//   _košt, _azke, _thao_, _erya,
   {{0x28c686b7,0x442d001b,0xb87b0580,0x645e34eb}},	//   _रीति, ře_, _atíp, _enpi,
   {{0x628281e9,0xaca3019d,0x6a7c80e7,0xf80700e8}},	// [6dd0] _mloo, _alụg, _réfl, вчен,
   {{0x9f580510,0x7e7d0123,0xa2c98054,0x764d01b4}},	//   _será_, lksp, _हीन्, _haay,
   {{0x224b04b8,0x764d25d0,0x62828091,0x69c60102}},	//   _tack_, _kaay, _oloo, _ezke,
   {{0x628281c0,0x4b7a007c,0x60dc0a2a,0xed59816b}},	//   _nloo, _נארו, _eirm, _lyže_,
   {{0xed588cde,0x764d1341,0x9f5828d5,0x7ae50009}},	//   кої_, _maay, _verá_, _huht,
   {{0x60dc68ef,0x764d64be,0x66e8800d,0x6282a5d5}},	//   _girm, _laay, _něko, _aloo,
   {{0x7ae50006,0x9f580e67,0x224d837a,0x6282cbcb}},	//   _juht, _terá_, tdek_, _bloo,
   {{0x2369803b,0x2018846d,0x7ae54597,0x66e8801b}},	//   ćaj_, órin_, _muht, _pěkn,
   {{0x66047337,0x3a3f82f7,0x20c2807b,0x6e299cb9}},	//   _reik, reup_, rðin_, _iceb,
   {{0x94078201,0x6d49c777,0x7989809a,0x91bc0039}},	//   yinə_, _isea, rzew, ומחי,
   {{0xa2f5aaed,0x764d7338,0x628281c6,0x79898035}},	//   _спеч, _baay, _floo, szew,
   {{0xddcd026f,0x764d44bb,0x89b4819d,0xf38c83de}},	//   _dlaž, _caay, ịtọs_, _קראָ,
   {{0x61fbc289,0x66042649,0xb87b0ece,0x22400110}},	//   mbul, _veik, _ruín, veik_,
   {{0x61fbcff6,0x753b82a0,0x7e7d7339,0x7ae5050b}},	//   lbul, _mpuz, ërpr, _buht,
   {{0x387880f2,0x88838077,0x66041de0,0x30da80be}},	//   örre_, _میکن, _teik, _אַהע,
   {{0x94078201,0xb87b00f7,0x7e7d048d,0x6721f33a}},	//   rinə_, _buío, cksp, mulj,
   {{0x60dc3ffd,0x94078201,0x22402dc4,0x98a00289}},	// [6de0] _pirm, sinə_, reik_, ntić_,
   {{0x61ed1268,0x224035ca,0x764d0c2e,0xa84a0174}},	//   acal, seik_, _zaay, علام_,
   {{0xe61a828b,0x61fb883a,0x6d49f33b,0xeb9a5296}},	//   еде_, kbul, _asea, _чин_,
   {{0x61ed733c,0x95ca9444,0xa96a0256,0xdfcf00f7}},	//   ccal, нула_, _зима_, سين_,
   {{0x6aa40087,0x98a005a2,0xe5a3951b,0x63a90799}},	//   mnif, jtić_, бици, ßenv,
   {{0x1aeb80c8,0x6282b8f2,0xafe31aed,0xbebd01a9}},	//   _টিজে_, _sloo, _горл, ltīt,
   {{0xb5fd9874,0x6282a2f5,0x6721817f,0x6d49913b}},	//   _pošt, _ploo, julj, _esea,
   {{0x6721da06,0x98a00754,0x61fb8ce9,0x391481cf}},	//   dulj, ftić_, gbul, амир,
   {{0xddcd0a20,0x83fc8e78,0x201883a7,0x628286a8}},	//   _slaž, _anđe, ório_, _vloo,
   {{0xddcd1011,0x83fc9f79,0x473495b7,0x764d733d}},	//   _plaž, _vođs, анос, _saay,
   {{0x61fb8365,0x764d0637,0xf65f006a,0x2fd88106}},	//   bbul, _paay, nlæg_, ärg_,
   {{0x7bc88d11,0x91e68009,0x61ed0388,0x45d50c9b}},	//   _izdu, _соде, xcal, ионс,
   {{0x7ae501c2,0xd90e87d2,0x6d4f8118,0x25f403db}},	//   _suht, _عید_, _ácat, ंड़ी_,
   {{0x764d02a3,0x67d492bc,0x7ae504a2,0x2c7986c0}},	//   _waay, _колу, _puht, _pèdi_,
   {{0x8aa70951,0xb87b0013,0xd25b1fec,0xddcd0d11}},	//   град, _suío, нца_, _ulaž,
   {{0xf65f0ae1,0x6aa41162,0x5faf064a,0x48fb801b}},	//   dlæg_, gnif, _जुगल, लीको_,
   {{0x61ed058d,0x98a91432,0x3ea900b9,0x940a0085}},	// [6df0] rcal, stač_, _ijat_, hibə_,
   {{0x61fba050,0xf00b001c,0x98a90267,0x68e600fc}},	//   zbul, _đẳng_, ptač_, _dukd,
   {{0x61e2dae4,0x2fc700f2,0x753b8140,0x828b8032}},	//   _ogol, ång_, _spuz, _látọ,
   {{0x61e2e2ae,0x5d55a2be,0x635c8087,0x6aa420e6}},	//   _ngol, икет, _mănă, cnif,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e2f33e,0x4d7c00be,0x98a00088,0xf1bf046d}},	//   _agol, ערגע, vtić_, _iyá_,
   {{0x43698071,0x9f5c8580,0x961d0264,0x7d1d3ede}},	//   тайн_, _nevà_, ধ্যম_, hrss,
   {{0x6d498013,0x3f8c826c,0x3dc900b9,0xbb3c0e82}},	//   _tsea, dzdu_, _ozaw_, געהי,
   {{0xb42787d2,0x6d498009,0xd5388872,0x798d09ab}},	//   _معاو, _usea, _مثلا_, nzaw,
   {{0x5d848013,0x25bf8201,0x290d922d,0x660ba46f}},	//   _الكل, _iyul_, rsea_, lagk,
   {{0x205481bb,0x98a00d11,0x6443d288,0x5ba78009}},	//   стыр, stić_, meni, _сраз,
   {{0x6443f33f,0x6721f340,0x2cba0101,0x660b809c}},	//   leni, rulj, _skpd_, nagk,
   {{0x05d0016f,0x6cc600e8,0xfce61033,0x920801a9}},	//   सेंब, ийма, рого, ntāž,
   {{0x6443f341,0x629b8110,0x442790e1,0x6721cf6d}},	//   neni, liuo, ngn_, pulj,
   {{0xe29a5955,0xa09a83c8,0xdca30572,0xf1bf026b}},	//   вав_, _ביסט, цари, _ayá_,
   {{0x6443c2d8,0x63be026f,0x629b8110,0x6f1c9727}},	//   heni, _vypn, niuo, árce,
   {{0xe9da00e9,0x6443b4bd,0x2007820f,0x673c02ce}},	// [6e00] тка_, keni, _keni_, _sprj,
   {{0x64438b5d,0xbebd0029,0x200780f1,0x7e608101}},	//   jeni, stīt, _jeni_, _snmp,
   {{0x6443db1b,0xb4b205fc,0x2cb804fe,0x629b8084}},	//   deni, टकी_, mord_, kiuo,
   {{0x7d047342,0xb17b00f2,0x2a6d84b7,0x2cb83a1a}},	//   _kwis, _igån, jjeb_, lord_,
   {{0x6443bcc9,0x9c7c82d4,0xe80106a7,0x9f4e8242}},	//   feni, _liče, _लड़का_, _jefò_,
   {{0x7d041b86,0x2007f343,0xd7f200f7,0x2cb80687}},	//   _mwis, _neni_, _ذكر_, nord_,
   {{0x2d80c1a8,0x9c7cd3f5,0xd838a5ea,0x8fa37344}},	//   šie_, _niče, niče_, _даре,
   {{0x7bc89f07,0xd257f345,0x2a7f81c0,0xddcd17ac}},	//   _vzdu, аць_, gkub_, _plaż,
   {{0x30a69ba8,0x6443f346,0x2007f347,0x506681e2}},	//   иров, beni, _beni_, атна,
   {{0x2007f348,0x9da5803d,0x213d82c4,0x2cb81eb4}},	//   _ceni_, _اصفه, _dpwh_, jord_,
   {{0x6d4f8207,0xb5fd826c,0x2007ccdc,0x7d04022b}},	//   _ácar, _košp, _deni_, _awis,
   {{0xd83881d0,0x442c8229,0x3ea6f349,0x7761002a}},	//   diče_, _hcd_, nnot_, _álxe,
   {{0x6a78007b,0xb87b00f7,0x2007e699,0x443a734a}},	//   _lífs, _suím, _feni_, _bbp_,
   {{0xb8cb80c8,0x2007b6bf,0x68ed80f7,0x443a4762}},	//   _কী_, _geni_, _éada, _cbp_,
   {{0x200cf34b,0x443a0748,0x66e8928a,0x26c204e8}},	//   madi_, _dbp_, _měkk, blko_,
   {{0x200cf34c,0x64439d4b,0x20078042,0x32641454}},	//   ladi_, zeni, _zeni_, отув,
   {{0x20078a0b,0x2cb820e5,0x1bf88105,0x7c3a81a1}},	// [6e10] _yeni_, bord_, ुराल_, _obtr,
   {{0x200cc3b3,0x6d4d734d,0x6a7cf34e,0x3eb910d1}},	//   nadi_, _isaa, _défi, lost_,
   {{0x7d040352,0x6443f34f,0x3ce9022c,0xed59811f}},	//   _zwis, veni, _huav_, _srž_,
   {{0xa2830bca,0x200cf350,0x3ce901c0,0x63bb03bf}},	//   _بیرو, hadi_, _kuav_, ğund,
   {{0x644398cc,0xe618821e,0x200cf351,0xa3d4d0cf}},	//   teni, рді_, kadi_, सेस_,
   {{0x3eb97352,0x6d4d022e,0x200c8239,0x308500f7}},	//   host_, _msaa, jadi_, _السف,
   {{0x6443f353,0x26cd8104,0x62898013,0x3eb97354}},	//   reni, _theo_, theo, kost_,
   {{0x20078a8f,0x3e7b00f1,0x3eb90668,0x3a29489b}},	//   _seni_, _këtu_, jost_, ngap_,
   {{0x629bf355,0x6e3bcb14,0x3eb92803,0x3ce90282}},	//   riuo, _ibub, dost_, _nuav_,
   {{0x14748013,0x7c2d8067,0xac748013,0x92e200ab}},	//   _والج, đars, _والش, নীয়_,
   {{0x160b853f,0x6d4d7356,0x25f409c8,0x2007dbc3}},	//   _हजार_, _asaa, ंडली_, _veni_,
   {{0x443a00ee,0x394904b9,0x9c7c817f,0x8b9a81c6}},	//   _sbp_, kwas_, _viče, _גבעת,
   {{0x200c8587,0x6609f357,0x3ce90069,0x2007ac5a}},	//   badi_, _meek, _cuav_, _teni_,
   {{0xd838803b,0xa956812a,0x6609f358,0xab2a4c1d}},	//   tiče_, _לינק_, _leek, лога_,
   {{0x8fa292e1,0xc0528039,0x9ef580f7,0x6e3b82ec}},	//   _наше, _מזג_, _استش, _obub,
   {{0x4f168159,0x3a29010b,0x2731d512,0x6609b057}},	//   _פֿון_, ggap_, mán_, _neek,
   {{0x2731f359,0x7e64735a,0x49ca0bda,0x6d5b81c5}},	// [6e20] lán_, _inip, улан_, _nrua,
   {{0xe9d71d1d,0x6e3b83c3,0x764604dc,0x81ac8264}},	//   ску_, _abub, leky, _গরম_,
   {{0x6609f35b,0x7e6463ee,0x2731f35c,0xef1a5381}},	//   _beek, _knip, nán_, уме_,
   {{0xdddb82a5,0x3ce9146a,0x62860364,0xe821835a}},	//   _sluš, _yuav_, _ulko, _माझा_,
   {{0x27318013,0x6d5b8083,0x200cd556,0x3ce9022c}},	//   hán_, _crua, yadi_, _xuav_,
   {{0x6e3b8135,0x2b4c80b9,0x76460122,0x62998545}},	//   _ebub, _psdc_, heky, _amwo,
   {{0x33178013,0x7f860013,0x200cee23,0x7e64046d}},	//   مزيد_, _الأن, vadi_, _onip,
   {{0x50f4910b,0x200cf35d,0x2731f35e,0x9695a369}},	//   озит, wadi_, dán_, _друш,
   {{0x3eb9680b,0x200cf35f,0x29121066,0x6d5bf360}},	//   vost_, tadi_, nsya_, _grua,
   {{0xdefa827e,0x7ae88019,0xb5fd8267,0x97148be2}},	//   лым_, _tudt, _inša, омоц,
   {{0x200cd1b5,0xb8ef89a3,0x2731b554,0x3ce901e9}},	//   radi_, _वी_, gán_, _suav_,
   {{0x200cb6ff,0x3ce90069,0x7c2a83ba,0xddc401a9}},	//   sadi_, _puav_, lgfr, _maiņ,
   {{0xa1338077,0xddc09e03,0x3ce90069,0x6d408176}},	//   _فروش, _lomž, _quav_, _jpma,
   {{0x657d08cf,0xc9178039,0x27318019,0x200cb891}},	//   rysh, _פחות_, bán_, qadi_,
   {{0x657d7361,0xd5ed0129,0x2731ac7d,0xd6db0163}},	//   sysh, _toà, cán_, _йти_,
   {{0x6d4d4d88,0x78ba812b,0x139b80be,0x46a404bd}},	//   _tsaa, lotv, אבלע, _најв,
   {{0x660f05f5,0x90991354,0x66098cfa,0x3a2902f7}},	// [6e30] mack, ават_, _reek, rgap_,
   {{0x660f7362,0x7ae2a043,0x297b807c,0x68ed01b4}},	//   lack, _liot, אטמא, rqad,
   {{0x200a2c5a,0x64557363,0x6d40a585,0x394901e0}},	//   _debi_, mdzi, _apma, swas_,
   {{0x46c90074,0x644706c1,0x67250748,0xddc082d4}},	//   रतिह, leji, ruhj, _domž,
   {{0xd126a219,0x2731f364,0x628d00f7,0x6489026c}},	//   _تم_, zán_, mhao, džiz,
   {{0x2731f365,0x64556b23,0x1bfb23e7,0x6609f366}},	//   yán_, ndzi, ्रिल_, _week,
   {{0x78ba856f,0xa3d4816f,0x6609d32b,0x0ec903eb}},	//   dotv, सेल_, _teek, रताड,
   {{0x2731f367,0x6d5b893a,0x539c00be,0x7ae2cf8b}},	//   ván_, _trua, טיוו, _ciot,
   {{0x3ebf8867,0xc42b8277,0x940e8201,0x6f0701c0}},	//   _ikut_, _مثال_, hifə_, _hwjc,
   {{0x2731f368,0x487988cc,0x6455009a,0x78ba825b}},	//   tán_, рсия_, jdzi, gotv,
   {{0xbebd0029,0xcdc9012a,0xe7399a1f,0xfe460c40}},	//   drīb, _סך_, шен_, онно,
   {{0x2731f369,0x9f58736a,0x660f0bcf,0x7ae29e14}},	//   rán_, _perú_, gack, _giot,
   {{0x2731f36b,0x2d84003e,0x44ef0201,0x3eadc7ad}},	//   sán_, áme_, _cü_, _mjet_,
   {{0x27318290,0x7ae2811b,0x2b410176,0x764601e0}},	//   pán_, _ziot, _bphc_, seky,
   {{0x68e3836a,0x44ef5f16,0x7ebd0866,0x63a90799}},	//   _iind, _eü_, répr, ßenp,
   {{0x68e3f36c,0x7e6415d0,0x201800dd,0x21201809}},	//   _hind, _unip, _sdri_, trih_,
   {{0x3200008e,0x68e3bbad,0x81e200ab,0x2018008e}},	// [6e40] rbiy_, _kind, নুন_, _pdri_,
   {{0x3eada719,0x28cf8c1c,0x68e3f36d,0x394f82df}},	//   _ajet_, _सीमि, _jind, _msgs_,
   {{0x68e3e3f8,0x91e630fe,0x3ce306a7,0x201881d6}},	//   _mind, _моне, _टूटे_, órii_,
   {{0x68e38d23,0x628d32ba,0x200a736e,0x6a7c810c}},	//   _lind, chao, _webi_, _yéfu,
   {{0x7ae2bfe4,0x3ead826c,0x395df36f,0x8afc8035}},	//   _riot, _djet_, _nrws_, _kręg,
   {{0x68e3f370,0x9c7cb583,0x2018011f,0x3ead8646}},	//   _nind, _biča, _udri_, _ejet_,
   {{0x44208179,0x78ba86ec,0xa2c6816f,0x7ae28035}},	//   ği_, votv, ातल्, _piot,
   {{0x68e3f371,0x1fcf80c8,0x4420f372,0x628401bb}},	//   _aind, রশাস, şi_, nkio,
   {{0xfe43835f,0xf2d304de,0x48aa86f1,0x5ca6a7ee}},	//   _інфо, ועה_, итом_, _диаб,
   {{0x66028102,0x3878032e,0x44388014,0x6a7c8036}},	//   lbok, _jorr_, _ùr_, _réfu,
   {{0x44f08104,0x7ae2f373,0x67218024,0x387830a1}},	//   _hà_, _tiot, grlj, _morr_,
   {{0x68e3905d,0x6455009a,0xd25080d5,0xa3c983b7}},	//   _eind, wdzi, _سنت_, ोधर_,
   {{0x61a58a16,0xd6d80cde,0x68e3f374,0xa3dd25ef}},	//   खपृष, ють_, _find, तेन_,
   {{0x44f0f375,0xbf148077,0x443e8042,0x68e3f376}},	//   _mà_, _فوتب, _jbt_, _gind,
   {{0x44f08142,0x64553256,0x64474672,0x629f09ca}},	//   _là_, rdzi, reji, tiqo,
   {{0x68e3f377,0x443ef378,0x672881a1,0x44ef4d8d}},	//   _zind, _lbt_, mudj, _tü_,
   {{0x44f0877f,0x629f7379,0x672880fe,0x628d737a}},	// [6e50] _nà_, riqo, ludj, rhao,
   {{0x660d02f1,0x38780219,0x628d737b,0x27e700e8}},	//   _heak, _corr_, shao, ønn_,
   {{0x660d09ca,0x67288da8,0x44f0826b,0x7d161e51}},	//   _keak, nudj, _aà_, _zvys,
   {{0x44f09b6a,0x6602f289,0x9c7c8c95,0xf7738538}},	//   _bà_, gbok, _riča, וקע_,
   {{0x3ead820f,0x63ad0029,0x44f0801c,0x7522e663}},	//   _vjet_, šinā, _cà_, groz,
   {{0xe3df0a49,0x317a0051,0x44f0f37c,0x2249011e}},	//   _ব্যব, _הרשמ, _dà_, leak_,
   {{0x8c440201,0x3ebf80dd,0x68eb8420,0x212900b9}},	//   əşdi, _tkut_, _sugd, luah_,
   {{0x44f090ab,0x6d5f0085,0x6721957c,0x2249011b}},	//   _fà_, _orqa, vrlj, neak_,
   {{0x6aa980b2,0x44f0eb50,0x273501a3,0xe520582e}},	//   rnef, _gà_, lån_, _बिधि_,
   {{0x6721812b,0x6abbf37d,0x68e38168,0x62840102}},	//   trlj, souf, _qind, zkio,
   {{0x6d5f438c,0x68e3f37e,0x7bc5737f,0x629d1eb4}},	//   _arqa, _vind, _nyhu, _omso,
   {{0x7d09b4cf,0x68e3a0dd,0xee3f016b,0x64900074}},	//   _kwes, _wind, bným_, _käig,
   {{0x2249011e,0x81a79ec9,0x660d4da0,0x44f08129}},	//   deak_, _بحال, _deak, _xà_,
   {{0x9c7ca997,0x629d6c9c,0x6721825b,0x7d09820c}},	//   _ličn, _amso, prlj, _mwes,
   {{0x3d1805fc,0x93590ef5,0x6728817f,0x39425cd7}},	//   _भटके_, орту_, cudj, _spks_,
   {{0x6486807b,0xc7b284de,0x2249011b,0x7d098c6a}},	//   _aðil, _רבה_, geak_, _owes,
   {{0xd94315b7,0x66e8801b,0x216720a9,0xa96709a0}},	// [6e60] нети, _děku, пити_, пита_,
   {{0x3ea203ab,0x44f0ce8a,0xbcfb04c3,0x13e380ab}},	//   likt_, _rà_, rxét, নুয়,
   {{0xb8f31094,0x44f084be,0x443e86cb,0x76567380}},	//   _ही_, _sà_, _rbt_, _kayy,
   {{0x21291a6e,0x44f0c823,0xe7ee0105,0xddcf9c0b}},	//   buah_, _pà_, _जलवा_, _šeše,
   {{0x38787381,0x443e80ee,0x78a1807b,0x7d098114}},	//   _torr_, _pbt_, kilv, _cwes,
   {{0x44f0dea9,0x628b8558,0x3ea20a0f,0x29005eec}},	//   _và_, _algo, hikt_, mpia_,
   {{0x44f0877f,0x3af180ff,0x5f273224,0x6602f28b}},	//   _wà_, _cáp_, _норм_, pbok,
   {{0x44f0f382,0xee3f026f,0x443e80ee,0x60f895a6}},	//   _tà_, tným_, _wbt_, ония_,
   {{0x7ae6537e,0x85068416,0x6d4401c0,0x629c8084}},	//   _mikt, _روان, _npia, _įrod,
   {{0x672302a5,0xb0be04c5,0x50be06b7,0x660d1922}},	//   šnje, ्तिग, ्तिष, _seak,
   {{0x660d0006,0x765603c3,0x66e8801b,0x3d0f016f}},	//   _peak, _bayy, _někt, तीने_,
   {{0x7ae67383,0x290002f7,0x6458f384,0x2249011b}},	//   _nikt, kpia_, ldvi, xeak_,
   {{0x6728b69f,0xf8be052a,0x765600fc,0x78a1a2c8}},	//   sudj, ्ताय, _dayy, bilv,
   {{0xb9db8051,0x64900406,0x644ab40f,0x7ae67385}},	//   _החדש, _näid, nefi, _aikt,
   {{0x083b82f6,0x2249011e,0x3edf01bc,0x7ae67386}},	//   _העול, teak_, _amụọ_, _bikt,
   {{0xe8df801c,0x212909da,0x644a8114,0x765604b9}},	//   ược_, tuah_, hefi, _gayy,
   {{0x69c6032b,0x22490102,0x260b86a7,0x2eeeebdf}},	// [6e70] _cyke, reak_, ारसी_, _huff_,
   {{0x644ade9f,0x212903ac,0x69c60106,0x200e89ab}},	//   jefi, ruah_, _dyke, _jefi_,
   {{0x21290ad4,0x3f871c4b,0x6d5d183d,0xa5bb0118}},	//   suah_, ánu_, lvsa, rgóu,
   {{0x273500f2,0x629d24e8,0x3f8f009a,0x39520198}},	//   rån_, _umso, ągu_, änsä_,
   {{0x3f870052,0x9c7c80c3,0x3af18129,0x64577387}},	//   šnu_, _vičn, _sáp_, _kaxi,
   {{0xd7e68013,0xfd6201bc,0x644af388,0x2eee8118}},	//   _لك_, _akwọ, gefi, _ouff_,
   {{0xe2998084,0x6a7c8036,0x93bc8493,0xe738062c}},	//   жай_, _réfr, _scăr, _неё_,
   {{0xe8f983c5,0x6aad7389,0x94110085,0x7d09820c}},	//   оли_, nnaf, rizə_, _twes,
   {{0x81b100c8,0x44330358,0x765600b9,0xd12e80f7}},	//   য়ের_, _ocx_, _rayy, لمي_,
   {{0x76561f76,0x7659c9fd,0x644af38a,0x9f5a0216}},	//   _sayy, ldwy, cefi, capó_,
   {{0x7e7bf38b,0x6d440098,0x200e8242,0x7e6992f1}},	//   _koup, _spia, _defi_, _knep,
   {{0x29000358,0x76560359,0xaf9897ae,0xe5a6563d}},	//   ypia_, _qayy, ятых_, дими,
   {{0x7ae6738c,0xdb1e016b,0x3ea22e28,0x61ebe82c}},	//   _rikt, _vypí, rikt_, _iggl,
   {{0xd9429928,0x2bda8c28,0x7ae6738d,0x765600fc}},	//   _реши, येवा, _sikt, _wayy,
   {{0xfce3738e,0x64570201,0xa3d8009a,0x6441b1b7}},	//   торо, _daxi, ़ें_, _mbli,
   {{0x764b8019,0x6458816b,0xfa671a51,0x644af38f}},	//   jegy, zdvi, маск_, zefi,
   {{0x7ae6088b,0x3ea00118,0x68e700f3,0x7659831d}},	// [6e80] _vikt, _imit_, _bijd, ddwy,
   {{0xf42500c8,0xeb0d8105,0xc5f40326,0x7ae63228}},	//   ম্বর_, _सबूत_, _daɓe_, _wikt,
   {{0xd70a10ac,0x7ae67390,0xbcfb0019,0x78be1699}},	//   інде_, _tikt, tvég, ropv,
   {{0x29001194,0x6441f391,0x7e7ba527,0xb87b0187}},	//   ppia_, _abli, _coup, _suít,
   {{0x6aa4004f,0x649002f1,0x64418362,0x644a8425}},	//   miif, _täid, _bbli, tefi,
   {{0x7414845b,0x44f40009,0xe1ff85e4,0x6fd6073c}},	//   روبا, _mä_, ñón_, _भरपू,
   {{0x17790364,0x3ea017fe,0x6b83831d,0x200ed06d}},	//   _есть_, _omit_, gyng, _refi_,
   {{0xf1bf00f7,0x68e701ed,0x5a348081,0x2eee8901}},	//   _gcás_, _zijd, хнит, _ruff_,
   {{0x79844349,0xb87b002a,0x44f41a57,0x248c80ee}},	//   nyiw, _guís, _nä_, _tldm_,
   {{0x3ea00065,0x9c7c8289,0x7d02960c,0x7e7b8118}},	//   _amit_, _kičm, mpos, _zoup,
   {{0x7d0299e0,0x3ce78d86,0x98a9009a,0x9346804a}},	//   lpos, _छूटे_, stać_, _інде,
   {{0xc5f90074,0xbd6b08b0,0x645701b4,0x2ca301ed}},	//   ंडेय_, орге_, _saxi, wijd_,
   {{0x2ca30613,0x7d02f392,0x200581cd,0x44331b1d}},	//   tijd_, npos, bbli_, _pcx_,
   {{0x44f45a63,0x7d028b80,0x2eee8106,0xd7ef8a3d}},	//   _dä_, ipos, _tuff_, _ју_,
   {{0x68e70a0f,0x2ca300f3,0x6457002a,0x7d02808e}},	//   _rijd, rijd_, _vaxi, hpos,
   {{0x2738cd67,0xbcfb0019,0x645701b4,0x320f0061}},	//   mén_, tvéd, _waxi, úgy_,
   {{0x7d02f393,0x7e7b9d16,0x6aad19f3,0x5ea400f7}},	// [6e90] jpos, _roup, rnaf, _جميل,
   {{0x6fa0000f,0xd01112dc,0x7e7ba84b,0xd7f8802e}},	//   _गेहू, الا_, _soup, ncă_,
   {{0x7e7bf394,0x764ba015,0x2738be3d,0x2fc7006a}},	//   _poup, tegy, nén_, æng_,
   {{0x7d0d2480,0x29190858,0x35b5831a,0x44310118}},	//   _kwas, _tvsa_, нбер, lgz_,
   {{0x68e70613,0x7d0295d0,0x8498003d,0x7996009a}},	//   _tijd, gpos, _رئیس_, czyw,
   {{0x64900006,0x7d0d0fb7,0x2738804e,0x752b890d}},	//   _täie, _mwas, kén_, rugz,
   {{0x4fc4176e,0x7e7b86c0,0x27388019,0xce958098}},	//   _аста, _toup, jén_, _завъ,
   {{0xd24e80f7,0xe3b09f33,0x20111fe7,0x2738881b}},	//   منى_, جره_, _hezi_, dén_,
   {{0x2011026c,0x9f4a0032,0x63538085,0xbebd0ec3}},	//   _kezi_, _agbè_, _mənə, trīn,
   {{0x20110247,0x3ea01e12,0x6441972b,0x81b10264}},	//   _jezi_, _smit_, _ubli, _ওরা_,
   {{0x394684df,0x20117395,0x3dc91066,0x7d0d3bf8}},	//   _epos_, _mezi_, _ayaw_, _awas,
   {{0x28cf800f,0xb4d8000f,0xdd1e0087,0x2011005d}},	//   _सीरि, िष्_, _câşt, _lezi_,
   {{0x20c28125,0x5fd1901e,0x3eaf81a8,0x224d8cdb}},	//   rðir_, _हरवल, ingt_, meek_,
   {{0x27388333,0x7afe0748,0x224d8102,0x20113426}},	//   bén_, _ptpt, leek_, _nezi_,
   {{0x2738957a,0xcb6727f4,0x7d02f396,0x21391a91}},	//   cén_, наре_, zpos, _aqsh_,
   {{0x7d02a71d,0x9f5e84e8,0x44f47397,0xa3d786a7}},	//   ypos, natý_, _tä_, _सरन_,
   {{0x95560013,0x7d0d0355,0x26c20c03,0x764400b4}},	// [6ea0] _أخبا, _gwas, moko_, _ibiy,
   {{0x1fb66013,0x6d56451b,0x26c25e82,0x628f0661}},	//   нсер, _isya, loko_, _elco,
   {{0x4444146a,0x03a60729,0x7d1bf398,0xbcfb0036}},	//   _ib_, _чино, _avus, rvée,
   {{0x44441cdf,0x7d02803a,0x60c18502,0x81e200c8}},	//   _hb_, tpos, holm, নুষ_,
   {{0x64a6a5a4,0xe89b0059,0x27388c83,0xdca68294}},	//   нада, _çağı, zén_, нади,
   {{0x67230025,0xa8028201,0x98a48029,0x26c27399}},	//   šnja, _çıxa, kumā_, hoko_,
   {{0x26c2739a,0x98a48029,0x7d02c0eb,0x44440c6b}},	//   koko_, jumā_, spos, _mb_,
   {{0x644e739b,0x65640cf4,0x66e38a2e,0x26c2739c}},	//   hebi, _orih, _боса, joko_,
   {{0x4444739d,0x26c24d38,0x644e739e,0xc05ab941}},	//   _ob_, doko_, kebi, пін_,
   {{0x273893af,0x644e0c70,0x764432e1,0x8b96917e}},	//   tén_, jebi, _abiy, _преч,
   {{0x6d563f37,0x56954c2f,0xd7f88087,0x9c7c8669}},	//   _asya, вант, rcă_, _ličk,
   {{0x4444739f,0x2738aff3,0x645af3a0,0xd7f8802e}},	//   _ab_, rén_, _hati, scă_,
   {{0x645aa11f,0x83fc8267,0x225181d0,0x22593f51}},	//   _kati, _anđi, ánků_, _rask_,
   {{0x60c1a3a5,0x9f58f3a1,0x645ada84,0x63538201}},	//   colm, úró_, _jati, _sənə,
   {{0xaa671908,0x645a9b8e,0x5b241a73,0xb86589a7}},	//   нтак, _mati, льта, _جانو,
   {{0x645ab59f,0x65641c6d,0xd25829ba,0x7d0d73a2}},	//   _lati, _frih, нцу_, _twas,
   {{0x7e6d73a3,0xdc3c826c,0x2b52809a,0x7ebd0061}},	// [6eb0] _inap, _ašči, łych_, képz,
   {{0x645af3a4,0xd91b810f,0x644e73a5,0x655601c6}},	//   _nati, פובל, cebi, _סבתא_,
   {{0x201173a6,0x7e6d03a6,0x4ab28076,0xceeb026a}},	//   _vezi_, _knap, ुकाव, سران_,
   {{0x9f5873a7,0x765d006a,0x531a00be,0x9f5ebdf7}},	//   _però_, ndsy, _קורצ, lató_,
   {{0x320930e5,0xddc40087,0xdfc688f9,0x760c00be}},	//   mbay_, _iniţ, _چي_, פּאַ,
   {{0x645af3a8,0x7d1c8029,0x224d9ae1,0x212973a9}},	//   _cati, _ārst, week_, mrah_,
   {{0x26c2227d,0x60c1f3aa,0x224df3ab,0xdfd401e5}},	//   yoko_, volm, teek_, _боры,
   {{0x9f5e8019,0x7d1b826c,0x752480ce,0x644e73ac}},	//   ható_, _tvus, šiza, zebi,
   {{0x6e94ac87,0xb3eb8f24,0x224dd4e9,0x644e0214}},	//   _ситу, _فعال_, reek_, yebi,
   {{0x7e6d73ad,0x224d82d6,0x212909ca,0x4421012b}},	//   _anap, seek_, irah_, _ndh_,
   {{0x60c1c139,0x644e04e6,0x3209009c,0xb4cd904f}},	//   rolm, vebi, kbay_, रती_,
   {{0x656473ae,0x645af3af,0x64455820,0x2129293f}},	//   _prih, _zati, _abhi, krah_,
   {{0x50b5932a,0xe1f08829,0x26c216d8,0x21290455}},	//   _иску, _اسم_, roko_, jrah_,
   {{0x61fd73b0,0x44443ece,0x64948782,0x9c7c826c}},	//   _afsl, _qb_, _gàid, _ričk,
   {{0xaac61baf,0x645c2315,0x26c2013e,0x7aeb8122}},	//   نترن, rdri, poko_, _kigt,
   {{0x444401c5,0x7afc8065,0x2ca7b429,0x644e73b1}},	//   _wb_, _érte, hind_, sebi,
   {{0x61fb8272,0x2ca7949d,0x212909e1,0xc5f400fc}},	// [6ec0] icul, kind_, grah_, _gaɓa_,
   {{0x444473b2,0xe9d70c0e,0x395201b0,0x7aebf3b3}},	//   _ub_, тку_, rwys_, _ligt,
   {{0xe29a2702,0x645aa8eb,0xee3ac5c8,0x6d498118}},	//   _жан_, _rati, дне_, _apea,
   {{0x26c3003a,0x9bb70039,0x68ed0110,0x787e801b}},	//   čkog_, _יהיה_, _žodž, _závě,
   {{0x645aa67c,0x3ea6f3b4,0xa2bf1a4d,0x2ba7a64d}},	//   _pati, riot_, वकर्, _केबा,
   {{0x9f58008b,0x031606a7,0x9c7c81a1,0x53d601a2}},	//   _ferð_, _तबाह_, _kiči, _धराश,
   {{0x645af3b5,0x18a301e5,0x07a620e2,0x7aebbe34}},	//   _vati, _тарм, _равн, _bigt,
   {{0x69cb81b0,0x6728876c,0xcb130039,0x645aecad}},	//   _byge, vrdj, בלה_, _wati,
   {{0x645ac4f7,0x273c1867,0x7aebf3b6,0x2ca79407}},	//   _tati, lín_, _digt, bind_,
   {{0x2bbb8105,0x2ca7e20a,0xc5f40326,0xdb1e062c}},	//   _ऊँचा, cind_, _raɓa_, _kypä,
   {{0x273c03b3,0x320917ea,0x212900b9,0x9c7ca9b4}},	//   nín_, ybay_, zrah_, _niči,
   {{0x442173b7,0xb283c03d,0x290201a1,0x6f1ac7ea}},	//   _sdh_, _вышк, _otka_, rstc,
   {{0xa2d30074,0x3857826a,0x9f5e8019,0x7e6d02d4}},	//   _भीष्, رشید_, tató_, _vnap,
   {{0x3af8f3b8,0x273c0333,0x9c7c8084,0x98a383a7}},	//   _kép_, kín_, _biči, _киче,
   {{0xa3dd0321,0x9f5e8722,0x273c00e1,0x64450144}},	//   तें_, rató_, jín_, _vbhi,
   {{0x31668025,0x2129199c,0x273c01ac,0x9c7c817f}},	//   _kroz_, trah_, dín_, _diči,
   {{0x2246803d,0x2ab701b9,0xb5fb0118,0x9f5e8216}},	// [6ed0] _mbok_, għba_, rdád, pató_,
   {{0x66df1482,0x44210072,0x7d1b1fd3,0x765b84b9}},	//   _tūks, _udh_, áusu, _sauy,
   {{0x2ca7f3b9,0xb8fa235e,0x2129059e,0xdb1e80e7}},	//   vind_, _डी_, srah_, _évèn,
   {{0x6723003a,0x2ca78a15,0x21292acb,0x9f58007b}},	//   šnjo, wind_, prah_, _verð_,
   {{0x7aebf3ba,0x454580f7,0x2ca7b96b,0x961d81a9}},	//   _rigt, انتق, tind_, _noņe,
   {{0xb4cd89a3,0x6acb8f97,0x273c501c,0x7aeb868b}},	//   रते_, ात्र, bín_, _sigt,
   {{0x44299014,0x2ca7de39,0x447c0158,0x69cb806a}},	//   ğa_, rind_, ונגע, _syge,
   {{0x4429880a,0x3166812b,0x2ca7f3bb,0x649007b8}},	//   şa_, _broz_, sind_, _näin,
   {{0x7aeb8022,0x83fc8088,0x101584cf,0x2d99804a}},	//   _vigt, _anđu, льня, _åse_,
   {{0xd7098009,0x69cb84e8,0x20558185,0x44f9810c}},	//   нное_, _vyge, утир, _iè_,
   {{0x7c3800f2,0x44f9801c,0x9eaa15fe,0x16aa09a0}},	//   _övri, _hè_, евна_, евни_,
   {{0x44f9c080,0xb8038ebf,0x69cbe5de,0x00000000}},	//   _kè_, _श्रम_, _tyge, --,
   {{0x273c03b0,0x25e68035,0xa3e6064a,0x5e5683de}},	//   zín_, जेपी_, बेन_, נישע_,
   {{0x6aa994f9,0x44f9c38b,0x2eed8e61,0x6cd600f7}},	//   lief, _mè_, _lief_, اقسا,
   {{0x44f986fe,0xeb9a1194,0x60c5008e,0x273c23b9}},	//   _lè_, хив_, dohm, xín_,
   {{0x225f9e92,0x273c00e1,0x628d04a7,0xfaa325f5}},	//   nduk_, vín_, gkao, басо,
   {{0x41271aeb,0xe0da235b,0x7989822e,0x213f8057}},	// [6ee0] лото_, ева_, nyew, ntuh_,
   {{0x273c08a9,0x459b02f6,0x7d04018e,0x6aa9d820}},	//   tín_, _נסיע, _itis, hief,
   {{0xe4570158,0x645e0420,0x3dcd8326,0xfaa60dfd}},	//   _גייט_, _iapi, _ayew_, _бано,
   {{0x44f9c833,0x273c6dda,0x645e73bc,0x225ff3bd}},	//   _bè_, rín_, _hapi, jduk_,
   {{0x63b60029,0x76428239,0x225f80b9,0xd838816b}},	//   šanā, rfoy, dduk_, siči_,
   {{0x6adce4dc,0x44f9c096,0x10a60652,0x645e00f1}},	//   मग्र, _dè_, _сигн, _japi,
   {{0x645e73be,0x394073bf,0x201a02c4,0x439481e2}},	//   _mapi, ltis_, mapi_, райс,
   {{0x44f98f23,0x7d0400d2,0x201a3097,0x6e242c1d}},	//   _fè_, _otis, lapi_, _ndib,
   {{0x394073c0,0xc61086b7,0x225d84b7,0xcc369f54}},	//   ntis_, ारीय_, _dawk_, _مراع,
   {{0x645e6797,0x31570051,0x6e240102,0x39570039}},	//   _napi, ניין_, _adib, נשים_,
   {{0x7d0473c1,0xb866803d,0x394002f1,0xc6000264}},	//   _atis, ناگو, htis_, ্ণনা_,
   {{0x39402ad0,0x41b40072,0x645e393c,0x68ee10ba}},	//   ktis_, ंपास, _aapi, _libd,
   {{0x201a0500,0xb5fd886f,0xeda700ca,0x443a0036}},	//   kapi_, _inšt, ушно, _bcp_,
   {{0x645e33b0,0x6e240085,0x313784de,0x66d61e18}},	//   _capi, _edib, _ערוך_, ráka,
   {{0x201a0867,0x645e033e,0x7d04006f,0xf53f01a3}},	//   dapi_, _dapi, _etis, stå_,
   {{0x68ed80f7,0x9258181f,0x67008135,0x443a07b6}},	//   _éadr, ласт_, _ịkwa, _ecp_,
   {{0xf8070e49,0x6448816b,0x39400084,0x497502cb}},	// [6ef0] гчен, _obdi, gtis_, шлас,
   {{0xddc40025,0x44f98324,0x201a1e0a,0x645e5e75}},	//   _uniš, _rè_, gapi_, _gapi,
   {{0x44f9c396,0x501b8039,0x23fa0039,0x68ee020d}},	//   _sè_, גובו, _בהתא, _dibd,
   {{0x645e7232,0x44f9f3c2,0x6448b212,0xd838b7bc}},	//   _zapi, _pè_, _abdi, miču_,
   {{0xa3a915a7,0xbcfb0019,0xfd1f3ff8,0xed599bf5}},	//   _खेत_, zvén, nsì_, тол_,
   {{0x29090009,0x201a1eea,0x63858198,0x1abd00ab}},	//   mpaa_, capi_, игла, _আওয়া,
   {{0x44f986fe,0x6aa98e19,0x3f870074,0xe8d60039}},	//   _wè_, tief, änud_, _כושר_,
   {{0x44f9c396,0xca8580e5,0xa92594b7,0x31258037}},	//   _tè_, ргий, адил, адиг,
   {{0x81a880c8,0x66160125,0x6aa9ab11,0x2b4c80ee}},	//   _খুব_, _reyk, rief, _epdc_,
   {{0xe8e00028,0xa3b573c3,0x69cf28bd,0x656982c4}},	//   _địa_, जपा_, _myce, _ireh,
   {{0x7d0473c4,0x6d4d73c5,0x32559d1f,0xe73984ae}},	//   _stis, _apaa, _ввер, њем_,
   {{0x645e73c6,0x6b7a8158,0xbcfb0019,0xd5e60294}},	//   _sapi, _ברענ, rvén, ижни,
   {{0x2d9d8578,0x15ba01e5,0x7649804f,0xc8b48fd3}},	//   nzwe_, тыны_, _mbey, _گلوک,
   {{0xafe58009,0xab2a4bef,0x2aba81a9,0xc5f400fc}},	//   _колл, кога_, mība_, _taɓo_,
   {{0x63834094,0xc7a2a2e9,0x7649f3c7,0x201a05f3}},	//   огра, _мишк, _obey, vapi_,
   {{0x394073c8,0x4425b23e,0x645e0010,0x602800eb}},	//   ttis_, _ldl_, _wapi, zīmē,
   {{0x201a14ff,0x7d04025b,0x2aba80eb,0x7aef5f5f}},	// [6f00] tapi_, _utis, nība_, _dict,
   {{0x394073c9,0x6e3b802a,0x60260ba7,0xed4f003d}},	//   rtis_, _acub, рджа, _کپی_,
   {{0x394073ca,0x547b0039,0x324617c8,0x41d50816}},	//   stis_, _סטטו, _кенг, _दरअस,
   {{0x201a17a0,0xdfcf00f7,0x39400662,0x0566a0a9}},	//   sapi_, ذين_, ptis_, ивен,
   {{0x68ee04b7,0x83fc81a1,0x7ae440e1,0x09e40264}},	//   _tibd, _lađe, mmit, _ফ্রা,
   {{0x656981ec,0x7ae4288c,0xc7b8812b,0x2aba81a9}},	//   _dreh, lmit, lađe_, dība_,
   {{0x83fc8067,0x20183146,0x2348826a,0x66dd0019}},	//   _nađe, _ieri_, استی_, léke,
   {{0xe8df8104,0x7ae473cb,0x6490037b,0xc7b88289}},	//   ước_, nmit, _säil, nađe_,
   {{0x65698836,0x7ae467fd,0x5ecc8264,0x3afc0a05}},	//   _greh, imit, িষদে, _líp_,
   {{0x2018130c,0x2ba785fc,0x7ae473cc,0x7e6099b0}},	//   _jeri_, _केवा, hmit, _hamp,
   {{0xb8fd8d38,0x501b0051,0x20185d0e,0x6d4d03b2}},	//   _थी_, כויו, _meri_, _spaa,
   {{0x2d8b009a,0x212003f8,0x44380114,0x614681e2}},	//   tyce_, ksih_, egr_, _веда,
   {{0x7e608812,0x2aba80eb,0xa3e2a296,0x3a2680b9}},	//   _mamp, cība_, नेर_, _idop_,
   {{0x442d02af,0xd8388024,0x634a8201,0x20184dd9}},	//   ße_, tiču_, _gənc, _neri_,
   {{0x0b88239f,0x938815d2,0x7aef4d83,0x83fc8699}},	//   асти_, аста_, _pict, _gađe,
   {{0x7e60f3cd,0x7ae40bb1,0xbea40992,0xd838817f}},	//   _namp, gmit, _мајк, riču_,
   {{0x661d73ce,0x20186004,0x51f801bb,0x3ea9120e}},	// [6f10] mask, _beri_, рную_, _imat_,
   {{0xdb1a80e7,0x6d42cbe9,0x7af70216,0x7e6082d5}},	//   _exté, dtoa, _tuxt, _aamp,
   {{0x20182c3d,0xd7f801a1,0x7ce0016d,0x6d5b80dd}},	//   _deri_, руу_, förf, _ssua,
   {{0xd2469301,0x44fd4833,0x65698ed6,0x645573cf}},	//   _عن_, _kì_, _preh, lezi,
   {{0x7e60f3d0,0x442594ed,0x20183734,0x44fd73d1}},	//   _damp, _pdl_, _feri_, _jì_,
   {{0x44fd1b5b,0x645558fc,0x20185d13,0x661d485b}},	//   _mì_, nezi, _geri_, hask,
   {{0x44fd73d2,0xd7950013,0x1fe500c8,0x7e609670}},	//   _lì_, _الأخ, _প্রস, _famp,
   {{0x163493cd,0x6d5b81e9,0x7e6088b3,0x83fc81dd}},	//   _меся, _tsua, _gamp, _rađe,
   {{0x83fc80fe,0x44fd10ab,0x1c0b8770,0x20180059}},	//   _sađe, _nì_, _स्थल_, _yeri_,
   {{0x200139ab,0xdce40b5d,0x3ea93932,0xf1b982a5}},	//   nchi_, _prič, _amat_, jaše_,
   {{0xb4e392c7,0xd3a79ef7,0xaec61ef7,0xf1b9817f}},	//   नगी_, _трап, йбол, daše_,
   {{0x1d0a2be1,0x661d1d0c,0x7e60efaf,0x83fc812b}},	//   леми_, gask, _xamp, _vađe,
   {{0x24858074,0x645573d3,0x41299810,0xddcb8035}},	//   _kolm_, fezi, _соло_, legł,
   {{0x44fd73d4,0xdce4026f,0x645573d5,0xfc036aac}},	//   _dì_, _trič, gezi, зпро,
   {{0x66e64e7a,0x634a8085,0xeb970568,0x7ae473d6}},	//   _лока, _kəna, бир_, tmit,
   {{0x66dd0065,0x2018435e,0x2723817b,0xed5a200d}},	//   téke, _seri_, mın_, _бои_,
   {{0x7e60c58d,0x44fd0104,0xe9da05c2,0x27238182}},	// [6f20] _ramp, _gì_, ука_, lın_,
   {{0x21200867,0xc6108ebf,0x81bc00c8,0x7e60b5b2}},	//   rsih_, ार्य_, েইল_, _samp,
   {{0x2723f3d7,0x201873d8,0x2a7f89ca,0x98a00267}},	//   nın_, _veri_, kjub_, hrić_,
   {{0xc3330051,0x98a002ee,0xb87b01df,0x26df8010}},	//   _צור_, krić_, _xuíz, _chuo_,
   {{0xf767850c,0x7bda8063,0x201848dc,0x9878b6b7}},	//   _کا_, _sztu, _teri_, _ušću_,
   {{0xb8960013,0x40960013,0x20010098,0x272393da}},	//   _السع, _السر, cchi_, kın_,
   {{0x628632c7,0xa3e0023c,0xa3e29370,0x6d42f3d9}},	//   _koko, _तरफ_, नें_, stoa,
   {{0x2723884a,0x645573da,0x628673db,0xe643a0e4}},	//   dın_, zezi, _joko, _несп,
   {{0xd01080f7,0x661d2e2b,0x62860048,0x645532f5}},	//   ولة_, vask, _moko, yezi,
   {{0x62863f13,0x660473dc,0x44fd04be,0xb87b01df}},	//   _loko, _afik, _rì_, _suíz,
   {{0x44fd077f,0x661d73dd,0x66d8826f,0x443eb23e}},	//   _sì_, task, níko, _ict_,
   {{0x64551b77,0x6602f3de,0x7d160114,0x7ce01b57}},	//   wezi, ncok, _bwys, hörd,
   {{0x645536b9,0xf1b9812b,0xf1bf3132,0x60c8adad}},	//   tezi, taše_, _adán_, podm,
   {{0x6723003b,0x44fd0104,0x66040b67,0xc0aa819f}},	//   šnji, _vì_, _efik, _حاصل_,
   {{0x201ef3df,0x645573e0,0x628673e1,0x7afa90a6}},	//   mati_, rezi, _boko, _jutt,
   {{0x201e97f7,0x3ea914ec,0x44fd04be,0x7afac0e1}},	//   lati_, _umat_, _tì_, _mutt,
   {{0x645509e8,0x7afaf3e2,0x443ef3e3,0x7ce03cac}},	// [6f30] pezi, _lutt, _oct_, förd,
   {{0x798d61e1,0x26cb73e4,0x656d6497,0x81e580ab}},	//   ryaw, loco_, _irah, বুক_,
   {{0x23a79094,0x20010098,0x7afa9333,0x798d07cf}},	//   _केंद, rchi_, _nutt, syaw,
   {{0x3eb94b68,0x200173e5,0x656d00f1,0xf770003f}},	//   nnst_, schi_, _krah, عال_,
   {{0x201ef3e6,0x272382bb,0x2a3a0158,0x823a0158}},	//   kati_, zın_, _דערמ, _דערצ,
   {{0x272382bb,0xa3bd035a,0x98a00289,0x7afaa52a}},	//   yın_, _अशा_, vrić_, _butt,
   {{0xeb999cf9,0xddc9826f,0x27238085,0x6286355b}},	//   рий_, _dneš, xın_, _yoko,
   {{0xcfce80c8,0x7afaf3e7,0x656d0668,0x386373e8}},	//   রধান, _dutt, _orah, _hajr_,
   {{0x443e8118,0xaca3019d,0xe8f6a252,0x6e298133}},	//   _fct_, _alọg, олы_, _ideb,
   {{0x201ef3e9,0x3eafa566,0x7d048029,0x272382bb}},	//   gati_, ligt_, ģist, tın_,
   {{0xa3a90d38,0x656d73ea,0x661b8a0f,0x752473eb}},	//   _खेल_, _arah, _keuk, _sviz,
   {{0x27238a0b,0x656d5400,0x7d16031d,0x25f08d86}},	//   rın_, _brah, _pwys, ुँची_,
   {{0x62860038,0xdce0802e,0x2723817b,0x7ce001ec}},	//   _roko, _urmă, sın_, höre,
   {{0x201eb45a,0x62864201,0x656d1ac0,0x272383bf}},	//   cati_, _soko, _drah, pın_,
   {{0x6286085d,0xe51985e8,0x6e298cf0,0xaca380ff}},	//   _poko, नीति_, _odeb, _huỳn,
   {{0x83fc803b,0xb5fb73ec,0x6e29de67,0x661bf3ed}},	//   _mađa, ndál, _ndeb, _neuk,
   {{0x3eaf9b59,0xed5a1e72,0x614312a0,0xd94312e1}},	// [6f40] digt_, _топ_, мета, мети,
   {{0x6e29f3ee,0x7ce0016d,0x7e6473ef,0xc7b8811f}},	//   _adeb, före, _haip, lađa_,
   {{0x628673f0,0x3169026c,0x7e640d55,0x661b9412}},	//   _toko, avaz_, _kaip, _beuk,
   {{0x823607d2,0x7afaf3f1,0x7bde329a,0xddc981a1}},	//   _بردا, _rutt, _izpu, _sneš,
   {{0x7e64043b,0xa3e60f12,0x661bf3f2,0x634a811c}},	//   _maip, बेर_, _deuk, _cənn,
   {{0x6e29ee19,0x6d46036e,0x7e6473f3,0xc7b880d2}},	//   _edeb, itka, _laip, hađa_,
   {{0x7d09f0b6,0x46ca09c2,0x6d46554f,0xddc99502}},	//   _etes, रवाह, htka, _vneš,
   {{0x09de1880,0x201eb745,0x3a2073f4,0x7e6439a0}},	//   _मराठ, wati_, naip_, _naip,
   {{0x443e86e7,0x6d4401c0,0x26cb0037,0x6d465db2}},	//   _tct_, _nqia, voco_, jtka,
   {{0x7afad731,0xb4c403bb,0xdb1e02be,0x7e76477a}},	//   _tutt, एको_, _expé, _anyp,
   {{0xd7d0035a,0x83fc8289,0xdc3c8858,0x7afa8009}},	//   _तुमच, _gađa, _ašći, _uutt,
   {{0x656d09e6,0xc7b88a20,0xb5fd82a5,0x56941ff8}},	//   _prah, gađa_, _kaša, дают,
   {{0x201e8b50,0xb5fd82a5,0xfaf880eb,0x6fcaf3f5}},	//   pati_, _jaša, _trīs_, _सुरू,
   {{0xcce70307,0x6458f3f6,0xb5fd8267,0x290002f7}},	//   تسجي, nevi, _maša, dqia_,
   {{0x6d460867,0xf1b98699,0xc7b88042,0x7ae281bf}},	//   atka, maša_, bađa_, _khot,
   {{0x656d3adb,0x201c8b80,0x764d73f7,0x3eaf8338}},	//   _trah, _hevi_, _ubay, xigt_,
   {{0xb5fd8067,0x7ae28c41,0x64588a41,0x656d1af0}},	// [6f50] _naša, _mhot, kevi, _urah,
   {{0x6458adcf,0x7ce00884,0xf1b98796,0x80782274}},	//   jevi, töre, naša_, обус_,
   {{0x7d09f3f8,0x3eaff3f9,0x65608362,0x2bd20072}},	//   _stes, tigt_, _asmh, _दुपा,
   {{0x6e3d3ede,0x201c9a54,0x83fc812b,0xb5fd8bcf}},	//   ngsb, _levi_, _rađa, _baša,
   {{0x3eafb842,0x260a800f,0x41e7222c,0x3d0f016f}},	//   rigt_, ाड़ी_, _фіна, तीचे_,
   {{0x64589699,0x3eaf94a2,0xf1b980ce,0x7ae2f3fa}},	//   gevi, sigt_, jaša_, _ahot,
   {{0x661b91ee,0x68fd0bbd,0xfd64882e,0x7ae28219}},	//   _teuk, _husd, _karị, _bhot,
   {{0x7ae2d4d9,0x201c8267,0x3bbc0039,0x644a80e5}},	//   _chot, _aevi_, ימוד, affi,
   {{0xdb0a003e,0x7d098186,0x6458a86c,0xf2d400be}},	//   čnéh, _utes, bevi, ועק_,
   {{0xd24e80d5,0x48798009,0x6458d7b1,0xf1b98390}},	//   پنی_, ссия_, cevi, gaša_,
   {{0x201cf3fb,0x7e6473fc,0x4abd1130,0x7ae2f3fd}},	//   _devi_, _paip, ्काव, _fhot,
   {{0x7ae2ba7a,0x98ad8353,0x2bc49344,0xed5a2d49}},	//   _ghot, mreč_, _लुटा, бом_,
   {{0xdd920154,0xf1b9817f,0x239081a9,0x6d4659f4}},	//   روس_, baša_, _vējš_, utka,
   {{0x8fa58c0e,0x3ebf812b,0x66dd003d,0x7ae2816b}},	//   _нале, _ljut_, réka, _zhot,
   {{0x68fd02af,0x67029995,0x3a200110,0x7e6473fe}},	//   _ausd, _रूपक_, taip_, _taip,
   {{0xe61f00e1,0x68f500eb,0x80d40035,0x7afebdb4}},	//   skôr_, _aizd, _बीजे, ípti,
   {{0x68f5080a,0x64588201,0xdeb70039,0x66160267}},	// [6f60] _bizd, yevi, _מפקח_, čakč,
   {{0xd12f05ff,0x3eadf3ff,0x3ebfea0c,0x7ae9d0d2}},	//   امل_, _amet_, _ajut_, hmet,
   {{0x68f50508,0x7ae9ded5,0xd4c504a3,0xabfb025f}},	//   _dizd, kmet, _تغيي, _להיר,
   {{0xde03a6c5,0xb5fd8df1,0x7ae9f400,0xdfcf15a9}},	//   епци, _paša, jmet, ديم_,
   {{0x7ae9c3d5,0x68fd02f7,0x244f8214,0x20079a61}},	//   dmet, _gusd, kımı_, _ofni_,
   {{0x64a3a8f9,0x7afe020f,0xb4d68576,0xb5fd876c}},	//   нача, _kupt, सते_, _vaša,
   {{0x7ae2d48a,0x289b010f,0x2f01f401,0x201c8242}},	//   _phot, _פילא, _nóg_, _revi_,
   {{0x6458f402,0x201cf403,0x2007808e,0x7ae9f404}},	//   sevi, _sevi_, _afni_, gmet,
   {{0x81ce00c8,0x7afe002e,0x3ea7874c,0x224200b9}},	//   ষের_, _lupt, ënte_, _mckk_,
   {{0x26c3003a,0x2bd204e5,0x67220029,0x2db780be}},	//   čkom_, _दुभा, ņoju, _זלמן_,
   {{0x7ae2820f,0x7afe219b,0x442ccf60,0x16350cb1}},	//   _thot, _nupt, _idd_, меня,
   {{0x20078125,0x7ae985b0,0x3f82811f,0x78ba8267}},	//   _efni_, cmet, ćku_, sntv,
   {{0x201ce663,0x3ea40168,0x6d5d01ed,0x442c8144}},	//   _tevi_, ëjta_, uwsa, _kdd_,
   {{0xe7be2263,0x26d202ec,0x3ae180e1,0x68fd7405}},	//   ्थाप, _ekyo_, rópe_, _rusd,
   {{0x67d39af1,0x442c84b9,0x7afe0087,0x66d8807b}},	//   _пошу, _mdd_, _cupt, ríkj,
   {{0x628687b8,0x68f5061c,0xd7bb81c6,0x62840168}},	//   ökoh, _sizd, _לצור, gjio,
   {{0xdce98353,0x51871fc7,0x83fc80d2,0x68f564e7}},	// [6f70] _sreč, чува, _nađo, _pizd,
   {{0xdce98709,0x7d0d61fa,0x3eadd5d8,0xb4d68072}},	//   _preč, _itas, _smet_, सतो_,
   {{0x6490025d,0x44231a93,0x59f90364,0xf0938158}},	//   _päiv, maj_, _меня_, ענע_,
   {{0x442c8051,0x940c8201,0xe7300250,0xdce9807a}},	//   _add_, _ildə_, اصل_, _vreč,
   {{0x394681c0,0x290b0019,0xb5fd8115,0x629d00e5}},	//   _nqos_, _utca_, _fašn, _ilso,
   {{0x44230cb2,0x2a690006,0xdce98110,0x39492788}},	//   naj_, ldab_, _treč, mtas_,
   {{0x26c3003a,0x39497406,0x6e2d003a,0x644183ac}},	//   čkoj_, ltas_, _odab, _vcli,
   {{0x442310af,0x442c9503,0x2a690006,0x7d0d05ee}},	//   haj_, _edd_, ndab_, _otas,
   {{0x44237407,0x39497408,0x7ae9f409,0x6abb82fe}},	//   kaj_, ntas_, rmet, rnuf,
   {{0x26cff40a,0x6e2d740b,0x442306e4,0xe8d90a2c}},	//   logo_, _adab, jaj_, kwọ_,
   {{0xb9048403,0x229c0125,0xd25180f7,0x244f8457}},	//   _भी_, _líka_, _لنا_, rımı_,
   {{0x39492788,0x7c23aeec,0xddcd012b,0x26cfe677}},	//   ktas_, lanr, _snaš, nogo_,
   {{0xa3e000cf,0x20bf0ebf,0x95830009,0x7afe012b}},	//   _तरह_, ्वाध, вляе, _supt,
   {{0x649001c2,0x442cf40c,0x7ce0016d,0x629d00f3}},	//   _näit, _xdd_, föra, _also,
   {{0xcee911fb,0x38ad0086,0x316da391,0xb5fd8b48}},	//   ترین_, _görə_, lvez_, _našo,
   {{0x628baec9,0xa3e29199,0x7c238ad4,0x3a3f90dc}},	//   _jogo, नेट_, hanr, ngup_,
   {{0x628b8db7,0x26cf822e,0x394954cc,0xb5fdf40d}},	// [6f80] _mogo, dogo_, gtas_, _pašn,
   {{0x44230025,0x6609cba4,0xddc41c32,0x65640234}},	//   caj_, _afek, _kniž, _isih,
   {{0x645c2a31,0xfaa60084,0x39495064,0x26cfa47a}},	//   meri, _жано, atas_, fogo_,
   {{0x645c740e,0x628bbac4,0x26cf93a2,0xbc3a0061}},	//   leri, _nogo, gogo_, _اسکا_,
   {{0xfee98013,0x39492790,0x64a6a27b,0x6e228c41}},	//   أعلى_, ctas_, мада, raob,
   {{0x16bb02f1,0x7c2381e0,0x6e2281a1,0x628b83e4}},	//   _उद्ब, ganr, saob, _aogo,
   {{0x628bf22b,0x7529a4f4,0xbcfb0019,0x645c740f}},	//   _bogo, _evez, lvét, ieri,
   {{0x4423024a,0x628b9727,0xa7fc83bf,0x63a30019}},	//   zaj_, _cogo, rdım, _ünne,
   {{0xa80287d9,0x041d80ab,0x7c23c823,0x44237410}},	//   _çıka, _নারী_, banr, yaj_,
   {{0x645c03c3,0x66dd0065,0x6e20f411,0x76445f9d}},	//   jeri, téko, _hemb, _aciy,
   {{0x7529e5cc,0x6e2094e5,0x44233b19,0x7d0d2c21}},	//   _zvez, _kemb, vaj_, _stas,
   {{0x444420af,0xe7e60063,0x628b811e,0x6e2088b3}},	//   _ac_, _करना_, _gogo, _jemb,
   {{0x6e20c17a,0x442340fb,0x41e283dd,0xf1e2847d}},	//   _memb, taj_, _परिस, _परिन,
   {{0x6e2089ca,0xa3e58697,0xdb1e0118,0x3a249eb2}},	//   _lemb, _नरम_, _expí, lamp_,
   {{0x44237412,0x44447413,0xdfd080f7,0xb5fd826c}},	//   raj_, _dc_, _حيث_, _bašl,
   {{0x59e284e5,0x44447414,0x628bce65,0x39497415}},	//   _परार, _ec_, _xogo, ttas_,
   {{0x44230db7,0xdced003e,0x7c23f416,0xddc4024a}},	// [6f90] paj_, _hrač, yanr, _zniž,
   {{0x645c7417,0x7bc510af,0xfe70803d,0x7bc02353}},	//   ceri, _txhu, یدن_, ğmur,
   {{0x64450caa,0xe7ea0076,0x3a24a1c3,0x9f041368}},	//   _ichi, झेला_, kamp_, نولو,
   {{0x6e2090e1,0xdced0668,0x39493883,0xb5fd87aa}},	//   _cemb, _mrač, ptas_, _vašo,
   {{0x7c238648,0x64900074,0x44214517,0x6e20f418}},	//   tanr, _täit, _keh_, _demb,
   {{0xf41d00ab,0x442145b8,0x649008e5,0xd91a0039}},	//   _তাঁর_, _jeh_, _häir, _מושל,
   {{0x628b836f,0x44217419,0x765d741a,0x7ce01e5e}},	//   _pogo, _meh_, kesy, körn,
   {{0xc1e3146d,0x442102c1,0xc2459e4e,0x6e209e92}},	//   _खराब_, _leh_, хник, _gemb,
   {{0x64452d8d,0x316d82be,0x628b8858,0x7e7bf41b}},	//   _ochi, uvez_, _vogo, _inup,
   {{0x644500f6,0xdced0a20,0x44210573,0x645c741c}},	//   _nchi, _brač, _neh_, xeri,
   {{0x7aed0590,0x765d5984,0x645c0e79,0xc0a89368}},	//   kmat, fesy, veri, بايل_,
   {{0x6445741d,0xeb96893f,0x645c741e,0xa5bb6edd}},	//   _achi, _אדער_, weri, raón,
   {{0x753d0065,0x7aed741f,0x44215e93,0x4444037e}},	//   gusz, dmat, _beh_, _pc_,
   {{0x44441532,0xb4da0816,0x64450037,0x26101a4d}},	//   _qc_, ़ते_, _cchi, _थ्री_,
   {{0x444400a9,0x4421016f,0xe815835a,0xfddc8540}},	//   _vc_, _deh_, _द्या_, _बर्फ,
   {{0x644510ec,0x44217420,0x28ab81a2,0x44447421}},	//   _echi, _eeh_, टोरि, _wc_,
   {{0x6e20e1ad,0xdced2847,0x59d58006,0x6e266708}},	// [6fa0] _remb, _zrač, _डुमर, makb,
   {{0x6e20f422,0x6e26546c,0x7aed7423,0x7e7b809c}},	//   _semb, lakb, amat, _anup,
   {{0x6e2094ec,0x7d00c5a1,0x6f0b8087,0xb5fd826c}},	//   _pemb, _sums, _încă, _tašl,
   {{0x64900074,0x212900b9,0x291d82c4,0xd7ef01a8}},	//   _täis, bsah_, _owwa_, حكم_,
   {{0x69d9f424,0x7c2182d6,0x6fd00ad5,0xbcfb7425}},	//   _nywe, _belr, _तुरं, lvér,
   {{0xf366a523,0x765d009a,0x7e7b91d3,0x34ca86a7}},	//   етин, zesy, _enup, ाकेद,
   {{0x6e20f426,0x61e28065,0xbcfb01df,0x7e698118}},	//   _temb, _szol, nvér, _faep,
   {{0x29027427,0x2d4984c3,0x7d00f428,0xb5fb4233}},	//   _kuka_, búe_, _tums, ldáv,
   {{0x5bbd0107,0x634a8201,0x6e2609da,0x3a24bebb}},	//   _ईश्व, _məni, dakb, ramp_,
   {{0x29027429,0x69d9831d,0x3ea0003d,0x3ae1f42a}},	//   _muka_, _dywe, _alit_, rópa_,
   {{0x59e28105,0x44212793,0x2129016b,0x93aa8290}},	//   _परवर, _reh_, zsah_, _عاطف_,
   {{0x6445742b,0x6f0307a3,0x44214040,0xdced06c2}},	//   _schi, ínci, _seh_, _vrač,
   {{0x765d742c,0x7aed6a5c,0x656281ec,0xf8bf01d0}},	//   resy, vmat, nwoh, _svém_,
   {{0xe04a8077,0x753d009a,0xb4bd06ae,0x7aed248a}},	//   _رشته_, rusz, ेके_, wmat,
   {{0x765d0e87,0xdced0289,0x7aed18d6,0x75f68214}},	//   pesy, _urač, tmat, _yüzü,
   {{0x29020590,0x212900dd,0x753d2a87,0x557524dc}},	//   _buka_, tsah_, pusz, _агит,
   {{0x7aed1140,0x4421742d,0x60f907ac,0x200b8063}},	// [6fb0] rmat, _teh_, дная_, ście_,
   {{0x29022ef3,0x2ec982f1,0x26c48668,0x290f00eb}},	//   _duka_, िक्त, _ajmo_, īga_,
   {{0x3209008e,0x2aba81a9,0xdce40115,0x9c7c8176}},	//   pcay_, lību_, _srić, _chčm,
   {{0x2d4984c3,0x6aa4742e,0xd7c81ca3,0x6d4bd428}},	//   túe_, chif, رونه_, ttga,
   {{0x2aba80eb,0x8c458152,0x386a742f,0x660d0372}},	//   nību_, веле, _fabr_, _mfak,
   {{0x01360039,0x2298807b,0x64cbdb17,0x34cb801b}},	//   _ברשת_, _fékk_, िवेश, िवेद,
   {{0x7bda998c,0x2d4984c3,0xdca29242,0x64a28009}},	//   _cytu, súe_, ращи, раща,
   {{0xe7e62967,0x6d4b9770,0xb5fdadad,0xb5fb0019}},	//   _करता_, ptga, _mašk, ldáu,
   {{0x7ce05619,0xfc33804e,0x44f5a34b,0xb5fd82d4}},	//   förl, _محض_, _апас, _lašk,
   {{0x5ba78ab2,0xb4bd13d9,0xd3a79c60,0x660d7430}},	//   _през, ेको_, _преп, _afak,
   {{0x752d41ae,0xb5fd80d2,0x6e26020d,0x09de1299}},	//   _avaz, _našk, takb, _मर्य,
   {{0x98a9009a,0x395900b9,0x96962d01,0x644388e0}},	//   brać_, _opss_, трош, lgni,
   {{0xd94581ae,0x05631570,0x61459860,0x39590bda}},	//   _рели, авян, _рела, _npss_,
   {{0x634a8085,0x2a6d8114,0x394df431,0x752d0115}},	//   _səni, ldeb_, mtes_, _dvaz,
   {{0x29022f04,0x394daa26,0x4427b6a5,0x6e260072}},	//   _suka_, ltes_, ian_, pakb,
   {{0x628f16e8,0xdd921e44,0x3ea0009c,0x394d81b3}},	//   _coco, _نوع_, _ulit_, otes_,
   {{0x4427859c,0x394d821e,0x412701f3,0x2aba8029}},	// [6fc0] kan_, ntes_, кото_, cību_,
   {{0x6f03885c,0x6aa47432,0x38cb0fd3,0x6e240428}},	//   _kunc, shif, والی_, _heib,
   {{0x649b0f60,0x7d0405f8,0x394df433,0x6e24036e}},	//   _חסיד, _huis, htes_, _keib,
   {{0x6f03f434,0x7d040010,0x394deeb4,0x29022085}},	//   _munc, _kuis, ktes_, _tuka_,
   {{0x4427f435,0x7d040a0f,0x7bda809a,0x76428b0b}},	//   fan_, _juis, _sytu, rgoy,
   {{0x7d041e64,0x6e2462ce,0x4427c617,0x644380f2}},	//   _muis, _leib, gan_, ggni,
   {{0x2d808012,0x6f038510,0x7d044695,0x61f78085}},	//   ţie_, _nunc, _luis, əblə,
   {{0x68fc0065,0x394de2a2,0x4427f436,0xdee698c6}},	//   _hird, ftes_, aan_, _роби,
   {{0x442780ef,0x394df437,0x39403710,0xd83a814c}},	//   ban_, gtes_, nuis_, мэн_,
   {{0x4427f438,0x38a400f2,0x7bda809a,0xa786803d}},	//   can_, _före_, _tytu, نشجو,
   {{0x38a407d9,0x6f038509,0xc2469bbf,0x2bd20b75}},	//   _göre_, _cunc, _анек, _दुला,
   {{0xc7b88b6d,0x6f03a7e6,0x52769ec9,0x6e242564}},	//   nađi_, _dunc, _جائز, _ceib,
   {{0x394d87e2,0x98c69d59,0x7d0464ae,0x6f038580}},	//   ctes_, _искл, _cuis, _eunc,
   {{0x09e38a94,0x628f02a3,0x7d0432a9,0xb5fdbe45}},	//   _точн, _soco, _duis, _pašk,
   {{0x628f7439,0x7d04743a,0x6f03f43b,0x2aba80eb}},	//   _poco, _euis, _gunc, sību_,
   {{0x44278695,0x5a3419dc,0x7d0471f6,0x68fc0c5e}},	//   zan_, инст, _fuis, _aird,
   {{0x3eb90665,0x7d043db4,0x49750e11,0x3940743c}},	// [6fd0] mist_, _guis, ылас, guis_,
   {{0x3eb91c37,0x4427f43d,0xb5fdbe46,0x26c3026f}},	//   list_, xan_, _tašk, čkou_,
   {{0x4427f43e,0x7e6d3473,0x6aa2f43f,0xb5fd8da8}},	//   van_, _kaap, _olof, _haši,
   {{0xb5fd825b,0xdbdc808b,0x7e6d3103,0x394dc166}},	//   _kaši, _ráði, _jaap, ytes_,
   {{0x4427f440,0x7e6d199b,0x51842351,0x6d4f01b3}},	//   tan_, _maap, _кура, ntca,
   {{0xb5fd9c0b,0xdfc68013,0x4427a645,0x6aa28609}},	//   _maši, _هي_, uan_, _alof,
   {{0x7c254a12,0x225f8b99,0x3eb97441,0xddc2ba09}},	//   _mehr, teuk_, kist_, rdoš,
   {{0x4427c5ae,0x394df442,0x569481e2,0x36d59fa0}},	//   san_, ttes_, _каст, _собр,
   {{0x6f038289,0x6e949860,0x394df443,0xb4db0722}},	//   _sunc, _титу, utes_, ntàs,
   {{0x6f03f444,0xb5fdf445,0x4427d67a,0xf9920039}},	//   _punc, _naši, qan_, צרי_,
   {{0x394df446,0x5b158e17,0x7ea62e3c,0x69dd0370}},	//   stes_, _смет, _lópe, _lyse,
   {{0x3eb97447,0x4425ad24,0x394df448,0xbddb0722}},	//   gist_, _hel_, ptes_, rgèn,
   {{0x4425f449,0x7d046608,0xb5fd9351,0x69dd4afe}},	//   _kel_, _quis, _baši, _nyse,
   {{0x4425803a,0x7afd69a1,0x3ebe0065,0xe8bf000c}},	//   _jel_, _aist, őtt_, ्वोच,
   {{0x42560139,0x7c2501b9,0xc0528039,0x61e60035}},	//   лтат, _dehr, _הזו_, _szkl,
   {{0x7d04744a,0xb3d210be,0x68fc744b,0x4425f44c}},	//   _tuis, _दुःख, _sird, _lel_,
   {{0x7afd744d,0x6d4f0bfd,0x3edb00be,0x6d5b8069}},	// [6fe0] _dist, ctca, _אַזא, _npua,
   {{0x44258021,0xe9d74875,0x3b86148d,0x7afd031d}},	//   _nel_, уку_, _блог, _eist,
   {{0xb4c0053e,0xee3af44e,0x7afd2519,0x6ac612dc}},	//   ंची_, ене_, _fist, _مقدم,
   {{0x394003d3,0x7afd744f,0x442a15e8,0x5f068b85}},	//   puis_, _gist, lab_, _संस्_,
   {{0xe7e60105,0x68fc00eb,0x39407450,0x69dd6d5a}},	//   _करवा_, _tird, quis_, _gyse,
   {{0x3ea6f451,0x4425f452,0x442a7453,0x7afd01ac}},	//   shot_, _cel_, nab_, _zist,
   {{0x4425dc59,0xb5fb7454,0xc8db0039,0x8fa66386}},	//   _del_, ndár, _נקלט, _саве,
   {{0x442a616e,0xbea38e02,0xb4db0722,0xd91ab2dd}},	//   hab_, _ласк, ntàr, ньо_,
   {{0x4425d936,0x6e938064,0x442a7455,0xe6938013}},	//   _fel_, _القا, kab_, _القد,
   {{0x2e240104,0x442a3832,0x7e6d331b,0x78748061}},	//   _đườn, jab_, _saap, küvő,
   {{0x324692dc,0xd7f781bb,0x442a7456,0x7e6d10ab}},	//   _مناف, лую_, dab_, _paap,
   {{0x7c2af457,0x59af8006,0x7e62f458,0x80b68074}},	//   lafr, _जेकर, neop, _ऋगवे,
   {{0x7afd30af,0x99bf00ab,0x212b80f7,0xb5fdad38}},	//   _rist, _আর্ক, ácht_, _paši,
   {{0x442a7459,0x2d99745a,0x7c2af45b,0x673a82d4}},	//   gab_, ryse_, nafr, prtj,
   {{0x3eb9745c,0x447b80be,0x7e6d5dea,0x709b83de}},	//   pist_, ענלע, _taap, _אױגו,
   {{0xadf6800f,0x78ba8805,0x7afd00ee,0x386101ec}},	//   ेशान_, litv, _qist, wehr_,
   {{0x442a321c,0xf1b9c94f,0xddc9904c,0x7afd29da}},	// [6ff0] bab_, taši_, _snež, _vist,
   {{0xdddb8a56,0x78ba807a,0x442a0be9,0x1ae1a49a}},	//   _použ, nitv, cab_, _पठ्ठ,
   {{0x7afd745d,0x69dd271d,0x3a2900e4,0xa9240084}},	//   _tist, _wyse, paap_, _įžei,
   {{0xdce9803b,0x7afd05f3,0xaa671289,0x9f4a0091}},	//   _kreć, _uist, _сток, _agbó_,
   {{0x80bf0a49,0x44258813,0xa2b3809a,0xb5fd990f}},	//   ্তব্, _pel_, इफस्, _lašv,
   {{0x644767a2,0x78ba807a,0xa3bc052a,0xc7b881a1}},	//   ngji, jitv, _अधम_, lađu_,
   {{0x442580b2,0x78ba8353,0xd4980039,0x66dd4068}},	//   _vel_, ditv, רכות_, léku,
   {{0x4425a6bc,0xd6c3b25e,0xc7b88289,0xddc40110}},	//   _wel_, _امری, nađu_, _laiš,
   {{0x844792dc,0x38a4016d,0x442a1061,0x6d5bb0e5}},	//   _مخال, _höra_, yab_, _upua,
   {{0x6e2b8091,0x38a400f2,0x4425f45e,0xc62500ab}},	//   lagb, _köra_, _uel_, _ভাষা_,
   {{0x442a0a1b,0xaec60198,0x2902808b,0x5fcf90f7}},	//   vab_, ибол, íkar_, _सुखल,
   {{0xfd4c8104,0x442a14ec,0x6e2b820d,0x64400110}},	//   _nhiề, wab_, nagb, ėmim,
   {{0x442a745f,0x2bdb000f,0x9fa2808b,0x78ba82d4}},	//   tab_, _मुबा, síða_, bitv,
   {{0xb4c0053e,0x49b8806b,0x61e68214,0x659a80be}},	//   ंचे_, _حامد_, ükle, דישק,
   {{0x8a0612b2,0x3a2680ee,0x6e2bf460,0x661d2c15}},	//   изве, _yeop_, kagb, bbsk,
   {{0x442a7461,0xfd4c801c,0x7bde016b,0xfd630133}},	//   sab_, _chiề, _vypu, netị,

   {{0x442a0205,0x6e2bf462,0x7ce03cac,0x799b911f}},	// [7000] pab_, dagb, höri, nyuw,
   {{0xdbdf008b,0x3ea48359,0xddc41d70,0x442a7463}},	//   _tíði, _slmt_, _gaiš, qab_,
   {{0x09e28aed,0xa7fc82bb,0x6e36001b,0x9f4a0091}},	//   _पर्य, ldır, _kdyb, _agbò_,
   {{0x98a01487,0x2eedf421,0x75247464,0xe7371f8c}},	//   ksić_, _chef_, _kwiz, рец_,
   {{0x25a09301,0xa7fc884a,0xa8060198,0x7c2a81fa}},	//   áil_, ndır, _взгл, tafr,
   {{0x7ce0494b,0x7524313e,0x38a40106,0xe71a04a3}},	//   föri, _mwiz, _föra_, _ليست_,
   {{0xf767896c,0x38a404b8,0x78ba8db7,0x25a09807}},	//   _با_, _göra_, vitv, šil_,
   {{0xf1bf00f7,0x66040234,0xcb130039,0xb5fb0174}},	//   _meán_, _ngik, חלה_, deán,
   {{0x395201e2,0xe5a3835f,0x4c868171,0x78baf465}},	//   ntys_, _дити, _клав, titv,
   {{0xb5fd8029,0x92c880ab,0xf1b98858,0xb4c010f7}},	//   _pašv, োগে_, jašu_, ंचो_,
   {{0xdce9803b,0x78ba8db7,0x6f00e475,0x787900be}},	//   _sreć, ritv, _kimc, אָרו,
   {{0xdce982a5,0x7ceda4f7,0x26c6f466,0x6f0081b4}},	//   _preć, túrg, nnoo_, _jimc,
   {{0x2a64807a,0x628281b4,0x78baf467,0x1cbb05de}},	//   memb_, _inoo, pitv, ناسب_,
   {{0x7c288988,0xdce9805c,0x66c80214,0x6282822c}},	//   _jedr, _vreć, lıkl, _hnoo,
   {{0x644708cf,0x7c28f468,0xfd4c80ff,0x533412b2}},	//   rgji, _medr, _phiề, жест,
   {{0xdce9803a,0xb3458073,0xb5fdf469,0xf1bf2d83}},	//   _treć, luçã, _kašt, _deán_,
   {{0xf8071bd8,0x645af46a,0xb5fdb0d5,0x62828088}},	// [7010] ачен, _obti, _jašt, _mnoo,
   {{0x2bd209a3,0x26d93c50,0xb5fd805c,0x80d1016f}},	//   _दुका, loso_, _mašt, तकें,
   {{0x6e2bad32,0x62828365,0xb5fdb63c,0xfd4c8129}},	//   tagb, _onoo, _lašt, _thiề,
   {{0x39448029,0x63ad00eb,0xf1d820c0,0x645af46b}},	//   kums_, ģinā, _भुवन, _abti,
   {{0x7c289682,0x39448341,0x6c7800d5,0xb5fd85b7}},	//   _bedr, jums_, _صحیح_, _našt,
   {{0x6282c953,0x645a8216,0x38a40106,0x6f0702d4}},	//   _anoo, _cbti, _hörn_, _tujc,
   {{0xb34580a9,0x26d904be,0x1cb88875,0x6e2bf082}},	//   duçã, koso_, جانب_, pagb,
   {{0xb5fdf46c,0x224b82af,0x26d91520,0x6f00a3ca}},	//   _bašt, ück_, joso_, _gimc,
   {{0x26d928d5,0x394480eb,0x7c28f46d,0x5fcf80d4}},	//   doso_, gums_, _fedr, _सुजल,
   {{0x7c28905d,0x10a5a8a7,0x6aa99267,0x6282f46e}},	//   _gedr, сион, shef, _enoo,
   {{0x6e29d682,0x7d099e86,0x656d746f,0x26d901e8}},	//   _keeb, _hues, _asah, foso_,
   {{0x7d018aa2,0x7d09808e,0xba7480f7,0xa7fc8085}},	//   _hils, _kues, _وانت, tdır,
   {{0x2d9db818,0xf1b98904,0x765bf470,0xc10880ff}},	//   nywe_, tašu_, _mbuy, _hỗn_,
   {{0x7d0985b4,0x98a7000d,0xb34583a7,0xb5fb7471}},	//   _mues, čně_, cuçã, rdáp,
   {{0xb5fd803a,0x38a4007b,0x26d97472,0x7d01c74d}},	//   _zašt, _börn_, boso_, _mils,
   {{0x22490072,0x7d0980e7,0xa2062428,0x26d94a24}},	//   ggak_, _oues, спад, coso_,
   {{0x7d099220,0x644107a3,0x8c4607a1,0xb5fb01a8}},	// [7020] _nues, ólic, _лепе, neál,
   {{0x6d46127c,0x7d019c02,0x765bf473,0x39526a0e}},	//   muka, _nils, _abuy, rtys_,
   {{0x69cf2b56,0x6e29f474,0x6d4b016d,0x39520150}},	//   _exce, _beeb, _ägar, stys_,
   {{0x7c2e4685,0xdfcf26c2,0x528600f7,0x213ff475}},	//   labr, رين_, _الحك, kruh_,
   {{0x7d09840e,0x7d01a0d8,0x6d467476,0x7ae40197}},	//   _cues, _bils, nuka, mlit,
   {{0x657b8a56,0x7ae40fc0,0xb5fd8110,0x7c2e7477}},	//   _druh, llit, _rašt, nabr,
   {{0x6d461600,0x26d902e7,0x6f0081e4,0x3e7f0198}},	//   huka, yoso_, _timc, _jätä_,
   {{0x6d460393,0xb5fd81e2,0x6b8302ba,0x3944f478}},	//   kuka, _pašt, _ánge, tums_,
   {{0x6d4636a1,0x7d01861b,0xddcd21d1,0x7ae4198f}},	//   juka, _fils, _snaž, ilit,
   {{0xdb038117,0x6d461922,0x7ae4297a,0x39400083}},	//   szná, duka, hlit, iris_,
   {{0xb4e480dc,0xdb1e0118,0x201e8110,0x7c2e0084}},	//   नती_, _expú, rbti_, dabr,
   {{0x442ef479,0xdced005c,0x6d46331c,0x6e29f47a}},	//   laf_, _krać, fuka, _xeeb,
   {{0xf1948364,0xd012803d,0xe9ff80ff,0x6d46747b}},	//   _филь, _فلش_, _trạm_, guka,
   {{0x442ed68b,0x3940747c,0x7c2e01fa,0x7ae4747d}},	//   naf_, dris_, gabr, elit,
   {{0x38710358,0x443f02bb,0x26d94e11,0x5695041c}},	//   _razr_, ğu_, poso_, _макт,
   {{0x6d464408,0xe821058c,0x1dda0b04,0x442eac37}},	//   buka, यर्थ_, _युवत, haf_,
   {{0x656d15bd,0x442e879f,0xa3df8768,0x6e29f47e}},	// [7030] _usah, kaf_, _धुन_, _reeb,
   {{0x51f817ae,0xf8070a14,0x442e80fc,0x7ae43f19}},	//   сную_, счан, jaf_, alit,
   {{0xf7098104,0x7ae4747f,0x7d09f480,0x39407481}},	//   _lần_, blit, _sues, aris_,
   {{0x7d0985b4,0x394003ab,0xdced003b,0x657b816b}},	//   _pues, bris_, _brać, _pruh,
   {{0x7d09eaa4,0x7d018029,0x24f98a14,0x6e298006}},	//   _ques, _pils, анды_, _veeb,
   {{0x2ecf00c8,0xcc898077,0x6e29d328,0x7d0985a4}},	//   রতিষ, شنبه_, _weeb, _vues,
   {{0x61e2f482,0x6e298069,0x212689c4,0x3ea2008b}},	//   _ayol, _teeb, _awoh_, ykkt_,
   {{0x290301cd,0x290b09cf,0x6d4600a4,0x765baaac}},	//   _hija_, _kuca_, yuka, _ubuy,
   {{0xf7098104,0x7d018e1c,0xa3e58a74,0x657b82a0}},	//   _cần_, _tils, _नरक_, _uruh,
   {{0x3ea91e92,0xb5fb3554,0xd90c803d,0xf709801c}},	//   _alat_, reál, دیو_, _dần_,
   {{0x290330a1,0x3ea97483,0x290b59c2,0x3e8a1242}},	//   _mija_, _blat_, _luca_, айно_,
   {{0x764bb437,0x29031ac7,0x271780ff,0x291902f1}},	//   nggy, _lija_, _lăng_, _otsa_,
   {{0xf7098028,0x77e60e5b,0x6aad1bcc,0x29190282}},	//   _gần_, _कर्क_, dhaf, _ntsa_,
   {{0x27178104,0x3f77802e,0x3f9e8690,0x8fa59e4a}},	//   _năng_, _tău_, bytu_, _мале,
   {{0x6d465522,0x7ae47484,0x20078176,0x6fd90035}},	//   suka, tlit, _igni_, _बुलं,
   {{0x39407485,0x7c2e24d0,0x442ee7cc,0x290b27cd}},	//   tris_, sabr, zaf_, _buca_,
   {{0x29030341,0x7ae44f98,0x442e831d,0x2717801c}},	// [7040] _bija_, rlit, yaf_, _băng_,
   {{0x3e7f0009,0x290300d2,0x7a3f077f,0x271780ff}},	//   _tätä_, _cija_, _pàtà, _căng_,
   {{0xb4d60bb8,0x7ae47486,0x29030168,0xadc38032}},	//   िकी_, plit, _dija_, _ifẹn,
   {{0x6aad7487,0x2f5a8158,0xdced005c,0x7ce48722}},	//   chaf, ידענ, _prać, mòri,
   {{0x628639c4,0x20078698,0x29037488,0x200382d4}},	//   _inko, _ogni_, _fija_, žjih_,
   {{0xdced003a,0x54b78d13,0xb4e48740,0x6aa40d1b}},	//   _vrać, огія_, नते_, lkif,
   {{0x443a7489,0xbea68162,0xb649026b,0x644a8123}},	//   _mdp_, _давк, _emẹ̀, rgfi,
   {{0x5a3487eb,0x443a748a,0x442e831d,0x2007a1ba}},	//   чнит, _ldp_, saf_, _agni_,
   {{0x2104901b,0x80bf00c8,0x6e2284b9,0x50669287}},	//   रदेश_, ্তর্, mbob, отна,
   {{0xa3bb0006,0x61e286c0,0x3ea91581,0x271780ff}},	//   _आइल_, _vyol, _slat_, _xăng_,
   {{0x4ada016f,0xa2e695b9,0x73368019,0x987b0538}},	//   ढवाव, _дожд, _ذرائ, בריק,
   {{0x6d4297fe,0x443a20f8,0xadc38032,0xf70980ff}},	//   oroa, _adp_, _afẹn, _tần_,
   {{0x442c8038,0x443a748b,0xf99f09c4,0x6f040162}},	//   _ked_, _bdp_, _agèn_, _diic,
   {{0x6286748c,0xdc0880eb,0x442c941f,0xa0679f34}},	//   _anko, rēķi, _jed_, _мача_,
   {{0x442c9c6d,0x6f0410da,0x6d42baab,0x2717801c}},	//   _med_, _fiic, hroa, _răng_,
   {{0x290b02a5,0x7ce01f4d,0x3ea92f15,0x6d42f48d}},	//   _puca_, förs, _ulat_, kroa,
   {{0xb80e858c,0x2007011f,0x81dc80ab,0x442c831d}},	// [7050] _सलाम_, žnim_, ণের_, _oed_,
   {{0x6d4292f5,0x8fe7326c,0x6286748e,0x6aad748f}},	//   droa, оцед, _enko, shaf,
   {{0x4431263d,0xdce29487,0x6e2d178f,0x6aad007b}},	//   maz_, jvođ, _keab, phaf,
   {{0x7d0d1083,0xdce282a5,0x41ca816f,0x59cabb6b}},	//   _kuas, dvođ, ापास, ापार,
   {{0x27178028,0xa56792c8,0x25fe00d4,0x2903432f}},	//   _tăng_, تدان, रेपी_, _tija_,
   {{0x6e2d2ab6,0x9f350558,0x44317490,0x984817ae}},	//   _leab, _негі, naz_, _мяса_,
   {{0x394962f8,0x7ced8020,0x6e228041,0x95058019}},	//   luas_, gúra, bbob, _کہتے_,
   {{0x26cd8b80,0x443138ad,0xe3b08199,0x442cf491}},	//   _ujeo_, haz_, خره_, _eed_,
   {{0x057783f8,0x44311f1c,0x8d7784c0,0x7d0d0013}},	//   _بازد, kaz_, _بازا, _nuas,
   {{0x50db035a,0xdce40063,0x26ddc02d,0x442c8014}},	//   भविष, _ksią, lowo_, _ged_,
   {{0x2bdb36cf,0x25ee0076,0xd90f8065,0x39490282}},	//   _मुला, _घरही_, ریں_, huas_,
   {{0x443a5e70,0x7529b011,0x7d0d5470,0x39490359}},	//   _sdp_, _kwez, _buas, kuas_,
   {{0x443a73ee,0x4431435e,0x66dd0019,0x777a81c0}},	//   _pdp_, faz_, rékp, avtx,
   {{0xb4d612c7,0x75299afe,0x711a8039,0x44311caa}},	//   िके_, _mwez, _הוספ, gaz_,
   {{0x6e2d0013,0x7cf25ff1,0x75298234,0x07a58087}},	//   _feab, værd, _lwez, _хайн,
   {{0x6609f492,0x7d0d082a,0xa5bb0118,0x2bdb0072}},	//   _ngek, _fuas, mbón, _मुळा,
   {{0xf2d28158,0x26c26555,0x39492790,0xe297138c}},	// [7060] גען_, miko_, guas_, чат_,
   {{0x629985c6,0x6aa40aa2,0xb06301ac,0x60c1880a}},	//   _lowo, skif, jväč, nilm,
   {{0xdc9b0451,0xc5f68bb8,0x7d1bf493,0x9e6690ee}},	//   _הייל, ेश्य_, _atus, звед,
   {{0x442cf494,0x6299f495,0x26c27496,0x6d428ea4}},	//   _sed_, _nowo, niko_, troa,
   {{0xe5a385f1,0x6da38e17,0x7e760069,0xfce69da6}},	//   ници, ница, _mayp, подо,
   {{0x442c81cd,0x6609907a,0x26c238cd,0x6d42811e}},	//   _qed_, _egek, hiko_, rroa,
   {{0x442cde3b,0x26c23976,0x26dd8573,0x7d1b8009}},	//   _ved_, kiko_, bowo_, _etus,
   {{0xfa970158,0x62998e60,0xb909001c,0xf709801c}},	//   ִדיש_, _cowo, _nghị_, _cầm_,
   {{0x25fe146d,0xd90d84c0,0x26c27497,0x3ea68101}},	//   रेमी_, لین_, diko_, mkot_,
   {{0xf48495e4,0xb4d66eed,0x7c3a813c,0x3ea681a9}},	//   _تاری, िको_, _udtr, lkot_,
   {{0x7d0d0057,0x656402c4,0x26c25e16,0x08570039}},	//   _suas, _apih, fiko_, הבים_,
   {{0x7d0d0867,0xeeab0470,0x6299f3ee,0x76ab0991}},	//   _puas, сток_, _gowo, стов_,
   {{0x7d0d1155,0x60c1f498,0x645c7499,0x2d800073}},	//   _quas, bilm, ffri, _crie_,
   {{0x2d8010f4,0xb5fb00f7,0x6f1c017f,0x645c0019}},	//   _drie_, neái, _otrc, gfri,
   {{0x4431749a,0x20073f13,0x26c21768,0x7d0d0144}},	//   raz_, žnik_, biko_, _wuas,
   {{0x39490c52,0x6fbd0074,0x7cf20bc5,0x66e40226}},	//   tuas_, ्पसं, være, _поја,
   {{0x44310510,0x2d8002d6,0x25a203eb,0x00000000}},	// [7070] paz_, _grie_, cykl_, --,
   {{0x6e3b826c,0xb21b0366,0x7cf203ba,0x7529818e}},	//   _sdub, _knæk, tære, _rwez,
   {{0x8d1809d7,0x26ddf49b,0x7ae2ae5d,0x0675a3b2}},	//   _وزیر_, towo_, _okot, дуля,
   {{0x3ea6f49c,0x394910e1,0x7529f49d,0x60c1f49e}},	//   gkot_, puas_, _pwez, zilm,
   {{0xf65087bd,0xb60980eb,0x60c18850,0x26ddf49f}},	//   ائم_, višķ, yilm, rowo_,
   {{0x26c274a0,0x2cac826c,0x7b0800f7,0x7ae2e289}},	//   ziko_, _cldd_, _óstá, _akot,
   {{0x6299809a,0xfc3081a8,0x2fc50106,0x61e64768}},	//   _powo, احه_, _älg_, _zykl,
   {{0x26c22453,0x6e3bf4a1,0x75298deb,0x00000000}},	//   xiko_, _udub, _twez, --,
   {{0x645c74a2,0x7529822e,0x7d1bbdd4,0x3ebfc8d0}},	//   yfri, _uwez, _utus, _imut_,
   {{0xb4bc00cf,0xb5fb0013,0x6d4bb294,0x6299f4a3}},	//   _आगे_, ceái, muga, _wowo,
   {{0x60c18a0b,0x6d4b849f,0xf709801c,0x9a1281bc}},	//   rilm, luga, _tầm_, _pọtụ,
   {{0x2d8001e2,0x60c1f4a4,0xfd4b019d,0x291fad82}},	//   _prie_, silm, _uloọ, ppua_,
   {{0x26c270b5,0x6d59f4a5,0x7afb8100,0x6d4bc014}},	//   riko_, ntwa, mmut, nuga,
   {{0x7ae9a88b,0xdcfb826c,0x3ead8722,0x7afbdf16}},	//   llet, _oruč, _llet_, lmut,
   {{0x6d4b8125,0x26c2202f,0x3ead8009,0x290f807b}},	//   huga, piko_, _olet_, _huga_,
   {{0x2907f4a6,0x6d4ba05e,0x645c0ed0,0x7afb816a}},	//   _hina_, kuga, sfri, nmut,
   {{0x290f848f,0x2907f4a7,0x68f5026c,0xd24f0019}},	// [7080] _juga_, _kina_, _bhzd, شنل_,
   {{0x2907822e,0x6d4bf4a8,0x25fe0128,0x212000dd}},	//   _jina_, duga, रेणी_, rpih_,
   {{0x2907f4a9,0xe29a0eef,0x3ea68747,0xb4ca13ba}},	//   _mina_, _дан_, tkot_, लची_,
   {{0x9f968039,0x6d5996f7,0x6d4b819e,0x3d0a83eb}},	//   ודעה_, ftwa, fuga, ादले_,
   {{0x23c389c8,0xb5fb00f7,0x3ea6f4aa,0x7ae9906f}},	//   _वेबद, teái, rkot_, dlet,
   {{0x6d4600dd,0x7ae2b117,0x63a38114,0x3ebf9abb}},	//   irka, _skot, fynn, _emut_,
   {{0x290ff4ab,0x7ae98d85,0xb5fb00f7,0x3ead80f1}},	//   _auga_, flet, reái, _flet_,
   {{0x7ae9a53a,0x2907b48c,0xb5fb00f7,0x290fccf0}},	//   glet, _aina_, seái, _buga_,
   {{0x7c3e0f28,0x286aad01,0x2ee4826c,0xb5fb74ac}},	//   _odpr, орно_, _ikmf_, peái,
   {{0x26c0227a,0x63a38114,0x7ae98ab3,0x634a8085}},	//   _amio_, bynn, alet, _mənz,
   {{0x2907f4ad,0xc1088028,0x291d82af,0xf21281bc}},	//   _dina_, _mỗi_, _etwa_, _dọrọ,
   {{0x2907f4ae,0xc1088028,0x6d460639,0x7ae2f4af}},	//   _eina_, _lỗi_, frka, _ukot,
   {{0x2907f4b0,0xd9e30076,0xf21291d3,0xe4e700e8}},	//   _fina_, _कुढत_, _fọrọ, дівн,
   {{0x67d4838b,0x290784b9,0xdce4009a,0x443e8695}},	//   _полу, _gina_, _księ, _jdt_,
   {{0x6d4609ca,0xc108801c,0xad9b00e1,0x6d4b80c6}},	//   arka, _nỗi_, ncúz, zuga,
   {{0x6d4b818c,0x7d0881d0,0x6d46011f,0x7ae08096}},	//   yuga, _lids, brka, nomt,
   {{0x387800f7,0x64482fe5,0xdcfb817f,0x19580d55}},	// [7090] _barr_, ódic, _sruč, маты_,
   {{0x3ead813c,0x29070bd7,0x1b1e00ab,0x6b750d9e}},	//   _slet_, öna_, _ফিরে_, _злоу,
   {{0x7ae9f4b1,0x7ae091ba,0x3eadc5a7,0xae1c0c32}},	//   ylet, komt, _plet_, भुवन_,
   {{0x752d4027,0x6d59822b,0xdb1e03a8,0x644303a7}},	//   _kwaz, ttwa, _expó, _ônib,
   {{0xdce981dd,0x7ae981cc,0x212b0114,0x660d0637}},	//   _sređ, vlet, _uwch_, _mgak,
   {{0x6d4b9caa,0xdce981dd,0x629d370c,0x6ef60118}},	//   ruga, _pređ, _hoso, mábe,
   {{0x629d2139,0xdcfb8052,0x7ae9f4b2,0x6d4bbf60}},	//   _koso, _uruč, tlet, suga,
   {{0x660d2ff2,0xdce982ee,0x7982dba4,0x60c500dd}},	//   _ngak, _vređ, _brow, lihm,
   {{0x2bdf83eb,0x7ae98558,0x7afbf4b3,0x212b86c0}},	//   _पुरा, rlet, rmut, èch_,
   {{0x660d74b4,0x26c0142f,0x3f588187,0x7ae9f4b5}},	//   _agak, _smio_, féu_, slet,
   {{0xdce9803a,0x752d4289,0x44278144,0x07a58a18}},	//   _uređ, _awaz, mbn_, ханн,
   {{0x629d1e57,0x6721805c,0x290f8503,0x79829106}},	//   _noso, rplj, _tuga_, _frow,
   {{0x628bf4b6,0xd7568065,0x0d8306c8,0x79828039}},	//   _ingo, ولیت_, глян, _grow,
   {{0x6f0980eb,0xfd4e81bc,0x9a1281bc,0x3f58b673}},	//   _liec, _alkọ, _họpụ, béu_,
   {{0x7c3e8073,0x629d0573,0x68e1b58b,0xeb9a1016}},	//   ópri, _boso, mold, чив_,
   {{0x6f09a1f3,0xe29704ae,0x26c0026c,0xc3329101}},	//   _niec, нас_, _umio_, טול_,
   {{0x61430294,0xe9d722be,0xd94302d3,0x4427808e}},	// [70a0] лета, ект_, лети, kbn_,
   {{0x9c7c826f,0x68e1f4b7,0x2bdb2db8,0x2a6d8069}},	//   _akčn, nold, _मुका, heeb_,
   {{0x54570051,0x628b9cb9,0xf457007c,0xe666845e}},	//   _אביב_, _ongo, _אייר_, етло,
   {{0x7d088022,0x68e18a38,0x629d0114,0xdce40084}},	//   _sids, hold, _goso, _priė,
   {{0xf9920bca,0x7e6474b8,0x1a9b00be,0x6f09f4b9}},	//   _صبح_, _mbip, _זיכע, _diec,
   {{0x628bf4ba,0x653b00be,0x661b838a,0x34bc8a27}},	//   _ango, לענד, _efuk, ्चेद,
   {{0x6f098012,0x7d08806a,0xd62aae9f,0x629d38b6}},	//   _fiec, _vids, _нове_, _yoso,
   {{0x7982809a,0x7e640133,0xb5fb0144,0x290a0061}},	//   _prow, _nbip, nfác, _hiba_,
   {{0x7d089277,0x68e1c5b2,0xf9928154,0x290a42c3}},	//   _tids, fold, ابع_, _kiba_,
   {{0x628bf4bb,0x68e18019,0xdfda8098,0x2d848ca3}},	//   _engo, gold, зъм_, _irme_,
   {{0xc5fb13e5,0x690900d2,0x752d4077,0x65760a84}},	//   ृश्य_, _ožen, _swaz, _asyh,
   {{0x234ba452,0x290a071f,0x2a6d822c,0x7ae602c4}},	//   _رسمی_, _liba_, ceeb_, _nkkt,
   {{0x25a6e9b7,0x38cbc068,0x68e1f4bc,0x6ef60118}},	//   nyol_, _کانی_, bold, xábe,
   {{0x629d01bf,0x290a02a0,0x7e64587b,0x752d06c0}},	//   _soso, _niba_, _ebip, _vwaz,
   {{0x629d1640,0xfbdb06b7,0x9a871156,0x1bd422e9}},	//   _poso, _मुखम, нуал, горя,
   {{0x629d19ea,0x290a0087,0x752d74bd,0x2d84f4be}},	//   _qoso, _aiba_, _twaz, _orme_,
   {{0x6909250d,0x629d05e4,0x290a020c,0x752d74bf}},	// [70b0] _džen, _voso, _biba_, _uwaz,
   {{0x7e7d3a4d,0x6f09809a,0x6ef601df,0x5b151071}},	//   ldsp, _siec, rábe, _имот,
   {{0xe70b15e4,0x290a5e8d,0xdfd100f7,0x6f09f4c0}},	//   ستان_, _diba_, جيا_, _piec,
   {{0x6ee781a8,0x2a6d81c0,0x26cfceae,0x52a701a8}},	//   رسال, xeeb_, ungo_, _أصدق,
   {{0x6d5d74c1,0x3a29036e,0x7e7d64e5,0xe8d90870}},	//   ntsa, mbap_, idsp, ntị_,
   {{0x7aed74c2,0xe7330250,0xdced005c,0x6f09809a}},	//   llat, _مصر_, _krađ, _wiec,
   {{0x0ee10076,0xe2998973,0x8c1c0051,0x6d5d0006}},	//   नवाड, дай_, לוגי, htsa,
   {{0x443374c3,0x7ea600a9,0x7aed74c4,0x7e7d013c}},	//   _lex_, _tópi, nlat, jdsp,
   {{0x6d4f0052,0x6aa98125,0xe9d99ff8,0x442782f7}},	//   juca, rkef, ьки_, pbn_,
   {{0x39490e67,0x7e7bf4c5,0x6d4f74c6,0x7aed74c7}},	//   iras_, _haup, duca, hlat,
   {{0x7e7b9184,0x6ef60065,0x64419400,0x645e8722}},	//   _kaup, vább, _idli, òpie,
   {{0x38a41bd7,0x68e1f4c8,0x394974c9,0x628bf4ca}},	//   _hört_, sold, kras_, _ungo,
   {{0x394daa1e,0x7e7b816f,0x6724807d,0xee3f003e}},	//   ques_, _maup, _čije, ckým_,
   {{0x7e7b91de,0x6ef88118,0x10a2816c,0x98a282ee}},	//   _laup, míbe, _вишн, _више,
   {{0x394974cb,0x1d0726c8,0x6ef8801b,0x6ef60019}},	//   eras_, тери_, líbe, rább,
   {{0xc2433d2f,0x394907a3,0x1b1380ab,0x7e7bb308}},	//   инск, fras_, _সবাই_, _naup,
   {{0x9426117e,0x3949658a,0x6d5b8069,0x6d4f74cc}},	// [70c0] _импе, gras_, _nqua, cuca,
   {{0xb5fb6edd,0xdd310085,0xf53703de,0x44331d88}},	//   reát, ləşd, _שניי_, _gex_,
   {{0x443874cd,0xdced0025,0xb4c00076,0x63a70063}},	//   mar_, _građ, ूची_, cyjn,
   {{0x39492c70,0x7aed74ce,0xfaa61be4,0x76a980e8}},	//   bras_, clat, _рамо, нтів_,
   {{0x7ae4025d,0x290a2659,0xdce080eb,0x7e7b8036}},	//   moit, _tiba_, _apmā, _daup,
   {{0x55bb0039,0x7ae40009,0xf4d08264,0x5453804a}},	//   ומנו, loit, িত্ব, ивіт,
   {{0x3ea000c9,0xf70a001c,0xf1bf0118,0x38a402d0}},	//   _ooit_, _hầu_, _feás_, _dört_,
   {{0x44380695,0xf7770bea,0xee3f01ac,0x7ae474cf}},	//   har_, _בעלי_, tkým_, noit,
   {{0xb6a38f5a,0x26c4f4d0,0xbea38f9c,0x63a70035}},	//   _титл, _immo_, _татк, zyjn,
   {{0x443874d1,0xdd8f8013,0x7ae40009,0x7e7b807a}},	//   jar_, _بوك_, hoit, _zaup,
   {{0xd7f79a97,0x7ae42e62,0xf8370039,0xbcfb00e7}},	//   кую_, koit, כנית_, ntée,
   {{0x673a807b,0x7c3880a9,0x443337cd,0x7ae40364}},	//   rstj, lavr, _sex_, joit,
   {{0x44383c76,0x3ea002be,0x2bdb0074,0x673a807b}},	//   far_, _doit_, _मुजा, sstj,
   {{0x64d20076,0x403491b3,0x394900a9,0x6d4f7475}},	//   _सदृश, _секс, vras_, ruca,
   {{0x9f588009,0x6909056f,0x25ad1d1a,0xc339801b}},	//   ärä_, _džel, šel_, žívá,
   {{0x39491864,0x6d4f0052,0xd838842b,0xf70a001c}},	//   tras_, puca, lač_, _bầu_,
   {{0xf70a0028,0x7aed1d56,0x7ea60118,0x60f90e11}},	// [70d0] _cầu_, rlat, _cópu, еная_,
   {{0x2edb8c78,0xf70a001c,0x7e7bc3e0,0xdce9876c}},	//   यक्त, _dầu_, _saup, _iseć,
   {{0xf4120051,0x20070364,0xdced1c89,0x7ae42737}},	//   _לפי_, äni_, _urađ, boit,
   {{0x60c89cdf,0x7ae404c3,0x4ea78098,0xa295102a}},	//   hidm, coit, ърза, _самі,
   {{0x3cdf85b3,0xe7e50076,0xd12692dc,0xd838979d}},	//   गवले_, _कडवा_, _دم_, kač_,
   {{0x6aad052a,0x387c82f9,0x6f0d03e1,0x26c48299}},	//   lkaf, _navr_, _liac, _emmo_,
   {{0x2ca11083,0x7e7b82d7,0x9f3400e8,0x69d980b9}},	//   _mohd_, _taup, _весі, _sxwe,
   {{0xdce9b69f,0x6aad74d2,0x6ef8802a,0x6ef60061}},	//   _oseć, nkaf, tíbe, kába,
   {{0x443874d3,0x1017000f,0x2f1a8029,0x38a4016d}},	//   yar_, _तलाश_, _rīga_, _görs_,
   {{0x44384633,0x3ea003d3,0x6ef885e4,0x7ae4473f}},	//   xar_, _soit_, ríbe, zoit,
   {{0x1eca1927,0xb5fd81e2,0x61eb809a,0x6ef884c3}},	//   елни_, _rašy, _wygl, síbe,
   {{0x44380a73,0xaca38129,0x7fb3811c,0xba3983de}},	//   war_, _ruộn, nəqə, _װײַט,
   {{0x3ea04a61,0x7ae474d4,0x6f0d74d5,0xe8ee81e2}},	//   _voit_, voit, _diac, _гл_,
   {{0x628f0698,0x2a7d822c,0xd83880d2,0x443823ca}},	//   _anco, _hawb_, cač_, uar_,
   {{0x3ea04e6d,0x2a7d81c0,0x6f0d0090,0x395f82d7}},	//   _toit_, _kawb_, _fiac, ltus_,
   {{0x44382f04,0x670c0063,0x69091f0a,0x6f0d0081}},	//   sar_, _सूचक_, _džem, _giac,
   {{0xceb402bf,0xe8fa1a11,0x443846fb,0x38b60aa2}},	// [70e0] _ilə_, ела_, par_, _lære_,
   {{0x48c40a49,0x628f19c6,0x47bf00ab,0x2a7d822c}},	//   ্ত্র, _enco, ্থনী, _lawb_,
   {{0x444474d6,0x03a60993,0x6d4b9aae,0x395f82f1}},	//   _id_, _сино, erga, htus_,
   {{0xd838805c,0x395ff4d7,0x2a7d81c5,0x44441706}},	//   zač_, ktus_, _nawb_, _hd_,
   {{0x8e570f60,0x64a68e02,0xdca6997d,0x395d81c0}},	//   רינג_, лада, лади, _nqws_,
   {{0xa3e812ee,0xd37a9ae7,0x38b603ba,0x6aa30162}},	//   _बडा_, ечи_, _bære_, _înfr,
   {{0x38a4016d,0x38b6006a,0x2a7d8114,0x6e398122}},	//   _förr_, _værd_, _bawb_, bawb,
   {{0x7644022e,0x66e6cc43,0xdee6ce9a,0x7c3880fe}},	//   _ndiy, _соба, _соби, savr,
   {{0xd0108013,0xc05aaf8d,0x6f0d0013,0x2a7d81e9}},	//   يلة_, нін_, _riac, _dawb_,
   {{0x2ee680c9,0x2bdfbd25,0x444401c6,0x2ee965dc}},	//   loof_, _पुका, _nd_, _skaf_,
   {{0x2a668021,0x6f0d2c32,0xd838803b,0x3f878024}},	//   _бълг, _piac, rač_, _crnu_,
   {{0x444474d8,0xa3e80006,0xdce980ce,0x918692c5}},	//   _ad_, _बड़_, _pseć, _مجتم,
   {{0x44440f77,0x6f0d01ac,0x69092d16,0xe8948a08}},	//   _bd_, _viac, _džej, _валь,
   {{0x6aa2a539,0x764407d9,0xceb40201,0xb17b810f}},	//   _hoof, _ediy, _elə_, _נטור,
   {{0xb8658077,0x32671ff8,0x6ef60019,0x6aa2f4d9}},	//   _خانو, лтав, sába, _koof,
   {{0x444474da,0x6e2487f4,0xb6c90019,0x2a7d81c0}},	//   _ed_, ñibl, _جاتے_, _xawb_,
   {{0x38350aac,0x3f8780d2,0xf84b1cd0,0xaca3819d}},	// [70f0] инар, _zrnu_, ечей_, _skọl,
   {{0x26cb74db,0x201e82d6,0x3d18800f,0x6aad04fe}},	//   lico_, ncti_, _पढ़े_, skaf,
   {{0x3f874ded,0x6d40ac15,0x644574dc,0xe1ff0032}},	//   ínu_, _avma, _idhi, _gbón_,
   {{0x26cb1d03,0x17f80307,0x1e0f816f,0x4444011a}},	//   nico_, اركة_, िशेष_, _zd_,
   {{0x395ff4dd,0xa56480a0,0xe618821e,0x2a7d81c0}},	//   xtus_, مدون, уді_, _rawb_,
   {{0x21290587,0xd4698604,0x6f02ee62,0x26cb00e5}},	//   mpah_, тике_, amoc, hico_,
   {{0xeb9982da,0x2a7d8114,0x6aa2838a,0x64450c93}},	//   тий_, _pawb_, _boof, _mdhi,
   {{0xf53f04b8,0x38b65e3b,0xb1458ba8,0xe8e0001c}},	//   kså_, _være_, анил, _đứa_,
   {{0xe0d98ae7,0x81e700c8,0x20240125,0xd6d8902f}},	//   кви_, যের_, _árið_, _стр_,
   {{0x395fa985,0x05dea296,0x229c001b,0x1f65960f}},	//   rtus_, _फुटब, _díky_, аком,
   {{0x395f8744,0x752401dd,0x2a7d8282,0x3160011b}},	//   stus_, _stiz, _tawb_, ztiz_,
   {{0x26cb1d0a,0x644574de,0x6e360079,0x66e605c2}},	//   gico_, _adhi, _qeyb, рома,
   {{0x59a5016f,0x6ef8f17e,0xe9a89459,0x2d892641}},	//   _गॅलर, níba, _مدون_, _crae_,
   {{0x7cf2013c,0x7ae49640,0x44210122,0x690974df}},	//   mærk, čite, _cfh_, _džek,
   {{0x444474e0,0x394dc7b4,0xdc0881a9,0x46b58526}},	//   _vd_, lres_, mēģi, ंसाह,
   {{0x3eb902af,0x394d8e67,0x3a2607b6,0x76441a7b}},	//   chst_, ores_, рмаг, _udiy,
   {{0x394d862f,0x3d159344,0x3b072639,0x213f80ee}},	// [7100] nres_, _फूले_, рето_, nsuh_,
   {{0x394df4e1,0x444474e2,0x270e8f12,0xd25981a9}},	//   ires_, _ud_, िद्र_, miņu_,
   {{0x7c3c74e3,0xee3af4e4,0x657b9258,0x69dd74e5}},	//   marr, вне_, _asuh, _exse,
   {{0x0d869505,0x7c3c0102,0x9f47801b,0x33db04de}},	//   илен, larr, _nyní_, _יחיד,
   {{0x6aa2a608,0x2ee69b00,0x9784003d,0xd2598ec3}},	//   _roof, roof_, _گیاه, niņu_,
   {{0x394d92af,0x7c3c0e9b,0x394001c5,0x78a3add5}},	//   dres_, narr, msis_, _nonv,
   {{0x394d80c8,0x9f5c0364,0xa69684bd,0xf7432c60}},	//   eres_, ävä_, _крај, _меро,
   {{0x26cb0511,0x7c3c2a39,0x99668470,0x394074e6}},	//   xico_, harr, атол, osis_,
   {{0x7c3c00ad,0x26cb29c9,0x62809819,0x394074e7}},	//   karr, vico_, rdmo, nsis_,
   {{0x78a3c29c,0x7c3c74e8,0xa0a6a29c,0x394071a6}},	//   _conv, jarr, ршил, isis_,
   {{0x3ea48613,0x7c3c25bf,0x381702f6,0x69090858}},	//   _komt_, darr, יקים_, _džeh,
   {{0x394d9ed6,0xa1868a7f,0xf53f0bc5,0x39404b78}},	//   bres_, _выкл, tså_, ksis_,
   {{0x26cb74e9,0x394d809f,0x7c3c011e,0x290e993a}},	//   rico_, cres_, farr, _tifa_,
   {{0x7c3c00ad,0x6458a183,0x443cf4ea,0x2d8901b0}},	//   garr, ngvi, nav_, _vrae_,
   {{0x26cb1820,0xa3cc835a,0xdce984b7,0x39400915}},	//   pico_, रपट_, _speċ, esis_,
   {{0x443c81c5,0x2d891d03,0x25608247,0x68e89e4c}},	//   hav_, _trae_, kòl_, lodd,
   {{0x26c90025,0x443c803a,0xae0301fe,0x6fd9000f}},	// [7110] _imao_, kav_, रेशन_, _मशहू,
   {{0x7c3c07d0,0x92d700c8,0x1a65003d,0x37ab31ad}},	//   carr, িতে_, _گیری_, ктен_,
   {{0x443cf4eb,0x61ef0242,0x3e860061,0xd0180b69}},	//   dav_, _wycl, sítő_, рфу_,
   {{0x22950b53,0x394001c5,0x394dccd8,0x6ef8802a}},	//   _الحس, bsis_, yres_, tíba,
   {{0x98b30085,0x443cdb21,0x2bdf9c9d,0x3ea48609}},	//   şdır_, fav_, _पुजा, _domt_,
   {{0x394dbb09,0x7cf2006a,0xb4db0722,0x6ef8f4ec}},	//   vres_, værk, cràt, ríba,
   {{0x3f8a017f,0x7ced81a8,0xd25981a9,0x29195cb8}},	//   _grbu_, dúrt, ziņu_, _husa_,
   {{0x394dbd1a,0x7c3c6929,0x6b830511,0x29196083}},	//   tres_, zarr, _ángu, _kusa_,
   {{0x443c803a,0x394daed6,0x291174ed,0x7c3c0f3e}},	//   bav_, ures_, _kiza_, yarr,
   {{0x394df4ee,0x291974ef,0xdcf98591,0x26c97460}},	//   rres_, _musa_, _صفات_, _amao_,
   {{0x291174f0,0x291974f1,0xb69b3448,0x14d69101}},	//   _miza_, _lusa_, rmân, _פועל_,
   {{0x394daf8c,0x6e3d033e,0x6ef60207,0x39402681}},	//   pres_, gasb, rábo, ysis_,
   {{0xe7f40c78,0x7c3c011e,0x81ac00c8,0x29190e6d}},	//   _अर्थ_, tarr, _কেন_, _nusa_,
   {{0x6efd74f2,0x78ba8a11,0x2911012b,0xdce9a454}},	//   vébe, chtv, _niza_, _opeč,
   {{0x7c3c04b9,0x6d4f1581,0x29190bb1,0x24810122}},	//   rarr, arca, _ausa_, _dahm_,
   {{0x7c3c1b63,0x2919355d,0x25608247,0x6efd0019}},	//   sarr, _busa_, yòl_, tébe,
   {{0xe1fa1c60,0x7c3c159d,0xa3c9897d,0xbcfb01a8}},	// [7120] уга_, parr, _लेस_, stéa,
   {{0xeb9a04ae,0x7c3c022b,0x2ca582c4,0x3ae180e1}},	//   _био_, qarr, _nold_, rópy_,
   {{0xbb8600f7,0x394074f3,0x25608247,0x443c9024}},	//   _الجي, ssis_, wòl_, vav_,
   {{0xe29a3100,0xe7370abe,0x443a74f4,0xee3aa2e9}},	//   _сам_, сец_, _hep_, унд_,
   {{0x443cf4f5,0x443a0d29,0x291902a0,0x291109a6}},	//   tav_, _kep_, _gusa_, _fiza_,
   {{0x443a57e8,0x29113641,0x6562f4f6,0x628432cb}},	//   _jep_, _giza_, rtoh, ldio,
   {{0x961d8029,0x672482a5,0x6562f4f7,0x3ea4ed1f}},	//   _saņe, _čijo, stoh, _tomt_,
   {{0x443a23af,0xd00f00f7,0x65628168,0x7ae9811b}},	//   _lep_, _ألف_, ptoh, goet,
   {{0xd83a8196,0xd9fa001b,0x9c5aa452,0x98b8802e}},	//   лэн_, ्धित_, _مجاز_, илит_,
   {{0x2ca5c9f6,0x26c90140,0xa3c986ae,0x98ad81d6}},	//   _gold_, _smao_, _लेव_, ateľ_,
   {{0x6448f4f8,0x68e8831d,0x389b007c,0xd01081a8}},	//   _iddi, rodd, איינ, بلد_,
   {{0x6e22816f,0xfaa384fa,0x6abb8511,0x68e88114}},	//   ncob, _нахо, chuf, sodd,
   {{0x62840355,0x7c3aa1ba,0x3a391c32,0xc0e6d39f}},	//   ddio, _ketr, _resp_, _лодк,
   {{0xdcfb803a,0x443a74f9,0x68e8808e,0x66cf026b}},	//   _vruć, _cep_, qodd, _bòkè,
   {{0x443a74fa,0x872691cc,0x6aa60711,0x29193131}},	//   _dep_, _اعتم, _bokf, _susa_,
   {{0x2919188c,0x8aa40a08,0x272481bc,0x443a02f9}},	//   _pusa_, пруд, _ịnwa_, _eep_,
   {{0xa1590221,0x19590a14,0x443a2801,0x6448f4fb}},	// [7130] разу_, разы_, _fep_, _oddi,
   {{0x7ae98cdb,0x628406ae,0xa3b881a2,0x3a390299}},	//   zoet, adio, ङना_, _wesp_,
   {{0xb0658009,0x613f026b,0x836701a8,0x6282838a}},	//   llää, _bàlá, _ادخل, _oaoo,
   {{0x35f5943d,0x6448dba4,0xdced0110,0x29192360}},	//   опер, _addi, _praė, _tusa_,
   {{0x7c3a8b2b,0x64a5a5f5,0xee388d8e,0x5d678098}},	//   _betr, жала, сні_, стез,
   {{0x76598114,0xfbd009a7,0x61fd00eb,0x81cc80ab}},	//   sgwy, _آتی_, _izsl, _শুভ_,
   {{0x2ca58aa2,0x7ae9f4fc,0x045680f7,0x68fa01c6}},	//   _vold_, toet, زلية_, _כלשה,
   {{0xa92580e2,0x6448ddfb,0x6e228037,0x26d90866}},	//   одил, _eddi, ccob, érol_,
   {{0x76498ec9,0x26cfdf17,0x69091148,0x7ae9d502}},	//   _idey, migo_, _džev, roet,
   {{0x7ae48025,0x7c3ab864,0x26cfe6a7,0x25ed01ce}},	//   čita, _getr, ligo_, _घड़ी_,
   {{0x6d4400e1,0xf2e78a08,0x7ae9e8c3,0xe7398eef}},	//   _svia, _людо, poet, јем_,
   {{0x7c3aa1fa,0x7d1ba334,0x26cfc5ba,0x2a6901c0}},	//   _zetr, _kuus, nigo_, jfab_,
   {{0xbcfb0065,0x443a595b,0x21a58676,0x6e3b829c}},	//   rtén, _pep_, _филм, _meub,
   {{0x7d1be0d9,0x6c360013,0x26cfafdf,0x212d80ee}},	//   _muus, تفسا, higo_, mpeh_,
   {{0x25fe05e8,0x4425872c,0xc22701bc,0x644d80fc}},	//   रेजी_, _mfl_, _ụkọc, ɗait,
   {{0x6d4074fd,0x7e6d2aaa,0x26cf807a,0x6e3bb4dd}},	//   ámas, _gbap, jigo_, _neub,
   {{0x26cff4fe,0x7d1bf4ff,0x7d01b454,0xa5bb002a}},	// [7140] digo_, _nuus, _ohls, lcón,
   {{0x7649d559,0x25e302f1,0x3a3f8115,0x6ab99670}},	//   _adey, _टुटी_, haup_, _llwf,
   {{0xe61a96d4,0x7c3adf5f,0x2d8d8081,0xe7ef8dd2}},	//   аде_, _retr, _aree_, _घुमा_,
   {{0xa3e3064a,0x6d42f500,0x7d1bf501,0x7d019388}},	//   _फुट_, tsoa, _buus, _ahls,
   {{0x7c3a9598,0x2d8dc1d4,0x6e22861b,0x857696a5}},	//   _petr, _cree_, rcob, تدائ,
   {{0x6d42b9c8,0x645c49b5,0x6e22f502,0x9b26ac60}},	//   rsoa, ngri, scob, офил,
   {{0x6d4280a9,0xa2c10054,0x7c3af503,0xb4ca809a}},	//   ssoa, रोक्, _vetr, _लगी_,
   {{0xc2988895,0x22400239,0xf96a97ae,0x442581e0}},	//   ских_, naik_, арой_, _efl_,
   {{0x7d1be4be,0x69c08503,0x25642c02,0x26d901d6}},	//   _guus, uzme, jöl_, érom_,
   {{0x6f1c7504,0x7af60428,0x92ca8264,0x6e3b82f9}},	//   _kurc, hlyt, লকে_, _zeub,
   {{0xb4d6853e,0x22406b18,0x645c0140,0x2d807505}},	//   ाची_, kaik_, dgri, _asie_,
   {{0x6f1c6725,0x7d1b82a3,0x216a8ff7,0xa96a8d5f}},	//   _murc, _yuus, _види_, _вида_,
   {{0x291f81e8,0x2ab8810c,0x2d801b9c,0x256419de}},	//   cqua_, _géba_, _csie_, göl_,
   {{0x645c0854,0x26cfafa7,0xa2a68a27,0x6f1c1d88}},	//   ggri, zigo_, टॉर्, _ourc,
   {{0x0b8812e1,0xaca38028,0x93884ca2,0x7af60b81}},	//   ости_, _xuốn, оста_, flyt,
   {{0x6d480063,0x20182106,0x2d80002a,0xf1bf81d6}},	//   ądar, _agri_, _fsie_, žšej_,
   {{0x6e3be0e2,0x26cfa9e1,0xa2c12135,0xb9550081}},	// [7150] _reub, vigo_, रोग्, яващ,
   {{0xa2ca81ab,0x6f1c3a38,0xddc98087,0x3ea900ff}},	//   तोत्, _burc, _aceş, _hoat_,
   {{0x26cf984f,0x78a71487,0x2fc70028,0x22405649}},	//   tigo_, _vojv, àng_, baik_,
   {{0x6f1c034a,0x4b7a0158,0xef180110,0x98a90bda}},	//   _durc, _פארו, імі_, mpač_,
   {{0x26cf83cd,0xceb400be,0xd83b0196,0x798901b9}},	//   rigo_, ויף_, _вэб_, _ġeww,
   {{0x7d7c010f,0x7aed7506,0xdced408c,0x26cf9c83}},	//   ינדו, loat, _opač, sigo_,
   {{0x7ae48353,0x29030267,0x5c380039,0x69090b80}},	//   čitn, _ihja_, חרון_, _džet,
   {{0xc2458171,0x63a803ba,0x3b09011c,0x7bdc03de}},	//   чник, ødni, nmaq_, יקוו,
   {{0xddc41809,0x3a3f82f7,0x84678081,0xdced0196}},	//   _obiš, raup_, _мъже, _apač,
   {{0x6457a755,0x6d59e8b6,0x44258176,0xdce401b9}},	//   óxid, muwa, _ufl_, _oriġ,
   {{0xf7718277,0xc5e90bea,0x6d59afda,0x291fbed7}},	//   راد_, _עד_, luwa, squa_,
   {{0x7e7982d5,0x195981e2,0xe1ff07f1,0x248584fe}},	//   newp, _гады_, _ozó_, _halm_,
   {{0x6d59b8b6,0x2485f507,0x645c7508,0xeab08c3b}},	//   nuwa, _kalm_, tgri, _جعل_,
   {{0xa50a00b3,0x2eb88d14,0xc21281c6,0x98a001a1}},	//   сега_, _आत्त, _נהג_, mpić_,
   {{0x291d81cd,0x6d599e98,0xddcf0087,0xfce32361}},	//   _huwa_, huwa, tecţ, хоро,
   {{0x291d9aa3,0xa2cc035a,0xdbd788e5,0xee3a02ac}},	//   _kuwa_, _सगळ्, määr, _уни_,
   {{0x3e5b0039,0x6f0401bc,0x201811ee,0x6f1c7509}},	// [7160] _הדפס, _ihic, _pgri_, _surc,
   {{0xb4ca901b,0x6d4620e5,0x6d59ea3b,0x6f1c0039}},	//   _लगे_, mska, duwa, _purc,
   {{0xb4e80076,0x6d461cab,0x7c3e0029,0xe807184a}},	//   यकी_, lska, _iepr, वेला_,
   {{0x2721f50a,0x127a00f7,0xeafa026a,0x6d598041}},	//   _món_, _احدث_, _درخت_, fuwa,
   {{0x6d46088b,0x7c3e750b,0xdbce080a,0x6d5984b9}},	//   nska, _kepr, _bıça, guwa,
   {{0xb4d6853e,0xf7461a1f,0x6286750c,0x6d46750d}},	//   ाचे_, _него, _hako, iska,
   {{0x2ca526a4,0x6286750e,0x248580dd,0x69c402a6}},	//   öldi_, _kako, _dalm_, lzie,
   {{0x6286085d,0x6d599855,0x6d46694a,0x6aa4750f}},	//   _jako, buwa, kska, njif,
   {{0x62865a8f,0x69c47510,0x58868048,0xdced7511}},	//   _mako, nzie, пына, _spač,
   {{0x6d467512,0x62860d8b,0xfca98481,0x27218129}},	//   dska, _lako, _والو_, _bón_,
   {{0xd0418201,0x443e80eb,0x6f040229,0x3d1583b7}},	//   nilə, _iet_, _bhic, _फूटे_,
   {{0x443e9302,0x6286005c,0xa3cd06b7,0x6f04426a}},	//   _het_, _nako, _शेष_, _chic,
   {{0xbcfb003e,0x50b78077,0x443edd05,0xf0b78077}},	//   stém, زدید_, _ket_, زایش_,
   {{0x69c443e3,0x6f0401bc,0x212b81a8,0x272181a8}},	//   dzie, _ehic, íche_, _fón_,
   {{0x443e9302,0x291d83c3,0x6d460359,0x62864461}},	//   _met_, _zuwa_, aska, _bako,
   {{0x443ef513,0x6d5980a4,0xcff783c8,0xd0418085}},	//   _let_, yuwa, _מצוה_, dilə,
   {{0xdd9103f8,0x764d6482,0x3b090085,0xa3cd00c2}},	// [7170] _شود_, _iday, rmaq_, _शेर_,
   {{0x7c3e105d,0x443eb480,0xdddbadad,0x26cd8904}},	//   _gepr, _net_, _nauš, _smeo_,
   {{0x6d5980a4,0x62867514,0xdd02011f,0x69c4180b}},	//   wuwa, _fako, _žućk, azie,
   {{0xae01000f,0x6d59f515,0x7c289151,0x2485f516}},	//   _ईरान_, tuwa, _afdr, _salm_,
   {{0x69091fe9,0x443ecad8,0xe945004e,0x24858833}},	//   _džer, _bet_, _ترجی, _palm_,
   {{0x443eb3a0,0x291d80a4,0x6d59f517,0x752d004f}},	//   _cet_, _ruwa_, ruwa, _mtaz,
   {{0x443e88f8,0x6d5980a4,0x62862122,0x764d0079}},	//   _det_, suwa, _yako, _oday,
   {{0x443e80c9,0x6d461fe2,0x7bc3812b,0x764d34d8}},	//   _eet_, yska, rznu, _nday,
   {{0x27218813,0x443ef518,0xaca30135,0x31697519}},	//   _són_, _fet_, _anọg, ntaz_,
   {{0x443ef51a,0xd90f8065,0x764d751b,0x6f040df6}},	//   _get_, ھیں_, _aday, _shic,
   {{0xdee60003,0x66e60049,0x64438888,0x752d2084}},	//   дони, дона, mani, _ataz,
   {{0x6443f51c,0x443e8a0f,0x7c3e123c,0x6d463139}},	//   lani, _zet_, _sepr, tska,
   {{0xe8ee8193,0x628607dd,0x2b40805c,0x6299837a}},	//   _ал_, _rako, ćice_, _inwo,
   {{0x6d46751d,0x6f04004c,0x6443f51e,0x6286751f}},	//   rska, _whic, nani, _sako,
   {{0x7c3e020f,0x6d461277,0x62861619,0x752d0247}},	//   _vepr, sska, _pako, _etaz,
   {{0xe297002e,0x6d462c15,0x6289f520,0x69c41dc8}},	//   мас_, pska, ndeo, tzie,
   {{0x6443f521,0xf2d2812a,0x672482a5,0x20e184c5}},	// [7180] kani, דען_, _čiji, _पदाध,
   {{0x7ae9003b,0x69c41a69,0x6286412b,0xfd5f001c}},	//   četa, rzie, _wako, _luyệ,
   {{0x6443cb72,0x628629c7,0x443ef522,0x6d498087}},	//   dani, _tako, _ret_, _avea,
   {{0xd0418201,0x443eafac,0xd6d98558,0x2d920168}},	//   rilə, _set_, пті_, _krye_,
   {{0x6443c3fb,0xdce287aa,0xdddba4c8,0x1c2206a7}},	//   fani, stoč, _pauš, _मलाल_,
   {{0x62998edc,0x3e4e801c,0x843880f7,0x16032296}},	//   _anwo, ột_, أكثر_, रेटर_,
   {{0x443ef523,0xf487853d,0xd7f201a8,0xd90d0019}},	//   _vet_, بانی, _شكر_, _ایل_,
   {{0x3e868110,0x29180041,0x225f8b20,0xed5ae336}},	//   _būtų_, _hira_, gguk_, _моб_,
   {{0x29185f67,0x443ef524,0x6457a182,0xfd5f001c}},	//   _kira_, _tet_, óxic, _duyệ,
   {{0xd90d8416,0x291802a3,0xb4e82aef,0x47348c40}},	//   مین_, _jira_, यको_, ннос,
   {{0xf98f803d,0x085704de,0x90570039,0x205700be}},	//   هبی_, ובים_, וסיף_, וייל_,
   {{0x569411d2,0x29181f59,0x3ea6f525,0x7d1700b9}},	//   вают, _lira_, njot_, _sixs,
   {{0x2d84800d,0x6ef880f7,0xe9da9f31,0x2f1a8ec3}},	//   _jsme_, ríbh, _بذات_, _rīgu_,
   {{0x29180091,0x7e640101,0xbca501a8,0x00000000}},	//   _nira_, _ecip, رمزي, --,
   {{0x36d527d4,0xbcfb0174,0x2cac8114,0x38cb8fd3}},	//   _покр, ntéi, _modd_, _بانی_,
   {{0xe1888028,0x34db816f,0x5f040992,0x7640828f}},	//   _kỳ_, _बद्द, _изја, _nemy,
   {{0x7e7d7526,0x34951e4a,0x2bcf0327,0x752d7527}},	// [7190] mesp, _запр, _हेरा, _utaz,
   {{0x6d5d2b72,0x4427007e,0x31696ac3,0x6443f528}},	//   musa, _ün_, rtaz_, xani,
   {{0x6443b5d5,0x291800ad,0x69090024,0xdfd100f7}},	//   vani, _dira_, _džep, ديا_,
   {{0x64438610,0xcf9380be,0x7e7d0b82,0x6b857529}},	//   wani, כטע_, nesp, _ishg,
   {{0x64438d78,0x6d5d752a,0x2918752b,0x6ef629af}},	//   tani, nusa, _fira_, cábu,
   {{0x2918752c,0xd0068065,0xf5928019,0x3949752d}},	//   _gira_, _مل_, الوج, msas_,
   {{0xa3c9825e,0x64438b5d,0x6d5d30e5,0x2cac9106}},	//   _लेख_, rani, husa, _dodd_,
   {{0x7159ac18,0x3a290239,0x29182b17,0x7e7d4913}},	//   прос_, ncap_, _zira_, jesp,
   {{0x7e7d1a47,0xe9d99ff8,0x2cac8114,0x6ea3064a}},	//   desp, яки_, _fodd_, गानु,
   {{0xa3c122f9,0x29180509,0x3949752e,0x7e64752f}},	//   ्छा_, _xira_, isas_, _scip,
   {{0x65760358,0xfd5f001c,0x644181a9,0xe80a86ae}},	//   _spyh, _tuyệ, _ieli, हेला_,
   {{0x39492393,0x6441c631,0x7e7d1781,0xee370d8e}},	//   ksas_, _heli, gesp, нню_,
   {{0x3ead81d8,0x6441f530,0x6d5d7531,0x249a02f7}},	//   _moet_, _keli, gusa, _pnpm_,
   {{0x7afbbd42,0x3156810f,0x6441866b,0x2d92067f}},	//   llut, _ניצן_, _jeli, _vrye_,
   {{0x64419a6e,0xd5b800eb,0xeabf7532,0xa2a6864a}},	//   _meli, ņā_, _blù_, टॉक्,
   {{0xef198063,0x291815d7,0xfd4a0098,0x7afbf533}},	//   _niż_, _sira_, _език_, nlut,
   {{0x6d5d1a4e,0x291869d9,0x2056142e,0xeabf0706}},	// [71a0] cusa, _pira_, етер, _dlù_,
   {{0x6441f534,0xdcfb8042,0x7afbf535,0x6604005d}},	//   _neli, _oruđ, hlut, _izik,
   {{0x29186811,0x7afbf536,0x44380286,0xef1982a6}},	//   _vira_, klut, mbr_, _biż_,
   {{0x291804bf,0x9f580168,0x75208c53,0x3ead87f1}},	//   _wira_, _hyrë_, _pumz, _coet_,
   {{0x6441f537,0x3ead8a0f,0xef198609,0x26c00c53}},	//   _beli, _doet_, _diż_, _mlio_,
   {{0x6441f538,0x224204b7,0x7e7d5759,0xdca391d5}},	//   _celi, _hekk_, zesp, лачи,
   {{0xc5f180c8,0x26c07539,0x7afb808b,0x76462ab7}},	//   জেলা_, _olio_, flut, kaky,
   {{0x224201cd,0x7afb8ce9,0x78200006,0x6d5d020d}},	//   _jekk_, glut, _बलुक_, yusa,
   {{0x63b5009a,0xbcfb5d8b,0x50668a30,0xed579810}},	//   zyzn, stéi, нтна, _пот_,
   {{0x6441f53a,0xd6fb36a6,0x2918c1b6,0x78ae753b}},	//   _geli, ृष्ठ_, öra_, _jobv,
   {{0x7e7d2176,0x0f23a3b2,0x26c00362,0x7e628c53}},	//   tesp, льям, _blio_, ogop,
   {{0x6d5d103b,0x7d1adbab,0x7afbb673,0x22420176}},	//   tusa, _hits, clut, _nekk_,
   {{0xa2c41344,0x7d1af53c,0x6441ba05,0x2746826b}},	//   रसन्, _kits, _yeli, _bíná_,
   {{0x26c000e5,0x7d1d8580,0x2abc046d,0x660402ad}},	//   _elio_, _èsse, _bíbo_, _dzik,
   {{0xf76f8077,0x387ef53d,0x6d5d6c4e,0x7d1af53e}},	//   _هاي_, metr_, susa, _mits,
   {{0x6d5d2b4f,0x7d1af53f,0x39497540,0x442c8af8}},	//   pusa, _lits, tsas_, _lfd_,
   {{0x645a10dd,0xddc98968,0x38c90019,0x224200d9}},	// [71b0] ótic, _obeš, وائی_, _dekk_,
   {{0x7d1af541,0x90280a8e,0x7b158088,0x81e28264}},	//   _nits, ецца_, _ršum, _ধরা_,
   {{0x39497542,0x2242021e,0x798611fd,0x64477543}},	//   ssas_, _fekk_, _eskw, maji,
   {{0x64477544,0xc5d580e8,0x4615803d,0x2242008b}},	//   laji, кіль, نوار, _gekk_,
   {{0x6441b2c7,0x7d1af545,0x3ead837a,0x09db00ab}},	//   _peli, _bits, _voet_, _দরকা,
   {{0x442c88f1,0xd0450201,0x644736d8,0x64418168}},	//   _cfd_, yihə, naji, _qeli,
   {{0x61fc8085,0x7d1a8901,0x672d816b,0x3eada580}},	//   ərli, _dits, _čajo, _toet_,
   {{0x6441f546,0x442cf547,0x628d32ba,0x1db300c2}},	//   _weli, _efd_, ndao, ुनात,
   {{0x64418dc6,0x7afb82f7,0x7d1a9fb2,0x2b40805c}},	//   _teli, rlut, _fits, ćica_,
   {{0x7afb8e23,0x7d1ab82d,0x40959c9b,0x8c3c87c0}},	//   slut, _gits, трит, _boğu,
   {{0x81d700ab,0x629d4b58,0x6f1bf548,0x76467549}},	//   িথি_, _onso, _kiuc, taky,
   {{0x38b60125,0x6d598a0f,0x8c3c817b,0x623598ba}},	//   _væri_, orwa, _doğu, _реду,
   {{0x95990c6e,0x0d9901bb,0x0d83204d,0x764600dd}},	//   нтру_, нтры_, алян, raky,
   {{0x7646754a,0x629d754b,0x395f8a5b,0x628bf54c}},	//   saky, _anso, muus_, _hago,
   {{0x8c431814,0x04430811,0x628bebf3,0x316d80e7}},	//   ресе, ресн, _kago, ltez_,
   {{0x628b9ef3,0x3afa80f1,0xd5b212c8,0x7db604ad}},	//   _jago, tëpi_, _نفع_, _асоц,
   {{0x628b9b61,0x6447754d,0x69c9b007,0x316d8cf8}},	// [71c0] _mago, baji, nzee, ntez_,
   {{0x7ae4803b,0x629d02ec,0x81ac00c8,0x6723f54e}},	//   čiti, _enso, _কেউ_, _kunj,
   {{0x752400f3,0x6723836e,0x7d1af54f,0x6fc1864a}},	//   _huiz, _junj, _rits, शनिं,
   {{0x6f09f550,0x6aa98024,0x672d826c,0x7d1acbd4}},	//   _chec, jjef, _čajl, _sits,
   {{0x7d1af551,0x6f1b9295,0x6d4bf552,0x64a69a18}},	//   _pits, _diuc, gsga, када,
   {{0x628b82c4,0x752472b6,0xdce982a6,0xc0450e06}},	//   _aago, _muiz, _preġ, _مخفو,
   {{0x44447553,0x628bc81a,0x07a307a1,0x67238642}},	//   _me_, _bago, _карн, _nunj,
   {{0x44447554,0xbcfb0019,0x661b2cf6,0xe7eb06a7}},	//   _le_, ltét, žuki, _जुटा_,
   {{0xf2d30bea,0x628b811e,0x44442cad,0xc05a8a18}},	//   יעה_, _dago, _oe_, мін_,
   {{0x7d1aa468,0x1bed8006,0x7aed826c,0x628b85ee}},	//   _uits, _चुकल_, čata, _eago,
   {{0xa0a38196,0x6aa98144,0x2fc98326,0x64477555}},	//   ршыл, bjef, _ƙaga_, vaji,
   {{0x67238699,0x628bedb2,0x44447556,0x26c6808e}},	//   _dunj, _gago, _ae_, nhoo_,
   {{0x4444073a,0x64477557,0x316d82be,0x6280f558}},	//   _be_, taji, ctez_, memo,
   {{0x44447559,0x628b912b,0x6280e43e,0x752400f3}},	//   _ce_, _zago, lemo, _duiz,
   {{0x64475d98,0xa3cd01aa,0x56950b69,0x628bb29c}},	//   raji, _शेख_, _байт, _yago,
   {{0x44446302,0x6280c0b7,0x6447755a,0xf2c405a8}},	//   _ee_, nemo, saji, асун,
   {{0x4444755b,0x8cb3801b,0x26d9005d,0x7524755c}},	// [71d0] _fe_, _अवलो, miso_, _guiz,
   {{0x4444755d,0x26d9140a,0x6f09826c,0x628081e5}},	//   _ge_, liso_, _shec, hemo,
   {{0x6280cffe,0x15f4053d,0x2d9d0118,0xa5c7008b}},	//   kemo, _مسیح, _áweb_, _fróð,
   {{0xf7738158,0x26d9029b,0x291cf55e,0x6d4b874d}},	//   יקע_, niso_, _liva_, tsga,
   {{0x4444755f,0x644545ee,0x2249079f,0xed5991b3}},	//   _ye_, _kehi, maak_, хол_,
   {{0x40341525,0x44440104,0x628b8461,0x395f8198}},	//   _верс, _xe_, _sago, vuus_,
   {{0x628bee07,0x58d40767,0x6f09f560,0xdce080eb}},	//   _pago, _торт, _thec, _apmē,
   {{0xc2070b85,0xc3340051,0x64453111,0x316d80e7}},	//   _शराब_, בוק_, _lehi, ttez_,
   {{0xbcfb0065,0xdb150019,0x291ca010,0x26d91268}},	//   ntés, gyzé, _biva_, diso_,
   {{0x61fd7228,0x316df561,0x628ba65a,0x69c9890d}},	//   _mysl, rtez_, _wago, rzee,
   {{0x44440051,0x628bf562,0xca758a41,0x628090dd}},	//   _re_, _tago, _булы, bemo,
   {{0xed5a3d00,0x628090dd,0xcfc500c8,0x44217563}},	//   ном_, cemo, _এখান, _agh_,
   {{0x44447564,0x75240018,0x64451d94,0xe0df06c4}},	//   _pe_, _quiz, _behi, _gwòg_,
   {{0x44440b18,0x6723f565,0xbfb5bdf2,0x291cb33e}},	//   _qe_, _tunj, _محبت, _giva_,
   {{0x44447566,0xb5fb0065,0x394df567,0x7ae48353}},	//   _ve_, lgál, lses_, čitv,
   {{0x4444004c,0x26d91a4e,0x394d82e6,0x0e66223c}},	//   _we_, ciso_, oses_, _скин,
   {{0x44447568,0x3ea02651,0x394d85ef,0x64457569}},	// [71e0] _te_, _init_, nses_, _fehi,
   {{0x4444756a,0x7e69928e,0x644500ad,0xe1f73d00}},	//   _ue_, _acep, _gehi, угу_,
   {{0x3ea01c4f,0x657b82d5,0x22491a69,0xf8bf0580}},	//   _knit_, _apuh, baak_, _atés_,
   {{0xfaa61240,0xf2a618f6,0x394d81bf,0x628084c3}},	//   _само, _симп, kses_, xemo,
   {{0x62808548,0x7ae4756b,0x3ea0008e,0x7d1e62e3}},	//   vemo, mnit, _mnit_, _kips,
   {{0x7ae4756c,0xbcfb0061,0x53348110,0x690b002a}},	//   lnit, ltér, аект, güed,
   {{0x6280a515,0x27f7003e,0x09dc903e,0x394dd7cb}},	//   temo, čené_, मप्य, eses_,
   {{0x7ae40a92,0x7d1e002e,0x969585c2,0x8c3c880a}},	//   nnit, _lips, _круш, _coğr,
   {{0x8c3c82bb,0x26d90098,0x200780b9,0x7ae47142}},	//   _doğr, viso_, _azni_, init,
   {{0x7ae4756d,0x22490fbc,0x20c0851e,0x3ea0756e}},	//   hnit, zaak_, _eòin_, _anit_,
   {{0x7ae40bc8,0x64450cf4,0x644ae018,0x290280eb}},	//   knit, _rehi, mafi, ēka_,
   {{0x64451a6e,0x2f9703de,0x656f0799,0x61469073}},	//   _sehi, אכטן_, ttch, _беда,
   {{0x442102c4,0x25bf0019,0x26d9756f,0x7ae47570}},	//   _pgh_, ául_, riso_, dnit,
   {{0x40349515,0x5f948e8e,0x644af571,0x656f7572}},	//   _текс, _викт, nafi, rtch,
   {{0xd6d10c2a,0x60da8458,0x7792815b,0x2246808e}},	//   _وقت_, mitm, _ایجا, _keok_,
   {{0xfebb0077,0xa6ab0277,0x5a35013a,0x59d98540}},	//   _ساعت_, _سابق_, рнат, _बेडर,
   {{0x224900c9,0x644a9b61,0x442103ac,0x200b809a}},	// [71f0] raak_, kafi, _tgh_, ęcie_,
   {{0x04671b56,0x44211a34,0x61fd026f,0x7ae47573}},	//   _стим, _ugh_, _vysl, anit,
   {{0x64578510,0x644af574,0xf80706d2,0x672d9320}},	//   óxim, dafi, учан, _čajk,
   {{0x66f70bb8,0xbcfb7575,0x6d5d7576,0x394d84dc}},	//   ीतिक_, ctér, orsa, yses_,
   {{0xe5a59a3b,0x6d4f00f7,0xa2ba0935,0x212900dd}},	//   рили, nsca, _एकत्, qqah_,
   {{0x644af577,0xd7fb4a8a,0x00000000,0x00000000}},	//   gafi, _зуб_, --, --,
   {{0x38b6035f,0x628f0704,0x6d5d0799,0x60daa786}},	//   _vært_, _kaco, hrsa, ditm,
   {{0x290101cd,0x6d5d0042,0x6f0d7578,0x394dd292}},	//   llha_, krsa, _nhac, tses_,
   {{0x91e5a2e9,0x645e8228,0x672704b9,0x394df579}},	//   ропе, ópic, _hujj, uses_,
   {{0x764bf57a,0x394d8b39,0x3a2d81a1,0x6f0d018e}},	//   lagy, rses_, scep_, _ahac,
   {{0x394d8806,0x7d1e2eac,0x6f0d0219,0x672709ab}},	//   sses_, _rips, _bhac, _jujj,
   {{0x6f0d757b,0x89d695e4,0xe1ff0144,0x7d1e757c}},	//   _chac, اویر_, _oyó_, _sips,
   {{0x6f0d757d,0xcb128051,0x7ae4826c,0xf50611d5}},	//   _dhac, _ולא_, čitt, измо,
   {{0x764bdf11,0xb4c20f85,0x6609912e,0x60da8965}},	//   hagy, ्फे_, _mzek, citm,
   {{0x6d5d6290,0xbcfb28d6,0x6f0d0c49,0x6d4f757e}},	//   arsa, ttér, _fhac, asca,
   {{0x6f0d757f,0xd13201a8,0x3ea001c6,0x6aad008b}},	//   _ghac, قمر_, _unit_, gjaf,
   {{0x7d1e0502,0x628f02b7,0x2d8c00eb,0x7ae40ca9}},	// [7200] _tips, _daco, ādes_, rnit,
   {{0xe3ba0112,0xbcfb7580,0x67270c2e,0xa5bb268b}},	//   _або_, stér, _bujj, rcót,
   {{0x5c5b0051,0x628f7581,0xb4c2236c,0xbcfb0c83}},	//   _בדיק, _faco, ंसी_, ptér,
   {{0x539b0039,0x628f10e4,0x6d440035,0x644ab943}},	//   _סיכו, _gaco, _kwia, wafi,
   {{0x66098063,0x7aed82a5,0x644af582,0x7bce37e9}},	//   _czek, čatl, tafi, lzbu,
   {{0xd37af583,0x224682f7,0xc448803d,0xd9430f80}},	//   вчи_, _seok_, ایان_, _фери,
   {{0x6609f584,0x69dd81ac,0xf2c681a1,0x672703f7}},	//   _ezek, úsen, исин, _gujj,
   {{0x644ac095,0xbcfb4395,0x628f01df,0x6e24303d}},	//   safi, prég, _xaco, _ngib,
   {{0x60f88098,0xaca40032,0x644aae08,0x63bc18b6}},	//   лния_, _arọw, pafi, hyrn,
   {{0x6d5d02a5,0x6f02a898,0x8c66826a,0x7ae901f4}},	//   vrsa, lloc, _خطرن, četi,
   {{0x627e0035,0xe811864a,0x6f0d7585,0x3f98816b}},	//   _złoż, डेला_, _phac, íru_,
   {{0xaca4019d,0x6448f586,0x98ab80eb,0x7bdb81c6}},	//   _drọw, _hedi, īcā_, _בקבו,
   {{0x628f24d2,0xe8948b73,0x9934806b,0xa1588bda}},	//   _raco, _галь, _افتت, _салу_,
   {{0x644890d1,0x628f29f2,0x6d4f0f35,0x91bb81c6}},	//   _jedi, _saco, rsca, _במדי,
   {{0x6f0d54d9,0x628f7587,0x6aa2f588,0xd9e880ab}},	//   _thac, _paco, _knof, _পরিম,
   {{0x64489da3,0x1b1911e9,0x8aa415b5,0x6f028087}},	//   _ledi, ужбы_, оруд, jloc,
   {{0x6d44009a,0x51871454,0x672d826c,0x2005467b}},	// [7210] _gwia, шува, _čaji, _šli_,
   {{0x92d700c8,0x6448f589,0xd9e880ab,0x4ddc0039}},	//   াকে_, _nedi, _পরাম, _שחזו,
   {{0x33950013,0x628f7325,0x66098061,0xb60804e8}},	//   _الجز, _taco, _szek, _tuší,
   {{0x2b5e128a,0x99890824,0x628402df,0x66c6758a}},	//   átce_, mbaž_, ceio, _kóka,
   {{0x6448a389,0x9a128133,0x764b997c,0x356b9156}},	//   _bedi, _dọkụ, ragy, трен_,
   {{0xdfc6f58b,0x04428767,0x6448adb0,0x8c42898d}},	//   _في_, пешн, _cedi, пеше,
   {{0xde678098,0xbcfb0866,0xe8d90133,0x7afd0af8}},	//   _възп, crée, gwụ_, _kkst,
   {{0x6f02f58c,0xa7fc82d0,0x66098cdb,0x3a98862c}},	//   cloc, rgıl, _tzek, атью_,
   {{0x7e7b8caa,0xe8f9a7d8,0xa2ba152c,0x627e066f}},	//   _ibup, лли_, _एकस्, _ułoż,
   {{0x6448f58d,0x26dd82ec,0x60d883a8,0x66d6007a}},	//   _gedi, liwo_, _cmvm, mški,
   {{0x25db85e8,0x34948b69,0x7ae481a1,0x2cf58072}},	//   _खेती_, _фахр, čitr, ेतील_,
   {{0x66c6007b,0x26dd8e80,0x5b158226,0x7bce016b}},	//   _bóka, niwo_, _умет, vzbu,
   {{0xa2a48ebf,0x7529ec65,0x7e7b8133,0x6448dfad}},	//   कार्, _juez, _mbup, _yedi,
   {{0x764982a3,0x66d60110,0x7bce3c0f,0xa5da80be}},	//   _leey, iški, tzbu, אַלי,
   {{0xdce2805c,0x7e7be38f,0x78a3b4ff,0xa3aa8697}},	//   stoć, _obup, _innv, खमय_,
   {{0x443301c0,0x86465a7c,0xd49180ff,0x7c2500b9}},	//   _efx_, _униж, _là_, _eghr,
   {{0x95560bbe,0x6d44758e,0x463b03de,0x26dd8326}},	// [7220] _اخبا, _uwia, _געפע, diwo_,
   {{0x7afd758f,0x6566076d,0xb4db0722,0x6c8600f7}},	//   _ekst, mukh, ssàr, _الدم,
   {{0x78b50289,0x6448d547,0x644e7590,0xee3a9a1f}},	//   _dozv, _redi, mabi, гне_,
   {{0x644e7591,0x6448ef94,0x61e904c4,0xf4130051}},	//   labi, _sedi, _žele, _מפת_,
   {{0x1dd2800f,0x673b005c,0x6448a88b,0x22407592}},	//   _देखत, _čuje, _pedi, mbik_,
   {{0x6fca823c,0x644e7593,0x7e7baa34,0x6f02c11c}},	//   ानमं, nabi, _ebup, sloc,
   {{0x6448d69a,0x09b580ab,0xdb09826f,0x6f02d5d8}},	//   _vedi, _জেলা, žnýc, ploc,
   {{0x6566005d,0x4425f594,0x76498def,0xdd2d0084}},	//   kukh, _egl_, _geey, vėžy,
   {{0x644e7595,0x41de001b,0x75298118,0x39525100}},	//   kabi, _नेमस, _guez, nsys_,
   {{0x7e6d26e8,0xd90d80d5,0xfbc80540,0xa2d80a27}},	//   _scap, نین_, रनाम, नोत्,
   {{0x2d800a8e,0x644e4eae,0xda7a8081,0xa507cdbf}},	//   _apie_, dabi, _бял_, _уефа_,
   {{0x490f0d86,0xcebb0326,0xb5fb01a8,0x41d9a64d}},	//   _तीनो_, _kuƙi_, lgái, _बेवस,
   {{0x200b8063,0x3a268580,0xd7c780d7,0x26c783ed}},	//   ęcia_, _igop_, لویه_, ënoi_,
   {{0x1fa69109,0x6ce73941,0x316015a0,0x26cb18bd}},	//   _григ, сіме, driz_, shco_,
   {{0x78b5003e,0xf8db8039,0x2a69008e,0x2419076a}},	//   _rozv, _תחומ, tgab_, ровы_,
   {{0x7e6d386a,0x65660234,0x7b1585f3,0xada601d6}},	//   _ucap, bukh, _ušut, _spúš,
   {{0x7c2500b9,0x2d99841c,0xa2da001b,0xcfd60264}},	// [7230] _tghr, _àsex_, _नगर्, _তুলন,
   {{0x644e345a,0x660d1768,0x764f0035,0x9055004a}},	//   cabi, _izak, lacy, івец,
   {{0x7bde92ca,0xddcd0035,0x752988dc,0x22406abb}},	//   úpul, _udał, _suez, bbik_,
   {{0x764f7596,0x8f9b81c6,0x3f9c80fe,0x395f8084}},	//   nacy, טיבי, _mrvu_, yrus_,
   {{0x98c50214,0x316001e8,0x94258721,0x61e4f597}},	//   ştır_, criz_, омле, _žiln,
   {{0x76499a2b,0x66d60110,0x60c701a1,0x224b4ef7}},	//   _weey, rški, _uljm, _heck_,
   {{0x3ea49727,0xd49180ff,0x764f009a,0x4425f598}},	//   _fnmt_, _và_, kacy, _vgl_,
   {{0x644e7599,0xcfb200ab,0x7b158267,0x6b830187}},	//   zabi, _টেকন, _ašur, _ângu,
   {{0x4425861b,0x644e1382,0x0595803d,0x7e6481a8}},	//   _tgl_, yabi, _بازگ, óipe,
   {{0xf77187bd,0x212b0051,0xe0d9a3a4,0x4431811c}},	//   واج_, _much_, рво_, _üz_,
   {{0x644e0e7b,0xd0098193,0x16aa038d,0xb69b0187}},	//   vabi, рене_, авни_, rlân,
   {{0x644e2eb9,0x764f759a,0x395ff59b,0x3f9c80c3}},	//   wabi, gacy, prus_, _drvu_,
   {{0x644e759c,0x7afb8e35,0x61ed8503,0xa50a15a6}},	//   tabi, mout, _žalf, иема_,
   {{0x7ae9f59d,0x660d01a1,0x2eb68035,0x66d0026b}},	//   lnet, _dzak, _अक्त, _bòkù,
   {{0x212b0943,0xa5bb2602,0x36e90019,0x660d41b5}},	//   _auch_, scóp, _گروپ_, _ezak,
   {{0x7ae990c3,0x3160275e,0x212b01ec,0x644e4617}},	//   nnet, triz_, _buch_, sabi,
   {{0xe0da14b7,0x644e759e,0x7ae9d3d7,0x2b40811f}},	// [7240] ава_, pabi, inet, ćici_,
   {{0x3160011e,0x6604759f,0x212b0a7a,0x7afbf5a0}},	//   rriz_, _iyik, _duch_, hout,
   {{0x212b02af,0x2905f5a1,0x7afbf5a2,0xd7ff0162}},	//   _euch_, illa_, kout, _ţări_,
   {{0x28d99094,0xe29a1269,0x2eb9816f,0xbcfb00e7}},	//   योति, _там_, _आवृत, préc,
   {{0x7ae9936f,0x94aaa865,0xddcd009a,0x7afbf5a3}},	//   dnet, итка_, _gdań, dout,
   {{0xd0e8004e,0x7ae9811b,0x659b0e82,0x764f75a4}},	//   _اکرم_, enet, יינק, zacy,
   {{0xf76791fb,0xd4678b30,0x7afbf5a5,0x1fb56336}},	//   _تا_, ције_, fout, _естр,
   {{0x2905f5a6,0x7afbf5a7,0x6738826c,0x62965759}},	//   ella_, gout, _rtvj, ndyo,
   {{0xcb131a15,0x045a826a,0x764f00f3,0x68fa8087}},	//   ולה_, _نجات_, vacy, totd,
   {{0x3f9c803a,0x1d0a8698,0x26c902a5,0xb17b03de}},	//   _prvu_, _тези_, _slao_, סטיר,
   {{0x660d0065,0x7afbec9b,0x7ae9dab4,0xa09b00be}},	//   _szak, bout, bnet, בייט,
   {{0x99e880ab,0x29058009,0xd6db3f4b,0x7642f5a8}},	//   _পরীক, alla_, рто_, nboy,
   {{0x764f1111,0xf6538039,0x67240590,0x2bde950e}},	//   racy, וצר_, _diij, _केतू_,
   {{0x7ae0f5a9,0x61ed8110,0x02b800d4,0x6fb681a8}},	//   limt, _žalg, _इकॉन, _ومشا,
   {{0x57f3838c,0x212b75aa,0x53340adb,0x224b75ab}},	//   _општ, _such_, дест, _peck_,
   {{0x690b009f,0x25a6007a,0x7982819d,0xb88281d0}},	//   güen, _šole_, _kpow, řídi,
   {{0x69c0dc0a,0x660d75ac,0x645a80e1,0xd52d027d}},	// [7250] nyme, _uzak, _odti, _dựn,
   {{0xf8070f16,0xcf9b0b30,0x7ae08e9d,0x7ae9801b}},	//   очен, ије_, himt, znet,
   {{0x764d00b9,0x7d07026c,0x7ae9a4ba,0x37ab1a21}},	//   _keay, mljs, ynet, штан_,
   {{0x0f7b8039,0x7982809a,0x645a8748,0xe8a78c2d}},	//   שראל, _opow, _adti, _कच्च,
   {{0xa3df0e1a,0x2905f5ad,0xdca58468,0xf53f01a3}},	//   _देत_, ylla_, зали, npå_,
   {{0x91ba0039,0x69c0b577,0xd7ca8072,0xab9800d7}},	//   _המשי, dyme, ानाच, _اخیر_,
   {{0x447c0158,0x7982826b,0x7afb814f,0xdcfb8140}},	//   ינגע, _apow, tout, _upuč,
   {{0xd2a98364,0xfbd0803d,0xe7fe8105,0xdffe83b7}},	//   ские_, خته_, _उड़ा_, _उड़द_,
   {{0xa3db8b85,0xaca381bc,0x213980f1,0x2905f5ae}},	//   _ढेर_, _ahụl, ësh_, tlla_,
   {{0x7ae9f5af,0x6d4980fc,0x88c98389,0x98bd6efe}},	//   snet, _iwea, слов_, ोसिए,
   {{0xb8e392e0,0x07a58b73,0x660400b9,0x7ae9cf66}},	//   _एक_, чанн, _syik, pnet,
   {{0xe298835f,0x752d05ee,0x6a94804a,0x3f830af8}},	//   _має_, _buaz, _оріє, _mpju_,
   {{0xe0cea619,0x6b5080f7,0x7ebf03ed,0x3eab136f}},	//   _зв_, _tógá, _nëpu, _šité_,
   {{0x213f859c,0x40878992,0x913a8039,0x69d490f7}},	//   mpuh_, _фудб, _העסק, _बेटी,
   {{0x68e1f5b0,0xf99f6289,0x6e298326,0x99dd816b}},	//   mild, _arè_, _ogeb, raňu,
   {{0x8b23039d,0x6e29f5b1,0x61e975b2,0x28de103e}},	//   едсе, _ngeb, _žela, फोनि,
   {{0xf983620b,0x798d75b3,0x753b862b,0xf99f010c}},	// [7260] нгто, gwaw, _ntuz, _crè_,
   {{0x765bf5b4,0x6e29838a,0xb4662f84,0x68e1b8ad}},	//   _aduy, _ageb, _экол, nild,
   {{0x753bb1f8,0xf99f03ec,0x752d1fe7,0x66e69c64}},	//   _atuz, _erè_, _zuaz, пожа,
   {{0x68e18d35,0x690b07e0,0xf99f0247,0x798d0365}},	//   hild, qüen, _frè_, bwaw,
   {{0x68e19739,0xa50a867c,0x1d0a8ae7,0xe29b01c6}},	//   kild, беда_, беди_, _השכר,
   {{0x394026f4,0x7afb007a,0x2d9203ec,0x6562f5b5}},	//   mpis_, čute, _msye_, rroh,
   {{0x6fb60b76,0x79828035,0xbcfb0061,0x68e1a353}},	//   _عمرا, _spow, krén, dild,
   {{0x994c0038,0x78b8e070,0x66c6008b,0x6562f5b6}},	//   _môže_, _sovv, _bókm, proh,
   {{0x672e026c,0x64438106,0x7ae0dd05,0x2d9ff5b7}},	//   _hubj, bbni, rimt, _grue_,
   {{0xbf0505fc,0x26c6f5b8,0x7ae0b978,0xd90e803d}},	//   रत्न_, lkoo_, simt, دیت_,
   {{0xb4e8816f,0x25a000b9,0xb2268049,0x7d070267}},	//   मची_, _aril_, _емел, vljs,
   {{0x6b9c012b,0x25a0110f,0x0b0000ab,0xe0df0176}},	//   dvrg, _bril_, ্দুল_, _awòl_,
   {{0x68e1d062,0x91d4a78a,0x68fe0a0f,0xaaa9801b}},	//   bild, _बेचै, kopd, कारक,
   {{0x013783c8,0xf53f01a3,0x690b0118,0x2ceb497a}},	//   _צרות_, rpå_, güel, сьмо_,
   {{0xa87b8039,0x187b8039,0xd25b0fe6,0xe0df0242}},	//   _האור, _הטוב, йца_, _dwòl_,
   {{0x59de0fce,0x3d23046d,0xbcfb0061,0x31690cdb}},	//   _नेहर, _béwì_, ntéz, tuaz_,
   {{0x44f510f8,0xc2c400f7,0x394000e4,0x98b9041c}},	// [7270] _опис, ريكي, gpis_, олат_,
   {{0x7e7d1254,0x798d14d9,0x66f201a9,0x6e298362}},	//   lfsp, rwaw, māka, _sgeb,
   {{0x2fc70104,0x66f200eb,0x753bf5b9,0x41c881d0}},	//   áng_, lāka, _stuz, ाईँस,
   {{0xa63480e8,0xf99f06c0,0xd0920085,0x68e18965}},	//   енці, _trè_, _müəs, zild,
   {{0x7aed03c3,0xfe70803f,0x3d09816f,0x66f200eb}},	//   mnat, ادم_, ितले_, nāka,
   {{0x2fc70104,0x2bde8006,0x83399156,0x39590216}},	//   ơng_, _केहू_, очит_, _ivss_,
   {{0x6443f5ba,0x20c9807b,0xddc2c679,0xe45081a8}},	//   rbni, _búin_, rgoš, اضه_,
   {{0x7aed2141,0x5694a7d6,0x2480805c,0x6d49c799}},	//   nnat, _паст, đima_, _twea,
   {{0x61ed805c,0xf4879b1c,0xac278d94,0xa3df0074}},	//   _žalb, _нужн, _ефек, _देस_,
   {{0x629d81ac,0x3ea90722,0x3b090359,0x7aed0428}},	//   ôsob, _anat_, hlaq_, hnat,
   {{0x68e1817b,0x3e8a15a6,0x656bf5bb,0x39402840}},	//   rild, ойно_, lugh, zpis_,
   {{0x32e386c0,0x68e1f5bc,0x3940008b,0xee370d55}},	//   _dèyè_, sild, ypis_, мню_,
   {{0x68e18612,0x7bc3828f,0x66f201a9,0x7afc8061}},	//   pild, lynu, gāka, _írta,
   {{0xa3df01b6,0xe8f8b941,0x7aed75bd,0x2bd1975d}},	//   _देह_, _елі_, enat, तनपा,
   {{0x02c90076,0xeb9728b4,0xbcfb75be,0x26cdb93d}},	//   रसंभ, мир_, prén, _oleo_,
   {{0x7aed2127,0x3940005c,0x2127801c,0x66f200eb}},	//   gnat, tpis_, _hinh_, bāka,
   {{0x21278104,0x09e30391,0xa3e48540,0x672e35cf}},	// [7280] _kinh_, вотн, _पेन_, _subj,
   {{0xdcfb803b,0x7aed0a4f,0xa3df0744,0x3ea90639}},	//   _osuđ, anat, _देव_, _znat_,
   {{0x21278028,0x443a75bf,0x68fe0bfd,0x212ff5c0}},	//   _minh_, _ifp_, ropd, _lugh_,
   {{0x21278028,0x67000bb8,0x273380ff,0x39406fd4}},	//   _linh_, ैतिक_, _mãn_, ppis_,
   {{0x7ae475c1,0xb5fb0019,0x471b03de,0x20561eb5}},	//   miit, lgár, קונג, _отвр,
   {{0x7ae4043d,0x2127801c,0xb4e8816f,0xed59016b}},	//   liit, _ninh_, मचे_, áži_,
   {{0x201e0324,0x9f88007b,0x6f0406ec,0xd8233b78}},	//   _àti_, _góða_, _okic, _адри,
   {{0x6b830106,0xdce6016b,0x78bc34fa,0x21278362}},	//   _änge, dukč, _horv, _ainh_,
   {{0x645e06b9,0x78bc156e,0x2127801c,0x69c474c8}},	//   _odpi, _korv, _binh_, nyie,
   {{0x7aed003a,0x7ae475c2,0x443a3989,0x6f043c86}},	//   znat, hiit, _nfp_, _akic,
   {{0x20c980f7,0x2127801c,0x442c808e,0x7aed75c3}},	//   _iúil_, _dinh_, _igd_, ynat,
   {{0xa1c687eb,0x25a60353,0x752880cd,0x66f200eb}},	//   _обед, _šola_, _hidz, tāka,
   {{0x7aed0988,0x6282f5c4,0x20078085,0x78bc067f}},	//   vnat, _iboo, _eyni_, _oorv,
   {{0x66f200eb,0xf76f80d7,0x61e902d4,0xf4840469}},	//   rāka, دای_, _želo, кусн,
   {{0xa3df0935,0x3b0902a6,0x25ad0493,0xc059b941}},	//   _देश_, tlaq_, ţel_, _хіі_,
   {{0x7ce908ae,0x2bb6805e,0x3ea902d5,0x326475c5}},	//   džre, _अपना, _unat_, ктув,
   {{0x7aed75c6,0x2bff0fcc,0xaca30870,0xa3df0740}},	// [7290] rnat, _शुरू_, _abụg, _देर_,
   {{0x21278028,0x273704b7,0x7528dbf7,0x62828122}},	//   _xinh_, _aħna_, _nidz, _lboo,
   {{0x645575c7,0x7d0510e1,0x78bc0bfe,0x6d4d1d26}},	//   mazi, _ikhs, _dorv, _hwaa,
   {{0xa29e800d,0x6d4d44b8,0x7c3abe02,0x7528808e}},	//   _खोल्, _kwaa, _aftr, _aidz,
   {{0x78bc52fd,0xca240d9e,0x442cf5c8,0x6e2d0122}},	//   _forv, _афри, _bgd_, _mgab,
   {{0x645575c9,0xeb99e368,0x6282a5d5,0x8b958eef}},	//   nazi, зик_, _aboo, ерич,
   {{0x780d8cf0,0xa3ca8327,0x21278129,0x6d4d0c2e}},	//   _हरेक_, रैल_, _rinh_, _lwaa,
   {{0x21278104,0x6e2d2cf2,0x2d4d027f,0x2901026f}},	//   _sinh_, _ngab, kže_, loha_,
   {{0x15f3b432,0x645575ca,0x68ef8511,0x6abd75cb}},	//   _आखिर_, kazi, écdo, _mosf,
   {{0x6f041918,0x2d4d30d5,0xb4be0006,0x6e2d13b6}},	//   _skic, dže_, _आवे_, _agab,
   {{0x6455697e,0x6d4d4a65,0x2127801c,0x6609808e}},	//   dazi, _awaa, _vinh_, _hyek,
   {{0x6282846d,0x7ac488ed,0x61ea8061,0xa5bb0216}},	//   _gboo, _исче, ámlá, lcóy,
   {{0x67298063,0x21278028,0x6d59800b,0xe9ce9b56}},	//   _miej, _tinh_, nswa, _ск_,
   {{0x6d4d0cda,0xbebd81e2,0x6f1d6dd9,0x2b91826c}},	//   _dwaa, _siūl, amsc, _kšc_,
   {{0x6299f5cc,0x6abd0b80,0xdee62361,0x443a0037}},	//   _kawo, _bosf, _поки, _vfp_,
   {{0x78bc75cd,0x629bf5ce,0x61e481ac,0x6729a1f3}},	//   _sorv, nduo, _žili, _niej,
   {{0xe9da1c74,0x64a6618f,0xdca61240,0x64551898}},	// [72a0] чка_, _запа, _запи, bazi,
   {{0x64550698,0xc05900e8,0x6299f01f,0xdce281b9}},	//   cazi, дії_, _lawo, rroċ,
   {{0x6d4d0a0f,0x75288abf,0x9e66916b,0x66098234}},	//   _zwaa, _ridz, евед, _ayek,
   {{0x6299f5cf,0xd0418201,0x20c980f7,0x481680be}},	//   _nawo, rhlə, _súil_, ײַבן_,
   {{0xe5a39285,0x442cec89,0xdd94853b,0x6594a662}},	//   лици, _pgd_, талы, талу,
   {{0x2480817f,0x6e3b838a,0x66098176,0xf99f0242}},	//   đimo_, _efub, _dyek, _myèl_,
   {{0x7ac68009,0x2ca7002a,0x6299f5d0,0x752881a9}},	//   еспе, _ónde_, _bawo, _vidz,
   {{0x7528809a,0x645575d1,0xd25080f7,0x629bf035}},	//   _widz, zazi, جنة_, gduo,
   {{0x6299f5d2,0x645575d3,0x4c86a79e,0x6d598c93}},	//   _dawo, yazi, _плав, cswa,
   {{0xa3c2005e,0xeb9a89a5,0xbcfb1de2,0xd7fa8ce5}},	//   ्ना_, _низ_, trém, зум_,
   {{0xa3df0063,0x64551ab6,0x6d4d01b0,0x2cacf5d4}},	//   _दें_, vazi, _swaa, _indd_,
   {{0x645511b7,0x56941afd,0x6299c2da,0xf99f02d6}},	//   wazi, гают, _gawo, _byèl_,
   {{0x645575d5,0x7ae28aba,0x2918022b,0x6f1d0865}},	//   tazi, _imot, _ohra_, rmsc,
   {{0x7ae2803e,0x2d4d0042,0x6299809a,0xdce2826f}},	//   _hmot, rže_, _zawo, kroč,
   {{0x64552836,0x6299801d,0xa73781a8,0x7b058118}},	//   razi, _yawo, _كثير_, cóus,
   {{0xdce28353,0x645575d6,0x291802f7,0x290cf5d7}},	//   droč, sazi, _ahra_, llda_,
   {{0x645575d8,0xe9f80163,0x290175d9,0x69d682d0}},	// [72b0] pazi, енті_, toha_, _üyed,
   {{0x629b8084,0xe4e5909b,0x67299c43,0x657d75da}},	//   zduo, _औषधि_, _siej, mtsh,
   {{0xec360051,0x660987cf,0x6d4088db,0xe81c150e}},	//   _באתר_, _syek, _atma, भेला_,
   {{0x6d59f5db,0xf4120039,0x291802c4,0xb8c82774}},	//   tswa, _כפי_, _ehra_, _खो_,
   {{0x9f5c8364,0x672985a4,0x657d005d,0x656f054a}},	//   _hyvä_, _viej, ntsh, nuch,
   {{0xdce2dd99,0x6299ac5a,0x6d59d4a3,0xbcfb0144}},	//   broč, _sawo, rswa, mués,
   {{0x6d59f5dc,0x09c9816f,0x6299dfa2,0x6d40f5dd}},	//   sswa, िन्य, _pawo, _etma,
   {{0x656f75de,0xada680e1,0xeab180f7,0x290cf5df}},	//   kuch, _slúž, شعب_, elda_,
   {{0x629b81e2,0x36d48009,0x3eadf5e0,0x656f019d}},	//   rduo, _сотр, _inet_, juch,
   {{0xa3d103b7,0x656f003e,0x3ebf8fb0,0x25a6007a}},	//   वना_, duch, _hout_, _šolo_,
   {{0x366a1511,0x644bb70f,0x3ebf86c0,0xf99f06c0}},	//   мано_, čnič, _kout_, _syèl_,
   {{0x656f75e1,0xed5a2d49,0xdee60bc7,0xfe7201a8}},	//   fuch, мом_, томи, جدد_,
   {{0x316d82be,0x3eadf5e2,0xf1d98035,0x3ebf8299}},	//   quez_, _mnet_, _बेचन, _mout_,
   {{0x7d0397bb,0x71d6807c,0x7ae28f28,0x316975e3}},	//   nons, _בונד_, _zmot, draz_,
   {{0xe7e1035a,0xe7b282e3,0x3eadf5e4,0x6d400177}},	//   _गेला_, _نمود, _onet_, ímab,
   {{0xc3328bea,0x656f5820,0x212a125b,0x657d1d3e}},	//   שון_, buch, _sibh_, btsh,
   {{0x656f00ab,0x3b0701f3,0xeabf00ff,0x0eaf064a}},	// [72c0] cuch, тето_, _giùm_, टारड,
   {{0x07a605e9,0x7d0380e8,0x3ebf92b6,0xe0431777}},	//   казн, jons, _aout_, инуи,
   {{0x7d03b4e6,0x3ebf9b33,0x6d4082a6,0xa3df0b49}},	//   dons, _bout_, _stma, _देऊ_,
   {{0xcfa90013,0x31696a14,0xdd1101d0,0x3ebff5e5}},	//   عالم_, braz_, mýšl, _cout_,
   {{0x29078e3a,0x7d03f5e6,0x3ebf83ec,0x6f0282ed}},	//   _okna_, fons, _dout_, rooc,
   {{0x7d03c2ab,0x26c00118,0x7ae2a9b4,0x50436336}},	//   gons, _loio_, _smot, _верб,
   {{0x3ebfe2cc,0xa3e803b7,0x7e0f01a2,0x656f724b}},	//   _fout_, _मेम_, _सर्ग_, zuch,
   {{0xb8650065,0xf8ca853f,0x49748073,0x3ebf9c40}},	//   _لاہو, िस्प, глис, _gout_,
   {{0x0d7783f8,0x6d408186,0xa3df249a,0xc8788214}},	//   _لینک_, _utma, _देई_, liği_,
   {{0x30a68750,0x52bf0e00,0x1be394df,0xa8a69bbf}},	//   трив, _एक्स, _केवल_, трик,
   {{0x6458a653,0x08570039,0x656f57fc,0x443e9e01}},	//   mavi, כבים_, wuch, _ift_,
   {{0x6458f5e7,0xe24680f7,0xdce600eb,0x656f75e8}},	//   lavi, _شخصي, vukā, tuch,
   {{0x2002809a,0x443e8019,0xbcfb0019,0x28a68072}},	//   łki_, _kft_, nség, _कोथि,
   {{0x645899bb,0x656f49e3,0x657d75e9,0x315783de}},	//   navi, ruch, rtsh, _יידן_,
   {{0x68e881f2,0x656f0352,0x6d4675ea,0x657d75eb}},	//   midd, such, apka, stsh,
   {{0x656f0870,0x63a52847,0xc8788214,0x68e8f338}},	//   puch, _vrhn, diği_, lidd,
   {{0x5a3423e1,0x3ebf8242,0x22494ec9,0x7d03b00e}},	// [72d0] рнут, _rout_, rbak_, yons,
   {{0x64588b48,0x660d1c54,0x7d1a81a1,0x3ebf867f}},	//   javi, _iyak, _nhts, _sout_,
   {{0x7d03f5ec,0x3ebf8bfe,0x672d0c53,0x32d18091}},	//   vons, _pout_, _kiaj, _láya_,
   {{0xbcfb4612,0x248587d5,0x660d43d3,0xadc4046d}},	//   dréi, _sblm_, _kyak, _abẹw,
   {{0x629d75ed,0xbcfb3f52,0x3cf807d2,0x6d5d75ee}},	//   _iaso, gség, _سعید_, nssa,
   {{0xb97a0051,0x6d5d75ef,0x6458f5f0,0x629d0019}},	//   _אנשי, issa, gavi, _haso,
   {{0x3ebff5f1,0x7d03aea7,0x629d44bb,0x68e8e957}},	//   _tout_, rons, _kaso, didd,
   {{0x629d3cd0,0x81de80c8,0x7d03cd5d,0x672d3963}},	//   _jaso, _দুই_, sons, _niaj,
   {{0x7d03f5f2,0x660d3818,0x629d254c,0x35f5a183}},	//   pons, _nyak, _maso, _спар,
   {{0x2ecc01cb,0x629d057b,0x68e88ec8,0x26c00118}},	//   ास्त, _laso, gidd, _soio_,
   {{0xd2518013,0x660d69e2,0x28d995bc,0x26c003a8}},	//   _هنا_, _ayak, योगि, _poio_,
   {{0xc332804c,0x28b18074,0x656b8087,0x660d3294}},	//   _הוא_, जाहि, orgh, _byak,
   {{0x672d0812,0x01658a13,0x7ae980e1,0x68e8c953}},	//   _diaj, _скло, miet, bidd,
   {{0x7ae9a5d6,0x515a8039,0x660d1061,0x6abb82d4}},	//   liet, _טכנו, _dyak, ljuf,
   {{0x629d2185,0xbea60a08,0xbcfb0019,0x2905b057}},	//   _baso, _байк, zség, mola_,
   {{0xd00e8013,0x2905aac3,0x7ae9f5f3,0xe297279a}},	//   _علي_, lola_, niet, лас_,
   {{0x660d75f4,0x6458f5f5,0x3f8a0101,0x6da602ac}},	// [72e0] _gyak, yavi, _spbu_, _сипа,
   {{0x7ae9f5f6,0xc8788214,0x317f811b,0x69c981b4}},	//   hiet, tiği_, ituz_, iyee,
   {{0x7ae9f5f7,0x629d75f8,0x3f5180eb,0x2f190019}},	//   kiet, _faso, nšu_, sége_,
   {{0x629d0247,0xbcfb75f9,0x2905f5fa,0x443ed9f4}},	//   _gaso, tség, hola_, _sft_,
   {{0x2905f5fb,0x7ae9f5fc,0x69c981c0,0xbddb0866}},	//   kola_, diet, jyee, ccèd,
   {{0x629d5f3b,0x2f158106,0x628401e8,0x75360144}},	//   _zaso, råga_, lfio, _muyz,
   {{0xbcfb0065,0xa3e4923a,0x929d809a,0x629d266d}},	//   sség, _पेश_, woła, _yaso,
   {{0xa3bc0665,0x645882d7,0x7e640010,0x7ae9d502}},	//   _आपन_, savi, _ndip, giet,
   {{0x3f518029,0x6d4401e9,0x6da39c1c,0x62840114}},	//   ešu_, _ntia, _лита, ifio,
   {{0x7e64123c,0xb603826f,0xe97b00be,0x64588085}},	//   _adip, ýšen, עניש, qavi,
   {{0x7ae9f5fd,0xbec280f1,0x2286f2f2,0x68e88e05}},	//   biet, _çësh, _булг, ridd,
   {{0x68e8f5fe,0x7ae9b428,0x6d5d04fe,0xbcfb1a25}},	//   sidd, ciet, tssa, isée,
   {{0x672d3dc8,0x2905f5ff,0x6d5d7600,0x62fc0264}},	//   _viaj, bola_, ussa, ্ষায়_,
   {{0x290596cb,0x660d004f,0x629d2023,0x6722f4f6}},	//   cola_, _vyak, _saso, hmoj,
   {{0xd5a48986,0xa3df101b,0x6d4402f9,0x629d06a4}},	//   _کہ_, _देख_, _etia, _paso,
   {{0x3d1a0105,0x63a88503,0x6d5d42a4,0x6b9b066f}},	//   _मीठे_, _mrdn, pssa, ługo,
   {{0xdcfb8025,0x085502c7,0x20180748,0x286b1715}},	// [72f0] _upuć, иваю, _azri_, ерео_,
   {{0x63a8f601,0xe6c0803a,0x629d35eb,0x7ae9811b}},	//   _ordn, _čišć, _waso, ziet,
   {{0x5f9509b5,0x629d7602,0x963592e9,0x7a2b82d0}},	//   риет, _taso, анец, _kötü,
   {{0xbcfb0036,0xa283003d,0x290583df,0x69c9f603}},	//   sséd, _دیرو, zola_, yyee,
   {{0x7ae9a046,0xe80b800f,0x29058365,0x4e7892c8}},	//   viet, _सुना_, yola_, احمد_,
   {{0x64a5b553,0x7ae9809a,0x690b002a,0x93459b3c}},	//   рака, wiet, güet, анке,
   {{0xe2999052,0x7ae9ce0d,0x273a80f1,0x39495c47}},	//   вай_, tiet, _nën_, lpas_,
   {{0x05158a49,0x2bb68bb8,0x64577604,0x69db811e}},	//   াদের_, _अपरा, _lexi, tzue,
   {{0x2905f5b9,0xe8f994b7,0x50b5bd85,0xc8b58d15}},	//   tola_, кли_, асну, асны,
   {{0x9f859269,0x273a80f1,0x69db816a,0x317f8102}},	//   агод, _bën_, rzue, rtuz_,
   {{0x7ae9f605,0x6d4421b9,0x25a9009c,0x63a880d2}},	//   piet, _stia, _aral_, _grdn,
   {{0x28d98054,0x2905b4e7,0x2d8d81bc,0x25a924bc}},	//   योजि, sola_, _kpee_, _bral_,
   {{0x224d8573,0x20d580e8,0x66f200eb,0x25a90037}},	//   mbek_, _війс, nāki, _cral_,
   {{0xccf28158,0xc5f28039,0x20f432df,0x2905f606}},	//   ַכן_, קדם_, _आदेश_, qola_,
   {{0x425626c5,0xfbc30d9e,0x6b830106,0x395ff607}},	//   итат, обро, _ängl, lsus_,
   {{0x7a2b8182,0xaa462623,0x4a46662b,0x3a3fdc10}},	//   _götü, реал, рнав, ncup_,
   {{0x7d0705f5,0xe2971182,0x00e61597,0x60c38bd6}},	// [7300] bojs, шат_, ажан, _konm,
   {{0x38c80416,0xf1bf04c3,0xe0d74317,0x61e6807b}},	//   داری_, _agás_, аву_, úkli,
   {{0x39491da9,0x81cb8264,0xdb019b9c,0x3ea07608}},	//   apas_, রছি_, _arlí, _kait_,
   {{0x4aca01fe,0x395fef3c,0xaaca02f1,0xe5c69ff8}},	//   _रविव, ksus_, _रविक, исло,
   {{0x3a3f9b1d,0x6722f609,0x224d81a1,0xbcfb00e7}},	//   dcup_, rmoj, dbek_, ssée,
   {{0xa29e800d,0x60c383ec,0xf366828b,0x3ea0760a}},	//   _खोज्, _nonm, атин, _lait_,
   {{0x316de217,0xbcfb0866,0xee3a961a,0x31602353}},	//   erez_, prév, _анб_, lsiz_,
   {{0x645c3669,0x8f9b098a,0x22401495,0x2fc73cac}},	//   hari, _בילי, ncik_, änge_,
   {{0xee0aa1a7,0x31600457,0x66f200eb,0x63a8db3c}},	//   _реал_, nsiz_, cāki, _wrdn,
   {{0x645c760b,0x60c382ba,0x28a69c6f,0xf48484c0}},	//   jari, _conm, _कोशि, _داری,
   {{0x645707f4,0x224003ac,0x26c48041,0x10370039}},	//   _rexi, kcik_, _komo_, יטים_,
   {{0x25a90205,0x28a6a296,0x3160007e,0x3ea00219}},	//   _pral_, _कोरि, ksiz_, _cait_,
   {{0x25a6998b,0xe5c427ee,0x316d8162,0x60c3f60c}},	//   nvol_, осро, crez_, _fonm,
   {{0x645c0423,0x7d020307,0x26c4eda3,0x60c382d6}},	//   gari, _íosl, _lomo_, _gonm,
   {{0x3ea006e3,0xa3bc035a,0xd0f580d4,0x7d07017f}},	//   _fait_, _आपण_, ीकरण_, rojs,
   {{0x5a3500b3,0x66e40073,0xdbdc816b,0x645c02f1}},	//   снат, _моја, jším, aari,
   {{0x765d4824,0x7afa0125,0x7c87760d,0xbcfb008b}},	// [7310] masy, étta, _куне, frét,
   {{0x44990153,0x765d0e7e,0x3949297a,0x3ea00102}},	//   _свою_, lasy, rpas_, _zait_,
   {{0x26c48db7,0x442704be,0x929527ba,0xfc46016b}},	//   _bomo_, _àn_, _ланц, číte_,
   {{0x26c48510,0x765d2bb5,0x61e9005c,0x39490687}},	//   _como_, nasy, _želu, ppas_,
   {{0x8c45a8ca,0x6da5835f,0x395f811c,0xd05a8085}},	//   беле, сила, xsus_, sitə,
   {{0x316d82be,0x7c8782ff,0xbcfb00e7,0x64418122}},	//   vrez_, руде, crét, _qfli,
   {{0x765d0e87,0x3946f60e,0x6f0d760f,0x22597610}},	//   kasy, _atos_, _okac, _kesk_,
   {{0x7aed7611,0x645c7612,0x2139020f,0x395f8074}},	//   niat, zari, _kush_, tsus_,
   {{0x645c5aef,0x20028059,0x3a3fedd9,0xf99180f7}},	//   yari, şkil_, rcup_, سبة_,
   {{0x14778c48,0x316df561,0x6f0d528c,0x645c47a3}},	//   _خارج, rrez_, _akac, xari,
   {{0x395f82be,0x85048875,0x645c737e,0x3ea015d7}},	//   ssus_, _بولن, vari, _pait_,
   {{0x765d1f4e,0xc4c901c6,0x31607613,0x2b818035}},	//   gasy, _אג_, ysiz_, móc_,
   {{0x7d1e0af8,0x7aed0be5,0xa969813a,0x95830fe6}},	//   _phps, diat, _сила_, пляе,
   {{0x2d82173d,0x2ed4863a,0x60daf614,0x22938019}},	//   rtke_, _दत्त, chtm, _دلچس,
   {{0x4adb8074,0x2d827615,0x7af61c02,0x799d05ee}},	//   _बताव, stke_, tnyt, _assw,
   {{0x645c463a,0x7aed7616,0x7f3a8158,0x31607617}},	//   sari, giat, _געקו, tsiz_,
   {{0x5d860013,0xe8fa23b0,0xe80b83ca,0x39468122}},	// [7320] _الخل, гла_, _सुता_, _xtos_,
   {{0x3160080a,0x645c5665,0x7af6119b,0x26c4f2fc}},	//   rsiz_, qari, snyt, _somo_,
   {{0x4444004c,0xbbb68744,0x7aed0ab3,0xbcfb008b}},	//   _if_, _अपेक, biat, rrét,
   {{0x667680f7,0x7aed7618,0xe8e08028,0x673b00c3}},	//   إدار, ciat, _thủy_, _čujt,
   {{0x2cea825d,0x63f70fd3,0x21390db1,0xb33c8372}},	//   лько_, _نفیس_, _gush_, _irħi,
   {{0xc9530bea,0x765d0247,0x3ea0800d,0x6d56031d}},	//   _ממש_, zasy, žit_, _mwya,
   {{0x25a6a51d,0x765d06c0,0xdbdc816b,0x0ec80075}},	//   svol_, yasy, pším, _लवंड,
   {{0x26c48098,0x6aa42497,0x656f031d,0x3946816a}},	//   _uomo_, ndif, yrch, _ptos_,
   {{0x4444715b,0xc05a8221,0x765d3cfa,0x66f200eb}},	//   _of_, лін_, vasy, nāku,
   {{0x7aed697e,0xdd8f82e3,0x656f1c32,0x7afb007a}},	//   ziat, _سوم_, vrch, čuti,
   {{0x765d208e,0xa3e8235e,0x48a78a14,0x60da83e4}},	//   tasy, _मेल_, стым_, rhtm,
   {{0x444446a1,0x645af619,0xe3b18065,0x60da8168}},	//   _af_, _heti, _کرے_, shtm,
   {{0x765d6105,0x645a8812,0x7aed761a,0xd24f80f7}},	//   rasy, _keti, viat, _أنه_,
   {{0x98a38009,0x765d3bb4,0x897b8039,0x7aed0035}},	//   _ниче, sasy, _ערוצ, wiat,
   {{0x765d25e3,0x2f120061,0x7aed7160,0xd00f81a8}},	//   pasy, zági_, tiat, _كله_,
   {{0x4444761b,0x645a877b,0x61ed943c,0xbcfb0019}},	//   _ef_, _leti, _žali, trés,
   {{0x6aa2804f,0x7984076d,0x1ef801a8,0x273e1d88}},	// [7330] _maof, gtiw, _دعوة_, _aïn_,
   {{0x4aa90076,0x7aed761c,0xb33c8197,0xa3abba68}},	//   _चोरव, siat, _erħi, खिम_,
   {{0x661b8063,0x7aed761d,0x2d921bb9,0x629639bd}},	//   _szuk, piat, čneš_, beyo,
   {{0xbcfb02be,0x645a8706,0xe8b586ab,0x6aa28174}},	//   prés, _aeti, _अच्च, _naof,
   {{0x645ab85d,0x2bd10074,0x356bb1ad,0x7afd0bfd}},	//   _beti, सनका, урен_, _ijst,
   {{0xa3e801ce,0x1b499cfd,0x2489825b,0xf99f761e}},	//   _मेँ_, азки_, đamo_, _dyèt_,
   {{0x2f120019,0xc7c40790,0xdb09816b,0xfd108199}},	//   sági_, _ести, žníc, رجه_,
   {{0xa3bc0105,0xcf9204de,0x6d4b804a,0x66f201a9}},	//   _आपस_, _קטן_, ppga, nākt,
   {{0x69d687d9,0xe0d99957,0x7e6981bc,0x661bf61f}},	//   _üyel, иви_, _idep, _uzuk,
   {{0xe6c5005c,0x645af620,0x1f65afa5,0x6d49851e}},	//   _češć, _geti, оком, _itea,
   {{0xa3e80403,0xdbf2000d,0x69100006,0xb8d190d0}},	//   _में_, _příp, päev, _ऑफ_,
   {{0x753b8010,0x60c70bd6,0x823480d7,0xd62a2ba5}},	//   _kuuz, _lojm, _فرها, ионе_,
   {{0x645a8182,0x69cb013c,0xdd0e861c,0x753b85ee}},	//   _yeti, øgel, nışl, _juuz,
   {{0x7afd026c,0x394dbdf9,0x753be3a1,0xf77180d7}},	//   _ajst, mpes_, _muuz, _قاب_,
   {{0xda5a1182,0x62960242,0xf99f32e1,0x44442dc8}},	//   ираш_, teyo, _asè_, _vf_,
   {{0x7d0a80d2,0x25b506a5,0x8c3c83bf,0x225f89d1}},	//   zofs, ñaló_, _mağa, nauk_,
   {{0x02ca0a74,0x62966289,0xe0df06c0,0x44441532}},	// [7340] _रवीन, reyo, _pwòp_, _tf_,
   {{0x78a3f621,0x26c2003a,0x0ef4f622,0x394dbb09}},	//   _janv, ljko_, ेक्स_, ipes_,
   {{0xee3ad34c,0x79847479,0x66f20029,0x60c72d06}},	//   ане_, stiw, sāku, _dojm,
   {{0x268a8307,0x645a9a6e,0x2fc7016d,0x78a39f5a}},	//   شخصي_, _seti, änga_, _lanv,
   {{0x645aaba8,0x659680f7,0x226501d0,0xba480084}},	//   _peti, تجار, řský_, grįž,
   {{0x53348729,0x6d4980f7,0x7e698135,0x6562ae9c}},	//   пект, _dtea, _edep, rsoh,
   {{0xdfd20013,0x39400239,0xf4878fd3,0x645af623}},	//   _غير_, lqis_, تانی, _veti,
   {{0x78a3a468,0x249800f3,0x7d0a826c,0x25a00118}},	//   _aanv, herm_, sofs, _osil_,
   {{0x645ac332,0x78a3b33e,0x673c0198,0x2c110074}},	//   _teti, _banv, _hurj, _दुनू_,
   {{0x23650353,0x2a600069,0x673c283a,0x320f0019}},	//   šlji_, haib_, _kurj, ügyi_,
   {{0x4a468dbd,0x2a668098,0x25a02a91,0xd7fa82df}},	//   _днев, _дълг, _asil_, руп_,
   {{0x3ea6c8ed,0xfd57846d,0xd6d9066f,0xb3578061}},	//   ndot_, _alaṣ, ół_, _بیٹا_,
   {{0x2d86867f,0xdb0181a8,0xc33381c6,0xda1e908a}},	//   ntoe_, _urlá, _חוף_, _परित_,
   {{0x3ea68198,0xd12f81e2,0xe57180be,0x98a78162}},	//   hdot_, _іх_, ײַך_, _vină_,
   {{0xd25b27d4,0x92c712c0,0x66fc9911,0xac190eef}},	//   ица_, ощад, jčko, сову_,
   {{0xa3ab8f12,0x290cf624,0x7a390071,0xda1e8075}},	//   खित_, loda_, спар_, _परात_,
   {{0x497517d4,0x60c710d1,0x78a38085,0xdd0e811c}},	// [7350] ялас, _pojm, _yanv, xışl,
   {{0x7e7d128d,0x37ab098d,0xa9bb01a2,0xd2500019}},	//   lgsp, итен_, _ईपीए, ٹنے_,
   {{0x2a600359,0x765b808e,0xf99f06c0,0x6d49e0e9}},	//   baib_, _peuy, _pyès_, _stea,
   {{0x41ca95fb,0x7e7d1277,0x59ca8054,0x539a02f6}},	//   िहास, ngsp, िहार, _פירו,
   {{0xdd9b804a,0x290c8816,0x64a10609,0x8c3c8380}},	//   рше_, koda_, _eġiż, _sağa,
   {{0xdd0e8085,0x03a5b09a,0x673c02a6,0x7a4122ef}},	//   rışl, зико, _furj, _fátó,
   {{0x60080a14,0x290c805d,0x673c7625,0x54580039}},	//   _днём_, doda_, _gurj, חסון_,
   {{0xc7b2004c,0x78a3f626,0x93fc0039,0x6d4980b9}},	//   _אבל_, _sanv, ילוי, _ttea,
   {{0x394d80e7,0x7bd88754,0xf4878a4c,0xd49bc543}},	//   upes_, _čauš, _мужн, _вре_,
   {{0x395902d5,0xdea38019,0xedb48290,0xae2080c2}},	//   _mwss_, _ریڈی, _تحفظ, _बरतन_,
   {{0x9f450009,0xb5fda840,0x78a3a474,0x26c900fc}},	//   _älä_, _odšk, _vanv, _boao_,
   {{0xfaff0b18,0xa3e485e8,0x394def3c,0x61ed87dd}},	//   _një_, _पेट_, ppes_, _žalu,
   {{0x290c83c3,0xbcfb016a,0xbddb1b0d,0xf1a7b8a6}},	//   boda_, trép, scèn, _френ,
   {{0x6cd60013,0x7afbf627,0x386101ec,0x290cd63b}},	//   أقسا, lnut, jahr_, coda_,
   {{0xd141866f,0xf65f0646,0x00000000,0x00000000}},	//   snąć_, rkær_, --, --,
   {{0x39461570,0xb1461263,0x32d1826b,0x7afbf333}},	//   знаг, знал, _báyi_, nnut,
   {{0x3ea4806a,0x25a011ee,0x386101ec,0x867b01c6}},	// [7360] _ramt_, _usil_, fahr_, _הרפו,
   {{0xe9d7239f,0x3ea493c2,0x7afb9ded,0x673c07b8}},	//   чку_, _samt_, hnut, _purj,
   {{0x7afba7da,0x645e00eb,0x98aa0162,0x443a7628}},	//   knut, _iepi, _aibă_, _igp_,
   {{0x290c9351,0xfaff00f1,0x59db82f1,0x645e02d0}},	//   zoda_, _gjë_, यनार, _hepi,
   {{0x7afb803e,0xa3e4a0c0,0x3ea6f629,0x1ea980f7}},	//   dnut, _पेज_, rdot_, تالي_,
   {{0x645e06a4,0x2d868cfa,0xeaf68aed,0x5fcb92c6}},	//   _jepi, rtoe_, ुक्त_, ाहाल,
   {{0x290c803b,0x2d868a53,0xbc6781a8,0x443a22c9}},	//   voda_, stoe_, سمين_, _mgp_,
   {{0x645e327a,0x7afb803a,0x290cf62a,0xbea392e9}},	//   _lepi, gnut, woda_, _паск,
   {{0x61e4762b,0x2ca5813c,0x7d0e2b33,0xfe208074}},	//   nzil, _fald_, kobs, _बरिस_,
   {{0x81ae0a49,0x645e396c,0xf98f80a0,0x2ed500c2}},	//   _কথা_, _nepi, ابي_, दस्त,
   {{0xb4d88fe4,0x3f638009,0xa3e48beb,0x7c3a8122}},	//   ासी_, нтяб, _पेच_, _igtr,
   {{0xd6db1c74,0x290cf62c,0x7e62804f,0x7afb8140}},	//   сто_, soda_, naop, cnut,
   {{0x290ca1ce,0x628281ed,0x7e7d18a1,0x690f8366}},	//   poda_, _icoo, rgsp, røer,
   {{0x293780be,0x248d0668,0x645e762d,0xdcef0087}},	//   _זאגן_, đemo_, _cepi, ducă,
   {{0x645e762e,0x9b580087,0x7e629aef,0x6aa65b1e}},	//   _depi, зист_, kaop, _bakf,
   {{0x38178bea,0x60cab346,0x68ee0722,0x443a542a}},	//   _מקום_, _hofm, _ambd, _egp_,
   {{0xa2ce064a,0x7e6d1312,0x3ced809a,0x69c08122}},	// [7370] _सवर्, _idap, _अगले_, nxme,
   {{0x6d4d53cc,0x6f0f047f,0x7d0e04dc,0x645e1e93}},	//   _itaa, locc, cobs, _gepi,
   {{0x6aa6008e,0xdb08816a,0xee4a819d,0xf79901f9}},	//   _fakf, _ardí, _ịdịn, تناب_,
   {{0x6f0f047f,0xfaff00f1,0xf40300ab,0x7e62802a}},	//   nocc, _ujë_, _এরপর_, gaop,
   {{0xdca5bd0c,0x64a589f7,0x64d1016f,0xa2c08f1b}},	//   дали, дала, _सकाळ, वान्,
   {{0x6d4d004f,0xe8d90133,0x71d60e82,0x777a9fe7}},	//   _mtaa, ftụ_, _חושד_, kutx,
   {{0x7afb9f1c,0xb0b080d4,0x78698061,0x2ca597ab}},	//   tnut, जयनग, _jövő, _vald_,
   {{0xe9d98607,0x612200e7,0x7e6d762f,0x2ca5d306}},	//   жки_, rôle, _ndap, _wald_,
   {{0xc69283c8,0xc8c880d4,0x6e3b8420,0x3f418580}},	//   _באן_, ाउंट, _igub, _sóu_,
   {{0x672400f1,0x6f19831d,0xbddb0866,0x65698db1}},	//   _shij, llwc, rcèl, _iveh,
   {{0x645e7630,0x6d4d7631,0x7afb803e,0x61e40c9f}},	//   _repi, _ataa, pnut, zzil,
   {{0x645e003d,0x443a7632,0x3f678279,0x0378804e}},	//   _sepi, _sgp_, rđu_, _رحمت_,
   {{0x186998a0,0xa0698f27,0xb33c8197,0x6e3b912e}},	//   _дали_, _дала_, _isħa, _mgub,
   {{0x78a70b48,0xee3701e2,0x79898a53,0x7e6d09c4}},	//   _najv, ьня_, mtew, _edap,
   {{0xa3e80076,0xdc4581e2,0x7d0e39f6,0x6f0f01e8}},	//   _मेख_, jūči, robs, bocc,
   {{0x7b3c05f5,0x66047633,0x2a7fa6e9,0xdce40390}},	//   _očuv, _txik, ngub_, _ivič,
   {{0x8c3c8a0b,0x7989f634,0x6aa61238,0x2bba0c9a}},	// [7380] _bağl, ntew, _vakf, _उपका,
   {{0xddc40087,0x7649f635,0xe6c98bcf,0x6aa67636}},	//   _ediţ, _afey, _čašć, _wakf,
   {{0x8c3c87c0,0x28c40540,0x130a2f84,0x6aa612cf}},	//   _dağl, लॉगि, _мной_, _takf,
   {{0xe61a8895,0xf42a0009,0x61e41d88,0x7e6d00ee}},	//   оде_, _enää_, pzil, _xdap,
   {{0xdd908bca,0x6aa98080,0x83fc8699,0xfce6c98a}},	//   اوت_, ddef, _međe, модо,
   {{0xb4d88076,0x6e3bb8cd,0xa533804a,0x7e6287b6}},	//   ासे_, _egub, вніч, saop,
   {{0xf76789d7,0x7791015b,0x7e6282c4,0xbb4795a9}},	//   _جا_, _میلا, paop, ولون_,
   {{0xf96a8198,0x291a0144,0xff24c787,0x416a82ee}},	//   орой_, llpa_, _سبزی, ојом_,
   {{0xcb130039,0x6d5b819d,0x26c682f7,0x8c3c807e}},	//   כלה_, _gwua, mjoo_, _yağl,
   {{0x6e3b9d10,0x41bb00be,0xba3b07f1,0x7b1303ed}},	//   _zgub, קציע, _raïm, nçur,
   {{0x6d4d35cd,0x7e60ad26,0xdce4026f,0xd838a3c3}},	//   _staa, _kemp, _cvič, ječe_,
   {{0x6d40b91d,0x7e608455,0xb8d586ae,0x25a4bcf0}},	//   _kuma, _jemp, _चो_, _ksml_,
   {{0x7e60845c,0x6d40c288,0x94190085,0xbcfb0866}},	//   _memp, _juma, əyən_, ssém,
   {{0x6d40ac1d,0x7e60a6a8,0x6f0f047f,0x777aa63a}},	//   _muma, _lemp, socc, putx,
   {{0x3d16823c,0x6d40ac7b,0xbbc9000d,0x78a708ae}},	//   _पीछे_, _luma, रहेक, _rajv,
   {{0x8c3ca92c,0x7e60e86f,0x6d40f637,0x3e880e06}},	//   _sağl, _nemp, _ouma, rító_,
   {{0x6d40f638,0x26d901e2,0xeabf00ff,0xb5fd8dcc}},	// [7390] _numa, ūros_, _chùa_, _keše,
   {{0x657d09ae,0x3ea9074c,0x7e60b009,0xf0fb2135}},	//   mush, _haat_, _aemp, ्वेद_,
   {{0x657d7639,0x7e60f63a,0x6d407362,0x8c4403a7}},	//   lush, _bemp, ímav, _шеќе,
   {{0x6d40f073,0x7e60d4b6,0xa3e80beb,0xb5fd8450}},	//   _buma, _cemp, _मेट_, _leše,
   {{0x6d40f63b,0x5067028b,0x3ea9038e,0x657d10fa}},	//   _cuma, _отва, _maat_, nush,
   {{0x2018237b,0x3ea92468,0x6d40f63c,0xa3ab873c}},	//   _fyri_, _laat_, _duma, खिल_,
   {{0xeb91826a,0x657d3845,0xd6e00035,0x6d40f63d}},	//   اظت_, hush, ółki_, _euma,
   {{0x657d005d,0x7e60859c,0x32190009,0x3ea9763e}},	//   kush, _gemp, _kysy_, _naat_,
   {{0x6d40be63,0x7afa0125,0x6aa9848d,0x7d049b9c}},	//   _guma, étti, rdef, éisc,
   {{0x7e60f63f,0x657d7640,0x47c58009,0x629b8114}},	//   _zemp, dush, ебов, seuo,
   {{0x32558aca,0x6d40f641,0x79898a15,0x81e780ab}},	//   _звер, _zuma, stew, _মুখ_,
   {{0x6d40d4c4,0x2249026c,0x657d3b41,0xe0bf8264}},	//   _yuma, jcak_, fush, ইসেন,
   {{0x6d408079,0x657d5dda,0x58d584fa,0x5d670198}},	//   _xuma, gush, _подт, ниям_,
   {{0x332df642,0x26d903ed,0x09f681c6,0x98a2bf61}},	//   lmex_, ëror_, _אמנם_, _бише,
   {{0x69cb1d5b,0xd838f597,0x232a0be2,0x141a01a8}},	//   ägen, teče_, зови_, سيرة_,
   {{0x3ea90613,0x657d7643,0x8c3c8214,0x2fd8928d}},	//   _gaat_, bush, _rağm, ørge_,
   {{0xc3329a15,0x7e60f644,0x8c462118,0xa2c08b84}},	// [73a0] רון_, _remp, _пепе, वात्,
   {{0x7e60f645,0x6d4094ff,0x7e667646,0x7d5703de}},	//   _semp, _ruma, lakp, _רייד_,
   {{0x6d40f647,0x7e60903b,0x7c3e0122,0x7d1c00b9}},	//   _suma, _pemp, _igpr, mlrs,
   {{0x040b0104,0x6d40e4d2,0x8c1580ab,0x28c4064a}},	//   _lượn, _puma, াধান_, लॉजि,
   {{0x683408ae,0x6d40c0ac,0x7ae432ba,0x13d50264}},	//   dždž, _quma, mhit, _হইয়,
   {{0xdb0501ec,0x66df0168,0x5ba68425,0x49180327}},	//   _erhä, _mëka, ериз, _बीचो_,
   {{0xb5fd979d,0x910310ca,0x969680a9,0x2f190019}},	//   _reše, _спре, _праш, ségi_,
   {{0x6d40aeb5,0x6b83016d,0x657d0314,0xada6a27b}},	//   _tuma, _ånge, yush, _пабл,
   {{0x6d40c336,0x7e660359,0xdee3c11c,0x66e3814c}},	//   _uuma, dakp, _соти, _сота,
   {{0x3ea97648,0xc05785a8,0x63b7823e,0xbcfb0061}},	//   _saat_, нію_, çanè, rsék,
   {{0x443ef649,0x273a8084,0x60ce0122,0x7ae413fa}},	//   _igt_, _būna_, _mobm, khit,
   {{0x753a811e,0x09e68003,0x657d3855,0x6e2405ee}},	//   _hitz, _поен, tush, _bzib,
   {{0xe9738077,0x1af780be,0x7ae4764a,0xc2e9866e}},	//   _مهند, _אמאל_, dhit, _تعلم_,
   {{0x657d2f95,0x3ea92580,0x6e24026c,0x2edd8f1b}},	//   rush, _waat_, _dzib, _मत्त,
   {{0x3ea9178f,0x25bf002e,0x6e240316,0xad1b8039}},	//   _taat_, ţul_, _ezib, פולר,
   {{0x41e71af1,0x3da70112,0x753a8102,0x657d547c}},	//   ніза, _зроб, _litz, push,
   {{0x22490573,0x5a351354,0x6e240af8,0xfc300061}},	// [73b0] rcak_, тнат, _gzib, لحہ_,
   {{0x2bba000c,0x394f0029,0xf8070f16,0x6f1d764b}},	//   _उपचा, īgs_, нчен, llsc,
   {{0xc10401a8,0x7ae401f6,0x6e2405ee,0x2ae7826b}},	//   دولي, bhit, _zzib, _lákọ_,
   {{0x443e867f,0x753a8102,0x7ae4764c,0xb1841e51}},	//   _agt_, _aitz, chit, šťas,
   {{0x443e8072,0x6da59775,0xada58150,0x753a8c45}},	//   _bgt_, тила, талл, _bitz,
   {{0xd378003a,0xeb999d5c,0x443ecf6b,0x3ea9b8ee}},	//   šće_, дик_, _cgt_, žat_,
   {{0xa3c30074,0xc1c9801b,0x753a8102,0x443e816a}},	//   ्हि_, ाङ्ग, _ditz, _dgt_,
   {{0x3942008e,0x443e8bfd,0x9f348163,0x753a8f3e}},	//   _yuks_, _egt_, _бесі, _eitz,
   {{0xceb2878d,0x798d764d,0x443e802a,0x2360817f}},	//   _דין_, ntaw, _fgt_, ćija_,
   {{0xa3c30576,0x24858144,0x2ae7826b,0x76598114}},	//   ्हा_, _uclm_, _dákọ_, lbwy,
   {{0x661bcbee,0x672981c0,0xe80b903e,0x29010187}},	//   _hyuk, _khej, _सुखा_, inha_,
   {{0x92eb92dc,0x753a8102,0x798d177c,0x6134011c}},	//   _عراق_, _zitz, ktaw, rülə,
   {{0x040b0028,0x6aad41fd,0xfdc000ab,0x09d600ab}},	//   _tượn, ddaf, উন্ড, _সেনা,
   {{0xe9d88112,0x6aaba578,0x661b8deb,0x764d112e}},	//   _які_, _hagf, _myuk, _efay,
   {{0x2d9e026f,0x7ae4764e,0x398b8aa2,0x5f060081}},	//   ňte_, thit, løs_, _изка,
   {{0x06f60077,0x69c40102,0x6f0402f7,0xe2973229}},	//   _جستج, txie, _ujic, кас_,
   {{0x61e9a4e8,0x261904e5,0x7ae40744,0xf2d280be}},	// [73c0] nzel, _युपी_, rhit, בען_,
   {{0x7d7b0bea,0x7ae43c86,0xbebb0168,0x9ffa01ad}},	//   _קניו, shit, smët, وراء_,
   {{0x7ae45b51,0xcc770039,0x7f43823e,0xdd1c80e1}},	//   phit, _בעיה_, _junq, _nášh,
   {{0x753a82af,0x798d4290,0x6d440c53,0xcf9283de}},	//   _sitz, btaw, _kuia, שטא_,
   {{0xa2c08bb8,0x673b8458,0x753af64f,0x61e981ed}},	//   वास्, _diuj, _pitz, jzel,
   {{0x7e6467fd,0xd90d0065,0x2b5e8748,0x62840037}},	//   _leip, _ٹیم_, _pwtc_, lgio,
   {{0x6609f650,0x443e80ff,0x61e98bfd,0xb5fd8824}},	//   _exek, _vgt_, ezel, _pešc,
   {{0xbcfb7651,0x78aa8267,0xbebb0168,0x753a8192}},	//   rséi, _safv, hmër, _witz,
   {{0x7f438c15,0x6da38002,0xbd8a8077,0x6aabf652}},	//   _aunq, _кита, _زنان_, _dagf,
   {{0x753a8a0f,0x6729bd06,0x443ec0dd,0xbebb0168}},	//   _uitz, _zhej, _ugt_, jmër,
   {{0x04439982,0x47350d5f,0x7f4381df,0x03a3835f}},	//   _техн, лнос, _cunq, _вихо,
   {{0x2cac9a50,0x7f438081,0x73369ec9,0x7e6408f1}},	//   _hadd_, _dunq, _شرائ, _ceip,
   {{0x2918056c,0xe894a187,0xd90e8065,0x6d44041c}},	//   _okra_, _баль, _ویب_, _cuia,
   {{0x6fb4a219,0x40a8853d,0x291800ee,0x79808e8c}},	//   _ممتا, _سختی_, _nkra_, mumw,
   {{0xa3abbd6d,0xb5fd895e,0x629f0085,0xac181bc6}},	//   खिए_, _meša, teqo, вору_,
   {{0x62840698,0x291ec333,0x3863006a,0x798d688c}},	//   ggio, llta_, _sejr_, ttaw,
   {{0x6f028023,0x6aad09ca,0x53345943,0x291eede3}},	// [73d0] dnoc, rdaf, ретт, olta_,
   {{0x798d7653,0x273b0110,0x661b89c4,0x7ae2f1b3}},	//   rtaw, _kūno_, _ryuk, _llot,
   {{0x798d7654,0x661b859c,0x0675a1ae,0x61e9f655}},	//   staw, _syuk, гуля, zzel,
   {{0xf7700c2a,0x8f148221,0xcf9380be,0x201c83ac}},	//   زام_, афіч, יטע_, _myvi_,
   {{0x442583ec,0xa4d580e8,0x83fc8088,0x356b8087}},	//   _szl_, лоді, _ređa, френ_,
   {{0xd0068013,0x057480f7,0xa2db001b,0x6aabf656}},	//   _هل_, شاهد, नसक्, _sagf,
   {{0xeb99dace,0xb5fd8efd,0x7ae2b1c3,0xf4848a67}},	//   хий_, _deša, _blot, ручн,
   {{0x61e98a11,0xdd1c81ac,0xd1858a0e,0x6f02c776}},	//   tzel, _vášh, глий, cnoc,
   {{0x61fb050b,0xa91d81d0,0x3f814961,0xd83882d4}},	//   _žulj, huže, luhu_, veča_,
   {{0x7e644e71,0x61e9f24b,0xdce98824,0xbc5695d8}},	//   _seip, rzel, _kveč, čšíc,
   {{0x7ae2f657,0x25a90587,0x6441f658,0xa91d817f}},	//   _flot, _asal_, _igli, juže,
   {{0xa91d803b,0x291ea180,0xa68304fa,0x61e98061}},	//   duže, alta_, блюд, pzel,
   {{0xa2c09a4d,0x3f811a83,0xd12e803d,0xd838890c}},	//   वार्, huhu_, تمی_, reča_,
   {{0xd83882d4,0x717280d7,0x7cf4011c,0xdce9b937}},	//   seča_, _اهوا, _kürə, _oveč,
   {{0x3bd50009,0x75ea8019,0xe29a06e6,0x7e64632b}},	//   аютс, _közé, нав_, _teip,
   {{0x425505fa,0xe7f9073c,0xef1f0085,0x3f8101b4}},	//   итут, ्पना_, clü_, duhu_,
   {{0x612b0019,0xf2d280be,0xb2260b79,0x316dd834}},	// [73e0] küld, זען_, умал, nsez_,
   {{0x6441803d,0x3ea25292,0x26d27659,0x63b70144}},	//   _ngli, lekt_, _hoyo_, _frxn,
   {{0x2a692d68,0xb5fd9432,0x645c079a,0x26d2765a}},	//   baab_, _reša, mbri, _koyo_,
   {{0xa3c31d2a,0x645c765b,0x6441a166,0x26d21d26}},	//   ्हर_, lbri, _agli, _joyo_,
   {{0xb5fdec8b,0x26d20010,0x3ead8358,0x2d82765c}},	//   _peša, _moyo_, _daet_, nuke_,
   {{0x50432183,0x3f8116f2,0x291e0019,0xd9b2064a}},	//   _герб, buhu_, _óta_, ीमीट,
   {{0xb5fd9c9a,0x2d8f8722,0x645c01a8,0x7ae2b5cf}},	//   _veša, atge_, ibri, _plot,
   {{0x7980823d,0x5fbb0039,0xe73795d1,0x6441f65d}},	//   tumw, _אצלנ, _бес_, _egli,
   {{0xb5fd8858,0xdce99b46,0xa91da98e,0x3ea24494}},	//   _teša, _zveč, dužb, dekt_,
   {{0x26c002f7,0xc7af0065,0x2d82686f,0x78a1ae28}},	//   _anio_, _بڑے_, duke_, gelv,
   {{0xba3b2218,0x645c765e,0x26d20f33,0xc91701c6}},	//   _haït, dbri, _boyo_, רחית_,
   {{0x7c2582af,0x7ae2f65f,0xc9868087,0x5186a34b}},	//   ühre, _ulot, _буки, _бука,
   {{0xef1f0214,0x612b0285,0x78a1f660,0xb5fd8968}},	//   rlü_, lüle, belv, _lešn,
   {{0xa3c30076,0xa91d8067,0x1fa68c9d,0x26c07661}},	//   ्हल_, tuže, _бриг, _enio_,
   {{0xe8140576,0x612b1238,0x24192b97,0xac191515}},	//   _तुला_, nüle, товы_, тову_,
   {{0x32551444,0xddc0801b,0x4a550ca0,0x2d827662}},	//   рвар, _nemů, ркас, buke_,
   {{0x645c23b5,0xdce9c5cc,0x39468110,0x50f523e1}},	// [73f0] bbri, _sveč, _juos_, азат,
   {{0xd37805f5,0x270d80d4,0x656f4d9c,0x0f0d83b6}},	//   šća_, िक्र_, msch, िक्स_,
   {{0x929527d6,0x656f0e83,0x33200580,0x351c01c6}},	//   _канц, lsch, blix_, _אוזנ,
   {{0x8aa7181d,0x7d1a8074,0x35b5824f,0x3f817663}},	//   _срод, _akts, ибер, ruhu_,
   {{0x656f7664,0x7c289087,0x298b0d70,0x7cf40085}},	//   nsch, _azdr, _ясно_, _sürə,
   {{0x2ee201cb,0x88bc801b,0x656f5e5e,0x61ed01f6}},	//   _पत्त, změr, isch, mzal,
   {{0xdce9b69f,0x656f01ec,0x25fc06a7,0xa2dc0816}},	//   _uveč, hsch, _लेनी_, _नवम्,
   {{0x645c0669,0x656f6665,0xc245ee38,0x61ed2b8c}},	//   zbri, ksch, шник, ozal,
   {{0x9c879168,0x61ed4761,0xa48780f7,0x6aaf0229}},	//   _مشاه, nzal, _مجان, _macf,
   {{0xe0d9872f,0x656f3fea,0xf77180f7,0x644181e0}},	//   тво_, dsch, ياج_, _ugli,
   {{0xa91d8067,0x316d82be,0x672d0e35,0x26d200ee}},	//   tužb, ssez_, _bhaj, _poyo_,
   {{0x672d5344,0x645c151e,0x7e6b96fb,0x2d820074}},	//   _chaj, wbri, nagp, tuke_,
   {{0x6b83e97f,0x3ea212d2,0x7ae98448,0xb5fd8bda}},	//   lung, rekt_, mhet, _mešo,
   {{0x2d820d11,0x7ae9f665,0xed57002e,0x28c90a0d}},	//   ruke_, lhet, рор_, राफि,
   {{0x6b83c3f9,0x660d0004,0x2d827666,0x7f470282}},	//   nung, _exak, suke_, _nujq,
   {{0x7ae98711,0x2d827420,0x645c05f8,0x656f01ec}},	//   nhet, puke_, sbri, bsch,

   {{0x6b83e3c8,0xe9d70767,0x786610ca,0xfd4e81bc}},	// [7400] hung, акт_, иказ, _dakọ,
   {{0x6b83f667,0x20567668,0x6d562d0f,0x7f470168}},	//   kung, ртар, _itya, _bujq,
   {{0x44440747,0x6299f669,0x6b8381e2,0x7ae9805d}},	//   _ig_, _obwo, jung, khet,
   {{0x6b8389ed,0x5a960003,0xfd4e819d,0x656400b4}},	//   dung, _троф, _gakọ, _kwih,
   {{0x6f09830b,0x7ae9f66a,0x7ceb02af,0x69c98282}},	//   _djec, dhet, _dürf, jxee,
   {{0x6b838a8c,0x6f0985a4,0x6e29826c,0xb5fd8754}},	//   fung, _ejec, _dzeb, _tešn,
   {{0x6b83f66b,0x4444766c,0x39468176,0x7afb8081}},	//   gung, _mg_, _suos_, fiut,
   {{0x7ae9904d,0x612b690e,0xa31088fd,0x7c288353}},	//   ghet, rüle, ावेज_, _vzdr,
   {{0x444415f8,0xe1ff02ba,0xc05a8a4c,0x612b766d}},	//   _og_, _león_, кін_, süle,
   {{0x4444766e,0x6b838859,0x0cc100c8,0x8c4398ba}},	//   _ng_, bung, _উত্ত, _дефе,
   {{0x7d18816b,0x6b8380b4,0x61ed4dd9,0x7afb9c43}},	//   movs, cung, zzal, biut,
   {{0x44440a1c,0x656f683e,0x7ae99f29,0x7afb9f91}},	//   _ag_, tsch, chet, ciut,
   {{0x4444766f,0xd9549125,0x2369812b,0xca9784de}},	//   _bg_, _انتخ, ćaje_, _כדאי_,
   {{0x656f1736,0x44443b49,0xdb0d8009,0x3990823e}},	//   rsch, _cg_, äköi, màs_,
   {{0x656f26b1,0x44447670,0x7f848013,0x67228084}},	//   ssch, _dg_, _العن, kloj,
   {{0x4444246a,0xd2580604,0x083b8051,0x61ed0102}},	//   _eg_, ицу_, _בעול, tzal,
   {{0x6b83a4d4,0xa91df671,0x90991ceb,0x6f0985f3}},	// [7410] zung, luža, лват_, _rjec,
   {{0x261a8740,0x6f09920e,0x6b838b5e,0x7ae98019}},	//   _बड़ी_, _sjec, yung, zhet,
   {{0xba3b7672,0x2ba6836d,0x7e6b809c,0x64457673}},	//   _païs, _कैला, tagp, _ighi,
   {{0x4444494f,0x7ceb01ec,0x7ae98168,0x6b83b219}},	//   _zg_, _bürg, xhet, vung,
   {{0x4444045c,0x6b83a2eb,0x6f09f674,0xb5fd8b67}},	//   _yg_, wung, _vjec, _vešo,
   {{0x588401e5,0xb4e18035,0x2fc70106,0x7d18aea1}},	//   _мыса, दसे_, ängs_, govs,
   {{0x7ae9f675,0xe299f676,0x7e6b9049,0xbcfb00e7}},	//   thet, гай_, pagp, nséq,
   {{0x9f058591,0x6f1b8234,0xa91d825b,0x69c9811b}},	//   _اورو, _ukuc, duža, txee,
   {{0x60d517aa,0x7ae9f677,0x7afbf678,0xdce9816b}},	//   _kozm, rhet, riut, _uveď,
   {{0x6b83f679,0x64450104,0x1c1ba36a,0xdce400c3}},	//   pung, _nghi, _पुथल_, _ivić,
   {{0x7ae98234,0x69c6abf5,0x6d41820d,0x7d07026c}},	//   phet, äker, _iila, dnjs,
   {{0xed5a3d00,0x6d41e041,0x6717a13e,0x629982a0}},	//   лом_, _hila, तविक_, _ubwo,
   {{0x6d41f1ac,0x6d4b03d3,0x225f8458,0x249a00b9}},	//   _kila, _égal, mbuk_, _pbpm_,
   {{0x3a368039,0x7bdc1bb6,0xe1ff2564,0xdff90035}},	//   _פרסם_, tyru, _peón_, ्पाद_,
   {{0x6d419b31,0xd3b50009,0xcb031862,0xf99f767a}},	//   _mila, ость, रचंड_, _apè_,
   {{0x612f8bc5,0x4444767b,0x6d41f67c,0x9e660371}},	//   følg, _wg_, _lila, _увид,
   {{0x4444752f,0x3f858365,0xa3a80b9f,0x6d418cdb}},	// [7420] _tg_, lulu_, _खैर_, _oila,
   {{0x4444767d,0x6d41f67e,0xb4e68105,0xac8619a8}},	//   _ug_, _nila, _पते_, _угол,
   {{0x6b9e767f,0x7e69890c,0x7d188140,0xe3b887c0}},	//   _uppg, _beep, vovs, _ayın_,
   {{0x6d41f680,0x612f9277,0xb5fd8196,0x2bbda770}},	//   _aila, bølg, _tešl, ्मना,
   {{0x6d41f681,0x7e69f682,0x3f85c1c8,0x7ce6807b}},	//   _bila, _deep, hulu_, _aðra,
   {{0x3f85f683,0x6d41820f,0x28c90701,0x0ee203b7}},	//   kulu_, _cila, राणि, _पतझड,
   {{0x6d41e078,0x7d18f684,0xcec381d0,0x25ada6e3}},	//   _dila, rovs, áří_, _esel_,
   {{0x7d18a0f1,0xa3b9073c,0xcfd080c8,0x68fe033e}},	//   sovs, चित_, ানমন, lipd,
   {{0x6d41f685,0xddcd06ec,0x26c48144,0x7d189f66}},	//   _fila, _odaš, _inmo_, povs,
   {{0x6d41f460,0x3990809f,0x291a7626,0x3f859a1a}},	//   _gila, ràs_, nopa_, fulu_,
   {{0xf98f89d7,0x3f85f686,0x8f35143d,0x61301614}},	//   وبی_, gulu_, женц, mäld,
   {{0xa91d8052,0x6d41f687,0xa25b0187,0x3990823e}},	//   ruža, _zila, _anôn, pàs_,
   {{0x6f0388f1,0x317ff688,0x44210748,0x2fc700ff}},	//   énci, cruz_, _syh_, ̣ng_,
   {{0x44270104,0x6448173d,0xa2d492c6,0x6d418438}},	//   _ơn_, ždin, यॉर्, _xila,
   {{0x2bbd8a16,0x60d509a4,0xd82f8087,0x5695310c}},	//   ्मया, _rozm, _хэ_, _дайт,
   {{0x925900a9,0x7ceb007e,0x6ee60177,0x00000000}},	//   раат_, _sürd, _tóba, --,
   {{0x60f90110,0x3ea6c712,0x60d57689,0x7e6994cf}},	// [7430] аная_, deot_, _pozm, _reep,
   {{0x28c901c4,0x291a469c,0x7e69f68a,0xfc4701d0}},	//   राधि, gopa_, _seep, číst_,
   {{0x4427768b,0x6d41f68c,0x7ae30087,0xf77011cc}},	//   _án_, _rila, _înto, فان_,
   {{0x6d419600,0x7ceb768d,0xdb1f0198,0x60c48326}},	//   _sila, _würd, äväk, _ɗima,
   {{0xb5fd81e2,0x3f85f68e,0x7aed48ed,0xa91d812b}},	//   _iešk, zulu_, mhat, dužn,
   {{0x7aed768f,0x6d41c0ac,0x23c492c7,0x87e71374}},	//   lhat, _qila, वमंद, _любе,
   {{0x6d41894d,0x2ee97690,0x6f0d017f,0xaac583eb}},	//   _vila, _olaf_, _ojac, वालक,
   {{0x6d418c9e,0xa2cc016f,0x3b090197,0x25ad808e}},	//   _wila, हाय्, nnaq_, _tsel_,
   {{0x6d41f691,0xed598067,0x225fa0a7,0x2a7900b9}},	//   _tila, _brže_, rbuk_, _mdsb_,
   {{0x10a59a3b,0x3eb20085,0x2ee900ee,0x225f9b7c}},	//   цион, _sayt_, _alaf_, sbuk_,
   {{0x7aed029b,0x1eca0abe,0xa6ca0abe,0x25a0065d}},	//   khat, ални_, ална_, _spil_,
   {{0x7d1e06ab,0xa91d8945,0x2ca7e0e3,0xf77200be}},	//   _skps, drže, lend_, וקט_,
   {{0x94040085,0x7aed081b,0x6f0d0b67,0x3f85f606}},	//   əmə_, dhat, _djac, sulu_,
   {{0x628f114e,0x3f85f692,0x6e2d0253,0x64919f79}},	//   _acco, pulu_, _dzab, _užič,
   {{0x0443079e,0x8c431c9b,0xb5fde7ca,0x6e2d7693}},	//   дерн, дере, _bešk, _ezab,
   {{0x7aed2172,0xb4e686b7,0x2ca7f694,0x0d860009}},	//   ghat, _पत्_, hend_, _длин,
   {{0xe8fa141e,0x7ceb07d9,0x25a006cb,0x2ca7d521}},	// [7440] ала_, _süre, _upil_, kend_,
   {{0x6ab683eb,0xddc08353,0x628f047f,0x394b107c}},	//   _अफ्र, _nemš, _ecco, _ducs_,
   {{0x7d1c7232,0x232a035f,0xab2a035f,0x32461fd9}},	//   mors, _вони_, _вона_, _менг,
   {{0xe5c68198,0x6da6a4dc,0x68fe00c3,0x7d1c0e06}},	//   жско, жида, sipd, lors,
   {{0xc27b025f,0x2b5a7695,0x82361abb,0x2ca7b480}},	//   _דרכי, _htpc_, _گرگا, fend_,
   {{0xd37a85f1,0x7d1c035f,0x7ae40f52,0x2ca7a86b}},	//   ачи_, nors, lkit, gend_,
   {{0xaac585b3,0x613000f2,0xa91d8052,0x248087d9}},	//   वांक, räld, tužn, ğim_,
   {{0x7ae40e11,0x248087d9,0x6e242d23,0x6ab61670}},	//   nkit, şim_, _oyib, ndyf,
   {{0xc3330bea,0x23698067,0x83fcc955,0x3994016d}},	//   ווה_, ćaja_, _međi, näs_,
   {{0x7aed0019,0x83fc8668,0x7d1c127a,0x20070035}},	//   zhat, _leđi, jors, źnie_,
   {{0x6e2d0065,0x64488122,0x224680ee,0x7ae40198}},	//   _szab, _igdi, _tgok_, kkit,
   {{0x7996009a,0xd946b0bb,0x224682c4,0x6e2400b4}},	//   ktyw, _деди, _ugok_, _byib,
   {{0x7d1c1da3,0xd62701a8,0x6e240a03,0x6a9b81c6}},	//   fors, تعدي, _cyib, _כשאנ,
   {{0x7d1c025b,0x99fb8039,0xe3b30060,0x395982df}},	//   gors, _דפדפ, ورز_, ísse_,
   {{0x7aed7696,0x3edf082e,0xb5fd8da8,0x63be01f4}},	//   that, _abụọ_, _pešk, _crpn,
   {{0xd838a3c3,0x25b00364,0xb606920e,0x7ae413d2}},	//   ječi_, ällä_, _kršć, gkit,
   {{0x7aed5847,0x6f1d7697,0xb5fd801b,0x6e2d00b4}},	// [7450] rhat, mosc, _vešk, _uzab,
   {{0x7aed35bc,0xa2a181fe,0x7d1c0081,0x1601064a}},	//   shat, _कॉन्, cors, _लेयर_,
   {{0xb5fd803a,0x7aed7698,0x2ca7f699,0x7e6d00dd}},	//   _tešk, phat, vend_, _keap,
   {{0x6f1d0819,0x6d45769a,0x2ca78cfa,0x1dc69344}},	//   nosc, _hiha, wend_, लमंत,
   {{0x7cf000f2,0x63a1826f,0x7ceb0085,0x7cef8edd}},	//   _därf, _spln, _gürc, _jørg,
   {{0x6d456463,0xf1bf2391,0x7e6d2360,0xb5fd99d1}},	//   _jiha, _irá_, _leap, _ješi,
   {{0x6d45769b,0xb5fda6b5,0x2ca787b3,0x0442f69c}},	//   _miha, _meši, rend_, нешн,
   {{0x6d452f87,0x7e6d769d,0x2901769e,0x2ca7baf2}},	//   _liha, _neap, liha_, send_,
   {{0xceb2c100,0x7d1c07d9,0xe8f99f2b,0x44458019}},	//   _אין_, yors, йли_, _فراہ,
   {{0xa3cb000d,0xb5fd865c,0xb4ea016f,0x6d45769f}},	//   लमा_, _neši, _मते_, _niha,
   {{0x7ae401e2,0x7afd000b,0x7d1c1a70,0x63a1816b}},	//   ykit, _omst, vors, _upln,
   {{0x7e6d0ae3,0x6f1d6071,0x7d1c4e54,0x25bf89ff}},	//   _ceap, gosc, wors, _krul_,
   {{0x7cf00006,0x6d4576a0,0x63be5d50,0xb5fd8390}},	//   _järg, _biha, _srpn, _beši,
   {{0x78b5011f,0xe1f0830f,0x6d4503bf,0x6d4d00b9}},	//   _nazv, _جسم_, _ciha, _duaa,
   {{0x6d456d47,0x7d1c0065,0xb5fd8110,0xe73a0ae7}},	//   _diha, rors, _deši, _лек_,
   {{0x7d1c36b9,0x9ad38135,0x934318f6,0x6f1d00e5}},	//   sors, _dịgh, енсе, cosc,
   {{0x6d450091,0x7ae476a1,0x6d5b8282,0x612b0061}},	// [7460] _fiha, rkit, _ntua, rüln,
   {{0x7ae45f3c,0x6d450959,0x7e7b8c30,0xf6170039}},	//   skit, _giha, _adup, _מחפש_,
   {{0x6d5b80a9,0xc2c60013,0x2d8f016d,0x09a8adb8}},	//   _atua, _فيدي, _äger_, _कन्य,
   {{0xf1bf07ca,0x61460fcb,0x7cef8bc5,0xe737813a}},	//   _frá_, _нема, _lørd, пех_,
   {{0xd838ab0d,0x290176a2,0xf1bf01a8,0xd1388084}},	//   reči_, biha_, _grá_, ymą_,
   {{0x4425800d,0x6d5b81a8,0xd83882d4,0x612b2353}},	//   _byl_, _dtua, seči_, nüll,
   {{0xdc3600be,0x07a3300b,0xab38854c,0xb90c8032}},	//   האַט_, _парн, опку_, _eemọ_,
   {{0x7cf00106,0x7ceb0085,0x6d5b8168,0xd25081a8}},	//   _färg, _müra, _ftua, خنة_,
   {{0x25fc06ae,0xb60601f4,0x6f1d76a3,0xf65f1277}},	//   _लेली_, nošč, vosc, kjær_,
   {{0x60f8835f,0x3ea00242,0x261582f1,0x6f02c69a}},	//   іння_, _abit_, _फुटी_, lioc,
   {{0xb5fdf6a4,0x6d452690,0xd1388d42,0xdceb8267}},	//   _reši, _riha, rmą_, _šićk,
   {{0x6d4576a5,0x6f0281dd,0x6d4d008e,0x7cf00106}},	//   _siha, nioc, _puaa, _lärd,
   {{0x6d452cc6,0xb5fda4ca,0x612b02af,0x290113c8}},	//   _piha, _peši, füll, yiha_,
   {{0x2ed9800c,0xd12f835f,0x317b898a,0x6f028037}},	//   _भक्त, _їх_, _פרומ, hioc,
   {{0x291e8503,0x50b780f7,0x6d4509fa,0x290c9235}},	//   mota_, _ردود_, _viha, mnda_,
   {{0x7c250a56,0x628d0b80,0xf1bf03cd,0x2d9f76a6}},	//   _vyhr, ugao, _prá_, çues_,
   {{0x7cef84d6,0xdb240061,0x69c00118,0xb5fdf6a7}},	// [7470] _høre, írás, _ámel, _teši,
   {{0x291ef6a8,0x7cef813c,0x3cf8809a,0x3eab0039}},	//   nota_, _køre, ्चों_, lect_,
   {{0x6d5b998f,0x290126a3,0x2d8b1b31,0x5eb00264}},	//   _stua, riha_, luce_, টারে,
   {{0x291ef6a9,0xfbbd8768,0x3eb9013c,0x6f028081}},	//   hota_, ्मसम, ndst_, gioc,
   {{0x83fc8025,0xe81d000f,0x7cf0016d,0x3eab002e}},	//   _među, _बुरा_, _färd, iect_,
   {{0xa2d900d4,0x6aa9ce80,0x69d682d0,0x03a5910e}},	//   फॉर्, weef, _üyey, дико,
   {{0xeb99a001,0x291ef6aa,0x3a268122,0x290c8326}},	//   ций_, dota_, _ayop_, dnda_,
   {{0xa91d8b5d,0x290cf6ab,0x6130016d,0x3eab0e9e}},	//   drža, enda_, mäla, ject_,
   {{0x6aa9f6ac,0x6ed1064a,0x386e8c0b,0x7cf0039c}},	//   reef, धानु, _befr_, _häre,
   {{0xd378005c,0x26c9247b,0xddc40110,0x2d8b079a}},	//   šći_, _anao_, _neiš, duce_,
   {{0x273580f2,0x7cf00006,0x16aa0d69,0x3eab76ad}},	//   gång_, _järe, овни_, fect_,
   {{0x7cef8aa2,0xd838b7a2,0x98a280eb,0x441a80be}},	//   _døre, ječu_, ēkā_, _וועס,
   {{0xb8e38a49,0x2d8b0025,0xdce982ee,0xba74936d}},	//   _এক_, guce_, _cveć, _سانت,
   {{0x58d4ac18,0x7cef821e,0x291ecaa0,0xb606007a}},	//   _почт, _føre, cota_, vošč,
   {{0x9d43321a,0x1543002e,0xe81d06a7,0x7cef806a}},	//   терд, терм, _बुला_, _gøre,
   {{0x91d183bb,0x2d8b76ae,0x7d03f6af,0x99e39c32}},	//   _तपाई, buce_, hins, žňuj,
   {{0x7d0380a4,0x3946204d,0x45360198,0xb0c9086a}},	// [7480] kins, днаг, _охот, रांग,
   {{0x26c90025,0x3947808e,0x394ff6b0,0x49990009}},	//   _znao_, _jins_, _mugs_, ятся_,
   {{0x7cf000f2,0x6f029601,0x09d600ab,0x26c90122}},	//   _värd, tioc, _সেখা, _ynao_,
   {{0x7cf000f2,0x6fb08bb8,0xc6a38226,0x3947e4ad}},	//   _däre, _जनसं, врши, _lins_,
   {{0x6f02f6b1,0x290cc6e8,0x7d0384b9,0x395d8069}},	//   rioc, ynda_, fins, _ntws_,
   {{0xdb0a8bc5,0x7d03be02,0x6f0290d3,0xa3e506a7}},	//   lvfø, gins, sioc, बैक_,
   {{0x291e95d8,0x612b0074,0xe2080035,0x3eab0144}},	//   vota_, külj, _wróć_, yect_,
   {{0x27e70257,0x7cef83ba,0x7ceb6237,0x291e8609}},	//   ønne_, _røre, _nürn, wota_,
   {{0x60dc76b2,0x7cefdff1,0x7d049a25,0x2d5407b8}},	//   _korm, _søre, éiss, _näe_,
   {{0xf6518117,0x1604a120,0x2d8b0042,0x6562ae9c}},	//   _لئے_, _शेयर_, vuce_, mpoh,
   {{0x3947809f,0xdce9d006,0x56950294,0x645a9764}},	//   _dins_, _sveć, нант, _ifti,
   {{0x394787ca,0x291ef6b3,0x6d48ccbc,0xfbd38039}},	//   _eins_, sota_, _hida, _שתף_,
   {{0x3947f1db,0x6d48f6b4,0xf1bf002a,0x3eab4d4f}},	//   _fins_, _kida, _ayán_, rect_,
   {{0x28d21344,0x2d9947f4,0x67240c2e,0x6d48f6b5}},	//   साफि, rtse_, _ekij, _jida,
   {{0x6d48c237,0xdceb81cd,0x7cf005ec,0x28d2064a}},	//   _mida, stgħ, _bärb, सानि,
   {{0x612b09ce,0x6d4889ca,0x7d03f6b6,0x69c2be02}},	//   rülm, _lida, zins, _kroe,
   {{0x60dc3d10,0xb5fd800d,0xdce98024,0x7d03f6b7}},	// [7490] _borm, _ješt, _uveć, yins,
   {{0xb5fd8301,0xc8c927af,0x6d488079,0xa3ce801b}},	//   _mešt, राइट, _nida, शमा_,
   {{0xdb1a9099,0x60dc1520,0x3f8c803a,0xb5fd816b}},	//   _artí, _dorm, nudu_, _lešt,
   {{0x7d038157,0x6d48f607,0x656d3e9d,0xff25803d}},	//   wins, _aida, _kwah, ربای,
   {{0xb5fd803a,0x6d48e02c,0xdca5be32,0x7cf001ec}},	//   _nešt, _bida, еали, _wäre,
   {{0x6d48956b,0x394fa651,0x60dc76b8,0x3f8c8359}},	//   _cida, _rugs_, _gorm, kudu_,
   {{0xa3c106b7,0x75cb016f,0x2735816d,0x764d01b4}},	//   ूमि_, ामुळ, tånd_, _ogay,
   {{0x645a87ca,0x764d76b9,0x69c292af,0xdb0501ec}},	//   _efti, _ngay, _broe, _erhö,
   {{0x31798065,0x7d03da27,0x69c2831d,0x80b60035}},	//   ész_, pins, _croe, _उसमे,
   {{0xe8f6a00e,0xf1b2010f,0x6d48f6ba,0x6724005c}},	//   ель_, נסי_, _gida, _skij,
   {{0x78b88098,0x3947f6bb,0x3f8c8cb7,0xd4988071}},	//   _davv, _vins_, gudu_, _юрт_,
   {{0x3947ca06,0xb5fdacf6,0xa3bc8768,0x9ad381bc}},	//   _wins_, _fešt, इटर_, _dịch,
   {{0x69c2caa4,0xc332804c,0xfc46016b,0xa91d81d6}},	//   _groe, _עוד_, číme_, huži,
   {{0x6ee604c3,0x3999ca40,0x7ae9f6bc,0x3f8cf6bd}},	//   _móbi, mès_, lket, budu_,
   {{0x3999f6be,0x03a30009,0xfaa652e4,0x656d1abb}},	//   lès_, лиро, наво, _ewah,
   {{0x7ae9f6bf,0xa91d8024,0x60dc76c0,0xb5e8826b}},	//   nket, duži, _sorm, _bẹ́r,
   {{0x3999f6c1,0x60dc2277,0x6e29f6c2,0xbbbd83eb}},	// [74a0] nès_, _porm, _nyeb, ्मुक,
   {{0x2905f6c3,0xb22322e9,0x26f0097d,0xa2a180d4}},	//   nila_, умул, _चतुर_, _कॉस्,
   {{0x60dc3a9c,0x7ae9aa0a,0xd12f00f7,0x6d489bad}},	//   _vorm, kket, حمل_, _rida,
   {{0x6d4892cf,0x6e29f6c4,0x6b7b0039,0x7ae98088}},	//   _sida, _byeb, _צרכנ, jket,
   {{0x60dc4777,0x6d489039,0x2905f6c5,0x7f49f6c6}},	//   _torm, _pida, kila_, _dieq,
   {{0xd378003a,0xa91df6c7,0xb5fd81ac,0x3999f6c8}},	//   šću_, buži, _rešt, dès_,
   {{0x6d488687,0xfd690135,0xa3d48ada,0x3dd880ab}},	//   _vida, _bipụ, тойч, _দেখল,
   {{0x69c294c1,0xd00f0124,0x7c28826f,0xb5fdbd79}},	//   _proe, _الف_, _vydr, _pešt,
   {{0x6d488852,0xa92a8048,0x6e9380f7,0x3999e94b}},	//   _tida, зіне_, _حلقا, gès_,
   {{0x69c28b3c,0xb5fdb3fc,0x6722b7a1,0x290584b9}},	//   _vroe, _vešt, looj, gila_,
   {{0x28d2823c,0xa0a381e5,0xe1ef803d,0x612f9e01}},	//   ताबि, ушыл, لسی_, møll,
   {{0x3f8cf6c9,0x69c2f6ca,0x7ae9d307,0x3999f6cb}},	//   rudu_, _troe, cket, bès_,
   {{0x2905f6cc,0xc0e688cc,0x399982be,0x3f8c805c}},	//   bila_, _подк, cès_, sudu_,
   {{0x63a880ee,0x3f8c8115,0x6722822c,0xfd6901bc}},	//   _kpdn, pudu_, hooj, _zipụ,
   {{0xd7eff6cd,0x9f47826f,0x80cd86a7,0xe3b00019}},	//   _су_, šné_, तारे, یرہ_,
   {{0x656d0435,0xe7fa02f1,0x7cf00799,0x27478032}},	//   _twah, _एइजा_, _pärc, _mìnì_,
   {{0xfeb80077,0x02e10894,0x7f49ae31,0xa91d817f}},	// [74b0] _سايت_, _नवीन, _rieq, kržl,
   {{0xa91d8052,0x7ae9811e,0x25a9008e,0x6d4f9a25}},	//   tuži, zket, _ipal_, _écai,
   {{0x7d07003a,0x2d8081ac,0x61300198,0xa91d8968}},	//   mijs, šiel_, mäll, držl,
   {{0x7d0776ce,0xa91d8796,0x39b202d6,0x7bc50197}},	//   lijs, ruži, _fņs_, _irhu,
   {{0xa3b9058c,0x7cf00338,0x7c2d8326,0xb27603de}},	//   चिक_, _hära, ƙark, _בערג_,
   {{0x7d070a20,0x2a690072,0x2905ada4,0xf77304e3}},	//   nijs, lbab_, xila_, _مار_,
   {{0x7ae9f6cf,0x947480d7,0xb4aa8327,0x6114047f}},	//   tket, ادها, गड़े_, _сдру,
   {{0x63ba006a,0x3999f6d0,0x635181a9,0x799b80fc}},	//   ætni, tès_, _jāni, ttuw,
   {{0x7cf000f2,0x7ae9a8bc,0x26cd8216,0x61301cce}},	//   _lära, rket, _ineo_, käll,
   {{0x3eafcb68,0x3999c9ca,0x61303d02,0x7ae9f160}},	//   legt_, rès_, jäll, sket,
   {{0x2d8f803b,0x12e780e8,0x25a976d1,0x7bc501c0}},	//   luge_, _підг, _apal_, _nrhu,
   {{0xb8e89c6f,0x752394c6,0x3999f6d2,0x7cf48362}},	//   _लो_, lonz, pès_, _eàrd,
   {{0x2905f658,0xdce4003a,0xd7f88012,0x61300cb4}},	//   pila_, _sviđ, ază_, fäll,
   {{0xda1c03b7,0xbcfb4eed,0x7c24f6d3,0x7cf00338}},	//   _भुगत_, spén, şire, _bära,
   {{0xb4b20a16,0x232a4898,0x25a91868,0xab2a1bba}},	//   _ऐसी_, дови_, _epal_, дова_,
   {{0x6a8307b6,0x7cf00106,0x6134823e,0xb95b0362}},	//   илса, _dära, màla, _crìo,
   {{0xee3a0698,0x7523979f,0x7d070b67,0x9c7c807a}},	// [74c0] _юни_, konz, bijs, _hoče,
   {{0x7d072ee4,0xb95b0104,0x9c7ccf66,0xa2a18f85}},	//   cijs, _trìn, _koče, क्त्,
   {{0xdce404a8,0xdb01a564,0x752380e5,0x2a690300}},	//   _uviđ, _aplí, donz, bbab_,
   {{0x2d8f8fa3,0x2d808029,0x69c48110,0x224f82f7}},	//   fuge_, šiem_, _šiem, _nggk_,
   {{0x80b2835a,0x8e5703c8,0x6b830106,0x9c7c807a}},	//   _असले, דינג_, _ångr, _loče,
   {{0x26cd822e,0x7989f6d4,0x7523b00e,0x645c76d5}},	//   _eneo_, drew, gonz, ncri,
   {{0x69dddfbf,0x6f04047f,0x9c7c82d4,0x79898037}},	//   äsen, _omic, _noče, erew,
   {{0x66e3867c,0x2732001b,0x501b0039,0x2fc7006a}},	//   _коса, dáno_, _חולו, ænge_,
   {{0x66e38f2e,0x09e400ab,0x78bc16e1,0x50669be4}},	//   _тота, _নেতা, _karv, ктна,
   {{0x6f041fa7,0x48aa8162,0x30a3804a,0x75238db1}},	//   _amic, фтим_, арюв, conz,
   {{0x61300009,0x7d07026c,0x6ee60333,0x0fd08264}},	//   väll, vijs, _lóbu, ান্ধ,
   {{0x9c7c803a,0x78bc76d6,0x6f0400c3,0x7d0701ed}},	//   _doče, _larv, _cmic, wijs,
   {{0x613004b8,0x442c8355,0xf0b78077,0x7d07115c}},	//   täll, _hyd_, رایش_, tijs,
   {{0x7cf00006,0x78bc361c,0x3ebb04b7,0x6f0476d7}},	//   _pära, _narv, _waqt_, _emic,
   {{0x2bc592ee,0x2b4b00ee,0xa2b894fc,0x013781c6}},	//   विया, _picc_, ्यप्, _שרות_,
   {{0x7b641b56,0x59b68075,0x61300009,0x32641454}},	//   ртре, _अनार, säll, итув,
   {{0x78bc3eb2,0x442c8aa2,0x23698668,0x645c0144}},	// [74d0] _barv, _lyd_, ćaji_, bcri,
   {{0x7bc50267,0x7cf00106,0x3eaf8192,0x6e2d3219}},	//   _trhu, _härn, wegt_, _iyab,
   {{0x69c676d8,0x7cef8022,0x7cf01d5b,0x1dcb06a7}},	//   _erke, _børn, _kärn, ामकत,
   {{0x7cf0016d,0x7af6026f,0x959994bc,0x98b901a9}},	//   _järn, chyt, етку_, _pusē_,
   {{0x78bc3ea6,0xa2b884c5,0x2732001b,0x690b01b9}},	//   _farv, ्यन्, záno_, rżeb,
   {{0x2d8ff6d9,0x7aed76da,0x442c831d,0xb4bd81ce}},	//   ruge_, lkat, _byd_, इये_,
   {{0xeab180f7,0x67d4218a,0x7523f6db,0x212780b9}},	//   معة_, _кору, ronz, _rknh_,
   {{0x7aed76dc,0x69c60186,0x442cab0e,0x2489817b}},	//   nkat, _yrke, _dyd_, şam_,
   {{0x7aed01e2,0xe0d1804e,0x6e2d76dd,0x62829a1a}},	//   ikat, مزد_, _nyab, _ddoo,
   {{0x9c7c90d1,0x6ff38201,0xb4b20063,0xdb1a816b}},	//   _poče, ləcə, _ऐसे_, _vrtá,
   {{0x6e360063,0x7aed76de,0xdee63b78,0xd70a01e2}},	//   _szyb, kkat, гони, енне_,
   {{0x7c2582af,0x6e2d2122,0x630589a7,0x7cf4823e}},	//   ühru, _byab, _حوصل, _vàre,
   {{0xe9ce86d2,0xc8788201,0x98a59e4e,0x2718807a}},	//   _ук_, bağ_, _биле, nčna_,
   {{0xa91d8289,0x9c7ca454,0xdc4381d0,0x6e2d76df}},	//   tužu, _toče, _léči, _dyab,
   {{0x9c7c80ce,0xc2610135,0x6e2d060e,0x833a0185}},	//   _uoče, _ụdịr, _eyab, ечат_,
   {{0x645c21d6,0x7cf000f2,0x7aed12e8,0x78bc2e8f}},	//   scri, _gärn, gkat, _sarv,
   {{0x61e9c80e,0x4a750a8e,0x10a60dc8,0xf8b7816f}},	// [74e0] nyel, рыст, лиан, _असाय,
   {{0x4a431819,0x7aed038a,0x45fb01c6,0xb5fd81d6}},	//   снув, akat, _נהיג, _rešp,
   {{0x749b0051,0x7e76007b,0x7af643e0,0x78bc76e0}},	//   _אייפ, _keyp, phyt, _varv,
   {{0xe61ac68f,0x6d561eb7,0x7aed03d5,0x66769650}},	//   нде_, _kuya, ckat, ادار,
   {{0x78bc03ff,0xf7678117,0xc27b02f6,0xd17517ae}},	//   _tarv, _گا_, _ארכי, _высы,
   {{0x7ae30012,0x2fc794e4,0x412a00e8,0x6564004f}},	//   _într, _orng_, _чого_, _mtih,
   {{0xf767803f,0x7cf00106,0x746980e8,0xae048054}},	//   _دا_, _läro, трів_, _शेरन_,
   {{0x7cefa2c9,0x6d5603e4,0x41b49f33,0x6466011c}},	//   _føro, _ouya, لمبر, əriş,
   {{0x69c476e1,0x61e98065,0xdce40063,0x442cf6e2}},	//   nvie, gyel, _zwią, _wyd_,
   {{0x7f42a0d8,0x442c879f,0xdd8f8c48,0x2fc7808e}},	//   lmoq, _tyd_, _روم_, _brng_,
   {{0xd9d1035a,0x7cf00006,0x7aed00f1,0x6e2d03ac}},	//   _सप्ट, _pärn, ykat, _syab,
   {{0x7ceb0afe,0x69c401e2,0x63ba809a,0x6d5622eb}},	//   _türk, kvie, _istn, _buya,
   {{0x2d8b2737,0x6d560661,0x7cf00589,0x7a7b8e82}},	//   urce_, _cuya, _värn, _טראס,
   {{0x6130016d,0x69c476e3,0xe81d03db,0x6d564def}},	//   sälj, dvie, _बुझा_, _duya,
   {{0x7aed76e4,0x66f4800f,0x656476e5,0x6abd76e6}},	//   tkat, _आतंक_, _etih, _pasf,
   {{0x7cf0016d,0x81ae00ab,0x7bc88140,0xb5fb136f}},	//   _härl, কিন_, _mrdu, dbáv,
   {{0x7aed76e7,0x6d566a68,0x9f4783bb,0x7cf0016d}},	// [74f0] rkat, _guya, ání_, _kärl,
   {{0x7aed76e8,0x7bc8f6e9,0x98a7a752,0x6729a5dd}},	//   skat, _ordu, čiću_, _skej,
   {{0xb8dd0fd5,0x7c2902af,0x9f47801b,0x61fb8c9f}},	//   _आस_, ßerd, šní_, zzul,
   {{0xf7700307,0xb8ec023c,0xf9900019,0x29180144}},	//   سام_, _शो_, تبہ_, _ejra_,
   {{0x6ff38201,0x7bc88102,0x127a00be,0x7bc381c0}},	//   rəcə, _ardu, _בארע, wvnu,
   {{0x2eb2000d,0xbf020576,0x61fb811c,0x7bc88362}},	//   _जस्त, _लग्न_, vzul, _brdu,
   {{0x6ed8035a,0x2bc58bb8,0x3ea90854,0x7ae2c9f6}},	//   यामु, विधा, _obat_, _boot,
   {{0x61e982d6,0xa2e58767,0x61fba8cc,0xd1858037}},	//   tyel, роид, tzul, алий,
   {{0x69c00118,0x61fbe07c,0x7ae282f9,0x88d581e2}},	//   _ámet, uzul, _doot, аўні,
   {{0x3ebff6ea,0x20558162,0x3ea91ed6,0x94558326}},	//   _haut_, штир, _abat_, _zān,
   {{0x3dc91882,0x3ebf8029,0x69c43a09,0x6d5647d0}},	//   _araw_, _kaut_, zvie, _suya,
   {{0xed5a00bf,0x798d0c2d,0xfe4624b6,0x6d56114b}},	//   ком_, kraw, инно, _puya,
   {{0x2369803b,0x3ebf810b,0xdce2826f,0xed59812b}},	//   ćaju_, _maut_, zpoč, _brži_,
   {{0x6ee6002a,0x394ec612,0xddc2826c,0x317f82d0}},	//   _cóbr, _gifs_, nboš, msuz_,
   {{0x8c46324a,0x317f899b,0x04461485,0x6d560041}},	//   реве, lsuz_, ревн, _wuya,
   {{0x68e3f6eb,0x69c40029,0x1601101c,0xf1a980cf}},	//   _hond, tvie, _लेकर_, _कहान,
   {{0x68e3c337,0x09060c07,0x317f880a,0x26d2009c}},	// [7500] _kond, апан, nsuz_, _inyo_,
   {{0xe8f731b3,0xa2cc816f,0x26d201c0,0x27391de7}},	//   алу_, _दोन्, _hnyo_, ména_,
   {{0x68e3a88b,0xd90d00d5,0x69c475ee,0x3ebff6ec}},	//   _mond, ریف_, svie, _baut_,
   {{0x46a6f6ed,0x3ebf8087,0xbea68110,0x26c0011b}},	//   радв, _caut_, радк, _jaio_,
   {{0x26c00e67,0x82360077,0x7f42f6ee,0x28762252}},	//   _maio_, _خردا, rmoq, _выбр,
   {{0x6b818183,0x68e38102,0x051480ab,0xa0670087}},	//   _bvlg, _nond, িত্র_, _вара_,
   {{0x3ebf83d3,0x7cf000f2,0xdb01826f,0x7ae29c2b}},	//   _faut_, _närm, _splá, _poot,
   {{0xbab88895,0xf1a68a8e,0x38781722,0x9c7cd9c6}},	//   угих_, арон, _herr_, _doča,
   {{0x68e38205,0xdcfb803a,0x7cf0277e,0x635c01f4}},	//   _bond, _zvuč, _pärl, _očno,
   {{0x9c7ca50d,0x26d2020d,0x7ae2a943,0x290780b9}},	//   _foča, _anyo_, _woot, _cmna_,
   {{0x68e3f6ef,0x7cf004b8,0x7ae28006,0x63ba9e10}},	//   _dond, _värl, _toot, _ustn,
   {{0x7cf0016d,0xd36f80d7,0x6d4f80e7,0x387800b9}},	//   _därm, _آهن_, _écar, _lerr_,
   {{0x6f038813,0xae01035a,0xed598699,0x443a1fe7}},	//   ènci, _लेखन_, _prži_, _azp_,
   {{0x68e38065,0x2bbd84c5,0x29078101,0x26d276f0}},	//   _gond, ्मचा, _gmna_, _enyo_,
   {{0x26c00118,0xc1b68cf0,0x81cd80ab,0x61b6c1d0}},	//   _faio_, _अनुग, রহণ_, _अनुष,
   {{0x290cf6f1,0x68e38613,0x7cf003ff,0x3ea91083}},	//   lida_, _zond, _järj, _ubat_,
   {{0xdddb803a,0x4c952aed,0x3ebf8359,0x6d43948c}},	// [7510] _oduš, _липс, _raut_, ymna,
   {{0x290cf213,0xd8790250,0x26c00102,0x798d00fc}},	//   nida_, امات_, _zaio_, rraw,
   {{0x25ad8422,0x3ebfa9cf,0xdead09ab,0x902801e2}},	//   _spel_, _paut_, _shaƙ, ацца_,
   {{0x798d0063,0x290cb212,0x02a71401,0x7e7d1aef}},	//   praw, hida_, _тром, nasp,
   {{0x51840254,0x3ebf80e7,0x28b786a7,0x443a01ed}},	//   _мура, _vaut_, _असलि, _zzp_,
   {{0x9c7cb0d8,0xa91d992c,0x61ed01f6,0x438581a8}},	//   _poča, prži, myal, ملتق,
   {{0x290ca755,0x68e38e9c,0x3b0980bf,0x316682f7}},	//   dida_, _rond, леко_, _atoz_,
   {{0x68e3acad,0x5694a1a6,0x7e7d76f2,0xfbd08154}},	//   _sond, _маст, jasp, بته_,
   {{0x61ed1cbd,0x6f09f6f3,0x290c8c9f,0x224b816d}},	//   nyal, _imec, fida_, äck_,
   {{0x39590352,0x290ce478,0xa3d786b7,0x672d3fb6}},	//   _muss_, gida_, ामद_, _akaj,
   {{0x9c7c812b,0xfbd080f7,0x26c076f4,0x68e3f6f5}},	//   _kočn, _يتم_, _paio_, _vond,
   {{0x7cf000f2,0x1efa00f7,0x7e7d020d,0x613d80e7}},	//   _värm, اعدة_, gasp, dèle,
   {{0x290c8c52,0xd25682f6,0x9c7c8353,0x7cf001ec}},	//   bida_, _השנה_, _močn, _wärm,
   {{0x290ca755,0x69cb82af,0xed5994f0,0x68fa8f67}},	//   cida_, _irge, _muž_, chtd,
   {{0x6f958307,0x7f858013,0xa3d7bb6b,0xf7462109}},	//   _العض, _البن, ामि_, _леко,
   {{0x6ab58076,0x9c7c9234,0x39593aea,0x7cf00198}},	//   _अघोर, _nočn, _buss_, _kärk,
   {{0x7cf00009,0x9f460061,0x6e3b8135,0xd5b10129}},	// [7520] _järk, szló_, _nzub, ắc_,
   {{0x205676f6,0xa3d79308,0x7cf068fd,0x2d8241a2}},	//   стар, ामा_, _märk, mske_,
   {{0x9c7ca4c8,0x7afb805d,0xe45703c8,0x2a7900c3}},	//   _bočn, khut, _לייט_, _fesb_,
   {{0x290c82a0,0x6e9380f7,0xf7439821,0xf72980e8}},	//   zida_, كلما, пехо, ацій_,
   {{0x94128201,0xd90d0117,0xa2b8c1d0,0x290c82ed}},	//   əyə_, ریہ_, ्यस्, yida_,
   {{0x26c0a5f2,0x290cf6f7,0xed598289,0x6f098135}},	//   žio_, xida_, _duž_, _emec,
   {{0x69cbf132,0x290cd0a8,0x9f47826f,0x6e3b81bc}},	//   _arge, vida_, šná_, _ezub,
   {{0xbea3a6c8,0xbf168875,0x290c87d8,0x273222ef}},	//   _наск, _اورب, wida_, báni_,
   {{0x290cb64b,0x7e7d6b47,0xed598bcf,0x7ceb5e9c}},	//   tida_, vasp, _bržu_, _kürt,
   {{0x2d82003a,0x7e7d0573,0x7e64046d,0x3ce58711}},	//   dske_, wasp, _afip, _golv_,
   {{0x33f6965d,0xdeb507ac,0x69cbcc81,0xe4d784c0}},	//   _учас, обны, _erge, _دولت_,
   {{0x7afba906,0x290cf6f8,0x7ae6705d,0xd6db1e0b}},	//   chut, sida_, _nokt, уто_,
   {{0xeb14823c,0xa2d581aa,0xfa368277,0x69cb80c3}},	//   तचीत_, भार्, _اراد, _grge,
   {{0x290c90ba,0x51628135,0x2a790695,0x9c7c816b}},	//   qida_, _gọọm, _sesb_, _močo,
   {{0xe7e300c8,0x3cfa0105,0x672d0088,0xdb1aae90}},	//   _মধ্য, _उतरे_, _tkaj, _asté,
   {{0x61ed522c,0x290a76f9,0x39592176,0x672d0a5a}},	//   tyal, _amba_, _puss_, _ukaj,
   {{0x9c7c9807,0x6f0f00e5,0x2d820e06,0x00000000}},	// [7530] _ročn, micc, cske_, --,
   {{0x61ed2027,0x7cf000f2,0x6f0f76fa,0xed5980ce}},	//   ryal, _närh, licc, _ruž_,
   {{0x61ed76fb,0xaac42e2e,0xc5e680ab,0xdfd100f7}},	//   syal, _लोकक, _খেলা_, بيا_,
   {{0xed598503,0x7cef83ba,0x635c0bcf,0x6f0f0037}},	//   _puž_, _tørk, _očnj, nicc,
   {{0x7cef83ba,0x1a9a00be,0x9c7c80c3,0x7ceb6393}},	//   _høri, _דירע, _vočn, _fürt,
   {{0x92d580c8,0x80b7864a,0x27322631,0x6f0f0037}},	//   _হতে_, _असें, ráni_, hicc,
   {{0x9c7cc964,0x09d1835a,0x7ae60214,0x7afb805d}},	//   _točn, तम्य, _yokt, thut,
   {{0x2d823ea6,0x442100ff,0x7e6280e5,0x7ceb3408}},	//   yske_, _mxh_, ccop, _kürs,
   {{0xe8f9c094,0x44298063,0x7afb8859,0x6f0f46da}},	//   или_, ła_, rhut, dicc,
   {{0xa3cc0a74,0x672b820f,0x9f85a5d9,0x7afbb21f}},	//   लिम_, logj, огод, shut,
   {{0xf0920bea,0xef1a36b8,0x6d41a7bf,0x7e7b8ad4}},	//   וני_, имо_, _ihla, _keup,
   {{0x2d822e02,0x7cf00009,0x2f5491d2,0x6d5bf6fc}},	//   tske_, _tärk, ятьс, _kuua,
   {{0xa2b88105,0xed5a1b56,0x2d8418cc,0x7cf00106}},	//   ्यर्, рог_, éme_, _häri,
   {{0xa069abe1,0x2d8276fd,0xfd6481bc,0x2a7f81ec}},	//   _така_, rske_, _afrị, laub_,
   {{0xf0b8815b,0x69c9f6fe,0x6d418234,0x28c286a7}},	//   _دانش_, lvee, _mhla, _वोटि,
   {{0x2d820289,0xed5a0003,0xf26a2c18,0xa3cc00d4}},	//   pske_, _кои_, риал_, लिब_,
   {{0x6d41cfe1,0xe9da1232,0xb5fb375a,0x60c3cf3d}},	// [7540] _ohla, шка_, lcán, _kanm,
   {{0xe0d70ef5,0x60c396ce,0x3eadc8ce,0x2a7f8282}},	//   ову_, _janm, _abet_, haub_,
   {{0x14d70158,0x7cf02fc8,0x09b6825e,0x60c38247}},	//   _וויל_, _näri, _अन्य, _manm,
   {{0x60c38247,0x6d41f6ff,0x27e7016d,0x7ceb7700}},	//   _lanm, _ahla, änna_, _fürs,
   {{0xf5b69dd2,0x60c3839c,0x61303cac,0x6d418834}},	//   تصاد, _oanm, fält, _bhla,
   {{0x6d41f701,0xf366828b,0x7e62879a,0x7af98176}},	//   _chla, отин, scop, _alwt,
   {{0xbcfb02be,0x439486d2,0x46ca01d0,0x8fa30162}},	//   mpét, чайс, ियाह, _оаре,
   {{0x60c3838e,0x7cf0016d,0x656981b9,0x6d418234}},	//   _aanm, _däri, _fteh, _ehla,
   {{0xe5a68ab2,0xaaa68c78,0x60c38970,0x2cb82dae}},	//   _физи, क्षक, _banm, kerd_,
   {{0x6d418068,0xa3ba0b9f,0x2d80a585,0x80d0009a}},	//   _ghla, _आईं_, šies_, _डोमे,
   {{0x4438f702,0x60c3f703,0x26c4a057,0xfaa6bd0d}},	//   _ár_, _danm, _kamo_, _мажо,
   {{0x74138077,0x26c6f704,0x2cb8090d,0x7cfdf705}},	//   _توما, ndoo_, eerd_, _pèrg,
   {{0x60c38205,0xdced0024,0x25a6de46,0x6280f706}},	//   _fanm, _svađ, ntol_, mamo,
   {{0x4aa6b192,0x6f0f2e93,0x2cb850fe,0x80a186a7}},	//   क्रव, sicc, gerd_, _खाये,
   {{0x26118105,0x6f0f24c7,0x613005ec,0xd7e69138}},	//   _देनी_, picc, häls, _філо,
   {{0x6280f707,0xda0c0063,0x60c38247,0x26c4f708}},	//   namo, _सेहत_, _zanm, _namo_,
   {{0x68e77709,0x3eb911de,0x67ff8019,0x798402e8}},	// [7550] _pojd, mest_, _tájé, gsiw,
   {{0x4ad18076,0x3eb90778,0x8b08001b,0x2d99430f}},	//   _दोनव, lest_, _pořá, muse_,
   {{0x65698352,0x6280f70a,0x74150c48,0x2d990074}},	//   _steh, kamo, _روحا, luse_,
   {{0x3eb94acd,0xf8b78bb8,0x6280f70b,0x2d9901df}},	//   nest_, _अस्प, jamo, ouse_,
   {{0x443e8117,0xd5bb99b8,0xb0658009,0xd469879e}},	//   _azt_, рсе_, nkää, биле_,
   {{0x9f4442b2,0x7cf00006,0x9c7c8042,0x3ac78129}},	//   ájú_, _päri, _uočl, _ốp_,
   {{0x2a7f85b6,0x60c3f70c,0x3eb90074,0x2d99770d}},	//   taub_, _ranm, kest_, huse_,
   {{0xa3cc0a74,0x3eb902fd,0x8c1c012a,0x61300364}},	//   लित_, jest_, יווי, sält,
   {{0x443e8065,0x25bf8886,0xdce41408,0x60c38bb1}},	//   _ezt_, _usul_, _stič, _panm,
   {{0x6f0d770e,0x2d997277,0xdb1e770f,0xe8f99e4e}},	//   _amac, duse_, _espè, сло_,
   {{0xccf2804c,0x395ff710,0xf092093f,0x628082ba}},	//   _רכב_, squs_, ענט_, bamo,
   {{0x7cf00406,0x69cf03a8,0x628086ea,0x2ca1051e}},	//   _järv, _orce, camo, _achd_,
   {{0xcb128039,0x60c3f711,0x2d990074,0x0d830b79}},	//   _אלא_, _tanm, guse_, нлян,
   {{0x6f0d088e,0xb606816b,0x7bc18122,0xa3cf92c6}},	//   _emac, _ukáž, _kslu, शिप_,
   {{0xdce40efd,0xa50718f6,0xb5fd939c,0x1d071ed5}},	//   _utič, чера_, _ofšo, чери_,
   {{0xaabd8540,0x7cf0277e,0x877a83de,0x612f9277}},	//   ्यिक, _närv, _פאפי, pøls,
   {{0xc3328039,0xe8fa2118,0x26c4c1f1,0xe71701c6}},	// [7560] תון_, бла_, _ramo_, _מחקר_,
   {{0x7bc1811f,0x49990364,0x79840114,0x9c7c8115}},	//   _oslu, ются_, rsiw, _počm,
   {{0x4abd9b91,0xaabd8c78,0x628095e6,0x69cf01f4}},	//   ्याव, ्याक, yamo, _erce,
   {{0x6280bc93,0x273204c3,0xe73a8009,0x628fbf85}},	//   xamo, máns_, щее_, ócol,
   {{0x237f003a,0x273203a2,0x69cf0699,0xbcfb00e7}},	//   ćuje_, láns_, _grce, mpér,
   {{0x7ae401dd,0x7f5c5fed,0x4c949d7b,0x3f8781a1}},	//   ljit, _turq, фикс, _ovnu_,
   {{0x628090dd,0x26c4803a,0x60231cf8,0x66028065}},	//   tamo, _tamo_, _здра, szok,
   {{0x7ae42e08,0xada68056,0x7af60110,0x25a68115}},	//   njit, _набл, nkyt, ptol_,
   {{0x3f9a21d1,0x7cef9277,0x7cfd89c4,0xd7f88493}},	//   lupu_, _rørv, _sère, rcăm_,
   {{0x6f0d34cb,0x2d990074,0x7cef804a,0xfcaa80d7}},	//   _smac, vuse_, _sørv, _دارو_,
   {{0x3eb97712,0x6280f713,0x6f1d05a4,0xdb1e7714}},	//   test_, pamo, érco, _espé,
   {{0x2d990006,0x7f447715,0x273204c3,0xb0658198}},	//   tuse_, _chiq, dáns_, tkää,
   {{0x3eb97716,0x7ae404a8,0x6d4af717,0x60db00fc}},	//   rest_, djit, omfa, _ɗumb,
   {{0x3eb90665,0x69c2f718,0x2d99032a,0x48e393f1}},	//   sest_, _isoe, ruse_, _почв,
   {{0x3eb90065,0x6e2400a9,0x2d9922a5,0x8fa384ae}},	//   pest_, _exib, suse_, _заје,
   {{0x78ba8065,0x7ae400f1,0x6f0d2e0b,0x2d990087}},	//   letv, gjit, _umac, puse_,
   {{0x442d009a,0x672f009a,0x7cef806a,0x27320061}},	// [7570] łe_, mocj, _kørt, ránt_,
   {{0x51f811e9,0x81ae00ab,0x9c7c816b,0x656d0a5a}},	//   чную_, কিং_, _dočk, _itah,
   {{0x6f1d7719,0xdb039c32,0x2732002a,0x09a9b41c}},	//   onsc, stné, cáns_, _कह्य,
   {{0x69cf026c,0x6f1d2fd1,0x645af71a,0x6d5f27e0}},	//   _trce, nnsc, _agti, _kuqa,
   {{0x6f1d57cb,0x7cf04683,0xd1388110,0x4993004e}},	//   insc, _värv, klą_, _سیار,
   {{0x6d5f3b77,0x3f85f71b,0x11da0039,0x3af8826b}},	//   _muqa, yslu_, _וחשב, _bépo_,
   {{0x6d570a50,0x2366026c,0x6d5f771c,0x68e3008b}},	//   _mixa, _čojk_, _luqa, öndu,
   {{0x80db0076,0x60c72736,0x752e0bcf,0x629f005d}},	//   नावे, _hajm, zobz, ngqo,
   {{0xb1459d7b,0x656d313e,0x765bf71d,0x6594c53f}},	//   мнил, _ntah, _iguy, _пату,
   {{0x248c8122,0x271882d4,0x7f44771e,0x6f1d14cf}},	//   _gddm_, včni_, _shiq, ensc,
   {{0x7bc1803b,0x7cf00074,0x656d0a5a,0x26118035}},	//   _uslu, _märt, _atah, _देती_,
   {{0x60c7020f,0xa3cc0935,0x7c2907d9,0x6441f71f}},	//   _lajm, लिस_, ğerl, _izli,
   {{0x7cef8aa2,0x443c0084,0x6d450362,0x2bc598a9}},	//   _ført, _šv_, _bhha, विका,
   {{0x60c715d8,0x3e7c0104,0x27322ff3,0x7afd50fe}},	//   _najm, ật_, táns_, _alst,
   {{0x656d113b,0x7f4400ee,0xa3e086ab,0xa7fc82d0}},	//   _etah, _thiq, दमय_, ncıl,
   {{0x765bf720,0x6d5f45ef,0x273203a2,0x6d57023e}},	//   _nguy, _fuqa, ráns_, _eixa,
   {{0x7af607ac,0x60c72051,0x273203a8,0x442587b6}},	// [7580] rkyt, _bajm, sáns_, _lxl_,
   {{0x7af66a51,0x6441b8c1,0x7afd7721,0x3f9a5755}},	//   skyt, _ozli, _elst, tupu_,
   {{0xa2a6001b,0x59ba0074,0x6ea50f3d,0x60c74169}},	//   _छाप्, _उनकर, _कामु, _dajm,
   {{0x9c7c8805,0xee3aa9dc,0x7aeb8a53,0x78ba8061}},	//   _točk, оне_, _nogt, zetv,
   {{0x628412f5,0xd5b084e3,0x6441aec6,0x6b9c7722}},	//   maio, افت_, _azli, lurg,
   {{0x3f9a3859,0x29130118,0x7cf00192,0x6d4af723}},	//   pupu_, cixa_, _gärt, umfa,
   {{0x78baf724,0x2bd104e5,0x9c7c81a1,0xa2a506d4}},	//   vetv, हिया, _joči, ङ्क्,
   {{0x7cef8aa2,0x2005b07e,0x60c7009a,0x7cf03453}},	//   _børs, dzli_, _zajm, _kärs,
   {{0x7aeb81b0,0x9c7c807a,0x224200b9,0xa2a6001b}},	//   _dogt, _loči, _jzkk_, _छान्,
   {{0x7c2d807e,0x6b9c011b,0x7cf00338,0x9404011c}},	//   şara, kurg, _märs, şmə_,
   {{0x656d7725,0x78ba920e,0x9c7c807a,0xb5fb0118}},	//   _stah, retv, _noči, rcám,
   {{0x7cef8a38,0x656080b8,0x79965050,0x6b9c008b}},	//   _førs, _kumh, kryw, durg,
   {{0xdb1a80a9,0x7792803d,0x6560e871,0x7cf00338}},	//   _estã, ریکا, _jumh, _närs,
   {{0xa2b8928a,0x9c7c8669,0x672f23b3,0x79967726}},	//   ्यक्, _boči, socj, dryw,
   {{0x7c342011,0xd00fa791,0x6b9c0ba0,0x7aeb822c}},	//   верх, _рф_, gurg, _yogt,
   {{0x60c70067,0xa3cf9199,0xaf0801a8,0xcf2701bd}},	//   _sajm, शित_, _يقوم_, _ترتي,
   {{0x6aad04b9,0x656d1ec7,0x6560802a,0x291e933e}},	// [7590] rfaf, _utah, _numh, onta_,
   {{0x7b6704fa,0x272403bf,0xa3cc28bf,0xf1c880ff}},	//   _отме, mına_, लिश_, _mỡ_,
   {{0x291e8e71,0x6b45f727,0x2724080a,0x6f0280f7}},	//   inta_, lóge, lına_, fhoc,
   {{0x7bc52ec5,0x7cf0016d,0x7cef806a,0x7afd0d1a}},	//   _ishu, _färs, _nørr, _ulst,
   {{0x6560bb92,0x27240182,0x60c70390,0xe57881e2}},	//   _cumh, nına_, _tajm, дзі_,
   {{0xa3c3801b,0x7d157728,0xdb1a8118,0x7cef821e}},	//   _září_, nizs, _ortó, _rørs,
   {{0xe3b1a003,0xeb99a1f2,0x4ada8076,0xcfa40162}},	//   ارت_, чий_, भांव, _ишти,
   {{0x6f02835c,0x2b46af0e,0x84580039,0x442594a6}},	//   choc, _choc_, ובוס_, _vxl_,
   {{0x9f52001b,0xf1c880ff,0x7d15026c,0xb5290032}},	//   ází_, _cỡ_, kizs, _atọ̀,
   {{0x2eed8cfa,0xdb1a809f,0x2724061c,0x6b45a68b}},	//   _hoef_, _està, dına_, dóge,
   {{0xe73a11b3,0x7996009a,0x644181a9,0x3ea60103}},	//   зен_, zryw, _uzli, нинг,
   {{0x291ef729,0x7b030074,0x272407c0,0x60db09ab}},	//   anta_, _jõud, fına_, _ɗuma,
   {{0x9c7c9c0b,0xf1c880ff,0x7bc5772a,0xdb03928a}},	//   _soči, _gỡ_, _ashu, ntní,
   {{0xb0ce009a,0x25bf02df,0x2eed8901,0xdb038174}},	//   _होंग, çula_, _loef_, itní,
   {{0x7cf000f2,0xb602000d,0x62843577,0x261180dc}},	//   _särs, _žádn, taio, _देसी_,
   {{0x7b030074,0x272407c0,0x27f88aa2,0x39580197}},	//   _nõud, bına_, ørne_, _sirs_,
   {{0x7989aa0a,0x409601cf,0x46dd01a2,0x6b458144}},	// [75a0] nsew, ерет, यारह, cóge,
   {{0x7cf00879,0xa0a30087,0x6b9c55c7,0x02bd800c}},	//   _värs, лауд, purg, ्युन,
   {{0xb9080105,0x9c7c8668,0x7cf00884,0x6f02f72b}},	//   _मच_, _uoči, _färr, thoc,
   {{0x261185b3,0xb5aa8013,0x3cde02f1,0xdb1ac315}},	//   _देही_, كاتك_, खावे_, _ostá,
   {{0x291e82a3,0x9c7c8639,0x3958772c,0x2d9d80b4}},	//   ynta_, _močv, _tirs_, guwe_,
   {{0x69c66325,0x636783bf,0x6f02f72d,0xf1c880ff}},	//   _iske, _sına, shoc, _rỡ_,
   {{0x6f02810c,0x44441502,0x52bd80c2,0x67242aaa}},	//   phoc, _jz_, ्यूस, _ojij,
   {{0xe6ca090a,0xc7d70051,0x6e968872,0x26118128}},	//   ियोज, _אולי_, _سلطا, _देवी_,
   {{0xc1b78fe6,0x645a0267,0x25660428,0x7644772e}},	//   елых_, žtih, _nôl_, _nziy,
   {{0xf2df0104,0xa2d5816f,0x3958a372,0xf1c880ff}},	//   _nhân_, _मोठ्, örs_, _vỡ_,
   {{0xdb1ac3c7,0x7cef8aa2,0x76444f62,0x80ca00ab}},	//   _está, _tørr, _aziy, রাপ্,
   {{0x27240182,0xaaa788af,0xa3bd92ee,0xdbc78074}},	//   tına_, _गायक, इबर_, _pöör,
   {{0x4444772f,0x2b5913f0,0x7c3a8114,0x443a1061}},	//   _az_, _risc_, _hytr, _ayp_,
   {{0x27240459,0xf2df0028,0x672401bc,0x2b5900ee}},	//   rına_, _chân_, _ejij, _sisc_,
   {{0x44447730,0x6d5af731,0x2724084a,0xdb1e0510}},	//   _cz_, _mita, sına_, _espí,
   {{0x7c3a8081,0x083b8039,0xdbc782f1,0x5334282a}},	//   _mytr, _מעול, _töör, гест,
   {{0x44441738,0x80ca00c8,0x325512a0,0x0f5800be}},	// [75b0] _ez_, রান্, твар, _איהם_,
   {{0x7bc501e9,0x6d5aa95e,0x68ee07f1,0x673d21a9}},	//   _tshu, _nita, _cobd, llsj,
   {{0x3f9e811e,0x2d8b009a,0x69c6011e,0x3cde1d9a}},	//   nutu_, lsce_, _eske, खारे_,
   {{0x6d5acc26,0x3ee48098,0xa3cf99f1,0x2d9da291}},	//   _aita, лючв, शिस_, tuwe_,
   {{0x6d5acf6a,0x64a584f6,0x3f9e823d,0xa2a603a4}},	//   _bita, вала, hutu_, _छात्,
   {{0x6d5af732,0x3f9ea2b2,0x26c9805c,0xa3bd801b}},	//   _cita, kutu_, žao_, इबल_,
   {{0x6d5a878a,0x6282838e,0xdb03827f,0x261181ce}},	//   _dita, _beoo, stní, _देरी_,
   {{0x02bd8076,0xe9d99317,0x8e8480f7,0x0ed0016f}},	//   ्येन, дки_, _ملفه, _तोंड,
   {{0x6d5a80a4,0x2d8b009a,0xa2a28aed,0x79898176}},	//   _fita, jsce_, _गार्, usew,
   {{0x6d5af733,0x79898295,0xd12e80a0,0x2bc2a5ef}},	//   _gita, rsew, يمي_, _वैवा,
   {{0x3f9eecbd,0x79898609,0x2d9909ff,0x52b581a8}},	//   gutu_, ssew, erse_, _لماذ,
   {{0x6d5af734,0x7aef3db4,0x6806810c,0x6e3b808e}},	//   _zita, _noct, _séjé, _kyub,
   {{0xf2df0028,0x7ae9f735,0x44447736,0x644509da}},	//   _phân_, mjet, _sz_, _azhi,
   {{0x7ae9f737,0x3f9e854e,0x44445e93,0xdddb825b}},	//   ljet, butu_, _pz_, _oduž,
   {{0xed570dc8,0x28a6ae04,0x6d4e00f1,0x2d990333}},	//   тор_, _खाति, rmba, arse_,
   {{0x38c80bca,0x7afb8575,0x61e42d08,0x2fc782c4}},	//   کاری_, nkut, txil, _isng_,
   {{0xf2df0028,0x7aef0be5,0x7d0181a8,0x5a63396b}},	// [75c0] _thân_, _doct, _olls, ркуб,
   {{0x443a7738,0x44447739,0x29058234,0x61e446f0}},	//   _typ_, _tz_, nhla_, rxil,
   {{0x44444569,0xc8b50110,0x7afbefff,0x248786c0}},	//   _uz_, ысты, kkut, danm_,
   {{0x6d5af73a,0x7d01872c,0x7f49f73b,0x7ae9969b}},	//   _sita, _alls, _cheq, jjet,
   {{0x6d5a8025,0x7ae981c8,0x6f1d0acf,0x2905bd70}},	//   _pita, djet, érci, khla_,
   {{0xe046493f,0x684600c4,0x1d3385a8,0x65640198}},	//   _анги, _анга, анія, _muih,
   {{0x9fc70767,0x17c7091e,0x69c4009a,0xb5fb01a8}},	//   _игра_, _игри_, lwie, rcái,
   {{0x6d5af73c,0x7afbf49c,0x6aa4164d,0xb5fb00f7}},	//   _wita, gkut, ngif, scái,
   {{0x44328063,0x6d5ac16c,0x7c3a8035,0xee378048}},	//   ły_, _tita, _wytr, _ант_,
   {{0xa3cf823c,0x6d5a802e,0x9c7caeb2,0x7afbe261}},	//   शिश_, _uita, _poču, akut,
   {{0xa09b0158,0x2739773d,0x69c401ec,0x2d803ef3}},	//   וייט, ként_, hwie, _awie_,
   {{0x3f9e88bf,0x973d00ce,0x7d1890aa,0x6722ba0a}},	//   rutu_, kuće, livs, nnoj,
   {{0x973d0024,0xf19482c7,0x6564010c,0x3f9ef73e}},	//   juće, _силь, _cuih, sutu_,
   {{0x973d02a5,0x3f9ef73f,0x77638118,0x2d800035}},	//   duće, putu_, _funx, _dwie_,
   {{0xd7eff740,0x9388039d,0x386e8118,0x7ceb01ec}},	//   _ту_, кста_, _iffr_, _kürz,
   {{0x99800035,0x905781c6,0x7d18811a,0x2cad01d0}},	//   dził_, _בסוף_, hivs, řed_,
   {{0xdb1a80f2,0x973d0a20,0xdb1e0118,0x45d50992}},	// [75d0] _istä, guće, _arpó, _сопс,
   {{0xc7ad8065,0x3dc902d5,0x7f498168,0x2739016b}},	//   _بڑی_, _isaw_, _sheq, rénu_,
   {{0xccf20051,0x6e3b87d5,0x753501b9,0x248786c0}},	//   _הכי_, _syub, mozz, vanm_,
   {{0x07a4246a,0x75352fc7,0x395c9da3,0x7bd70609}},	//   раїн, lozz, _livs_, _irxu,
   {{0x3da79c74,0x7ae98e54,0xa18401bb,0xa6349138}},	//   треб, vjet, _высл, анці,
   {{0x75356ab9,0x6b558084,0xa3cf9107,0xf773066e}},	//   nozz, _išgi, शिल_, _نار_,
   {{0xa3cc0321,0x22468019,0x3ea90369,0x7ae9f741}},	//   लिए_, _azok_, _ocat_, tjet,
   {{0x24878205,0x05c3064a,0x7cfd810c,0xf36680d7}},	//   sanm_, षबाब, _tèro, دئوی,
   {{0x7ae9f742,0x9c7c9c32,0xdced0bda,0x7afbf743}},	//   rjet, _počt, _atač, rkut,
   {{0x7ae9d8ab,0x0cce00ab,0x7763bedf,0x6f198428}},	//   sjet, _রক্ত, _punx, liwc,
   {{0x3ce70076,0x7ae9f744,0xb4cf816f,0x65640198}},	//   ञाने_, pjet, षयी_, _suih,
   {{0x290581a1,0x6f198428,0x24858252,0x7cf48362}},	//   shla_, niwc, _helm_, _fàrs,
   {{0xe0ce8021,0x29037745,0x6aa40186,0x59b793e5}},	//   _лв_, _olja_, vgif, _अहिर,
   {{0x333f82a6,0xc99280f7,0xdb1a8198,0x753500df}},	//   llux_, _الوظ, _estä, gozz,
   {{0x656406cb,0x798d0428,0x6aa407b3,0x3ea90242}},	//   _wuih, esaw, tgif, _fcat_,
   {{0xdce4005c,0x69c44af7,0x2365817f,0x3169011c}},	//   _otić, twie, _mulj_, fqaz_,
   {{0x09e311b3,0x91e301f3,0x6aa40be7,0x75357746}},	// [75e0] ботн, боте, rgif, bozz,
   {{0x26c27747,0x27390548,0x69c4724b,0x51560c4f}},	//   leko_, béns_, rwie, утбу,
   {{0x6f047748,0x6aa400f2,0x28a69344,0xdb1a8009}},	//   _klic, pgif, _खासि, _ystä,
   {{0x2bd1035a,0xdb9b036b,0x26c2011e,0x973d00d2}},	//   हिरा, _אסטר, neko_, puće,
   {{0xa3cc03eb,0x6d5e494e,0x63ba82f7,0x6f042b8c}},	//   लिक_, _kipa, _sptn, _mlic,
   {{0x60c18364,0x6f04009f,0xa7860124,0x236580c3}},	//   jelm, _llic, _مشرو, _bulj_,
   {{0x60c1e7a4,0x628610e1,0x6d5e0010,0x7d188b81}},	//   delm, _keko, _mipa, rivs,
   {{0x6d5e7749,0x26c2120e,0x7cf4809f,0x291a774a}},	//   _lipa, jeko_, _càrr, lipa_,
   {{0xdced0efc,0x58868071,0x60ce0282,0x26c2011e}},	//   _stač, лына, _kabm, deko_,
   {{0x57b48396,0x6d5e3030,0x6286774b,0x60c1f74c}},	//   абот, _nipa, _leko, gelm,
   {{0xdb03826f,0x6f04774d,0xeb9789a0,0x394280eb}},	//   stná, _blic, _бих_, ēks_,
   {{0x62860052,0x26c20578,0x291a002e,0x6d5e011e}},	//   _neko, geko_, hipa_, _aipa,
   {{0x60c1f74e,0xf2df001c,0x7b030074,0x291a774f}},	//   belm, _giây_, _nõua, kipa_,
   {{0x6f043656,0x656f80e7,0x6d5e7750,0x273c84e8}},	//   _elic, _éche, _cipa, mínu_,
   {{0x6d5e078a,0x75357751,0x6286171a,0x26c20102}},	//   _dipa, rozz, _beko, beko_,
   {{0x7b640193,0x41e705e9,0x443ea715,0x628609c4}},	//   стре, ліза, _myt_, _ceko,
   {{0x161c01fe,0xad2704c1,0x6f1d0118,0xb11501e5}},	// [75f0] _पेपर_, _مردو, ércu, амаш,
   {{0x4a541a20,0x0edd035a,0x6fa88540,0x6d5e1341}},	//   скус, याकड, _कमां, _gipa,
   {{0x443ef752,0xdce4012b,0xf77000f7,0x6eac06a7}},	//   _nyt_, _stić, كان_, _झामु,
   {{0x6286105d,0x2fca00b9,0x1b7a00be,0x28d506ab}},	//   _geko, _dsbg_, _שטרע, _डोरि,
   {{0xa684835f,0x443ef753,0x60c198e8,0x7aed5fb5}},	//   слід, _ayt_, yelm, mjat,
   {{0x7aed7754,0x26c200ad,0x443e9e51,0x2903003a}},	//   ljat, zeko_, _byt_, _ulja_,
   {{0x2bd80f1b,0x60c183a7,0x26c20737,0x1d06847f}},	//   डिया, velm, yeko_, рещи_,
   {{0x41b5ac18,0x16168105,0x26c2011b,0xe6108180}},	//   асот, _देवर_, xeko_, _کشف_,
   {{0x60c195c8,0x54a78b8c,0x6289831d,0x31af0457}},	//   telm, _محاف, raeo, nüz_,
   {{0xa2d58778,0x6f16151f,0xbc6880f7,0x6b45818a}},	//   _मोर्, _smyc, _ممكن_, cógn,
   {{0x26c27755,0x6d5e063f,0x28a6800f,0x60c1f756}},	//   teko_, _ripa, _खारि, relm,
   {{0x6d5e7757,0x7f4d7758,0x7aed1369,0x63a3f759}},	//   _sipa, _chaq, jjat, munn,
   {{0x7f4d02c1,0x6d5e4f68,0xd8f58077,0x63a3f75a}},	//   _dhaq, _pipa, _پزشک, lunn,
   {{0x62860859,0x26c2775b,0xdca604bd,0x4e96003d}},	//   _seko, seko_, јави, دشگر,
   {{0x07a58b33,0x6d5e775c,0x63a3808b,0xa3d5847d}},	//   _тайн, _vipa, nunn, िटि_,
   {{0x2b40775d,0x7c3e026f,0x672980f1,0xaabda8d7}},	//   ulic_, _vypr, _njej, ्यटक,
   {{0x61fb871f,0x61e99ddb,0x628633fc,0x63a38c9a}},	// [7600] nyul, nxel, _veko, hunn,
   {{0xa3d585b3,0xe9d7239f,0x63a3acfa,0xc8e006b7}},	//   िटा_, шку_, kunn, नाइट,
   {{0x6286775e,0x0fd917ae,0x63a39be8,0x9e66bb34}},	//   _teko, льцы_, junn, авед,
   {{0x7d1c10d7,0xe9a65bc1,0xf9878077,0x2055079e}},	//   lirs, _камп, _وب_, стур,
   {{0x70c58105,0x6286807b,0x63be00b9,0xae168006}},	//   _वसूल, ðkom, _hppn, _देशन_,
   {{0x80ca00c8,0x26070327,0x63a3f75f,0x67298144}},	//   রাহ্, हनती_, funn, _ejej,
   {{0xb5fb0073,0xb4e68105,0x69d98114,0x63a3f760}},	//   ncár, _बची_, _arwe, gunn,
   {{0xb6a39a1f,0xbea39052,0x672980f1,0x7b030074}},	//   _мисл, _маск, _gjej, _lõun,
   {{0x9f5910ab,0xdb070061,0x38c8803d,0x443e8428}},	//   árí_, ntjá, هادی_, _wyt_,
   {{0x7f4d02c1,0xa3e603bb,0xd90e8bca,0x63a3c53c}},	//   _shaq, पमा_, بیت_, bunn,
   {{0x644880d2,0x69d982af,0x47354f78,0x7d1c7761}},	//   _uzdi, _erwe, йнос, dirs,
   {{0x88bc81d0,0x273ccff4,0xd8388088,0xd041811c}},	//   cněn, míns_, ngči_, ndlə,
   {{0x973d003b,0xceb38039,0x7ae2f762,0x7d1c3089}},	//   guća, חיר_, _inot, firs,
   {{0xb0d50072,0x7d1c6141,0xd90e80d7,0x31af2353}},	//   _डोंग, girs, _آید_, vüz_,
   {{0x27320019,0xd7fa84ae,0x7aed7763,0x9b680a2e}},	//   hány_, _јул_, tjat, ишта_,
   {{0x29187764,0xe70509a7,0x63be00b9,0xdb1a9b05}},	//   _amra_, _دستی, _dppn, _astú,
   {{0x7aed7765,0x7d1c0511,0x6f1d0e83,0xb5fb002a}},	// [7610] rjat, birs, misc, acár,
   {{0x6f1d7766,0x7d1c0333,0x7bdaf767,0x7c290192}},	//   lisc, cirs, _ortu, ßers,
   {{0x7aed3967,0x83f93c10,0x8e3800d7,0xa267047f}},	//   pjat, _сенс_, _مسیر_, _въгл,
   {{0xb8fe101c,0x6f1d7510,0xec360051,0x63a3f768}},	//   _दो_, nisc, _לאתר_, vunn,
   {{0x261185e8,0xd0870198,0x88bc81d0,0x63a380fc}},	//   _देखी_, _выби, vněn, wunn,
   {{0x63a3a421,0x2bd3b497,0x7ae28039,0xfbd180f7}},	//   tunn, थिला, _anot, كتب_,
   {{0x672980f2,0xaca3082e,0x7f428036,0x88bc81d0}},	//   _tjej, _adịg, bloq, tněn,
   {{0x2bd805b3,0x63a3f2d5,0x7bda9665,0xcac98009}},	//   डिता, runn, _drtu, угие_,
   {{0x6f1d7769,0x88bc81d0,0x80ca00ab,0x7d1c0085}},	//   disc, rněn, রার্, yirs,
   {{0x09059109,0x60c502af,0x7ae2f76a,0x63a3f76b}},	//   спон, nehm, _enot, punn,
   {{0x68f502a5,0x6f1d57d8,0x83aba27b,0x7e640122}},	//   _mozd, fisc, _штаб_, _pgip,
   {{0x6d4380f2,0x81c680c8,0x6f1d0e83,0x0a188077}},	//   llna, _উপর_, gisc, افیک_,
   {{0x2d8403d3,0xe8ee9a3b,0x2f55035f,0xa3cf83dd}},	//   ème_, _ел_, ютьс, शिक_,
   {{0xd37e9487,0x4aa78424,0x7ae2b29a,0x6f1d01a8}},	//   šćen_, _गाँव, _znot, aisc,
   {{0x65618073,0x7d1c48e8,0x68fca6be,0xe29a03c5}},	//   _milh, rirs, örde, лав_,
   {{0x6441cb13,0x6aa9f76c,0xadf9897d,0x27f883ca}},	//   _myli, ngef, ्नान_, ärne_,
   {{0xe9da07ac,0x7d1c776d,0xb5fb0020,0x64a6174a}},	// [7620] ыка_, pirs, scár, _лапа,
   {{0x26d2275f,0x343a0277,0xb4e6800f,0x27322b95}},	//   _hayo_, _مسجد_, _बचे_, vány_,
   {{0x26d2049f,0x63be094c,0x6441a2ea,0xdb07007b}},	//   _kayo_, _uppn, _nyli, stjá,
   {{0x7b030074,0xdd8f003d,0x69c9864e,0x26d26006}},	//   _jõul, _توی_, kwee, _jayo_,
   {{0x26d2334c,0xdd8f9368,0x6561f76e,0x644a017f}},	//   _mayo_, فون_, _bilh, šlić,
   {{0x6441972b,0xd1321a3e,0x26d23f6e,0x68f5007a}},	//   _byli, _رمز_, _layo_, _gozd,
   {{0x973d0025,0x8fa31c74,0xb6060353,0x64419532}},	//   dućn, _наре, lišč, _cyli,
   {{0x26d2544e,0x64418514,0x68e3f76f,0x497486f9}},	//   _nayo_, _dyli, _annd, олис,
   {{0x65618073,0xdce2805c,0xe29f807b,0x32029e51}},	//   _filh, spođ, óða_, áky_,
   {{0xa2da00d4,0x973d003a,0x656f82be,0xdd8f80f7}},	//   _पोस्, gućn, _écha, _أول_,
   {{0x6f1d474f,0x3202803e,0x61e48110,0x06e412c6}},	//   tisc, šky_, _šild, गांव_,
   {{0xb7db007c,0x26d24edd,0x656980fc,0x2d498333}},	//   אקטי, _cayo_, _yueh, núen_,
   {{0xe894ad5d,0x7afdaaaf,0x7cfd809f,0xb606007a}},	//   _даль, öste, _sèri, jišč,
   {{0xb6060db7,0xf76f8077,0x6f1d7510,0x3ceb83ca}},	//   dišč, بای_, sisc, चाये_,
   {{0x68f50e04,0x6f1d7770,0x249f03bf,0xb4fb83c8}},	//   _rozd, pisc, ğum_, נפלי,
   {{0x6ec48fd5,0x26d215d4,0xae9b01a8,0xaca3026b}},	//   _रसगु, _gayo_, _إضغط_, _idọg,
   {{0x291e8009,0x50f51a4e,0x6f0281d6,0xb4fa852a}},	// [7630] oita_, озат, dkoc, ्साय_,
   {{0x291e95bd,0x29077771,0xb88200e1,0x26d21d8b}},	//   nita_, óna_, _šírk, _zayo_,
   {{0xf84b0656,0x672d026c,0x26d21d8b,0x68f5298e}},	//   учай_, _kjaj, _yayo_, _vozd,
   {{0x291ef772,0x2a6681c0,0x17f801a8,0x7d1a9de6}},	//   hita_, _ngob_, حركة_, _amts,
   {{0x291eaca0,0xa3aba3e7,0x65618187,0x290c8079}},	//   kita_, कून_, _pilh, khda_,
   {{0x672d23b8,0x21ba00be,0xdb0389b9,0x973d0669}},	//   _ljaj, _דזשא, punë, kućo,
   {{0x051680f7,0x973d01dd,0x6561a445,0x81bb00ab}},	//   تيوب_, jućo, _vilh, _আছি_,
   {{0x69c98051,0x8c1c00be,0x6f02826c,0x973d00d2}},	//   twee, טווי, ckoc, dućo,
   {{0x291ed0b9,0x6441864c,0x656195f8,0x6aa980e3}},	//   fita_, _wyli, _tilh, rgef,
   {{0x69c9a8ac,0x26d27773,0xc10580f7,0x6aa981ec}},	//   rwee, _sayo_, زوجي, sgef,
   {{0xb17b04b8,0x69c9c9a6,0x26d2009c,0x973d0503}},	//   _fråg, swee, _payo_, gućo,
   {{0xe73a0767,0x050600ab,0x69cf7774,0x69dd2aa0}},	//   рем_, _ঈদের_, _osce, _orse,
   {{0x291ede8c,0xee3705e9,0x95830fe6,0x200382d4}},	//   bita_, жня_, мляе, šji_,
   {{0x973d012b,0x628b811b,0x290c8229,0x26d26beb}},	//   vrće, _hego, chda_, _wayo_,
   {{0x26d202b8,0xc7460199,0x628b8642,0x69cf6549}},	//   _tayo_, _وضعي, _kego, _asce,
   {{0x28ac2885,0xa22a0323,0x7bc18118,0xb606007a}},	//   _चाहि, ажба_, _mplu, tišč,
   {{0x628b8065,0x3b0700b3,0xdce08087,0x256f061c}},	// [7640] _mego, цето_, _jumă, _gül_,
   {{0x628bc068,0xa2da000c,0xf53f0082,0xa3e9800d}},	//   _lego, _पोर्, står_, ममा_,
   {{0x69cf2fe5,0x2d4981df,0x7bc18069,0x69dd7775}},	//   _esce, túen_, _nplu, _erse,
   {{0x91e6622f,0x444413c8,0x63a101ac,0x628b9ff4}},	//   _доме, _iy_, álne, _nego,
   {{0x444426e6,0x6f028a0f,0x7bc18358,0xf2df0028}},	//   _hy_, rkoc, _aplu, _châu_,
   {{0x44447776,0x6f099b90,0x291e8102,0x6f02f777}},	//   _ky_, _elec, xita_, skoc,
   {{0x444426e6,0x261a850a,0x628b8a58,0x0eaa00d4}},	//   _jy_, _मेरी_, _bego, _कांड,
   {{0x444400f8,0xaec39317,0x3945809f,0x1e869be4}},	//   _my_, _обсл, ells_, _флам,
   {{0x291ee26c,0x753c0063,0x628bc672,0x61e481a1}},	//   tita_, korz, _dego, _šilb,
   {{0x672d003b,0xeb9a8698,0x444448f2,0x644102f1}},	//   _sjaj, _виж_, _oy_, ülik,
   {{0x44440082,0x291eef94,0xdce982a5,0xe1ff00ff}},	//   _ny_, rita_, _steć, _ngón_,
   {{0x290cddd3,0x628bdbce,0xa2da27fb,0x76440a03}},	//   shda_, _gego, _पोल्, _byiy,
   {{0x44447778,0x753c7779,0x291ef77a,0xe0cf803d}},	//   _ay_, forz, pita_, رزی_,
   {{0x4444777b,0x628b8102,0x224b81ec,0x387f00ce}},	//   _by_, _zego, ücke_, _đuro_,
   {{0x44440578,0x987b83c8,0xcb1b0073,0x76444176}},	//   _cy_, _דרוק, аќа_, _eyiy,
   {{0x4444777c,0x290a0046,0x539b807c,0x63a70289}},	//   _dy_, _alba_, יילו, rujn,
   {{0x44444953,0x88bc801b,0xf53f3739,0x5d8401a8}},	// [7650] _ey_, vněj, tråd_, _قليل,
   {{0xd49b0676,0x4444031d,0x6f098a0f,0x2bcb016f}},	//   _три_, _fy_, _slec, ाबदा,
   {{0x6f0986da,0x6d47135a,0x444402ec,0xb8d31d9a}},	//   _plec, mlja, _gy_, _टा_,
   {{0xdb0383f8,0x69dd00dd,0x6d47007b,0x2be00105}},	//   puné, _trse, llja, _पछता,
   {{0x628b81c1,0x237f005c,0x7bc1b232,0xdb070106}},	//   _rego, ćuju_, _splu, rtjä,
   {{0x628bd728,0xdb07016d,0x88bc81d0,0x929d8035}},	//   _sego, stjä, sněj, dkła,
   {{0x6b4595d8,0xe299b592,0x656d03ac,0x4900016f}},	//   lógi, бай_, _luah, _शकतो_,
   {{0xb17b22ea,0x753c6321,0x6aad1aac,0x6f1b82a0}},	//   _tråd, zorz, ngaf, _umuc,
   {{0x6d47011a,0x672b80e8,0x673d082c,0x25708580}},	//   klja, mngj, dosj, _gàl_,
   {{0xa3bb87bd,0x65653419,0xbef600c2,0x635c0242}},	//   _ناصر_, _nihh, ुघ्न_, _dčny,
   {{0x6d4194e5,0x753c777d,0x644501c0,0x60d5777e}},	//   _ikla, vorz, _nyhi, _mazm,
   {{0x4444777f,0x656d0458,0x753c009a,0x291c81f6}},	//   _ry_, _buah, worz, _emva_,
   {{0x44447780,0x91e58dae,0x753c7781,0x7b0e826b}},	//   _sy_, _холе, torz, _dùud,
   {{0x2d9e026f,0x657b8010,0x91f681c6,0xb97a825f}},	//   čte_, _mtuh, _ממנו_, _הנסי,
   {{0xe8df001c,0x987a83de,0x7af9b597,0x63860110}},	//   _ngực_, _פאקט, _kowt, ягва,
   {{0x6b633ba1,0x63ae813c,0xe3630d9e,0x7e69f782}},	//   екса, _åbne, екси, _ngep,
   {{0x6d472588,0x753c0211,0x5bb888fd,0x6ebc10be}},	// [7660] blja, porz, _आह्व, ष्णु,
   {{0x44447783,0x20561e0b,0x3ebf833e,0x7e69d9a0}},	//   _ty_, птер, _abut_, _agep,
   {{0x44447784,0x78a3007b,0x212600d2,0x36c6a8fb}},	//   _uy_, ónva, đoh_, збег,
   {{0x60c88063,0x6d41809c,0x48dd8fb2,0x248c928a}},	//   zedm, _akla, _कोसो_, _sedm_,
   {{0x6284040e,0x26c0004f,0xae16a7af,0xa4d4804a}},	//   mbio, _mbio_, _देखन_, долі,
   {{0xb4d698e6,0x60d538c0,0x29058bda,0x673d0140}},	//   िये_, _gazm, jkla_, zosj,
   {{0x69c2837a,0xf21486a7,0x7af9b7f7,0x644500b9}},	//   _spoe, _तेज़_, _bowt, _xyhi,
   {{0x6d41f785,0x79a69bd8,0x7cfd810c,0x62840f3e}},	//   _ekla, прое, _bèrs, nbio,
   {{0x6da38ff0,0x60d5017b,0xd5c08006,0xada3e21c}},	//   _пита, _yazm, _एहिज, _патл,
   {{0x6722f355,0x26c00091,0xdce406ec,0x290582d5}},	//   lioj, _abio_, _otiđ, gkla_,
   {{0x6602ab99,0x8f3522e9,0x673d7786,0xe1ef804e}},	//   lyok, денц, tosj, نسی_,
   {{0x60c8aed5,0xe7ed82f1,0xb903ad63,0x67228084}},	//   sedm, _छपरा_, _पो_, nioj,
   {{0xb0ac035a,0xa2d58076,0x6602f787,0x673d5203}},	//   _चांग, _मोट्, nyok, rosj,
   {{0x2ec993ba,0x2905816d,0xeb05125f,0x38c88019}},	//   _रस्त, ckla_, रस्त_, _ذاتی_,
   {{0x58bb8039,0x6d470669,0x00bb8039,0x673d05f3}},	//   _המוצ, rlja, _המומ, posj,
   {{0x6d470025,0x656d7788,0x5bb8062c,0x66029a1a}},	//   slja, _tuah, ялся_, kyok,
   {{0xb606016b,0xd2340081,0x2bcb0035,0x26cb7789}},	// [7670] _práš, ентъ, ाबहा, meco_,
   {{0xb4d68c33,0x26cb4edd,0x2bce0105,0x8af00085}},	//   ियो_, leco_, _हैवा, lməl,
   {{0x20070b4c,0x6f0d778a,0x628401e8,0x60d50115}},	//   áni_, _klac, bbio, _vazm,
   {{0x6d41c6bb,0x26cb02df,0xe9df4d63,0x2121008e}},	//   _skla, neco_, _trú_, sihh_,
   {{0x20070805,0xd5bbaf07,0x9f5c801b,0x3f9831fd}},	//   šni_, ссе_, ává_, _evru_,
   {{0xee38835f,0x6f0d574b,0x1dde00ba,0x26cb07b6}},	//   чні_, _llac, मितत, heco_,
   {{0x6f0d084a,0x628f0812,0x6d41816b,0x26cb09c4}},	//   _olac, _keco, _vkla, keco_,
   {{0x64410063,0x07098013,0x36d49017,0x2ef581e5}},	//   żliw, _بيري_, _поср, _ўзар,
   {{0x59e028bf,0x290584e8,0xdb1a9b9c,0x6d4187b6}},	//   नियर, tkla_, _astó, _tkla,
   {{0x27390065,0x48058cde,0xf1d28063,0x6f0d778b}},	//   mény_, дпов, तिजन, _alac,
   {{0x6f0d087b,0x628f776d,0x26cb0216,0xbea625f5}},	//   _blac, _oeco, feco_, манк,
   {{0x6f0d01e4,0x628f778c,0x7523e0a2,0x2b490267}},	//   _clac, _neco, linz, jlac_,
   {{0x6f0d009a,0x213ed4a3,0x7bc501f6,0xee3a0a18}},	//   _dlac, both_, _aphu, інг_,
   {{0xd8258992,0x332d808e,0x628f0580,0xd009802e}},	//   _одли, lnex_, _aeco, _меле_,
   {{0x04431b62,0x8c4324b2,0x6f0d778d,0x628f0039}},	//   верн, вере, _flac, _beco,
   {{0x6f0d778e,0x26c00025,0x25ee816f,0x752382a0}},	//   _glac, _ubio_, _आपली_, hinz,
   {{0xe8fa069b,0x628f4bad,0x31679100,0x6284778f}},	// [7680] ола_, _deco, _kinz_, rbio,
   {{0x8cbf80dc,0x66028010,0x629d5ab5,0x9c7c82d6}},	//   ल्मो, vyok, _edso, _enčj,
   {{0x7a6a07b6,0x628f00e5,0x6b45ce45,0x8af0011c}},	//   _минг_, _feco, lógu, lməm,
   {{0xe5c6941e,0xe80e83b7,0xa3e1890f,0x628f00f3}},	//   дско, ानता_, दिन_, _geco,
   {{0x67228110,0x27390061,0x333fe554,0x8af0029a}},	//   rioj, gény_, doux_, nməm,
   {{0xd37aaaeb,0x6722949e,0x9f5f04e8,0x7afdbe43}},	//   очи_, sioj, ryté_, östn,
   {{0x69dd813c,0x22468590,0x68fc3852,0xbebb01ed}},	//   æsen, _syok_, _iord, diën,
   {{0x68fc6bc5,0x63aa80dd,0x2b406dae,0xc2988eef}},	//   _hord, rufn, noic_, чких_,
   {{0x68fc4237,0x26cb672d,0xbebd8084,0x7523a786}},	//   _kord, veco_, _smūg, binz,
   {{0x68fc7790,0x6f0d7791,0xcce680f7,0x6d5c017f}},	//   _jord, _slac, _تسري, jmra,
   {{0x68fc404a,0x6f0d5c92,0x3f98826f,0x7c6580f7}},	//   _mord, _plac, éru_, _كامل,
   {{0x6d4aa9cb,0x656880f1,0x522680a9,0xdb1af792}},	//   llfa, _hidh, _офла, _estò,
   {{0x628f429c,0x68fc1ae1,0x26cb411c,0x22468122}},	//   _reco, _oord, reco_, _uyok_,
   {{0x68fc006f,0x628f114e,0x656896bb,0xbebb01ed}},	//   _nord, _seco, _jidh, ciën,
   {{0x6f0d7793,0x3eaf9252,0x628f01e8,0xd6db24b6}},	//   _tlac, yggt_, _peco, _дтп_,
   {{0x6568820f,0x973d0582,0x6448f154,0x35b54f25}},	//   _lidh, kući, _mydi, _збир,
   {{0x68fc251b,0x973d0067,0x6568925b,0x6448f794}},	// [7690] _bord, jući, _oidh, _lydi,
   {{0x973d0289,0x2b490669,0x7b178087,0x6568f795}},	//   dući, slac_, nţur, _nidh,
   {{0xf7702219,0x44271918,0x68fc4a98,0xb4cb016f}},	//   لان_, _än_, _dord, ळजी_,
   {{0x61e2f796,0x6568f797,0x629d0366,0x25a6f798}},	//   _orol, _aidh, _udso, frol_,
   {{0x68fc64a2,0x973d003a,0x656888ce,0x427a03c8}},	//   _ford, gući, _bidh, _מארג,
   {{0x7afd1838,0x78718019,0x6568a549,0x2d9971a6}},	//   _host, _művé, _cidh, isse_,
   {{0x7523f799,0xc61f809a,0xe2998254,0x61e28114}},	//   rinz, _मेरठ_, пай_, _arol,
   {{0x7e6d7492,0x25a68cc0,0x7afd2791,0x7523a542}},	//   _ngap, brol_, _jost, sinz,
   {{0x68fc779a,0xbebb00f3,0x61e2f79b,0x7523804f}},	//   _yord, tiën, _crol, pinz,
   {{0x7afd779c,0x68fc04c3,0x6d450282,0x7e6d779d}},	//   _lost, _xord, _nkha, _agap,
   {{0xb8d78b9f,0x7afd038e,0xff2611d0,0x2d8d88f9}},	//   _छा_, _oost, емно, _hwee_,
   {{0x7afd779e,0x6da6220b,0x7769808e,0x6d45779f}},	//   _nost, нима, _jiex, _akha,
   {{0x656882a3,0x7e7b804f,0x7aeb810c,0xa3ab8072}},	//   _yidh, _mfup, _ingt, कूर_,
   {{0x257404b8,0x656882a3,0x7afd77a0,0xd1968039}},	//   _väl_, _xidh, _aost, _טכני_,
   {{0xa3e70f04,0xdddb88fc,0xd3721a43,0x7afd653c}},	//   ндра_, _neuž, اهر_, _bost,
   {{0x7afd07b5,0x6d45005d,0x68fc77a1,0xdb0384e8}},	//   _cost, _ekha, _sord, ytný,
   {{0x4a750196,0xcb1280be,0x68fc5e35,0xdc3c0390}},	// [76a0] тыст, אלן_, _pord, _išča,
   {{0x46c1000d,0x38c8004e,0x290e0dfa,0x4f960087}},	//   ष्ठह, باری_, ófa_, ерду,
   {{0x8cd906bf,0x7afd77a2,0x7649f7a3,0x66060e34}},	//   _फोटो, _fost, _ayey, lykk,
   {{0x7afd77a4,0x68fc0e9e,0xb907058c,0x216a24b6}},	//   _gost, _word, _मो_, _ними_,
   {{0x6f1d0722,0x63ae0690,0x45d4a109,0x2bd801d0}},	//   èrci, lubn, толс, डिका,
   {{0x7afd5a65,0x6296270d,0x25a684c3,0x9f590013}},	//   _zost, layo, rrol_, árú_,
   {{0xf3668ab2,0xa3abf7a5,0x1fb50226,0xdb039b39}},	//   нтин, कूल_, _истр, stný,
   {{0xa067138c,0x6e938013,0x6296022e,0xdd92a6ee}},	//   _часа_, _ملفا, nayo, _مور_,
   {{0x88bc81d0,0x6568b18c,0xe737a634,0xb53a10ab}},	//   knět, _tidh, _чет_, _atọ́,
   {{0x3ea009da,0x92cc00ab,0x61e2910f,0x7b15816a}},	//   _adit_, লায়_, _vrol, _náuf,
   {{0xf53f00f2,0x62964e50,0x2d8000b9,0x4034a345}},	//   från_, kayo, _atie_, тенс,
   {{0x61e28687,0xbebb00f3,0x6fb18cfd,0x7b0306ae}},	//   _trol, ciël, _अमरू, _jõut,
   {{0x7afd77a6,0x629604a7,0xc33382f6,0x2d9977a7}},	//   _rost, dayo, _גוף_, usse_,
   {{0x7afd3a1e,0xd24f80f7,0x3ea00039,0x63a105bf}},	//   _sost, _انه_, _edit_, álno,
   {{0x63ae0042,0xd00f8dc0,0xa29501e2,0xf0939101}},	//   gubn, _сф_, каві, _ענק_,
   {{0xa3e19a8f,0x629677a8,0x3958008e,0xdb1880e1}},	//   दित_, gayo, _ahrs_, ftvé,
   {{0x7afd3cc3,0x4ac281ab,0x9f5f0061,0x30a70dfd}},	// [76b0] _vost, व्यव, sztó_, ерев,
   {{0x273c816b,0xaa6439df,0x7afd00b9,0xb17b0106}},	//   míny_, утск, _wost, _från,
   {{0x28150416,0x7afd2d81,0x56958009,0x629677a9}},	//   خواس, _tost, вает, bayo,
   {{0x7afd45cc,0x629677aa,0xfe708199,0x316a02f9}},	//   _uost, cayo, مده_, _eibz_,
   {{0x4ea489f7,0x02bc82f1,0xdb1e2ba3,0xdb07128a}},	//   урха, ्जैन, _espó, nují,
   {{0xf9920bea,0xfaff01b0,0x7c3402d0,0x03a5cb24}},	//   _דרך_, _hoë_, _çerç, вико,
   {{0xdce5007a,0x776980b9,0xdb07128a,0xf53f26f4}},	//   _nihč, _tiex, hují, yrån_,
   {{0x2d8da468,0x2bc2816f,0x7e7b8c53,0xb4ce03ca}},	//   _twee_, _शहरा, _ufup, _रस्_,
   {{0x3dc901c0,0x0edd809a,0xbebb110f,0x7e648503}},	//   _npaw_, _नोएड, riël, žipr,
   {{0x26cfcd67,0x60099634,0xdb07001b,0x3ea0008e}},	//   lego_, дном_, dují, _sdit_,
   {{0xe73a0dcd,0x2d800087,0x7b030074,0x3dc902d5}},	//   ден_, _stie_, _jõus, _apaw_,
   {{0x26cf8063,0xe2908013,0xfbd284de,0x26dd81ec}},	//   nego_, _هذه_, _כתב_, ndwo_,
   {{0xe0cea2f1,0xc3328039,0x273c816b,0x00e3853d}},	//   _кв_, _דוא_, gíny_, _متغی,
   {{0xa3b589a3,0x290b80eb,0xa5a986a7,0x62961855}},	//   _जमा_, īcas_, _घिनौ, wayo,
   {{0x6296132f,0x7b030074,0x66061afd,0x672634c8}},	//   tayo, _nõus, sykk, pikj,
   {{0x6d43c1c8,0x2d80802e,0x3f85d135,0x291177ab}},	//   hona, ţiei_, mplu_, _alza_,
   {{0x6d43b07e,0x973d0668,0x26cf8cc7,0x629677ac}},	// [76c0] kona, guću, dego_, rayo,
   {{0x6d43f7ad,0x629677ae,0x2eed808e,0x224b01e0}},	//   jona, sayo, _anef_, _dyck_,
   {{0xf9f980ab,0x6296033e,0x224b0118,0x3f9c00e7}},	//   েছিল_, payo, _eyck_, évu_,
   {{0x6d4e6c20,0x8fa30d46,0x443a002a,0xd7ef00f7}},	//   llba, раце, _ixp_, تكم_,
   {{0xdb1e0063,0x9db7845a,0x6d43acfb,0xe7699c2c}},	//   _wspó, ندوز_, fona, رحمن_,
   {{0x80c10bb8,0x6d43ea30,0x260e82f1,0x6b558084}},	//   र्दे, gona, तैषी_, _išgy,
   {{0x25ee809a,0x61e6026c,0x60dc0834,0x59e00035}},	//   _आपकी_, _hrkl, _iarm, निवर,
   {{0x26cf809a,0x61d895a6,0x61e600fe,0x6d4e0192}},	//   cego_, емия_, _krkl, hlba,
   {{0x6d43acf2,0x0566917e,0x6f008083,0x6b4584f0}},	//   bona, _аван, _iomc, tógr,
   {{0x6d43e135,0x61e6017f,0x998d8035,0x70ac8072}},	//   cona, _mrkl, dzeń_, चलेल,
   {{0xd0078003,0xf6518065,0xb4ae8935,0x3cdb81ab}},	//   веќе_, _نئے_, कली_, _गोटे_,
   {{0x60dc6f8a,0x75270a0f,0x6f0080b9,0x7c3a82a6}},	//   _larm, wijz, _jomc, _ixtr,
   {{0x6f0380a9,0x6f008024,0x6b45816a,0x7527090d}},	//   ênci, _momc, pógr, tijz,
   {{0x26cff7af,0x25f5816f,0x062427ee,0x6f00bc6b}},	//   zego_, ्हती_, рфюм, _lomc,
   {{0x212ba2a2,0x752700f3,0x26cf82e7,0x57d106ae}},	//   èche_, rijz, yego_, _सनेह,
   {{0x6d4e0998,0xdb0701d0,0x26cff7b0,0x6d48810c}},	//   alba, pují, xego_, _lkda,
   {{0x998d809a,0x61e4811f,0xc093046d,0x2fca05ee}},	// [76d0] czeń_, _šilj, _aláṣ, _apbg_,
   {{0x26cff7b1,0x67240025,0x2bab0105,0x764d04b9}},	//   wego_, _zmij, _छिपा, _iyay,
   {{0x3d080063,0x26cff7b2,0x60dc77b3,0x61e677b4}},	//   _सकते_, tego_, _darm, _erkl,
   {{0x6d48f7b5,0x2bf2001b,0x6d43f7b6,0x7982f7b7}},	//   _akda, ीहरू_, wona, _otow,
   {{0x6d43f7b8,0x26cf823b,0xddc5ad94,0xdca595b7}},	//   tona, rego_, убли, гали,
   {{0xe79500d5,0x7b030074,0x26cff7b9,0x3f4782f1}},	//   _مارک, _tõus, sego_, tõus_,
   {{0x5f945955,0x6f0080b9,0x7982d9a0,0xe7870251}},	//   _вист, _fomc, _atow, _југо,
   {{0xe9d99f2b,0xf1b78105,0x799b8300,0x6d43f160}},	//   еки_, _आमदन, tsuw, sona,
   {{0x6d43f7ba,0x764d63c8,0x60dc77bb,0x7aef0573}},	//   pona, _nyay, _yarm, _mnct,
   {{0x672402fd,0x32090079,0x6d438079,0x29118c83}},	//   _smij, iyay_, qona, óza_,
   {{0xd8258103,0x26d983a8,0x60259be4,0xe4f08054}},	//   удни, _ósos_, удна, चारि_,
   {{0xa3e705b3,0x9c1481bc,0x7b0a03c1,0x290c82c4}},	//   पिन_, _kọnz, _výuk, akda_,
   {{0x64400085,0x24980197,0x61e901a1,0xdb1c03ed}},	//   əmiy, tarm_, _šeln, strë,
   {{0x69d9d9b7,0x7afbae5c,0x998d8035,0x5887a4bd}},	//   _iswe, ljut, rzeń_, _рыда,
   {{0xf99f0205,0x6d4e0101,0x32090079,0x61e60267}},	//   _avè_, rlba, eyay_, _srkl,
   {{0x7afb8500,0x672406ec,0x28c6170c,0x80c15b64}},	//   njut, _umij, र्नि, र्से,
   {{0x60dc77bc,0xdb1c19aa,0x7f3b03de,0x387f011c}},	// [76e0] _parm, ntré, _רעפו, _şura_,
   {{0xe9d701bb,0xfd690870,0x7f49913b,0x61e600c3}},	//   ыку_, _mkpụ, _akeq, _vrkl,
   {{0x60dc29e0,0xa68689b8,0xdee6ac60,0xbeaa803d}},	//   _varm, глед, ложи, فهان_,
   {{0x69cba468,0x6d5a820f,0xee3a8a8e,0x7f5b8144}},	//   _opge, _shta, нне_, _chuq,
   {{0x7d018510,0x7afb90d3,0x2579823e,0x1c1c82f1}},	//   _bols, djut, _cèl_, _भेजल_,
   {{0x7d01f7bd,0x394587f1,0x25798f33,0x6ab677be}},	//   _cols, jols_, _dèl_, lgyf,
   {{0xfd690135,0x69d9f7bf,0x61e477c0,0x6e3b913b}},	//   _akpụ, _aswe, lvil, _exub,
   {{0xdced011c,0x29038338,0x6ab60428,0x25798242}},	//   _otağ, öjan_, ngyf, _fèl_,
   {{0x7d01afc7,0x62348cdf,0xee378081,0x3914d18a}},	//   _fols, репу, _бнт_, имир,
   {{0x41bb00be,0x64568085,0x973d026c,0x91bb03de}},	//   עציע, əyin, mrći, עמיי,
   {{0xbf10035a,0x473514d6,0x5ede00ab,0x58f700be}},	//   ासून_, инос, যানে, אמיע_,
   {{0x7bdaf7c1,0xa3e19094,0xd6db0221,0x61e477c2}},	//   _istu, दिर_, хто_, kvil,
   {{0x776d062f,0x3fc8804e,0x2bd08035,0x160c01a2}},	//   _viax, ردگی_, थौरा, हनगर_,
   {{0x61db84de,0x61e46ab4,0x69c08084,0xdb1a841c}},	//   _נקוד, dvil, mtme, _estô,
   {{0x94058201,0x61e45d3e,0xa87b8039,0x69c0f7c3}},	//   _belə_, evil, _ארוח, ltme,
   {{0x2bac8d1c,0x2d848699,0x69c08cda,0xd5d48072}},	//   _घटना, _otme_, otme, _धनंज,
   {{0x69c0f7c4,0x3f9ec33c,0xa5f90012,0xdb03841c}},	// [76f0] ntme, lstu_, _репу_, sunç,
   {{0x69c0f7c5,0x7bda8074,0x3209057b,0xa3b5916e}},	//   itme, _ostu, ryay_, _जमल_,
   {{0x2579df9e,0x7d0186a8,0xff07a183,0x6d47014c}},	//   _sèl_, _rols, лядн, moja,
   {{0x7d01f7c6,0x2d9d82a0,0x3f9eddea,0xd5fb819d}},	//   _sols, tswe_, istu_, _ndụ,
   {{0x7d01909b,0xdb070125,0x6cf086af,0x51841501}},	//   _pols, stjó, चांग_, _гуса,
   {{0x3f9ef7c7,0x6d472046,0x290f00eb,0x63a5801b}},	//   kstu_, noja, īgas_, áhno,
   {{0xaa0d800d,0x9992009a,0x7d01c91e,0x3945823e}},	//   िन्छ_, czył_, _vols, vols_,
   {{0x290377c8,0x7d01f7c9,0x3d10826b,0x69c0bda6}},	//   _hoja_, _wols, _fàwo_, ftme,
   {{0x29030025,0x7afb8006,0xf4d98ae7,0xa2dd0105}},	//   _koja_, rjut, _имаш_, _पसन्,
   {{0x672bb6fb,0xdb1c0c83,0x7d0180b9,0x7afbaeac}},	//   ligj, rtré, _uols, sjut,
   {{0x290326b8,0x6d472b47,0xdb1c77ca,0x7b15802a}},	//   _moja_, doja, stré, _cáuc,
   {{0x290300a9,0xf74626bb,0x3945907c,0x96661bcb}},	//   _loja_, ремо, sols_, икне,
   {{0xe7376e38,0x6d4747d0,0xf1d9801b,0x69d9d44e}},	//   рея_, foja, _भनिन, _uswe,
   {{0x2bdc9344,0x2bda903e,0x2ed280a5,0x7c3883ed}},	//   _मनमा, भिचा, _सस्त, _çarç,
   {{0xe29a05c2,0xfc031033,0xab2a004a,0x5ecb0264}},	//   кав_, опро, вова_, িয়ে,
   {{0x672b820f,0x25a0004a,0x628d02d5,0x6a865068}},	//   jigj, _tvil_, gbao, рлаа,
   {{0xdca63dc3,0x64a60b01,0xcb670328,0xa9261343}},	// [7700] _капи, _капа, рате_, адал,
   {{0x0ce080ab,0xa0a61cf2,0x29030dd7,0x236f8168}},	//   _বক্ত, ражд, _coja_, _ligj_,
   {{0x9c7c811f,0x29030168,0x98be8ec3,0x629b83e4}},	//   _jače, _doja_, notā_, kauo,
   {{0xeab2003f,0x539b0051,0x52753f61,0x61e43635}},	//   _بعد_, _ביטו, _гуру, pvil,
   {{0xd838941f,0x80c100d4,0x25a080f7,0x6f040035}},	//   mače_, _रॉके, éil_, _moic,
   {{0xd8388669,0xdc19009a,0x290303ed,0xa4d4af8d}},	//   lače_, _włąc, _goja_, сокі,
   {{0x6f16016d,0xf8c61664,0x28c6073c,0xed578eef}},	//   _olyc, र्णय, र्णि, јој_,
   {{0xa3e705e8,0x2ba7800f,0x31c6a1a7,0xd838cd28}},	//   पित_, _गिरा, асов, nače_,
   {{0x8af00201,0x7d01007b,0xd257943b,0x28c62c4c}},	//   lməs, ölsk, иць_, र्थि,
   {{0xdde98077,0x9c7c8289,0x69c08039,0xc8669e0b}},	//   _حرفه_, _bače, rtme, итни,
   {{0x6d4777cb,0x6f0477cc,0x7bdae22f,0x69c0a52a}},	//   voja, _boic, _ustu, stme,
   {{0x28c6000c,0x3f9e9aba,0x6d47307c,0x6f04297d}},	//   र्ति, rstu_, woja, _coic,
   {{0x6d4706f7,0x2ee02e9c,0x6f0400f7,0xd838936f}},	//   toja, _daif_, _doic, dače_,
   {{0x6d470084,0x7afd8338,0x644d89ab,0xf806804a}},	//   uoja, östv, ƙait, _вчин,
   {{0x6d4777cd,0x9f591931,0x290377ce,0x8af00201}},	//   roja, áró_, _roja_, ymət,
   {{0x290377cf,0xd8388353,0x200f826f,0x3a751958}},	//   _soja_, gače_, íliš_, слар,
   {{0x9c7c8db7,0x6d473855,0x212c8090,0xcad781c6}},	// [7710] _zače, poja, oidh_, סומת_,
   {{0x6cd50bca,0x777881c0,0x7c3e00b9,0x27ea0706}},	//   _اقدا, _kuvx, _fxpr, _brbn_,
   {{0xd8388904,0x20070087,0x39498118,0x29030088}},	//   bače_, âni_, _íase_, _voja_,
   {{0x63678019,0x7d05026c,0xb95b026b,0x35f5af8d}},	//   _tűni, _hohs, _apìt, йпер,
   {{0x8af0011c,0x645a9fe7,0xe4ec108a,0x7c3b0850}},	//   rmət, _azti, _छोडि_, ğuru,
   {{0x28c606bf,0x69dd3bb9,0x62828091,0x973d026c}},	//   र्दि, _isse, _afoo, mrću,
   {{0xab29979e,0x443e8118,0x3edf0032,0x6ee181bc}},	//   лока_, _cxt_, _agọọ_, _ịbuw,
   {{0x5c380039,0x443e8118,0x2bb88035,0xd43801c6}},	//   ירון_, _dxt_, _इमरा, יטוי_,
   {{0x3ce28076,0x672984cd,0x9c7c90d3,0x212c80f7}},	//   _टोके_, _imej, _sače, fidh_,
   {{0x2903807b,0xa3c928bf,0x6f0401a8,0xa2c936cf}},	//   ðja_, ोबा_, _soic, _हॉस्,
   {{0x6f040081,0x311d914f,0x66e66b35,0x2011ba49}},	//   _poic, योगः_, бона, ázi_,
   {{0x6d5e00f1,0x212c8068,0x69dd73aa,0x27320353}},	//   _shpa, aidh_, _osse, kšne_,
   {{0x99858013,0xd83887df,0xda788698,0x7d0500ee}},	//   _التو, vače_, _тях_, _bohs,
   {{0x30798158,0x332d81b9,0x9c7c81a1,0xd5fa825f}},	//   _גאַנ, liex_, _tače, אפשר,
   {{0xd838826f,0x69dd3428,0x67298353,0x62999a08}},	//   tače_, _asse, _omej, _kewo,
   {{0x673ba0f1,0x62998247,0xf7432012,0x9f4857f7}},	//   _njuj, _jewo, _нещо, _orné_,
   {{0xd83884c4,0x6299e210,0x61fb913b,0x7bc386ae}},	// [7720] rače_, _mewo, nxul, htnu,
   {{0x673b8870,0x320d8079,0x6729804f,0x644802f1}},	//   _ajuj, iyey_, _amej, üdis,
   {{0x69dd2b2d,0xd8388369,0xa1568039,0xa2d8903e}},	//   _esse, pače_, צבעה_, _मसल्,
   {{0x7bde003a,0xe61a8088,0xdfcf1e09,0x63ae928d}},	//   _ispu, лде_, عين_, _åbni,
   {{0xdb1c28d5,0xa50a89a0,0x1d0aa109,0x67298609}},	//   ntrí, леда_, леди_, _dmej,
   {{0x7ae477d0,0x69c42dab,0x6729ba7a,0x62998242}},	//   ldit, mtie, _emej, _aewo,
   {{0x62998574,0xdee68cdf,0x320d8079,0x61eb8428}},	//   _bewo, _лови, eyey_, _argl,
   {{0xef91003d,0xa03701c6,0x5214a7ee,0x2b4082d4}},	//   _آیند, _האלה_, ждит, čico_,
   {{0x64a6a1e2,0x80dc80c8,0x629983ec,0x249a0388}},	//   _газа, বাস্, _dewo, _oepm_,
   {{0xf8d80321,0x69c477d1,0xdce981b9,0x7ae477d2}},	//   ड़िय, itie, _tweġ, hdit,
   {{0x32ca8b71,0x212c8ad0,0x332d84b7,0x6d4ac4f1}},	//   _было_, ridh_, biex_, mofa,
   {{0x62998574,0x69c477d3,0xab66df60,0x61e48110}},	//   _gewo, ktie, _увел, _šilu,
   {{0x5fdaaa9e,0x7ae41e75,0x7bde77d4,0xf8d806a7}},	//   _बनवल, ddit, _aspu, ड़ाय,
   {{0x80dc80ab,0x5f9495b7,0xa3ac86a7,0x63b5017f}},	//   বাহ্, _дикт, _कटा_, tuzn,
   {{0x7ae28074,0x93880009,0xdb1c0333,0xac181027}},	//   _kaot, йста_, atrí, бору_,
   {{0x69c42796,0x15fa92c7,0xd138a9d9,0x28c60cf0}},	//   ftie, ्हार_, lną_, र्सि,
   {{0x7bde41f1,0x7ae29581,0x909950cd,0xd0438326}},	// [7730] _espu, _maot, иват_, _banɗ,
   {{0x6729c615,0x672f009a,0x29c2807b,0x7bc3826f}},	//   _smej, licj, iða_, ytnu,
   {{0x660f00f2,0x69c420ff,0x7ae40609,0xb901123a}},	//   lyck, atie, bdit, _दस_,
   {{0x69c4212f,0xb65a0091,0x636f026b,0xd366a423}},	//   btie, _abẹ́, _dònì, _زه_,
   {{0xd24691fb,0x69c44893,0xf77092dc,0xf8a9003d}},	//   _آن_, ctie, رام_, _نگاه_,
   {{0x212a02af,0x629f008e,0x25a9f7d5,0xd0438326}},	//   _gmbh_, laqo, šalo_, _ganɗ,
   {{0x7ae286e7,0xd138809a,0xff538060,0xfd59826b}},	//   _baot, dną_, _فخر_, _kubẹ,
   {{0x17689109,0x130980e8,0xd1388110,0x3eb98257}},	//   _груп_, рний_, eną_, _øst_,
   {{0x659499b8,0x7ae2833e,0x28c61c5f,0xdc0501a2}},	//   _нату, _daot, र्वि, रहुड_,
   {{0x660f01d0,0x77c997c7,0xaca40133,0x61eb8824}},	//   dyck, алог_, twọk, _vrgl,
   {{0x69c4011e,0x672f051c,0x61e4aa7c,0x7ae2851e}},	//   ztie, ficj, _šilt, _faot,
   {{0x7ae28635,0x798d00e4,0xfbd081f9,0x657b9aef}},	//   _gaot, kpaw, _ستم_, _kuuh,
   {{0xa3e18778,0x69c404b7,0x98a591d5,0xd54a01a8}},	//   दिक_, xtie, _диле, لجسم_,
   {{0x9c7c8b67,0x3ea90722,0x3f6600e7,0xdd7a80be}},	//   _kača, _edat_, _cœur_, יטשל,
   {{0x61e98364,0x9c7c8052,0xeb9a0558,0x68e39149}},	//   lvel, _jača, риб_, _iand,
   {{0x6f1d01ec,0xa3ea890f,0x29078102,0x16098c28}},	//   chsc, मित_, _hona_, वहार_,
   {{0x68e3f7d6,0xfce6095a,0x2907f7d7,0xf2d2898a}},	// [7740] _kand, _допо, _kona_, וען_,
   {{0x68e3a8cd,0x29078c30,0xe8f76103,0xd838bad9}},	//   _jand, _jona_, олу_, lača_,
   {{0x68e3bf41,0x2907a9b8,0x28c606bf,0x7bde005c}},	//   _mand, _mona_, र्षि, _uspu,
   {{0x69c477d8,0xa3c90b86,0x2907ca00,0x645e77d9}},	//   ptie, ोबर_, _lona_, _izpi,
   {{0x6d4a8541,0x212a00dd,0xbebb0168,0xe5a3802e}},	//   tofa, _tmbh_, shëg, дичи,
   {{0x68e3f7da,0x628477db,0x7ae28c5e,0x28c6483a}},	//   _nand, lcio, _saot, र्शि,
   {{0x26c002ba,0x61e99e12,0x7ae297c9,0xa4fb37b6}},	//   _ocio_, evel, _paot, ילסט,
   {{0xf1a68c8e,0x68e390f4,0x9c7cb99a,0xe73a8098}},	//   орон, _aand, _dača, _теб_,
   {{0x2907f7dc,0xd8388503,0x628406a5,0x80ca016f}},	//   _bona_, dača_, icio, स्थे,
   {{0x68e3c3d6,0x29c28125,0x2918f7dd,0x26c00118}},	//   _cand, rða_, óra_, _acio_,
   {{0x68e3f7de,0x2907f7df,0x7ae28074,0x6f1d627e}},	//   _dand, _dona_, _taot, thsc,
   {{0x660f151f,0xd8388669,0xd1388035,0x80ca0b84}},	//   tyck, gača_, sną_, स्ते,
   {{0x9c7c9807,0x68e3f7e0,0xfa3680d5,0x645e0102}},	//   _zača, _fand, _براد, _azpi,
   {{0x32d50028,0x62861412,0x660f016d,0x29078041}},	//   _ấy_, _afko, ryck, _gona_,
   {{0xc04f9a8c,0x7d08813c,0xd838842b,0x9c83816b}},	//   _ці_, _mods, bača_, _účes,
   {{0x68e3dd51,0xd83880fe,0x6aa081f8,0x398082d6}},	//   _zand, cača_, namf, _kòs_,
   {{0x68e3f7e1,0x29078418,0xbebb0a53,0x290105e7}},	// [7750] _yand, _yona_, biër, tjha_,
   {{0x62843673,0x68e3f7e2,0x26d977e3,0x98ac8110}},	//   acio, _xand, leso_, rodė_,
   {{0x974300ce,0x3cfea776,0x61e9f7e4,0x657ba5ac}},	//   šćuj, लाने_, zvel, _suuh,
   {{0x628477e5,0x7d1a8bc5,0x63b8a3b8,0x9c7cc94f}},	//   ccio, _alts, duvn, _rača,
   {{0xfe7083f8,0x672d363a,0x291e84bf,0x2369008e}},	//   نده_, _mmaj, khta_, mmaj_,
   {{0xd8388024,0x0395c75d,0x7d088079,0xb4d582f1}},	//   zača_, прия, _cods, िजे_,
   {{0x8ccd000f,0xeb99ab27,0x7ed792dc,0x629d0359}},	//   द्यो, щий_, _وزرا, _keso,
   {{0x11d980f7,0x27320353,0x629d00e5,0x61e9d072}},	//   موعة_, kšna_, _jeso, tvel,
   {{0xdb1c4fd4,0xd83882a5,0x629d77e6,0x29078915}},	//   ntrá, vača_, _meso, _pona_,
   {{0x2ba58029,0x68e3c0ac,0x7d08a1c3,0x9c7c9c89}},	//   pēc_, _qand, _gods, _tača,
   {{0xd838842b,0x6f1b94df,0x777c01df,0x61e99c99}},	//   tača_, _kluc, _xurx, svel,
   {{0x68e383c3,0xe73a28fb,0x3ce58082,0xe6460e8e}},	//   _wand, сем_, _halv_, земп,
   {{0xe9ce9439,0xd838803a,0x2907f7e7,0x645e009a}},	//   _як_, rača_, _tona_, _szpi,
   {{0x291ec315,0x81c100ab,0xb4c802f1,0x6f1bf7e8}},	//   chta_, ংবা_, ोजे_, _lluc,
   {{0x629d77e9,0xd83882a5,0xbebb1699,0x26d902c4}},	//   _beso, pača_, riër, beso_,
   {{0x26d9160a,0x98a5802e,0x629d3183,0x26c000d2}},	//   ceso_, bilă_, _ceso, _ucio_,
   {{0x28c2901b,0x61ed803a,0x25a982a5,0xf1b9f7ea}},	// [7760] _शामि, _šalj, šalj_, nuš_,
   {{0x672d3899,0x628433d2,0x78a1a2b7,0xdb1c023e}},	//   _zmaj, scio, nalv, strà,
   {{0x629d0980,0x6f1b8037,0xa5bb4eed,0x6f09e370}},	//   _feso, _bluc, nzón, _boec,
   {{0x444404b7,0x629d079f,0x78a1e3ee,0x3f8707d0}},	//   _ix_, _geso, halv, ínua_,
   {{0x6f029770,0x7d08890f,0x5fdda120,0x50bd81a2}},	//   rjoc, _pods, _फैसल, ्भाष,
   {{0x3ea2092e,0xa06a046e,0x78a18144,0xdb0ab635}},	//   hakt_, _гага_, jalv, ntfö,
   {{0xe7b680ab,0x7d08abfe,0x3dc6f7eb,0xdb0701d6}},	//   _জন্য, _vods, stow_, vujú,
   {{0xdee3f7ec,0x6120017b,0x66e3c675,0xa03b00be}},	//   _поси, _bölg, _поса, _העלפ,
   {{0x6d4e2994,0xcad7010f,0x7ae60687,0x63b885b9}},	//   koba, לוקת_, _makt, suvn,
   {{0x672d45cd,0x9c7c905e,0x78a1ab47,0x290a0091}},	//   _smaj, _začn, galv, _joba_,
   {{0x6d4e77ed,0x26d96e77,0x25a682d5,0xdb0700e1}},	//   doba, teso_, lsol_, rujú,
   {{0x3f8a8341,0x7ae61c3a,0x291eba98,0x200282a5}},	//   ību_, _nakt, shta_, ćki_,
   {{0x629d325b,0x6d4e77ee,0xdb0700e1,0x9c7c80fe}},	//   _reso, foba, pujú, _jačo,
   {{0x6d4e156c,0x60188098,0x26d920d1,0x629d77ef}},	//   goba, _моля_, seso_, _seso,
   {{0x629d77f0,0x7ae64c0b,0x26d977ab,0x291cf53b}},	//   _peso, _bakt, peso_, _ilva_,
   {{0xe7f00a0d,0x7ae600f1,0x083b8496,0x60dade9c}},	//   घटना_, _cakt, _לעול, letm,
   {{0x7ae677f1,0x9f479a0d,0x6d4e308e,0x629d02d4}},	// [7770] _dakt, íní_, boba, _veso,
   {{0x290a278b,0x629d664a,0x60da8214,0x236901a1}},	//   _coba_, _weso, netm, smaj_,
   {{0xdb1c77f2,0xdbdc0144,0xa3e1108a,0x59ac0c28}},	//   strá, báñe, _धनि_, _चिअर,
   {{0x25a90b81,0x61e2936f,0xde1981a8,0x657f01f6}},	//   _kval_, _osol, يقات_, _kuqh,
   {{0x6f1b80f3,0x84e58073,0x63658118,0xa5098185}},	//   _vluc, долж, lóng, жела_,
   {{0x3ea21799,0xd83882d4,0x65770372,0x7ae663b9}},	//   zakt_, jačo_, _jixh, _zakt,
   {{0x444477f3,0x9c7c9601,0x67d42094,0x61e2ada4}},	//   _xx_, _tačn, _пору, _asol,
   {{0x68e775ec,0x7b1581ac,0x6d4e34e6,0x63a8808e}},	//   _hajd, _záuj, zoba, _dvdn,
   {{0xe29f1ca8,0x78a1f4c8,0x61200019,0xc245a4b6}},	//   _með_, talv, _föld, ьник,
   {{0x80bd816f,0xdb0380f7,0x36e606a7,0xaca381bc}},	//   _शाळे, isné, _जोड़ी_, _maịl,
   {{0xf7460b26,0x3ea25a73,0x2ba780d4,0xa9c4803d}},	//   дено, takt_, _गिटा, وزیو,
   {{0x61200019,0x272200ff,0x291c97ab,0x09f981a8}},	//   _zöld, _móng_, _elva_, _وفاة_,
   {{0x6d4e298e,0x7ae677f4,0x3ea204fe,0x444477f5}},	//   toba, _rakt, rakt_, _sx_,
   {{0x68e71f2a,0x7ae9d17f,0x7ae677f6,0x61ed77f7}},	//   _najd, ldet, _sakt, dval,
   {{0x6d4e3928,0x290a1b37,0x27220028,0x7ae600f1}},	//   roba, _roba_, _nóng_, _pakt,
   {{0x6d4e0cb7,0x7ae9f7f8,0xc0528039,0x8f9a8496}},	//   soba, ndet, _שזה_, _ויקי,
   {{0x69c9c561,0x26d20578,0x7ae62c9f,0xc3328039}},	// [7780] ntee, _ibyo_, _vakt, דון_,
   {{0x7ae60393,0x27220028,0x3ead8214,0x68e701c0}},	//   _wakt, _bóng_, _adet_, _cajd,
   {{0x28cf95fb,0x7ae677f9,0x69c98364,0x3ce706af}},	//   त्यि, _takt, htee, _छोटे_,
   {{0x7ae99807,0x69c9f7fa,0x3a3f2cf6,0xa25b00e7}},	//   jdet, ktee, _župe_, _icôn,
   {{0xd6e080c8,0x68e747c7,0xa5da915f,0x7ae9f7fb}},	//   ণালয, _fajd, تبار_, ddet,
   {{0xa3ea901b,0x3ea0007b,0x09bc80c8,0x27320353}},	//   मिल_, _leit_, _অনলা, kšno_,
   {{0x25a6c072,0xdb1c006a,0x63bc01fa,0x2d800bfd}},	//   ssol_, rtræ, nurn, _luie_,
   {{0xf8ce801c,0x69c9aadb,0xdb1c3f7e,0x8af00085}},	//   _cứng_, ftee, stræ, zlən,
   {{0xdb1c0efa,0x63bc77fc,0x69c981b4,0x67228c53}},	//   mträ, hurn, gtee, mhoj,
   {{0x6aa403ae,0x63bc77fd,0xdb1c05ec,0x26d21088}},	//   haif, kurn, lträ, _abyo_,
   {{0x8c3c87d9,0x2018f42a,0x9c8383fb,0x60da8214}},	//   _beğe, ári_, _účas, retm,
   {{0xdb1c2a93,0x63bc77fe,0x7d1e1b46,0x69c98079}},	//   nträ, durn, _alps, btee,
   {{0x8c3c87d9,0x69c98a0f,0x673d1c02,0x61e28234}},	//   _değe, ctee, rnsj, _usol,
   {{0x61ed5c34,0x26d202ec,0x63bc77ff,0x63b5066f}},	//   vval, _ebyo_, furn, trzn,
   {{0x63bc003a,0xc60700c8,0x3ea02dc4,0x69a41513}},	//   gurn, _লেখা_, _feit_, _चौबी,
   {{0x61ed81e2,0xe2f801e5,0x61ed07b3,0xa3b68035}},	//   _šali, месі_, tval, _जिन_,
   {{0x62340134,0x80c800c8,0x68e77800,0x2722001c}},	// [7790] вету, রজন্, _pajd, _sóng_,
   {{0x3ea00352,0x7ae98019,0x644501e9,0x3f8729af}},	//   _zeit_, zdet, _txhi, ínuo_,
   {{0x61ed0f52,0x75354412,0x69c98102,0xf6500019}},	//   sval, mizz, ztee, _مئی_,
   {{0x75354806,0x19951006,0xd2500117,0x6f0d7801}},	//   lizz, _памя, انے_, _joac,
   {{0x25a9f802,0x2ee90867,0x68e700ee,0xa3e7063a}},	//   éal_, _maaf_, _tajd, पिक_,
   {{0x753501c1,0x2edc0996,0x2366826f,0x7bca84e1}},	//   nizz, _बस्त, _ahoj_, ftfu,
   {{0xc7c416d4,0x4fc446b2,0x78a502f7,0x43758162}},	//   _исти, _иста, mahv, нуит,
   {{0x69c98364,0x23668069,0x753501e8,0x67228c53}},	//   ttee, _choj_, hizz, choj,
   {{0x7ae99d95,0x28cf18b1,0xe1f1806b,0x26dd8247}},	//   rdet, स्थि, اسب_, mewo_,
   {{0x3ea00352,0x7ae9b2b9,0x26ddf803,0x6aa47804}},	//   _seit_, sdet, lewo_, zaif,
   {{0x753504b7,0x69c9b737,0x637581a1,0x6f0d7805}},	//   dizz, stee, _ušno, _boac,
   {{0x69c9f0d9,0x28cf000c,0x61200061,0x501a01c6}},	//   ptee, स्ति, _kölc, פורו,
   {{0x4a9a80be,0x3ea02c9f,0x6b819be0,0xdb1c0aaa}},	//   _זינג, _veit_, _hulg, ntrå,
   {{0x3ea001ec,0x2b4200b9,0xc0e2c1a4,0x6b8186ae}},	//   _weit_, _sjkc_, _бошк, _kulg,
   {{0x6aa400f6,0x6b81ce08,0x680a8085,0xf8b2825f}},	//   taif, _julg, nədl, _עשה_,
   {{0xf7d68039,0x0cdc8743,0x2ee91306,0x6289f806}},	//   _נופש_, _यस्म, _gaaf_, nceo,
   {{0xe9d74709,0x6df300f7,0x6aa42cc4,0x753575dc}},	// [77a0] нкт_, _مكيا, raif, bizz,
   {{0x7535047f,0x63bc7807,0x7e647808,0xebe61383}},	//   cizz, purn, _izip, _зооп,
   {{0xf1ac0540,0xe50380c2,0x28c283eb,0x749b01c6}},	//   _चिकन, लानि_, _शासि, _מייפ,
   {{0x28cf8b3b,0xe5c6a8a7,0x26c273c6,0x73e32361}},	//   त्ति, еско, ngko_, _союз,
   {{0xdb1c3cac,0xceb304de,0xed5a8eef,0x127b03de}},	//   rträ, ריד_, под_, _מאכע,
   {{0x61e6003a,0x53e6817a,0xdb1c7809,0x09d880ab}},	//   _iskl, ециа, strä, তিমা,
   {{0xd9430a94,0x99bc80c8,0x61430110,0xdb1c0106}},	//   _сери, _অনেক, _сера, pträ,
   {{0x200d0059,0x9c7ca365,0x2b401ca5,0x28c2a776}},	//   çmiş_, _kačk, nnic_, _शाहि,
   {{0x7e6401bc,0xf98f9190,0x2b404d40,0x2bac8072}},	//   _nzip, یبی_, inic_, _घटका,
   {{0x2b40780a,0x9c7c931b,0x6fc4016f,0x6b81805f}},	//   hnic_, _mačk, ांपू, _fulg,
   {{0x4438f0ab,0x6f0d5b21,0x7535022b,0x23668069}},	//   _är_, _poac, vizz, _thoj_,
   {{0x3cfe9d2a,0x78a500d2,0x29038106,0x09d880ab}},	//   लावे_, zahv, öjar_, তিবা,
   {{0x753523b5,0xd6e300ab,0xe33780be,0x657a8c14}},	//   tizz, যালয, _אראפ_, _kith,
   {{0x636580ab,0x2b40805c,0x645a816b,0x22590338}},	//   róne, čicu_, _kyti, _rysk_,
   {{0x75354412,0x6b8184c3,0xd90e826a,0xf3670705}},	//   rizz, _xulg, _نیک_, етан,
   {{0x67d3000d,0x9c7cc96c,0x753575dc,0xdbdc016a}},	//   nějš, _bačk, sizz, _cáña,
   {{0x3a75196f,0x7b64160f,0x290e8041,0x680a8085}},	// [77b0] тлар, утре, _kofa_, zədl,
   {{0x657af80b,0xb4df816f,0x98be81d0,0x52dd864a}},	//   _nith, _तसे_, votě_, _मस्स,
   {{0x7b1c82be,0x61e6780c,0x43950993,0x78a518c2}},	//   _réun, _eskl, _шанс, rahv,
   {{0xf77088ca,0x657aaab6,0x8ccd0996,0xdb01803e}},	//   مان_, _aith, द्रो, _ovlá,
   {{0x6463003b,0x645a8176,0x657a8c49,0x6b8182f1}},	//   štić, _ayti, _bith, _sulg,
   {{0x7aed0dde,0x271e090f,0x6b81f80d,0x657a803d}},	//   ldat, _पत्र_, _pulg, _cith,
   {{0x657a81e4,0xdb1c0bbd,0x7aed0e8e,0xfaf181a8}},	//   _dith, strå, odat, لثة_,
   {{0x6b81dd8f,0xf99f0247,0xb4cd0bb8,0x657aa7c9}},	//   _vulg, _kwè_, रभु_, _eith,
   {{0x657a9997,0xf99f06c0,0x645a9761,0x628988d8}},	//   _fith, _jwè_, _eyti, rceo,
   {{0xdb1c0168,0x7982de33,0x9f5f04e8,0x3f8331d4}},	//   turë, _duow, rytý_, _kuju_,
   {{0x3f83063e,0x9783803d,0x7afd000b,0x2ca7bbad}},	//   _juju_, دیبه, _onst, mand_,
   {{0xa29580e8,0x657a8234,0x765b808e,0x2d9f8133}},	//   _раді, _zith, _kyuy, _kwue_,
   {{0xd00e853d,0x2b404811,0x290ea388,0xf99f06c4}},	//   ملی_, vnic_, _fofa_, _nwè_,
   {{0x7afd2ac0,0x2ca79598,0xe0d985a8,0xdbdc01fa}},	//   _anst, nand_, _цвк_, _báða,
   {{0x64a32844,0xdb0183fb,0xfaa6096b,0xdca31509}},	//   раса, _zvlá, каво, раси,
   {{0x78a38bc5,0x2b0486b7,0x7aed009c,0x2ca7f80e}},	//   _henv, वायु_, gdat, hand_,
   {{0x7aebae1c,0xe8ea0087,0x21a610ef,0x02e20105}},	// [77c0] _magt, ммад_, тизм, _पसीन,
   {{0x7afd780f,0x31230196,0x2ca7bba4,0x7aebac15}},	//   _enst, адуг, jand_, _lagt,
   {{0xb4664317,0x657abf0f,0x3f8300d2,0x25ad9faf}},	//   _школ, _rith, _cuju_, _avel_,
   {{0x7aeb9066,0x9c7c9408,0x28c60af3,0x657abbd6}},	//   _nagt, _tačk, र्जि, _sith,
   {{0x776982a3,0x54360416,0x67d3001b,0x657a8387}},	//   _dhex, _سرگر, vějš, _pith,
   {{0xd9461eb5,0x2ca7f810,0x61467811,0x61e40c53}},	//   _реги, gand_, _рега, mwil,
   {{0xc7a325f1,0x9c7c8668,0x8fa63941,0x7bce5d46}},	//   _виск, _jači, _шаве, ntbu,
   {{0xdd92806b,0x657a8051,0x645a850f,0x9f4a8722}},	//   _نور_, _with, _vyti, _urbà_,
   {{0x78a3f812,0xe737eb35,0xd8389b46,0x9966be32}},	//   _benv, _рет_, mači_, ктол,
   {{0xd1050a74,0xd838811f,0xd83a81e5,0x8af00085}},	//   रायण_, lači_, дэм_, rməy,
   {{0x61edf813,0x94069f33,0x2d9205ee,0x61e47814}},	//   _šalt, _جواه, _atye_, hwil,
   {{0xb8f989a3,0x78a385f8,0xd838aa06,0x65950087}},	//   _डॉ_, _eenv, nači_, ламу,
   {{0xa3ea83eb,0x61e400f3,0xa3de809a,0x290eef9b}},	//   मिक_, jwil, दौर_, _tofa_,
   {{0xc27b8f60,0x78a3832b,0x2d84804f,0xba3b0cfa}},	//   _חרדי, _genv, _mume_, _beïn,
   {{0x69c0f815,0x2d84f816,0xd8389502,0x46b48697}},	//   lume, _lume_, kači_, ुलाह,
   {{0x28c60076,0xc8c63a6a,0x3ea4813c,0xd1389fc3}},	//   र्घि, र्घट, _nemt_, lią_,
   {{0x9c7c8eef,0x2d84802e,0x60f913cd,0x7aed1b31}},	// [77d0] _dači, _nume_, нная_, rdat,
   {{0x7bda803b,0x7aed412a,0xdce8801b,0xdbde8118}},	//   _optu, sdat, _vidě, _líña,
   {{0x7aed7817,0x76b9f818,0xba3b03b2,0x69cd6de3}},	//   pdat, елер_, _geïn, stae,
   {{0x9c13819d,0xd838811f,0x63ba00e1,0x9c7c85f3}},	//   _bọnk, gači_, átne, _gači,
   {{0x2d84acd2,0x3cfe826c,0x7bda80eb,0xd1388110}},	//   _cume_, _bntv_, _aptu, kią_,
   {{0x9c7cf819,0x8c45bf61,0x7aebf81a,0x69c0f81b}},	//   _zači, леле, _sagt, dume,
   {{0x7aebacb7,0x2d8481df,0x31340009,0x78a380e7}},	//   _pagt, _eume_, _терр, _renv,
   {{0x7b1587a3,0x2d848b2c,0x6d551d2b,0xd838826c}},	//   _náut, _fume_, hoza, cači_,
   {{0xa3e3800f,0x2ca7f81c,0x78b2007b,0x61200106}},	//   _पैर_, pand_, _ákvö, _möln,
   {{0x7aeb9a70,0x6009afa5,0x80e100ab,0x41058198}},	//   _wagt, еном_, নাক্, узов,
   {{0x29110a2b,0xd05c0201,0xec158154,0x3ea61229}},	//   _moza_, _barə, _حواد, линг,
   {{0xc9f59e7b,0x51f5804e,0x69c0c461,0x61e4002f}},	//   _مستع, _مستر, bume, ywil,
   {{0x6d439627,0x69c08918,0x2d8400e7,0xd1388035}},	//   onna, cume, ême_, bią_,
   {{0x9c7c807d,0x2722009f,0xd83881dd,0x26cf016d}},	//   _sači, _dóna_, zači_, _ögon_,
   {{0x2ca594d1,0x68e1dab6,0x39898dfa,0x9c7c8110}},	//   _meld_, meld, _hús_, _pači,
   {{0x28cf8eb4,0xa3b6809a,0xba3b009f,0x7d1c1c89}},	//   त्रि, _जिस_, _veïn, skrs,
   {{0xd838803b,0x6724226a,0xb1460652,0x626600a9}},	// [77e0] vači_, _ilij, гнал, уваа,
   {{0x28cf0128,0xdcfb812b,0x68e1b8ad,0x2d848088}},	//   स्लि, _otuđ, neld, _rume_,
   {{0x9c7c81e2,0x6724781d,0x69c0bb66,0x9b460eca}},	//   _tači, _klij, zume, _مندو,
   {{0x68e1d54f,0x6d43f81e,0x69c0ccde,0x78a880c3}},	//   held, enna, yume, zadv,
   {{0x6724120e,0xd838803b,0x363680f7,0xdd8f80f7}},	//   _mlij, rači_, دراس, كون_,
   {{0xd838811f,0x69c0a52e,0x9c7c8bda,0xb5fd82d4}},	//   sači_, vume, _mačv, _izšl,
   {{0xd37aae87,0xd838817f,0xa0672c54,0x7ae0ed97}},	//   нчи_, pači_, _бара_, temt,
   {{0x6d4391cd,0xd3788da4,0x5b14a159,0x79862fb9}},	//   anna, _opće_, рмит, _kukw,
   {{0x79860010,0x6aa6008d,0x6d553b7b,0xdbde8118}},	//   _jukw, _mekf, yoza, _víña,
   {{0x2ca5905d,0x69c0b2b1,0x6724781f,0x68e1d54f}},	//   _geld_, rume, _alij, geld,
   {{0x67240613,0x6d5a84b7,0x6ac689a7,0xd1388d42}},	//   _blij, _ikta, _مقام, rią_,
   {{0x68ee518b,0x78a8c799,0xd1388110,0x9c7cacf6}},	//   _labd, sadv, sią_, _bačv,
   {{0x6282f7bf,0x672400c3,0x6f1d5d7e,0x395e890d}},	//   _igoo, _dlij, rksc, plts_,
   {{0x67242203,0x7e7d81ac,0xceb40085,0x25ec81ab}},	//   _elij, _úspe, _edə_, _आईनी_,
   {{0x6d550019,0x29114444,0xa3ea92c6,0xaca3019d}},	//   roza, _roza_, मिट_, _ngụg,
   {{0x290c803a,0x57fb8051,0x79865854,0xab6203bf}},	//   ljda_, _טלוו, _bukw, şünc,
   {{0x29114e15,0xaca3019d,0x6d5a8d77,0x6d488390}},	// [77f0] _poza_, _agụg, _okta, _ojda,
   {{0x68ee02c1,0x291ef820,0xb274223c,0x657e0122}},	//   _cabd, nkta_, слуш, _giph,
   {{0x72d52a96,0xa2d00a16,0x29110b67,0x1a65003d}},	//   _конф, _डॉक्, _voza_, _چیزی_,
   {{0x539a0051,0x6d5a81cd,0xfaff020f,0xef1f0457}},	//   _שירו, _akta, _unë_, nkü_,
   {{0xdbde87ca,0x6605884b,0xd838acf6,0x636580e1}},	//   _síða, рпла, maču_, fónn,
   {{0x5bb5e013,0x68ee0079,0x273209d1,0x6282be6e}},	//   асиф, _gabd, ršni_, _agoo,
   {{0x2ca5837a,0x68e1a653,0x39898118,0x6120595d}},	//   _veld_, veld, _sús_, _möll,
   {{0xe9d98607,0x7c2b8d11,0x2ca5831d,0x68e19412}},	//   вки_, _đorđ, _weld_, weld,
   {{0x13de00c8,0x63a4807d,0x7aef0229,0x13068009}},	//   ডিয়, ćina, _mact, рный_,
   {{0xe8f6a187,0x9c7c80fe,0x672402ce,0x7d7980d5}},	//   аль_, _račv, _slij, _شمار_,
   {{0x6c848013,0x3eab2651,0x68e18e20,0xd706060a}},	//   _المم, fact_, reld, азни,
   {{0x7bc3bef2,0x398980f7,0x539a8039,0x25a0802e}},	//   munu, _tús_, _ייעו, ţile_,
   {{0x7b7491fb,0x7bc3dd13,0x776d0079,0xa9a5b0bb}},	//   _اطلا, lunu, _dhax, _тилд,
   {{0x59a9108a,0x78a7000d,0xdca30cae,0x4a44a22c}},	//   _चौधर, _nejv, жари, _унів,
   {{0xbb5601a8,0x68ee0162,0x2336161a,0x79860326}},	//   لنسب, _rabd, ахар, _sukw,
   {{0x7aef7821,0x958611c7,0xf7720117,0x68ee045f}},	//   _cact, _клие, _بات_, _sabd,

   {{0x7bc3a9d1,0x67f004be,0x09b580be,0x645e0035}},	// [7800] hunu, kójá, יפּט_, _wypi,
   {{0x3f87b8c4,0x9c7c9f66,0x68ee201e,0x201a0168}},	//   _kunu_, _začu, _qabd, typi_,
   {{0x4ea6d750,0x2ba5000f,0x78a7496c,0x3f879c89}},	//   арла, गीदा, _dejv, _junu_,
   {{0x7bc3a723,0xe80686ce,0x7a2c0036,0xa6e2007b}},	//   dunu, षमता_, _côté, áðhe,
   {{0xcd06831f,0x55069df3,0x1a9b00be,0x68ee0326}},	//   ички, ичка, _ביכע, _tabd,
   {{0x21a302a4,0x7ae44d5d,0x7e6984a8,0x636580e1}},	//   _фирм, leit, _dzep, fóno,
   {{0x7bc3f822,0x66e69ae2,0x237f026f,0xb226807b}},	//   gunu, _кова, ňuje_, kvæð,
   {{0xb0248142,0x7ae47823,0x3f9a0198,0xdb1c13de}},	//   _ngườ, neit, mppu_, drrë,
   {{0x9c7c836f,0x69c47801,0x7bc3838a,0xacea8187}},	//   _raču, nuie, aunu, _имаа_,
   {{0x3f878182,0x9c7c803b,0x7bde120c,0x7ae42ec7}},	//   _bunu_, _saču, _oppu, heit,
   {{0x7ae47824,0x776281df,0x61eb809f,0x291ef825}},	//   keit, olox, _esgl, rkta_,
   {{0x7ae41fa0,0xe29ac094,0xdc3b81c6,0x6124a63e}},	//   jeit, _рад_, _בעבר, _dòla,
   {{0x7bde2324,0xd8388024,0x6b88db21,0x9f658019}},	//   _appu, vaču_, _hudg, ítés_,
   {{0x80c22d63,0x61200201,0x2d994799,0x7c2b87c0}},	//   _लागे, _bölm, rpse_, _ömrü,
   {{0x7ae4593e,0x06bc80c8,0x7aef05dc,0x80aa1055}},	//   feit, _ইউনি, _pact, टरने,
   {{0x6d58f826,0x6b88a833,0x69dd026c,0x7ae4011b}},	//   hova, _mudg, _ppse, geit,
   {{0x69c41220,0x6d58a8ee,0xd838812b,0x673d0d86}},	// [7810] guie, kova, raču_, misj,
   {{0x2b498289,0x6d5885b9,0x7bc3807e,0x3ea901c6}},	//   čaci_, jova, yunu, _heat_,
   {{0x7ae42c22,0x6d47003a,0x7e698019,0x3ea900ee}},	//   beit, mnja, _szep, _keat_,
   {{0x926b0196,0x7ae40548,0x14c9816f,0xef19822b}},	//   _арга_, ceit, _राहण, _biża_,
   {{0x6aad09ca,0x69c40087,0x6d5884e8,0x7e60810c}},	//   maaf, cuie, fova, _cymp,
   {{0x3ea90af9,0x6365f827,0x7bc3d32b,0xfce58171}},	//   _leat_, tóno, tunu, соко,
   {{0xd7c9003d,0x628681d6,0x25640338,0x2d810af8}},	//   _حوزه_, ľkon, följ_, _mihe_,
   {{0x7bc385b2,0x68e50009,0x6aad276a,0x7f5b805d}},	//   runu, lehd, naaf, _ukuq,
   {{0x6d589807,0x7bc3d568,0x65949ad3,0x3d948c9d}},	//   bova, sunu, _мату, _митр,
   {{0x7bc3f34b,0x6d588efc,0x3f87811f,0x7ae402af}},	//   punu, cova, _punu_, zeit,
   {{0x6d470289,0xbb858013,0x673d026c,0x141981a8}},	//   dnja, _الصي, fisj, _حياة_,
   {{0x7ae404c3,0x2d810198,0x643a83de,0x3f8780fe}},	//   xeit, _aihe_, _געענ, _vunu_,
   {{0x7ae47828,0xcb128039,0xaa088591,0x6aad0079}},	//   veit, _מלא_, _نزول_, daaf,
   {{0x2d9e003e,0x409580f7,0x7ae4289c,0x395c8267}},	//   ďte_, _الغر, weit, _gkvs_,
   {{0x612004b8,0x7ae4618b,0x61e9f829,0xab2a197d}},	//   _följ, teit, lwel, гова_,
   {{0xe7ec95bc,0x69c4782a,0x6aad2580,0x935a186e}},	//   _जनता_, tuie, gaaf, ургу_,
   {{0x7ae4782b,0x61e9d820,0x6d47005c,0x81d58264}},	// [7820] reit, nwel, bnja, হিক_,
   {{0x7ae4782c,0x6d470024,0x2d810578,0xd00a1182}},	//   seit, cnja, _gihe_, лезе_,
   {{0x7ae45412,0x61e9f814,0xa2e60c9b,0x6d5e019d}},	//   peit, hwel, _лонд, _ikpa,
   {{0x61e9f82d,0xd3788d26,0x8cdac537,0x290300c3}},	//   kwel, _opća_, प्नो, _enja_,
   {{0x69c41e3a,0x9c7c8353,0x612101bc,0x25640338}},	//   quie, _načr, _ịlek, jölk_,
   {{0x40ab1e5c,0x256981a8,0x6f161a1a,0xef1982a6}},	//   _مخفی_, túla_, _loyc, _viża_,
   {{0x6f04782e,0x63a4805c,0x661d009a,0x6d5e0870}},	//   _onic, ćino, zysk, _mkpa,
   {{0x070c85e8,0x6d58f82f,0x6d4702a5,0x4900001b}},	//   _सचिव_, sova, znja, राको_,
   {{0x6d588f20,0x5e4a9541,0x28cf542e,0x442080eb}},	//   pova, _спам_, स्कि, ņi_,
   {{0x3f8a10e1,0x6f042e5b,0x6722f830,0x644f8035}},	//   _kubu_, _anic, lkoj, _ście,
   {{0xa3e70d38,0x6d4704c4,0xb5fd85b9,0xf1b980e1}},	//   _मैं_, vnja, _vyše, vyše_,
   {{0x0dcb1cf4,0x6d5e0870,0x95cb028b,0x6aad0079}},	//   луги_, _akpa, луга_, xaaf,
   {{0xe287853d,0x673d4ee2,0x61e98234,0xdb0a8118}},	//   _اطمی, risj, cwel, nsfí,
   {{0x92c500ab,0x3039803d,0x673d00e8,0x3f9801a9}},	//   _এসে_, اتیک_, sisj, _otru_,
   {{0xc2eb80ab,0x67228009,0x6aad004f,0x4034cf78}},	//   কারি_, kkoj, taaf, _фейс,
   {{0x6d470fda,0x1fce00ab,0x69c0ad70,0xc29919bb}},	//   snja, রবাস, orme, рках_,
   {{0x8af00201,0x3f8a00e4,0x6aad1bad,0xb1150951}},	// [7830] vlət, _aubu_, raaf, омаш,
   {{0x6d4002be,0x69c08c41,0x213ee350,0xa3e880d4}},	//   émat, irme, nith_, यबा_,
   {{0xdbe30118,0x61e98234,0x61248176,0x201e8196}},	//   _téña, zwel, _lòlo, nyti_,
   {{0x95998638,0x3f8a00a4,0x7bc75e24,0x61e9adf5}},	//   атку_, _dubu_, muju, ywel,
   {{0xd5bbc03d,0x7bd50cdb,0x7bc73855,0xa2270a19}},	//   усе_, ltzu, luju, _طرحه,
   {{0x201e81e2,0xa19424e0,0x0395a442,0x61ef07f1}},	//   kyti_, _харч, ория, _iscl,
   {{0xeb99e059,0xdb1c160a,0x251c0158,0x213eb70d}},	//   ший_, ctró, רווא, dith_,
   {{0x201e81e2,0x8af00201,0x7d17002a,0xb0658009}},	//   dyti_, llər, _loxs, hdää,
   {{0x6b82f831,0x7bc77832,0x61e9adae,0xe61380f7}},	//   _diog, huju, uwel, _عشر_,
   {{0x8af00201,0x61e9949d,0x7bc77833,0x6f041388}},	//   nlər, rwel, kuju, _snic,
   {{0xa0699c45,0xfbdd83b7,0x18698abe,0x61e9f834}},	//   рана_, _महिम, рани_, swel,
   {{0x81e000ab,0x6b82f532,0x2b490088,0xdddb80c3}},	//   থিত_, _giog, jnac_, _zguš,
   {{0x92678077,0x8af00201,0x7d1714cf,0x20d5804a}},	//   _ادام, klər, _boxs, _дійс,
   {{0x53dd800c,0x6b82826c,0xfbdd8519,0x2bc69b91}},	//   _महाश, _ziog, _महाम, रूवा,
   {{0x48ee835a,0xa87980be,0x672989a4,0x8af00085}},	//   _असतो_, _דאַר, _olej, dlər,
   {{0xe29a03a7,0x798382af,0x3f8a2cf6,0xab660221}},	//   раа_, _hinw, _rubu_, івал,
   {{0x6aab8065,0x8af00085,0x7983f46f,0x3f9800c3}},	// [7840] _megf, flər, _kinw, _stru_,
   {{0x6729b9e9,0x6aab8019,0x798390e4,0xd91007d2}},	//   _alej, _legf, _jinw, ریز_,
   {{0x4fea2118,0x61ef1621,0x6d5c1f21,0xdd998176}},	//   рмен_, _escl, mora, _atň_,
   {{0x9e669383,0xd6d980e8,0x2c17001b,0xadc30091}},	//   овед, йті_, नहरू_, _afẹf,
   {{0x67229a04,0x672981c0,0x8af00085,0x6b82851e}},	//   rkoj, _dlej, blər, _riog,
   {{0x412a0c8e,0xdb1c07e2,0x7af60110,0x07a61133}},	//   _того_, ctrò, ldyt, _магн,
   {{0xdcfa80eb,0x6b82847f,0xdfd2623a,0x6729f835}},	//   _citā, _piog, _تيز_, _flej,
   {{0x6d5c1044,0x81bd00ab,0x213e8428,0x798b83f7}},	//   hora, _আহত_, with_, _bugw,
   {{0x7bc70668,0x69d67836,0xaca4046d,0xb0658198}},	//   zuju, ntye, _atọw, ydää,
   {{0x6d5c4124,0x201e81e2,0xdddb825b,0xdce880eb}},	//   jora, tyti_, _uguš, _vidē,
   {{0xe51f808e,0x28cf0128,0x213e9997,0xf0930039}},	//   _भवति_, स्टि, rith_, ונת_,
   {{0x201e8110,0x8af00201,0x798381ec,0x3f848326}},	//   ryti_, zlər, _einw, _jimu_,
   {{0x7bc71e92,0xceb38039,0x6d5c7837,0x8af00085}},	//   wuju, ויר_, fora, ylər,
   {{0x6d5c4a34,0x7bc72659,0x291849a0,0x61e284be}},	//   gora, tuju, _nora_, _ipol,
   {{0x68e8f838,0x8af00085,0x44257839,0x389b81c6}},	//   medd, vlər, ál_, _דיונ,
   {{0x7bc773cd,0x68e8f83a,0x61fd025b,0x7bd50102}},	//   ruju, ledd, _prsl, rtzu,
   {{0x8c3c8179,0x2cac8355,0x2918783b,0x9487002e}},	// [7850] _deği, _oedd_, _bora_, _мынд,
   {{0x25fe858c,0x6d5c4bad,0x68e8d1a7,0xc8671c9b}},	//   लिनी_, cora, nedd, отеи,
   {{0x8af00086,0x6729f83c,0x29184d78,0xddc40654}},	//   rlər, _plej, _dora_, _iziš,
   {{0x61e2f83d,0xd3668077,0xf7708872,0x8af00085}},	//   _opol, _سه_, نان_, slər,
   {{0xd2468307,0x29180931,0x7de78013,0xc33200be}},	//   _أن_, _fora_, تسام, _טוט_,
   {{0xd0068307,0x636583a2,0x291816c9,0x3eafc948}},	//   _كل_, móni, _gora_, sagt_,
   {{0x61ed58b2,0x2bc6801b,0x61e28d88,0x6365b6af}},	//   lwal, रूला, _apol, lóni,
   {{0x130980e8,0x7e7d826f,0xc8788214,0x6d5c07c6}},	//   сний_, _úspo, ceği_, zora,
   {{0x61ed1175,0x636585e4,0x68f556a2,0x7b1c8036}},	//   nwal, nóni, _kazd, _réut,
   {{0x68f55a65,0x68e88365,0x3ead8fb0,0x2cb132d8}},	//   _jazd, gedd, _heet_, jazd_,
   {{0xb4e78076,0x6d5c3b86,0x25a90812,0x61ed2485}},	//   यजी_, vora, _awal_, hwal,
   {{0x61ed5baa,0x6d5c08c4,0xd5b800eb,0xbebb0168}},	//   kwal, wora, ņām_, dhës,
   {{0x68e8a27f,0x2d85f83e,0x7ae98074,0x6365807b}},	//   bedd, _kile_, meet, jóni,
   {{0x61ed586b,0x3ead88ae,0x7ae9d087,0x6365816a}},	//   dwal, _leet_, leet, dóni,
   {{0xf0928039,0x6d5c783f,0x69c9c21e,0xe1ff04be}},	//   _אנו_, rora, luee, _aró_,
   {{0x6d5c4e64,0x63658511,0xa0269ea9,0x2d85f840}},	//   sora, fóni, stöö, _lile_,
   {{0x6d5c11d6,0x26d20578,0x29186e51,0x61fb83b2}},	// [7860] pora, _icyo_, _pora_, nvul,
   {{0x3f848010,0x26df8135,0x0e5702f6,0x29180df6}},	//   _simu_, _abuo_, _משפט_, _qora_,
   {{0x7ae998d0,0xe9ff00ff,0x29187841,0x2cac804a}},	//   keet, _tiếc_, _vora_, _redd_,
   {{0x2d85f842,0x68e8b311,0x63658118,0x7bc1026c}},	//   _aile_, zedd, bóni, šluc,
   {{0x3ead81e0,0x7ae9f843,0xaad50beb,0x63658118}},	//   _deet_, deet, _डॉटक, cóni,
   {{0x2b918028,0x68f513ec,0x6d4a9986,0x644f809a}},	//   _bác_, _gazd, unfa, _ścia,
   {{0x61e28259,0x2b918142,0x3f84822e,0x6d4a9d5b}},	//   _spol, _các_, _timu_, rnfa,
   {{0x2d85f844,0xa3ad85b3,0x2907a225,0xb998835f}},	//   _eile_, _कबर_, _anna_, ових_,
   {{0x2d85862d,0x68f5017b,0x05769ec9,0x68e8f845}},	//   _file_, _yazd, _فائد, tedd,
   {{0x7d1a016d,0x3a3704de,0x859b8039,0xfe45815b}},	//   ötsl, פרים_, _לשמו, _تکمی,
   {{0x7d088022,0x69c47846,0x7ae9a2b2,0xbebb0168}},	//   _inds, hrie, beet, dhër,
   {{0x2d85f847,0x69c43dca,0x68e8f848,0x290781e8}},	//   _zile_, krie, sedd, _enna_,
   {{0xc3338039,0x7d1aa488,0x68e885ee,0x61e2f849}},	//   _אוף_, _kots, pedd, _upol,
   {{0x14df8cce,0xc16f835f,0x69c4784a,0xbebb00f1}},	//   प्पण, _її_, drie, thës,
   {{0x7d1aed3c,0x63a90067,0x2b918028,0x61ed3160}},	//   _mots, ćeno, _xác_, wwal,
   {{0x69c400ed,0x61ed6874,0x6b860ad4,0x63659e31}},	//   frie, twal, _cikg, tóni,
   {{0x69c4784b,0x239580eb,0x6b86784c,0x2907f84d}},	// [7870] grie, _māja_, _dikg, _ynna_,
   {{0x6365960a,0x7bcacebd,0x61ed784e,0x98b90071}},	//   róni, kufu, rwal, ілет_,
   {{0x68f51601,0x29070459,0x61ed270e,0x69c400c6}},	//   _vazd, ına_, swal, arie,
   {{0x2d8584be,0x7bc38024,0x63658e15,0x2b91801c}},	//   _sile_, vrnu, póni, _rác_,
   {{0x2a6690af,0xa3cf835a,0x6e228065,0x7d1a8417}},	//   _nyob_, वून_, gyob, _bots,
   {{0x3eada468,0x85e8835f,0x7ae9f84f,0xf99203c8}},	//   _weet_, ядів_, weet, _ברך_,
   {{0x2d85822e,0x7ae99711,0xdd918117,0xdbf78424}},	//   _vile_, teet, روں_, ंटेड_,
   {{0x69c9a71e,0xf773815b,0x394c8039,0xfd4e81bc}},	//   tuee, _ساز_, ends_, _kekọ,
   {{0x1dd19516,0x4cb300c8,0x7d1a9c02,0x20188009}},	//   _समित, _জানু, _fots, ärin_,
   {{0x2b918104,0x672d566b,0x2d858ad0,0x7ae992e5}},	//   _tác_, _alaj, _uile_, seet,
   {{0x61200125,0x672d7850,0x6f1b86c0,0x69c401ac}},	//   _tölv, _blaj, _kouc, zrie,
   {{0xe28ef851,0x98ad9010,0x26cf8288,0xf8dd03ca}},	//   _ја_, ının_, nggo_, न्तय,
   {{0x6f1ba218,0xee37054c,0x61200019,0x799d0069}},	//   _mouc, дня_, _költ, _ntsw,
   {{0x684592b2,0x69c47852,0x6f1b9243,0x290780e8}},	//   _онла, vrie, _louc, _unna_,
   {{0x3cf0809a,0xeb971073,0x23695989,0x69c47853}},	//   _इससे_, дис_, flaj_, wrie,
   {{0x6d439066,0x23697854,0x69c40367,0x61ed8110}},	//   hina, glaj_, trie, _šaly,
   {{0x63a4856f,0x798700f3,0x2a6681c0,0xf2d280be}},	// [7880] ćini, _bijw, _xyob_, כען_,
   {{0x69c68353,0x69c47160,0x672d0042,0xfd4e81bc}},	//   škeg, rrie, _zlaj, _dekọ,
   {{0x6f1ba2a2,0x23697855,0x7f428264,0x28dd0b04}},	//   _bouc, blaj_, tioq, न्धि,
   {{0x69c41f19,0x7d1a8074,0x6fc5816f,0x9f5d00e1}},	//   prie, _sots, _विनं, _prvé_,
   {{0x7d1ad915,0xdd8f8c3b,0x9f658019,0x80ad00ab}},	//   _pots, لون_, ítás_, _চার্,
   {{0x6d43b5b2,0x7bcaf856,0xb0dd5845,0x6f09c1e5}},	//   gina, tufu, न्दग, _enec,
   {{0xfbcf80a0,0x7d1a81a1,0x395ef857,0x6d4e490d}},	//   لتي_, _vots, vots_, inba,
   {{0x1b7780f7,0x7bcaf858,0x6600808e,0xba3b1412}},	//   وصية_, rufu, _trmk, _geïs,
   {{0x6d43f859,0x7bd8e4f9,0x3ea6f85a,0x9663932a}},	//   bina, stvu, mbot_, _акте,
   {{0xb5fd85b9,0x3ea68428,0x6120007b,0x7d08806a}},	//   _myšl, lbot_, _tölu, _unds,
   {{0xcb6a9b1c,0x672d27ef,0x395e81a9,0x9982928a}},	//   _даже_, _plaj, rots_, šků_,
   {{0x6d4e785b,0x613200ec,0x3a269bf5,0x61e6785c}},	//   enba, _fælg, _омег, _opkl,
   {{0x7ae2b66f,0x61320366,0x672d18f1,0x6664047f}},	//   _ibot, _kæld, _vlaj, върз,
   {{0xb3470073,0xfd4eaaaa,0xdb150061,0x63538493}},	//   _opçõ, _rekọ, mszé, măna,
   {{0x61e60110,0xd30f80ff,0xfd4e81bc,0x3ea680e4}},	//   _apkl, _mệnh_, _sekọ, kbot_,
   {{0x68f88022,0x9f4c877f,0x290a0247,0x91f28105}},	//   _havd, _èdè_, _anba_, _अनाज_,
   {{0x7ae28077,0x497510fc,0x291c9619,0x6365f85d}},	// [7890] _mbot, елас, _kova_, mónt,
   {{0x6d43b7c9,0xeb1b835a,0x3dc680f5,0x6f1bf85e}},	//   xina, _फक्त_, drow_, _souc,
   {{0xa3d600a5,0x6f1b956b,0xe610803d,0xa3e7009a}},	//   _समय_, _pouc, یشه_, _मैच_,
   {{0x6d43f85f,0x68f88168,0x41c7064a,0x291c94cb}},	//   wina, _lavd, _लिपस, _lova_,
   {{0x6d43f860,0xd30f8028,0xfce5b6ac,0x6f1bc844}},	//   tina, _bệnh_, еоло, _vouc,
   {{0x7aed4a7b,0x0d84835f,0x68f8807a,0x7ae29bcc}},	//   leat, влін, _navd, _abot,
   {{0x61320022,0x3ea6f861,0x6f1b824d,0xf8b2007c}},	//   _sælg, bbot_, _touc, _תשל_,
   {{0xdb1c7862,0x3dc6b4ec,0x20030326,0x6f09f863}},	//   strö, brow_, _irji_, _unec,
   {{0x6d43dedf,0xa2d08ebf,0x61200019,0x2734001c}},	//   pina, _धार्, _tölt, _hãng_,
   {{0x63a90e78,0x6132013c,0x291c88e9,0x63ba007a}},	//   ćenj, _vælg, _cova_, štni,
   {{0x291cf864,0x3f917865,0x6d418197,0x7aed336e}},	//   _dova_, _juzu_, _imla, keat,
   {{0xdb1c02be,0x6565008e,0x06b000ab,0x6fc0a263}},	//   ntrô, _akhh, _কাহি, _विरू,
   {{0x7aed0102,0xa6db007b,0x273400ff,0x281280d7}},	//   deat, miðl, _lãng_, نویس,
   {{0x7afb8102,0x621a807c,0x61320366,0xdd8f0290}},	//   ldut, _מונק, _kæle, صوف_,
   {{0x6d4e04fe,0x64570118,0x69c213ba,0x187580be}},	//   rnba, _cxxi, _लिही, _אײַך_,
   {{0x3ebf86cb,0x636583a8,0x291c81a1,0x23b10935}},	//   _ndut_, cónt, _zova_, _जबरद,
   {{0x6fc59d2a,0xb0b6800f,0x6462009a,0x6286826f}},	// [78a0] _विडं, _आजमग, _świę, žkov,
   {{0x25a003ec,0x20567866,0x3ea69916,0xb5fd816b}},	//   _itil_, нтер, wbot_, _vyšl,
   {{0x9c7c9807,0xb4ac0996,0xe29a0638,0x27e782f7}},	//   _obča, खरी_, _нан_, _jpnn_,
   {{0xbbe900d5,0x3f91011e,0x200c04b7,0x66047867}},	//   _کریم_, _duzu_, _ġdid_, _krik,
   {{0x3ea6bbb9,0x7d1e7868,0x0cd49242,0x69db80f1}},	//   rbot_, _kops, волю, jtue,
   {{0x7afb8118,0x3dc681c6,0x6604003d,0x2d927869}},	//   edut, rrow_, _mrik, _muye_,
   {{0x26c0786a,0x7bce786b,0x3f912752,0x3ea68362}},	//   _odio_, nubu, _guzu_, pbot_,
   {{0x26c0022e,0x291ca6f4,0x68f88ec3,0x6604786c}},	//   _ndio_, _sova_, _savd, _orik,
   {{0x3202803e,0x7bce0867,0x3f897616,0x3945f86d}},	//   íky_, hubu, _riau_, fils_,
   {{0x26c06f6c,0x7bce6c4b,0xc05a8196,0xadb781a8}},	//   _adio_, kubu, зім_, _أهلا_,
   {{0x39960ae1,0x59c281ab,0x6604786e,0x2d920326}},	//   _læs_, _शिवर, _arik, _auye_,
   {{0xe2928013,0xd378b8c1,0x38c6846d,0xceeb01a8}},	//   _إذا_, _opći_, _bírà_, أردن_,
   {{0xae0383db,0xa3d3035a,0x3945809f,0x69db8f0c}},	//   लियन_, हून_, bils_, ctue,
   {{0x66040bc5,0x291c847f,0x3945f605,0xd7f080f7}},	//   _drik, _uova_, cils_, _نكت_,
   {{0x81dc80c8,0x66041b0e,0x63658118,0x4034917f}},	//   ডিও_, _erik, cóns, _шекс,
   {{0x6604786f,0x2b098035,0xd05c0326,0xdb07021e}},	//   _frik, वाएँ_, _harɗ, nsjø,
   {{0xf9930c2b,0x98c709b8,0x3f91011f,0x58d524f5}},	// [78b0] ابر_, فغان, _suzu_, коат,
   {{0x7bce7870,0x7aed4cc6,0x33290df6,0x6f0d136f}},	//   bubu, seat, skax_, _hnac,
   {{0x80d88a74,0x6d477871,0xf8b383c8,0x853c0039}},	//   _माने, mija, רשע_, _מגזי,
   {{0x23668069,0x6d418267,0xdcfe0162,0x998901d6}},	//   _nkoj_, _smla, _tipă, dzať_,
   {{0xf7708277,0x6f0d7872,0x7ed4a6ee,0x69db9a25}},	//   حال_, _mnac, ازما, xtue,
   {{0x8c458254,0x518401a1,0xcd980039,0xfce5d7f5}},	//   келе, _буса, עדות_, токо,
   {{0x3945907c,0xaca301bc,0x63ad825b,0x6f0d0bfd}},	//   vils_, _akịd, ćano, _onac,
   {{0x4905035a,0x64410035,0x533283a7,0x05c9975d}},	//   _होतो_, źliw, иејт, _रिपब,
   {{0xc6928051,0x6595bb34,0x44298029,0x3945cbec}},	//   _כאן_, _разу, ņa_, tils_,
   {{0x6d418fc4,0x6f0d7037,0x95ee001b,0x7afb8037}},	//   _umla, _anac, _छनौट_, sdut,
   {{0x69dbf873,0x7d1e007d,0xf09204de,0x3945e4ca}},	//   stue, _rops, יני_, rils_,
   {{0x7d1e1601,0x0caa0ebf,0x4427f874,0x69dbf875}},	//   _sops, कर्म, myn_, ptue,
   {{0x693592bc,0x49bb9381,0xb6ba8039,0x7d1e7876}},	//   _инду, _راشد_, וצרי, _pops,
   {{0x6da31927,0x2360803b,0x7bce7877,0xb4ac0540}},	//   рира, čije_, tubu, खरे_,
   {{0x628f3f6f,0x4427c3c9,0x6b8bf878,0x7d1e0087}},	//   _bgco, nyn_, _kigg, _vops,
   {{0x7bce3ced,0x6b8b822b,0x26c0111b,0x628f09ab}},	//   rubu, _jigg, _udio_, _cgco,
   {{0x6d477879,0xcb670c6e,0xe9da035f,0x7bce1152}},	// [78c0] bija, тате_, ька_, subu,
   {{0x6b8b9da3,0x64590063,0x7d1e0efd,0x442781b0}},	//   _ligg, _świe, _uops, kyn_,
   {{0x69c98613,0x8cd70035,0x2cb80866,0xfaff03ed}},	//   hree, _बातो, mard_, _ikën_,
   {{0x4427831d,0xe5a68cc1,0xe5c6a903,0x69c9a722}},	//   dyn_, види, вско, kree,
   {{0xf2d31a6a,0x527502fb,0xca750a41,0xdce18176}},	//   _דער_, _буру, _буры, _eklč,
   {{0x2cb81009,0x69c9802e,0x44278114,0xb9070264}},	//   nard_, dree, fyn_, _মো_,
   {{0xd9432c87,0x61431155,0x44278428,0x6b8bf87a}},	//   _тери, _тера, gyn_, _bigg,
   {{0x236d8353,0x51f88009,0x96a200d4,0x9a86904b}},	//   glej_, ению_, _क्लॉ, купл,
   {{0x7de584c1,0x63a9003a,0x25ec809a,0x87558098}},	//   _مسلم, ćeni, _आईटी_, _сърц,
   {{0x68fc6bf2,0x6f0d408d,0x25a6a2ca,0x4427831d}},	//   _jard, _snac, mpol_, byn_,
   {{0x44388082,0x68fc4f9e,0x63a48025,0x6b8bccfd}},	//   _år_, _mard, ćins, _figg,
   {{0xfaa6a070,0x68fc787b,0x6d470ae9,0x69c9a06b}},	//   _радо, _lard, wija, bree,
   {{0xa2d790a1,0x628681ac,0x6602ce25,0x2d8cde16}},	//   _यात्, ľkos, nvok, _kide_,
   {{0x2d8cf87c,0x6b8bcef6,0x6143c4f1,0x02cb001b}},	//   _jide_, _zigg, _кеча, िल्न,
   {{0xa5cc800f,0x25698061,0x2d8cf87d,0xb8208264}},	//   _समझौ, múlt_, _mide_, _ফেরত_,
   {{0x2d8cecba,0x68fc058f,0x6d476749,0x656e0083}},	//   _lide_, _aard, sija, albh,
   {{0x68fc787e,0x3a753dd8,0x3eb92bbd,0x27ea0101}},	// [78d0] _bard, улар, mast_, _apbn_,
   {{0x44f52850,0x44278198,0x3da40081,0x660284dc}},	//   _спос, yyn_, _тръб, dvok,
   {{0x68fc5665,0x6d45787f,0x5184096f,0x628f01e8}},	//   _dard, _imha, рута, _tgco,
   {{0x3eb97880,0x2d8c83d3,0x68fc0362,0x6602143c}},	//   nast_, _aide_, _eard, _šoki,
   {{0x4427e8c2,0x2d8c9c04,0x2d9c007a,0x6720f881}},	//   wyn_, _bide_, _čvek_, _domj,
   {{0x4427c276,0x68fc2530,0x6b8ba257,0x7afd15c1}},	//   tyn_, _gard, _sigg, _hast,
   {{0xe2998a8e,0x7afd7882,0x2d8c8091,0x6b8ba176}},	//   най_, _kast, _dide_, _pigg,
   {{0x4427c555,0x69c9a71e,0x3eb91796,0x2b9880e7}},	//   ryn_, tree, jast_, _déc_,
   {{0x3eb92fc8,0x3a2920d5,0x7afd2921,0xc3340039}},	//   dast_, nyap_, _mast, יוק_,
   {{0x68fc1613,0x69c98a62,0x2d8cc4bd,0x629b847f}},	//   _xard, rree, _gide_, scuo,
   {{0x6b8be60c,0x777b81c0,0x5eab00ab,0x2cb87883}},	//   _tigg, _khux, _কাজে, vard_,
   {{0x6d4511cd,0x69c9a388,0x752181ec,0x3eb92b2e}},	//   _amha, pree, _holz, gast_,
   {{0x2d4d0267,0xc0e58323,0xd49180ff,0x7e6d018e}},	//   džeb_, _болк, _làm_, _cyap,
   {{0x7afd0665,0x3f8ddb06,0x78b51b4e,0x6ed60006}},	//   _aast, _lieu_, _nezv, _भावु,
   {{0x66028824,0x68fc7884,0x3eb906ae,0x7e6d34e7}},	//   zvok, _rard, bast_, _eyap,
   {{0x68fc439a,0x7afd05d8,0x765b8085,0x2cb80036}},	//   _sard, _cast, _oxuy, sard_,
   {{0x68fc280f,0x9f5e83d3,0x7afd7885,0xa3b380dc}},	// [78e0] _pard, _été_, _dast, जीत_,
   {{0x63ad803a,0x68fc1b44,0x98be8087,0x7afd286f}},	//   ćanj, _qard, mită_, _east,
   {{0x68fc7886,0x8caa1094,0xddcd003b,0x78b5002e}},	//   _vard, _ज्यो, _izaš, _dezv,
   {{0x5fc90540,0x25a68b17,0x2d8c8039,0x3fb90019}},	//   ांजल, tpol_, _side_, ئپنگ_,
   {{0x2d8c82ba,0x3f8df887,0x7ae400dd,0xe4e68221}},	//   _pide_, _dieu_, mfit, гійн,
   {{0x7ae47888,0x25a6f889,0x7521907c,0x61461df3}},	//   lfit, rpol_, _colz, _сега,
   {{0xc61c80c8,0x0b8a891d,0x25a6e416,0x75219502}},	//   _দেখা_, нсии_, spol_, _dolz,
   {{0x3cf08063,0x7afd002a,0x436780a9,0xfbac1995}},	//   _इसके_, _xast, лајн_, टीएम,
   {{0x64a6f2f2,0x5f11835a,0x3eb929f7,0xdca69bf5}},	//   _база, णार्_, vast_, _бази,
   {{0x200780c3,0xc23701c6,0xa6db008b,0x98be8493}},	//   _brni_, טרפו_, miði, dită_,
   {{0x04938307,0x7c938013,0x20078067,0x3eb92c9f}},	//   _المح, _المص, _crni_, tast_,
   {{0x6d4a8c93,0x7bc1017f,0x6d8b0609,0x798e038a}},	//   lifa, šluk, _eżal, _libw,
   {{0x3eb9788a,0x7afd788b,0xdb0a8aa2,0x88cc00ab}},	//   rast_, _rast, dsfø, র্যক,
   {{0x6d4af88c,0xb4c104c5,0x260a06a7,0xdb01d95b}},	//   nifa, ुले_, ामजी_, _atlè,
   {{0x8ca4000f,0x3eb960e3,0x3cec801b,0xd00f982d}},	//   कड़ो, past_, _आउने_, _уф_,
   {{0x6d4a8010,0xa2a00fd5,0xe2f80558,0x98be8162}},	//   hifa, गुल्, лесі_, bită_,
   {{0x7afd0181,0x6d4a914c,0x2b49788d,0x98be8162}},	// [78f0] _vast, kifa, riac_, cită_,
   {{0x2b4901ac,0x6d4a804f,0xf1c801a8,0x3f8d8129}},	//   siac_, jifa, اولى_, _sieu_,
   {{0x20075dc8,0x63adacf6,0x6d4af88e,0x3a2902c4}},	//   íni_, ćank, difa, syap_,
   {{0x672f009a,0x7521d3a5,0x7afd01a8,0xa2d08072}},	//   nkcj, _solz, _uast, _धाग्,
   {{0xfad6093f,0xeef800be,0x6d4a80dd,0x7521ce13}},	//   _דורך_, טמאר_, fifa, _polz,
   {{0x69cd0355,0x85300300,0x6d4a9267,0x78ba8824}},	//   mrae, _kuɗa, gifa, jatv,
   {{0x3f8d80ff,0xc2938019,0x98be8162,0x2911010c}},	//   _tieu_, میاب, zită_, _inza_,
   {{0x1309a4b6,0x3cfe8c93,0x798e0deb,0x6d4a8901}},	//   тний_, _eatv_, _zibw, aifa,
   {{0x65158019,0x20078b67,0x6d4a8b5e,0x798e0a03}},	//   _پوائ, _srni_, bifa, _yibw,
   {{0x2360825b,0x39459383,0x2901788f,0x60098604}},	//   čija_, рног, ndha_, вном_,
   {{0xe73a0381,0xa2f591c7,0xb4c38bbc,0x2eff81ec}},	//   вен_, _впеч, ्ली_, _kauf_,
   {{0x6609f890,0xc9f58019,0x9f5d00e1,0x6d556ab9}},	//   _krek, _نستع, _prvá_, enza,
   {{0x3f82250d,0x2911016a,0x63a501a8,0x6d8b022b}},	//   rmku_, _onza_, _athn, _eżam,
   {{0x64590063,0x69cd68c2,0x98be8087,0x6abb81ec}},	//   _świa, drae, rită_, lauf,
   {{0x29013017,0x8883803d,0xdb01e6e7,0xd46a1860}},	//   ddha_, _دیدن, _atlé, тиве_,
   {{0x97c4803d,0x6d550511,0x6d4ab5eb,0x9f5d016b}},	//   _اتوم, anza, zifa, _trvá_,
   {{0x63a5662c,0xe0da0fe7,0xb1461908,0xe297105c}},	// [7900] _ethn, ква_, анал, рау_,
   {{0x399b8073,0xf09280be,0x78bb00e7,0x6abbf891}},	//   _mês_, ַנד_, _œuvr, hauf,
   {{0xa2e6087e,0x28dd800d,0x6abb81ec,0x6609f892}},	//   _конд, _मानि, kauf, _arek,
   {{0x66e68a08,0xdee6c5c8,0x7c2e82af,0x6609ac9f}},	//   рода, роди, _übri, _brek,
   {{0x6b840b3c,0x22a681d0,0x3ea9816a,0x6d4a9d80}},	//   mmig, níků_, ñata_, tifa,
   {{0x6609f893,0x6b8401b4,0x80dd7894,0x03c680ae}},	//   _drek, lmig, _पाये, асим,
   {{0x6d4a8cf6,0x6d8b0609,0xdb150061,0xb6060824}},	//   rifa, _bżaj, lszá, ljšč,
   {{0x6609f895,0x6b840876,0x6d4a805d,0x3ce9811f}},	//   _frek, nmig, sifa, đava_,
   {{0x24f68d31,0x3f980010,0xe5a3be32,0x6609d203}},	//   _вчер, _huru_, _мити, _grek,
   {{0x3f980cd6,0x6b8401ec,0x637e8168,0xf8b303de}},	//   _kuru_, hmig, këng, ֿשר_,
   {{0x3f987896,0xb4d287e6,0x6d489c88,0x6f00f897}},	//   _juru_, वली_, _imda, _kamc,
   {{0x09e6a599,0x6f02de93,0x91e68abe,0x141781a8}},	//   _водн, ndoc, _воде, _خيمة_,
   {{0x51f692c8,0x6f0086ec,0x2bc48133,0x291181a8}},	//   _خسار, _mamc, _ịche_, ánaí_,
   {{0xa3b3a594,0x69c0c43c,0x58d381a1,0x3d198054}},	//   जीव_, msme, _дошт, पाये_,
   {{0x3f987898,0xb17b83de,0x397b83de,0xf99f0176}},	//   _nuru_, _שטור, _שטונ, _erèl_,
   {{0x69cd0197,0x394c82e6,0x9e670019,0x6b8402d5}},	//   trae, lids_, _پابن, gmig,
   {{0x645e4844,0x6d48e4e5,0x69c0f899,0x63ad8668}},	// [7910] _expi, _omda, nsme, ćani,
   {{0x3f98789a,0x2eff80e7,0xa0a71501,0x69cd0114}},	//   _buru_, _sauf_, ршал, rrae,
   {{0x3f980369,0x69cd789b,0x2901789c,0x63a90140}},	//   _curu_, srae, rdha_, ćens,
   {{0x6609c306,0x6f00c13a,0x6d488f70,0x69c080eb}},	//   _prek, _camc, _amda, ksme,
   {{0x6605abe0,0x64a5af63,0xdef8a252,0x69c0869f}},	//   спла, бала, рых_, jsme,
   {{0xa3be023c,0xee388221,0xdb1c0511,0xb4c381a2}},	//   ुंच_, шні_, buró, ्ले_,
   {{0xadc38028,0x237d81c0,0xdb1c0118,0x6abb8192}},	//   _trắn, _phwj_, curó, tauf,
   {{0x66098de8,0x6d48ebfe,0x612d9e18,0xcc5801c6}},	//   _trek, _emda, _túlk, יסוק_,
   {{0x6abb81ec,0x69c0a445,0x798501c0,0x13068198}},	//   rauf, gsme, omhw, сный_,
   {{0x9be7835f,0x23e780e8,0x27fc80b9,0x6f008088}},	//   _відк, _відв, _bsvn_, _zamc,
   {{0x612d8019,0xe8df0028,0x40498c6c,0x237d8069}},	//   _júli, _ngọc_, упно_, _thwj_,
   {{0x22958013,0x7d0183a6,0xaa9581a8,0xe73a0d15}},	//   _الإس, _hals, _الإث, уем_,
   {{0xa3da035a,0x528580f7,0xf99f0176,0x2b4d866f}},	//   डून_, _الشك, _brèm_, miec_,
   {{0xdce39234,0xdca31c45,0x7bd5789d,0x394cd0b5}},	//   konč, зари, fuzu, cids_,
   {{0x61fd00dd,0x7d01f89e,0xd4918129,0x20188198}},	//   _assl, _mals, _bài_, ärit_,
   {{0x2b4dda65,0x3f980870,0xdce3856f,0x2b9c001b}},	//   niec_, _ruru_, donč, _víc_,
   {{0x200a003b,0x6132013c,0x3f98789f,0x3b070081}},	// [7920] _srbi_, _fæll, _suru_, щето_,
   {{0xdb150065,0x3f980133,0xb4c3800d,0x6b8433ec}},	//   rszá, _puru_, ्लो_, smig,
   {{0x6d4e6b46,0xdb150019,0x6f008bcf,0xa4fb0e82}},	//   miba, sszá, _pamc, _גליט,
   {{0x1e868012,0xee3a8eef,0x7d01f8a0,0x98b8061c}},	//   блем, лне_, _aals, ızın_,
   {{0x7d01f8a1,0x81e700ab,0x239581a9,0x3f9801bc}},	//   _bals, ভিউ_, _māju_, _wuru_,
   {{0xb4d28f22,0x6d4e4382,0x3f983ef2,0x69c08186}},	//   वले_, niba, _turu_, vsme,
   {{0x69d60216,0x7d01f8a2,0x4adc9107,0xa13703de}},	//   luye, _dals, _यादव, _פאלק_,
   {{0xe44f8013,0x6d4e0ddd,0xe73781bb,0x7af6007b}},	//   عضو_, hiba, _лес_, neyt,
   {{0xa92a8071,0x394c83a6,0x69c0f8a3,0x69d6189d}},	//   гіне_, tids_, usme, nuye,
   {{0x6d4e301c,0xa3d30074,0x69c0b12d,0xce379101}},	//   jiba, हूँ_, rsme, _האמת_,
   {{0x9c7ca02e,0x3f9203c3,0x394c8106,0x5eaa00ab}},	//   _obči, _biyu_, rids_, _কয়ে,
   {{0xe29a9697,0x61e412a5,0x973d0d26,0x3f8686c0}},	//   _сад_, ktil, opći, nmou_,
   {{0x8b658013,0x518681e2,0xe66704fa,0x637e80f1}},	//   _بالم, _лука, стно, rënd,
   {{0x61e4240c,0x7bd578a4,0x6d4e630c,0x394a090d}},	//   dtil, tuzu, giba, _nmbs_,
   {{0xa3d30b85,0x6b9a8722,0x0ed89513,0xf2c70048}},	//   हूं_, _jutg, _डांड, йсан,
   {{0xe616007a,0xdb038106,0x387c80c3,0x7bd578a5}},	//   žišč, ssnö, _izvr_, ruzu,
   {{0x388e82bf,0x6d4e78a6,0x7bd500b4,0x25ac016b}},	// [7930] lər_, biba, suzu, čilý_,
   {{0x660d6f78,0xaa7b026f,0x2be20740,0x27058129}},	//   _irak, _obýv, _पहचा, _ồn_,
   {{0xd0110277,0xa295102a,0xaa950dc0,0x61e46ce2}},	//   بلا_, _мані, _минч, atil,
   {{0x660d78a7,0x69d60234,0x61e478a8,0xb4c382f1}},	//   _krak, buye, btil, ्ल्_,
   {{0x5fc50076,0x2cb200f2,0x388e8201,0x7d01d536}},	//   _लटकल, _ändå_, hər_, _pals,
   {{0xc3010a49,0x78ad8289,0x2b4d809a,0x6d588a35}},	//   _একটি_, _đavo, wiec_, gnva,
   {{0x7d01bffd,0xeab180f7,0xe3b28065,0xcda9803d}},	//   _vals, وعة_, ورٹ_, _چهره_,
   {{0x388e8201,0x2903247b,0x6d4e63c5,0x6d5898c7}},	//   dər_, _haja_, ziba, anva,
   {{0x7d01f65b,0x799980dd,0x6d4e01d4,0x612d8061}},	//   _tals, _quww, yiba, _múlv,
   {{0x388e8201,0x95578277,0x4fe98b69,0x47c596df}},	//   fər_, _اخرا, амон_, обов,
   {{0x290303b7,0x660d7892,0x388e8201,0x25a94815}},	//   _maja_, _arak, gər_, _atal_,
   {{0x7c2e016b,0x61e43dcb,0x7bc38502,0x6d4e78a9}},	//   vybr, ytil, msnu, wiba,
   {{0xc3328039,0x5fc59305,0x3ead262c,0x683f846d}},	//   _קוד_, _विकल, ñeta_, _bádé,
   {{0x388e8201,0x290301ec,0x7ae9c92c,0x2cba0144}},	//   bər_, _naja_, lfet, _qepd_,
   {{0x69cb00ab,0x6d4e78aa,0x660d78ab,0xe7b580f7}},	//   ágen, riba, _erak, _بمعد,
   {{0x660d2130,0xe2971092,0x61e44903,0x4911800d}},	//   _frak, жат_, ttil, ताको_,
   {{0x29033df7,0x2d930cf8,0x7af6008b,0x6b5e81a9}},	// [7940] _baja_, _fixe_, reyt, nīga,
   {{0x38cb19f7,0x2905829b,0x29030264,0xb17b016d}},	//   لامی_, ndla_, _caja_, _spår,
   {{0x660d1784,0xb4d6000f,0x22400061,0x69d60fa3}},	//   _zrak, हली_, szik_, suye,
   {{0x6b9ac762,0x644800e1,0x69d60036,0x9411811c}},	//   _rutg, údiu, puye, _üzə_,
   {{0x388e8085,0x29033df7,0x6f0478ac,0xee838162}},	//   zər_, _faja_, _maic, мышо,
   {{0x69c44ccf,0x442e8123,0x61320366,0x3f868118}},	//   msie, tyf_, _mælk, smou_,
   {{0x7ae9ae31,0x69c42796,0x6d5886b1,0x6f160176}},	//   ffet, lsie, rnva, _onyc,
   {{0x4420803a,0x442e879f,0x78bc0223,0x31c691d2}},	//   ći_, ryf_, _herv, осов,
   {{0xb99784d9,0x316e80b9,0x29034914,0x78bc78ad}},	//   овых_, _pkfz_, _yaja_, _kerv,
   {{0x2ee0026c,0x6b9a8362,0x69c44918,0x388e811c}},	//   _acif_, _tutg, isie, tər_,
   {{0x80d000c8,0xc05a90ac,0x25a91f1c,0x2005007b}},	//   স্থ্, ріп_, _stal_, _álit_,
   {{0x69c478ae,0x752888ae,0x6722db1a,0x7bd8acf7}},	//   ksie, _hodz, njoj, muvu,
   {{0x7528f8af,0x76429149,0x95d80009,0x7bd8a4f6}},	//   _kodz, nzoy, одят_, luvu,
   {{0x69c43888,0x2369811a,0x3af50129,0x660d78b0}},	//   dsie, čaje_, _ấp_, _vrak,
   {{0x2903059e,0x69c41c43,0x6f0401e4,0x4fb381a8}},	//   _raja_, esie, _faic, _قصير,
   {{0x290378b1,0xc2990fbf,0x31a083ec,0x7528dcb0}},	//   _saja_, сках_, _kòz_, _lodz,
   {{0x78bc78b2,0x660d78b3,0x7f4d2243,0xa2dc2135}},	// [7950] _berv, _urak, _imaq, _फार्,
   {{0x7bd8c216,0x48ab02cb,0xc17800e8,0x7528afbe}},	//   kuvu, ртам_, оїх_, _nodz,
   {{0x29030074,0x28dd824c,0x5f9509b5,0xbf73846d}},	//   _vaja_, _मासि, чиет, _apàṣ,
   {{0x29031eec,0x80dd02f1,0x67228168,0x753a811b}},	//   _waja_, _पावे, gjoj, _altz,
   {{0xe4f781ce,0x5f1c11c6,0x64a5814c,0x78bc2a8d}},	//   ंजलि_, यात्_, пала, _ferv,
   {{0x6b828019,0x64a58ba7,0x75288035,0x7d053533}},	//   _ahog, чака, _codz, _jahs,
   {{0x9c7c8353,0x6b828635,0x0edb016f,0x7d0578b4}},	//   _obču, _bhog, _भांड, _mahs,
   {{0x28dd853e,0x6b828083,0xdce70dcc,0x31a082d6}},	//   _माहि, _chog, dojč, _bòz_,
   {{0xe4e78160,0x7ae9939a,0xda0e0054,0x6f0460e2}},	//   _міжн, rfet, सियत_, _raic,
   {{0x75288063,0xa2cb04c5,0x7ae9bd2b,0x6b5e81a9}},	//   _godz, तृत्, sfet, rīga,
   {{0x3ea08b7c,0x6b828083,0x63ad82ce,0x1869d46b}},	//   žite_, _fhog, ćans, сани_,
   {{0x3d1985b3,0x290384c4,0x2576007b,0xe3b08a47}},	//   पावे_, žja_, mæli_, _شرم_,
   {{0x7d056fd3,0x61330214,0x6b89a2c9,0x799d1abb}},	//   _bahs, _kılı, mmeg, _nusw,
   {{0xb4d665a5,0xcfe98077,0x200e826c,0x6b89f8b5}},	//   हले_, _هفته_, _frfi_, lmeg,
   {{0x799d02af,0x7d050be6,0x6f0401e4,0x60c1f8b6}},	//   _ausw, _dahs, _taic, malm,
   {{0x3f670098,0x799d68b6,0xe29a07b6,0x69c478b7}},	//   _нищо_, _busw, саа_, tsie,
   {{0x6abd072a,0x78bc5d05,0x26c278b8,0xa8238065}},	// [7960] _desf, _perv, mako_, _رکھن,
   {{0x01bd8a49,0x26c278b9,0x69c40412,0x6aa478ba}},	//   _আমাদ, lako_, rsie, scif,
   {{0x78bc2539,0x75288063,0x80dd01d0,0x79950242}},	//   _verv, _rodz, _पारे, _dizw,
   {{0x26c24f5b,0xe61aae8c,0x6b8980f3,0x8f9a807c}},	//   nako_, йде_, jmeg, ציני,
   {{0x78bc4489,0x75288b04,0x60c18065,0xddcb8214}},	//   _terv, _podz, kalm, ğişi,
   {{0x6d5c3b8a,0x6b82f8bb,0x3ae80065,0x7bd8f8bc}},	//   nnra, _shog, _ابھی_, tuvu,
   {{0x06c700c8,0x8af00201,0x673b86a5,0x60c18019}},	//   ষ্টি, ynəl, _fluj, dalm,
   {{0xdce7003b,0xd90d803d,0x320f80e4,0x26c278bd}},	//   vojč, یین_, _brgy_, jako_,
   {{0xa3d6023c,0x26c278be,0xadc3801c,0x2576803d}},	//   _समझ_, dako_, _trạn, _فهرس,
   {{0xe1ef880b,0x60c1f8bf,0xd7fa80c4,0x6d5c1d3e}},	//   اسي_, galm, бум_, jnra,
   {{0x64438063,0x7d051083,0x6b82925b,0x06e380ab}},	//   czni, _rahs, _thog, _নোটি,
   {{0x7d054001,0x6c7b80be,0x0ea706af,0x26c24f61}},	//   _sahs, _פראד, कुंड, gako_,
   {{0x61330214,0x7d050122,0x6abd4612,0x27340129}},	//   _yılı, _pahs, _resf, _mãnh_,
   {{0xe6b9941b,0x2734001c,0x5ba707a1,0x26c278c0}},	//   _उज्ज, _lãnh_, зраз, aako_,
   {{0x0fd700ab,0x7e6401df,0x799d126a,0xdb18807b}},	//   _সন্ধ, _exip, _susw, rsvæ,
   {{0xb7db81c6,0x443178c1,0x7d056710,0x26c20f3e}},	//   _הקהי, ryz_, _wahs, cako_,
   {{0x69bf80d4,0xd0470085,0x433b80be,0x7d0578c2}},	// [7970] लीपी, əməs, צעמב, _tahs,
   {{0x673b8087,0x6729808e,0xdb188338,0x55bc025f}},	//   _sluj, _soej, lsvä, _המזו,
   {{0x67210a74,0x2fc71abb,0x389b80be,0x673b8722}},	//   यापक_, éng_, ציאנ, _pluj,
   {{0xf7709a3e,0xdb18816d,0x0675acd1,0x6d8b022b}},	//   هان_, nsvä, муля, _eżat,
   {{0x28dd83b7,0xc1788084,0x2fc70129,0x7bc73ee4}},	//   _मालि, klė_, ũng_, lsju,
   {{0x25de016f,0x26c278c3,0x7ae29ee8,0x80d8a418}},	//   कंती_, zako_, _acot, _मागे,
   {{0xdb018feb,0xbbe88013,0x60c184a2,0x26c20365}},	//   _atlá, كريم_, valm, yako_,
   {{0x7aed2472,0x3b0900b9,0xeeb98081,0x7c2a02df}},	//   nfat, ndaq_, _флаш_, _àfre,
   {{0x26cd807a,0x26c212e5,0x7aed0114,0x6b89f8c4}},	//   _ideo_, vako_, ifat, rmeg,
   {{0x26c24349,0x9f4181a8,0xe125804a,0x3ea903ed}},	//   wako_, ithí_, ємни, _afat_,
   {{0x26c20379,0xfbd084c0,0xf7708065,0xf99f0242}},	//   tako_, _متن_, _شاہ_, _grèv_,
   {{0xd24e95e4,0x60c1ca7c,0x201102a5,0x994f07c0}},	//   انی_, salm, _mrzi_, yüş_,
   {{0x26c278c5,0x60c19d69,0x68faa0d8,0x7afb83e4}},	//   rako_, palm, betd, meut,
   {{0x25ad8267,0x61e9f42f,0x26c278c6,0x3ebf81a1}},	//   _mtel_, mtel, sako_, _leut_,
   {{0x26c278c7,0x212a0046,0x7aed30af,0x64a300c5}},	//   pako_, _robh_, ffat, таса,
   {{0x2907f8c8,0x7afbe32b,0xb0dd8105,0x25adf8c9}},	//   _hana_, neut, _माँग, _otel_,
   {{0x61e98cc9,0x2907f8ca,0x2d858101,0x201178cb}},	// [7980] ntel, _kana_, _ohle_, _arzi_,
   {{0x660478cc,0x2907f8cd,0x23608503,0x994f080a}},	//   _isik, _jana_, čiji_, rüş_,
   {{0x2907f8ce,0x351b0451,0x251b0158,0xe29a1ae2}},	//   _mana_, _ווינ, _וויא, _ман_,
   {{0x2907f8cf,0x201102a5,0x25a0059e,0x48fa0b04}},	//   _lana_, _drzi_, _kuil_, _उसको_,
   {{0x7bdc1a6e,0x26c00073,0x7afbf8d0,0x25a002be}},	//   luru, _meio_, deut, _juil_,
   {{0x29079bcc,0xdb0a816d,0x6604004f,0x7ae2c6ff}},	//   _nana_, nsfö, _msik, _scot,
   {{0x7bdc0393,0x61e9f8d1,0x69cf81d0,0xa43889c7}},	//   nuru, etel, ácen, язку_,
   {{0x290791c9,0x69bf8035,0x63ba01d6,0xbebb03ed}},	//   _aana_, लीभी, átny, gjël,
   {{0x2907f8d2,0x7bdc3374,0x05768060,0x61e9f8d3}},	//   _bana_, huru, _قائد, gtel,
   {{0x3ea90162,0xdb18ac15,0x0d838087,0x2d858a2a}},	//   _sfat_, dsvå, _алун, _ghle_,
   {{0x29078025,0x660432ca,0x7d1af8d4,0x7bdc78d5}},	//   _dana_, _asik, _ints, juru,
   {{0x81c400c8,0x7bdc59f6,0xf09301c6,0x25a0051e}},	//   _এমন_, duru, כנת_, _buil_,
   {{0x61e9802e,0xdb188106,0x25a0198f,0xceb38039}},	//   ctel, rsvä, _cuil_, כיר_,
   {{0x961d80eb,0xd0109190,0x7bc726f4,0xdb0a8106}},	//   _uzņe, _ملت_, tsju, gsfö,
   {{0xdd940110,0x7bdc78d6,0x66045f42,0x9f590065}},	//   тары, guru, _esik, író_,
   {{0x2907bb27,0x25a00635,0x7bc74321,0xd138a392}},	//   _zana_, _fuil_, rsju, lką_,
   {{0x2907f8d7,0x7d1a90f4,0x7aed0370,0x0dbb0bca}},	// [7990] _yana_, _onts, rfat, _باعث_,
   {{0x7bdc78d8,0xd1388d42,0x7d0885b7,0x7aed00df}},	//   buru, nką_, _nads, sfat,
   {{0x3ebf83d3,0x25ad90f4,0x395ef8d9,0x61e9f8da}},	//   _peut_, _stel_, ints_, ztel,
   {{0xf1a71094,0x7d1af8db,0x61e9b24b,0x69cf825a}},	//   _कंपन, _ants, ytel, _दिली,
   {{0xd2468013,0x3ebf82be,0x6b8d78dc,0x31a403bf}},	//   _إن_, _veut_, mmag, _göz_,
   {{0x3878007b,0x6b8d78dd,0xdd918019,0xf99f02d6}},	//   _fyrr_, lmag, ھوں_, _drèt_,
   {{0x290780a4,0x36d5824b,0x60c50590,0x7afb8009}},	//   _rana_, _повр, mahm, teut,
   {{0x2907e37e,0x61e98956,0x7d1af8de,0x395ecc04}},	//   _sana_, ttel, _ents, ents_,
   {{0x2907f8df,0x61e98cfa,0x6d55125c,0xda0880ff}},	//   _pana_, utel, kiza, _cỏ_,
   {{0x7fd585a8,0x60c502af,0x7d0880eb,0x7bdc061c}},	//   німі, nahm, _gads, yuru,
   {{0x61e9f8e0,0x6d438ad0,0x2907f8e1,0xdee6214a}},	//   stel, mhna, _vana_, нони,
   {{0x61e9f8e2,0x2907f8e3,0x395ebdc9,0x7bdc78e4}},	//   ptel, _wana_, ants_, vuru,
   {{0x290780a4,0xee372b05,0xf6521c2c,0x26c003a7}},	//   _tana_, еня_, ائج_, _veio_,
   {{0x7bdc78e5,0x60c509ca,0x6d556555,0x25a006a8}},	//   turu, jahm, giza, _vuil_,
   {{0x31a40182,0x60c53acd,0x6b8d008b,0x629c81d0}},	//   _söz_, dahm, fmag, ěrov,
   {{0x28e2035a,0x7bdc550b,0x66043adb,0xab2742e6}},	//   _पाहि, ruru, _tsik, носа_,
   {{0x2d96042f,0x660478e6,0x64a648ac,0xe9da3696}},	// [79a0] _прос, _usik, _папа, яка_,
   {{0x7bdc4512,0x6d55255e,0x8cdb80d4,0x7cf38457}},	//   puru, ciza, _नागो, nırı,
   {{0x6d43e290,0x313680be,0x7d08f8e7,0x3d1d0072}},	//   dhna, ענעם_, _rads, मारे_,
   {{0x69c98364,0xf99f06c0,0x78bb0bcf,0x81cf0264}},	//   ksee, _prèt_, _đuve, _শহর_,
   {{0x6a9b0039,0x6f09810c,0x25760366,0x7cf382d0}},	//   _משכנ, _daec, bælt_, kırı,
   {{0xafe61fee,0xdd8f806b,0x6d438c5e,0xa3d40035}},	//   _погл, مون_, ghna, _हटा_,
   {{0x76968179,0x01630615,0x69c98009,0x69cb88dc}},	//   _büyü, _скро, esee, _avge,
   {{0x290a433d,0x2d9a0669,0xf99f1f5a,0x6d556df4}},	//   _haba_, _lipe_, _grès_, ziza,
   {{0x0566adf8,0xd250803d,0x6d554752,0x853000fc}},	//   _зван, شند_, yiza, _huɗu,
   {{0x6d43f72d,0xda0880ff,0x290a003d,0x6602a943}},	//   chna, _vỏ_, _jaba_, mwok,
   {{0xdd8f806b,0xd138cb13,0x6bd688ca,0x2360009a}},	//   _اول_, rką_, _ستار, knij_,
   {{0x290a78e8,0xd1388d42,0xda0880ff,0x2d9a0032}},	//   _laba_, ską_, _tỏ_, _aipe_,
   {{0xe1ff0118,0x6b4302f1,0x82339a2d,0x68469d88}},	//   _axón_, _jõge, _مروا, _bédé,
   {{0x236081dd,0x290a20fa,0x2d9a78e9,0x2c0d0072}},	//   čiju_, _naba_, _cipe_, हिलं_,
   {{0x99828110,0xe6df0135,0x291f001c,0x85300326}},	//   škų_, _agụụ_, _đua_, _nuɗu,
   {{0x6d55673d,0x236060ee,0x6b9c802a,0x7c258192}},	//   siza, gnij_, _érgu, ähri,
   {{0x290a0a87,0x6b8d5e35,0xdb1c016d,0x684680e7}},	// [79b0] _baba_, rmag, dsrä, _fédé,
   {{0x3eb90352,0x6f1b8706,0x290cda1d,0x602a811c}},	//   lbst_, _snuc, ndda_, həmm,
   {{0xb9094d54,0x3f8971a0,0xf99f102d,0x290a78ea}},	//   _या_, _khau_, _près_, _daba_,
   {{0xe522001b,0x69c98df6,0xcb35047f,0x7cf385b2}},	//   माथि_, ysee, _ремъ, zırı,
   {{0x1d09a184,0xa5099c64,0xdd9b8009,0x22840098}},	//   дели_, дела_, чше_, _бург,
   {{0x61ed2445,0x290a03c3,0x3f8901c0,0x063800be}},	//   mtal, _gaba_, _lhau_, ענגט_,
   {{0xf99f03d3,0x3ce90fea,0xdfd80698,0x6f0990e4}},	//   _très_, _जाने_, _път_, _taec,
   {{0xe299b105,0x3f890028,0x23698353,0x6f1b80d2}},	//   май_, _nhau_, čajo_, _unuc,
   {{0x339280f7,0x7cf3817b,0x13068009,0x290a78eb}},	//   جليز, tırı, тный_, _yaba_,
   {{0x69c9f8ec,0x2ba985fc,0x61ed4eac,0x63a182f1}},	//   rsee, _चंपा, ital, _tuln,
   {{0x6d41c7f8,0xef86218a,0xf746181f,0x61ed1a52}},	//   _illa, клоп, вено, htal,
   {{0x61ed2016,0xbebb00f1,0x2d9a2e5d,0x7e7b82f7}},	//   ktal, njëh, _sipe_, _kyup,
   {{0xcb368051,0x3f8901e9,0x69c6801b,0x61ed78ed}},	//   _שאני_, _dhau_, šker, jtal,
   {{0xa3bf0035,0x98a2a361,0x18a281e5,0x3afc027d}},	//   ुओं_, _кише, _кашм, _ập_,
   {{0x290a78ee,0x61ed1447,0x03a678ef,0x00000000}},	//   _raba_, etal, тибо, --,
   {{0x290a2498,0xdb01816d,0x61ed78f0,0xf8b90129}},	//   _saba_, _utlä, ftal, _đũa_,
   {{0x2d9a08b3,0xc33282f6,0xdb1c016d,0x60c39c2b}},	// [79c0] _tipe_, בון_, vsrä, _kenm,
   {{0x3ce90b85,0x290a01b4,0xe0d70eef,0x236d0088}},	//   _जाये_, _qaba_, кву_, čeja_,
   {{0x838a035f,0x40966e38,0x60c383ec,0x290a0074}},	//   _обов_, трат, _menm, _vaba_,
   {{0x60c398e8,0xa3d7001b,0x290a5e2a,0xc29402e3}},	//   _lenm, _सित_, _waba_, _میزب,
   {{0x290a3365,0x290cf8f1,0xdee3b0bc,0x26d202c4}},	//   _taba_, ydda_, рочи, _mdyo_,
   {{0x628613cf,0x6602aacb,0x7ae40074,0xcdb70039}},	//   _izko, rwok, lgit, דפסה_,
   {{0x6d41810c,0xd47a03de,0x7e7b810c,0xd0070162}},	//   _dlla, ואַל, _eyup, _иере_,
   {{0x6d41b8b7,0xd5b2803d,0x7bca8b81,0x7ae4360b}},	//   _ella, _نفر_, rsfu, ngit,
   {{0xada69957,0x35a69957,0xe5a6e103,0x44380114}},	//   _разл, _разг, _ризи, hyr_,
   {{0x3ea000e7,0x799c0326,0x2cac8326,0xc05a90ac}},	//   _agit_, _jirw, _ufdd_, дім_,
   {{0x60c3f8f2,0x3f8901c5,0x41d48f85,0x26c48392}},	//   _denm, _phau_, _दिवस, _kemo_,
   {{0x290a97aa,0x443878f3,0x60c38fb0,0x200782f7}},	//   žba_, dyr_, _eenm, _dsni_,
   {{0x3eb90192,0xe7e481ab,0x26d20365,0x60c386c4}},	//   rbst_, _कमवा_, _ddyo_, _fenm,
   {{0xb4dd0d14,0x8e209246,0x61ed2205,0xc693807c}},	//   डले_, лiк_, vtal, יאר_,
   {{0x3f89209e,0x2d4d10d3,0x60c8839c,0x1c0281ab}},	//   _thau_, džet_, madm, लबिल_,
   {{0x61ed78f4,0xeab30013,0x26c49c03,0x2249011e}},	//   ttal, شعر_, _nemo_, tzak_,
   {{0x4394493f,0x799c30cb,0xdb019f48,0x661603ed}},	// [79d0] ратс, _birw, _utlå, _gryk,
   {{0x61ed0eb9,0x6d588025,0x58b80013,0x60c8b0f1}},	//   rtal, jiva, نامج_, nadm,
   {{0x66740077,0x6286011b,0x26c49d26,0x61e08380}},	//   _مدیر, _ezko, _bemo_, huml,
   {{0x26c48052,0x2366803a,0x61ed6b5e,0x673d00e8}},	//   _cemo_, _njoj_, ptal, nksj,
   {{0x6f0d78f5,0x61e0dae9,0x799c1bc2,0x22da025f}},	//   _maac, juml, _firw, _אחרא,
   {{0x6d5897a6,0x6b9d0637,0x236680c3,0x6f0d78f6}},	//   giva, _hisg, _ajoj_, _laac,
   {{0x60c38247,0x29010088,0x764b0019,0x60c88144}},	//   _renm, meha_, _ügyf, dadm,
   {{0x4429803a,0x29015ff9,0x60c38242,0x6b9d0197}},	//   ća_, leha_, _senm, _jisg,
   {{0x6d58f8f7,0x6b9d3f8c,0x69cd0428,0x60c3f8f8}},	//   biva, _misg, nsae, _penm,
   {{0x6d588025,0x6d41a6dc,0x8145803d,0x9f5886c0}},	//   civa, _ulla, اندن, _aprè_,
   {{0x25b278f9,0x68e50c5e,0x6ec7897d,0x6b650196}},	//   _styl_, ighd, ारपु, jėgo,
   {{0xe1f18077,0x29cf00eb,0xe7e48105,0x8af0011c}},	//   _هست_, kļa_, _कमरा_, nnət,
   {{0xcb128051,0x44380355,0x60c38cab,0x7f3a80be}},	//   _ללא_, wyr_, _tenm, גערו,
   {{0x290102ce,0x443878fa,0x6da31a1f,0xe816073c}},	//   jeha_, tyr_, сира, णिमा_,
   {{0x62860063,0x04430554,0x8c431878,0x443e78fb}},	//   _szko, берн, бере, át_,
   {{0x6d588025,0x66160bc5,0x3ea002c4,0x6b9d0037}},	//   ziva, _tryk, _ugit_, _cisg,
   {{0xc3328496,0x443808dc,0xdb1883ba,0xdb018580}},	// [79e0] זון_, syr_, rsvø, _culé,
   {{0x6d58ec95,0x88d58264,0x26c48037,0x7ae478fc}},	//   xiva, ত্রক, _semo_, sgit,
   {{0x3ce92f52,0x6d58ebf8,0x6609b4e7,0xcae38035}},	//   _जाते_, viva, _asek, _गांड_,
   {{0x6aad00e5,0x5276053b,0x69dbf8fd,0x59d48a27}},	//   ccaf, _бугу, krue, _दिलर,
   {{0xee3a876a,0x26c4807a,0x7bce0b81,0x62860ec3}},	//   энд_, _vemo_, lsbu, _uzko,
   {{0x18a30554,0xa0a31ed5,0x27e100ee,0x6b8b85ee}},	//   _гарм, _гард, buhn_, _ahgg,
   {{0x6d58c87c,0x26c48353,0x7bce14fb,0xec3600be}},	//   riva, _temo_, nsbu, טאַר_,
   {{0x660606cb,0x395a737e,0x201878fe,0x53349a4e}},	//   kwkk, lips_, _irri_, реит,
   {{0x0d8689c7,0x6f0d02a3,0x9e668b9b,0x6d589bf3}},	//   _блан, _raac, _свад, piva,
   {{0x61e090d7,0x7f4478ff,0x6f0d5857,0x7bce7900}},	//   ruml, _aliq, _saac, ksbu,
   {{0x7bce1601,0x637e80f1,0x9f58b9cb,0xd8db03de}},	//   jsbu, hëni, _apré_, עקטר,
   {{0x7f442df7,0xfaa69016,0x2ee68a53,0x7bce04dc}},	//   _cliq, _садо, ngof_, dsbu,
   {{0x66e60592,0x2d4d025b,0x3ce90074,0x6b9d7901}},	//   _कारक_, džer_, _जादे_, _risg,
   {{0xe8949a97,0x237900b9,0x3d0f0035,0x20187902}},	//   _каль, _sksj_, ायें_, _orri_,
   {{0xa3e40a27,0x7a488029,0x27f7826f,0x2d9ea61e}},	//   _नमः_, sūtī, čená_, _mite_,
   {{0x2d9e8186,0x290e87ca,0xa2b54709,0x236d007a}},	//   _lite_, _hafa_, рбач, čejo_,
   {{0x290e80a4,0xc299176e,0x1dc68778,0x26cb00e5}},	// [79f0] _kafa_, тках_, रीमत, maco_,
   {{0xf1da0fb2,0x26cb016a,0x290ea41b,0xdb150061}},	//   यंजन, laco_, _jafa_, tszó,
   {{0x6d450201,0xa3a9858c,0x29017903,0x6d570372}},	//   _ilha, _गंध_, reha_, _imxa,
   {{0x7ff40013,0x273b0168,0x2d9e851e,0x290e9e50}},	//   إسلا, _bëni_, _aite_, _lafa_,
   {{0x6cc59c28,0x3d0a035a,0x29010b44,0x398b8aa2}},	//   айла, ायचे_, peha_, løse_,
   {{0xabd599e6,0xdfc684a3,0x6609807a,0x8cba12e0}},	//   ациј, _وي_, _vsek, ्रयो,
   {{0x2d9ef904,0x2d99810c,0x00000000,0x00000000}},	//   _dite_, _èsem_, --, --,
   {{0x6609ca7c,0xb33b07d9,0x613f82df,0x2b49027d}},	//   _tsek, _hiçb, _pêlo, nhac_,
   {{0x6d450073,0xaca30032,0x290e9896,0xb1458cf3}},	//   _olha, _ajọd, _bafa_, инил,
   {{0xe9ff00ff,0x69dbf905,0x2d9e85ed,0x290e82d6}},	//   _giấc_, rrue, _gite_, _cafa_,
   {{0xa0699c9b,0x8c679c8a,0x290e8300,0x1869831f}},	//   тана_, _стад, _dafa_, тани_,
   {{0x7d03c5b7,0x6d450300,0x61fd4bc1,0x3a75c8ac}},	//   lens, _alha, _opsl, _клер,
   {{0x6d4501c0,0x290e8915,0x7d038cfa,0x93948019}},	//   _blha, _fafa_, oens, _اجلا,
   {{0x7d03f906,0x82348077,0xc0e28ca0,0x60c701d0}},	//   nens, _درما, _дошк, _nejm,
   {{0xb7b000c8,0x30798158,0x207980be,0x32190359}},	//   _চট্ট, _באַנ, _באַא, _arsy_,
   {{0x60d500b9,0x6d457907,0xa3d70ad5,0x200a02f7}},	//   _adzm, _elha, _सिर_, _rsbi_,
   {{0xeb971156,0x395a03a6,0x3b0718a0,0xdcfa801b}},	// [7a00] рит_, tips_, шето_, _chtě,
   {{0x7bce01e0,0x1aee00ab,0xa63b01c6,0x777b85e7}},	//   psbu, _চোখে_, _סגיר, _akux,
   {{0x7d03f908,0xc7968110,0x2d9ef909,0x395a4799}},	//   dens, арды, _rite_, rips_,
   {{0x91e614b7,0x6d5c790a,0x2d9ebf19,0x28e21c6f}},	//   _коме, lira, _site_, _पाकि,
   {{0x7d038cf7,0xd64e8133,0x3f8dbb6d,0x613f8123}},	//   fens, mọkụ_, _dheu_, _pêll,
   {{0x7d03dd7e,0x60c70088,0x764b0061,0x2b40026c}},	//   gens, _gejm, _ügye, lkic_,
   {{0x2d9ed26e,0x0fe080c8,0x9b5898ba,0xe4ee154b}},	//   _vite_, _বন্ধ, ликт_, _जानि_,
   {{0x6d5c790b,0xcfb70051,0x290eb160,0x60c7001b}},	//   hira, _כללי_, _safa_, _zejm,
   {{0x6d5c790c,0x7d03a2c7,0x2d9ef90d,0xd5a50105}},	//   kira, bens, _tite_, _गूंज,
   {{0x6d5c1dc0,0x7d03a475,0x2d9e8087,0xa3d74452}},	//   jira, cens, _uite_, _सिल_,
   {{0x94068077,0x61e4010a,0x13068098,0xb8ce8128}},	//   _خواه, huil, _взем, _कल_,
   {{0x644e0b67,0x6d5c0ba3,0xd49180ff,0x290ecc11}},	//   dzbi, eira, _này_, _wafa_,
   {{0x26cb790e,0x224d809a,0x6d450282,0xee870fe6}},	//   raco_, czek_, _plha, рыно,
   {{0x657d8b18,0x6d5c2557,0x97a69ae2,0x26cb041c}},	//   _ësht, gira, _крил, saco_,
   {{0xf2c710f8,0x443c8019,0x939701a8,0x26cb07b6}},	//   исан, nyv_, لجرا, paco_,
   {{0x442d003a,0x7d03a859,0x60c75c79,0x4fb3936d}},	//   će_, zens, _sejm, _بصور,
   {{0x6d5c1f37,0x443f0029,0x61e47509,0x443c8144}},	// [7a10] bira, ņu_, guil, hyv_,
   {{0x2b4687e2,0x7d039045,0x660d6c35,0x23698805}},	//   _lloc_, xens, _isak, čaji_,
   {{0x7d03f90f,0x2d8302a5,0x69c00168,0xe81986a7}},	//   vens, mlje_, _çmen, धिया_,
   {{0x7d0384b2,0xd3668199,0x2d834619,0xdb01804a}},	//   wens, _ره_, llje_, _utlø,
   {{0x25a913b8,0x60c72719,0x61e405ae,0x88de80ab}},	//   _jual_, _tejm, cuil, ব্যক,
   {{0x6d4af910,0x25a90890,0xb4d1816f,0xd469999a}},	//   ghfa, _mual_, वणे_, лиле_,
   {{0x2b46ea0c,0xbebb0168,0x58d40087,0x3209286f}},	//   _bloc_, njës, _фост, lway_,
   {{0x660d52cb,0x386981a1,0x13098087,0x224d8cdb}},	//   _osak, _ćar_, уний_, tzek_,
   {{0x6d5c4ec6,0x29114e41,0x7d0390b6,0x660d0c8b}},	//   yira, _kaza_, pens, _nsak,
   {{0x5d8580f7,0x39458ca0,0x661b948e,0x6d4af911}},	//   _الطل, сног, _iruk, chfa,
   {{0xe73a044f,0x224da47d,0x29117912,0x93278019}},	//   ген_, szek_, _maza_, _پران,
   {{0x6d5c3e6f,0x32090637,0x25a909c5,0x26c90118}},	//   wira, kway_, _bual_, _ceao_,
   {{0xf1a79fee,0x25a905b4,0x9b748013,0xe28e9401}},	//   _трен, _cual_, _بالص, _ха_,
   {{0x61e40009,0x7c3c03ba,0x9f5880e5,0x32090c6b}},	//   vuil, tyrr, _aprì_, dway_,
   {{0x6d5c7913,0x2905912e,0x8c430765,0x32092651}},	//   rira, mela_, пере, eway_,
   {{0x290591e8,0x3ea0812b,0xaec63a94,0xce5a00d7}},	//   lela_, žiti_, _убил, _مشخص_,
   {{0x29110745,0x32094702,0x2d8300ce,0x612d8019}},	// [7a20] _baza_, gway_, blje_, _súly,
   {{0x2905c761,0xe2970d46,0x291105e4,0xeeeb001c}},	//   nela_, сау_, _caza_, ượng_,
   {{0x3ead26ef,0x61e415ba,0x32093c6e,0x29110326}},	//   žete_, suil, away_, _daza_,
   {{0x661b979a,0x6f0602a5,0x29058234,0x80c6001b}},	//   _bruk, nekc, hela_, िरहे,
   {{0x61e4237c,0x6b8400f2,0x2905829b,0x63a88754}},	//   quil, mlig, kela_, _sudn,
   {{0x29058582,0x2911054e,0x28e20540,0xbebb03ed}},	//   jela_, _gaza_, _पाटि, njër,
   {{0x68e37914,0x602631a9,0x7ae98192,0x661bc2c0}},	//   ónde, _удва, fget, _eruk,
   {{0x6b840bfa,0x661b8448,0x1de0852a,0x7ae9a9da}},	//   nlig, _fruk, _निपत, gget,
   {{0xdb018118,0x3ce902f1,0x2905e387,0xcb1301c6}},	//   _gulí, _जाले_, fela_, ללה_,
   {{0x3a370051,0x290584bb,0x63a88019,0x7958a6e8}},	//   צרים_, gela_, _tudn, риор_,
   {{0x2d83003b,0x6c868013,0x6b8462aa,0x7f5d7915}},	//   vlje_, _الام, klig, tisq,
   {{0x6b846653,0x8f474fca,0x09e6ac39,0x398f0192}},	//   jlig, сход, _годн, müse_,
   {{0x25a97916,0x2905d460,0x7f5d05db,0x6b841c6d}},	//   _qual_, bela_, risq, dlig,
   {{0x29059845,0x660d0db7,0x80de00c8,0x63a280f7}},	//   cela_, _vsak, ন্ত্, _hion,
   {{0x63a28010,0x7bda192c,0x853b84de,0x29112775}},	//   _kion, štun, נגלי, _raza_,
   {{0x660d03c3,0x6b841c6d,0x2d8306ec,0x63a2804f}},	//   _tsak, glig, slje_, _jion,
   {{0x6d488117,0x63a2f917,0x660d0726,0x6d5a8f06}},	// [7a30] _olda, _mion, _usak, _omta,
   {{0x39474cd5,0x63a29581,0x210303b7,0x3209340d}},	//   óns_, _lion, रजेश_, rway_,
   {{0xe4ee0b75,0x320900dd,0x6b84139a,0x4c9554bf}},	//   _जाति_, sway_, blig, _финс,
   {{0x6d4880ad,0x2905cc58,0xc7b380be,0x3cfb801b}},	//   _alda, zela_, לבע_, ल्ने_,
   {{0xbf470324,0x628281c5,0x29110388,0x2905926f}},	//   únṣe_, _nyoo, _taza_, yela_,
   {{0x81b780c8,0xfe708fc5,0xf2b38f12,0x7d071b4e}},	//   _ছিল_, ردن_, ीर्घ, nejs,
   {{0x2905c3cb,0x395e815d,0x7ae98c4d,0xf8ae07d2}},	//   vela_, dits_, tget, _شکل_,
   {{0x80de00c8,0xe9d99541,0x63a2808c,0x661bf918}},	//   ন্দ্, аки_, _cion, _truk,
   {{0x63a2911b,0xc9a6ad94,0x661b82a0,0x7f498197}},	//   _dion, овые_, _uruk, _ileq,
   {{0x92e98a49,0x672415f5,0x26cf92e5,0x395ef2f4}},	//   য়ে_, _snij, lago_, gits_,
   {{0xa3cb01fe,0x2905f919,0x5f063e1c,0x1cb887bd}},	//   रीम_, rela_, озна, _طالب_,
   {{0x2905f91a,0x26cff386,0x7c2a023e,0xbf8780ff}},	//   sela_, nago_, _àfri, _điền_,
   {{0x6b840e23,0x80ba8054,0x23788061,0xaa58a184}},	//   vlig, _श्वे, _írja_, _лицу_,
   {{0x2369803a,0x7afd5dc0,0x395ed433,0x7e9a807c}},	//   čaju_, _abst, cits_, יסרו,
   {{0x6b840687,0x64a30be4,0x26cf9210,0xdca366b7}},	//   tlig, дара, kago_, дари,
   {{0x63a2822c,0x236967cf,0x96ba0073,0xeeeb00ff}},	//   _xion, gnaj_, _туку_, ưỡng_,
   {{0x6b841c6d,0x26cfde16,0x628281c5,0xa3cb066f}},	// [7a40] rlig, dago_, _xyoo, रीब_,
   {{0x7afd02c4,0x6d43d0fe,0xf99f0176,0x090327d8}},	//   _ebst, jkna, _krèy_, мпун,
   {{0xb9020063,0x6b8425d8,0xcc8a0077,0xc6a6a6c8}},	//   _नए_, plig, _خنده_, орли,
   {{0x34b490f7,0xe61a917e,0x1e8680a9,0x4eba80ab}},	//   ुर्द, иде_, олем, ুল্ল,
   {{0x63a29d3f,0xdd8f80d7,0x929d866f,0x2b4718ad}},	//   _rion, چون_, wełn, _înca_,
   {{0xdd8f806b,0x6d4e791b,0xf99f0176,0x26cf838a}},	//   نون_, nhba, _orèy_, aago_,
   {{0xf746932a,0x26cfb71c,0x22400019,0x395ea6be}},	//   _дево, bago_, lyik_, vits_,
   {{0x7d070933,0x3ce082d0,0x657c0122,0x5a349577}},	//   zejs, şiv_, horh, знит,
   {{0x63a2822e,0x395e8557,0x6f1d91b9,0x6d4e635f}},	//   _vion, tits_, _ósca, khba,
   {{0x3f86ee94,0x929d809a,0x321d831d,0xdb08816a}},	//   llou_, pełn, _drwy_, _mudé,
   {{0xe81d08fd,0x63a2d430,0x6d4e00f7,0x213809d1}},	//   फिया_, _tion, dhba, _morh_,
   {{0x80ba885d,0x2b5f8162,0x201c8824,0xa3df852a}},	//   _श्रे, ciuc_, _vrvi_, _तित_,
   {{0x3326f789,0xfd5784be,0x657c0aa2,0x079b83c8}},	//   _inox_, _adaṣ, forh, יסטל,
   {{0x2369009a,0xb4d5016f,0x22400637,0x26cf8cdb}},	//   wnaj_, हणे_, dyik_, zago_,
   {{0x7d07791c,0x26cfac69,0x93bc8162,0x3f86d1b7}},	//   rejs, yago_, _drăg, klou_,
   {{0x67198327,0x27f395d8,0x26cf9fe7,0x00000000}},	//   _नोंक_, žaní_, xago_, --,
   {{0xaf4b07d2,0x26cff91d,0x2369016b,0x7d070035}},	// [7a50] _مشکل_, vago_, rnaj_, pejs,
   {{0x3495138c,0x6d4e02af,0xcd00009a,0xdb088144}},	//   _напр, chba, ęści_, _dudé,
   {{0x26cf8637,0xb8d30540,0x213809d1,0x2fc700d7}},	//   tago_, _ऑल_, _dorh_, èng_,
   {{0xaca301bc,0x4758804a,0xbf58804a,0xa3cb0b99}},	//   _chụd, орія_, орії_, रीण_,
   {{0x7bc8831d,0x26cf9caa,0xdd1481ac,0x59e22cfc}},	//   _awdu, rago_, _dĺžk, _पियर,
   {{0x7aed5f16,0xd0a28091,0x2ea81d6a,0xa50986e9}},	//   lgat, _gẹgẹ, _गल्त, сека_,
   {{0x26cff91e,0x6d43a38a,0x2b4b0748,0x26c2009a}},	//   pago_, rkna, _klcc_, ybko_,
   {{0x7aed480e,0x3f868722,0x05dc0697,0x3f9901a1}},	//   ngat, clou_, _बिलब, jmsu_,
   {{0xa3cb0744,0x5d558db4,0x02028162,0x2b5f8493}},	//   रीत_, _екат, езын, riuc_,
   {{0x3ea90013,0x2eb61305,0xa3ab02f1,0xe3b39f33}},	//   _agat_, ूर्त, खदा_, _قرص_,
   {{0xf3f080f7,0x48fd085d,0x657c791f,0xb33b1a25}},	//   _لأن_, र्यो_, vorh, _niço,
   {{0x321d831d,0x3f6a06f9,0x23fa81c6,0x2d810234}},	//   _trwy_, симо_, _לפעמ, _akhe_,
   {{0x657c10c9,0xf1a70105,0x7afb8c7e,0xdb0184e8}},	//   torh, _कंगन, mfut, _gulá,
   {{0x7aed7920,0x61e9f921,0xb226807b,0x7bda0110}},	//   egat, muel, stæð, štum,
   {{0xf746144c,0xa066a2f7,0x18668dbd,0x93bc8087}},	//   _неко, _наша_, _наши_, _grăd,
   {{0x25a581cd,0x23b18e14,0x7aed3846,0x8b956ec1}},	//   _lill_, _máj_, ggat, друч,
   {{0xe29740ed,0x7afb83e4,0x6b650196,0x00000000}},	// [7a60] зат_, ifut, jėgu, --,
   {{0xf8bd9513,0x7aed011b,0x9f4600d7,0xe9d70a4c}},	//   ोरिय, agat, dulé_, яку_,
   {{0x61e9f922,0x2252009a,0x31660267,0xdb240019}},	//   huel, szyk_, đoz_, _ہوگی,
   {{0x61e9f923,0x25a5a630,0x4422a384,0x2d87f924}},	//   kuel, _aill_, _čk_, elne_,
   {{0x539b010f,0xd6cf8154,0x61e98216,0xceb304de}},	//   _ליטו, اقه_, juel, גיד_,
   {{0xf9878117,0x25a58635,0x660459eb,0x61e9da6d}},	//   _سب_, _cill_, _mpik, duel,
   {{0x69dd8038,0xb4ac8105,0x200c047f,0x60260190}},	//   ásen, _गली_, _èdi_, _эдва,
   {{0xe3af8077,0x2d87b27a,0x25adf148,0x98a30956}},	//   درو_, alne_, _fuel_, _чисе,
   {{0x6d5e7925,0x64430214,0xdcf88c22,0xdb1c3dc9}},	//   _ompa, _üniv, lovč, rprè,
   {{0x25fb85b3,0x63a60687,0x7aed0019,0x6d5e00ee}},	//   ोबरी_, _likn, zgat, _nmpa,
   {{0xc05a81e5,0x66047926,0xdcf8842b,0x764280fc}},	//   сіп_, _apik, novč, lyoy,
   {{0x6d5e0db7,0x69d67119,0x6f1606e7,0x61e9923d}},	//   _ampa, ksye, _cayc, buel,
   {{0x61e985b4,0x764280a4,0x5fce0768,0x62860711}},	//   cuel, nyoy, _हौसल, _nyko,
   {{0x61e42f7f,0xdcf889d1,0x753a8102,0x7aed0362}},	//   dril, kovč, _jotz, wgat,
   {{0x0133990c,0x66047927,0xd4040c40,0x1dd900d4}},	//   _سعود, _epik, няти, _भटकत,
   {{0x7aed0087,0x3ce90074,0x3ea916fb,0x6286067f}},	//   ugat, _जाके_, _ugat_, _byko,
   {{0x7aed72a7,0x7bd50019,0xd7f88087,0x63a6492f}},	// [7a70] rgat, sszu, ltă_, _dikn,
   {{0x7aed7928,0x48ab1988,0x69c481b9,0xa41c86a7}},	//   sgat, стам_, _ħiel, पटाप_,
   {{0xd7f88012,0x60ce0144,0x61e40100,0x2ef599bb}},	//   ntă_, _debm, aril, дзер,
   {{0xf77396a5,0xf1dd809a,0x25a5f929,0xadc4046d}},	//   راض_, _मिलन, _sill_, _ayẹw,
   {{0x25ada51c,0x61e9f92a,0x764282d5,0x7f4d0197}},	//   _quel_, xuel, gyoy, _mlaq,
   {{0x61e985a4,0xc2120039,0x61e2007a,0x6b828032}},	//   vuel, _שהם_, šolc, _akog,
   {{0x25a5d9b3,0xe9ff001c,0x753ab2be,0x3b9583a7}},	//   _vill_, _khắc_, _dotz, мјит,
   {{0x25a59965,0xb2259509,0x7528e613,0x7f4d0609}},	//   _will_, дмил, _endz, _nlaq,
   {{0x25a584b5,0x6d474b55,0xf77089a7,0x44210115}},	//   _till_, kkja, _صاف_, _lrh_,
   {{0x6b82f92b,0xdb1c2e46,0x48f2001b,0x753a8cdb}},	//   _ekog, rpré, ुभयो_, _gotz,
   {{0xdee62118,0xdb1c07e2,0x65638073,0x6b4e846d}},	//   мони, spré, minh, _dùgb,
   {{0xd90f8117,0x6563f92c,0x501a0039,0x6d5e09ca}},	//   ئیں_, linh, קורו, _smpa,
   {{0x61e9f92d,0x236da1f3,0xa2948221,0xe8ee817c}},	//   quel, mnej_, _заці, _ил_,
   {{0x236d998a,0x6b89a0ef,0x61e40850,0x6563d6d7}},	//   lnej_, lleg, vril, ninh,
   {{0x6da30abe,0x628f8024,0xe5a32634,0xd7f88087}},	//   тира, škoć, тири, ctă_,
   {{0x6b898357,0xe9ff0028,0x65639217,0x236df92e}},	//   nleg, _chắc_, hinh, nnej_,
   {{0xe1f981e2,0x6563d293,0x6f19831d,0x6d5e0359}},	// [7a80] ntų_, kinh, ddwc, _tmpa,
   {{0x6d5e0397,0x69d602e7,0x62860a21,0x65638187}},	//   _umpa, rsye, _vyko, jinh,
   {{0x62860063,0x65638073,0xa00a05ff,0x6b89b8b9}},	//   _wyko, dinh, تقال_, kleg,
   {{0x61e4003a,0xe1f981e2,0xdcf88088,0x6443a9d9}},	//   pril, ktų_, rovč, dyni,
   {{0x236df223,0x7d17029a,0x6b89821e,0x60ce01c0}},	//   dnej_, _yaxs, dleg, _tebm,
   {{0x6b828687,0x6563b318,0xf8b2052a,0x64438114}},	//   _skog, ginh, _जलिय, fyni,
   {{0x6b89bc25,0x69cb81b4,0x64431238,0x212a0706}},	//   fleg, _awge, _ünit, _inbh_,
   {{0x27f7000d,0x521492b2,0xd0418085,0x6b89ac9f}},	//   žení_, едит, qalə, gleg,
   {{0x2918792f,0x6d470125,0x6563df9c,0x26c6e8f0}},	//   _kara_, ykja, binh, mboo_,
   {{0x29187930,0xd8f880e8,0x270e8424,0x656383a7}},	//   _jara_, чної_, _ससुर_, cinh,
   {{0x29187931,0x6b89d0bf,0x236df932,0x7f4d4b4f}},	//   _mara_, bleg, bnej_, _plaq,
   {{0x29187933,0xd7f8802e,0xb7d88065,0x6b89809a}},	//   _lara_, rtă_, _ہوتا_, cleg,
   {{0xd7f8802e,0xdb08baa8,0x29180162,0x56941afd}},	//   stă_, _judí, _oara_, кают,
   {{0x291860ff,0xd7f88087,0x77608118,0x6b80f934}},	//   _nara_, ptă_, _lmmx, lomg,
   {{0xe7e58d38,0x5ba72345,0x6d477935,0xdb1a8866}},	//   _किया_, драз, rkja, _atté,
   {{0x44210bc1,0x6563d707,0x290ca9ea,0x6b80f936}},	//   _vrh_, zinh, leda_, nomg,
   {{0x291845a1,0x60c90088,0x64438035,0x851a0054}},	// [7a90] _bara_, _đemb, zyni, _फोकट_,
   {{0x29180763,0x290cdd49,0x4421026f,0x6563df9c}},	//   _cara_, neda_, _trh_, xinh,
   {{0x29187937,0x656383a7,0xe9ff001c,0x248980fc}},	//   _dara_, vinh, _thắc_, ƙami_,
   {{0x05e084e5,0x290c8098,0xdb08816b,0xe1f98084}},	//   _निशब, heda_, _budí, ytų_,
   {{0x29187938,0x65638073,0x236d81ac,0x16220ebf}},	//   _fara_, tinh, vnej_, मियर_,
   {{0x2918549e,0x290c920e,0x61ed1600,0x6443f939}},	//   _gara_, jeda_, mual, tyni,
   {{0x673ba2ae,0x6563f93a,0x6b89cf90,0x236dda65}},	//   _touj, rinh, tleg, tnej_,
   {{0x291837af,0x65639677,0x38b50b4c,0x6b51016d}},	//   _zara_, sinh, _fúró_, _fåge,
   {{0x236da201,0x2918793b,0x6b89ac9f,0x656383a7}},	//   rnej_, _yara_, rleg, pinh,
   {{0x6b89a09d,0xdb0600f1,0xe1f98110,0x290c82f1}},	//   sleg, _pikë, rtų_, geda_,
   {{0xe1f981e2,0x6b89f93c,0x61ed2e58,0xef1981b9}},	//   stų_, pleg, hual, _każ_,
   {{0x442635d5,0xa822b1a7,0xb33b00f1,0x61ed0102}},	//   _čo_, اکون, _diçk, kual,
   {{0x290cf93d,0x3ea4016d,0xdb0883a8,0x25bf8609}},	//   beda_, ämt_, _xudí, _jtul_,
   {{0x290c8333,0x98aa001b,0xdb050019,0x61ed137c}},	//   ceda_, _době_, _ruhá, dual,
   {{0xf1bf0307,0x291839ba,0x61fbc794,0xa3cb016f}},	//   _atá_, _rara_, ltul, रील_,
   {{0xdbd60074,0x3eadcaf9,0x61fbf93e,0xa3c28a27}},	//   _rääg, _nget_, otul, ्ठत_,
   {{0x2918793f,0x61fbf8d5,0x3f821caf,0x6f0400b4}},	// [7aa0] _para_, ntul, moku_, _ibic,
   {{0x5e5700be,0x3f827940,0x29180085,0xdce38110}},	//   _נייע_, loku_, _qara_, monė,
   {{0x29187941,0x3ead808e,0x25bf8326,0x6e2402d4}},	//   _vara_, _bget_, _atul_, _hrib,
   {{0x291801cd,0x60c3017b,0x25bf8239,0x3ae80065}},	//   _wara_, ınma, _btul_, _کبھی_,
   {{0x7981ad19,0x61ed0867,0xef198372,0x8af0011c}},	//   kolw, cual, _daż_, rhəd,
   {{0x59b51094,0x69c47942,0x3ead904a,0x3f8228bd}},	//   _अंतर, mpie, _eget_, hoku_,
   {{0x290cf943,0xf8a70701,0xdee69950,0x66e69511}},	//   veda_, _कृपय, _пови, _пова,
   {{0x31c69242,0x2d858214,0xe805050d,0x6b510efa}},	//   нсов, _ekle_, _रहता_, _tåge,
   {{0x290c805c,0x61fbd147,0x69c47944,0x49748615}},	//   teda_, gtul, npie, клис,
   {{0x2ee0328d,0x6f043168,0x09f70039,0xdb06010c}},	//   _adif_, _abic, עמים_, _diké,
   {{0xb4cc8701,0x61ed1717,0xf65f8125,0x6e2400b4}},	//   लरी_, zual, _þær_, _arib,
   {{0x7d1af945,0x3ead0aa2,0x98aa01d0,0x3f8208f9}},	//   _hats, øet_, _sobě_, goku_,
   {{0x7d1af946,0x614686c8,0x290c8072,0xd9469fe5}},	//   _kats, _педа, peda_, _педи,
   {{0x0217810f,0xc69383c8,0xd90e803d,0x2d850036}},	//   _נחום_, טאר_, _اید_, ôle_,
   {{0x7d1a83c3,0xef1f03bf,0x6e240c2e,0xc88581ec}},	//   _mats, nlük_, _erib, ößte_,
   {{0xb33b0085,0xa3e895b2,0x26d27947,0xfaff03ed}},	//   _kiçi, _बिन_, _geyo_, _ajër_,
   {{0x3da71878,0x6e247948,0xb5a71663,0x672d7949}},	// [7ab0] _проб, _grib, _прой, _inaj,
   {{0x6f0f2e3c,0x7d1aa419,0x6f1d4721,0xa3c280c2}},	//   lecc, _nats, ldsc, ्ठा_,
   {{0x61ed1441,0xfe7023e0,0x2d830984,0x69c401e8}},	//   sual, _ندی_, moje_, apie,
   {{0x6458f94a,0x2d831d9d,0xdc3600be,0x6f0f62a7}},	//   dzvi, loje_, _סארט_, necc,
   {{0x7d1af94b,0x6b8d5aae,0x5f749a05,0x645880e1}},	//   _bats, mlag, دالر, ezvi,
   {{0x2d83794c,0x7d1a9e34,0x6b8d10b6,0xdb088580}},	//   noje_, _cats, llag, _audà,
   {{0x7d1a84bb,0x2ef58992,0xef1981b9,0x4cca80ab}},	//   _dats, _извр, _taż_, _রাখু,
   {{0x6b8d794d,0x61fbf94e,0xb33b627c,0x6f1d00f3}},	//   nlag, ttul, _biçi, jdsc,
   {{0xfe738065,0x2d83794f,0x7d1ad072,0x11d680f7}},	//   _صدر_, koje_, _fats, نوية_,
   {{0x2d8301e2,0x98a59c39,0x61fbc001,0x6d4a8edc}},	//   joje_, кипе, rtul, ckfa,
   {{0x69c40063,0xf8b202f6,0x6f1bf950,0x6f0f12cc}},	//   zpie, ישי_, _kauc, fecc,
   {{0x66161da3,0x7981d3c1,0x6b8d442b,0x61fb8087}},	//   _psyk, solw, jlag, ptul,
   {{0x780d000c,0x6b8d7951,0xa3d411bc,0x7d1af952}},	//   सबुक_, dlag, सीन_, _yats,
   {{0x0cb000c8,0x4d15054c,0x3f82012b,0x2d837953}},	//   কর্ত, льст, soku_, goje_,
   {{0x69dd0186,0x6b8d7954,0xdbcc002a,0x6b6788f9}},	//   _avse, flag, _póñe, _gègè,
   {{0x6f043009,0x6609d9d1,0x6b8d7955,0x6f1b87c6}},	//   _ubic, _opek, glag, _nauc,
   {{0xf2d28158,0x03a3303c,0xef1f0214,0x69dbc79a}},	// [7ac0] יען_, рито, zlük_, nsue,
   {{0x672d40fb,0x25d7093f,0x63abf956,0xd5b7000f}},	//   _znaj, _שוין_, _lign, _इंतज,
   {{0x69c47957,0x6f1b96a0,0x7d1a8336,0x07a681b5}},	//   spie, _bauc, _rats, важн,
   {{0x7d1a8bfa,0xdee68a7c,0x0bb70051,0x69db8be7}},	//   _sats, тоди, _שלכם_, ksue,
   {{0x6b8400e7,0x7d1acfac,0x61e9817f,0xed5a9539}},	//   moig, _pats, jrel, мод_,
   {{0xa8061a1f,0x44258187,0x61e998ad,0x63abd48d}},	//   _изгл, _brl_, drel, _aign,
   {{0x6609843b,0x6f0f0876,0x63abddeb,0x3f6a8ae7}},	//   _epek, yecc, _bign, _живо_,
   {{0x7d1ac650,0x6f0f04c3,0x6f1b82be,0x5b14895d}},	//   _wats, xecc, _gauc, умит,
   {{0x7d1af958,0x6f0f7959,0xf74383a7,0x9cf6802e}},	//   _tats, vecc, _тето, _ачеш,
   {{0x63abac9f,0x35dc0035,0x6b8d007a,0x7d1a822c}},	//   _eign, _बिज़, zlag, _uats,
   {{0x6f0f2e3c,0x2d83795a,0x61e9a725,0x63abf95b}},	//   tecc, voje_, arel, _fign,
   {{0x6b8400e7,0xf99f03ec,0x2d5402f1,0x69db8661}},	//   joig, _apèl_, _näeb_, bsue,
   {{0x6f0f11b9,0x2d831d9d,0x61e99238,0x7ae2e042}},	//   recc, toje_, crel, _idot,
   {{0xe9ff0104,0x644581ec,0xac190073,0x0cbf0f21}},	//   _nhạc_, ähig, ногу_, ्रेम,
   {{0x2d83028f,0x6b8d2130,0x7bdc2472,0x1af58264}},	//   roje_, tlag, gsru, _আসতে_,
   {{0x291c8182,0x97a411e9,0x672d0010,0x2d833033}},	//   _hava_, _крыл, _unaj, soje_,
   {{0x49751878,0x6b8d0456,0x291c9bb9,0x2018795c}},	// [7ad0] глас, rlag, _kava_, _asri_,
   {{0x6b8d408d,0x6f1bf95d,0x29cf4635,0x291e8019}},	//   slag, _sauc, rża_, ndta_,
   {{0x6c350c2b,0x6b8d10cc,0x7ae28009,0x30a7180f}},	//   _صفحا, plag, _odot, трав,
   {{0x7bc72a57,0x61e98aaa,0x291cf95e,0xc2e880ab}},	//   mpju, yrel, _lava_, ক্তি_,
   {{0xdef887ac,0x4425f95f,0xfce5a4b6,0x201e00d2}},	//   тых_, _srl_, голо, _štit_,
   {{0x63ab8213,0x7ae2f960,0xe3b0004e,0x0d84902a}},	//   _sign, _adot, _دری_, алін,
   {{0x97a78048,0x26d948ba,0x63aba898,0xdb088333}},	//   _арал, kaso_, _pign, _sudá,
   {{0x61e98003,0xe4e308fd,0xb8821ded,0x3f8901c0}},	//   trel, कृति_, číta, _nkau_,
   {{0x2249048f,0x63abf961,0x291cbd92,0x28a70ebf}},	//   nyak_, _vign, _bava_, _कृति,
   {{0x61e9f962,0x291c92d0,0x3f8900dd,0x7ae28102}},	//   rrel, _cava_, _akau_, _edot,
   {{0x69db9b65,0x63ab820d,0x3a2680f3,0x291cb8ad}},	//   ssue, _tign, _erop_, _dava_,
   {{0x69c11807,0x61e9f963,0x628b809a,0x26d90c2e}},	//   _člen, prel, _tygo, gaso_,
   {{0xcdf60a7f,0x09e58009,0x55f60e11,0x291c8037}},	//   ычны, _солн, ычну, _fava_,
   {{0x6d41c512,0x60d50259,0x3f8900b9,0x7bdc7964}},	//   _jola, _nezm, _ekau_, tsru,
   {{0x6b510502,0x5faf0e10,0xf992807c,0x26d97965}},	//   _såga, _जंगल, _הרג_, baso_,
   {{0x26d905e4,0x7c2ef966,0x6d4193fa,0x13d1801b}},	//   caso_, _ábre, _lola, _सबैभ,
   {{0x0eaa035f,0x60d559ca,0xa3d40540,0x7bdc1388}},	// [7ae0] _який_, _bezm, _सौर_, ssru,
   {{0x6b513032,0x6d41f967,0x291c8118,0x2ecc836d}},	//   _våga, _nola, _xava_, ार्त,
   {{0xd0488201,0x40961bb7,0x46ea8e17,0x60d5002e}},	//   fadə, урат, еден_, _dezm,
   {{0xf1bf0333,0x291c0390,0x27e7066e,0x6d41f2b1}},	//   _irán_, žva_, ánna_, _aola,
   {{0x6d41f968,0x1634b10c,0xdee3a639,0xe9ff0129}},	//   _bola, реля, сочи, _thạc_,
   {{0xa3cb073c,0xa3b81995,0x7af60084,0x3f8f82f1}},	//   रीक_, _चढा_, lgyt, algu_,
   {{0x4ab8023c,0xab5c8029,0x69c283b2,0xfbaa8049}},	//   _अलाव, _atļa, _stoe, нтий_,
   {{0x7d1e0181,0x6d418307,0xb6a6f969,0x33203cc0}},	//   _laps, _eola, _библ, ndix_,
   {{0x6d41f0cb,0xdd8f881b,0x316a813a,0x26d900e5}},	//   _fola, _کول_, ешно_, vaso_,
   {{0x6d41a6aa,0x7d1e000d,0x6d4e0a0f,0xdb0b823e}},	//   _gola, _naps, jkba, _ligè,
   {{0xb4c2823c,0x31370051,0x893700be,0x291c82d6}},	//   ूरी_, אריך_, אריע_, _vava_,
   {{0x3a2683d3,0x60c487d9,0x6d41ada5,0xa3b80105}},	//   _trop_, _şimd, _zola, _चढ़_,
   {{0x26d9044b,0xe29280f7,0x291ce72d,0x246e8201}},	//   raso_, _اذا_, _tava_, _həm_,
   {{0x040e00c8,0x74ca9c9d,0x6d58f96a,0xf65f0366}},	//   হিনী_, _स्मृ, nhva, lbæk_,
   {{0x070486ce,0x26d92a0f,0x88bb80be,0x06f68a27}},	//   रभाव_, paso_, _אזוי, ीभाव_,
   {{0x60daa981,0x98bc8176,0xae222af8,0xe31502ee}},	//   latm, _movč_, मिशन_, јмањ,
   {{0x5a3500b3,0x236928cd,0xdb0bc3e0,0xce6825f5}},	// [7af0] шнат, riaj_, _digè, _брэд_,
   {{0x7c28f96b,0x660d1629,0x2369009a,0xdce380c3}},	//   _ordr, _ipak, siaj_, tinč,
   {{0xa3cb09a3,0x8ccb3d6d,0xd011026a,0xdb1c1c32}},	//   रीख_, _त्यो, تلا_, sprá,
   {{0x398b8aa2,0x660d0133,0xdce38be4,0x644a8035}},	//   løst_, _kpak, rinč, dyfi,
   {{0x6d41a86f,0xa91c80e1,0x7c28f96c,0x8ca78075}},	//   _pola, voľn, _ardr, टेनो,
   {{0x660d3b2d,0xa5098c9d,0x6d4181b4,0x60da80dd}},	//   _mpak, тека_, _qola, jatm,
   {{0xeab180f7,0x8cc19391,0x60da8380,0x36d58084}},	//   يعة_, रुषो, datm, _вобр,
   {{0x0b4587b6,0x05b500d4,0x660d09a4,0x7e7b8cdb}},	//   рнин, ंदाब, _opak, _txup,
   {{0x5f448c2b,0x660d02d5,0x6d4e067f,0x63af01b4}},	//   _انقل, _npak, ykba, _micn,
   {{0x63af1601,0xe61088ca,0x291308f1,0x6d58816b}},	//   _licn, _عشق_, nexa_, chva,
   {{0x6b511918,0x660d1600,0x2d87f96d,0x200103f8}},	//   _någo, _apak, mone_, nthi_,
   {{0x63af0706,0x6e29ed08,0x3f6a13b4,0x00000000}},	//   _nicn, _kreb, тимо_, --,
   {{0x7bc57535,0x43848013,0x7f3a8158,0x0ab48c48}},	//   _athu, _النق, דערו, _احمد,
   {{0x2d87f96e,0x69c9b179,0xa0a5c54e,0x660d00dd}},	//   none_, mpee, _калд, _dpak,
   {{0x6f09a0d9,0xdca61285,0x64a62428,0xdfd180f7}},	//   _obec, рави, рава, _بيع_,
   {{0x6e298140,0x3a2d026c,0x2d87b7cd,0x589481a8}},	//   _oreb, _šepa_, hone_, _اجهز,
   {{0xe8fa307d,0x52aa130f,0x2d8786ee,0xc33282f6}},	// [7b00] кла_, твам_, kone_, חון_,
   {{0x2d87b4a2,0x7c2a002a,0xf1bf0129,0x38cb01f9}},	//   jone_, _áfro, _trán_, نامی_,
   {{0x2d87f96f,0x661b94c7,0x46ba0fcc,0xd10203b6}},	//   done_, _asuk, _इलाह, र्षण_,
   {{0x61ed384d,0x6e29b0f3,0xe5c6beb9,0x661b8748}},	//   bral, _breb, аско, _bsuk,
   {{0x2d87f970,0x6e299193,0x63a45a20,0x0cd1801b}},	//   fone_, _creb, mmin, हरूम,
   {{0x2d87f971,0xb5fb0019,0xcbe6c0ed,0xb4c280c2}},	//   gone_, szág, ации, ूरे_,
   {{0x6ca38081,0xa9670249,0xad9b016a,0x60daa126}},	//   оръж, _тира_, ntúa, vatm,
   {{0x6d5880fe,0x644af972,0xa3cb2af8,0xf1bf0f09}},	//   shva, ryfi, रीट_, _orál_,
   {{0x63a46de3,0x2d879ba4,0x644adf48,0x9982801b}},	//   imin, bone_, syfi, íků_,
   {{0x6602f973,0x63a468c7,0x67208c53,0x717481a8}},	//   mtok, hmin, _hamj, إهدا,
   {{0x6602f6da,0x60dad21f,0x63a47974,0xeb36b1a7}},	//   ltok, ratm, kmin, _پراخ,
   {{0x8cca81ab,0xdce38029,0x6722f975,0x61ed7976}},	//   _स्तो, minā, ndoj, yral,
   {{0x60dad984,0x6602f977,0xdce380eb,0x661b80b9}},	//   patm, ntok, linā, _xsuk,
   {{0x6b5810ab,0x61ed0965,0x672080c3,0x61e2913b}},	//   _nígb, vral, _lamj, _ivol,
   {{0x06d780ab,0x6b55bdf7,0x6b510106,0x394301f4}},	//   _হাসি, _hága, _fågl, _rojs_,
   {{0x6720f978,0x63a43d8b,0x2d87f979,0x63b7016d}},	//   _namj, gmin, zone_, _vuxn,
   {{0xa3cb00d4,0x660d1eec,0x2d87b819,0x2913002a}},	// [7b10] रीज_, _upak, yone_, texa_,
   {{0x61ed5343,0x63a4436c,0x98c73811,0x60d8826c}},	//   rral, amin, рсал, _jevm,
   {{0x2913062f,0x61ed1325,0x63a4094d,0x7bc532f5}},	//   rexa_, sral, bmin, _uthu,
   {{0x6e29a3fa,0x61e2807d,0xdce38029,0x2d87be61}},	//   _preb, _ovol, dinā, wone_,
   {{0x6d450006,0x539a010f,0xfe709a3e,0x1af580ab}},	//   _koha, _תירו, وده_, _আসলে_,
   {{0x6d456139,0x6e299487,0xb4c1c50b,0x2abd026b}},	//   _joha, _vreb, ंडे_, _fábó_,
   {{0x6d453de5,0xb5fb0118,0x0445f97a,0x2d87a9da}},	//   _moha, nzáb, сейн, rone_,
   {{0x6e29f97b,0xe299c600,0x661bf97c,0x2d87a012}},	//   _treb, лай_, _tsuk, sone_,
   {{0x2d87f97d,0x316c8859,0x26ddf97e,0x661b8234}},	//   pone_, fidz_, mawo_, _usuk,
   {{0x672082fd,0x6d45797f,0x69c98009,0xdce380eb}},	//   _zamj, _noha, rpee, binā,
   {{0x1b1f80c8,0x04958013,0x69c9837a,0xdce38029}},	//   ভাবে_, _الاح, spee, cinā,
   {{0x2f564c2f,0x8c490085,0x09cd00ab,0x63a4011c}},	//   стос, _maşı, _লিনা, xmin,
   {{0x6d4521aa,0xa3b0800f,0x7521f980,0x877a80be}},	//   _boha, _टूट_, _kalz, רארי,
   {{0x04461a1f,0xada625f2,0x6d457981,0x6b898299}},	//   бегн, сагл, _coha, loeg,
   {{0x61e2803e,0x63a40074,0x224d8019,0x75218214}},	//   _zvol, tmin, lyek_, _malz,
   {{0x67560077,0x236d809a,0xaca38133,0x6b899384}},	//   _دختر, niej_, _adịl, noeg,
   {{0xeb972f0c,0xdce38029,0x224d8019,0x26dd8234}},	// [7b20] сит_, zinā, nyek_, dawo_,
   {{0xa3e8864a,0x8c49017b,0xb4e68697,0xad9b0118}},	//   _बिल_, _başı, _भये_, ptúa,
   {{0x236d8063,0x6d5c0ad0,0x672080f1,0xd8da80be}},	//   kiej_, mhra, _pamj, רקער,
   {{0x8c490201,0x656e366f,0x6602f982,0x6d4500e1}},	//   _daşı, libh, ttok, _zoha,
   {{0x6d4508b1,0xa3d403eb,0xca750071,0x644e45ba}},	//   _yoha, सीर_, _дуры, lybi,
   {{0x7521a816,0xdb1c01ec,0x7a0a00eb,0x6602f983}},	//   _calz, sprä, rētā, rtok,
   {{0xf86316d4,0xf36695b5,0x61e2f984,0x06d780ab}},	//   _евро, йтин, _svol, _হারি,
   {{0xf0633e7e,0x2b400754,0x60d8880a,0xdce380eb}},	//   _эксп, njic_, _sevm, rinā,
   {{0xdce38029,0x75218197,0x224d8019,0x2d8a41b5}},	//   sinā, _falz, gyek_, kobe_,
   {{0x8c4902bb,0x26c2009a,0x644e0084,0x290a80e1}},	//   _yaşı, ecko_, kybi, ýba_,
   {{0xaab8058c,0x61f601e0,0x23810110,0x2d8a7985}},	//   _अलंक, huyl, lėje_, dobe_,
   {{0x224d861b,0x442cf986,0x2fc7808e,0x290281d0}},	//   byek_, _ird_, _dtng_, řka_,
   {{0x238101e2,0x442c82f7,0x6e2200eb,0x8af00085}},	//   nėje_, _hrd_, _šobr, rhəl,
   {{0x67d4845d,0x6d5c02cd,0xb4e6800d,0x26dd83f7}},	//   _доку, ghra, _भयो_, zawo_,
   {{0x60de00dd,0x64b906a7,0x93bc8162,0x4fc69246}},	//   dapm, _आलीश, _brăi, _усла,
   {{0x443f003a,0xa91c81ac,0x63ba811f,0x442c91e6}},	//   ću_, koľk, _mutn, _mrd_,
   {{0x6d5c0ad0,0xe820923a,0x3f8b00d2,0xdb0881ac}},	// [7b30] bhra, यिका_, mocu_, _budú,
   {{0x6d5c06f6,0x236d8063,0x442c93c2,0x6e2d1171}},	//   chra, ziej_, _ord_, _irab,
   {{0x442763f8,0x63ba83fb,0x6e2d10e8,0x6e220118}},	//   _én_, _nutn, _hrab, _áobr,
   {{0xdddb8a56,0x75218799,0x2a60022c,0x3cfe8037}},	//   _využ, _salz, bzib_, _actv_,
   {{0x442c9c14,0x6b8982d8,0xf1272380,0x63ba826c}},	//   _ard_, voeg, _льво, _autn,
   {{0x67d5494d,0x8c490214,0x442cf987,0x63ba8bb1}},	//   _могу, _taşı, _brd_, _butn,
   {{0x58d40256,0x6b587988,0xdb1c1235,0x3f8b0b80}},	//   _хост, _híga, språ, kocu_,
   {{0x225f811e,0x6d5c016b,0xc1788084,0x6d8d81df}},	//   tzuk_, zhra, enė_, túas,
   {{0x24898063,0x656e029b,0x3dc9022c,0xa3e586a7}},	//   łam_, yibh, _ntaw_, _भटक_,
   {{0x6f0d31d8,0x6009968a,0x764f009a,0xb4b80327}},	//   _abac, аном_, dycy, _छले_,
   {{0x236d809a,0x442cc814,0x3dc9008e,0x6e2d4e6c}},	//   piej_, _grd_, _ataw_, _arab,
   {{0x6e2d36f9,0x5ea800ab,0x16aa0ae7,0x9eaa24dd}},	//   _brab, _ক্ষে, ивни_, ивна_,
   {{0x6d5c11cd,0x200a8214,0x656e0197,0x25b28214}},	//   thra, çbir_, tibh, _ünlü_,
   {{0x6e2d7989,0x644e0d42,0x2fc7808e,0x6f0d6018}},	//   _drab, tybi, _ttng_, _ebac,
   {{0x6e2d00ad,0xa34a0081,0x656e2360,0xd3ba0048}},	//   _erab, азва_, ribh, ругі_,
   {{0x7afbf98a,0x42ca0254,0x6b55a3be,0xe81e8105}},	//   ngut, рган_, _mágo, _बनता_,
   {{0xb1460a95,0xe0da0b01,0xc8788085,0x39460084}},	// [7b40] онал, ива_, mağa_, онаг,
   {{0x40964aac,0xaca3819d,0x6724004f,0x6f0d0b80}},	//   орет, _adọl, _haij, _zbac,
   {{0x93bc8087,0xb17b0106,0x3cfe8144,0x443c8118}},	//   _trăi, _tvån, _rctv_, xxv_,
   {{0x3cfef98b,0x25b7003d,0x11d6102a,0x23810084}},	//   _sctv_, _دهید_, _мігр, tėje_,
   {{0x672400eb,0x442c88ae,0xe53481e2,0x63ba8699}},	//   _maij, _srd_, зель, _sutn,
   {{0x442cf98c,0x61e4080a,0x6b5583a8,0x6b96798d}},	//   _prd_, msil, _bágo, llyg,
   {{0x6b5c80e7,0x200581a1,0x39940198,0x23810084}},	//   _lége, jtli_, jäsi_, sėje_,
   {{0x8cca8ebf,0x61e4798e,0x672418b2,0x7afbd7b9}},	//   _स्रो, osil, _naij, ggut,
   {{0x3947a110,0x60dc2bcb,0x645801b9,0x61e4424d}},	//   _bons_, _kerm, _żvil, nsil,
   {{0x60dc0886,0x3a370039,0x6b558118,0x442cf98f}},	//   _jerm, קרים_, _fágo, _trd_,
   {{0x6d5a8009,0x61e41c08,0x3947d433,0x5f950087}},	//   _ilta, hsil, _dons_, зинт,
   {{0xd6db0fbb,0x6e2d061b,0x672401c0,0x61e47990}},	//   што_, _prab, _caij, ksil,
   {{0x6d48f991,0x3947809f,0xdb060009,0x67240267}},	//   _koda, _fons_, _mikä, _daij,
   {{0x60dc7992,0x6ad3000f,0xc5f382f6,0xd5b801e2}},	//   _nerm, तर्र, ודש_, ўся_,
   {{0x63a2b04e,0x29c08028,0x5c042e47,0x6b967993}},	//   _khon, _hòa_, мята, flyg,
   {{0x6f0d0025,0xa3dc853f,0x7ae0f994,0x53341c9b}},	//   _ubac, तीय_, namt, мест,
   {{0x60dc2c0a,0x776d07f4,0x63a29e9e,0x61e40c27}},	// [7b50] _berm, _imax, _mhon, gsil,
   {{0x6d48f995,0x60dc010b,0x7ae098b3,0x8cca84c5}},	//   _noda, _cerm, hamt, _स्लो,
   {{0x60dc1277,0x3f159d67,0x63a28114,0xdce700eb}},	//   _derm, здес, _ohon, cijā,
   {{0x441a0051,0xdcf8800d,0x4421020f,0x6b5c8b4c}},	//   _פורס, pově, _ish_, _légb,
   {{0x60dc7996,0x6d48e0e2,0xbc68003d,0x5f0000d4}},	//   _ferm, _boda, _همین_, ष्ट्_,
   {{0x6d48f997,0x8d659317,0x60dc079a,0xdb0bd2ed}},	//   _coda, явле, _germ, _vigí,
   {{0x6d48e17a,0x63a28090,0x7aef8118,0x00000000}},	//   _doda, _bhon, ócto, --,
   {{0x63a2f998,0x44217999,0xe9d99bd8,0xc245b5aa}},	//   _chon, _msh_, бки_, зник,
   {{0x63a291e7,0xe1f180f7,0xddc6009a,0x95c88b26}},	//   _dhon, رسة_, zykł, _духа_,
   {{0x395e8051,0x60dc01df,0x7afb833e,0xc69280be}},	//   ghts_, _xerm, sgut, _טאן_,
   {{0x63a281a8,0x7d7a80be,0xad9b023e,0x672421ba}},	//   _fhon, _פרעג, rtúl, _paij,
   {{0x7c2a07a3,0x6d488a0f,0xed598a20,0x6b8d008e}},	//   _áfri, _zoda, _duže_, joag,
   {{0xc60980ab,0x2005801b,0x539a81c6,0x899f026b}},	//   লিকা_, stli_, _פינו, _díẹ̀,
   {{0x69d98372,0x395ef99a,0x6b5c8019,0x63a2f99b}},	//   _iwwe, chts_, _vége, _zhon,
   {{0x68e1f88a,0x913a8039,0x63a98084,0x7e628037}},	//   mald, _לעסק, omen, zzop,
   {{0x68e1b85d,0xbb430dc7,0x63a9f99c,0x3f788088}},	//   lald, неск, nmen, rčuk_,
   {{0x63a9f99d,0x80de80ab,0xb18381d0,0xdfa512c5}},	// [7b60] imen, _মাত্, šťuj, _تحوي,
   {{0xdca617f9,0x68e1f99e,0x64a612a0,0x63a9dfbf}},	//   _напи, nald, _напа, hmen,
   {{0x63a9f99f,0x60dc1d80,0xf99f0032,0x249f0326}},	//   kmen, _verm, _apès_, ƙuma_,
   {{0x6d48f314,0x63a992d3,0x2d981836,0x61e479a0}},	//   _soda, jmen, llre_, psil,
   {{0xa3b5000f,0x68e1a28b,0x63a2f9a1,0x63a981b5}},	//   _छूट_, kald, _rhon, dmen,
   {{0x63be2376,0x63a9f9a2,0x63a294f2,0xd5b9821e}},	//   _kupn, emen, _shon, ісі_,
   {{0x63a29ffd,0x7d18f9a3,0x7ae0b7f0,0x6d5a81d0}},	//   _phon, revs, tamt, _vlta,
   {{0x80de80c8,0x987b00be,0x5a3480b3,0x291a06c2}},	//   _মাধ্, _האלט, днит, lepa_,
   {{0xa3dc823c,0x6d48ad12,0x7ae084b9,0x68e18a64}},	//   _तौर_, _toda, ramt, fald,
   {{0x63a9bed7,0x7ae090f6,0x6d5ad430,0x68e18dde}},	//   amen, samt, _ulta, gald,
   {{0x7ae08a20,0x69d981cd,0xa91c81ac,0x80de80ab}},	//   pamt, _ewwe, koľv, _মাদ্,
   {{0x389b00be,0x29c0801c,0x628281c5,0x63a9f9a4}},	//   מיינ, _tòa_, _txoo, cmen,
   {{0x7d0300f2,0x68e1811e,0xa3c2809a,0xf1bf0028}},	//   _önsk, bald, _एंड_, _trái_,
   {{0x61438a94,0x68e185dc,0x5e578158,0x291a120e}},	//   _печа, cald, ליכע_, jepa_,
   {{0xdb1a85e4,0x6d5500f3,0x439500e8,0xab95004a}},	//   _auté, rkza, давс, диві,
   {{0x6b58002a,0xa87b84de,0x69be02f1,0x88bc81d0}},	//   _dígo, _לאור, _वंशी, zděl,
   {{0x248d0063,0xa3dc816f,0x752500b9,0x6b8d011b}},	// [7b70] łem_, तीत_, _tahz, roag,
   {{0x92cd00ab,0xa8a7760d,0xaca3019d,0x30a717d6}},	//   রণে_, прек, _akụd, прев,
   {{0xb4d9085d,0xf990019f,0xaf2000ab,0xa3e89370}},	//   ारी_, ابق_, ধারণ_, _बिग_,
   {{0x60c502af,0x99800699,0x68e1811b,0xe7fe0327}},	//   schm, rviš_, zald, _उमरा_,
   {{0xe2ab003d,0x7bda81b9,0x63be050b,0x6b84811f}},	//   _دادن_, _awtu, _zupn, čigl,
   {{0x628001e2,0xdb1704c3,0x213838f8,0x51872109}},	//   _žmog, _muxí, _gnrh_, _хума,
   {{0xea008104,0x63a9d538,0x68e1c166,0xa3d78074}},	//   _đại_, tmen, vald, ़ीं_,
   {{0xb4d91008,0x63a9e772,0x5f948162,0x7f5b913b}},	//   ारु_, umen, _зист, _uluq,
   {{0x32091f52,0x68e1811e,0x3f8f811f,0x4ea784bd}},	//   ntay_, tald, mogu_, _хрва,
   {{0x57e99b6f,0xdb0b816a,0xd5b187c3,0xdb1c1277}},	//   одом_, _digá, _شفا_, sprø,
   {{0x68e1f9a5,0x63a9f9a6,0xdb170187,0x2455806b}},	//   rald, pmen, _auxí, _تناس,
   {{0x68e18dde,0x8367819f,0xdb170118,0xe73a2345}},	//   sald, _عدال, _buxí, цем_,
   {{0x68e1f9a7,0xb4d90074,0xb606811f,0x25bf99d2}},	//   pald, ारू_, _gušć, _juul_,
   {{0xdb0f01df,0x64a601e2,0x61fbf9a8,0x63be79a9}},	//   _dicí, дага, muul, _pupn,
   {{0x3f8f8006,0xdbf2128a,0xaad1885d,0x9c7c8af8}},	//   kogu_, přít, _सभाक, _večg,
   {{0xf0928051,0xe9da11b1,0xf77209a7,0xdb170118}},	//   _שנה_, жка_, _جات_, _fuxí,
   {{0x2fcd003a,0xe2970381,0xb5fb02ba,0x32090079}},	// [7b80] _čega_, дат_, nzál, gtay_,
   {{0x6e2479aa,0x6b5cf9ab,0x23810084,0x6606a5ac}},	//   _isib, _méga, rėja_, _äkki,
   {{0x7d1c5159,0x6b5c82be,0x9c7c8267,0xb8f60006}},	//   mers, _léga, _keče, _सभ_,
   {{0x320902a3,0x61fb9ec1,0x2bc48105,0x3d008beb}},	//   btay_, kuul, _लंबा, _राहे_,
   {{0x291a019d,0x9c7c8e63,0x7ae479ac,0x6b5c83e6}},	//   pepa_, _meče, mait, _néga,
   {{0xe81e8e18,0x7ae479ad,0x9c7c82ee,0xdfd200f7}},	//   _बनला_, lait, _leče, _ليس_,
   {{0xab94835f,0x3f8f80fe,0xc10e80ff,0x139495a6}},	//   никі, bogu_, _bỗng_, никю,
   {{0x7ae46711,0x18a35068,0x9c7c883d,0xb6068115}},	//   nait, _расм, _neče, _pušć,
   {{0x8bb380f7,0x25bf81b4,0x2127a33f,0x6e245dd6}},	//   خصوص, _guul_, _banh_, _nsib,
   {{0x7ae479ae,0x2127801c,0x224b816d,0x6b5c8036}},	//   hait, _canh_, äcka_, _déga,
   {{0x7ae479af,0x21278028,0xb2268125,0x9cd78039}},	//   kait, _danh_, fræð, _חובה_,
   {{0x7528ae1e,0x2ee0026c,0x32094336,0xf1bf1c32}},	//   _hadz, _ceif_, ytay_, _krát_,
   {{0x7ae479b0,0x99669fb5,0x7d1c79b1,0x09c88264}},	//   dait, _откл, fers, _শিকা,
   {{0xb4d941d0,0x88bc801b,0xdce380c3,0x6d58888b}},	//   ारे_, zděj, rinć, nkva,
   {{0x7ae456e6,0x6e2479b2,0x63a6026c,0xa3d902f1}},	//   fait, _esib, _bhkn, ठीं_,
   {{0xf1c300d4,0x799a8114,0x64430722,0x7ae4134c}},	//   _वंदन, lltw, _ànim, gait,
   {{0xf1bf0028,0x06ad00ab,0x753abfaf,0x9f46016b}},	// [7b90] _quá_, _ক্রি, _ontz, nulý_,
   {{0x752886e4,0x51f807ac,0x6f1d12a7,0x320902a3}},	//   _nadz, ьную_, lesc, rtay_,
   {{0x6ec3023c,0x9cd60039,0x32090079,0x7ae479b3}},	//   रखपु, _אותה_, stay_, bait,
   {{0x6f1d79b4,0x7c250efd,0x0fd5009a,0x753a811e}},	//   nesc, _ishr, डीगढ, _antz,
   {{0x8f9c0039,0x63ad1063,0x23810110,0xc10e827d}},	//   קידי, mman, lėjo_, _rỗng_,
   {{0x11da0051,0x64a5a845,0xdca5a4dd,0x237f005c}},	//   _מחשב, нала, нали, čuju_,
   {{0x68e52c10,0xaf078098,0x6837819d,0x21278129}},	//   mahd, _очак, _ọda, _ranh_,
   {{0x63ad44bd,0x753af9b5,0x61fb8eea,0xed5980d2}},	//   nman, _entz, tuul, _duža_,
   {{0x2d910e4d,0x63ad0dba,0x8ccab6a6,0x75288748}},	//   koze_, iman, _स्को, _fadz,
   {{0xb5fb03b0,0x29010461,0xb4d979b6,0x9c7cc96c}},	//   rzál, ngha_, ारो_, _seče,
   {{0x61fbeabc,0x63ad79b7,0x06ad00c8,0x6f1d0144}},	//   suul, kman, _ক্লি, fesc,
   {{0x6d890038,0x6f1d0e83,0x6729cbee,0x238101e2}},	//   hľad, gesc, _jaej, dėjo_,
   {{0x80de80c8,0x7ae40a7f,0x7d1c35df,0x3f9e0029}},	//   _মার্, vait, ters, ētu_,
   {{0x61e9f9b8,0x6b9bce13,0x7bc1d0a4,0x7ae479b9}},	//   msel, llug, _kulu, wait,
   {{0x7ae479ad,0x61e9b1d7,0x7bc1859e,0xe946803d}},	//   tait, lsel, _julu, _سروی,
   {{0x7bc1f9ba,0x63ad79bb,0x28d200d4,0xdc0380e1}},	//   _mulu, gman, दुनि, jčít,
   {{0x61e9f9bc,0x7ae479bd,0x7bc18886,0xf2d2812a}},	// [7ba0] nsel, rait, _lulu, טען_,
   {{0x7ae479be,0x63ad7241,0x7bc18009,0x61e9abcc}},	//   sait, aman, _oulu, isel,
   {{0xdfcf0dd0,0x5ed180c8,0x7bc1f9bf,0x7528f9c0}},	//   ميل_, _হয়ে, _nulu, _radz,
   {{0xeaa78307,0xaa460ca0,0x61e9f9c1,0x7528b5c6}},	//   _مع_, _земл, ksel, _sadz,
   {{0xee3a81e5,0x4425f9c2,0x61e9ab36,0x75288ec3}},	//   янд_, _asl_, jsel, _padz,
   {{0x7bc1f9c3,0x61e981eb,0x6b8282d6,0xb60602d4}},	//   _bulu, dsel, _sjog, mešč,
   {{0xa0a328fb,0x7bc18079,0x6b9bd6ef,0x6d58f88a}},	//   _бард, _culu, flug, rkva,
   {{0xa3e211be,0x7bc1cc3f,0x67c8800d,0x6d58f9c4}},	//   नीय_, _dulu, _něja, skva,
   {{0x36679634,0x61e9b1d7,0x6f1d5e93,0xd13080f7}},	//   _зато_, gsel, vesc, لمة_,
   {{0x63ad79c5,0x65a001ec,0x7bc1838a,0x04188264}},	//   zman, wöhn, _fulu, থিবী_,
   {{0x741384c1,0x63ad79c6,0xa3dc8816,0x61e9f9c7}},	//   _مولا, yman, तीश_, asel,
   {{0xb5fb0019,0xb4d9016f,0x6f02f9c8,0x63630074}},	//   szám, ार्_, ngoc, _kõne,
   {{0x28d183b7,0x6f1d0328,0xf710001c,0x2d91136f}},	//   _द्वि, resc, _tầng_, toze_,
   {{0xb5240b71,0x6b5104b8,0x6f1d002e,0x201807de}},	//   льск, _någr, sesc, _opri_,
   {{0x63ad07e2,0x6f1d180b,0x394e8106,0x7f98a6f6}},	//   tman, pesc, _iofs_, líqu,
   {{0x6b55e608,0x23810110,0xdb17002a,0x409b81c6}},	//   _pági, rėjo_, _buxá, _מבוס,
   {{0x2d9106c0,0x2018047f,0x60db00ce,0xb5fb0061}},	// [7bb0] poze_, _apri_, _đumb, zzáj,
   {{0xfbd00065,0x9998002e,0xbebb0123,0x00000000}},	//   شتہ_, екут_, geëe, --,
   {{0x63ad79c9,0x2d540074,0x6b5c8036,0x9f460144}},	//   pman, _päev_, _négo, culó_,
   {{0x291e8135,0x7ff41a05,0x572780f7,0x61e9b06b}},	//   heta_, اسلا, عراق, ysel,
   {{0x291ef9ca,0x7bc1b138,0x5e5880e8,0xdb1a82df}},	//   keta_, _sulu, ниця_, _cutí,
   {{0x4a5a004c,0x291e9351,0x2b490024,0x672980b9}},	//   _חדשו, jeta_, ljac_, _waej,
   {{0xa3dc853e,0xdb1e00e7,0xf1bf7062,0x9c7c826c}},	//   तील_, _supé, _trás_, _rečc,
   {{0x61e9bd42,0x2b490052,0x7f988333,0x7ae28362}},	//   tsel, njac_, fíqu, _ceot,
   {{0xdcbb8364,0x291ef9cb,0xdb0600f1,0x6b9bf9cc}},	//   _еще_, feta_, _shkë, rlug,
   {{0x7bc1f9cd,0xdb1a841c,0x04678087,0x69c2a86c}},	//   _tulu, _cutâ, _птем, _duoe,
   {{0x6b9bf9ce,0x8cca8305,0xf772006b,0x44258087}},	//   plug, _स्टो, لاح_, _usl_,
   {{0x61e994c7,0x78ba0177,0x2ac78032,0x69c00037}},	//   psel, _útve, _díbó_, _èmeg,
   {{0x291eaade,0xc7b280be,0xd7f88087,0xdb1c01ec}},	//   beta_, יבט_, ară_, rprü,
   {{0x5e568158,0x291e9520,0xb6060353,0xdb1c01ec}},	//   דישע_, ceta_, vešč, sprü,
   {{0xf990990c,0xeb9a3847,0x69cb201d,0x9c7c8bcf}},	//   _ابن_, див_, ígen, _keča,
   {{0x68e3f3ce,0x332dc189,0x7ae2802a,0x9c7c81f4}},	//   _hend, ndex_, _xeot, _ječa,
   {{0x68e3f9cf,0xeb970dc8,0x98bc81d0,0x6b51183d}},	// [7bc0] _kend, тит_, _nově_, _pågr,
   {{0x20561dbc,0x3d1101fe,0x68e3b0aa,0xa3c1a23e}},	//   ктер, द्दे_, _jend, ंदा_,
   {{0xd12f187e,0xdb1a8118,0x38608326,0xe9df026b}},	//   تمل_, _sutí, _ƙiri_, _ewú_,
   {{0x291ef9d0,0xed5988ae,0x9c7c826f,0x20070722}},	//   zeta_, _bužo_, _neča, ània_,
   {{0x291e8ce9,0x33200722,0x332d8079,0x660f8106}},	//   yeta_, meix_, ddex_, _äckl,
   {{0x68e3f833,0xcbcd80ab,0x7ae28074,0x3320023e}},	//   _nend, _রয়েছ, _seot, leix_,
   {{0x291e803b,0x8af0011c,0x1fb681e5,0xd7068c9b}},	//   veta_, hkəm, _асар, _изви,
   {{0x040d8028,0x291e882e,0x3320009f,0x68e3f9d1}},	//   _hướn, weta_, neix_, _aend,
   {{0x291e82a5,0x9c7c8eef,0x1d268fe7,0xa3e2064a}},	//   teta_, _deča, _имам, नीत_,
   {{0x68e3b745,0xd5ae8117,0x29079b1d,0xd7f8802e}},	//   _cend, _بہت_, _ccna_, tră_,
   {{0x68e38b6e,0x39570051,0x9f5f0009,0x93469229}},	//   _dend, דשים_, yttä_, _инже,
   {{0x68e38cfa,0x320d81b4,0x28a73410,0xa5f9062c}},	//   _eend, btey_, केटि, нему_,
   {{0x64588110,0x3320009f,0x3a2680b9,0xf1bf026b}},	//   lyvi, deix_, _usop_, _asán_,
   {{0x68e38430,0xd12f80f7,0xa2d55d93,0x6fcabe85}},	//   _gend, _ومن_, युन्, _संपू,
   {{0x68e882a3,0x0713acfc,0x30a38081,0xc04f80e8}},	//   madd, ण्डव_, _кръв, _ті_,
   {{0x3320009f,0x68e8f9d2,0x68e3f9d3,0x490e8cf0}},	//   geix_, ladd, _zend, त्रो_,
   {{0x6b5c82be,0x68e3b29f,0x6e3650dc,0x4423022c}},	// [7bd0] _régl, _yend, _gryb, swj_,
   {{0x6d5c148c,0x68e891c9,0x7bc10061,0x645894ef}},	//   ckra, nadd, ílus, kyvi,
   {{0x2d830024,0x1aef00ab,0xc7f50eef,0xe8d781c6}},	//   mnje_, ঙ্গে_, узећ, דובר_,
   {{0x29074af7,0xfaff0168,0xf40880ab,0x68e8f9d4}},	//   żna_, _emër_, লবার_, hadd,
   {{0xd246987e,0xb90900c8,0x61ff0201,0x68e8f9d5}},	//   _ان_, _যা_, quql, kadd,
   {{0x7bc500f6,0xac0992b2,0x672d0009,0x6b580531}},	//   _kuhu, енка_, _laaj, _rígi,
   {{0xeb998b9c,0x68e3a88b,0x4c158013,0x7bc540f5}},	//   ник_, _rend, ابتس, _juhu,
   {{0xbebb020f,0x320d8358,0x7bc51ec7,0x15f592c7}},	//   ndës, ttey_, _muhu, ुंदर_,
   {{0x68e3a84c,0x63bd5896,0x61ed79d6,0x7bc501da}},	//   _pend, _misn, nsal, _luhu,
   {{0x68e3820f,0x2d830052,0x63bd192c,0x68e88365}},	//   _qend, jnje_, _lisn, gadd,
   {{0x68e38e79,0x20010867,0xdee60aac,0x9c7c8132}},	//   _vend, nuhi_, лони, _teča,
   {{0x68e3d33a,0x21213778,0xfc46928a,0x3ce586b1}},	//   _wend, hehh_, žích_, _helv_,
   {{0x68e8eabc,0xfa3482e3,0x7ae98f3e,0x9f60008b}},	//   badd, _پرند, maet, _þrír_,
   {{0x7ae9831d,0x68e88079,0x68e3f9d7,0x7bc579d8}},	//   laet, cadd, _uend, _buhu,
   {{0x6d5c79d9,0x63bd1ade,0x332007e2,0x49b8880b}},	//   rkra, _bisn, teix_, _شاهد_,
   {{0x6e29a588,0x7ae98355,0x629d0101,0x7bc579da}},	//   _oseb, naet, _byso, _duhu,
   {{0x61ed043b,0x3320009f,0xa3ab8bb8,0xd38702c7}},	// [7be0] gsal, reix_, _गठन_, уйте_,
   {{0x6f099cd4,0x61fb80ee,0x29c980ff,0xdb1988f9}},	//   _acec, irul, _múa_, _diwé,
   {{0x5ecd80ab,0x61ed79db,0x7bc502a0,0x2d9a0870}},	//   ারনে, asal, _guhu, _ikpe_,
   {{0x61fb80ee,0x672d0079,0x6db980e1,0x238580eb}},	//   krul, _xaaj, _dňam, dējo_,
   {{0xe505823c,0x7ae98355,0x80e300c8,0x68e88ef2}},	//   _राशि_, daet, _পার্, yadd,
   {{0x200151c8,0xad9b79dc,0x16c10996,0x3a3ac56a}},	//   buhi_, ltúr, _एल्ब, _čpp_,
   {{0xbebb020f,0x50b511d2,0x98a300eb,0xa92801a9}},	//   ndër, _всту, _tajā_, režģ,
   {{0x29c9f9dd,0x69c67102,0xf3638110,0x2d83007d}},	//   _búa_, _kuke, йтын, znje_,
   {{0xee3a9ef7,0xa6869b4f,0x68e8f9de,0x7f75813a}},	//   _яна_, _слад, tadd, _турц,
   {{0xd13080d5,0xb426826a,0x7764002a,0x301482fb}},	//   آمد_, _معصو, _alix, адор,
   {{0x68e8f9df,0x69c62de5,0xad9b0e14,0xddd0192c}},	//   radd, _luke, ktúr, _češl,
   {{0xa3c1af52,0x70e101ce,0x68e89a2b,0x7bc579e0}},	//   ंदर_, _फ़्ल, sadd, _ruhu,
   {{0x62800a8e,0x9f5f026f,0x69c679e1,0x9b9380f7}},	//   _žmon, nuté_, _nuke, _النت,
   {{0x7bc5043d,0x776404c3,0xa903009a,0x672d68e7}},	//   _puhu, _elix, _लाइफ_, _waaj,
   {{0x69c6011e,0x2d832a06,0x7ae640d0,0x776454ec}},	//   _auke, rnje_, _bekt, _flix,
   {{0x61ed6f26,0x2d8300d2,0x69c61f73,0x256600e7}},	//   tsal, snje_, _buke, _rôle_,
   {{0x49752187,0x6722b009,0x63bd1da3,0x2d83115c}},	// [7bf0] алас, deoj, _visn, pnje_,
   {{0x629d0a56,0x61ed1600,0x69c65dc7,0xeb21d8a3}},	//   _vyso, rsal, _duke, _मस्त_,
   {{0x629d0063,0x63bd6783,0xa0a701cf,0x30a73799}},	//   _wyso, _tisn, ушал, урав,
   {{0x3ce58a38,0x61ed3e43,0x9c7c99ba,0x6b55f9e2}},	//   _selv_, psal, _pečn, _lágr,
   {{0x3d00b497,0x1d09bba1,0x2001059e,0x2d768035}},	//   _राखे_, вели_, suhi_, ałem_,
   {{0x6e298db7,0x29c9862f,0xf1a90592,0x9c7cd89a}},	//   _vseb, _rúa_, _कठिन, _večn,
   {{0x29c9cd67,0x67d40009,0xfd6201bc,0xe05700d5}},	//   _súa_, _госу, _agwọ, _حیات_,
   {{0x9c7c876c,0xe2998a8e,0x2369321c,0x78ba4ded}},	//   _tečn, кай_, nhaj_, _útva,
   {{0xe6678ef5,0x7ae98114,0xa3e58054,0x6e298234}},	//   _ство, raet, _बौर_, _useb,
   {{0x7ae980c6,0xdb0a00e1,0x29058b80,0x50b5869b}},	//   saet, ľnéh, ugla_, исну,
   {{0xa0a5a6c8,0x68e71ac7,0x29058b80,0x670a05fc}},	//   ранд, _mejd, rgla_, _वादक_,
   {{0x29c987f4,0x7523cd8a,0x68e750e7,0xe8168074}},	//   _túa_, lenz, _lejd, _तहरा_,
   {{0xd945b6b8,0xfd4e846d,0x61e2c23b,0x91e5a041}},	//   _вели, _afiṣ, _gwol, _толе,
   {{0x68e703fb,0x7523b263,0x3ea90886,0x69c60a03}},	//   _nejd, nenz, _dzat_, _ruke,
   {{0xad9b007b,0x69c60662,0x63630074,0x3ea901a1}},	//   ttúr, _suke, _sõna, _ezat_,
   {{0x7523979f,0xdb02801c,0xe363046e,0x38ac10ab}},	//   henz, _khoá, окси, _lórí_,

   {{0x6d41f9e3,0x6b84788e,0xdb1d01b3,0x7ae679e4}},	// [7c00] _onla, rnig, _misè, _vekt,
   {{0x2fc79635,0xb17b04b8,0x7ae603f8,0x69c601f4}},	//   _kung_, _svår, _wekt, _vuke,
   {{0x2d9847ad,0x7523ac2f,0x03a626c8,0xb4fb0051}},	//   more_, denz, _вино, _בפיי,
   {{0x6d41aa59,0x2fc78077,0x69c60009,0x66028110}},	//   _anla, _mung_, _tuke, tuok,
   {{0x645c45ba,0x443a10dc,0xdce182d0,0x38ac0032}},	//   lyri, _hrp_, _aklı, _bórí_,
   {{0x7523b190,0x660287ac,0x443a682c,0x291802c4}},	//   genz, ruok, _krp_, _ubra_,
   {{0x2fc7809c,0xf8aa00dc,0xa6ca8568,0x7b668113}},	//   _nung_, _करिय, _алба_, итие,
   {{0xe3af85ff,0x9f5f0036,0xaac60035,0x6d41b64d}},	//   وري_, puté_, वशिक, _enla,
   {{0x752391e8,0x2d9879e5,0x25be8699,0x3f86816b}},	//   benz, kore_, _titl_, mnou_,
   {{0xf8aa2f52,0x2fc78681,0x6b5c8019,0x3f8685b9}},	//   _कराय, _bung_, _mégi, lnou_,
   {{0x2fc78028,0x2d982937,0x6b5ca8d6,0x01370039}},	//   _cung_, dore_, _légi, ברית_,
   {{0x2fc78028,0x3f868eb2,0x236903ed,0xdcf88196}},	//   _dung_, nnou_, xhaj_, tovė,
   {{0x7bc8f9e6,0x2d980051,0x2fc7808e,0x7c2200d2}},	//   _hudu, fore_, _eung_, _ćora,
   {{0x2d980578,0x443a79e7,0x236681c0,0x645c3e0c}},	//   gore_, _brp_, _hloj_, fyri,
   {{0x7bc889e1,0xdcfa80eb,0xe516123a,0x2fc789c4}},	//   _judu, _aktī, द्धि_, _gung_,
   {{0x7523ec8e,0x443a0748,0x7bc88b8f,0x88bb81c6}},	//   zenz, _drp_, _mudu, _במוז,
   {{0x3f868400,0x98a3009a,0x78eb0790,0x75239ba4}},	// [7c10] dnou_, _mają_, вьев_, yenz,
   {{0xb4e58076,0x2d9879e8,0x6e2d2cde,0x2fc782b8}},	//   _भजे_, core_, _isab, _yung_,
   {{0x752392bb,0xd8791e7b,0x2fc70028,0x442716ce}},	//   venz, دمات_, êng_, _èn_,
   {{0xf7708872,0x3f990025,0x7523f9e9,0x7bd7011b}},	//   وان_, nosu_, wenz, _itxu,
   {{0x7523a414,0x7aed33fd,0x442cde35,0xd33603c8}},	//   tenz, maat, _asd_, _פרשה_,
   {{0x7bc8812b,0x7aed4228,0x200e0722,0x645a01ec}},	//   _budu, laat, àfic_, ätig,
   {{0x7523f9ea,0x7bc88079,0xf1b20039,0x3f86816b}},	//   renz, _cudu, _מסך_, bnou_,
   {{0x7aed5880,0x5f949dba,0x7bc895bd,0x7523f3d3}},	//   naat, _дист, _dudu, senz,
   {{0x7523f9eb,0x6e2d0555,0x7c3af9ec,0x5ecd8264}},	//   penz, _nsab, _ertr, ারদে,
   {{0x6d41af15,0x0fd9a252,0x2fc79a7e,0x6e3baaaa}},	//   _unla, льмы_, _pung_, _irub,
   {{0x7bc8e463,0x6e3b826f,0x6e2d2fba,0x315800be}},	//   _gudu, _hrub, _asab, ייזן_,
   {{0x32120364,0xdb02801c,0x3204a1f3,0x2fc780ff}},	//   ytyy_, _thoá, bumy_, _vung_,
   {{0x2d9879ed,0x98a587d9,0x657c1b0f,0x443a10d1}},	//   tore_, rklı_, tirh, _srp_,
   {{0xceb28051,0x645c79ee,0x6b5cf9ef,0x61d68051}},	//   פים_, tyri, _régi, _הוסף_,
   {{0x2d9879f0,0x2d879a2f,0xa3e20006,0x645c8074}},	//   rore_, inne_, नीं_, _ürit,
   {{0x2d9879f1,0x2005f9f2,0x256b8bc5,0x7aed25a5}},	//   sore_, muli_, _følg_, gaat,
   {{0x3f86826f,0xa1c311d0,0x2005b2f5,0x7f440037}},	// [7c20] vnou_, збуд, luli_, _iniq,
   {{0x9c7c82ee,0x66063cfd,0x6f1bf9f3,0x41df864a}},	//   _dečj, mukk, _abuc, पीएस,
   {{0x20058025,0xb17a893f,0x66064695,0x7aed02a3}},	//   nuli_, נטער, lukk, baat,
   {{0x7aed79f4,0x442c82ee,0x7bc8a0aa,0x2d87f9f5}},	//   caat, _rsd_, _rudu, enne_,
   {{0xf2d3093f,0x63a41da3,0xb1480077,0x7bc8c4f8}},	//   _מער_, mlin, _پیام_, _sudu,
   {{0x442cf9f6,0x78ba0019,0xf9879a05,0xbbe900d7}},	//   _psd_, _útvo, _رب_, _حریم_,
   {{0x3d0981fe,0x8884026a,0x6e3baaaa,0x63a430be}},	//   _सारे_, _بیان, _erub, olin,
   {{0xd3268cde,0x660624bb,0xbf16803d,0x51f88009}},	//   ськи, kukk, _دورب, анию_,
   {{0x6e3bf9f7,0x66062e55,0x7bc8a93f,0x637e8110}},	//   _grub, jukk, _wudu, gūna,
   {{0xb5fb0117,0x7bc8b734,0x63a45820,0xa3a88127}},	//   zzás, _tudu, hlin, _खीर_,
   {{0x63a40e51,0x319b00be,0x20059598,0x63b6007b}},	//   klin, רבינ, guli_, kmyn,
   {{0xb7671d38,0xd0418085,0x66066a3f,0xad9b01d6}},	//   стой, nclə, fukk, krúc,
   {{0x63a40c63,0x7aed2c51,0x7a368875,0x88c000ab}},	//   dlin, vaat, _دعائ, েরিক,
   {{0x200582ec,0x7aed138a,0x9c7c8b67,0xb90c019d}},	//   buli_, waat, _rečj, rahụ_,
   {{0x2005cbe0,0xd0b28085,0x317b81c6,0xa3dc8072}},	//   culi_, yğəm, _תרומ, तीच_,
   {{0x63a479f8,0xe3b0190c,0x63b6007b,0x317ef9f9}},	//   glin, فرق_, gmyn, litz_,
   {{0x6e2d2cde,0x3d098e5b,0x9955110b,0x9c7c812b}},	// [7c30] _usab, _साले_, окац, _bečk,
   {{0x9c7c8353,0x7aed04a2,0xf77f2888,0xed59992c}},	//   _večj, saat, liç_, _tuži_,
   {{0x9c7c8d2f,0x63a44da0,0x6d450367,0x7aed50a4}},	//   _dečk, blin, _inha, paat,
   {{0x2d8c8d2f,0xceeb8077,0x7aed01b4,0x657acc21}},	//   _ajde_, اران_, qaat, _amth,
   {{0x2005f9fa,0xf8ae053d,0x44211d26,0x799ae07c}},	//   zuli_, _یکم_, _hph_, kotw,
   {{0x9989009a,0x637e8084,0x81d40b69,0x23d5bd2f}},	//   stał_, vūna, _хорх, оцир,
   {{0x4c6980e5,0x7afd82b7,0x6b5c80e7,0x442100b9}},	//   рийн_, ósto, _légu, _jph_,
   {{0x6fcfa774,0xe1f9a457,0x6f1b9d8b,0x657a8234}},	//   _संबं, аги_, _ubuc, _emth,
   {{0x6e3b82a0,0xc8da816f,0x291cca45,0x7769802a}},	//   _urub, _म्हट, _bbva_, _ilex,
   {{0x3eadf9fb,0x2005cc9b,0x69dbcb69,0x7f56011c}},	//   _izet_, tuli_, rpue, _soyq,
   {{0x69db80c8,0xcea90451,0xdb0400f7,0xfd1080f7}},	//   spue, _סי_, rmiú, _سجل_,
   {{0x60dc884a,0xae0d81a2,0x6d452c22,0x63a479fc}},	//   ırma, _समान_, _anha, xlin,
   {{0x3f9f80f6,0x63a47817,0xe8ee951b,0xd1098077}},	//   _mkuu_, vlin, _ол_, _نقشه_,
   {{0x660606d9,0x6b898e8b,0xafe59cf2,0x63a43d3e}},	//   rukk, lneg, _докл, wlin,
   {{0x66060d7a,0x68e19fe9,0x63a449f6,0x6b5c846d}},	//   sukk, mbld, tlin, _eégu,
   {{0x44210a56,0xe80d035a,0x69cbacdb,0xf8b28039}},	//   _dph_, ांना_, _kuge, _קשה_,
   {{0x7aeb8065,0x7bdc1614,0x69cbf9fd,0xfaa317cb}},	// [7c40] _megt, spru, _juge, дато,
   {{0x69cb9f73,0x7aeb9529,0x3f9f808e,0xdb0b8722}},	//   _muge, _legt, _akuu_, _aigü,
   {{0x69cbf9fe,0x3ead81ac,0x1c1e0074,0x9c7c807a}},	//   _luge, _azet_, _पहिल_, _večk,
   {{0xee3adec9,0xe29a23e1,0x69c39140,0xed598669}},	//   ине_, _вам_, _line, _mužu_,
   {{0x6b898e8b,0xe297102a,0x69c3811b,0x7c218176}},	//   dneg, _маю_, _oine, _aplr,
   {{0xafe614d6,0x7bc2a651,0x77699c6a,0x463b00be}},	//   _могл, _siou, _elex, יענע,
   {{0x317e9ef9,0x69cbc948,0xdcf50087,0x77699f0f}},	//   vitz_, _auge, liză, _flex,
   {{0x395802be,0x69cbf9ff,0x69c3a5ac,0x6b89e54f}},	//   _hors_, _buge, _aine, gneg,
   {{0x69c3f6d3,0x914aa60a,0xf77f7a00,0x39587a01}},	//   _bine, ачна_, viç_, _kors_,
   {{0x55038153,0x6b5cbb09,0x9c7c8bda,0x657a805d}},	//   _опуб, _régu, _leči, _umth,
   {{0x69c3e478,0x6b899840,0xcb6ab0bb,0x6b5c887a}},	//   _dine, bneg, _каже_, _ségu,
   {{0x69c38943,0x2d9c803b,0x395802be,0x6b9b85db}},	//   _eine, love_, _lors_, coug,
   {{0x443ec775,0x3ead013c,0x69cbc8dc,0x224b8106}},	//   _hrt_, ået_, _guge, äckt_,
   {{0x7d1b005c,0x395801e2,0x4421008e,0x276921d7}},	//   đuso, _nors_, _pph_, _گشتی_,
   {{0xd37b045d,0x69cb82af,0x9c7c80d2,0xdea40326}},	//   ача_, _zuge, _beči, _maiƙ,
   {{0x56950364,0x69c3cb2c,0x443efa02,0x3a2202f7}},	//   _найт, _zine, _mrt_, _bpkp_,
   {{0x9c7c82ee,0x60f901bb,0x39587a03,0x4fb40a47}},	// [7c50] _deči, йная_, _bors_, _تصور,
   {{0x443efa04,0xad9b0125,0x7bda81b9,0xc4c48065}},	//   _ort_, brúa, _ottu, _لے_,
   {{0x2d9ca9b4,0x4421008e,0x39587a05,0xced88133}},	//   dove_, _uph_, _dors_, _ịzụr,
   {{0xe80c0665,0x6b5c8061,0x6602edcf,0xf1bf1a64}},	//   _हमरा_, _mégs, frok, _spád_,
   {{0x6b898db7,0x7bdafa06,0x7aeb879f,0x662780f7}},	//   vneg, _attu, _regt, تراك,
   {{0xa3e2009a,0x69cb80b4,0x9c7c8301,0x6b898035}},	//   नीक_, _ruge, _zeči, wneg,
   {{0x6b89fa07,0x69c3e2c9,0xdb1d0118,0x81cd00ab}},	//   tneg, _rine, _lisí, _রবি_,
   {{0x69c3e619,0x3f9fad15,0x66029a69,0x69cbbd7d}},	//   _sine, _ukuu_, brok, _puge,
   {{0x8cd883bb,0x34a803bb,0x6b899d10,0x443e86db}},	//   नुहो, _गर्द, rneg, _ert_,
   {{0x69c38a2a,0x8af00085,0x290c8106,0x6b89be4e}},	//   _qine, nkər, ggda_, sneg,
   {{0xe73a00b3,0xb4e7dd93,0xc7a60dc7,0x225f87d5}},	//   бен_, परी_, зинк, syuk_,
   {{0x69cbfa08,0x88d100ab,0x224b8338,0x52758087}},	//   _tuge, িরিক, äcks_, _нулу,
   {{0x69c3aeb0,0x1dcb8074,0x9c7cfa09,0xe28ea7f4}},	//   _tine, ादित, _reči, _ча_,
   {{0xe80c023c,0x2eeda51d,0xd25684de,0xad9b008b}},	//   _हमला_, _leef_, _משנה_, trúa,
   {{0x98a28d5f,0x80aa009a,0x70aa0006,0x2b590722}},	//   _пише, _करें, _करेल, _bosc_,
   {{0x2d9c8024,0x39587a0a,0x1dcb80d4,0x3a2200ee}},	//   zove_, _sors_, ादात, _ppkp_,
   {{0x3f827a0b,0xe8fa1d38,0x9c7c8353,0x020604d9}},	// [7c60] miku_, йла_, _veči, язан,
   {{0xdce38110,0xe1f705e9,0x59ce864a,0x9f5f04e8}},	//   minė, ягу_, _हंसर, vrté_,
   {{0x2d9c85f5,0xdce38110,0xb4d82418,0x64a61246}},	//   vove_, linė, ाडी_, _хана,
   {{0x6602d4e9,0xe5c684ae,0x79818bb1,0xed5881d6}},	//   trok, пско, hilw, _soľ_,
   {{0x39583842,0xdce38110,0xe5348009,0x6736008e}},	//   _tors_, ninė, дель, _mayj,
   {{0x6602d689,0x7bc601e0,0x09da80ab,0x237f1f1c}},	//   rrok, _hiku, _দিলা, ďuje_,
   {{0xdee69baa,0x66e6ae39,0x7bc67a0c,0x3f824217}},	//   _нови, _нова, _kiku, kiku_,
   {{0x6602fa0d,0x07a38638,0xe76a9381,0x443ef400}},	//   prok, _засн, _احسن_, _vrt_,
   {{0xa2a20592,0x0e6681e2,0xa6aa990c,0x7ae47a0e}},	//   _कुम्, _экан, _طارق_, ibit,
   {{0x7bc67a0f,0x4973c97a,0xdce38084,0x443eb8ad}},	//   _liku, ельс, dinė, _trt_,
   {{0x3f822371,0xa3ac0327,0x9ad301bc,0x6b5c8036}},	//   fiku_, गता_, _kịta, _dégr,
   {{0x290283bf,0x6d5afa10,0xdb0400e7,0x69da001b}},	//   şka_, _hota, blié, _čten,
   {{0x63a2fa11,0x61469faa,0xd05c0201,0x8f9b83c8}},	//   _ikon, _неда, _verə, מיטי,
   {{0x6d5a8364,0x7bc60009,0xe5c40198,0xdb1d2a8d}},	//   _jota, _aiku, ессо, _visí,
   {{0x6d5a86c1,0xaeec00c8,0x7bc6020c,0x7f592373}},	//   _mota, _কারণ_, _biku, _макс_,
   {{0x637104b8,0xdb1d003e,0x26c91f79,0x7bc60573}},	//   _mång, _tisí, _ugao_, _ciku,
   {{0x2aab1b4f,0x637104b8,0x6d489c51,0x63a2822e}},	// [7c70] ство_, _lång, _onda, _mkon,
   {{0x6d5af099,0xd1388110,0x636302f1,0x6f1d14cf}},	//   _nota, ndą_, _mõni, lfsc,
   {{0x2d834aff,0x7bc67a12,0x7bc300e5,0xb9c401a8}},	//   mije_, _fiku, _ènuo, رقمي,
   {{0x6d48fa13,0x7bc60959,0xd36680d7,0x6d4f0699}},	//   _anda, _giku, _شه_, škač,
   {{0x6d5ac73f,0x44330683,0x6b8d0362,0x80c58e1b}},	//   _bota, _hsx_, mnag, লুপ্,
   {{0x64a5bd85,0x63a2a705,0x6d5aa2fb,0xdca58256}},	//   мала, _akon, _cota, мали,
   {{0x6d5afa14,0x26d287d9,0x7c22017f,0x764085ee}},	//   _dota, ıyor_, _ćork, _ermy,
   {{0x6b8d7a15,0xc24584dd,0x2d837a16,0xe9d992b2}},	//   nnag, дник, hije_, оки_,
   {{0x2d8300b4,0x69cf02ce,0x69c73356,0x6b8d4b4f}},	//   kije_, _juce, _kije, inag,
   {{0x63710370,0x3f8202f7,0x2d830c97,0xdce38084}},	//   _hånd, wiku_, jije_, vinė,
   {{0x2d8302a5,0x637104b8,0x69c702fd,0x69cf0baf}},	//   dije_, _gång, _mije, _luce,
   {{0x69c7030b,0xdce381e2,0xdb0f0118,0x69cf0118}},	//   _lije, tinė, _micó, _ouce,
   {{0x27e0803a,0x63710448,0x69dd10af,0x7bc67640}},	//   _čine_, _månd, _ntse, _riku,
   {{0x2d837a17,0x69c71ef3,0x7bc668e0,0xdce38110}},	//   gije_, _nije, _siku, rinė,
   {{0x3f8207d8,0xdca312b2,0x64a30eab,0x69dd2fa3}},	//   piku_, вари, вара, _atse,
   {{0x63a9ba2a,0x69cf29f2,0x6b8d7a18,0x672b80f1}},	//   nlen, _buce, gnag, jegj,
   {{0x2d834212,0x69c71351,0x7ae43ccc,0x7bc67a19}},	// [7c80] bije_, _bije, rbit, _viku,
   {{0x69c7030b,0x63a9d820,0x69cf7a1a,0x657e005d}},	//   _cije, hlen, _duce, _umph,
   {{0x69c77a1b,0xb8f608fd,0x63a9fa1c,0x443c0019}},	//   _dije, _हल_, klen, _év_,
   {{0xdb1d03a7,0xadeb03b6,0x6d5afa1d,0x69cf00e5}},	//   _visã, जीवन_, _sota, _fuce,
   {{0x2bd210be,0xf1af0701,0x64419ca2,0x4425fa1e}},	//   _दूता, _जीवन, _arli, _apl_,
   {{0x63a2fa1f,0x6b843e84,0x7e62810c,0x64418115}},	//   _skon, liig, ryop, _brli,
   {{0xa2a21094,0x63a9ac37,0x20058267,0x7e6282d6}},	//   _कुत्, flen, jrli_, syop,
   {{0xdb0d0003,0x5a3497f9,0x63bbfa20,0x6d5a0074}},	//   rmaç, енит, gmun, ötaj,
   {{0x64419d94,0x4425b1d4,0x200580e5,0x6eaa0072}},	//   _erli, _epl_, erli_, _घरगु,
   {{0x6d48fa21,0x7bde0024,0x213800dd,0x58868196}},	//   _unda, _otpu, _jarh_, дыма,
   {{0x2d83003b,0x63a9fa22,0x9c7cfa23,0x776d002a}},	//   vije_, blen, _peču, _plax,
   {{0x6d0e8076,0x63a2e57b,0x224982a5,0xd7cf8aad}},	//   _साँग_, _ukon, _šake_, _संरच,
   {{0x2d8300ce,0x9f6580e7,0x200581e8,0x7aef05d8}},	//   tije_, étés_, arli_, _rect,
   {{0x63710a38,0x7aef5c92,0xe894917c,0x60178870}},	//   _måne, _sect, _паль, ụmah,
   {{0x69c7030b,0xd7ef8088,0xe5718158,0x63710370}},	//   _rije, _шу_, אַן_, _låne,
   {{0x2d8302a5,0x69c7111b,0x200cfa24,0x69cf36b5}},	//   sije_, _sije, mudi_, _puce,
   {{0x9ccb0087,0xe1f00064,0x7afdab49,0x2eba816f}},	// [7c90] _мына_, لسل_, ósti, ेशोत,
   {{0x9f45877f,0x63bbfa25,0x69cf0144,0x63a9fa26}},	//   _ìlú_, zmun, _vuce, zlen,
   {{0x69c7030b,0x200c803b,0xb4eb0054,0x2fc901c5}},	//   _vije, nudi_, मरी_, _kiag_,
   {{0xf8df085d,0x20df0bb8,0x28df0aed,0xb0df06bf}},	//   _प्रय, _प्रध, _प्रि, _प्रग,
   {{0x69c7030b,0x200cce28,0xf773804e,0x69dd0b64}},	//   _tije, hudi_, _یار_, _utse,
   {{0xee389439,0x660b837a,0x2fc97a27,0x212c8168}},	//   ьні_, rugk, _liag_, jedh_,
   {{0x63a9fa28,0x43698607,0x03a5d190,0x2d8100b9}},	//   tlen, зайн_, нико, _mmhe_,
   {{0x644180d2,0x2fc90069,0xdb1e0118,0x42559c9b}},	//   _vrli, _niag_, _supú, етот,
   {{0x63a9fa29,0xcad281bc,0xa3b60035,0x0e8e882e}},	//   rlen, _pịrị, _चीफ_, sịrị_,
   {{0xa3b605fb,0x7d798eca,0x63bbfa2a,0xa3cf0072}},	//   _चीन_, _عمار_, smun, शदा_,
   {{0x3ea914ec,0xe73a31ad,0x63bbfa2b,0x2fc902d5}},	//   _ayat_, пен_, pmun, _biag_,
   {{0xe73a35aa,0x660004e8,0xd6d201a8,0x9c7c8af8}},	//   чем_, ámko, طقس_, _večt,
   {{0x2b1486b7,0x2fc97a2c,0x15ba0009,0xd7f88087}},	//   _धातु_, _diag_, зывы_, asă_,
   {{0x636302f1,0x200582d4,0x332d857b,0xfe7f0580}},	//   _mõnu, prli_, leex_, taïr_,
   {{0x6ea00eed,0xc4d281c6,0x3f6a0eef,0xa5bb066f}},	//   _गुरु, רגל_, _нико_, twór,
   {{0x92c380c8,0xe9da09c7,0x636a016b,0x645c87f1}},	//   ্রী_, зка_, _výno, _àrie,
   {{0x6b840074,0xe1f98084,0x67240314,0xe29729f2}},	// [7ca0] riig, nsų_, _ibij, еат_,
   {{0x850e8fea,0xdff38441,0x2fc9022c,0x76440314}},	//   _साइट_, _आबाद_, _ziag_, _iriy,
   {{0x2fc9022c,0xaadf801b,0x63a0b4e6,0xaf068162}},	//   _yiag_, नडाक, yomn, епел,
   {{0x44446b98,0x09e60912,0x91e61232,0x68e3017b}},	//   _ir_, _помн, _поме, ında,
   {{0x6d5e3935,0xa3bd0105,0x163492c0,0x67244d91}},	//   _kopa, इगर_, теля, _mbij,
   {{0x4444542c,0x61e4262d,0x256f02f1,0x26cd8037}},	//   _kr_, mpil, _küla_, _egeo_,
   {{0x6724017f,0x6d5e4907,0x69d600f1,0x63a0fa2d}},	//   _obij, _mopa, lqye, tomn,
   {{0x31c8c83a,0xd3779d7b,0x44440039,0x25740338}},	//   रद्ध, ечь_, _mr_, _fälg_,
   {{0xc2988765,0xdb040118,0x6d4b81a8,0x22407a2e}},	//   ьких_, nmiñ, álaí, nvik_,
   {{0x4444073a,0xc27b0451,0x200cfa2f,0x63a080e1}},	//   _or_, פריי, tudi_, somn,
   {{0x63a0d261,0x76446718,0xb4cc8744,0xe8948110}},	//   pomn, _ariy, रखी_, тань,
   {{0xc6a71c74,0x200c98c3,0x4ea7403d,0xd7f88162}},	//   ерги, rudi_, ерга, rsă_,
   {{0x44447a30,0x753a81ec,0x3d178074,0x200cb8d6}},	//   _ar_, _katz, _नामे_, sudi_,
   {{0x44447a31,0x238c81d0,0x22402176,0xb4eb12c6}},	//   _br_, ději_, dvik_, मरे_,
   {{0x97a716d9,0x77930bca,0x850e858c,0x3d12058c}},	//   _прил, _میدا, _साईट_, _तारे_,
   {{0x53340785,0x644305e4,0xe3b305ff,0x9b582118}},	//   лест, _ánim, ارس_, нист_,
   {{0x444415f8,0x764401bf,0x61e43097,0x69cab356}},	// [7cb0] _er_, _griy, gpil, _kife,
   {{0x7c28de6e,0x23690933,0x93bc8162,0x7cd90198}},	//   _opdr, skaj_, _spăl, _юмор_,
   {{0x44447a32,0x6b82895e,0x63630074,0x661d2c34}},	//   _gr_, _omog, _sõnu, ltsk,
   {{0xdddd009a,0xb4bf06bf,0x661d6504,0x673d1388}},	//   mysł, ेशी_, otsk, ndsj,
   {{0x753a80ad,0x63ad4846,0x660f2651,0x7c28a585}},	//   _batz, mlan, nuck, _apdr,
   {{0x444420af,0x63ad448e,0x69ca831d,0xa2c48c1c}},	//   _yr_, llan, _nife, ाइन्,
   {{0xeb9980d6,0x32090e35,0x63ad7a33,0x69aa0beb}},	//   мик_, lray_, olan, _जीटी,
   {{0x3f86fa34,0xdb009f5a,0x0b4582df,0x661d0687}},	//   ciou_, nomè, тнин, ktsk,
   {{0x63ad2cda,0xdb1afa35,0x660f02a5,0x27e08042}},	//   ilan, _autó, juck, _čina_,
   {{0x63ad029b,0x673b81e9,0x7f4d016a,0x672401a1}},	//   hlan, _hauj, _anaq, _sbij,
   {{0x2d87ae04,0x66e606cf,0x644501e9,0xdee627d4}},	//   mine_, кона, _nrhi, кони,
   {{0x63ad2175,0x44443998,0x6d5e3cc1,0x764405cb}},	//   jlan, _rr_, _sopa, _priy,
   {{0x444423fa,0x2d87803c,0x7ae9fa36,0x69ca9f58}},	//   _sr_, oine_, mbet, _fife,
   {{0xdb1d025d,0x444408f7,0x7ae98b81,0x673bc290}},	//   _lisä, _pr_, lbet, _lauj,
   {{0xdca62772,0x64a625a4,0x61fd1f5f,0x68f70079}},	//   тави, тава, _avsl, daxd,
   {{0x673b8a8e,0x6724003b,0x2d87fa37,0x320919ee}},	//   _nauj, _ubij, hine_, fray_,
   {{0x6d5e42d8,0x7bcbd3d4,0x644501ec,0x3209057b}},	// [7cc0] _topa, _migu, _erhi, gray_,
   {{0x44447a38,0x63ad42af,0x2d87fa39,0x7af602c4}},	//   _tr_, alan, jine_, sayt,
   {{0x44444b96,0x2d878ee0,0x61e47a3a,0x61fb8085}},	//   _ur_, dine_, spil, hsul,
   {{0x6a860436,0x63ad2b91,0x7bcbb995,0xe809a418}},	//   _алма, clan, _nigu, _विना_,
   {{0x9f595007,0x63a42c93,0x63758c58,0x7ae984fe}},	//   éré_, moin, _mánd, dbet,
   {{0x63a46761,0x7bcb87fc,0x2d879ea0,0xb4cc816f}},	//   loin, _aigu, gine_, रखे_,
   {{0x69ca939a,0xbef2016f,0xe9df001c,0x291808c5}},	//   _rife, _अजून_, _trúc_, _icra_,
   {{0x442084b7,0xdb1a8722,0xdcee00e1,0x63a40198}},	//   ċi_, _autò, jobľ, noin,
   {{0x7bcba0a7,0x171b8158,0x61fb97ef,0x75828fd3}},	//   _digu, _קומע, gsul, _پیغم,
   {{0x63ad7a3b,0x673b9ded,0x63710687,0x717480f7}},	//   zlan, _zauj, _måna, اهدا,
   {{0x63ad7a3c,0x6375fa3d,0x63a40009,0x7bda016a}},	//   ylan, _bánd, koin, ítul,
   {{0x7ae99a34,0x7bcbfa3e,0x6375ad84,0x63ad0085}},	//   cbet, _gigu, _cánd, xlan,
   {{0xa2a2159a,0x5f944f78,0x6375a8f4,0x673d03ba}},	//   _कुल्, рият, _dánd, rdsj,
   {{0x661d003b,0x61e2f931,0x63ad7a3f,0x58d3b1b3}},	//   rtsk, _itol, wlan, _кошт,
   {{0x63ad3d08,0x661d2adc,0xb4bf0c28,0x7f5f011c}},	//   tlan, stsk, ेशे_, _toqq,
   {{0x63ad1793,0x7988cb58,0x637583a8,0x7f4d07f1}},	//   ulan, lidw, _gánd, _unaq,
   {{0x80d70424,0x2d878169,0x29180144,0xdb04008b}},	// [7cd0] _बलदे, yine_, _bcra_, rmið,
   {{0xdb1d025d,0xd7e7035f,0xe9df002a,0xdb0085ec}},	//   _sisä, відо, _crúa_, llmä,
   {{0x31c4246b,0x201e8009,0x7ae98214,0x77b60118}},	//   рств, ntti_, ybet, láxa,
   {{0x201e8364,0x63ad011c,0x61e2fa40,0x2d87e43e}},	//   itti_, qlan, _otol, wine_,
   {{0xf770819f,0x7bcb8098,0xfe7080a0,0x63b9831d}},	//   غام_, _rigu, يده_, _rhwn,
   {{0x2cac8355,0xe9df0020,0x7ae98428,0xa97903de}},	//   _bydd_, _grúa_, wbet, _טאָכ,
   {{0x2d878315,0x7ae99c2b,0xdb040019,0x61e2fa41}},	//   rine_, tbet, lliá, _atol,
   {{0x2d87fa42,0x2cac831d,0x61fbd064,0x2246dfff}},	//   sine_, _dydd_, tsul, _brok_,
   {{0x7ae98422,0x2d87c6b7,0x68f50065,0xe7849d27}},	//   rbet, pine_, _kezd, _туро,
   {{0x2cac831d,0x61fbb15a,0x68f57a43,0x7bcb8d56}},	//   _fydd_, rsul, _jezd, _wigu,
   {{0x7bcb833e,0x61e28133,0x61fb8170,0x378a05c2}},	//   _tigu, _etol, ssul, ебно_,
   {{0xeeeb0104,0x2018809f,0xd24e826a,0x77b88216}},	//   ường_, ària_, آنی_, píxe,
   {{0x5fcf8701,0x6561a6be,0x79889a7a,0x63a474d4}},	//   _संकल, _kolh, bidw, voin,
   {{0x6371016d,0x6b89fa44,0x39588106,0x5bbe0c32}},	//   _råna, lieg, örst_, ्द्व,
   {{0x232a35d9,0xab2a1c60,0x63a47a45,0x656183a7}},	//   нови_, нова_, toin, _molh,
   {{0xf0928051,0x69c18214,0x6b89dcb0,0x29030019}},	//   _לנו_, lmle, nieg, _adja_,
   {{0xf2d28159,0x63a46de3,0x68f5188a,0x256f0006}},	// [7ce0] מען_, roin, _bezd, _küll_,
   {{0x63a42e17,0xdb00ae90,0x6b89811b,0x764b0e06}},	//   soin, romé, hieg, _ágya,
   {{0x6b898063,0x9d1b00be,0x776081c0,0xf3f100ff}},	//   kieg, _אויט, _pomx, ật_,
   {{0x2d8a7a46,0xe9df016a,0xdfcf01a8,0x6b89fa47}},	//   libe_, _irún_, سيه_, jieg,
   {{0x2cac8355,0x65618db7,0x6f0400b9,0xdb07002a}},	//   _sydd_, _bolh, _mdic, _émái,
   {{0x656183a7,0x660480e1,0xad9b01a8,0x201eb220}},	//   _colh, šiko, trúi, ytti_,
   {{0x3a202dd5,0x798881b9,0x50b8064a,0xd90d00b7}},	//   ltip_, vidw, _अरिष, _زین_,
   {{0x40930013,0x69ce7a48,0x3f84bc76,0x2246808e}},	//   _الفر, _hibe, _ummu_, _prok_,
   {{0x69ce6a7b,0x49748153,0x65618073,0xc174cf78}},	//   _kibe, илис, _folh, илищ,
   {{0x6f0426ca,0x2ee000dd,0xdb1e016b,0x753e008e}},	//   _adic, _afif_, _kupó, _napz,
   {{0xa3c40063,0x69ce7a49,0x6b89fa4a,0x7d1a80b9}},	//   एगा_, _mibe, bieg, _icts,
   {{0xa3d81d6a,0x7c3ab838,0x236d81ac,0x201ef7d2}},	//   ादन_, _istr, ckej_, rtti_,
   {{0x11548607,0x61e28019,0xb8cb9d41,0xf1ba801c}},	//   _вклю, _utol, _कु_, _thơ_,
   {{0x6f0405dc,0xda7b8051,0x442ca0d5,0x1c18bef1}},	//   _edic, _אנדר, _kpd_, _धमाल_,
   {{0x443a7a4b,0x68fafa4c,0x80db81c6,0x753e7a4d}},	//   _csp_, matd, _אחוז, _dapz,
   {{0x1dd48996,0x68fa829a,0xdb198176,0xdb2181d6}},	//   ददात, latd, _chwè, _štúr,
   {{0x69ce3a19,0xa2c0053e,0x8d870adb,0x50f51f0d}},	// [7cf0] _bibe, लेल्, _бунд, изат,
   {{0x637807f4,0x2d8a040e,0x3f8b003a,0xa5bb11b9}},	//   _aínd, cibe_, licu_, stób,
   {{0x69ce0812,0x443a7969,0xdb1e01ca,0xb0353fc5}},	//   _dibe, _gsp_, _cupó, рнеш,
   {{0x3f8b29b4,0x68fa829a,0x3ead8168,0x3d1b0074}},	//   nicu_, hatd, _pyet_, _बाडे_,
   {{0x69ce3d3e,0xe8010105,0x63780032,0x68faed86}},	//   _fibe, _लटका_, _dínd, katd,
   {{0x69ce12e5,0x7aed0c39,0x6b89bbb9,0x6443826c}},	//   _gibe, lbat, wieg, tvni,
   {{0x636a007b,0x3f8b00ce,0x6b898f67,0x6561874c}},	//   _sýni, kicu_, tieg, _volh,
   {{0x442caad0,0x3f8b003a,0x7aed0102,0x6443dbc9}},	//   _dpd_, jicu_, nbat, rvni,
   {{0x7c3ada07,0x3f8b0067,0x64488102,0x7bcf7a4e}},	//   _estr, dicu_, _erdi, _micu,
   {{0x7aed008e,0x236d81ac,0x7bcf3e92,0x636a00e1}},	//   hbat, skej_, _licu, _výni,
   {{0x6e2d2853,0xb8dd904f,0x637585a4,0x6b898f7d}},	//   _apab, _आर_, _cánc, pieg,
   {{0x76498205,0x443a7a4f,0xc7a600e8,0x3f8b05f3}},	//   _krey, _rsp_, римк, gicu_,
   {{0x6d890025,0x68fa829a,0xee373592,0x6b5c8061}},	//   ržan, batd, аня_, _négy,
   {{0x61e9fa50,0x7afb8364,0xeeeb0028,0xb17b0106}},	//   mpel, laut, ưởng_, _stån,
   {{0x2d8a41ba,0x69dbfa51,0x69ce51d1,0x63787a52}},	//   ribe_, lque, _ribe, _líne,
   {{0x7afb8e37,0x6f042e1e,0x69ce083a,0x7aed339c}},	//   naut, _udic, _sibe, gbat,
   {{0x69dbfa53,0xdb1e04c3,0x7bcf0458,0x69ce1e5f}},	// [7d00] nque, _supó, _dicu, _pibe,
   {{0x60e71505,0x7aed11c9,0x6f1bbf85,0x6729e141}},	//   имум_, abat, _acuc, _abej,
   {{0x7aed00a4,0x20560f04,0x7afbe5c3,0x645883a8}},	//   bbat, штар, kaut, xxvi,
   {{0x76498125,0xf8b28039,0x70d2db64,0x7afbad38}},	//   _brey, חשב_, _सल्ल, jaut,
   {{0x69ce425c,0xee7a95a8,0x28b80540,0x76498216}},	//   _tibe, خصات_, _अरवि, _crey,
   {{0x442caf99,0x3f8b012b,0x7649a4a0,0x7bd7011c}},	//   _ppd_, zicu_, _drey, _yuxu,
   {{0x7afb822e,0x998d809a,0x6e3bfa54,0x6d89026c}},	//   faut, steś_, _esub, džal,
   {{0x200c8289,0x7649808b,0x7afbfa55,0x61e6008e}},	//   vrdi_, _frey, gaut, _ktkl,
   {{0x764990c9,0x637585e4,0x32000176,0x7e60016d}},	//   _grey, _sánc, nsiy_, ämpl,
   {{0x7aed0087,0xd90e804e,0x6448807a,0x200c82d4}},	//   zbat, ذیب_, _trdi, trdi_,
   {{0x7c3a9e0f,0x68fa811c,0x7afbfa56,0x6448fa57}},	//   _ustr, ratd, baut, _urdi,
   {{0x61e60067,0x44380114,0x69db8363,0x77640980}},	//   _otkl, dwr_, bque, _coix,
   {{0xa11683f8,0xdb00840e,0x3f8b003a,0x69db93ff}},	//   _نوشت, nomí, ricu_, cque,
   {{0x7bcf0698,0x3f8b00fe,0x61e90315,0xac191170}},	//   _sicu, sicu_, _çeli, логу_,
   {{0x61e60029,0x999980e1,0x44380114,0x7bcf0957}},	//   _atkl, ísť_, gwr_, _picu,
   {{0x88778039,0x8c3c8085,0x539800e8,0x7f40913b}},	//   _כתוב_, _uyğu, ався_, _namq,
   {{0x7bd702c1,0x7aed7a58,0x7bcf3ad6,0x49750110}},	// [7d10] _wuxu, rbat, _vicu, блас,
   {{0x6375807b,0x7aed7002,0x9f588081,0x2fd87a59}},	//   _mána, sbat, _avrà_, _burg_,
   {{0x7bdea602,0x69db8feb,0xd246815b,0x75357a5a}},	//   ípul, zque, _کن_, mezz,
   {{0x6e44003d,0x75357166,0x7649fa5b,0x68f89235}},	//   _انیم, lezz, _prey, _levd,
   {{0x6375807b,0xfce582a4,0x6b8d7a5c,0x0356007c}},	//   _nána, боло, miag, _הירש_,
   {{0xa80501df,0x290a91b9,0x75357a5d,0x063803de}},	//   _coñé, óbal_, nezz, ינדט_,
   {{0x7afbc545,0x69c52ebd,0x28c303eb,0x65650372}},	//   taut, mmhe, वेशि, _mohh,
   {{0x6b8d501b,0x75350081,0x20011f72,0xd49802f6}},	//   niag, hezz, mshi_, יכות_,
   {{0x8e8580f7,0x637581a8,0x656502d5,0x81df8264}},	//   _الذه, _cána, _oohh, ধীন_,
   {{0x69db9ef5,0x6b8d00ad,0x61e9fa5e,0x320db1bb}},	//   rque, hiag, rpel, rrey_,
   {{0x69dba37c,0xa0a5a5f2,0x6d419cdf,0x20017199}},	//   sque, санд, _iala, nshi_,
   {{0x6d41b66b,0x61e987b3,0xb17b01a3,0x2001004f}},	//   _hala, ppel, _stål, ishi_,
   {{0x6d41d522,0xaaa7016f,0x75352e7c,0x200105ee}},	//   _kala, _कुलक, fezz, hshi_,
   {{0x6d41ae69,0x6d43fa5f,0x63a98fca,0x3d1200c2}},	//   _jala, ndna, loen, ़लें_,
   {{0xdd8f0b76,0x69d98c85,0xa3b3016f,0xf3f10129}},	//   روف_, _huwe, टतं_, ập_,
   {{0x6d41e6e6,0x69d9f21e,0x660f026c,0xda030074}},	//   _lala, _kuwe, brck, _लिखत_,
   {{0x69d9a0ff,0x7af982a6,0x3de200ab,0x64430115}},	// [7d20] _juwe, _mewt, _বিকল, _šnit,
   {{0x63a980f3,0x865b0039,0x69d9fa60,0x3a3d80ee}},	//   hoen, _עדיי, _muwe, _mswp_,
   {{0xa2b40701,0x63a9a023,0xa3b780d4,0x69d9c8dc}},	//   _आरक्, koen, छता_, _luwe,
   {{0x7c3e003a,0x6d41d5cd,0x69c5037a,0x66040a35}},	//   _ispr, _aala, amhe, _kvik,
   {{0x471b0158,0x63a98cfa,0xa805002a,0x61e60711}},	//   רונג, doen, _poñé, _utkl,
   {{0xf8dc08fd,0xdb00fa61,0x7ae2b3d2,0xd2b701c6}},	//   _बलिय, romí, _sfot, _ללכת_,
   {{0x6d418595,0x6e22fa62,0x6fb68199,0xdc2a9f33}},	//   _dala, stob, _همسا, استه_,
   {{0x5f968307,0x6d419a2f,0x68f895dc,0xdb0083fb}},	//   _الرئ, _eala, _sevd, pomí,
   {{0x25be8748,0x2fdf01a1,0x8d1a87c3,0x637c89c4}},	//   _thtl_, _čugi_, _مزار_, _léng,
   {{0x6d41fa63,0xe80d035a,0xa3d81094,0x69d9fa64}},	//   _gala, ांचा_, ादा_, _duwe,
   {{0xa3df800f,0x2c0b826a,0x63a983a6,0x69d99407}},	//   _धूप_, _معنی_, boen, _euwe,
   {{0x443e8943,0x63a9afde,0x289b03c8,0x656501a1}},	//   _ist_, coen, ריטא, _sohh,
   {{0x753501c1,0x6d41fa65,0x4aa709f2,0x0ab684e3}},	//   tezz, _yala, _कुंव, _احاد,
   {{0x7bda8d4f,0x6d41ac96,0x2d8e826c,0x236681c0}},	//   _kutu, _xala, nife_, _hooj_,
   {{0x75352414,0x7bda8406,0x7aed802e,0x20017a66}},	//   rezz, _jutu, _întâ, xshi_,
   {{0xa5bb256c,0x25740106,0x23668140,0x7bda80ef}},	//   ctón, _häll_, _jooj_, _mutu,
   {{0x7c3e2465,0x6b8d07e8,0x75352e7c,0x2366822c}},	// [7d30] _espr, riag, pezz, _mooj_,
   {{0x7bda8e67,0x23668282,0x63a9fa67,0x443e8252}},	//   _outu, _looj_, zoen, _ost_,
   {{0x69c50013,0x6d41fa68,0x7bdaa211,0x610b00eb}},	//   rmhe, _rala, _nutu, vēlē,
   {{0x20014d78,0x63781fd3,0xdb0d00f7,0x637c89c4}},	//   rshi_, _vínc, olaí, _jénd,
   {{0x672d00f1,0x637cb952,0x200102f7,0x787f8061}},	//   _mbaj, _ménd, sshi_, _kávé,
   {{0x7bdafa69,0x61ed7a6a,0x6d4192b5,0x69d9a1ba}},	//   _butu, mpal, _qala, _ruwe,
   {{0x6d41e319,0x6d43a6f4,0x7bdae957,0xdcf500eb}},	//   _vala, rdna, _cutu, lizē,
   {{0x6d41e37f,0x236681c0,0x69d9809c,0xa2c0170c}},	//   _wala, _cooj_, _puwe, लेक्,
   {{0x443e9cb0,0x6d41d2a2,0x63a9fa6b,0xe299b0ed}},	//   _est_, _tala, roen, рап_,
   {{0x672d7a6c,0x2d8e83a7,0x3f8ffa6d,0xe8f984a9}},	//   _abaj, cife_, ligu_, шло_,
   {{0x25a08013,0x764d4851,0x7bdacf6a,0x201e0106}},	//   éile_, _aray, _gutu, _ätit_,
   {{0x69d9fa6e,0xd6d98035,0x637c88f9,0x764d7a6f}},	//   _tuwe, _mało_, _cénd, _bray,
   {{0x99d79a43,0x764d2dc8,0x61ed2b7a,0xa5bb7a70}},	//   _اتصا, _cray, jpal, rtón,
   {{0x764d2f15,0x9f4600f7,0x29cd01a1,0x2366822c}},	//   _dray, mplí_, _džak_, _zooj_,
   {{0x3d1b00cf,0x8c4337be,0x6f09dbf7,0x2fc0125b}},	//   _बारे_, мере, _odec, _thig_,
   {{0x3f8f803a,0xdb0400f7,0x0aea01e5,0x66048bcf}},	//   jigu_, lliú, рдай_, šiki,
   {{0xe8fa1f7d,0x27e0803a,0xc33282f6,0x61ed1066}},	// [7d40] ила_, _čini_, וון_, gpal,
   {{0x6f09eaf2,0x61e480f7,0x9f5f01ca,0xa5bb018a}},	//   _adec, _éile, butó_, ntól,
   {{0xb17a80be,0x6d890754,0xdb0401a8,0x9f5f0144}},	//   סטער, džah, iliú, cutó_,
   {{0xd378803b,0x7bdaf180,0x68fe2f3c,0x39430122}},	//   _kuće_, _rutu, sapd, _eajs_,
   {{0xe5c6a15b,0x236681c5,0x6f098114,0x7bdafa71}},	//   оско, _rooj_, _ddec, _sutu,
   {{0x1dbc0bb8,0x63a9075f,0x6f098214,0xdb008019}},	//   ोगित, čene, _edec, domá,
   {{0x475a8656,0xd00702de,0x6602e82c,0x66e686b5}},	//   _края_, _мере_, ssok, _мова,
   {{0x68fc7a72,0x637581df,0x7ae4383e,0x63b6031d}},	//   _herd, _dáno, ncit, nlyn,
   {{0xde03a9e4,0xa5f78073,0x637c8118,0xdb00d7cb}},	//   _опти, _меѓу_, _rénd, gomá,
   {{0x7bda8bb0,0x7ae40101,0x6f098035,0x637c8118}},	//   _tutu, hcit, _zdec, _sénd,
   {{0x236681c5,0x61ed7a73,0x443ef24b,0x25740106}},	//   _tooj_, zpal, _ust_, _väll_,
   {{0xdbf080ab,0x656883ed,0x68fc7a74,0x764d7a75}},	//   _টিপস_, _hodh, _lerd, _pray,
   {{0x6568fa76,0x61e200f7,0x637c8333,0xdb008144}},	//   _kodh, íoll, _vénd, comá,
   {{0x68fc02d0,0x656888f9,0xdb0d01a8,0xd49b0a4c}},	//   _nerd, _jodh, rlaí, арб_,
   {{0x9f47820f,0x7bc2ea68,0x6568fa77,0x6378008b}},	//   ënë_, _khou, _modh, _sína,
   {{0xe517023c,0x764d7a78,0x6568cd91,0x20070968}},	//   _ताकि_, _tray, _lodh, šnik_,
   {{0x68fc7a79,0x637cb893,0x49751bbf,0x29d500f7}},	// [7d50] _berd, _géne, плас, سياس,
   {{0x68fc7a7a,0xdcf500eb,0x799a8edc,0xf84b0087}},	//   _cerd, rizē, nntw, ичей_,
   {{0x2d917a7b,0x68fc1df8,0x4735965d,0x61ed7a7c}},	//   mize_, _derd, знес, spal,
   {{0x68fc05f8,0x61ed2c44,0x6f1d50fe,0x7ae42e93}},	//   _eerd, ppal, ngsc, ccit,
   {{0x6d454958,0x637c862f,0x65688387,0x7afd0029}},	//   _kaha, _xéne, _bodh, _iest,
   {{0x68fc7a7d,0x2d917a7e,0x6d475f16,0x7afd05be}},	//   _gerd, nize_, ndja, _hest,
   {{0x6d4506df,0x290102a3,0x7afd23e8,0x69dd13c2}},	//   _maha, maha_, _kest, _huse,
   {{0x6d457a7f,0x7afd085d,0x29017a80,0xdb0090dd}},	//   _laha, _jest, laha_, tomá,
   {{0x68fc0182,0x69dd3744,0x9ad30133,0xdb0e80f7}},	//   _yerd, _juse, _dịga, ódál,
   {{0x6d453c6e,0x61e6803e,0x6568803d,0x2901321b}},	//   _naha, íkla, _godh, naha_,
   {{0xa3bd101c,0xfbdb081f,0x69d5019a,0x69dd7a81}},	//   ेगा_, _मूलम, _mize, _luse,
   {{0x69d50b90,0x7afd7a82,0xdb00816b,0x63ad0580}},	//   _lize, _nest, pomá, joan,
   {{0x2d9106c0,0x2901451a,0xa5bb0118,0x7bc9d1cc}},	//   fize_, kaha_, ptól, mmeu,
   {{0x6d45287c,0x2d9102a0,0x69d57a83,0x637cf4c8}},	//   _caha, gize_, _nize, _véne,
   {{0x7afd7a84,0x290102c1,0x69c3fa85,0x6d457a86}},	//   _best, daha_, _ihne, _daha,
   {{0x7afd0259,0x63ad469f,0x6d570899,0x69dd0d54}},	//   _cest, goan, _enxa, _buse,
   {{0x7afd7a87,0x6d456d5d,0x7ae4345a,0x2d8402be}},	// [7d60] _dest, _faha, rcit, èmes_,
   {{0x7afd2e04,0x7ae41137,0x0f148540,0x6441812b}},	//   _eest, scit, डल्स_, _osli,
   {{0x7afd05d8,0x69d57a88,0x656889c4,0x443c8069}},	//   _fest, _dize, _rodh, xwv_,
   {{0x68fc1736,0x6d457a89,0x68e50046,0x69dd2973}},	//   _werd, _zaha, achd, _fuse,
   {{0x68fc14ff,0x6d4568ee,0x69d5164b,0x6441fa8a}},	//   _terd, _yaha, _fize, _asli,
   {{0x7bc28051,0x7afd7a8b,0x69d5169d,0x25740106}},	//   _shou, _zest, _gize, _sälj_,
   {{0x777ba2fb,0x7bde52b5,0x645812ca,0x7bc282c4}},	//   _flux, _jupu, _ávid, _phou,
   {{0x7afd07f4,0x63a48796,0xf743a571,0x8c1b007c}},	//   _xest, čino, _песо, צופי,
   {{0x62840698,0x257400f2,0xc3330051,0x7bde0642}},	//   nzio, _välj_, תוח_, _lupu,
   {{0xad9b0013,0x04468767,0x4427810c,0x63710711}},	//   gsúl, _незн, btn_, _våni,
   {{0xac768875,0x7bc28051,0x2d917a8c,0x63ad004f}},	//   _عائش, _thou, vize_, yoan,
   {{0x6d457a8d,0x62840102,0x929d809a,0x29011ec7}},	//   _saha, kzio, wałe, zaha_,
   {{0x29016e0f,0x6e3d0a0f,0x2d917a8e,0x0ec70540}},	//   yaha_, uwsb, tize_, रेंड,
   {{0xa2cd0bbc,0x69dd5e8c,0x7bde7a8f,0x29010079}},	//   _दृष्, _ruse, _bupu, xaha_,
   {{0x2d917a90,0x92b900c8,0x6d477a91,0x63ad7a92}},	//   rize_, _চলে_, rdja, toan,
   {{0x2d9106a0,0x69dd2d38,0x7bde253a,0x1fa40110}},	//   size_, _puse, _dupu, _прыг,
   {{0x7afd7a93,0x6d45341e,0xa2cd0eb4,0x6375b240}},	// [7d70] _vest, _taha, _दृश्, _bánj,
   {{0x645801e2,0x9327003d,0x7afd286b,0x291eaf7e}},	//   _švie, _کردن, _west, ngta_,
   {{0x29017a94,0xb4bb901e,0xf1c800f7,0x628465b9}},	//   raha_, _घरे_, أولى_, azio,
   {{0x69dd3613,0x78b5026f,0x27f88c83,0x6f02826c}},	//   _tuse, _vyzv, árny_, gaoc,
   {{0xa3e30540,0xa3aa009a,0x091480ab,0x69d50061}},	//   _फंड_, खकर_, ত্যু_, _tize,
   {{0xdd9185ff,0x29016764,0xed56c060,0x361c01c6}},	//   ضوع_, qaha_, дош_, מודד,
   {{0x40342a96,0x201a00e5,0x98b81c43,0x8c428198}},	//   _перс, cupi_, _parą_, веще,
   {{0x291ef44b,0x2b497a95,0x77b60118,0xdce181a9}},	//   egta_, ndac_, páxi, _dolā,
   {{0x3a290057,0x7bc9d50c,0x2bdf82f1,0x0eac0035}},	//   ntap_, rmeu, _पंवा, _टुंड,
   {{0x44278748,0x98bc80eb,0x60099b6f,0x6f0d0db1}},	//   ptn_, _savā_, оном_, _adac,
   {{0x7d03fa96,0x07a60c5c,0xc7a62626,0x64418499}},	//   mans, данн, динк, _usli,
   {{0x22498301,0x54349abb,0x00000000,0x00000000}},	//   _šaku_, _سرمر, --, --,
   {{0x7bde5722,0xe28eb07d,0xfaff0a53,0x2eff8866}},	//   _supu, _ра_, _voël_, _meuf_,
   {{0xa3b611bc,0x7bde23a8,0x01c88019,0xdd998176}},	//   _चीज_, _pupu, _فونٹ_, _dwňg_,
   {{0xb4bb83b7,0x6ec200c2,0x2eff92b6,0x2aeb0133}},	//   _घरो_, रेजु, _oeuf_, _ụkọ_,
   {{0x05dd800f,0xd378803a,0x3947b660,0x2eff82be}},	//   मदाब, _kuća_, _hans_, _neuf_,
   {{0x3947e18b,0x6f029c89,0x27ed0088,0x7d0380ef}},	// [7d80] _kans_, vaoc, _čena_, kans,
   {{0x201a7a97,0x62847a98,0x63759931,0x1de18105}},	//   tupi_, rzio, _bánk, _पढ़त,
   {{0x7d03fa99,0x3947fa9a,0x6f029c89,0x83c61c64}},	//   dans, _mans_, taoc, _обож,
   {{0x4444073a,0x394795ab,0x9ad3019d,0x20070187}},	//   _is_, _lans_, _dịba, ânia_,
   {{0x6d89003a,0x7d03fa9b,0x66098b67,0x6f028b80}},	//   ržav, fans, _cvek, raoc,
   {{0x7d03a2b1,0x3947f792,0x753c7a9c,0xa3e32594}},	//   gans, _nans_, nerz, _फूड_,
   {{0x67240499,0xac9795a9,0x63758032,0x63781b9c}},	//   _ocij, ونها_, _kánh, _línm,
   {{0x7644113b,0x753c791d,0xd3788267,0x5b7b00be}},	//   _osiy, herz, _buća_, ַריא,
   {{0x44440341,0xc298a361,0x753c44ad,0x6f0d0a2a}},	//   _ls_, яких_, kerz, _rdac,
   {{0x44447a9d,0x7d03bc6b,0xd37880c3,0x636e8362}},	//   _os_, cans, _duća_, _cùnr,
   {{0x39479cb0,0x6d5ade24,0x753c26b1,0x76447a9e}},	//   _dans_, _inta, derz, _asiy,
   {{0x6d48d499,0x2011ca84,0xf99f02d6,0x657e4617}},	//   _hada, ázia_, _avèl_, _alph,
   {{0x4444073a,0xdb0d07e2,0xa5bb00f7,0x753c01ec}},	//   _as_, llaç, ltói, ferz,
   {{0x6d4a9de6,0x394789ff,0x63adfa9f,0x63711da3}},	//   ndfa, _gans_, čane, _lånt,
   {{0x45d41f7d,0x1fa71928,0xa5bb00f7,0x6d488fa9}},	//   торс, _ориг, ntói, _mada,
   {{0x6d48faa0,0x64583ac4,0x4444290f,0x7d03bc6b}},	//   _lada, _švic, _ds_, zans,
   {{0x44447aa1,0x7d03faa2,0x2eff826c,0x69d8aa3a}},	// [7d90] _es_, yans, _reuf_, _kive,
   {{0xc1788110,0x7c2aac15,0x2eaa00be,0xca4880ff}},	//   nkė_, ktfr, _משפּ, _mờ_,
   {{0x63a4803a,0x69d88019,0x661d2e92,0x7d03cab9}},	//   činj, _mive, lusk, vans,
   {{0x69d8ae31,0x7d03faa3,0x8c1a0158,0x64455dc7}},	//   _live, wans, _צורי, _ishi,
   {{0x6d48c38c,0x42790158,0xaaa7081f,0xdd9581e5}},	//   _bada, _זאָג, _कुचक, нады,
   {{0x6d48faa4,0x32091a34,0x7bcd2eec,0xdb0d0187}},	//   _cada, msay_, lmau, flaç,
   {{0x7d0390fe,0xfc3184e3,0xabd58226,0x69c71e01}},	//   rans, احت_, нциј, _ihje,
   {{0x3947a2c0,0x6d5a9a86,0x7d03faa5,0x661d5412}},	//   _sans_, _enta, sans, kusk,
   {{0x32097aa6,0x7d03843c,0x6d48faa7,0xca48801c}},	//   nsay_, pans, _fada, _cờ_,
   {{0x6d48faa8,0x64457aa9,0xf99180f7,0x661d7aaa}},	//   _gada, _oshi, طبخ_, dusk,
   {{0x2d83020f,0x7b67ac18,0x644502a0,0x673d7aab}},	//   dhje_, _отде, _nshi, fesj,
   {{0x7d01a225,0x673d02be,0x92bd80ab,0xa3c28128}},	//   _hels, gesj, _আলী_, ूषण_,
   {{0x69c70364,0x753c7aac,0x64457952,0x44447aad}},	//   _ohje, terz, _ashi, _ss_,
   {{0x69d8faae,0x63bbb8d3,0x7bc6020f,0x44447aaf}},	//   _give, llun, _shku, _ps_,
   {{0x44440057,0x64a31b28,0xdca3188e,0x2905fab0}},	//   _qs_, гара, гари, mala_,
   {{0x2905e088,0x38788bc5,0xbb431597,0x753c0081}},	//   lala_, ørre_, леск, serz,
   {{0x444460ee,0xfce63448,0x644501f6,0x63bb82af}},	// [7da0] _ws_, _попо, _eshi, ilun,
   {{0x2905fab1,0x63bba42a,0x27e98279,0x64450168}},	//   nala_, hlun, _čanj_, _fshi,
   {{0x44440fa9,0x6d89011f,0x69c700f1,0xc7b90668}},	//   _us_, ržat, _dhje, suđe_,
   {{0xdee695b5,0x6d48bc8d,0xdd200592,0x66e68470}},	//   ходи, _sada, _बाँध_, хода,
   {{0x6d48fab2,0x63bbfab3,0x7d018019,0x61e40372}},	//   _pada, dlun, _bels, qqil,
   {{0x2905a786,0x6d48fab4,0xd00a0bda,0xa3d80f97}},	//   jala_, _qada, _неге_, ादक_,
   {{0xc8b50071,0x63a28b67,0x6d48fab5,0x69d88ca9}},	//   _асты, _pjon, _vada, _rive,
   {{0x6d48a4db,0x32669eb5,0x69d8ebfe,0x5a349bcb}},	//   _wada, етов, _sive, внит,
   {{0x6f06188a,0xe1ef84c0,0x7d01fab6,0x7bd99295}},	//   dakc, یسی_, _fels, _diwu,
   {{0x2905fab7,0xfd6901bc,0xdb0d1b0d,0x7d01fab8}},	//   gala_, _dapụ, plaç, _gels,
   {{0x69d8c733,0x63bbfab9,0x26c489d1,0x387f0300}},	//   _vive, blun, _hzmo_, _ƙuri_,
   {{0x661d537f,0x32094b43,0x6722b033,0xf1b9cc91}},	//   tusk, ysay_, ngoj, vuše_,
   {{0x69d88e67,0x2d8300f1,0x7d0194cf,0x6b840079}},	//   _tive, thje_, _yels, dhig,
   {{0xae028076,0x661d2cc6,0xceb383c8,0xbf0c816f}},	//   रीयन_, rusk, ריש_, हणुन_,
   {{0x61e28364,0x645c8207,0x7bd980a4,0x41c39a3e}},	//   _huol, _árid, _yiwu, _حقوق,
   {{0x63a9011f,0x61e2deef,0x661d7aba,0x2d8300f1}},	//   čeno, _kuol, pusk, shje_,
   {{0x201eabc5,0x9ad301bc,0xdb1ba3b4,0x4fd80039}},	// [7db0] luti_, _bịaa, fluê, _אוהב_,
   {{0x644501e9,0x3d1b0006,0x660d113b,0x32093f6f}},	//   _tshi, _बाटे_, _ivak, rsay_,
   {{0xbf0c853e,0x644532a8,0x4ac50076,0x39a42369}},	//   हणून_, _ushi, लेजव, уштв,
   {{0x29059d0f,0x7d018bc5,0x660d0669,0x29fd80e1}},	//   zala_, _sels, _kvak, yňa_,
   {{0x69c700f1,0x61e2827e,0x2905d530,0x201ea5b5}},	//   _thje, _nuol, yala_, huti_,
   {{0x201e8867,0xe4e7835f,0x236900d2,0x29fd80e1}},	//   kuti_, хідн, ljaj_, vňa_,
   {{0xae0286a7,0x2246be3d,0xa4938fd3,0x63bbbae3}},	//   रीबन_, _asok_, دیات, tlun,
   {{0x660d003a,0x2905a064,0xd9c9800c,0x201e9b79}},	//   _ovak, wala_, रष्ट, duti_,
   {{0x63bbfabb,0x7ae98493,0x7d01fabc,0x29cd0668}},	//   rlun, rcet, _tels, _užas_,
   {{0x63bb80e3,0x7ae98dff,0x3a3900ee,0x201efabd}},	//   slun, scet, _mpsp_, futi_,
   {{0x2905f031,0x7d07026f,0xf99f0205,0x201eb55d}},	//   rala_, dajs, _avèk_, guti_,
   {{0x213e831d,0x236900b9,0xc62600ab,0xf42700ab}},	//   aeth_, jjaj_, যবসা_, মবার_,
   {{0x213ea537,0x23690253,0xe9ce8fbf,0x81e600ab}},	//   beth_, djaj_, _вк_, _যৌন_,
   {{0x201efabe,0x2905829b,0x660d21f6,0x333f8036}},	//   buti_, qala_, _dvak, leux_,
   {{0x5c150e02,0xab2a1501,0x201e9d60,0x1c3902c7}},	//   льту, мова_, cuti_, нять_,
   {{0x26df804f,0x333f8036,0xbebb0168,0x236f810c}},	//   _nguo_, neux_, rfër, _jogj_,
   {{0xe2975591,0x91e3102f,0xe9da0721,0xbb4324b2}},	// [7dc0] ват_, иоте, дка_, шетк,
   {{0x6b8435d4,0x8c960221,0x63a48743,0x29030216}},	//   shig, _армі, čini, _ceja_,
   {{0x29037abf,0x2d980751,0x63787ac0,0x6d5e24af}},	//   _deja_, mire_, _líni, _inpa,
   {{0x8a062070,0x2d987ac1,0x6d4e0a64,0x637c80e7}},	//   _изме, lire_, ldba, _réno,
   {{0x25fd8b9f,0x25740106,0x6722fac2,0x29030168}},	//   रीली_, _fält_, rgoj, _feja_,
   {{0x2d987ac3,0x6f04764b,0x63758125,0x61e28081}},	//   nire_, _leic, _mánu, _ruol,
   {{0xa2d62418,0x50c61513,0xdb0401df,0x7c2e7ac4}},	//   _मृत्, _वरिष, lliñ, ntbr,
   {{0x61e28364,0x2d9826da,0x201efac5,0xe3af80a0}},	//   _puol, hire_, vuti_, يري_,
   {{0x69dc1f73,0x2d982cf7,0x2fc90114,0x443a7ac6}},	//   _kire, kire_, _rhag_, _lpp_,
   {{0x443a021e,0x61e28098,0x69dc02a3,0xa5458060}},	//   _opp_, _vuol, _jire, _مضمو,
   {{0x660d0025,0x99638071,0x213efac7,0x534681e5}},	//   _svak, ртыл, reth_, _ахла,
   {{0x6d5e1d5b,0x61e28009,0xa3e6000f,0x3f86fac8}},	//   _anpa, _tuol, _पढ़_, nhou_,
   {{0x2d983fe4,0x69dc2f45,0x6f040083,0x6b82ae5d}},	//   fire_, _oire, _deic, _ilog,
   {{0xe8549301,0x69dc7ac9,0x2d984ae1,0xdb11808b}},	//   _منتد, _nire, gire_, ðgön,
   {{0x2903020f,0x6f047aca,0x403482cb,0x6b82806a}},	//   _reja_, _feic, _сейс, _klog,
   {{0x290300a9,0x69dc56a3,0x6d5e34eb,0x2d987acb}},	//   _seja_, _aire, _enpa, aire_,
   {{0x28ce8076,0x69dc7acc,0x2d985589,0xf1b98fee}},	// [7dd0] हेरि, _bire, bire_, luša_,
   {{0x69dc1142,0x7c3a93c7,0x6b82c9e8,0x2d984140}},	//   _cire, _optr, _llog, cire_,
   {{0x290300a9,0xe7198013,0x6b8284be,0x443a1142}},	//   _veja_, فيات_, _olog, _gpp_,
   {{0x4aae0076,0x3f99274c,0xf770880b,0xdb0401df}},	//   _झुकव, nisu_, يان_, bliñ,
   {{0x7bdd7a1a,0x333f80e7,0xb2872252,0x3ea98722}},	//   _iisu, veux_, _рынк, çat_,
   {{0x64a5896b,0xf1b9807d,0x69dc7acd,0x6b828ab3}},	//   лала, kuša_, _gire, _alog,
   {{0x7bdd0b3f,0xe8d9801c,0x637800f7,0x7aed0037}},	//   _kisu, _đỏ_, _síni, ocat,
   {{0x69dc25fc,0x7aed7ace,0x2d986a7b,0x2a6d009a}},	//   _zire, ncat, zire_, _żeby_,
   {{0xe9d99383,0x7bdd7acf,0x2d983796,0x333f82be}},	//   нки_, _misu, yire_, reux_,
   {{0x7bdd3e0a,0x6f044be5,0x6b82fad0,0x3b093ca0}},	//   _lisu, _seic, _elog, haaq_,
   {{0x93f592b2,0xa3e31513,0x6b82fad1,0x2d980d19}},	//   _спец, _फूल_, _flog, vire_,
   {{0x2d980e8c,0x7bdd01f7,0x63758511,0xdebb8300}},	//   wire_, _nisu, _cánt, _sauƙ,
   {{0x6f047ad2,0x64577ad3,0x7afb8590,0x7aed7ad4}},	//   _veic, _arxi, mbut, dcat,
   {{0xceb2804c,0x1a9a8158,0x3f86871d,0x4a9a80be}},	//   צים_, _אינע, zhou_, _אינג,
   {{0x2d987ad5,0x6f047ad6,0xc7b90668,0x7bdd1f37}},	//   rire_, _teic, suđa_, _bisu,
   {{0xe5200074,0x6e3b8035,0x7afbfad7,0x25740338}},	//   _बाकि_, _opub, nbut, _päls_,
   {{0x69dc7ad8,0x7bdd1e92,0x320dfad9,0x49ca1a07}},	// [7de0] _pire, _disu, nsey_, елан_,
   {{0x6d5e0295,0x7aed0661,0x2d87807a,0x7afb810c}},	//   _unpa, acat, jhne_, hbut,
   {{0x443a59b3,0xef1a8ae7,0x3f86879f,0x7649fada}},	//   _upp_, еме_, thou_, _asey,
   {{0x7aed0098,0xdc9b012a,0x77bd01df,0x068681a1}},	//   ccat, _טייל, téxi, лген,
   {{0xd5ba8a7f,0x63a40e20,0x3f86867f,0x69dc10b6}},	//   нск_, mnin, rhou_, _tire,
   {{0x63a47adb,0xf9878872,0xc0e31d28,0xa5bb7adc}},	//   lnin, _طب_, _горк, ltór,
   {{0xf98302de,0x6b82fadd,0x7649f3c7,0xf99f02d6}},	//   _угро, _plog, _esey, _avèw_,
   {{0x63a47ade,0x5214867c,0x08770158,0xf1b98668}},	//   nnin, адит, _געלט_, vuša_,
   {{0xe8d98104,0x3f84859c,0x6375c2b2,0xa92a81e5}},	//   _đề_, _ilmu_, _ránt, ніне_,
   {{0xdd8f9baf,0x442c8144,0x7afbeb6e,0x2d988338}},	//   _فوق_, _tqd_, abut, _öre_,
   {{0x63a4088b,0xc0578d13,0x7aed5474,0x9f5f0009}},	//   knin, гія_, ycat, ystä_,
   {{0x6b82803b,0xe81c023c,0x63a41a1c,0xf1b98289}},	//   _ulog, _पटना_, jnin, ruša_,
   {{0x63a40e23,0x7bdd0698,0x3f990289,0x957c809a}},	//   dnin, _risu, risu_, _ciąg,
   {{0x091a0a49,0xceb3812a,0x7bdd3742,0x63a418d6}},	//   ন্তু_, מיר_, _sisu, enin,
   {{0x7bdd4a80,0x64581986,0x7ae2913b,0x63a4007b}},	//   _pisu, _ávil, _kgot, fnin,
   {{0x63a435e8,0x98138b76,0x9ad301bc,0x7bc080ee}},	//   gnin, _ابوا, _fịla, nlmu,
   {{0x7aed7adf,0x3171007d,0x7bdd0ca9,0xbda7006b}},	// [7df0] rcat, _pozz_, _visu, _محدو,
   {{0x7aed17d6,0x7bdd7ae0,0xdb04007b,0xa5bb7ae1}},	//   scat, _wisu, slið, dróg,
   {{0x7bdd3275,0x31c40009,0x63a47ae2,0x7aed026c}},	//   _tisu, сств, bnin, pcat,
   {{0xa5bb0c52,0x7ae2fae3,0xc7b9026c,0x3b090df6}},	//   ctór, _ngot, brđe_, qaaq_,
   {{0xd2469a05,0x11d900f7,0x44312023,0x2d878083}},	//   _بن_, _لوحة_, ltz_, thne_,
   {{0x7ae295c7,0x394e80dd,0x2715801c,0x3f84b533}},	//   _agot, _nafs_, ền_, _elmu_,
   {{0x44317ae4,0x8bf080ab,0x799aac64,0x7afbb5e8}},	//   ntz_, _টিউন_, ditw, tbut,
   {{0x63ad95d8,0x69ca92c6,0x61e60380,0x4431011b}},	//   čano, _सीबी, _yukl, itz_,
   {{0xa3d604c5,0x7afb89bf,0x2d87a651,0xfaa5ac39}},	//   िगत_, rbut, phne_, рапо,
   {{0x44237ae5,0x6375803e,0x661d0916,0x7ae28102}},	//   kuj_, _páns, drsk, _egot,
   {{0x63a44b3e,0xd7a9816f,0x661d1c7b,0x2d85fae6}},	//   ynin, _कदाच, ersk, _ille_,
   {{0x201889e9,0x6d43c1a3,0x3ebf8637,0x6235b2de}},	//   ária_, lena, _kyut_, _веду,
   {{0x63a47ae7,0x3984016d,0x59c51995,0x443116ee}},	//   vnin, _lösa_, वतार, etz_,
   {{0x6d43803a,0xe2c880e8,0x399b8032,0x443103e1}},	//   nena, _слід_, _dásè_, ftz_,
   {{0x44230063,0xa5070b9c,0x661d3888,0x6da31a1f}},	//   guj_, реса_, arsk, цира,
   {{0x61e60503,0x6d4389e8,0x2907a9a4,0x6b9b847f}},	//   _pukl, hena, _hena_, niug,
   {{0x6d43d1b4,0x2907fae8,0x63a42ed4,0x6da600e8}},	// [7e00] kena, _kena_, rnin, _випа,
   {{0x63a4006f,0xa5bb3c82,0x9f5f0bfa,0x61e61487}},	//   snin, stór, rstå_, _vukl,
   {{0x69c19dcd,0x2907fae9,0x63a442ab,0x63780125}},	//   ille, _mena_, pnin, _sínu,
   {{0x2d858d1a,0x2907faea,0x26178076,0x61e65848}},	//   _alle_, _lena_, _निशी_, _tukl,
   {{0x2bdf80dc,0x7d0a90fd,0x3a3d82f7,0xf1b981a9}},	//   _पंजा, tafs, _npwp_, jušo_,
   {{0x5e5700be,0x7b3e0035,0x2907faeb,0x660408b1}},	//   יינע_, _dłuż, _nena_, _mwik,
   {{0x98a316d9,0xa0a32351,0x18a33941,0xa0670081}},	//   _дире, _дард, _дарм, _кара_,
   {{0x27e0025d,0x2d8586e3,0x6f0b913b,0xd378803b}},	//   _niin_, _elle_, cagc, _kući_,
   {{0x6d43a853,0xfe0281ce,0x2907b01d,0x0566a27b}},	//   bena, रीशस_, _bena_, _кван,
   {{0x6d4391b9,0x63a90ed6,0x7c3e00e8,0x27e00362}},	//   cena, čeni, _oppr, _aiin_,
   {{0xe8d98142,0x2bdf90d0,0x2907811e,0x3ceb8740}},	//   _để_, _पंचा, _dena_, _चलते_,
   {{0x27e78358,0x7ae28353,0xf1b982a5,0x443e8a87}},	//   _dunn_, _ugot, vrše_, _ipt_,
   {{0x7c3e1b80,0x27e02afd,0x2907d242,0x6f160428}},	//   _appr, _diin_, _fena_, _ddyc,
   {{0xe7e70076,0x443e80b9,0x44237aec,0x6f160035}},	//   _ओढला_, _kpt_, tuj_, _edyc,
   {{0x290cfaed,0x7d08faee,0xdb09a564,0x25b981a8}},	//   mada_, _meds, cleó, _ísle_,
   {{0x290cc2bf,0x6d43e827,0x44230f66,0x052700c8}},	//   lada_, zena, ruj_, য়ের_,
   {{0x44237aef,0x29078234,0x6d43ebfe,0x637c802a}},	// [7e10] suj_, _yena_, yena, _céni,
   {{0x645aa62c,0x637c83f8,0x63787af0,0x7d088082}},	//   _orti, _déni, _sínt, _neds,
   {{0x6f16031d,0x7b3e009a,0xa3c88fd5,0x6378002a}},	//   _ydyc, _służ, ोगा_, _pínt,
   {{0x290cfaf1,0x6d4391ee,0x637ce6cf,0x30d980be}},	//   hada_, wena, _féni, אַנע,
   {{0x7d088022,0x98a70459,0xf77091cc,0xbb3a00be}},	//   _beds, ını_, بال_, _גערי,
   {{0xd90f0bca,0x99850013,0x2d9cfaf2,0x2bdfa518}},	//   _آیا_, _السو, give_, _पूजा,
   {{0xeb998ba8,0x290cb3ec,0x29079651,0x645a9351}},	//   лик_, dada_, _rena_, _crti,
   {{0x2907faf3,0x443e8057,0x672d022c,0x1b49891d}},	//   _sena_, _dpt_, _ncaj, узии_,
   {{0x290cfaf4,0x6d43c2a5,0x645a810b,0x69c1809f}},	//   fada_, pena, _erti, tlle,
   {{0x8d748307,0x05748250,0x27e010b5,0x6f098708}},	//   _والا, _والد, _siin_, _heec,
   {{0x69c1831d,0x66e621f2,0x6d8a8019,0xb8ef8a27}},	//   rlle, йона, _حملہ_, _शर_,
   {{0x4cd080ab,0x29078234,0x69c1d561,0x07a60162}},	//   _স্কু, _wena_, slle, самн,
   {{0x290cc2bf,0x2907822e,0x9ad30135,0x201ede35}},	//   bada_, _tena_, _dịka, arti_,
   {{0x61fb8859,0x225e03c1,0x6f09faf5,0x27e78338}},	//   mpul, _čtk_, _leec, _tunn_,
   {{0x7ff5936d,0xf7f58591,0x673b8365,0x637cc458}},	//   _استا, _استد, _obuj, _séni,
   {{0x087680be,0x2d9c92ec,0x637cb32e,0xd3788b80}},	//   _לעצט_, zive_, _péni, _pući_,
   {{0xae1c825e,0x61fbb2b6,0x224902c4,0x66040ce7}},	// [7e20] _निधन_, npul, gwak_, _uwik,
   {{0x673bfaf6,0x186a0eef,0xd378811f,0x39458806}},	//   _abuj, лази_, _vući_, nels_,
   {{0x63ad8805,0x7c3e0ffd,0x6ff38162,0x63780032}},	//   čanj, _uppr, _făce, _dínr,
   {{0x290c8510,0x443e802a,0xdc3b00be,0xcb6a02eb}},	//   zada_, _rpt_, _געטר, _саме_,
   {{0x290c9764,0x2d9cb1de,0x39458e61,0x443e810b}},	//   yada_, tive_, kels_, _spt_,
   {{0xa1160416,0x860780f7,0x2d9a00b9,0x13bd00ab}},	//   _دوست, حقوق_, _jmpe_, _আওয়,
   {{0x308600f7,0x2d9c97af,0x3945d852,0x6e2602c4}},	//   _الأف, rive_, dels_, hukb,
   {{0x645aaa06,0x7d08838e,0x290cabc3,0x799e004f}},	//   _vrti, _weds, wada_, lipw,
   {{0x290cf007,0xdb1bee0d,0xdb0403d3,0x3945faf7}},	//   tada_, cluí, rniè, fels_,
   {{0x20188003,0x2166867c,0x99669ae2,0x301495ac}},	//   ário_, стиг, стил, одор,
   {{0xdb0f0019,0x443e86cb,0xc32a80f7,0x645ab331}},	//   ődés, _upt_, _مكان_, _urti,
   {{0x2d9a249f,0x290a7af8,0x3a200bb1,0xe61f0187}},	//   _ampe_, _leba_, krip_, trô_,
   {{0x290c8852,0x8f9b8039,0x29186cff,0x3d0501d0}},	//   pada_, ריכי, _odra_, वरले_,
   {{0x3a20627e,0x291c0019,0xc69383c8,0x290cac96}},	//   drip_, óval_, לאר_, qada_,
   {{0x499b9a15,0x3f9d8326,0xa2db5a9c,0x96f930b4}},	//   _תשוב, yiwu_, पेन्, _кейт_,
   {{0x764d00a4,0x07a40992,0xec3400e8,0x26120072}},	//   _tsay, _најн, янсь, _तिची_,
   {{0x290a00ce,0x7dcdd561,0x3a200cfa,0x6f0f6e12}},	// [7e30] _beba_, núsc, grip_, macc,
   {{0x3f890069,0x6f098118,0x6f0f46d8,0x290a7af9}},	//   _hlau_, _seec, lacc, _ceba_,
   {{0x290a4ba4,0xa5bb6546,0x7bc40196,0x2606a594}},	//   _deba_, prób, bliu, सीसी_,
   {{0xd7c904e5,0xd378803b,0x6d475ed5,0x657700f1}},	//   रतिच, _kuću_, leja, _hoxh,
   {{0xf7708064,0x7dcd8722,0x6db58b79,0x61ed029a}},	//   عام_, júsc, ойду, qqal,
   {{0xed59b3fa,0x6d557afa,0xdb028125,0xce380039}},	//   рок_, ndza, _skoð, צאות_,
   {{0xe7c91199,0x25fd8054,0xb4e58032,0xd7c9016f}},	//   रताप, रीजी_, _afàì, रताच,
   {{0xa2d01d2a,0x765b8104,0x69c529be,0x7dc07afb}},	//   _दरम्, _truy, llhe, löst,
   {{0x6d472c1e,0x6f0f2fe5,0x6925943d,0x6458a8c5}},	//   keja, dacc, омпа, avvi,
   {{0xe8df8104,0x6d4700dd,0x61fbfafc,0x2d8301ed}},	//   _giới_, jeja, rpul, jkje_,
   {{0xa3d9146d,0x6f0f2c05,0x3945bdf9,0x3f895d10}},	//   ाषा_, facc, rels_, _blau_,
   {{0x4427fafd,0x6f0f7afe,0x3945faff,0x3f890722}},	//   mun_, gacc, sels_, _clau_,
   {{0x63bbb3f8,0x3945fb00,0x70c61094,0x3f8901c0}},	//   moun, pels_, _वर्ल, _dlau_,
   {{0x6d472422,0x63a9fb01,0x63bbfb02,0x637c8866}},	//   geja, lnen, loun, _dénu,
   {{0x44279cbc,0xfce3324a,0x63a9a3ec,0x6e26228a}},	//   nun_, доро, onen, sukb,
   {{0x63a9e936,0x6f0f5d17,0x6b8d4318,0xbea63696}},	//   nnen, cacc, ghag, _майк,
   {{0x44278260,0x6d477b03,0x61ebfb04,0x7bc47b05}},	// [7e40] hun_, beja, _jugl, rliu,
   {{0x44278e59,0x61e384be,0x64418cab,0x602605a8}},	//   kun_, _jinl, _opli, жджа,
   {{0x61eb8698,0x61e3fb06,0xa2e60012,0x25e30105}},	//   _lugl, _minl, _монд, _टूटी_,
   {{0xe73a9bc6,0x6b8d7b07,0xddc98063,0x4427c16c}},	//   ред_, chag, _treś, dun_,
   {{0x63bb82ba,0x63a980e1,0x290a00e1,0x637c89c4}},	//   doun, dnen, _teba_, _mént,
   {{0xa2dabf53,0x4427fb08,0x8c430214,0x7c668591}},	//   _पृष्, fun_, ışve, قابل,
   {{0x61eb8125,0x4427a2b8,0x69b90a0d,0x0b8a9092}},	//   _augl, gun_, ्तरी, исии_,
   {{0x63bb85db,0x63a98257,0x2fc0022c,0x38608754}},	//   goun, gnen, _nkig_, _čir_,
   {{0x6f02b28d,0xfbd30039,0x6f0f7b09,0x224200b9}},	//   mboc, ותה_, vacc, _jpkk_,
   {{0x224200b9,0xba9b007c,0x2fc6a052,0x63a985ee}},	//   _mpkk_, יספי, llog_, anen,
   {{0x4427fb0a,0x6f0f7b0b,0x6c4a8065,0x2fc6dbf7}},	//   cun_, tacc, _خلاف_, olog_,
   {{0x63bbd0f2,0x61eb95f8,0x61e390f6,0x91e68dc7}},	//   coun, _fugl, _einl, _доде,
   {{0x8bd78158,0xa2d686de,0x6d471b0a,0xdb0981ec}},	//   _וואו_, मेश्, teja, ließ,
   {{0x63a0d8c1,0x3cdc03ca,0x6f0f5ba6,0x26c500eb}},	//   limn, _गृहे_, sacc, ālo_,
   {{0x672ba4f1,0x6d477b0c,0xfe6e07d2,0x2d837b0d}},	//   yggj, reja, نگی_, rkje_,
   {{0x63a0a3c3,0x6d471d8a,0xb4f886b7,0x27fe8101}},	//   nimn, seja, ुरुप_, mptn_,
   {{0x4427ddbe,0x6ce70221,0x51f801bb,0x6d470d8b}},	// [7e50] zun_, _міне, жную_, peja,
   {{0x6e22a1f6,0x442790fe,0x63a9acf6,0x6b8d7b0e}},	//   drob, yun_, znen, shag,
   {{0x63bbfb0f,0x7dc012d2,0x2366805c,0x6616026f}},	//   youn, röst, _onoj_, _zvyk,
   {{0x4427ef36,0x63a9003e,0x2fc6817f,0x4fe80048}},	//   vun_, čens, glog_, імін_,
   {{0xaaf60451,0x4427b6bf,0x63bb81df,0x63a9fb10}},	//   _מזרח_, wun_, voun, vnen,
   {{0x4427fb11,0x6f0d1581,0xf2d203c8,0x61ebfb12}},	//   tun_, _leac, _נעם_, _rugl,
   {{0x61e38091,0x1fa7d296,0x61ebfb13,0xfd500133}},	//   _rinl, _драг, _sugl, _achụ,
   {{0x4427fb14,0x6f0d0046,0x64418353,0x61eb8081}},	//   run_, _neac, _vpli, _pugl,
   {{0x26cd8025,0xe29987b6,0x13068009,0x6f1b86ec}},	//   _uzeo_, сап_, чный_, _iduc,
   {{0x442781da,0x61eb817f,0x63a980e1,0x637c802a}},	//   pun_, _vugl, snen, _sént,
   {{0x61e3fb15,0x637c8019,0x7c59803d,0x7dc00019}},	//   _vinl, _pént, _دلار_, zöss,
   {{0x6609c176,0xe73a2829,0x7b648991,0x6f0d01a8}},	//   _kwek, щем_, _отче, _ceac,
   {{0x6f0d1a2f,0xee372312,0x987782d4,0x1e832829}},	//   _deac, пня_, _išče_, елям,
   {{0x386a8013,0x6609b22c,0xf1b981a9,0x645e00c3}},	//   óirí_, _mwek, kuši_, _prpi,
   {{0xaffe8104,0xf1b98029,0x637c81df,0x6f0d032f}},	//   _trướ, juši_, _tént, _feac,
   {{0x6d86807b,0xeb970b9c,0x6f0d7b16,0x66168110}},	//   _aðal, пис_, _geac, šyki,
   {{0xe8d98104,0x66098870,0x6b9d0609,0x6b847b17}},	// [7e60] _độ_, _nwek, _dmsg, rkig,
   {{0x6f1b802e,0x63a0fb18,0x645e0bc8,0x7dc48722}},	//   _aduc, zimn, _trpi, pòsi,
   {{0x757b0039,0x98a3116b,0x660993fa,0xdefa862c}},	//   _הטיפ, нифе, _awek, был_,
   {{0x91e61317,0x442a0074,0xdb24004e,0x444401c6}},	//   _номе, mub_, _توحی, _ip_,
   {{0x2fc680c9,0x44380b04,0x645c7b19,0x83fc80c3}},	//   rlog_, ltr_, lvri, _mrđe,
   {{0x6f1bc29c,0x6f0288f1,0x6e22fb1a,0x44447b1b}},	//   _educ, sboc, rrob, _kp_,
   {{0x44384407,0x442a0201,0x6609fb1c,0x645c0cab}},	//   ntr_, nub_, _ewek, nvri,
   {{0x44440039,0x20188267,0x660982d6,0xa7a78162}},	//   _mp_, šrik_, _fwek, _екса_,
   {{0x442a4c7e,0x6f0d1645,0xbebb00f1,0x3f86816b}},	//   hub_, _reac, ngët, mkou_,
   {{0x44445e6e,0x6f0d2ab6,0xb603800d,0x442a5c3d}},	//   _op_, _seac, ášen, kub_,
   {{0x6568fb1d,0x4444009a,0xdd8f80f7,0x442a7b1e}},	//   _indh, _np_, _حول_, jub_,
   {{0x3f868205,0x442a10b5,0x6d4afb1f,0x637c8118}},	//   nkou_, dub_, lefa, _véns,
   {{0x44440f23,0xf1be0a74,0x657a8077,0x54f083eb}},	//   _ap_, ्तान, _koth, _चलाए_,
   {{0x6d4ae60c,0xcaa580f7,0x44380789,0x657a85ee}},	//   nefa, _تصمي, ftr_, _joth,
   {{0x69da81ec,0x6f0d3f88,0x442a2177,0x69c781b9}},	//   mmte, _teac, gub_, ċjet,
   {{0x69c8881a,0x657a8c54,0x6d4ae5a7,0xa5bb0ce0}},	//   llde, _loth, hefa, crón,
   {{0x26dd0324,0x290eede8,0x201c0b67,0x2b492cfd}},	// [7e70] _àwo_, _kefa_, švil_, reac_,
   {{0x290e84b9,0x3a2900b9,0x657afb20,0x442a06ae}},	//   _jefa_, ruap_, _noth, bub_,
   {{0x7bc2c97e,0xdb0d007b,0x3a290359,0x47359a8b}},	//   _okou, blað, suap_, днес,
   {{0xb9040592,0x6568803d,0x2d8c811e,0x290efb21}},	//   _पृ_, _andh, _alde_, _lefa_,
   {{0x05960077,0x63ad7b22,0xddc9802e,0xe6188558}},	//   _رایگ, mnan, _creş, зді_,
   {{0x657a8ad0,0x290e912e,0x44447b23,0x33f181df}},	//   _coth, _nefa_, _yp_, _páx_,
   {{0x6d5702c1,0x5fbd0076,0x63ad4f0a,0xeb999cd0}},	//   _maxa, ईवाल, onan, жий_,
   {{0x63ad6e87,0xe1f99f43,0x3f86827f,0x69c8d150}},	//   nnan, оги_, ckou_, elde,
   {{0x6d4a8b40,0x6d570e1b,0x63ad2af6,0x8e778591}},	//   befa, _oaxa, inan, _عارض,
   {{0x6d570079,0x64457b24,0xdb00807b,0x442a7b25}},	//   _naxa, _ophi, rnmá, yub_,
   {{0x6d4180f2,0x8af98698,0x61e7002e,0x63ad088b}},	//   _ibla, _днес_, _mijl, knan,
   {{0x4444053e,0x69c8c72b,0x637583a8,0x6b830162}},	//   _rp_, alde, _lánz, _îngh,
   {{0x6d572c96,0xceb40201,0xa3b88875,0x2bb880f7}},	//   _baxa, _edən_, _عامر_, _عامة_,
   {{0x7bc983d3,0x442a66b2,0xf0b8803d,0x7bc2801b}},	//   lleu, tub_, _کاهش_, _zkou,
   {{0xef1f0059,0x2905809f,0xf8d18fea,0x61fd00eb}},	//   mkün_, mbla_, _हरिय, _atsl,
   {{0x6d5882a5,0x442a7b26,0x645c1151,0x7e620118}},	//   zdva, rub_, rvri, _áopo,
   {{0x44387b27,0x442a275c,0xc3328051,0x61e700f3}},	// [7e80] str_, sub_, כון_, _bijl,
   {{0x2617890a,0x44447b28,0xe9d70c5c,0xf8d186b7}},	//   _निजी_, _tp_, дку_, _हराय,
   {{0x44447b29,0x657aa360,0x3f8d80e7,0x3f86826f}},	//   _up_, _roth, _bleu_, tkou_,
   {{0x6d41fb2a,0xddc9802e,0x657afb2b,0x6d4afb2c}},	//   _abla, _preş, _soth, wefa,
   {{0x63a41572,0x6d4afb2d,0x3f86816b,0x69c8fb2e}},	//   miin, tefa, rkou_, ylde,
   {{0xf98784c0,0x7bc2867f,0x3f86d1b7,0x63a42334}},	//   _شب_, _skou, skou_, liin,
   {{0x7bc98114,0x6d58b1c3,0xb17680ff,0xf1b9826c}},	//   fleu, rdva, _nhượ, nušu_,
   {{0x290ef20f,0x63a41e3f,0x63758b4e,0x6d41d82c}},	//   _sefa_, niin, _kány, _ebla,
   {{0x657a809f,0x6d4aa410,0x998900e1,0x914aabd4}},	//   _toth, pefa, stať_, очна_,
   {{0x63ad09b3,0x66029cdb,0x63a43314,0x442a802a}},	//   znan, mpok, hiin, _ªb_,
   {{0x69c884b8,0xb5fd8699,0x63a447f8,0x63758019}},	//   rlde, _vrše, kiin, _lány,
   {{0x59d0000f,0x7bc99c4f,0x39580082,0x6d5702a3}},	//   _तीसर, cleu, _lars_, _saxa,
   {{0x63ad19a4,0x63a43273,0x395802c4,0x6d5701df}},	//   vnan, diin, _oars_, _paxa,
   {{0xea000104,0x395816fb,0xd6d9809a,0x7bc0fb2f}},	//   _xuất_, _nars_, _cały_, lomu,
   {{0x63ad7b30,0x63a40087,0xb5fd826c,0x69cb8035}},	//   tnan, fiin, _kršc, हतरी,
   {{0x6d576e42,0x69d40cce,0x63a419b3,0x7bc0fb31}},	//   _waxa, _बीबी, giin, nomu,
   {{0x6d577b32,0xdce881d0,0x61e701ed,0xb60401d0}},	// [7e90] _taxa, _podě, _pijl, tvář,
   {{0xc4c4850c,0xef198063,0x66028831,0x63ad7b33}},	//   _نے_, _może_, dpok, snan,
   {{0x31c41485,0xfe708077,0x27e9010b,0x63a402ec}},	//   тств, یده_, _kian_, biin,
   {{0x660d3e9d,0xea00001c,0x8af00085,0x27e97b34}},	//   _kwak, _suất_, ndəl, _jian_,
   {{0x27e900f7,0xdb0080f7,0x61e70282,0x61fd0b64}},	//   _mian_, cimé, _tijl, _utsl,
   {{0x660d21bb,0x6e2bb991,0xc10500f7,0x39587b35}},	//   _mwak, rugb, _سوري, _gars_,
   {{0x660d0a40,0xf99201c6,0x6fca9e51,0x6e2b82c4}},	//   _lwak, _גרם_, kých, sugb,
   {{0x58d41e4a,0x7bc9fb36,0xa5bb016a,0x29110a03}},	//   _рост, uleu, dróm, _heza_,
   {{0x7bc9fb37,0xb5c98117,0xa5bb2b49,0x26c902d5}},	//   rleu, _فورم_, tról, _nyao_,
   {{0x6d41825b,0x29113351,0xf99200be,0x2cfb1513}},	//   _ubla, _jeza_, ָרט_, ्रोल_,
   {{0x2cfb023c,0x63a402a3,0x291165b4,0x27e9376b}},	//   ्रैल_, yiin, _meza_, _bian_,
   {{0x2b5900f7,0x63ada9c7,0xf8b200be,0x1cb8830f}},	//   _nasc_, čans, רשט_, _غالب_,
   {{0xe28efb38,0x29c28125,0x27e94883,0x3dc580b9}},	//   _са_, rðar_, _dian_, _kklw_,
   {{0xef1f0065,0x29110578,0x63758b4c,0x44278fb0}},	//   lkül_, _neza_, _rány, orn_,
   {{0xf8c68935,0x205488b0,0x8fa601cf,0x8c4311d2}},	//   _रुपय, _атыр, _паке, лере,
   {{0x27e90104,0x69c1fb39,0x44278834,0xe1fa1b4d}},	//   _gian_, lole, irn_, зга_,
   {{0xa3c08076,0x29115e24,0x63a4532e,0x395875e5}},	// [7ea0] ंकत_, _beza_, riin, _pars_,
   {{0x63bb036f,0x69c1a2ac,0x63a47b3a,0x291102d0}},	//   čuna, nole, siin, _ceza_,
   {{0x64a6307d,0x39587b3b,0x6d4e5721,0x7bc0c165}},	//   _чана, _vars_, meba, yomu,
   {{0x69c1fb3c,0x6d5c3117,0x7e645a6a,0xd00f0199}},	//   hole, ldra, _krip, صله_,
   {{0x69c1e765,0xe5c6a070,0x7bc66dde,0xb8f600c8}},	//   kole, нско, _ikku, _হল_,
   {{0xf3f181bc,0x6d4e7b3d,0x7e647973,0x29117863}},	//   _bụ_, neba, _mrip, _geza_,
   {{0x961d06b7,0x68460009,0x53e68ada,0x7c2e4696}},	//   _भट्ट_, _янва, нциа, nubr,
   {{0x6d4e7b3e,0xddcd0087,0xf99f1abb,0x291177e7}},	//   heba, _oraş, _awèh_, _zeza_,
   {{0x7fd780be,0x4427c030,0xb5fd8bda,0x6fca816b}},	//   _טולס_, arn_, _vršc, vých,
   {{0x7c96c7de,0x6d4e0639,0x69c1fb3f,0x27e9379c}},	//   _прец, jeba, gole, _sian_,
   {{0x7bc60125,0xa3d005e8,0xddcd0182,0x394ca24f}},	//   _okku, षता_, _araş, reds_,
   {{0x6d5abeda,0x7e640573,0xb907950e,0xddcd0087}},	//   _hata, _brip, _मृ_, _braş,
   {{0x8f9b8f60,0x63a2b495,0x3cfd856b,0x657e457e}},	//   ליטי, _imon, रुवे_, _boph,
   {{0x69c1fb40,0x63a28069,0x6d5a8b17,0x7bc64951}},	//   cole, _hmon, _jata, _akku,
   {{0x6d5afb41,0x3ce504b8,0xb5fd8067,0x27e93c76}},	//   _mata, älv_, _mrša, _tian_,
   {{0xa3c0901b,0xa3c285e8,0x5ba4054c,0x29117b42}},	//   ंकि_, ृति_, груз, _seza_,
   {{0x29117b43,0x660d321f,0xe1f30bbe,0x63a28609}},	// [7eb0] _peza_, _uwak, اسر_, _mmon,
   {{0x442ebdc7,0x63a28122,0x7bc602ec,0x661b80c3}},	//   kuf_, _lmon, _ekku, _rvuk,
   {{0x63a2fb44,0x2911003a,0x7c2e0511,0x442704be}},	//   _omon, _veza_, cubr, _ín_,
   {{0x6d5ababf,0x69de0580,0x69c1e0a2,0xda218074}},	//   _aata, ampe, zole, _मिलत_,
   {{0x7bcd3963,0x69c19fa4,0xed59b306,0x3b0900b9}},	//   mlau, yole, дол_, mbaq_,
   {{0x64a58bac,0xdca5879e,0x6d5aab7d,0x83fc90d3}},	//   кала, кали, _cata, _srđa,
   {{0x6d5afb45,0x69c18775,0x7bc6007b,0xe73f02f1}},	//   _data, vole, _ykku, lnõu_,
   {{0x69c19e8b,0xc245a358,0x7bcd7b46,0x44278a51}},	//   wole, вник, nlau, rrn_,
   {{0x69c1fb47,0xe9d9b24a,0x6d454be8,0x6d5c1a27}},	//   tole, мки_, _obha, ydra,
   {{0x6d5afb48,0x6b89fb49,0xe8f68b79,0x63a2fb4a}},	//   _gata, skeg, кль_, _emon,
   {{0x7bcd3ffa,0x443caafe,0xe0cf80ab,0x69c19342}},	//   klau, ctv_, রশ্ন, role,
   {{0x7e6440f2,0x6d45780b,0xf0ee009a,0x3984016d}},	//   _prip, _abha, _जल्द_, _höst_,
   {{0x6d5ac83c,0x69c18b91,0x98b1817b,0x6d5c1345}},	//   _yata, pole, ızı_, tdra,
   {{0x7afd7b4b,0x443a0187,0xf1b9826c,0x9f4a823e}},	//   _afst, _pqp_, krši_, _rubí_,
   {{0x6d4e7b4c,0x64a301e5,0x6d5c1c2b,0x6e3d35cd}},	//   reba, аара, rdra, atsb,
   {{0x7bcd7b4d,0x2005fb4e,0x7afb8abf,0x39841614}},	//   glau, mpli_, ncut, _löst_,
   {{0x6f0907f4,0x6a831ede,0xcb128158,0xf5060698}},	// [7ec0] ñece, алта, ילן_, _изпо,
   {{0x4c860ddc,0x3cf08035,0x443c9029,0x7afd008b}},	//   _алов, _चलें_, ytv_, _efst,
   {{0x8af00085,0x200586c0,0x7bcd5d7e,0x38cb0019}},	//   ndək, npli_, blau, وامی_,
   {{0xe7d080c8,0x7bcd7b4f,0x7bc60326,0x34b701c6}},	//   িদ্য, clau, _ukku, _יפים_,
   {{0x6d5afb50,0x442e8859,0xa3bf0105,0x753b26d5}},	//   _pata, wuf_, इवर_, đuzv,
   {{0xdb0d02be,0x6d5afa66,0x63a2847f,0x3cfd801b}},	//   nnaî, _qata, _smon, रुले_,
   {{0x6d5a8214,0xb5fd8904,0x71a3087e,0x61ea8ca9}},	//   _vata, _vrša, _тарз, _rifl,
   {{0x6d5afb51,0x7c839982,0x442e96b2,0x5a349928}},	//   _wata, руше, ruf_, гнит,
   {{0x6d5a9e0a,0x442eb41e,0xa92a81e5,0x443c9434}},	//   _tata, suf_, міне_, stv_,
   {{0x69c30353,0xce3782f6,0x443cfb52,0x0e9b8039}},	//   čneg, _באמת_, ptv_, _חשמל,
   {{0x442e80dd,0xb42588ca,0x7d189e51,0x7e62a337}},	//   quf_, _معنو, mavs, lvop,
   {{0x331a8416,0x7f428144,0x7d18dbc9,0x83838198}},	//   _آزاد_, nfoq, lavs, _выше,
   {{0x61eab474,0x95cb0073,0x07a401e2,0xdd9101a8}},	//   _tifl, дува_, раўн, موح_,
   {{0x7d188c79,0x6e3d04dc,0xc1be06a7,0x39840338}},	//   navs, rtsb, ्तोग, _möss_,
   {{0x7bcd7b53,0x4992803d,0x3a297b54,0x6fc28072}},	//   tlau, _میکر, wrap_, षकां,
   {{0xf1b98052,0x69c7035f,0x63bb0805,0x3a295e75}},	//   vrši_, _skje, čuno, trap_,
   {{0x7bcd00e3,0x25f4016f,0x7d188669,0x7f5bea68}},	// [7ed0] rlau, ंदणी_, kavs, _rauq,
   {{0x7bcd22cc,0xa2a7016f,0xdb00816b,0x661d005f}},	//   slau, _घेण्, dimí, mssk,
   {{0xa2c983bb,0x7d1880d2,0x395cb8f8,0x39840106}},	//   _हुन्, davs, _mavs_, _röst_,
   {{0x7e622a06,0x443103bf,0x569595a6,0x2d8101ec}},	//   _šopi, muz_, лает, _hohe_,
   {{0x2d814171,0x2a6681c0,0x661d0b81,0x7afb82d0}},	//   _kohe_, _nrob_, nssk, vcut,
   {{0xaac6901c,0xbbcb8ebf,0x69c7021e,0xef1982a6}},	//   _लड़क, ात्क, _ukje, _doża_,
   {{0x44311d66,0x03a5b4fd,0x2d8100b9,0x628683ba}},	//   nuz_, лико, _mohe_, økon,
   {{0x69c500f1,0x2fc901c5,0xdb0402df,0x3869f6a3}},	//   lohe, _nkag_, rniç, _čar_,
   {{0x99159af1,0xab5b019d,0x7dcd808b,0xe8d980ff}},	//   льні, _akük, húsi, _đố_,
   {{0x7afbb594,0x69c500f1,0x661d0370,0x27ed80ff}},	//   scut, nohe, dssk, _hien_,
   {{0xe73a32a7,0x27ed81cd,0x5fb797a3,0x3cf0826f}},	//   нен_, _kien_, _अदाल, ňové_,
   {{0x2a66b28d,0x44310a82,0x27ed81b9,0x39898118}},	//   _frob_, duz_, _jien_, _músi_,
   {{0x63a9fb55,0xa3c089a3,0x61458746,0x69c57b56}},	//   mien, ंकर_, _бела, kohe,
   {{0x27edfb57,0x69c500f1,0x2bcb83eb,0x6289ced7}},	//   _lien_, johe, ातका, myeo,
   {{0x6b96031d,0x44310cdb,0x41cf92c6,0xb5fd8140}},	//   thyg, guz_, _सीएस, _oršo,
   {{0x09be23e7,0xe7bb0b04,0x6b8d2277,0x7f860144}},	//   ्त्य, _उदयप, gkag, _póqu,
   {{0xe29719ae,0x6f198063,0x3996013c,0x62898708}},	// [7ee0] гат_, dawc, _læse_, nyeo,
   {{0x63a9ecef,0x7a470029,0x44315157,0x66044914}},	//   hien, dītā, buz_, _itik,
   {{0x27edfb58,0x63a986a2,0x6f162651,0x6bd60872}},	//   _bien_, kien, _keyc, _متحر,
   {{0x63a9fb59,0x6d5e45da,0xb5fd812b,0x4b560098}},	//   jien, _hapa, _vršn, _съот,
   {{0x6d5e7b5a,0x63a9e5b7,0x27ed92f9,0x9cb3003d}},	//   _kapa, dien, _dien_, _نمیت,
   {{0x8e57010f,0x69c550b5,0x6b830087,0x63a9910f}},	//   טינג_, cohe, _îngr, eien,
   {{0x69dc0352,0x6d5e7b5b,0x63a99f10,0x672402ce}},	//   _ihre, _mapa, fien, _odij,
   {{0x6d5e7b5c,0x27ed8640,0xa2db063a,0x6f0b826c}},	//   _lapa, _gien_, पेक्, cbgc,
   {{0x22400763,0x61ee0239,0x38678118,0x44317b5d}},	//   ntik_, _kibl, _arnr_, zuz_,
   {{0x6d5e7b5e,0x291a0587,0x6e938013,0x27edfb5f}},	//   _napa, napa_, _الكا, _zien_,
   {{0x66041bcc,0xeaaf815b,0x99638190,0x672405f3}},	//   _atik, قعی_, стыл, _bdij,
   {{0x645afb60,0x63a9e164,0x69c500f1,0x661d2130}},	//   _isti, cien, zohe, tssk,
   {{0x6d5e0397,0x628990e4,0x4ea728fb,0x395c80eb}},	//   _bapa, cyeo, урна, _tavs_,
   {{0x6b829333,0x2fc68613,0xbf108076,0x4431011e}},	//   _hoog, hoog_, ारुन_, tuz_,
   {{0x6d5e0595,0x66045024,0x6fd6026f,0x291a6c44}},	//   _dapa, _etik, mácn, dapa_,
   {{0x44317b61,0x6b82a75c,0x9b581ac9,0x61ee6571}},	//   ruz_, _joog, лист_, _aibl,
   {{0x27ed83d3,0x69c5020f,0x69dc008c,0x6d48fb62}},	// [7ef0] _rien_, tohe, _bhre, _obda,
   {{0x6b8282c1,0x7f5f0201,0x645a981c,0x27ed84df}},	//   _loog, _haqq, _osti, _sien_,
   {{0x69c55dc7,0x61ee27c8,0x69dc0c41,0x629b81e8}},	//   rohe, _dibl, _dhre, zzuo,
   {{0x69c500f1,0x6d48bff5,0x63a981df,0x547a007c}},	//   sohe, _abda, xien, _סטרו,
   {{0x63a9fb63,0x6d5e07d9,0x27edfb64,0x291a03ac}},	//   vien, _yapa, _vien_, bapa_,
   {{0x201ea6a5,0x63a98063,0x320917ea,0x61ee6c63}},	//   ksti_, wien, mpay_, _gibl,
   {{0x27edc106,0x6b82fb65,0x63a9c839,0x7a4700eb}},	//   _tien_, _boog, tien, sītā,
   {{0x5f94c675,0x3b8582ac,0x7f5f02a6,0x4421120b}},	//   _лист, рлиг, _naqq, _mvh_,
   {{0x201eae8f,0xe2999fc7,0x320903ec,0x4999835f}},	//   esti_, тап_, npay_, втня_,
   {{0x63a9fb66,0xa9a5997d,0x7e69dc7d,0xb5fb0019}},	//   sien, риод, _irep, tván,
   {{0xe8d98104,0x637c8019,0x6fd8a564,0x2240011b}},	//   _đồ_, _lény, líca, ztik_,
   {{0x66e60b01,0x6d5e17b9,0x7e69fb67,0xdee60ab2}},	//   иона, _sapa, _krep, иони,
   {{0x6fd886a5,0x291a6b6e,0x2d9800f7,0xcaf48065}},	//   níca, yapa_, thre_, _اسمب,
   {{0xceb2804c,0xc0e58381,0xf2d28496,0x32090c0b}},	//   קים_, _колк, _ועד_, dpay_,
   {{0x6d5e0364,0x61ee0024,0x291a0267,0xfce64f97}},	//   _vapa, _ribl, vapa_, рово,
   {{0x6b8282a3,0x6d5e0010,0x291a0010,0x7e698118}},	//   _xoog, _wapa, wapa_, _orep,
   {{0x6d5e7b68,0x57250013,0xdb0083b0,0x291a2645}},	// [7f00] _tapa, _طريق, nimá, tapa_,
   {{0x6fd8ad84,0x2240011b,0x9d463dc3,0xa06a5f60}},	//   díca, rtik_, _теод, каза_,
   {{0x291a0393,0xb5fb026f,0x7e69fb69,0xef1a8073}},	//   rapa_, hvál, _arep, вме_,
   {{0x637c8019,0x291a085c,0x7e2a86b5,0x6fd89986}},	//   _fény, sapa_, віка_, fíca,
   {{0x5de688cc,0x69dc6b5d,0x764d00b9,0x7f420144}},	//   ажда, _thre, _xpay, _ñoqu,
   {{0x7e69fb6a,0xe0da0d5f,0x23ba80eb,0xac26983a}},	//   _drep, _авг_, dīja_, афик,
   {{0x20b90364,0x7e69fb6b,0xdb09816b,0xe6d3170c}},	//   _быть_, _erep, šnýc, _सर्ज,
   {{0x7d1c7b6c,0x291812ed,0x7ac6abad,0x201e9ff6}},	//   hars, _hera_, испе, vsti_,
   {{0x3a207b6d,0x29187b6e,0x7e69ac15,0x1dc61a8f}},	//   nsip_, _kera_, _grep, लकात,
   {{0x64a6c7af,0x7f5f56ed,0x7d1c75b0,0x79838428}},	//   _каза, _saqq, jars, _conw,
   {{0x3f84fb6f,0x29180292,0x645afb70,0xf4878019}},	//   _komu_, _mera_, _usti, _پالی,
   {{0x201ef59b,0x2918565f,0x320900e4,0x7f5f2828}},	//   rsti_, _lera_, ypay_, _qaqq,
   {{0x7d1c7b71,0x6d8b0085,0xdb008118,0x23ba81a9}},	//   fars, _müav, cimá, cīja_,
   {{0x2918204d,0x91e3817c,0xdb0401a8,0xd5b80198}},	//   _nera_, _доче, cniú, асс_,
   {{0xb05780f7,0x5fb88651,0x5f7712c8,0xd5b80081}},	//   _نشيط_, ेकाल, _ناظر, рся_,
   {{0x5bb80009,0xa2dd8bb8,0x987b81c6,0x386d01d0}},	//   ался_, _परम्, _ירוק, _čer_,
   {{0x764d105a,0xa9072105,0x6f1d1d82,0x29181d94}},	// [7f10] _upay, لبان, masc, _bera_,
   {{0x6f1d1d3f,0x69c8cc7e,0xd1388110,0x69c782d4}},	//   lasc, node, ngą_, čjeg,
   {{0x6d557b72,0x32090242,0x6ff3802e,0xd37101a8}},	//   meza, spay_, _făcu, _فهد_,
   {{0x7e698c6b,0x637c8019,0x6d55212e,0x6f1d7b73}},	//   _prep, _tény, leza, nasc,
   {{0xd37a0158,0x6db28063,0xdb00803e,0x63ad7b74}},	//   _ערשט, kład, ximá, mian,
   {{0x29184db6,0x63ad7b75,0x98778904,0x6d554cb2}},	//   _gera_, lian, _ušće_, neza,
   {{0x88e50a49,0xf8e50a49,0xb8950013,0x40950013}},	//   _প্রক, _প্রথ, _الأع, _الأر,
   {{0x1fa496d4,0x63ad0c5a,0x61b183eb,0x7d1c0333}},	//   _друг, nian, ीक्ष, zars,
   {{0x7d1c68ef,0x6f1d0722,0x6d5551c2,0x957c809a}},	//   yars, dasc, keza, _piąt,
   {{0x290110dd,0x63ad7b76,0x38978201,0x6fd604c3}},	//   ncha_, hian, lərə_, táco,
   {{0xa3d72af8,0x63ad7b77,0x2d858042,0x6f1d7b78}},	//   िता_, kian, _iole_, fasc,
   {{0x7d1c7b79,0x63ad340a,0xd498a2d2,0x6561fb7a}},	//   wars, jian, _тру_, _halh,
   {{0x2d85fb7b,0x29012fb0,0x69c8fb7c,0x63ad2bc2}},	//   _kole_, kcha_, bode, dian,
   {{0xb8dd8a49,0x69c89c4f,0x799aa64a,0x6d550542}},	//   _আর_, code, chtw, geza,
   {{0x63ad7b7d,0x2d85c6ef,0x232a4898,0xab2a1895}},	//   fian, _mole_, лови_, лова_,
   {{0x29187b7e,0x7d1c1f14,0x73990f88,0x63ad1ab6}},	//   _sera_, sars, атус_, gian,
   {{0xa9263274,0x29187b7f,0x6d557b80,0x3f848091}},	// [7f20] йдал, _pera_, beza, _romu_,
   {{0x7d1c02ed,0x6443ac15,0x59c79990,0xf2d28158}},	//   qars, ktni, रकिर, לען_,
   {{0x29182c9f,0xaaceb497,0x237f80ee,0x6443fb81}},	//   _vera_, _हुनक, kjuj_, jtni,
   {{0x29017b82,0x2d858032,0x29187b83,0x764280e7}},	//   acha_, _aole_, _wera_, ttoy,
   {{0x59c7824c,0x6561a28a,0xdfcf80a0,0x6443d613}},	//   रकार, _balh, ريه_, etni,
   {{0xb9960013,0x64438e23,0x29010609,0x656182df}},	//   _السب, ftni, ccha_, _calh,
   {{0x2d858da6,0x3f84827f,0x6561fb84,0x69c8a803}},	//   _dole_, _tomu_, _dalh, vode,
   {{0x6fb6845b,0x6d551088,0x6b9b9acd,0x09d08c2d}},	//   _امرا, zeza, ghug, हत्य,
   {{0x656183a7,0x27e68039,0x6b86784c,0x6d5560a2}},	//   _falh, mmon_, _mokg, yeza,
   {{0x6f047b85,0x2918c2b9,0x63ad7b86,0x645e08d8}},	//   _afic, úra_, zian, _ospi,
   {{0x6d55095e,0x69c8fb87,0xb915019d,0x2b8e00e1}},	//   veza, rode, _agbụ_, _tých_,
   {{0x6b9bfb88,0x69c8fb89,0x6d554b97,0x7d1af039}},	//   chug, sode, weza, _hets,
   {{0x6f1d7b8a,0x41e680e8,0x98b88214,0xeabf046d}},	//   rasc, _ліка, ırı_, _adùn_,
   {{0x63ad009a,0xb606026c,0x27e6f4f6,0xe894854c}},	//   wian, dašč, hmon_, _маль,
   {{0x63ad563c,0x291efb8b,0x7d1a843d,0xfbdf001c}},	//   tian, mata_, _mets, _phê_,
   {{0x291edbaa,0x27e681a1,0x52150d70,0x6d5534e7}},	//   lata_, jmon_, ждат, seza,
   {{0x63ad231a,0x6d550511,0x29017b8c,0x75288035}},	// [7f30] rian, peza, tcha_, _oddz,
   {{0x63ad7201,0x6443fb8d,0x7e6d7b8e,0xf99f0176}},	//   sian, ytni, _irap, _etèn_,
   {{0x290108a9,0x63ad063f,0x6616009a,0x98a781cc}},	//   rcha_, pian, _zwyk, _yanı_,
   {{0x291ec794,0x290157ff,0x9be40221,0xdcee81d0}},	//   hata_, scha_, _ніяк, žděn,
   {{0x28cf8778,0x15f911bc,0xdce88110,0xbb3a00be}},	//   _सुनि, ंदिर_, _kodė, _דערי,
   {{0x6443f67f,0xac09cc1d,0xdb00aeac,0x998001d6}},	//   ttni, анка_, himä, triť_,
   {{0x291efb8f,0xef198063,0x7d1afb90,0x2fdf8ad0}},	//   data_, _też_, _dets, _thug_,
   {{0x2d8588c4,0x6561b843,0x3163026c,0x6f02bf16}},	//   _wole_, _walh, _hajz_, ccoc,
   {{0x0cd606ce,0x291efb91,0x7bc983c9,0x2d85c583}},	//   _धर्म, fata_, roeu, _tole_,
   {{0x291ea8c5,0x6609ce0e,0x6b9b8010,0x89a99505}},	//   gata_, _itek, shug, рков_,
   {{0x6e246d52,0x8af00201,0xa2c981d0,0xadf3066f}},	//   _svib, ndər, _हुर्, _इंजन_,
   {{0xe73a355a,0x7e6d09ca,0x35af8105,0x4425826c}},	//   шем_, _brap, _झगड़, _ivl_,
   {{0x291ec7b5,0x06cd00ab,0x7e6d4844,0xbddb7b92}},	//   bata_, রেসি, _crap, rtèn,
   {{0x7e6d009e,0x291eb146,0xbddb009f,0x6f1bd917}},	//   _drap, cata_, stèn, _leuc,
   {{0xe8d980ff,0x6729e17a,0x5fc981d0,0xe9b88019}},	//   _đỗ_, _odej, िकाल, _دنوں_,
   {{0x7e6d22a2,0xaace816f,0x130a0110,0x6609fb93}},	//   _frap, _हुडक, рнай_, _otek,
   {{0x442580eb,0xeb972e87,0x7e6d10b6,0x26c00118}},	// [7f40] _lvl_, цит_, _grap, _uxio_,
   {{0x3f82005c,0x67298032,0xbddb253a,0xb6065bd2}},	//   ljku_, _adej, ntèl, rašč,
   {{0x645e120e,0x7d1a8982,0x44258683,0x6f1b8362}},	//   _uspi, _rets, _nvl_, _beuc,
   {{0x44380cf6,0x291eaa79,0x7d1ab55b,0x6e22fb94}},	//   mur_, zata_, _sets, tsob,
   {{0x291ed130,0x91e61878,0x443810f5,0x7d1a8461}},	//   yata_, _моме, lur_, _pets,
   {{0x44447b95,0x27e68286,0x798181c0,0x2007023e}},	//   _kq_, smon_, jjlw, ínic_,
   {{0x44387b96,0x6f1ba90b,0x645c5b21,0x7d1afb97}},	//   nur_, _feuc, nwri, _vets,
   {{0x2480803a,0x44440098,0x291efb98,0x7d1a9e12}},	//   ćim_, _mq_, wata_, _wets,
   {{0x44384aba,0x291ed6c9,0x7d1a8065,0xd2508077}},	//   hur_, tata_, _tets, رند_,
   {{0x44387278,0x7e6d2371,0x44440187,0x59dd86a7}},	//   kur_, _rrap, _oq_, _नीदर,
   {{0x2618090a,0x291ee486,0x7764107f,0x6d58ab0d}},	//   बीसी_, rata_, _baix, meva,
   {{0x7764107f,0x291e96e8,0x7e6d7b99,0xd36f80f7}},	//   _caix, sata_, _prap, _لهم_,
   {{0x291eee14,0x44447b9a,0x35df800f,0x443802be}},	//   pata_, _aq_, _पीड़, eur_,
   {{0x44387b9b,0x6d588006,0x95cb37be,0x0dcb0767}},	//   fur_, neva, рума_, руми_,
   {{0x44387b9c,0xfbab02a9,0x77641a85,0x44250333}},	//   gur_, атай_, _faix, él_,
   {{0x2b918104,0x442d1b89,0x69a68c1c,0x81c380ab}},	//   _cách_, če_, टोरी, ্ষণ_,
   {{0xdce881e2,0x8d873f61,0x291c8088,0x6d58b31b}},	// [7f50] _todė, _дунд, _keva_, keva,
   {{0x44380763,0xa2dd8a0d,0x35df800f,0xa5bb002a}},	//   bur_, _परस्, _पीढ़, cróp,
   {{0x6d58fb9d,0x291c809f,0xa3caeeed,0x2b9c00e1}},	//   deva, _meva_, लका_, _síce_,
   {{0x65657b9e,0x291cfb9f,0x9ee980f7,0xb8f30074}},	//   _hahh, _leva_, مفضل_, _हँ_,
   {{0x1d099b4f,0xddc466c6,0xa3ab0af3,0x6447067f}},	//   бели_, _hriš, कोण_, ltji,
   {{0x2b9c03bb,0x6d5898d6,0xed599c9b,0xce380039}},	//   _více_, geva, сок_, קאות_,
   {{0x6f1b8118,0x44443009,0x644701b0,0x61fd0686}},	//   _teuc, _xq_, ntji, _husl,
   {{0x2b91801c,0x291c8118,0x212100dd,0x61f526f0}},	//   _xách_, _aeva_, lahh_, _hizl,
   {{0x6609bc86,0x60d55fbc,0x6d58dfa3,0x44387ba0}},	//   _utek, _hyzm, beva, zur_,
   {{0x291c8012,0x39458765,0x6fd66935,0x6d58a898}},	//   _ceva_, чног, máci, ceva,
   {{0x6fd601ac,0x64450069,0x77640ba3,0x6d418085}},	//   láci, _nqhi, _paix, _icla,
   {{0x44387ba1,0xf09200be,0x6565477a,0x6db28035}},	//   vur_, גנט_, _aahh, płac,
   {{0xa5bb7ba2,0x6fd60e14,0x44380077,0x77640722}},	//   tróp, náci, wur_, _vaix,
   {{0x44387ba3,0x2b918028,0x44447ba4,0xa5073799}},	//   tur_, _sách_, _pq_, зера_,
   {{0x61fd02af,0x444416f0,0x3e5d86c0,0x64590035}},	//   _ausl, _qq_, _lňt_, _ćwic,
   {{0x6fd67ba5,0x44387ba6,0x61f50029,0x501a8039}},	//   káci, rur_, _aizl, _פופו,
   {{0x44387ba7,0x44440247,0x63bba300,0x61f5007e}},	// [7f60] sur_, _wq_, inun, _bizl,
   {{0x44387ba8,0x63bb82af,0xdb19819d,0xddc416f2}},	//   pur_, hnun, _akwü, _friš,
   {{0x443800f1,0x6d58dd17,0x9f520032,0xb4fb0039}},	//   qur_, veva, _aiyé_, _לפיי,
   {{0xd9c784e5,0x6d419ee8,0xa3d7152c,0x63bb84b7}},	//   रकुट, _acla, ितः_, jnun,
   {{0x6fd67ba9,0x6d58d292,0xf1bf188b,0xc33302f6}},	//   gáci, teva, _iván_, _אור_,
   {{0xe5a38ba8,0x2fc002ee,0x61f5017b,0x6d4a80e7}},	//   ничи, _ljig_, _gizl, uffa,
   {{0x63bb91f8,0x6d5884c4,0x81c380c8,0x09e3222c}},	//   fnun, reva, ্ষা_, _чорн,
   {{0x291c8813,0x58bb0039,0x48e1016f,0x6d588100}},	//   _seva_, _המלצ, _करतो_, seva,
   {{0xacf68013,0x6d58fbaa,0x291cb6b7,0x8d1a803d}},	//   _فسات, peva, _peva_, _هزار_,
   {{0xe7d600ab,0x63bbfbab,0xd90d803d,0x7d1e7309}},	//   _সংগঠ, anun, لیه_, _neps,
   {{0xd250826a,0xf8be03eb,0x68050084,0x291cc2ab}},	//   رنگ_, ्थिय, _kėda, _veva_,
   {{0xd838a384,0x2d8c089c,0x48a78a14,0x6722804f}},	//   ruč_, öden_, ятым_, naoj,
   {{0xbddb02be,0x291c809f,0xb886802a,0xe1ff027d}},	//   stèm, _teva_, _baíñ, _trói_,
   {{0xddc41734,0x7d1e110a,0x25f400dc,0x6aa4026c}},	//   _priš, _ceps, ंदगी_, dzif,
   {{0x6fd67ba5,0x58d3add3,0x28ac5a9c,0x38c880d7}},	//   záci, _пошт, _टेलि, _باشی_,
   {{0xb4bd035a,0x61fd01e2,0x644701b0,0x61f503bf}},	//   _अशी_, _pusl, rtji, _sizl,
   {{0x6fdd00e7,0xfb340071,0x672d0091,0x6fd8928a}},	// [7f70] léco, энтэ, _idaj, mích,
   {{0x660d1cd3,0x61f5011c,0x127b80be,0x6fd66935}},	//   _itak, _qizl, זאמע, váci,
   {{0xf9938158,0xe2f900e8,0x4af91317,0x2121008e}},	//   ערע_, _мені_, _меню_, rahh_,
   {{0x6fd60e14,0x290586a5,0x63bb1bb9,0xa5bb0118}},	//   táci, zcla_, čuns, isóm,
   {{0xb8d40663,0x8d7482e3,0x7c288711,0x59bf0a27}},	//   _जे_, کانا, _avdr, ्वदर,
   {{0x6fd67ba5,0x660d0010,0xddc98035,0x236900c3}},	//   ráci, _mtak, _speł, ldaj_,
   {{0x22497bac,0x1b2180c8,0x2a6fb78d,0x66e38032}},	//   ltak_, _যাবে_, _srgb_, _bìkí,
   {{0x660d668c,0x23697bad,0x2b9880e7,0xdfd180f7}},	//   _otak, ndaj_, _déco_, _شيء_,
   {{0x22494ca3,0x63bb80e3,0x660d6340,0x6fdd2755}},	//   ntak_, rnun, _ntak, técn,
   {{0x672d6289,0x2fcf90cc,0x38715f5a,0xf1bf58a0}},	//   _adaj, logg_, _krzr_, ्विन,
   {{0x7523b818,0x660d4778,0xb88681df,0xa3bf01cb}},	//   manz, _atak, _raíñ, ेवा_,
   {{0x7d1e020f,0x2614800f,0x7523edc7,0x661b8133}},	//   _seps, नीकी_, lanz, _kwuk,
   {{0xf1bf08af,0x614588cc,0x41bf0fb8,0x59bf0bc2}},	//   ्वान, _жела, ्वास, ्वार,
   {{0x7523fbae,0x61fd803e,0xe9ff0104,0xe1ff0063}},	//   nanz, íslu, _hoặc_, _osób_,
   {{0xb886802a,0x660d4f5b,0x330b01bc,0x8c43028e}},	//   _vaíñ, _etak, _ụbọ_, кере,
   {{0xee3a0656,0xb4ae035a,0x75238314,0x6b8bb139}},	//   _дни_, _कधी_, hanz, _jogg,
   {{0x75238e8c,0x6d4f008b,0x6b8beb34,0x6808928a}},	// [7f80] kanz, únað, _mogg, _věde,
   {{0x6b8b92f1,0x7e647baf,0x2366012b,0x99890140}},	//   _logg, _isip, žoj_, traš_,
   {{0x6fd8b1fb,0x77668098,0x7523fbb0,0x757b0039}},	//   líci, дълж, danz, _וטיפ,
   {{0x7c3c4c1b,0x6b8b8106,0x661b8db1,0x9ec680d7}},	//   murr, _nogg, _bwuk, وزشه,
   {{0x6f09062f,0x7523fbb1,0xe5c68284,0x5e5a8019}},	//   ñeci, fanz, мско, تجاج_,
   {{0x7523b0cb,0x6db2809a,0x2b4050b5,0x61c780c2}},	//   ganz, ałan, lgic_, रकोष,
   {{0x3e8508cf,0x6b8b8079,0xd94317c8,0x6d5c7bb2}},	//   _këtë_, _bogg, _шери, iera,
   {{0x16198105,0x2b40026c,0xb5fd81f4,0xc0e32b97}},	//   _नौकर_, ngic_, _pršt, _роск,
   {{0x6d5c70b5,0x7523aaac,0x7c3c4512,0x6fd6002a}},	//   kera, banz, hurr, nácu,
   {{0x7523a816,0xc27b012a,0x7c3c011e,0x3014a5f5}},	//   canz, קריי, kurr, ндор,
   {{0x31371a15,0xe8df8104,0x130a8009,0x7e647bb3}},	//   ונים_, _thời_, _дней_, _asip,
   {{0x6568bde5,0x7c3c6e12,0x6b8bfbb4,0x3f8683ec}},	//   _hadh, durr, _gogg, njou_,
   {{0x4ae28bb8,0x6d5c7bb5,0xaae28c78,0x6568906a}},	//   _परिव, fera, _परिक, _kadh,
   {{0x6d5c3ee3,0x31678352,0x6600973c,0x28cf873c}},	//   gera, _ganz_, _mumk, _सुवि,
   {{0x6568b5ea,0x0cd400e8,0x7e640234,0x2d8c86f3}},	//   _madh, ворю, _esip, _mode_,
   {{0x69daab53,0x22492c1c,0x672085f3,0x7523804f}},	//   llte, ttak_, _nemj, zanz,
   {{0x6d5c2bf3,0x657a90f4,0x45d51b1c,0xe8df801c}},	// [7f90] bera, _onth, _поис, _khởi_,
   {{0x6d5c04b8,0x22490289,0xf77091fb,0x443ce16e}},	//   cera, rtak_, یان_, kuv_,
   {{0xb9072f80,0x7523fbb6,0x22497bb7,0x69da8014}},	//   _पर_, vanz, stak_, ilte,
   {{0x2d9edc70,0xa3ab1053,0x69da81ec,0x75238314}},	//   _alte_, कोश_, hlte, wanz,
   {{0x75238a5a,0x2d8ce6b6,0x6568fbb8,0x1d09be0e}},	//   tanz, _bode_, _badh, пели_,
   {{0x7bc2a2c0,0x2d8cb7cd,0x6b8b8098,0x6db2809a}},	//   _ajou, _code_, _sogg, słan,
   {{0x75238d02,0x6d45022e,0x6fd88e14,0x6b8bfbb9}},	//   ranz, _mcha, zíci, _pogg,
   {{0x61c7885d,0x6d5c0863,0x22158012,0x75239b25}},	//   रक्ष, zera, нфор, sanz,
   {{0x6568fbba,0x7c3c7bbb,0x3e3588ca,0x7523ee3d}},	//   _fadh, zurr, _سفار, panz,
   {{0x2d8c805f,0x6d457bbc,0x6568fbb8,0x6d5c7bbd}},	//   _gode_, _ncha, _gadh, xera,
   {{0x61f8803b,0x6d5c7bbe,0xd00e815b,0x7afd0122}},	//   _divl, vera, یلی_, _ogst,
   {{0x6fd8f916,0x6d4527c4,0x6d5c5d15,0x2bac866f}},	//   tíci, _acha, wera, yści_,
   {{0x6fd60feb,0x6e3d0747,0xdb040216,0xa1958110}},	//   dáct, gusb, xniñ, _падч,
   {{0x6145942c,0x7bdbc7f8,0x75218061,0x6fd8b85e}},	//   _чека, lluu, _jelz, ríci,
   {{0x6d5c7bbf,0xc4d280be,0x7f5d7bc0,0x6d453d08}},	//   rera, ָגן_, besq, _dcha,
   {{0x6d5c7bc1,0xb4e0035a,0x6d454edd,0xd00e80f7}},	//   sera, _तरी_, _echa, _الي_,
   {{0xfaa36e38,0x211a00f7,0xdb0f0061,0x5a0c83de}},	// [7fa0] гато, كتاب_, ájár, ַלאַ,
   {{0xe9d77bc2,0x7c3c7bc3,0x6720e713,0x752181d0}},	//   еку_, purr, _semj, _nelz,
   {{0x3f9fad15,0x6568fbc4,0xe8df801c,0xd00f00d7}},	//   _bluu_, _radh, _khối_, ملل_,
   {{0xd6d9809a,0xa3de8006,0x67263d7b,0x69d53cea}},	//   _był_, _दीं_, nakj, _ekze,
   {{0x2d8c956b,0x65688077,0x69d5026c,0xaace81af}},	//   _pode_, _padh, _fkze, _हुंक,
   {{0x63a47bc5,0xceb300be,0x644afbc6,0x6568c38f}},	//   lhin, ניג_, ttfi, _qadh,
   {{0x8fa68002,0x2d8ca786,0x6fd60019,0xb0cf86a7}},	//   _заве, _vode_, nács, _सुलग,
   {{0x65688f49,0x443cbe43,0x63a47bc7,0xddc98087}},	//   _wadh, ruv_, nhin, _preţ,
   {{0x644ada73,0x8fa38764,0x6568fbc8,0x0a0a8133}},	//   stfi, _сате, _tadh, _bụụr,
   {{0xe4d680f7,0x7a5380f7,0x200e808e,0xa2c1001b}},	//   _كتاب, اضيا, _ptfi_, लपत्,
   {{0x63a47bc9,0x893703de,0xc95301c6,0x3202136f}},	//   khin, ערטע_, אמת_, _luky_,
   {{0x6d45177a,0xe8df80ff,0x7c2aaeca,0x7bdb81b4}},	//   _scha, _chối_, msfr, cluu,
   {{0xd6db4f78,0x63a47bca,0x7c2ada63,0x7f5d4c04}},	//   ято_, dhin, lsfr, resq,
   {{0xddc9fbcb,0x99800084,0x127b80be,0x31348993}},	//   _kreš, irių_, _מאדע, _рекр,
   {{0x6fd8c3c7,0xe0d48158,0x395e9e96,0x0133853d}},	//   lícu, _בײַ_, mets_, _صعود,
   {{0x395ecd5a,0xa3ab0063,0x7c33826f,0x3a290144}},	//   lets_, कों_, _údrž, tsap_,
   {{0x27e90364,0x6fd602ba,0x44380083,0x6d450eba}},	// [7fb0] _ihan_, ráct, arr_, _tcha,
   {{0x6d457bcc,0x395efbcd,0xa3e791bc,0x442cae67}},	//   _ucha, nets_, _मीन_, _ovd_,
   {{0x6fd882ba,0xbb1b02be,0x3a297bce,0x63a47bcf}},	//   hícu, _boît, ssap_, bhin,
   {{0x63a41645,0x2a6681d0,0x7c2acb6a,0xdb070198}},	//   chin, _osob_, dsfr, ämät,
   {{0x395ea0e5,0x442cb613,0x9f58823e,0x6d9d8706}},	//   kets_, _avd_, _durà_, _dèan,
   {{0x395e83d3,0x200e0722,0xddc980fe,0x442c8299}},	//   jets_, ífic_, _breš, _bvd_,
   {{0x395e8370,0x7c2aaeca,0x27e97bd0,0xd46685a5}},	//   dets_, gsfr, _ohan_, вище_,
   {{0x58d42150,0x77d780f7,0x27e9001c,0x752181ed}},	//   _сост, _أغسط, _nhan_, _welz,
   {{0x35f58b87,0x272000c8,0xdcfe24fb,0x395e80e7}},	//   _апар, _ভালো_, _uopć, fets_,
   {{0x6fdd03d3,0xe4a7828b,0x6f0d002e,0x395e83a6}},	//   léch, _прео, _afac, gets_,
   {{0x07a60ea6,0xe73a1878,0xddc98025,0x8fa60698}},	//   ванн, мен_, _greš, ване,
   {{0x27e909c5,0x212580dd,0x63a40168,0x6fd88144}},	//   _chan_, salh_, xhin, bícu,
   {{0xe28ea46a,0x27e967ec,0x59d10c28,0x395efbd1}},	//   _та_, _dhan_, तकार, bets_,
   {{0x6d43fbd2,0x3202026f,0x2606041c,0x395ecc04}},	//   ngna, _ruky_, _vôo_, cets_,
   {{0x63a42748,0x44380176,0xb5fb6935,0x6d43a6a6}},	//   thin, urr_, tvár, igna,
   {{0x25e8823c,0x224d8370,0x6b89fbd3,0x6fd60019}},	//   _चीनी_, otek_, njeg, rács,
   {{0x224d8019,0x442a09d1,0xb5fb0061,0xb1461a4e}},	// [7fc0] ntek_, ssb_, rvár, кнал,
   {{0x409614d6,0x63a47bd4,0xd5af00f7,0x63b6031d}},	//   крет, shin, _وفي_, siyn,
   {{0x69c1f332,0x98b10214,0xdca609a0,0x657e01a8}},	//   inle, _bazı_, _рани, _inph,
   {{0x224dbbd7,0xee0c8133,0x66040c85,0xd00f0199}},	//   ktek_, _aṅụr, _kuik, زله_,
   {{0x224dfbd5,0x442c816d,0xe5348c73,0x67240a6f}},	//   jtek_, _svd_, гель, _meij,
   {{0x6d4380f2,0xdd8f80f7,0xddc9fbd6,0x7c2a848d}},	//   ggna, يون_, _preš, tsfr,
   {{0x395e84fe,0x8bc6ae87,0x20035499,0x6604027c}},	//   vets_, ксид, _guji_, _luik,
   {{0x6fd89220,0x68e3419b,0x6b89fbd7,0x442c81ed}},	//   tícu, ünde, gjeg, _vvd_,
   {{0x27e9031d,0x60270019,0x0566813a,0x395e84fe}},	//   _rhan_, _témá, _иван, tets_,
   {{0x27e91d15,0x4973976e,0xddc980eb,0x6fd89727}},	//   _shan_, альс, _treš, rícu,
   {{0x672421a3,0x395ef7c6,0x6b8982fd,0xb90a800f}},	//   _beij, rets_, bjeg, _मर_,
   {{0x2a668069,0x66042f30,0x69c1fbd8,0x395ec16f}},	//   _tsob_, _buik, anle, sets_,
   {{0x28d9000f,0x539b82f6,0x395e980a,0x6f0d9727}},	//   _बुनि, _קידו, pets_, ñaci,
   {{0xbbbd0076,0x7bc6076c,0x6604110f,0x61fc00d7}},	//   ्क्क, _ajku, _duik, _nirl,
   {{0x6724184f,0x27e9501e,0xd40404fa,0xb33b4bb7}},	//   _feij, _than_, ияти, _alça,
   {{0x200300dd,0x21230267,0x6e2d8267,0xdcfa8609}},	//   _ruji_, _sejh_, šabi, _antċ,
   {{0x61fc0459,0x68e68201,0x98b107c0,0xe5c701e2}},	// [7fd0] _birl, əkda, _razı_, _асно,
   {{0x645ad307,0x61bf000d,0x20030458,0x6fdd3aef}},	//   _opti, ्वेष, _puji_, déci,
   {{0xa5bb01df,0x351a0039,0x224de6dd,0xd47900be}},	//   dróx, _אותנ, ztek_, _װאָל,
   {{0xff25803d,0x224d885d,0x22402833,0x5ecc80ab}},	//   ابای, ytek_, buik_, ়েছে,
   {{0xdd9587ac,0xf77088ca,0x26c98073,0x22840b79}},	//   лады, تال_, çao_, _кург,
   {{0xdce885c5,0x63a2fbd9,0x6d43820d,0x61fc7bda}},	//   _aldı, _alon, ugna, _girl,
   {{0x6d43af74,0x20110102,0x26d282d0,0x6b89e6db}},	//   rgna, _utzi_, üyor_, tjeg,
   {{0x2489803a,0x04568013,0x224d8019,0x160300d4}},	//   ćam_, الية_, ttek_, लदार_,
   {{0xe1f9a9e4,0x63a28197,0x236dfbdb,0x67247bdc}},	//   нги_, _dlon, rdej_, _reij,
   {{0x67247bdd,0x63a2b55b,0x224dfbde,0x44210359}},	//   _seij, _elon, rtek_, _owh_,
   {{0x224dfbdf,0x6b89fbe0,0x68458084,0x69c186b1}},	//   stek_, pjeg, ынна, rnle,
   {{0x660406f7,0x290ec5ec,0x224d8061,0x6fd88118}},	//   _puik, _effa_, ptek_, lícr,
   {{0x7bd98135,0x4421010c,0x9b74bdf2,0x2bc70af3}},	//   _ikwu, _awh_, _خالص, रचना,
   {{0xde031814,0x66033799,0x8c460187,0x44216310}},	//   спри, спра, леге, _bwh_,
   {{0x67242202,0x64a31662,0xdca329e4,0x657e1029}},	//   _teij, бара, бари, _vnph,
   {{0x644e0004,0x3878813c,0x39963f7e,0x61fc7be1}},	//   rtbi, ærre_, _læst_, _sirl,
   {{0x3a2d8b50,0x644e3842,0xade3800f,0x77a60118}},	// [7fe0] nsep_, stbi, गतान_, _cóxe,
   {{0x8d662a04,0x2240038e,0xa3e41a42,0xc4862fc0}},	//   _свое, ruik_, _पीर_, _блок,
   {{0x7e69b2e1,0x765baf0f,0xf99f023e,0x6fd88118}},	//   _asep, _apuy, _atès_, dícr,
   {{0x7bd98135,0xdd2f81d0,0x69c77be2,0x7c2e06b1}},	//   _nkwu, měři, _ejje, msbr,
   {{0x6d410177,0x52e286ae,0xa5bb03a8,0x7e698061}},	//   ólag, _परेस, tróx, _csep,
   {{0x7bc401e2,0x61fc00f7,0xddcd0984,0x6fdd0b2c}},	//   lniu, _uirl, _kraš, réci,
   {{0x7794853d,0x2d9c87dd,0x7e69fbe3,0x2b9c1029}},	//   _پیشا, rkve_, _esep, _níck_,
   {{0x5a3497f9,0x69d881ac,0x6fdd03a7,0xa3e782f1}},	//   анит, _skve, péci, _मीद_,
   {{0xf126ebc7,0x6f9380f7,0x399601fa,0x63a2fbe4}},	//   льно, _القض, _fæst_, _vlon,
   {{0x865b83c8,0xddcd012b,0x776d0079,0x7bd98870}},	//   _אדמי, _oraš, _saax, _ekwu,
   {{0x3f92080a,0x63a280dd,0x61d700be,0x6df381a8}},	//   _boyu_, _tlon, רויף_, _اكلا,
   {{0xb8ec800f,0x7c2e013c,0xdb0d0187,0xdfd50049}},	//   _रख_, dsbr, miaç, ромы,
   {{0xdb0d00a9,0x2216ee38,0x9f92007b,0xef1f0061}},	//   liaç, _сфер, ráð_, ljük_,
   {{0x290e80e5,0x776d01b4,0x2bcc8f1b,0xcad781c6}},	//   _uffa_, _waax, ावका, _עוגת_,
   {{0x2b9c0028,0xd37b4c1d,0x7c2e220d,0x11db8039}},	//   _kích_, нча_, gsbr, _רחוב,
   {{0xddcd0390,0xdce884e8,0xc2c501a8,0x7bc457a3}},	//   _draš, _nadč, ليزي, gniu,
   {{0x7762fbe5,0x52e286a7,0x0ce1a263,0x5edc066f}},	// [7ff0] deox, _परोस, _फर्म, _गुप्_,
   {{0xa2c5801b,0xdb0081a8,0xdcfa82d6,0x5f5d0135}},	//   ापत्, dhmí, _antč, _ọnụọ,
   {{0xddcd2a06,0x765b808e,0x315783de,0xe1e50072}},	//   _graš, _spuy, ריבן_, _कठीण_,
   {{0x2d93062f,0xbddb00e7,0x0eb9827e,0xdb0d3187}},	//   _hoxe_, ctèr, кулы_, diaç,
   {{0x366986eb,0xe80b8a27,0xddcd0af8,0x752a8299}},	//   тало_, _संभा_, _zraš, fafz,
   {{0xed598a29,0x6d477278,0x5187229c,0x2d93011b}},	//   ток_, ngja, _сума, _joxe_,
   {{0x6fdd087a,0xcd980039,0x2b9c00ff,0x69d703a8}},	//   lécu, רדות_, _bích_, moxe,
   {{0x6b8d40fa,0x69d7002a,0xa0c401a8,0x69c68061}},	//   njag, loxe, _ايفو, éken,
   {{0x69c51585,0x7c24826c,0x386081a1,0x49c9917e}},	//   onhe, ćira, _ćira_, клин_,
   {{0x69c523c7,0x499594c4,0x672bf5cb,0x6b8d47c5}},	//   nnhe, ршит, lagj, hjag,
   {{0xdd7a8158,0xdb0d03a7,0x27ed801c,0x6563c96e}},	//   _שטעל, ciaç, _khen_, menh,
   {{0xc5e90039,0x6e2d826c,0x7bd98870,0xdd2f81d0}},	//   _חד_, šabu, _ukwu, věři,
   {{0x6443fbe6,0x539a8039,0x2d937be7,0x63a9808b}},	//   luni, _שינו, _boxe_, mhen,
   {{0x7c2e0448,0xddcd6f1d,0x64a601e5,0x6563fbe8}},	//   tsbr, _praš, аага, nenh,
   {{0xab2a28c4,0x1c3902c7,0x6443dfbc,0x232a2109}},	//   кова_, лять_, nuni, кови_,
   {{0x920712c7,0x63a98956,0x63bbfbe9,0xda0880ff}},	//   _वंशज_, nhen, niun, _hỏa_,

  };
  // table_hash = d39f-ae47, unused_entries = 116 (0.06%)

static const uint32 kQuadChrome0122_19SizeOne = 31722;    // One-langprob count
static const uint32 kQuadChrome0122_19IndSize = 31722;    //  Largest subscript
extern const uint32 kQuadChromeIndSize = kQuadChrome0122_19IndSize; // Source-agnostic named constant
static const uint32 kQuadChrome0122_19Ind[kQuadChrome0122_19IndSize] = {
  // [0000]
  0x00000000, 0x00000000, 0x08040709, 0x00000a24,   // -- --  bg.ru.uk_444 mk.un.un_900
  0x06000c13, 0x1a6b1cee, 0x0000131c, 0x04523508,   // sv.de.un_650 id.ceb.tl_422  et.un.un_800 zu.ha.fi_443
  0x236e05ec, 0x00000415, 0x2d162908, 0x03003f08,   // fr.hmn.ca_644 fi.un.un_700  sl.hr.sk_443 af.nl.un_430
  0x1c090daf, 0x00000d1c, 0x281e1c05, 0x13000914,   // ne.hi.mr_655 ne.un.un_800  id.ms.sw_333 hi.bh.un_660
  // [0010]
  0x00002815, 0x21520ea4, 0x0000111c, 0x0000181c,   // sw.un.un_700 is.ha.jw_433  ro.un.un_800 ga.un.un_800
  0x0000271c, 0x02212013, 0x06030ca4, 0x1f2864af,   // gd.un.un_800 sq.jw.da_665  sv.nl.de_433 lg.sw.cy_655
  0x05190b08, 0x00001215, 0x25131a07, 0x00000d15,   // es.gl.fr_443 hu.un.un_700  tl.et.eu_432 cs.un.un_700
  0x00002b15, 0x64005219, 0x11000721, 0x11001f18,   // vi.un.un_700 ha.lg.un_750  it.ro.un_860 cy.ro.un_740
  // [0020]
  0x19000b08, 0x00000724, 0x0000021c, 0x09000d21,   // es.gl.un_430 bg.un.un_900  da.un.un_800 ne.hi.un_860
  0x3216170e, 0x17163214, 0x11356805, 0x211611ee,   // sr.hr.bs_555 bs.hr.sr_666  ig.zu.ro_333 ro.hr.jw_422
  0x00002b1c, 0x00000f1c, 0x00001903, 0x64075204,   // vi.un.un_800 lv.un.un_800  gl.un.un_300 ha.it.lg_332
  0x0309060c, 0x040810ee, 0x00001115, 0x09003f0d,   // de.pl.nl_543 be.uk.ru_422  ro.un.un_700 af.pl.un_540
  // [0030]
  0x16092d5a, 0x0e0307a0, 0x00004a06, 0x55005308,   // sk.pl.hr_553 it.nl.is_322  yo.un.un_400 ht.rw.un_430
  0x21001e05, 0x0000090f, 0x0000050a, 0x00000701,   // ms.jw.un_330 pl.un.un_600  fr.un.un_500 it.un.un_200
  0x00002d1c, 0x00000115, 0x32171614, 0x32161714,   // sk.un.un_800 iw.un.un_700  hr.sr.bs_666 sr.hr.bs_666
  0x18002723, 0x00002115, 0x2d000d1b, 0x211812af,   // gd.ga.un_880 fa.un.un_700  cs.sk.un_770 ur.ar.fa_655
  // [0040]
  0x64351aad, 0x0000520f, 0x171632a4, 0x25196ba0,   // tl.zu.lg_643 ha.un.un_600  bs.hr.sr_433 ceb.gl.eu_322
  0x08030208, 0x532b1f0c, 0x00002724, 0x1b321704,   // da.nl.no_443 cy.vi.ht_543  gd.un.un_900 sr.bs.tr_332
  0x00001006, 0x0400110c, 0x0000080f, 0x2a1220a7,   // be.un.un_400 ro.ru.un_530  no.un.un_600 sq.hu.mt_532
  0x00000124, 0x0e210804, 0x21001213, 0x0000280f,   // en.un.un_900 no.jw.is_332  ur.fa.un_650 sw.un.un_600
  // [0050]
  0x06030cad, 0x0000011c, 0x1716320e, 0x35060a0c,   // sv.nl.de_643 en.un.un_800  bs.hr.sr_555 pt.de.zu_543
  0x09001307, 0x3b3117a0, 0x08040708, 0x1e001c14,   // bh.hi.un_420 sr.az.so_322  bg.ru.uk_443 id.ms.un_660
  0x2d092507, 0x1b00311a, 0x6b1011ec, 0x52352808,   // eu.pl.sk_432 az.tr.un_760  ro.lt.ceb_644 sw.zu.ha_443
  0x3217160e, 0x0000351c, 0x130d0912, 0x02000808,   // hr.sr.bs_555 zu.un.un_800  hi.ne.bh_654 no.da.un_430
  // [0060]
  0x211812ad, 0x0000120f, 0x042125ee, 0x0000091c,   // ur.ar.fa_643 hu.un.un_600  eu.jw.fi_422 pl.un.un_800
  0x12001822, 0x0000121c, 0x4a006e08, 0x321617af,   // ar.ur.un_870 hu.un.un_800  hmn.yo.un_430 sr.hr.bs_655
  0x27001822, 0x00006e15, 0x0000020f, 0x181221af,   // ga.gd.un_870 hmn.un.un_700  da.un.un_600 fa.ur.ar_655
  0x10110408, 0x17080408, 0x11253508, 0x0c08020d,   // ru.ro.be_443 ru.uk.sr_443  zu.eu.ro_443 da.no.sv_554
  // [0070]
  0x0f006e0c, 0x00001001, 0x00001c0f, 0x00000a15,   // hmn.lv.un_530 be.un.un_200  mr.un.un_600 pt.un.un_700
  0x00001315, 0x1c001307, 0x1c001305, 0x0000211c,   // bh.un.un_700 bh.mr.un_420  bh.mr.un_330 jw.un.un_800
  0x080225ee, 0x00003b15, 0x0000290f, 0x00000e15,   // eu.da.no_422 so.un.un_700  sl.un.un_600 is.un.un_700
  0x0100240d, 0x171632a9, 0x31001b13, 0x0704080d,   // yi.iw.un_540 bs.hr.sr_544  tr.az.un_650 uk.ru.bg_554
  // [0080]
  0x1f002a13, 0x0000070f, 0x0c080214, 0x1800271a,   // mt.cy.un_650 bg.un.un_600  da.no.sv_666 gd.ga.un_760
  0x0000100f, 0x00003115, 0x00003124, 0x0000110f,   // be.un.un_600 az.un.un_700  az.un.un_900 ro.un.un_600
  0x00001703, 0x311b03a9, 0x64006e07, 0x00000e0f,   // sr.un.un_300 nl.tr.az_544  hmn.lg.un_420 is.un.un_600
  0x2700181b, 0x17003204, 0x00001c01, 0x11040705,   // ga.gd.un_770 bs.sr.un_320  id.un.un_200 bg.ru.ro_333
  // [0090]
  0x27001814, 0x00004a0f, 0x2a281804, 0x31080c08,   // ga.gd.un_660 yo.un.un_600  ga.sw.mt_332 sv.no.az_443
  0x120c08af, 0x011a29a4, 0x080c3507, 0x520164ee,   // no.sv.hu_655 sl.tl.en_433  zu.sv.no_432 lg.en.ha_422
  0x00000715, 0x2a3b5307, 0x00000915, 0x16320d0c,   // bg.un.un_700 ht.so.mt_432  pl.un.un_700 cs.bs.hr_543
  0x00001a15, 0x320f0305, 0x08005308, 0x00002315,   // tl.un.un_700 nl.lv.bs_333  ht.no.un_430 ca.un.un_700
  // [00a0]
  0x21001819, 0x080a1707, 0x190b0aa4, 0x552132a0,   // ar.fa.un_750 sr.mk.uk_432  pt.es.gl_433 bs.jw.rw_322
  0x0000521c, 0x130d09af, 0x04253508, 0x10041ca0,   // ha.un.un_800 hi.ne.bh_655  zu.eu.fi_443 id.fi.lt_322
  0x0827180c, 0x00000a1c, 0x05042aa0, 0x00000b15,   // ga.gd.no_543 pt.un.un_800  mt.fi.fr_322 bn.un.un_700
  0x10080c0c, 0x00002524, 0x0a1707a9, 0x070a04af,   // sv.no.lt_543 eu.un.un_900  bg.sr.mk_544 ru.mk.bg_655
  // [00b0]
  0x3f03280d, 0x101120a9, 0x08020eaf, 0x07000a1a,   // sw.nl.af_554 sq.ro.lt_544  is.da.no_655 mk.bg.un_760
  0x00005515, 0x2d130855, 0x04110712, 0x21001218,   // rw.un.un_700 no.et.sk_442  bg.ro.ru_654 ur.fa.un_740
  0x35002812, 0x00001e01, 0x13090da9, 0x1a003522,   // sw.zu.un_640 ms.un.un_200  ne.hi.bh_544 zu.tl.un_870
  0x13090dec, 0x3f130313, 0x00002415, 0x080417af,   // ne.hi.bh_644 nl.et.af_665  yi.un.un_700 sr.ru.uk_655
  // [00c0]
  0x272821a9, 0x2508060c, 0x13000905, 0x00001601,   // jw.sw.gd_544 de.no.eu_543  hi.bh.un_330 hr.un.un_200
  0x07170a13, 0x070a10ee, 0x06002504, 0x2d003b04,   // mk.sr.bg_665 be.mk.bg_422  eu.de.un_320 so.sk.un_320
  0x00000b1c, 0x03003f1a, 0x17040aec, 0x181a6bad,   // bn.un.un_800 af.nl.un_760  mk.ru.sr_644 ceb.tl.ga_643
  0x3f040512, 0x16003207, 0x321716a4, 0x13000922,   // fr.fi.af_654 bs.hr.un_420  hr.sr.bs_433 hi.bh.un_870
  // [00d0]
  0x20004a0e, 0x28055304, 0x17163205, 0x20002522,   // yo.sq.un_550 ht.fr.sw_332  bs.hr.sr_333 eu.sq.un_870
  0x1c000909, 0x2100121a, 0x04001119, 0x0000210f,   // hi.mr.un_440 ur.fa.un_760  ro.ru.un_750 fa.un.un_600
  0x03023fa0, 0x0e000813, 0x532801a4, 0x20252804,   // af.da.nl_322 no.is.un_650  en.sw.ht_433 sw.eu.sq_332
  0x1c1309ec, 0x1e001c02, 0x536428ee, 0x2a000705,   // hi.bh.mr_644 id.ms.un_220  sw.lg.ht_422 it.mt.un_330
  // [00e0]
  0x10040107, 0x00002d0f, 0x17040813, 0x06000e08,   // en.fi.lt_432 sk.un.un_600  uk.ru.sr_665 is.de.un_430
  0x00001a06, 0x00000703, 0x3510010c, 0x0000050f,   // tl.un.un_400 it.un.un_300  en.lt.zu_543 fr.un.un_600
  0x00000815, 0x04070a09, 0x0e25100c, 0x00000f15,   // uk.un.un_700 mk.bg.ru_444  lt.eu.is_543 lv.un.un_700
  0x0e00020d, 0x01000608, 0x00001e03, 0x52000104,   // da.is.un_540 de.en.un_430  ms.un.un_300 en.ha.un_320
  // [00f0]
  0x1b3531ad, 0x00002015, 0x00000c15, 0x0000030f,   // az.zu.tr_643 sq.un.un_700  sv.un.un_700 nl.un.un_600
  0x25042907, 0x18006b04, 0x00002824, 0x00001815,   // sl.fi.eu_432 ceb.ga.un_320  sw.un.un_900 ar.un.un_700
  0x28000104, 0x13641a0c, 0x32003507, 0x6b061fa0,   // en.sw.un_320 tl.lg.et_543  zu.bs.un_420 cy.de.ceb_322
  0x00005203, 0x1800352c, 0x32171602, 0x00002b0f,   // ha.un.un_300 zu.ga.un_990  hr.sr.bs_222 vi.un.un_600
  // [0100]
  0x04001309, 0x00001c06, 0x00002515, 0x0a070407,   // et.fi.un_440 id.un.un_400  eu.un.un_700 ru.bg.mk_432
  0x00002b24, 0x1300090e, 0x00000c0a, 0x1c090da4,   // vi.un.un_900 hi.bh.un_550  sv.un.un_500 ne.hi.mr_433
  0x35285509, 0x1a556ba6, 0x04001e04, 0x1e001c0e,   // rw.sw.zu_444 ceb.rw.tl_521  ms.fi.un_320 id.ms.un_550
  0x00002101, 0x282a180d, 0x556410a4, 0x01002413,   // jw.un.un_200 ga.mt.sw_554  lt.lg.rw_433 yi.iw.un_650
  // [0110]
  0x00001015, 0x4a1b1007, 0x10000822, 0x0a0407ec,   // lt.un.un_700 lt.tr.yo_432  uk.be.un_870 bg.ru.mk_644
  0x00001f15, 0x00001603, 0x1c320da0, 0x00001224,   // cy.un.un_700 hr.un.un_300  cs.bs.id_322 ur.un.un_900
  0x00001901, 0x10641104, 0x16002904, 0x0000250f,   // gl.un.un_200 ro.lg.lt_332  sl.hr.un_320 eu.un.un_600
  0x0000310f, 0x1c556804, 0x0000251c, 0x32171605,   // az.un.un_600 ig.rw.id_332  eu.un.un_800 hr.sr.bs_333
  // [0120]
  0x31080ea0, 0x641355ad, 0x00006b06, 0x00003f03,   // is.no.az_322 rw.et.lg_643  ceb.un.un_400 af.un.un_300
  0x211218af, 0x00000e1c, 0x64003514, 0x091c13a4,   // ar.ur.fa_655 is.un.un_800  zu.lg.un_660 bh.mr.hi_433
  0x13000908, 0x00002b0a, 0x01002419, 0x32171609,   // hi.bh.un_430 vi.un.un_500  yi.iw.un_750 hr.sr.bs_444
  0x311b0408, 0x1b1f1a04, 0x27351b07, 0x040810a9,   // fi.tr.az_443 tl.cy.tr_332  tr.zu.gd_432 be.uk.ru_544
  // [0130]
  0x350e1b08, 0x1c352105, 0x16002919, 0x0000680f,   // tr.is.zu_443 jw.zu.id_333  sl.hr.un_750 ig.un.un_600
  0x0a0411af, 0x00006815, 0x35004a05, 0x1e0208a4,   // ro.ru.mk_655 ig.un.un_700  yo.zu.un_330 no.da.ms_433
  0x01321704, 0x0a071714, 0x170a0708, 0x55686407,   // sr.bs.en_332 sr.bg.mk_666  bg.mk.sr_443 lg.ig.rw_432
  0x00000215, 0x1b25350b, 0x25006b09, 0x0e351b12,   // da.un.un_700 zu.eu.tr_542  ceb.eu.un_440 tr.zu.is_654
  // [0140]
  0x32001602, 0x2a186b0c, 0x00002b2d, 0x0706310c,   // hr.bs.un_220 ceb.ga.mt_543  vi.un.un_A00 az.de.it_543
  0x00000b01, 0x270e1b60, 0x64006807, 0x20005304,   // es.un.un_200 tr.is.gd_664  ig.lg.un_420 ht.sq.un_320
  0x2d123b07, 0x0d01030c, 0x1c000b02, 0x55131005,   // so.hu.sk_432 nl.en.cs_543  es.id.un_220 lt.et.rw_333
  0x04001007, 0x281a130c, 0x1b0e2509, 0x08110407,   // be.ru.un_420 et.tl.sw_543  eu.is.tr_444 fi.ro.no_432
  // [0150]
  0x10000419, 0x13000b04, 0x04000a07, 0x0400081b,   // fi.lt.un_750 es.et.un_320  mk.ru.un_420 uk.ru.un_770
  0x1800211a, 0x0c251b0c, 0x0c052a05, 0x03005507,   // fa.ar.un_760 tr.eu.sv_543  mt.fr.sv_333 rw.nl.un_420
  0x0000241c, 0x0000242d, 0x35051b0c, 0x1200211a,   // yi.un.un_800 yi.un.un_A00  tr.fr.zu_543 fa.ur.un_760
  0x09000d05, 0x1e001c07, 0x4a006822, 0x4a3f030c,   // ne.hi.un_330 id.ms.un_420  ig.yo.un_870 nl.af.yo_543
  // [0160]
  0x08001022, 0x0d172dee, 0x0000110a, 0x0000080a,   // be.uk.un_870 sk.sr.cs_422  ro.un.un_500 no.un.un_500
  0x20283507, 0x172d29a4, 0x023f035a, 0x25351b12,   // zu.sw.sq_432 sl.sk.sr_433  nl.af.da_553 tr.zu.eu_654
  0x0000200f, 0x311b3504, 0x19000b02, 0x2d000d0e,   // sq.un.un_600 zu.tr.az_332  es.gl.un_220 cs.sk.un_550
  0x0a040804, 0x00000c0f, 0x3f003b02, 0x00001c15,   // uk.ru.mk_332 sv.un.un_600  so.af.un_220 mr.un.un_700
  // [0170]
  0x13040ea0, 0x07080408, 0x0d1b0e0c, 0x556b2807,   // is.fi.et_322 ru.uk.bg_443  is.tr.cs_543 sw.ceb.rw_432
  0x0000180a, 0x06001809, 0x00005301, 0x12000e0d,   // ar.un.un_500 ga.de.un_440  ht.un.un_200 is.hu.un_540
  0x04001711, 0x00001b24, 0x04000723, 0x31001b1b,   // sr.ru.un_630 tr.un.un_900  bg.ru.un_880 tr.az.un_770
  0x0a0417a4, 0x10000a0c, 0x12002120, 0x17163202,   // sr.ru.mk_433 pt.lt.un_530  fa.ur.un_850 bs.hr.sr_222
  // [0180]
  0x12002113, 0x1300042b, 0x1b00311b, 0x4a6b6804,   // fa.ur.un_650 fi.et.un_980  az.tr.un_770 ig.ceb.yo_332
  0x090a13ee, 0x04070a0c, 0x08000c13, 0x00000a0a,   // et.pt.pl_422 mk.bg.ru_543  sv.no.un_650 pt.un.un_500
  0x08040a0c, 0x0c060e07, 0x0a190b04, 0x04081705,   // mk.ru.uk_543 is.de.sv_432  es.gl.pt_332 sr.uk.ru_333
  0x12006408, 0x12000a09, 0x00005503, 0x00005506,   // lg.hu.un_430 pt.hu.un_440  rw.un.un_300 rw.un.un_400
  // [0190]
  0x04001008, 0x17000a0d, 0x0000060a, 0x0000112d,   // be.ru.un_430 mk.sr.un_540  de.un.un_500 ro.un.un_A00
  0x112a010b, 0x17000a19, 0x0000100a, 0x00002a03,   // en.mt.ro_542 mk.sr.un_750  be.un.un_500 mt.un.un_300
  0x0000040f, 0x18002113, 0x11002804, 0x0e080cad,   // fi.un.un_600 fa.ar.un_650  sw.ro.un_320 sv.no.is_643
  0x2d000c04, 0x00006806, 0x64002805, 0x21001221,   // sv.sk.un_320 ig.un.un_400  sw.lg.un_330 ur.fa.un_860
  // [01a0]
  0x1100041a, 0x00001701, 0x0d000905, 0x0c08020e,   // ru.ro.un_760 sr.un.un_200  hi.ne.un_330 da.no.sv_555
  0x040a1704, 0x311e1c04, 0x641e2807, 0x2100070d,   // sr.mk.ru_332 id.ms.az_332  sw.ms.lg_432 it.jw.un_540
  0x0000180f, 0x00000f0f, 0x091c1312, 0x1c001308,   // ar.un.un_600 lv.un.un_600  bh.mr.hi_654 bh.mr.un_430
  0x00002d15, 0x18001212, 0x1700110d, 0x1c0913ac,   // sk.un.un_700 ur.ar.un_640  ro.sr.un_540 bh.hi.mr_632
  // [01b0]
  0x00003f15, 0x0b230507, 0x0a0408ad, 0x05002305,   // af.un.un_700 fr.ca.es_432  uk.ru.mk_643 ca.fr.un_330
  0x00003b0f, 0x08001009, 0x1c0913af, 0x033f13ad,   // so.un.un_600 be.uk.un_440  bh.hi.mr_655 et.af.nl_643
  0x041005a4, 0x00002a15, 0x27001f05, 0x04001013,   // fr.lt.fi_433 mt.un.un_700  cy.gd.un_330 be.ru.un_650
  0x0000680a, 0x122118ec, 0x07642a0e, 0x21001c08,   // ig.un.un_500 ar.fa.ur_644  mt.lg.it_555 id.jw.un_430
  // [01c0]
  0x00006e06, 0x07002a22, 0x04001322, 0x6400352a,   // hmn.un.un_400 mt.it.un_870  et.fi.un_870 zu.lg.un_970
  0x13090d14, 0x00006e1c, 0x0000010f, 0x13003b12,   // ne.hi.bh_666 hmn.un.un_800  en.un.un_600 so.et.un_640
  0x321629a9, 0x352018a4, 0x19000b07, 0x090d1caf,   // sl.hr.bs_544 ga.sq.zu_433  es.gl.un_420 mr.ne.hi_655
  0x31001b12, 0x00002a24, 0x09001313, 0x040a0705,   // tr.az.un_640 mt.un.un_900  bh.hi.un_650 bg.mk.ru_333
  // [01d0]
  0x00000d0f, 0x1f3f27a4, 0x13091ca9, 0x55006422,   // cs.un.un_600 gd.af.cy_433  mr.hi.bh_544 lg.rw.un_870
  0x35005513, 0x122b200c, 0x00002d0a, 0x10000835,   // rw.zu.un_650 sq.vi.hu_543  sk.un.un_500 uk.be.un_A90
  0x03003f2b, 0x04100812, 0x1e1c21ec, 0x2400012b,   // af.nl.un_980 uk.be.ru_654  jw.id.ms_644 iw.yi.un_980
  0x2a000723, 0x321617a9, 0x3b006e07, 0x0000190a,   // it.mt.un_880 sr.hr.bs_544  hmn.so.un_420 gl.un.un_500
  // [01e0]
  0x00006b03, 0x3f0325a7, 0x0000101c, 0x0e0608a4,   // ceb.un.un_300 eu.nl.af_532  lt.un.un_800 no.de.is_433
  0x00002715, 0x00001003, 0x09001f12, 0x04002314,   // gd.un.un_700 be.un.un_300  cy.pl.un_640 ca.fi.un_660
  0x00000706, 0x00006e24, 0x040613a0, 0x3f080208,   // it.un.un_400 hmn.un.un_900  et.de.fi_322 da.no.af_443
  0x0000060f, 0x0000030a, 0x0f645513, 0x200304ee,   // de.un.un_600 nl.un.un_500  rw.lg.lv_665 fi.nl.sq_422
  // [01f0]
  0x1304200c, 0x1e211c12, 0x643f0307, 0x07000a1b,   // sq.fi.et_543 id.jw.ms_654  nl.af.lg_432 mk.bg.un_770
  0x17001602, 0x201904ee, 0x0000350f, 0x13002019,   // hr.sr.un_220 fi.gl.sq_422  zu.un.un_600 sq.et.un_750
  0x35002807, 0x2100120d, 0x00000e0a, 0x1e211c11,   // sw.zu.un_420 ur.fa.un_540  is.un.un_500 id.jw.ms_653
  0x55642509, 0x530523a7, 0x1c000914, 0x29002a19,   // eu.lg.rw_444 ca.fr.ht_532  hi.mr.un_660 mt.sl.un_750
  // [0200]
  0x05022d0c, 0x0000311c, 0x010c060c, 0x1f1218ee,   // sk.da.fr_543 az.un.un_800  de.sv.en_543 ga.hu.cy_422
  0x0600210c, 0x00005324, 0x0b133ba4, 0x0b0a1905,   // jw.de.un_530 ht.un.un_900  so.et.es_433 gl.pt.es_333
  0x0723190c, 0x2a1716eb, 0x3f190b09, 0x351a27ad,   // gl.ca.it_543 hr.sr.mt_662  es.gl.af_444 gd.tl.zu_643
  0x6400551a, 0x00001a0f, 0x0d0913a0, 0x0000201c,   // rw.lg.un_760 tl.un.un_600  bh.hi.ne_322 sq.un.un_800
  // [0210]
  0x190a08a4, 0x07002a13, 0x27003508, 0x0705010c,   // no.pt.gl_433 mt.it.un_650  zu.gd.un_430 en.fr.it_543
  0x00001b15, 0x02000e1a, 0x00000b03, 0x080220ee,   // tr.un.un_700 is.da.un_760  es.un.un_300 sq.da.no_422
  0x1105010b, 0x1800270d, 0x2d0a2302, 0x13071fa0,   // en.fr.ro_542 gd.ga.un_540  ca.pt.sk_222 cy.it.et_322
  0x1a0435ac, 0x1a20530c, 0x00000806, 0x12006b19,   // zu.fi.tl_632 ht.sq.tl_543  uk.un.un_400 ceb.hu.un_750
  // [0220]
  0x0100051b, 0x08001014, 0x55110507, 0x033f0608,   // fr.en.un_770 be.uk.un_660  fr.ro.rw_432 de.af.nl_443
  0x18271faf, 0x040708a9, 0x0a00171b, 0x06002009,   // cy.gd.ga_655 uk.bg.ru_544  sr.mk.un_770 sq.de.un_440
  0x0b0a19a9, 0x0000270a, 0x130704a7, 0x00002a0f,   // gl.pt.es_544 gd.un.un_500  fi.it.et_532 mt.un.un_600
  0x00006e0a, 0x0b0a2aee, 0x0000281c, 0x1a1c21a4,   // hmn.un.un_500 mt.pt.es_422  sw.un.un_800 jw.id.tl_433
  // [0230]
  0x213f1c04, 0x072004a6, 0x0b0723a4, 0x180e27ad,   // id.af.jw_332 fi.sq.it_521  ca.it.es_433 gd.is.ga_643
  0x00003515, 0x072a0da4, 0x180b1907, 0x070a17ad,   // zu.un.un_700 cs.mt.it_433  gl.es.ga_432 sr.mk.bg_643
  0x0c642805, 0x1c001e07, 0x170411ec, 0x09005508,   // sw.lg.sv_333 ms.id.un_420  ro.ru.sr_644 rw.pl.un_430
  0x1300091b, 0x28005522, 0x0000230a, 0x17080414,   // hi.bh.un_770 rw.sw.un_870  ca.un.un_500 ru.uk.sr_666
  // [0240]
  0x1801270c, 0x06005319, 0x0000530a, 0x1000020d,   // gd.en.ga_543 ht.de.un_750  ht.un.un_500 da.lt.un_540
  0x1b316b11, 0x28005314, 0x53211c55, 0x0000531c,   // ceb.az.tr_653 ht.sw.un_660  id.jw.ht_442 ht.un.un_800
  0x0c350807, 0x0700110c, 0x29002d13, 0x17000a23,   // no.zu.sv_432 ro.bg.un_530  sk.sl.un_650 mk.sr.un_880
  0x090d1c12, 0x53050111, 0x2d0d1755, 0x17071104,   // mr.ne.hi_654 en.fr.ht_653  sr.cs.sk_442 ro.bg.sr_332
  // [0250]
  0x21121812, 0x0a00171a, 0x01000604, 0x1632175a,   // ar.ur.fa_654 sr.mk.un_760  de.en.un_320 sr.bs.hr_553
  0x080410a0, 0x1b2d0d08, 0x04070a05, 0x02000813,   // be.ru.uk_322 cs.sk.tr_443  mk.bg.ru_333 no.da.un_650
  0x08041705, 0x292d0d0d, 0x09001c12, 0x321617a4,   // sr.ru.uk_333 cs.sk.sl_554  mr.hi.un_640 sr.hr.bs_433
  0x0c000202, 0x00000424, 0x1c0d0912, 0x24000112,   // da.sv.un_220 ru.un.un_900  hi.ne.mr_654 iw.yi.un_640
  // [0260]
  0x4a1e1c13, 0x06002305, 0x13001b09, 0x1b002502,   // id.ms.yo_665 ca.de.un_330  tr.et.un_440 eu.tr.un_220
  0x00000b0f, 0x1f2d0d60, 0x132911ee, 0x00003203,   // bn.un.un_600 cs.sk.cy_664  ro.sl.et_422 bs.un.un_300
  0x20211b12, 0x1b132512, 0x21001214, 0x00004a03,   // tr.jw.sq_654 eu.et.tr_654  ur.fa.un_660 yo.un.un_300
  0x00003201, 0x521203ac, 0x1b004a19, 0x2d000d14,   // bs.un.un_200 nl.hu.ha_632  yo.tr.un_750 cs.sk.un_660
  // [0270]
  0x351310a4, 0x0e35640c, 0x0b0a19ee, 0x0308020c,   // lt.et.zu_433 lg.zu.is_543  gl.pt.es_422 da.no.nl_543
  0x521e1c12, 0x11236808, 0x3500021a, 0x18211212,   // id.ms.ha_654 ig.ca.ro_443  da.zu.un_760 ur.fa.ar_654
  0x07001120, 0x0000170a, 0x290f03a0, 0x0d003511,   // ro.bg.un_850 sr.un.un_500  nl.lv.sl_322 zu.cs.un_630
  0x04000302, 0x00002b06, 0x04001019, 0x2d000d1a,   // nl.fi.un_220 vi.un.un_400  be.ru.un_750 cs.sk.un_760
  // [0280]
  0x04004a09, 0x030964a0, 0x00006e0f, 0x2b050311,   // yo.fi.un_440 lg.pl.nl_322  hmn.un.un_600 nl.fr.vi_653
  0x04001708, 0x1b001213, 0x00001f0a, 0x3f05030c,   // sr.ru.un_430 hu.tr.un_650  cy.un.un_500 nl.fr.af_543
  0x0000212d, 0x32161709, 0x211e1caf, 0x0a0717a4,   // jw.un.un_A00 sr.hr.bs_444  id.ms.jw_655 sr.bg.mk_433
  0x20006b04, 0x64001e04, 0x17000704, 0x102d0d0e,   // ceb.sq.un_320 ms.lg.un_320  bg.sr.un_320 cs.sk.lt_555
  // [0290]
  0x1800120d, 0x0f310d0b, 0x17000c08, 0x08040aa4,   // ur.ar.un_540 cs.az.lv_542  sv.sr.un_430 mk.ru.uk_433
  0x0a171105, 0x01001c04, 0x290d3202, 0x3f003511,   // ro.sr.mk_333 id.en.un_320  bs.cs.sl_222 zu.af.un_630
  0x12002d0d, 0x00000301, 0x0000310a, 0x00003524,   // sk.hu.un_540 nl.un.un_200  az.un.un_500 zu.un.un_900
  0x3f0305ec, 0x1c090607, 0x080213a4, 0x120b2d0c,   // fr.nl.af_644 de.pl.id_432  et.da.no_433 sk.es.hu_543
  // [02a0]
  0x0000551c, 0x3f3b04a4, 0x20230aee, 0x00003b1c,   // rw.un.un_800 fi.so.af_433  pt.ca.sq_422 so.un.un_800
  0x040a07a4, 0x17163209, 0x00002a0a, 0x04001a19,   // bg.mk.ru_433 bs.hr.sr_444  mt.un.un_500 tl.fi.un_750
  0x0d1c1308, 0x07041007, 0x6b0403ee, 0x13003b1b,   // bh.mr.ne_443 be.ru.bg_432  nl.fi.ceb_422 so.et.un_770
  0x070a17a0, 0x1e1c09a4, 0x6b3f04ad, 0x00000615,   // sr.mk.bg_322 pl.id.ms_433  fi.af.ceb_643 de.un.un_700
  // [02b0]
  0x042b13ee, 0x11001c04, 0x2d29520c, 0x13033ba4,   // et.vi.fi_422 id.ro.un_320  ha.sl.sk_543 so.nl.et_433
  0x130d0960, 0x3b3f0312, 0x161e1c04, 0x12001905,   // hi.ne.bh_664 nl.af.so_654  id.ms.hr_332 gl.hu.un_330
  0x00001a1c, 0x016b3bad, 0x19000b14, 0x31001b22,   // tl.un.un_800 so.ceb.en_643  es.gl.un_660 tr.az.un_870
  0x11070414, 0x64133fa4, 0x00000515, 0x0000312d,   // ru.bg.ro_666 af.et.lg_433  fr.un.un_700 az.un.un_A00
  // [02c0]
  0x0a0717ee, 0x00003b24, 0x03000522, 0x2d0d3baf,   // sr.bg.mk_422 so.un.un_900  fr.nl.un_870 so.cs.sk_655
  0x00001a01, 0x55354a04, 0x1e4a1c60, 0x0800041a,   // tl.un.un_200 yo.zu.rw_332  id.yo.ms_664 ru.uk.un_760
  0x3f684a12, 0x163f0355, 0x2800272a, 0x08041005,   // yo.ig.af_654 nl.af.hr_442  gd.sw.un_970 be.ru.uk_333
  0x2b0535ee, 0x1f001822, 0x3200160e, 0x036e640e,   // zu.fr.vi_422 ga.cy.un_870  hr.bs.un_550 lg.hmn.nl_555
  // [02d0]
  0x00001b0f, 0x23000304, 0x643b1ca4, 0x0a1707a4,   // tr.un.un_600 nl.ca.un_320  id.so.lg_433 bg.sr.mk_433
  0x0000290a, 0x00001a03, 0x00005303, 0x0f001007,   // sl.un.un_500 tl.un.un_300  ht.un.un_300 lt.lv.un_420
  0x3f000321, 0x1e1c31af, 0x11040813, 0x190b0405,   // nl.af.un_860 az.id.ms_655  uk.ru.ro_665 fi.es.gl_333
  0x04070a11, 0x683f0408, 0x04001713, 0x00000a03,   // mk.bg.ru_653 fi.af.ig_443  sr.ru.un_650 mk.un.un_300
  // [02e0]
  0x043b1aac, 0x522b3b05, 0x32080c0e, 0x12002119,   // tl.so.fi_632 so.vi.ha_333  sv.no.bs_555 fa.ur.un_750
  0x043b6b07, 0x1a000702, 0x01002304, 0x1a006b05,   // ceb.so.fi_432 it.tl.un_220  ca.en.un_320 ceb.tl.un_330
  0x6b001a09, 0x64002102, 0x00003137, 0x17000819,   // tl.ceb.un_440 jw.lg.un_220  az.un.un_B00 uk.sr.un_750
  0x0000641c, 0x00003b01, 0x0000170f, 0x09001c09,   // lg.un.un_800 so.un.un_200  sr.un.un_600 mr.hi.un_440
  // [02f0]
  0x100f55ec, 0x0000130f, 0x17212a07, 0x3b0313a4,   // rw.lv.lt_644 et.un.un_600  mt.jw.sr_432 et.nl.so_433
  0x0000552d, 0x1e531a0b, 0x2400011a, 0x00001c03,   // rw.un.un_A00 tl.ht.ms_542  iw.yi.un_760 id.un.un_300
  0x0e001009, 0x00002501, 0x311b1ea0, 0x17001002,   // lt.is.un_440 eu.un.un_200  ms.tr.az_322 be.sr.un_220
  0x53033fac, 0x3200161b, 0x0c080255, 0x040711ad,   // af.nl.ht_632 hr.bs.un_770  da.no.sv_442 ro.bg.ru_643
  // [0300]
  0x0000520a, 0x32171604, 0x2a200807, 0x213b2813,   // ha.un.un_500 hr.sr.bs_332  no.sq.mt_432 sw.so.jw_665
  0x16001e04, 0x0d1c090c, 0x64002a05, 0x00001824,   // ms.hr.un_320 hi.mr.ne_543  mt.lg.un_330 ar.un.un_900
  0x03121607, 0x55286408, 0x112507a4, 0x32001623,   // hr.hu.nl_432 lg.sw.rw_443  it.eu.ro_433 hr.bs.un_880
  0x12032011, 0x04101704, 0x25203ba4, 0x211812ec,   // sq.nl.hu_653 sr.be.ru_332  so.sq.eu_433 ur.ar.fa_644
  // [0310]
  0x13000819, 0x171107a0, 0x09033fad, 0x20282507,   // no.et.un_750 it.ro.sr_322  af.nl.pl_643 eu.sw.sq_432
  0x0000550f, 0x20001b12, 0x64003521, 0x19000a12,   // rw.un.un_600 tr.sq.un_640  zu.lg.un_860 pt.gl.un_640
  0x040a0760, 0x08041711, 0x0a171002, 0x041310a7,   // bg.mk.ru_664 sr.ru.uk_653  be.sr.mk_222 lt.et.fi_532
  0x060a070d, 0x00001f1c, 0x3f001c04, 0x070a17af,   // it.pt.de_554 cy.un.un_800  id.af.un_320 sr.mk.bg_655
  // [0320]
  0x0700171b, 0x13000919, 0x02005207, 0x0a000714,   // sr.bg.un_770 hi.bh.un_750  ha.da.un_420 bg.mk.un_660
  0x00004a2d, 0x290d53af, 0x00005201, 0x09001304,   // yo.un.un_A00 ht.cs.sl_655  ha.un.un_200 bh.hi.un_320
  0x070a1108, 0x07041004, 0x21001307, 0x0c00021a,   // ro.mk.bg_443 be.ru.bg_332  et.jw.un_420 da.sv.un_760
  0x251c1a04, 0x105507a4, 0x13211c04, 0x18002714,   // tl.id.eu_332 it.rw.lt_433  id.jw.et_332 gd.ga.un_660
  // [0330]
  0x11000712, 0x2d001914, 0x27001833, 0x19000b05,   // it.ro.un_640 gl.sk.un_660  ga.gd.un_A70 es.gl.un_330
  0x10000512, 0x203b21ec, 0x0c041304, 0x21005219,   // fr.lt.un_640 jw.so.sq_644  et.fi.sv_332 ha.jw.un_750
  0x00000c06, 0x2a5510ec, 0x1b000c02, 0x2d001011,   // sv.un.un_400 lt.rw.mt_644  sv.tr.un_220 lt.sk.un_630
  0x0d16290c, 0x4a0a07a7, 0x00006b15, 0x23006807,   // sl.hr.cs_543 it.pt.yo_532  ceb.un.un_700 ig.ca.un_420
  // [0340]
  0x121729a4, 0x00000f24, 0x166e320c, 0x3f000212,   // sl.sr.hu_433 lv.un.un_900  bs.hmn.hr_543 da.af.un_640
  0x03004a07, 0x1800350e, 0x2b280608, 0x0c121fa9,   // yo.nl.un_420 zu.ga.un_550  de.sw.vi_443 cy.hu.sv_544
  0x0c000836, 0x1f523b0b, 0x00000624, 0x1025070c,   // no.sv.un_AA0 so.ha.cy_542  de.un.un_900 it.eu.lt_543
  0x2b3f0308, 0x05131eee, 0x28080c0b, 0x20170307,   // nl.af.vi_443 ms.et.fr_422  sv.no.sw_542 nl.sr.sq_432
  // [0350]
  0x0b000702, 0x2b230e08, 0x0000061c, 0x00002915,   // it.es.un_220 is.ca.vi_443  de.un.un_800 sl.un.un_700
  0x0900291b, 0x00001f24, 0x1f182707, 0x0e000807,   // sl.pl.un_770 cy.un.un_900  gd.ga.cy_432 no.is.un_420
  0x6e6b6804, 0x1e001c05, 0x00001c1c, 0x64521f14,   // ig.ceb.hmn_332 id.ms.un_330  mr.un.un_800 cy.ha.lg_666
  0x09002807, 0x32001723, 0x01001e08, 0x0000081c,   // sw.pl.un_420 sr.bs.un_880  ms.en.un_430 uk.un.un_800
  // [0360]
  0x29000f21, 0x1c000919, 0x00002701, 0x23192504,   // lv.sl.un_860 hi.mr.un_750  gd.un.un_200 eu.gl.ca_332
  0x0000041c, 0x00006415, 0x0000020a, 0x0600010d,   // fi.un.un_800 lg.un.un_700  da.un.un_500 en.de.un_540
  0x315535a7, 0x32001607, 0x0000350a, 0x24000120,   // zu.rw.az_532 hr.bs.un_420  zu.un.un_500 iw.yi.un_850
  0x08023fee, 0x091c0dec, 0x1c001e04, 0x1600290d,   // af.da.no_422 ne.mr.hi_644  ms.id.un_320 sl.hr.un_540
  // [0370]
  0x0c080213, 0x0a1704ec, 0x00002a06, 0x05001909,   // da.no.sv_665 ru.sr.mk_644  mt.un.un_400 gl.fr.un_440
  0x0411170c, 0x0e120d07, 0x12000e09, 0x321208ac,   // sr.ro.ru_543 cs.hu.is_432  is.hu.un_440 no.hu.bs_632
  0x021808a4, 0x0000252d, 0x03003f14, 0x1300041b,   // no.ga.da_433 eu.un.un_A00  af.nl.un_660 fi.et.un_770
  0x21525507, 0x122d0d14, 0x050601af, 0x3f002304,   // rw.ha.jw_432 cs.sk.hu_666  en.de.fr_655 ca.af.un_320
  // [0380]
  0x1b00310e, 0x07000a23, 0x2a1f1a0c, 0x0b132355,   // az.tr.un_550 mk.bg.un_880  tl.cy.mt_543 ca.et.es_442
  0x23000619, 0x21005318, 0x12000413, 0x27002104,   // de.ca.un_750 ht.jw.un_740  fi.hu.un_650 jw.gd.un_320
  0x00000b06, 0x08170a08, 0x00006403, 0x1707040d,   // es.un.un_400 mk.sr.uk_443  lg.un.un_300 ru.bg.sr_554
  0x0a001723, 0x070a1714, 0x3f00031a, 0x6b006805,   // sr.mk.un_880 sr.mk.bg_666  nl.af.un_760 ig.ceb.un_330
  // [0390]
  0x321617a0, 0x04170a07, 0x02003204, 0x1e001c23,   // sr.hr.bs_322 mk.sr.ru_432  bs.da.un_320 id.ms.un_880
  0x1e182707, 0x170229a0, 0x07040a12, 0x1e1c21af,   // gd.ga.ms_432 sl.da.sr_322  mk.ru.bg_654 jw.id.ms_655
  0x11000612, 0x07130407, 0x06350eec, 0x2a0c0207,   // de.ro.un_640 fi.et.it_432  is.zu.de_644 da.sv.mt_432
  0x00000c01, 0x04071712, 0x100f5208, 0x2700060e,   // sv.un.un_200 sr.bg.ru_654  ha.lv.lt_443 de.gd.un_550
  // [03a0]
  0x3500041b, 0x0e2910ad, 0x12001907, 0x64005213,   // fi.zu.un_770 lt.sl.is_643  gl.hu.un_420 ha.lg.un_650
  0x0d130960, 0x5200281a, 0x08020ca4, 0x00000a0f,   // hi.bh.ne_664 sw.ha.un_760  sv.da.no_433 pt.un.un_600
  0x00001906, 0x10000818, 0x190b0a5a, 0x0c000f08,   // gl.un.un_400 uk.be.un_740  pt.es.gl_553 lv.sv.un_430
  0x00001e0a, 0x31086b02, 0x28005219, 0x08022102,   // ms.un.un_500 ceb.no.az_222  ha.sw.un_750 jw.da.no_222
  // [03b0]
  0x122d0d13, 0x1700160e, 0x3f000314, 0x2d0d18a4,   // cs.sk.hu_665 hr.sr.un_550  nl.af.un_660 ga.cs.sk_433
  0x32171bee, 0x53643b11, 0x1c090d0e, 0x09001308,   // tr.sr.bs_422 so.lg.ht_653  ne.hi.mr_555 bh.hi.un_430
  0x1b114a02, 0x17002307, 0x0800020e, 0x00000d24,   // yo.ro.tr_222 ca.sr.un_420  da.no.un_550 cs.un.un_900
  0x1700071a, 0x040a0713, 0x3f0902ec, 0x31001b1a,   // bg.sr.un_760 bg.mk.ru_665  da.pl.af_644 tr.az.un_760
  // [03c0]
  0x214a1c0c, 0x2d000d12, 0x3f0c0855, 0x00005224,   // id.yo.jw_543 cs.sk.un_640  no.sv.af_442 ha.un.un_900
  0x01236b04, 0x071708a4, 0x2d0e0c04, 0x0408100e,   // ceb.ca.en_332 uk.sr.bg_433  sv.is.sk_332 be.uk.ru_555
  0x01002412, 0x05001902, 0x00001306, 0x2d000d21,   // yi.iw.un_640 gl.fr.un_220  bh.un.un_400 cs.sk.un_860
  0x3f082daf, 0x19000a05, 0x0f0b10ac, 0x0d000e19,   // sk.no.af_655 pt.gl.un_330  lt.es.lv_632 is.cs.un_750
  // [03d0]
  0x050911a7, 0x351a55ac, 0x1e211c08, 0x0000051c,   // ro.pl.fr_532 rw.tl.zu_632  id.jw.ms_443 fr.un.un_800
  0x211735a4, 0x17000c07, 0x09200aad, 0x170413ec,   // zu.sr.jw_433 sv.sr.un_420  pt.sq.pl_643 et.fi.sr_644
  0x0f003f04, 0x080c02ad, 0x3b010604, 0x0900130c,   // af.lv.un_320 da.sv.no_643  de.en.so_332 bh.hi.un_530
  0x0c08060c, 0x0d091caf, 0x0000240f, 0x35002505,   // de.no.sv_543 mr.hi.ne_655  yi.un.un_600 eu.zu.un_330
  // [03e0]
  0x280c21a0, 0x28001807, 0x08020c04, 0x06001313,   // jw.sv.sw_322 ga.sw.un_420  sv.da.no_332 et.de.un_650
  0x00002801, 0x0e0c08ad, 0x2100050d, 0x00002003,   // sw.un.un_200 no.sv.is_643  fr.jw.un_540 sq.un.un_300
  0x0d00090c, 0x03002108, 0x0a285507, 0x0d000909,   // hi.ne.un_530 jw.nl.un_430  rw.sw.pt_432 hi.ne.un_440
  0x0000530f, 0x0000200a, 0x01641211, 0x0b1101a4,   // ht.un.un_600 sq.un.un_500  hu.lg.en_653 en.ro.es_433
  // [03f0]
  0x203229ad, 0x2d000d18, 0x0d002d12, 0x53070aa4,   // sl.bs.sq_643 cs.sk.un_740  sk.cs.un_640 pt.it.ht_433
  0x64003f1a, 0x082d1307, 0x354a280c, 0x0000640a,   // af.lg.un_760 et.sk.no_432  sw.yo.zu_543 lg.un.un_500
  0x00002124, 0x11070209, 0x531a1ca0, 0x2d000d19,   // fa.un.un_900 da.it.ro_444  id.tl.ht_322 cs.sk.un_750
  0x0c0e3f0c, 0x23000d04, 0x1b645508, 0x13000422,   // af.is.sv_543 cs.ca.un_320  rw.lg.tr_443 fi.et.un_870

  // [0400]
  0x2d000d20, 0x1e005309, 0x0900060d, 0x13000935,   // cs.sk.un_850 ht.ms.un_440  de.pl.un_540 hi.bh.un_A90
  0x1f001a02, 0x0e2d3f0c, 0x0400131a, 0x53080209,   // tl.cy.un_220 af.sk.is_543  et.fi.un_760 da.no.ht_444
  0x080e0ca9, 0x351f1860, 0x216b1aa9, 0x25131209,   // sv.is.no_544 ga.cy.zu_664  tl.ceb.jw_544 hu.et.eu_444
  0x1c3521ee, 0x0a0711ee, 0x19000b1b, 0x080c6e04,   // jw.zu.id_422 ro.bg.mk_422  es.gl.un_770 hmn.sv.no_332
  // [0410]
  0x2a00210c, 0x2d0e0da4, 0x08003f08, 0x6b3b520c,   // jw.mt.un_530 cs.is.sk_433  af.no.un_430 ha.so.ceb_543
  0x12061e04, 0x20115508, 0x12002122, 0x03063fa0,   // ms.de.hu_332 rw.ro.sq_443  fa.ur.un_870 af.de.nl_322
  0x286435af, 0x29000d13, 0x350713a7, 0x1a115508,   // zu.lg.sw_655 cs.sl.un_650  et.it.zu_532 rw.ro.tl_443
  0x00000a06, 0x0d2718a4, 0x01230708, 0x0f171602,   // pt.un.un_400 ga.gd.cs_433  it.ca.en_443 hr.sr.lv_222
  // [0420]
  0x00006b0a, 0x080c3ba7, 0x3f030ca4, 0x2000550d,   // ceb.un.un_500 so.sv.no_532  sv.nl.af_433 rw.sq.un_540
  0x09001312, 0x07040804, 0x0e20550c, 0x2700180e,   // bh.hi.un_640 uk.ru.bg_332  rw.sq.is_543 ga.gd.un_550
  0x00001f0f, 0x07001212, 0x211a280c, 0x17001605,   // cy.un.un_600 hu.it.un_640  sw.tl.jw_543 hr.sr.un_330
  0x04212855, 0x280e5508, 0x2d0d06a4, 0x0817040c,   // sw.jw.fi_442 rw.is.sw_443  de.cs.sk_433 ru.sr.uk_543
  // [0430]
  0x64211ea0, 0x1b521ea0, 0x2a131ea0, 0x061e1c05,   // ms.jw.lg_322 ms.ha.tr_322  ms.et.mt_322 id.ms.de_333
  0x13000121, 0x28005513, 0x100804a4, 0x522a5508,   // en.et.un_860 rw.sw.un_650  ru.uk.be_433 rw.mt.ha_443
  0x3b003114, 0x04551ea0, 0x10550fa4, 0x1a006b1b,   // az.so.un_660 ms.rw.fi_322  lv.rw.lt_433 ceb.tl.un_770
  0x1a000804, 0x0400131b, 0x27010ba0, 0x186b08a0,   // no.tl.un_320 et.fi.un_770  es.en.gd_322 no.ceb.ga_322
  // [0440]
  0x02070860, 0x0d09130c, 0x29000604, 0x6b551ea4,   // no.it.da_664 bh.hi.ne_543  de.sl.un_320 ms.rw.ceb_433
  0x1b3f0802, 0x21001f12, 0x1e046402, 0x686b1a08,   // no.af.tr_222 cy.jw.un_640  lg.fi.ms_222 tl.ceb.ig_443
  0x08000c1b, 0x250e0707, 0x161029a4, 0x1a00550c,   // sv.no.un_770 it.is.eu_432  sl.lt.hr_433 rw.tl.un_530
  0x35313bad, 0x07190e02, 0x06033fa4, 0x07081004,   // so.az.zu_643 is.gl.it_222  af.nl.de_433 be.uk.bg_332
  // [0450]
  0x322d0d04, 0x0100241a, 0x1f033ba9, 0x2d0c1a04,   // cs.sk.bs_332 yi.iw.un_760  so.nl.cy_544 tl.sv.sk_332
  0x01003f11, 0x211c1eec, 0x080206a4, 0x31001b19,   // af.en.un_630 ms.id.jw_644  de.da.no_433 tr.az.un_750
  0x211e1c0d, 0x31001b23, 0x18002121, 0x21181212,   // id.ms.jw_554 tr.az.un_880  fa.ar.un_860 ur.ar.fa_654
  0x1e001c2c, 0x04170808, 0x040a1707, 0x1c211e12,   // id.ms.un_990 uk.sr.ru_443  sr.mk.ru_432 ms.jw.id_654
  // [0460]
  0x113155a4, 0x6b001a07, 0x6b3f1aad, 0x041707ec,   // rw.az.ro_433 tl.ceb.un_420  tl.af.ceb_643 bg.sr.ru_644
  0x210f100c, 0x0e1104a4, 0x1c0d0960, 0x0a1008a4,   // lt.lv.jw_543 fi.ro.is_433  hi.ne.mr_664 uk.be.mk_433
  0x17040a07, 0x04170a04, 0x11170408, 0x213b1e04,   // mk.ru.sr_432 mk.sr.ru_332  ru.sr.ro_443 ms.so.jw_332
  0x0c0b2909, 0x00004a0a, 0x04070a04, 0x1b0c120c,   // sl.es.sv_444 yo.un.un_500  mk.bg.ru_332 hu.sv.tr_543
  // [0470]
  0x04081004, 0x100a070c, 0x3f0f2312, 0x23001902,   // be.uk.ru_332 bg.mk.be_543  ca.lv.af_654 gl.ca.un_220
  0x0e00080e, 0x6b041aa4, 0x19120a0b, 0x1e162902,   // no.is.un_550 tl.fi.ceb_433  pt.hu.gl_542 sl.hr.ms_222
  0x1e003504, 0x0100231a, 0x0d002a19, 0x1c000412,   // zu.ms.un_320 ca.en.un_760  mt.cs.un_750 fi.id.un_640
  0x28002521, 0x0d001302, 0x11006b13, 0x0000070a,   // eu.sw.un_860 bh.ne.un_220  ceb.ro.un_650 it.un.un_500
  // [0480]
  0x3f002518, 0x211812a4, 0x322a16ec, 0x1e001c1a,   // eu.af.un_740 ur.ar.fa_433  hr.mt.bs_644 id.ms.un_760
  0x17080a05, 0x536b250c, 0x0f21130c, 0x2a120804,   // mk.uk.sr_333 eu.ceb.ht_543  et.jw.lv_543 no.hu.mt_332
  0x090711ee, 0x311b2d07, 0x3f000619, 0x04112108,   // ro.it.pl_422 sk.tr.az_432  de.af.un_750 jw.ro.fi_443
  0x1f001c07, 0x06000c04, 0x351f2107, 0x1e001c2b,   // id.cy.un_420 sv.de.un_320  jw.cy.zu_432 id.ms.un_980
  // [0490]
  0x0c0123af, 0x2d0d090c, 0x21000b08, 0x00001106,   // ca.en.sv_655 pl.cs.sk_543  es.jw.un_430 ro.un.un_400
  0x01002320, 0x13002920, 0x24000118, 0x01002312,   // ca.en.un_850 sl.et.un_850  iw.yi.un_740 ca.en.un_640
  0x28002b13, 0x17321660, 0x1329110c, 0x083f6407,   // vi.sw.un_650 hr.bs.sr_664  ro.sl.et_543 lg.af.no_432
  0x53002102, 0x3200210d, 0x550652a4, 0x6b001a22,   // jw.ht.un_220 jw.bs.un_540  ha.de.rw_433 tl.ceb.un_870
  // [04a0]
  0x0e6b07ad, 0x19000b20, 0x04001314, 0x21001813,   // it.ceb.is_643 es.gl.un_850  et.fi.un_660 ar.fa.un_650
  0x0e132aa4, 0x210e0811, 0x29001212, 0x00006b1c,   // mt.et.is_433 no.is.jw_653  hu.sl.un_640 ceb.un.un_800
  0x16321708, 0x17000408, 0x521c1e0b, 0x0a2d0d11,   // sr.bs.hr_443 fi.sr.un_430  ms.id.ha_542 cs.sk.pt_653
  0x2700060d, 0x0a0708a4, 0x0000171c, 0x0e640255,   // de.gd.un_540 uk.bg.mk_433  sr.un.un_800 da.lg.is_442
  // [04b0]
  0x0a07110e, 0x08002019, 0x1a033fa4, 0x080c060d,   // ro.bg.mk_555 sq.no.un_750  af.nl.tl_433 de.sv.no_554
  0x0e3b3f04, 0x00000c2d, 0x170f290c, 0x00002a1c,   // af.so.is_332 sv.un.un_A00  sl.lv.sr_543 mt.un.un_800
  0x00000c1c, 0x00005215, 0x0f0413ad, 0x35005205,   // sv.un.un_800 ha.un.un_700  et.fi.lv_643 ha.zu.un_330
  0x11182712, 0x0a001722, 0x00004a15, 0x1c211e0c,   // gd.ga.ro_654 sr.mk.un_870  yo.un.un_700 ms.jw.id_543
  // [04c0]
  0x12002121, 0x182112ad, 0x060c02a4, 0x0000190f,   // fa.ur.un_860 ur.fa.ar_643  da.sv.de_433 gl.un.un_600
  0x17002908, 0x1c090dec, 0x08021fa9, 0x01080208,   // sl.sr.un_430 ne.hi.mr_644  cy.da.no_544 da.no.en_443
  0x2325190b, 0x16190b0d, 0x131e1c14, 0x3b00071b,   // gl.eu.ca_542 es.gl.hr_554  id.ms.et_666 it.so.un_770
  0x03001904, 0x28006808, 0x010553a0, 0x040810ad,   // gl.nl.un_320 ig.sw.un_430  ht.fr.en_322 be.uk.ru_643
  // [04d0]
  0x0e08025a, 0x080c1fee, 0x6b001a2b, 0x03053f07,   // da.no.is_553 cy.sv.no_422  tl.ceb.un_980 af.fr.nl_432
  0x071c640c, 0x110d0f12, 0x02000819, 0x281801ee,   // lg.id.it_543 lv.cs.ro_654  no.da.un_750 en.ga.sw_422
  0x2a002922, 0x1000041b, 0x03042509, 0x040708a4,   // sl.mt.un_870 ru.be.un_770  eu.fi.nl_444 uk.bg.ru_433
  0x0c080204, 0x0804170c, 0x24000119, 0x00003f24,   // da.no.sv_332 sr.ru.uk_543  iw.yi.un_750 af.un.un_900
  // [04e0]
  0x2500011a, 0x08020ca9, 0x1c000312, 0x18211211,   // en.eu.un_760 sv.da.no_544  nl.id.un_640 ur.fa.ar_653
  0x29000c0b, 0x1c001302, 0x1b001c04, 0x0600011a,   // sv.sl.un_520 bh.mr.un_220  id.tr.un_320 en.de.un_760
  0x2d000d09, 0x2d103207, 0x202a030c, 0x06033faf,   // cs.sk.un_440 bs.lt.sk_432  nl.mt.sq_543 af.nl.de_655
  0x09001f09, 0x25001314, 0x1f003519, 0x32002d04,   // cy.pl.un_440 et.eu.un_660  zu.cy.un_750 sk.bs.un_320
  // [04f0]
  0x190b0a0e, 0x0d0b1908, 0x211b0c04, 0x32294aad,   // pt.es.gl_555 gl.es.cs_443  sv.tr.jw_332 yo.sl.bs_643
  0x3f001b19, 0x2723050c, 0x080410ec, 0x0d051104,   // tr.af.un_750 fr.ca.gd_543  be.ru.uk_644 ro.fr.cs_332
  0x2d000a2b, 0x3b001821, 0x0700041a, 0x2d001e04,   // pt.sk.un_980 ga.so.un_860  ru.bg.un_760 ms.sk.un_320
  0x160c2907, 0x13000c13, 0x0c080205, 0x28551faf,   // sl.sv.hr_432 sv.et.un_650  da.no.sv_333 cy.rw.sw_655
  // [0500]
  0x211e1cad, 0x3b1e1ca0, 0x08020c0c, 0x32161705,   // id.ms.jw_643 id.ms.so_322  sv.da.no_543 sr.hr.bs_333
  0x321e0304, 0x063f35ad, 0x52001c02, 0x1e5528ad,   // nl.ms.bs_332 zu.af.de_643  id.ha.un_220 sw.rw.ms_643
  0x20321705, 0x3b00190d, 0x0d000912, 0x29001602,   // sr.bs.sq_333 gl.so.un_540  hi.ne.un_640 hr.sl.un_220
  0x00001237, 0x13000918, 0x352831a7, 0x102d0d13,   // ur.un.un_B00 hi.bh.un_740  az.sw.zu_532 cs.sk.lt_665
  // [0510]
  0x190b0a14, 0x19000b09, 0x090d1cac, 0x4a020d07,   // pt.es.gl_666 es.gl.un_440  mr.ne.hi_632 cs.da.yo_432
  0x0c001f19, 0x131f070c, 0x523528ec, 0x10002913,   // cy.sv.un_750 it.cy.et_543  sw.zu.ha_644 sl.lt.un_650
  0x55003514, 0x090d1c13, 0x35000a05, 0x1e1c350e,   // zu.rw.un_660 mr.ne.hi_665  pt.zu.un_330 zu.id.ms_555
  0x09002a0c, 0x035505a4, 0x0000270f, 0x11355508,   // mt.pl.un_530 fr.rw.nl_433  gd.un.un_600 rw.zu.ro_443
  // [0520]
  0x0b20550c, 0x216b2aad, 0x5300041b, 0x040a1702,   // rw.sq.es_543 mt.ceb.jw_643  fi.ht.un_770 sr.mk.ru_222
  0x2d120da4, 0x08210e55, 0x0d001c0c, 0x2d0d1812,   // cs.hu.sk_433 is.jw.no_442  mr.ne.un_530 ga.cs.sk_654
  0x52006413, 0x2a321708, 0x00001303, 0x2d0d12ac,   // lg.ha.un_650 sr.bs.mt_443  bh.un.un_300 hu.cs.sk_632
  0x352d1705, 0x1f000618, 0x06030ca0, 0x3b25030b,   // sr.sk.zu_333 de.cy.un_740  sv.nl.de_322 nl.eu.so_542
  // [0530]
  0x08040aa0, 0x230b0a0d, 0x21080e0b, 0x352864a4,   // mk.ru.uk_322 pt.es.ca_554  is.no.jw_542 lg.sw.zu_433
  0x32162912, 0x08060ca0, 0x080407ec, 0x0e001207,   // sl.hr.bs_654 sv.de.no_322  bg.ru.uk_644 hu.is.un_420
  0x01002408, 0x07101707, 0x29202aa0, 0x00000401,   // yi.iw.un_430 sr.be.bg_432  mt.sq.sl_322 ru.un.un_200
  0x11252009, 0x2100120e, 0x00001c24, 0x13000d09,   // sq.eu.ro_444 ur.fa.un_550  mr.un.un_900 ne.bh.un_440
  // [0540]
  0x1c00090e, 0x0e6428a4, 0x5500640d, 0x270e0813,   // hi.mr.un_550 sw.lg.is_433  lg.rw.un_540 no.is.gd_665
  0x0704170c, 0x28556408, 0x09553fec, 0x522a6455,   // sr.ru.bg_543 lg.rw.sw_443  af.rw.pl_644 lg.mt.ha_442
  0x19000a14, 0x20004a08, 0x00006803, 0x29002a12,   // pt.gl.un_660 yo.sq.un_430  ig.un.un_300 mt.sl.un_640
  0x100804af, 0x190a1f05, 0x28005207, 0x0200080d,   // ru.uk.be_655 cy.pt.gl_333  ha.sw.un_420 no.da.un_540
  // [0550]
  0x04550509, 0x180104a7, 0x066e6ba9, 0x05255313,   // fr.rw.fi_444 fi.en.ga_532  ceb.hmn.de_544 ht.eu.fr_665
  0x04081013, 0x28556412, 0x12520412, 0x2300051a,   // be.uk.ru_665 lg.rw.sw_654  fi.ha.hu_654 fr.ca.un_760
  0x00000803, 0x55001c08, 0x23000a1a, 0x23000808,   // no.un.un_300 id.rw.un_430  pt.ca.un_760 no.ca.un_430
  0x1e1c0ca6, 0x52281f0c, 0x2d1c21ee, 0x2d0d2911,   // sv.id.ms_521 cy.sw.ha_543  jw.id.sk_422 sl.cs.sk_653
  // [0560]
  0x4a001913, 0x31080ca0, 0x1c006422, 0x12202aad,   // gl.yo.un_650 sv.no.az_322  lg.id.un_870 mt.sq.hu_643
  0x3f006408, 0x6e2a05ee, 0x051310ee, 0x09060302,   // lg.af.un_430 fr.mt.hmn_422  lt.et.fr_422 nl.de.pl_222
  0x07000a04, 0x1a002d04, 0x12006b05, 0x091c1307,   // mk.bg.un_320 sk.tl.un_320  ceb.hu.un_330 bh.mr.hi_432
  0x00006e03, 0x103b1ea0, 0x112a0508, 0x1716320c,   // hmn.un.un_300 ms.so.lt_322  fr.mt.ro_443 bs.hr.sr_543
  // [0570]
  0x17005312, 0x13090d05, 0x04070a0d, 0x21001c04,   // ht.sr.un_640 ne.hi.bh_333  mk.bg.ru_554 id.jw.un_320
  0x063f0313, 0x046435a0, 0x13091cec, 0x10020fa4,   // nl.af.de_665 zu.lg.fi_322  mr.hi.bh_644 lv.da.lt_433
  0x00005524, 0x3b001905, 0x090d13af, 0x00003b06,   // rw.un.un_900 gl.so.un_330  bh.ne.hi_655 so.un.un_400
  0x290c0812, 0x06016e08, 0x3b2a1c07, 0x100f0608,   // no.sv.sl_654 hmn.en.de_443  id.mt.so_432 de.lv.lt_443
  // [0580]
  0x00002301, 0x0501060c, 0x1732165a, 0x28556ead,   // ca.un.un_200 de.en.fr_543  hr.bs.sr_553 hmn.rw.sw_643
  0x06001b0c, 0x0e000508, 0x00000324, 0x1e1c2114,   // tr.de.un_530 fr.is.un_430  nl.un.un_900 jw.id.ms_666
  0x35551a13, 0x13000c0d, 0x6b641a0c, 0x1c001604,   // tl.rw.zu_665 sv.et.un_540  tl.lg.ceb_543 hr.id.un_320
  0x1c09130e, 0x23002702, 0x356b1aa9, 0x13033faf,   // bh.hi.mr_555 gd.ca.un_220  tl.ceb.zu_544 af.nl.et_655
  // [0590]
  0x211e1c08, 0x2118120d, 0x0d09130e, 0x100a13a4,   // id.ms.jw_443 ur.ar.fa_554  bh.hi.ne_555 et.pt.lt_433
  0x04281908, 0x1a1e1c14, 0x07041005, 0x2100680e,   // gl.sw.fi_443 id.ms.tl_666  be.ru.bg_333 ig.jw.un_550
  0x551a64a9, 0x29001b19, 0x3f080c09, 0x04284a07,   // lg.tl.rw_544 tr.sl.un_750  sv.no.af_444 yo.sw.fi_432
  0x211e1c13, 0x08040aee, 0x1e1c21a9, 0x25001e0d,   // id.ms.jw_665 mk.ru.uk_422  jw.id.ms_544 ms.eu.un_540
  // [05a0]
  0x210c080c, 0x21002714, 0x32001707, 0x52001e08,   // no.sv.jw_543 gd.jw.un_660  sr.bs.un_420 ms.ha.un_430
  0x19000b12, 0x040708ec, 0x32170daf, 0x132a075a,   // es.gl.un_640 uk.bg.ru_644  cs.sr.bs_655 it.mt.et_553
  0x0800100e, 0x1e000f21, 0x31001b0c, 0x091c0da7,   // be.uk.un_550 lv.ms.un_860  tr.az.un_530 ne.mr.hi_532
  0x3b551a09, 0x033f2a0c, 0x1100270d, 0x55003204,   // tl.rw.so_444 mt.af.nl_543  gd.ro.un_540 bs.rw.un_320
  // [05b0]
  0x1b006b04, 0x02003f0e, 0x1b003109, 0x1c001309,   // ceb.tr.un_320 af.da.un_550  az.tr.un_440 bh.mr.un_440
  0x19000b19, 0x23052d07, 0x06006e07, 0x2d0d2905,   // es.gl.un_750 sk.fr.ca_432  hmn.de.un_420 sl.cs.sk_333
  0x236e0508, 0x2d000d13, 0x271f0107, 0x182709a4,   // fr.hmn.ca_443 cs.sk.un_650  en.cy.gd_432 pl.gd.ga_433
  0x230105ad, 0x12255508, 0x0e020811, 0x120d2d12,   // fr.en.ca_643 rw.eu.hu_443  no.da.is_653 sk.cs.hu_654
  // [05c0]
  0x09271eee, 0x1c1a1ea0, 0x070a1708, 0x53001819,   // ms.gd.pl_422 ms.tl.id_322  sr.mk.bg_443 ga.ht.un_750
  0x55316809, 0x31001b21, 0x35641ca4, 0x0235080c,   // ig.az.rw_444 tr.az.un_860  id.lg.zu_433 no.zu.da_543
  0x556b640d, 0x2300050c, 0x080621a0, 0x31532108,   // lg.ceb.rw_554 fr.ca.un_530  jw.de.no_322 jw.ht.az_443
  0x5264080c, 0x55311ca4, 0x230a0513, 0x011a2704,   // no.lg.ha_543 id.az.rw_433  fr.pt.ca_665 gd.tl.en_332
  // [05d0]
  0x2d001220, 0x13000804, 0x55083513, 0x0a07170c,   // hu.sk.un_850 no.et.un_320  zu.no.rw_665 sr.bg.mk_543
  0x191a6b11, 0x041c2112, 0x31353baf, 0x3f0f10a9,   // ceb.tl.gl_653 jw.id.fi_654  so.zu.az_655 lt.lv.af_544
  0x23000104, 0x04200804, 0x0a081713, 0x05001904,   // en.ca.un_320 no.sq.fi_332  sr.uk.mk_665 gl.fr.un_320
  0x190b23af, 0x2a200704, 0x1218210c, 0x20080607,   // ca.es.gl_655 it.sq.mt_332  fa.ar.ur_543 de.no.sq_432
  // [05e0]
  0x00001b03, 0x3f060808, 0x04211c5a, 0x19090a07,   // tr.un.un_300 no.de.af_443  id.jw.fi_553 pt.pl.gl_432
  0x19000b0e, 0x29063508, 0x0c3f0305, 0x00003506,   // es.gl.un_550 zu.de.sl_443  nl.af.sv_333 zu.un.un_400
  0x0d091314, 0x0800101a, 0x552305ac, 0x3f00290b,   // bh.hi.ne_666 be.uk.un_760  fr.ca.rw_632 sl.af.un_520
  0x06000c0c, 0x07000504, 0x00006401, 0x2305010c,   // sv.de.un_530 fr.it.un_320  lg.un.un_200 en.fr.ca_543
  // [05f0]
  0x236e0607, 0x07170aa9, 0x093b1f05, 0x32001605,   // de.hmn.ca_432 mk.sr.bg_544  cy.so.pl_333 hr.bs.un_330
  0x283b1f0d, 0x171632af, 0x081f0608, 0x05001113,   // cy.so.sw_554 bs.hr.sr_655  de.cy.no_443 ro.fr.un_650
  0x3f00031b, 0x6e06280c, 0x17000808, 0x0d13095a,   // nl.af.un_770 sw.de.hmn_543  no.sr.un_430 hi.bh.ne_553
  0x1c0913a4, 0x09121813, 0x2100280c, 0x122118af,   // bh.hi.mr_433 ga.hu.pl_665  sw.jw.un_530 ar.fa.ur_655
  // [0600]
  0x2a07010b, 0x080c02a4, 0x286e2b07, 0x16080208,   // en.it.mt_542 da.sv.no_433  vi.hmn.sw_432 da.no.hr_443
  0x0400171a, 0x130608a7, 0x35072507, 0x08040713,   // sr.ru.un_760 no.de.et_532  eu.it.zu_432 bg.ru.uk_665
  0x11000813, 0x00002a01, 0x0a170714, 0x3f1206ad,   // no.ro.un_650 mt.un.un_200  bg.sr.mk_666 de.hu.af_643
  0x011a2112, 0x12001f1b, 0x35006414, 0x21006807,   // jw.tl.en_654 cy.hu.un_770  lg.zu.un_660 ig.jw.un_420
  // [0610]
  0x0000092d, 0x07001012, 0x10000f13, 0x0000031c,   // hi.un.un_A00 be.bg.un_640  lv.lt.un_650 nl.un.un_800
  0x0b04050c, 0x040a1705, 0x040810a6, 0x1e1c04a9,   // fr.fi.es_543 sr.mk.ru_333  be.uk.ru_521 fi.id.ms_544
  0x351c210e, 0x2d002905, 0x04002713, 0x21001c0d,   // jw.id.zu_555 sl.sk.un_330  gd.fi.un_650 id.jw.un_540
  0x31001b14, 0x64556ba4, 0x090d1c07, 0x27001823,   // tr.az.un_660 ceb.rw.lg_433  mr.ne.hi_432 ga.gd.un_880
  // [0620]
  0x23080208, 0x314a3507, 0x05250107, 0x043f3109,   // da.no.ca_443 zu.yo.az_432  en.eu.fr_432 az.af.fi_444
  0x21001821, 0x05000804, 0x182d0d14, 0x190b04ad,   // ar.fa.un_860 no.fr.un_320  cs.sk.ga_666 fi.es.gl_643
  0x0a041108, 0x01033f60, 0x1b003120, 0x55006819,   // ro.ru.mk_443 af.nl.en_664  az.tr.un_850 ig.rw.un_750
  0x0000040a, 0x2b6b01a9, 0x181b2007, 0x00001915,   // fi.un.un_500 en.ceb.vi_544  sq.tr.ga_432 gl.un.un_700
  // [0630]
  0x1f2912af, 0x120407a0, 0x0d1219a0, 0x35006819,   // hu.sl.cy_655 it.fi.hu_322  gl.hu.cs_322 ig.zu.un_750
  0x6b3b1c07, 0x1800270e, 0x35645355, 0x1a006b08,   // id.so.ceb_432 gd.ga.un_550  ht.lg.zu_442 ceb.tl.un_430
  0x17081008, 0x29321604, 0x0d091cec, 0x0701270c,   // be.uk.sr_443 hr.bs.sl_332  mr.hi.ne_644 gd.en.it_543
  0x18002808, 0x064a3505, 0x05004a04, 0x2000070c,   // sw.ga.un_430 zu.yo.de_333  yo.fr.un_320 it.sq.un_530
  // [0640]
  0x2b006e07, 0x0602070c, 0x1e1c21a0, 0x551153ee,   // hmn.vi.un_420 it.da.de_543  jw.id.ms_322 ht.ro.rw_422
  0x35000a12, 0x050b10a0, 0x00000206, 0x1b3b310c,   // pt.zu.un_640 lt.es.fr_322  da.un.un_400 az.so.tr_543
  0x06001e04, 0x312518a4, 0x1c000905, 0x101a0c12,   // ms.de.un_320 ga.eu.az_433  hi.mr.un_330 sv.tl.lt_654
  0x09001f13, 0x091c13a9, 0x3f64030d, 0x0a071707,   // cy.pl.un_650 bh.mr.hi_544  nl.lg.af_554 sr.bg.mk_432
  // [0650]
  0x64001314, 0x1c000d13, 0x0a0407a4, 0x01000704,   // et.lg.un_660 ne.mr.un_650  bg.ru.mk_433 it.en.un_320
  0x17321655, 0x32162509, 0x04000719, 0x0b13040c,   // hr.bs.sr_442 eu.hr.bs_444  bg.ru.un_750 fi.et.es_543
  0x2d0d1214, 0x120b040c, 0x2b4a0714, 0x071708ec,   // hu.cs.sk_666 fi.es.hu_543  it.yo.vi_666 uk.sr.bg_644
  0x17001018, 0x0e000219, 0x6b020811, 0x3b003104,   // be.sr.un_740 da.is.un_750  no.da.ceb_653 az.so.un_320
  // [0660]
  0x02211c0c, 0x19000b04, 0x21001008, 0x0d1c1311,   // id.jw.da_543 es.gl.un_320  lt.jw.un_430 bh.mr.ne_653
  0x190853ee, 0x00001324, 0x3b001021, 0x21026b07,   // ht.no.gl_422 bh.un.un_900  lt.so.un_860 ceb.da.jw_432
  0x321716a9, 0x321716a0, 0x0a000712, 0x09000d07,   // hr.sr.bs_544 hr.sr.bs_322  bg.mk.un_640 ne.hi.un_420
  0x17000a12, 0x1b252aa4, 0x12001812, 0x0000090a,   // mk.sr.un_640 mt.eu.tr_433  ar.ur.un_640 pl.un.un_500
  // [0670]
  0x1c090d60, 0x19110bee, 0x1b313bec, 0x52001a0c,   // ne.hi.mr_664 es.ro.gl_422  so.az.tr_644 tl.ha.un_530
  0x1b1e1c02, 0x0b0a0cee, 0x070a1709, 0x17033f04,   // id.ms.tr_222 sv.pt.es_422  sr.mk.bg_444 af.nl.sr_332
  0x080410ad, 0x1c005207, 0x32311b55, 0x3f000708,   // be.ru.uk_643 ha.id.un_420  tr.az.bs_442 it.af.un_430
  0x17070a08, 0x55642807, 0x13071212, 0x00003f0f,   // mk.bg.sr_443 sw.lg.rw_432  hu.it.et_654 af.un.un_600
  // [0680]
  0x0e000812, 0x2b001c07, 0x12002a07, 0x2b001c02,   // no.is.un_640 id.vi.un_420  mt.hu.un_420 id.vi.un_220
  0x53355208, 0x31121b07, 0x2d080204, 0x0c000808,   // ha.zu.ht_443 tr.hu.az_432  da.no.sk_332 no.sv.un_430
  0x1a0b6b08, 0x0b521e07, 0x1e005207, 0x0c0e02ee,   // ceb.es.tl_443 ms.ha.es_432  ha.ms.un_420 da.is.sv_422
  0x35522a05, 0x351c21a7, 0x1e1c35ee, 0x0c00081a,   // mt.ha.zu_333 jw.id.zu_532  zu.id.ms_422 no.sv.un_760
  // [0690]
  0x092d0d0e, 0x161f2702, 0x6e080eec, 0x19000b13,   // cs.sk.pl_555 gd.cy.hr_222  is.no.hmn_644 es.gl.un_650
  0x35646b07, 0x25001e04, 0x292d0d55, 0x0d091305,   // ceb.lg.zu_432 ms.eu.un_320  cs.sk.sl_442 bh.hi.ne_333
  0x0000071c, 0x171632a0, 0x55643504, 0x04081708,   // it.un.un_800 bs.hr.sr_322  zu.lg.rw_332 sr.uk.ru_443
  0x04170aa0, 0x32000108, 0x28526b08, 0x2d001704,   // mk.sr.ru_322 en.bs.un_430  ceb.ha.sw_443 sr.sk.un_320
  // [06a0]
  0x645535a4, 0x080a07a4, 0x10002508, 0x044a2502,   // zu.rw.lg_433 bg.mk.uk_433  eu.lt.un_430 eu.yo.fi_222
  0x20001c05, 0x19000b0c, 0x531a6b07, 0x13000909,   // id.sq.un_330 es.gl.un_530  ceb.tl.ht_432 hi.bh.un_440
  0x03003f0e, 0x53006b04, 0x0c000f04, 0x00001301,   // af.nl.un_550 ceb.ht.un_320  lv.sv.un_320 et.un.un_200
  0x2500521a, 0x53292da4, 0x0000130a, 0x09001c13,   // ha.eu.un_760 sk.sl.ht_433  bh.un.un_500 mr.hi.un_650
  // [06b0]
  0x355564af, 0x0c000e04, 0x256413a0, 0x1f001e13,   // lg.rw.zu_655 is.sv.un_320  et.lg.eu_322 ms.cy.un_650
  0x285329a0, 0x08001021, 0x130153a0, 0x0d00090e,   // sl.ht.sw_322 be.uk.un_860  ht.en.et_322 hi.ne.un_550
  0x35286404, 0x09002908, 0x051f0111, 0x642868ee,   // lg.sw.zu_332 sl.pl.un_430  en.cy.fr_653 ig.sw.lg_422
  0x1e55280c, 0x312d0907, 0x08000223, 0x091c0daf,   // sw.rw.ms_543 pl.sk.az_432  da.no.un_880 ne.mr.hi_655
  // [06c0]
  0x00005315, 0x25005208, 0x1700290b, 0x18120e5a,   // ht.un.un_700 ha.eu.un_430  sl.sr.un_520 is.hu.ga_553
  0x00005306, 0x210c1f0c, 0x2527180c, 0x1b001904,   // ht.un.un_400 cy.sv.jw_543  ga.gd.eu_543 gl.tr.un_320
  0x100408a4, 0x190d0b0c, 0x1300270c, 0x21001c02,   // uk.ru.be_433 es.cs.gl_543  gd.et.un_530 id.jw.un_220
  0x0e001b14, 0x051f010c, 0x1c0d0909, 0x10000821,   // tr.is.un_660 en.cy.fr_543  hi.ne.mr_444 uk.be.un_860
  // [06d0]
  0x060e0f0c, 0x201b2ba4, 0x08041007, 0x0d321604,   // lv.is.de_543 vi.tr.sq_433  be.ru.uk_432 hr.bs.cs_332
  0x00000d06, 0x31006b07, 0x19200b12, 0x0f000919,   // ne.un.un_400 ceb.az.un_420  es.sq.gl_654 pl.lv.un_750
  0x07002a02, 0x3f040313, 0x09001107, 0x0c000e1a,   // mt.it.un_220 nl.fi.af_665  ro.pl.un_420 is.sv.un_760
  0x033f040d, 0x25121807, 0x1c000d0c, 0x28001e04,   // fi.af.nl_554 ga.hu.eu_432  ne.mr.un_530 ms.sw.un_320
  // [06e0]
  0x092555a7, 0x2d090d0c, 0x121821ec, 0x00000524,   // rw.eu.pl_532 cs.pl.sk_543  fa.ar.ur_644 fr.un.un_900
  0x16092907, 0x0e020fa9, 0x08070a05, 0x2b002704,   // sl.pl.hr_432 lv.da.is_544  mk.bg.uk_333 gd.vi.un_320
  0x532520a4, 0x07041707, 0x190b0a05, 0x0a041707,   // sq.eu.ht_433 sr.ru.bg_432  pt.es.gl_333 sr.ru.mk_432
  0x17321604, 0x23181f04, 0x04002d08, 0x23070ba4,   // hr.bs.sr_332 cy.ga.ca_332  sk.fi.un_430 es.it.ca_433
  // [06f0]
  0x1c0d09ec, 0x0804170e, 0x250723a0, 0x06050111,   // hi.ne.mr_644 sr.ru.uk_555  ca.it.eu_322 en.fr.de_653
  0x072a19ee, 0x31001f05, 0x27001f0d, 0x0f001021,   // gl.mt.it_422 cy.az.un_330  cy.gd.un_540 lt.lv.un_860
  0x1f05010c, 0x170407a4, 0x0a001021, 0x110504ee,   // en.fr.cy_543 bg.ru.sr_433  be.mk.un_860 fi.fr.ro_422
  0x5300550c, 0x0a071702, 0x4a00532a, 0x2b001c12,   // rw.ht.un_530 sr.bg.mk_222  ht.yo.un_970 id.vi.un_640
  // [0700]
  0x0d122d55, 0x1c0d09af, 0x1b063f5a, 0x0a071104,   // sk.hu.cs_442 hi.ne.mr_655  af.de.tr_553 ro.bg.mk_332
  0x3b005202, 0x080407a4, 0x00002703, 0x213b1f08,   // ha.so.un_220 bg.ru.uk_433  gd.un.un_300 cy.so.jw_443
  0x2b001c0c, 0x290f2dad, 0x043113af, 0x0c080e0c,   // id.vi.un_530 sk.lv.sl_643  et.az.fi_655 is.no.sv_543
  0x2d2920af, 0x292d0da4, 0x53001308, 0x2a0413ad,   // sq.sl.sk_655 cs.sk.sl_433  et.ht.un_430 et.fi.mt_643
  // [0710]
  0x35080214, 0x08000c0d, 0x0c0413a4, 0x00003106,   // da.no.zu_666 sv.no.un_540  et.fi.sv_433 az.un.un_400
  0x3b0955af, 0x3213040c, 0x100964a4, 0x3b001f05,   // rw.pl.so_655 fi.et.bs_543  lg.pl.lt_433 cy.so.un_330
  0x0e001213, 0x281129af, 0x55683505, 0x1b312d08,   // hu.is.un_650 sl.ro.sw_655  zu.ig.rw_333 sk.az.tr_443
  0x160f13a4, 0x282a5207, 0x095525a4, 0x35006405,   // et.lv.hr_433 ha.mt.sw_432  eu.rw.pl_433 lg.zu.un_330
  // [0720]
  0x106e06a4, 0x081004a4, 0x0000230f, 0x1f002702,   // de.hmn.lt_433 ru.be.uk_433  ca.un.un_600 gd.cy.un_220
  0x642835a7, 0x09312008, 0x35006b04, 0x0b0a3ba4,   // zu.sw.lg_532 sq.az.pl_443  ceb.zu.un_320 so.pt.es_433
  0x0e2d090c, 0x17040807, 0x0a001108, 0x1b292d07,   // pl.sk.is_543 uk.ru.sr_432  ro.mk.un_430 sk.sl.tr_432
  0x0e000c02, 0x2a00180d, 0x13122aa4, 0x17000a09,   // sv.is.un_220 ga.mt.un_540  mt.hu.et_433 mk.sr.un_440
  // [0730]
  0x0c083fee, 0x202d0d14, 0x2d1f2708, 0x35000b08,   // af.no.sv_422 cs.sk.sq_666  gd.cy.sk_443 es.zu.un_430
  0x231e1c0c, 0x0e1a6b08, 0x121013a7, 0x2855640b,   // id.ms.ca_543 ceb.tl.is_443  et.lt.hu_532 lg.rw.sw_542
  0x071013ee, 0x1f00270d, 0x0000012d, 0x352d0d13,   // et.lt.it_422 gd.cy.un_540  en.un.un_A00 cs.sk.zu_665
  0x09001c08, 0x3b5552a7, 0x2d0413ad, 0x6e00532a,   // mr.hi.un_430 ha.rw.so_532  et.fi.sk_643 ht.hmn.un_970
  // [0740]
  0x1300091a, 0x03005212, 0x1200180e, 0x00000d03,   // hi.bh.un_760 ha.nl.un_640  ga.hu.un_550 cs.un.un_300
  0x13001c08, 0x095511ee, 0x0000102d, 0x12006b09,   // id.et.un_430 ro.rw.pl_422  lt.un.un_A00 ceb.hu.un_440
  0x00001e06, 0x08001113, 0x2a002304, 0x64002813,   // ms.un.un_400 ro.uk.un_650  ca.mt.un_320 sw.lg.un_650
  0x03003f12, 0x08020c02, 0x012d0d0e, 0x17551155,   // af.nl.un_640 sv.da.no_222  cs.sk.en_555 ro.rw.sr_442
  // [0750]
  0x070411af, 0x11645513, 0x060c07a0, 0x033f2707,   // ro.ru.bg_655 rw.lg.ro_665  it.sv.de_322 gd.af.nl_432
  0x171632ee, 0x0c232b08, 0x1100550e, 0x13000513,   // bs.hr.sr_422 vi.ca.sv_443  rw.ro.un_550 fr.et.un_650
  0x0a040708, 0x0e04060c, 0x080411af, 0x20216412,   // bg.ru.mk_443 de.fi.is_543  ro.ru.uk_655 lg.jw.sq_654
  0x0e041e07, 0x033f1f0c, 0x04000e04, 0x2d002913,   // ms.fi.is_432 cy.af.nl_543  is.fi.un_320 sl.sk.un_650
  // [0760]
  0x27183507, 0x55110a05, 0x28643504, 0x211e1c0c,   // zu.ga.gd_432 pt.ro.rw_333  zu.lg.sw_332 id.ms.jw_543
  0x07171105, 0x04000821, 0x2805010c, 0x17070aa4,   // ro.sr.bg_333 uk.ru.un_860  en.fr.sw_543 mk.bg.sr_433
  0x0d0913a9, 0x253f0307, 0x0400100c, 0x05000b02,   // bh.hi.ne_544 nl.af.eu_432  be.ru.un_530 es.fr.un_220
  0x16321755, 0x00001a0a, 0x68203555, 0x1a0b6b0c,   // sr.bs.hr_442 tl.un.un_500  zu.sq.ig_442 ceb.es.tl_543
  // [0770]
  0x0d00091a, 0x280611ee, 0x0e020c14, 0x09005321,   // hi.ne.un_760 ro.de.sw_422  sv.da.is_666 ht.pl.un_860
  0x28353b0c, 0x2d000d22, 0x052b0c08, 0x6e003f08,   // so.zu.sw_543 cs.sk.un_870  sv.vi.fr_443 af.hmn.un_430
  0x13000d08, 0x10170a08, 0x0c00082c, 0x2d0d29a4,   // ne.bh.un_430 mk.sr.be_443  no.sv.un_990 sl.cs.sk_433
  0x2304010c, 0x3b0e11a4, 0x12682a08, 0x00004a24,   // en.fi.ca_543 ro.is.so_433  mt.ig.hu_443 yo.un.un_900
  // [0780]
  0x05003504, 0x251b1e0c, 0x0000272d, 0x3120010c,   // zu.fr.un_320 ms.tr.eu_543  gd.un.un_A00 en.sq.az_543
  0x6e1f1913, 0x07170a14, 0x0c00022c, 0x2902160c,   // gl.cy.hmn_665 mk.sr.bg_666  da.sv.un_990 hr.da.sl_543
  0x52000804, 0x00000e01, 0x1e211caf, 0x060e08a9,   // no.ha.un_320 is.un.un_200  id.jw.ms_655 no.is.de_544
  0x17002308, 0x24000122, 0x0c001912, 0x0c082307,   // ca.sr.un_430 iw.yi.un_870  gl.sv.un_640 ca.no.sv_432
  // [0790]
  0x04001113, 0x04001004, 0x280c550c, 0x25170aa0,   // ro.ru.un_650 be.ru.un_320  rw.sv.sw_543 pt.sr.eu_322
  0x1c6b55ad, 0x06006e12, 0x16002907, 0x230a19a0,   // rw.ceb.id_643 hmn.de.un_640  sl.hr.un_420 gl.pt.ca_322
  0x01296bee, 0x00000606, 0x11000108, 0x55521e0c,   // ceb.sl.en_422 de.un.un_400  en.ro.un_430 ms.ha.rw_543
  0x0f002302, 0x21283511, 0x170a11a4, 0x00003f1c,   // ca.lv.un_220 zu.sw.jw_653  ro.mk.sr_433 af.un.un_800
  // [07a0]
  0x3216290e, 0x04071004, 0x0e020c13, 0x0b0a190e,   // sl.hr.bs_555 be.bg.ru_332  sv.da.is_665 gl.pt.es_555
  0x05522aad, 0x286404ad, 0x20003f0d, 0x040c08a4,   // mt.ha.fr_643 fi.lg.sw_643  af.sq.un_540 no.sv.fi_433
  0x53001a0c, 0x2900110d, 0x17002d04, 0x0d2911a7,   // tl.ht.un_530 ro.sl.un_540  sk.sr.un_320 ro.sl.cs_532
  0x0400101a, 0x201c1ea0, 0x6b276e0c, 0x10062005,   // be.ru.un_760 ms.id.sq_322  hmn.gd.ceb_543 sq.de.lt_333
  // [07b0]
  0x1e1c1fa9, 0x2d0d1909, 0x55251c0c, 0x03000804,   // cy.id.ms_544 gl.cs.sk_444  id.eu.rw_543 no.nl.un_320
  0x0600032c, 0x230701a4, 0x00000a01, 0x0b5223a0,   // nl.de.un_990 en.it.ca_433  mk.un.un_200 ca.ha.es_322
  0x04001313, 0x2d0d12a0, 0x3b1c1eee, 0x21131ca6,   // et.fi.un_650 hu.cs.sk_322  ms.id.so_422 id.et.jw_521
  0x1200050d, 0x21181213, 0x033f050c, 0x05006419,   // fr.hu.un_540 ur.ar.fa_665  fr.af.nl_543 lg.fr.un_750
  // [07c0]
  0x1b003113, 0x08000611, 0x05282b07, 0x1821120c,   // az.tr.un_650 de.no.un_630  vi.sw.fr_432 ur.fa.ar_543
  0x07100413, 0x6b000412, 0x32000908, 0x1b1e1c05,   // ru.be.bg_665 fi.ceb.un_640  pl.bs.un_430 id.ms.tr_333
  0x0a040809, 0x31006b02, 0x00000e24, 0x10033f08,   // uk.ru.mk_444 ceb.az.un_220  is.un.un_900 af.nl.lt_443
  0x11050112, 0x10006b04, 0x0e5235ad, 0x211e1cee,   // en.fr.ro_654 ceb.lt.un_320  zu.ha.is_643 id.ms.jw_422
  // [07d0]
  0x0a002309, 0x131b31b3, 0x1200211b, 0x2d0d0e0e,   // ca.pt.un_440 az.tr.et_743  fa.ur.un_770 is.cs.sk_555
  0x06020c14, 0x1c001e0c, 0x313f010c, 0x1c090da0,   // sv.da.de_666 ms.id.un_530  en.af.az_543 ne.hi.mr_322
  0x09002a04, 0x00001b1c, 0x1710010c, 0x0f002314,   // mt.pl.un_320 tr.un.un_800  en.lt.sr_543 ca.lv.un_660
  0x13230c08, 0x29000d08, 0x11002a0e, 0x322d0d08,   // sv.ca.et_443 cs.sl.un_430  mt.ro.un_550 cs.sk.bs_443
  // [07e0]
  0x0a002313, 0x19000a2c, 0x0000231c, 0x13013b04,   // ca.pt.un_650 pt.gl.un_990  ca.un.un_800 so.en.et_332
  0x07001602, 0x040501ec, 0x13001c09, 0x050a230e,   // hr.it.un_220 en.fr.fi_644  mr.bh.un_440 ca.pt.fr_555
  0x25000512, 0x0500012b, 0x030208a4, 0x04070a13,   // fr.eu.un_640 en.fr.un_980  no.da.nl_433 mk.bg.ru_665
  0x1e111caf, 0x0c0523ec, 0x0a310eac, 0x2d0d0c09,   // id.ro.ms_655 ca.fr.sv_644  is.az.pt_632 sv.cs.sk_444
  // [07f0]
  0x12000a02, 0x00002303, 0x0a08040d, 0x050c23ad,   // pt.hu.un_220 ca.un.un_300  ru.uk.mk_554 ca.sv.fr_643
  0x0000191c, 0x29092da4, 0x3b003f05, 0x3f3b0313,   // gl.un.un_800 sk.pl.sl_433  af.so.un_330 nl.so.af_665
  0x11120807, 0x250b53a0, 0x05002313, 0x3500640c,   // no.hu.ro_432 ht.es.eu_322  ca.fr.un_650 lg.zu.un_530
  0x05002319, 0x32000d0d, 0x28001a13, 0x08100a05,   // ca.fr.un_750 cs.bs.un_540  tl.sw.un_650 mk.be.uk_333

  // [0800]
  0x06003113, 0x10033f0c, 0x0a25010c, 0x10005219,   // az.de.un_650 af.nl.lt_543  en.eu.pt_543 ha.lt.un_750
  0x0d320ba0, 0x16002908, 0x0500010d, 0x0a006402,   // es.bs.cs_322 sl.hr.un_430  en.fr.un_540 lg.pt.un_220
  0x08021b0c, 0x05000122, 0x1b003114, 0x2100181a,   // tr.da.no_543 en.fr.un_870  az.tr.un_660 ar.fa.un_760
  0x17272307, 0x2100050c, 0x0207080c, 0x0c002311,   // ca.gd.sr_432 fr.jw.un_530  no.it.da_543 ca.sv.un_630
  // [0810]
  0x0120680c, 0x0a080408, 0x211c1e11, 0x00002324,   // ig.sq.en_543 ru.uk.mk_443  ms.id.jw_653 ca.un.un_900
  0x6800080d, 0x160802a4, 0x13000913, 0x0703080c,   // no.ig.un_540 da.no.hr_433  hi.bh.un_650 no.nl.it_543
  0x250c2308, 0x110a0712, 0x0c002308, 0x21001208,   // ca.sv.eu_443 bg.mk.ro_654  ca.sv.un_430 ur.fa.un_430
  0x0a53680c, 0x1600290b, 0x130c2307, 0x091c1304,   // ig.ht.pt_543 sl.hr.un_520  ca.sv.et_432 bh.mr.hi_332
  // [0820]
  0x6408020d, 0x0200080c, 0x20002908, 0x29005502,   // da.no.lg_554 no.da.un_530  sl.sq.un_430 rw.sl.un_220
  0x00002906, 0x0b0a1902, 0x1b003111, 0x68005523,   // sl.un.un_400 gl.pt.es_222  az.tr.un_630 rw.ig.un_880
  0x32000d04, 0x12211812, 0x181f2712, 0x0207110c,   // cs.bs.un_320 ar.fa.ur_654  gd.cy.ga_654 ro.it.da_543
  0x32001604, 0x1f1729ee, 0x00006824, 0x060e3f55,   // hr.bs.un_320 sl.sr.cy_422  ig.un.un_900 af.is.de_442
  // [0830]
  0x20110f5a, 0x092d0d60, 0x55190bad, 0x0000010a,   // lv.ro.sq_553 cs.sk.pl_664  es.gl.rw_643 en.un.un_500
  0x27001813, 0x53311b0c, 0x32172909, 0x281827a4,   // ga.gd.un_650 tr.az.ht_543  sl.sr.bs_444 gd.ga.sw_433
  0x29005313, 0x08020714, 0x1b001e04, 0x3f001e0d,   // ht.sl.un_650 it.da.no_666  ms.tr.un_320 ms.af.un_540
  0x2818270e, 0x16000d04, 0x290668a9, 0x13002a1a,   // gd.ga.sw_555 cs.hr.un_320  ig.de.sl_544 mt.et.un_760
  // [0840]
  0x080c0e07, 0x13642a0c, 0x080255ec, 0x643207ee,   // is.sv.no_432 mt.lg.et_543  rw.da.no_644 it.bs.lg_422
  0x68002519, 0x0607080c, 0x1a6b1c0c, 0x07080a08,   // eu.ig.un_750 no.it.de_543  id.ceb.tl_543 mk.uk.bg_443
  0x043f0308, 0x075368a9, 0x1b003123, 0x10040855,   // nl.af.fi_443 ig.ht.it_544  az.tr.un_880 uk.ru.be_442
  0x07102708, 0x20000619, 0x19050b07, 0x203f0807,   // gd.lt.it_443 de.sq.un_750  es.fr.gl_432 no.af.sq_432
  // [0850]
  0x1b00310d, 0x03172007, 0x1c001e34, 0x0d1c09a9,   // az.tr.un_540 sq.sr.nl_432  ms.id.un_A80 hi.mr.ne_544
  0x21001c1a, 0x121e1c55, 0x2b27010c, 0x1f1827af,   // id.jw.un_760 id.ms.hu_442  en.gd.vi_543 gd.ga.cy_655
  0x0000320a, 0x211c1e0c, 0x2b641ca4, 0x6b033f0d,   // bs.un.un_500 ms.id.jw_543  id.lg.vi_433 af.nl.ceb_554
  0x211e1c09, 0x09000d0d, 0x06000113, 0x1007040c,   // id.ms.jw_444 cs.pl.un_540  en.de.un_650 ru.bg.be_543
  // [0860]
  0x08171112, 0x1b090ea4, 0x010a23a0, 0x55002d0d,   // ro.sr.uk_654 is.pl.tr_433  ca.pt.en_322 sk.rw.un_540
  0x6b3b31a9, 0x00000603, 0x00000506, 0x1e001c1b,   // az.so.ceb_544 de.un.un_300  fr.un.un_400 id.ms.un_770
  0x521603a0, 0x31131b08, 0x0d1c09ad, 0x0e0164ee,   // nl.hr.ha_322 tr.et.az_443  hi.mr.ne_643 lg.en.is_422
  0x110604a7, 0x112009ee, 0x050d2107, 0x29002d1a,   // fi.de.ro_532 pl.sq.ro_422  jw.cs.fr_432 sk.sl.un_760
  // [0870]
  0x0000681c, 0x031e3fa0, 0x12182113, 0x2d090d07,   // ig.un.un_800 af.ms.nl_322  fa.ar.ur_665 cs.pl.sk_432
  0x12190b13, 0x18001213, 0x19000b0d, 0x1e001c19,   // es.gl.hu_665 ur.ar.un_650  es.gl.un_540 id.ms.un_750
  0x0a040705, 0x0c00131b, 0x05001908, 0x2b1801a6,   // bg.ru.mk_333 et.sv.un_770  gl.fr.un_430 en.ga.vi_521
  0x0f095508, 0x1600290e, 0x0a04110c, 0x081f120c,   // rw.pl.lv_443 sl.hr.un_550  ro.ru.mk_543 hu.cy.no_543
  // [0880]
  0x122005a4, 0x11001f05, 0x1a080a12, 0x28556407,   // fr.sq.hu_433 cy.ro.un_330  pt.no.tl_654 lg.rw.sw_432
  0x06000c12, 0x131f35ee, 0x1e1c21a4, 0x190a2309,   // sv.de.un_640 zu.cy.et_422  jw.id.ms_433 ca.pt.gl_444
  0x11000104, 0x01033f02, 0x06080208, 0x0c000804,   // en.ro.un_320 af.nl.en_222  da.no.de_443 no.sv.un_320
  0x52001320, 0x202135ec, 0x18003504, 0x21042bee,   // et.ha.un_850 zu.jw.sq_644  zu.ga.un_320 vi.fi.jw_422
  // [0890]
  0x1e001c0c, 0x250418ad, 0x0f4a0a07, 0x4a52350c,   // id.ms.un_530 ga.fi.eu_643  pt.yo.lv_432 zu.ha.yo_543
  0x09001c0d, 0x0400171b, 0x292d03ec, 0x2b0e2104,   // mr.hi.un_540 sr.ru.un_770  nl.sk.sl_644 jw.is.vi_332
  0x0f1f5205, 0x190a23a0, 0x04060c67, 0x3f00061b,   // ha.cy.lv_333 ca.pt.gl_322  sv.de.fi_775 de.af.un_770
  0x04060c0c, 0x06001114, 0x02000809, 0x23190a02,   // sv.de.fi_543 ro.de.un_660  no.da.un_440 pt.gl.ca_222
  // [08a0]
  0x08200cad, 0x1b4a2504, 0x1b2906a4, 0x04130c55,   // sv.sq.no_643 eu.yo.tr_332  de.sl.tr_433 sv.et.fi_442
  0x2d190b07, 0x08022012, 0x1900050e, 0x55356404,   // es.gl.sk_432 sq.da.no_654  fr.gl.un_550 lg.zu.rw_332
  0x1a044a12, 0x18190b09, 0x13060c0c, 0x1b645504,   // yo.fi.tl_654 es.gl.ga_444  sv.de.et_543 rw.lg.tr_332
  0x2b006e2a, 0x1c55210c, 0x00003206, 0x0d1c1355,   // hmn.vi.un_970 jw.rw.id_543  bs.un.un_400 bh.mr.ne_442
  // [08b0]
  0x04001112, 0x28005509, 0x32002008, 0x21001c13,   // ro.ru.un_640 rw.sw.un_440  sq.bs.un_430 id.jw.un_650
  0x0f202912, 0x3f02040c, 0x08002b13, 0x2b0a6807,   // sl.sq.lv_654 fi.da.af_543  vi.no.un_650 ig.pt.vi_432
  0x6800552a, 0x12006e23, 0x172923a4, 0x68040aee,   // rw.ig.un_970 hmn.hu.un_880  ca.sl.sr_433 pt.fi.ig_422
  0x27002b34, 0x0c0802ac, 0x53001022, 0x0f002507,   // vi.gd.un_A80 da.no.sv_632  lt.ht.un_870 eu.lv.un_420
  // [08c0]
  0x0b1f13ec, 0x6b190a11, 0x2a00531b, 0x2a536e5a,   // et.cy.es_644 pt.gl.ceb_653  ht.mt.un_770 hmn.ht.mt_553
  0x09004a12, 0x1b003119, 0x190b18ee, 0x1308180c,   // yo.pl.un_640 az.tr.un_750  ga.es.gl_422 ga.no.et_543
  0x0e0a0107, 0x02006404, 0x18122112, 0x0802050e,   // en.pt.is_432 lg.da.un_320  fa.ur.ar_654 fr.da.no_555
  0x0400071b, 0x17161a0c, 0x2100280d, 0x00002024,   // bg.ru.un_770 tl.hr.sr_543  sw.jw.un_540 sq.un.un_900
  // [08d0]
  0x4a2a06ec, 0x026408af, 0x6b120e05, 0x056e3f0c,   // de.mt.yo_644 no.lg.da_655  is.hu.ceb_333 af.hmn.fr_543
  0x0d13090d, 0x17071008, 0x06002013, 0x0a063f07,   // hi.bh.ne_554 be.bg.sr_443  sq.de.un_650 af.de.pt_432
  0x18000708, 0x1f002a29, 0x1c10210c, 0x0f001b05,   // it.ga.un_430 mt.cy.un_960  jw.lt.id_543 tr.lv.un_330
  0x00000c03, 0x20002d1a, 0x1c211eaf, 0x01006e02,   // sv.un.un_300 sk.sq.un_760  ms.jw.id_655 hmn.en.un_220
  // [08e0]
  0x080213a0, 0x11006e1a, 0x1268640c, 0x2d6413a4,   // et.da.no_322 hmn.ro.un_760  lg.ig.hu_543 et.lg.sk_433
  0x11003b08, 0x1300041a, 0x2b3b1704, 0x212d0d55,   // so.ro.un_430 fi.et.un_760  sr.so.vi_332 cs.sk.jw_442
  0x041a11af, 0x2300190d, 0x2d13100c, 0x2d1064a4,   // ro.tl.fi_655 gl.ca.un_540  lt.et.sk_543 lg.lt.sk_433
  0x1f003208, 0x04000a13, 0x1b20180c, 0x6e00272a,   // bs.cy.un_430 mk.ru.un_650  ga.sq.tr_543 gd.hmn.un_970
  // [08f0]
  0x28060b04, 0x23001904, 0x1c005204, 0x1f080c05,   // es.de.sw_332 gl.ca.un_320  ha.id.un_320 sv.no.cy_333
  0x09233108, 0x011a6ba0, 0x3b3119a9, 0x10080209,   // az.ca.pl_443 ceb.tl.en_322  gl.az.so_544 da.no.lt_444
  0x020c08a4, 0x00002106, 0x200f29a4, 0x08003202,   // no.sv.da_433 fa.un.un_400  sl.lv.sq_433 bs.no.un_220
  0x2d001014, 0x0d0913af, 0x27061aa0, 0x1f2519a9,   // lt.sk.un_660 bh.hi.ne_655  tl.de.gd_322 gl.eu.cy_544
  // [0900]
  0x07001a09, 0x00003f01, 0x131b2008, 0x02000a19,   // tl.it.un_440 af.un.un_200  sq.tr.et_443 pt.da.un_750
  0x321617ee, 0x093f0308, 0x1a041812, 0x12000a0c,   // sr.hr.bs_422 nl.af.pl_443  ga.fi.tl_654 pt.hu.un_530
  0x1c000104, 0x271c04a0, 0x0d00091b, 0x10291a12,   // en.id.un_320 fi.id.gd_322  hi.ne.un_770 tl.sl.lt_654
  0x29321605, 0x00000306, 0x023b1f0d, 0x0d000908,   // hr.bs.sl_333 nl.un.un_400  cy.so.da_554 hi.ne.un_430
  // [0910]
  0x1b0c06ec, 0x680f0107, 0x07041008, 0x1c000d0e,   // de.sv.tr_644 en.lv.ig_432  be.ru.bg_443 ne.mr.un_550
  0x17166ba4, 0x00004a01, 0x29321704, 0x2900170c,   // ceb.hr.sr_433 yo.un.un_200  sr.bs.sl_332 sr.sl.un_530
  0x0523010c, 0x031b2807, 0x1a080ea0, 0x283b0904,   // en.ca.fr_543 sw.tr.nl_432  is.no.tl_322 pl.so.sw_332
  0x0a0407a9, 0x07040a08, 0x170a0712, 0x252b20ec,   // bg.ru.mk_544 mk.ru.bg_443  bg.mk.sr_654 sq.vi.eu_644
  // [0920]
  0x09000614, 0x296b1a08, 0x2a126e14, 0x0a100708,   // de.pl.un_660 tl.ceb.sl_443  hmn.hu.mt_666 bg.be.mk_443
  0x55643b14, 0x32170f02, 0x4a0c200e, 0x23110107,   // so.lg.rw_666 lv.sr.bs_222  sq.sv.yo_555 en.ro.ca_432
  0x27556460, 0x25050704, 0x1c054a12, 0x190a53af,   // lg.rw.gd_664 it.fr.eu_332  yo.fr.id_654 ht.pt.gl_655
  0x020c11af, 0x05190b0e, 0x0c060308, 0x05000e22,   // ro.sv.da_655 es.gl.fr_555  nl.de.sv_443 is.fr.un_870
  // [0930]
  0x28110513, 0x190a2314, 0x68311b13, 0x09002904,   // fr.ro.sw_665 ca.pt.gl_666  tr.az.ig_665 sl.pl.un_320
  0x00001137, 0x13091caf, 0x0a1923ad, 0x1a000c04,   // ro.un.un_B00 mr.hi.bh_655  ca.gl.pt_643 sv.tl.un_320
  0x110a1faf, 0x0723080c, 0x182027a4, 0x68071f0c,   // cy.pt.ro_655 no.ca.it_543  gd.sq.ga_433 cy.it.ig_543
  0x190b2dee, 0x2a006b07, 0x080a1014, 0x00002424,   // sk.es.gl_422 ceb.mt.un_420  be.mk.uk_666 yi.un.un_900
  // [0940]
  0x1e1c6ea0, 0x120f5211, 0x29000909, 0x0000062d,   // hmn.id.ms_322 ha.lv.hu_653  pl.sl.un_440 de.un.un_A00
  0x07080e0b, 0x0d00291a, 0x32230e07, 0x6e002b19,   // is.no.it_542 sl.cs.un_760  is.ca.bs_432 vi.hmn.un_750
  0x2a6b1aaf, 0x3b28520d, 0x1f05530b, 0x0300251a,   // tl.ceb.mt_655 ha.sw.so_554  ht.fr.cy_542 eu.nl.un_760
  0x0e000c0e, 0x1900230e, 0x03001208, 0x0a192307,   // sv.is.un_550 ca.gl.un_550  hu.nl.un_430 ca.gl.pt_432
  // [0950]
  0x3f1304ad, 0x070a170e, 0x3b006e08, 0x09006b04,   // fi.et.af_643 sr.mk.bg_555  hmn.so.un_430 ceb.pl.un_320
  0x0f4a3113, 0x2d100da4, 0x0400080d, 0x12001105,   // az.yo.lv_665 cs.lt.sk_433  uk.ru.un_540 ro.hu.un_330
  0x2b1605ec, 0x55006b1a, 0x0a0408af, 0x190a23ec,   // fr.hr.vi_644 ceb.rw.un_760  uk.ru.mk_655 ca.pt.gl_644
  0x102b050c, 0x0a001119, 0x1700290d, 0x01524a07,   // fr.vi.lt_543 ro.mk.un_750  sl.sr.un_540 yo.ha.en_432
  // [0960]
  0x05280ba9, 0x0f160da0, 0x00003b2d, 0x011f120c,   // es.sw.fr_544 cs.hr.lv_322  so.un.un_A00 hu.cy.en_543
  0x13002a19, 0x1b003108, 0x0400170c, 0x311b1c07,   // mt.et.un_750 az.tr.un_430  sr.ru.un_530 id.tr.az_432
  0x17002904, 0x4a2b01ee, 0x2d0d09af, 0x04081007,   // sl.sr.un_320 en.vi.yo_422  pl.cs.sk_655 be.uk.ru_432
  0x00002137, 0x13071f0c, 0x29080202, 0x08101107,   // fa.un.un_B00 cy.it.et_543  da.no.sl_222 ro.be.uk_432
  // [0970]
  0x2b005304, 0x03001607, 0x170a10a4, 0x08100708,   // ht.vi.un_320 hr.nl.un_420  be.mk.sr_433 bg.be.uk_443
  0x09110d07, 0x03291208, 0x0a102507, 0x525506a4,   // cs.ro.pl_432 hu.sl.nl_443  eu.lt.pt_432 de.rw.ha_433
  0x29002504, 0x2a094a08, 0x030208ec, 0x20042902,   // eu.sl.un_320 yo.pl.mt_443  no.da.nl_644 sl.fi.sq_222
  0x1b310e08, 0x09001302, 0x322907a9, 0x0c1b0e05,   // is.az.tr_443 bh.hi.un_220  it.sl.bs_544 is.tr.sv_333
  // [0980]
  0x00002306, 0x040764a9, 0x1300020e, 0x53000d04,   // ca.un.un_400 lg.it.fi_544  da.et.un_550 cs.ht.un_320
  0x2900101a, 0x072327a4, 0x0000122d, 0x08000422,   // lt.sl.un_760 gd.ca.it_433  ur.un.un_A00 ru.uk.un_870
  0x29001605, 0x1f0853ee, 0x01002418, 0x2b00270c,   // hr.sl.un_330 ht.no.cy_422  yi.iw.un_740 gd.vi.un_530
  0x041c1e12, 0x07000a0e, 0x29110f07, 0x072a11af,   // ms.id.fi_654 mk.bg.un_550  lv.ro.sl_432 ro.mt.it_655
  // [0990]
  0x27003b1a, 0x0a070412, 0x17000a1b, 0x08170aa4,   // so.gd.un_760 ru.bg.mk_654  mk.sr.un_770 mk.sr.uk_433
  0x32311b09, 0x3100090d, 0x0d000914, 0x04000718,   // tr.az.bs_444 pl.az.un_540  hi.ne.un_660 bg.ru.un_740
  0x3f002704, 0x1c0913a7, 0x063f0304, 0x1b003112,   // gd.af.un_320 bh.hi.mr_532  nl.af.de_332 az.tr.un_640
  0x29311ba0, 0x18002104, 0x2a093b0d, 0x2a311b0c,   // tr.az.sl_322 jw.ga.un_320  so.pl.mt_554 tr.az.mt_543
  // [09a0]
  0x0a0717af, 0x3f0e06a4, 0x07311b0d, 0x1c091314,   // sr.bg.mk_655 de.is.af_433  tr.az.it_554 bh.hi.mr_666
  0x2d0d0914, 0x17000a1a, 0x32001e04, 0x21001219,   // pl.cs.sk_666 mk.sr.un_760  ms.bs.un_320 ur.fa.un_750
  0x0704100c, 0x1c0d09a4, 0x0e0b0a05, 0x00005206,   // be.ru.bg_543 hi.ne.mr_433  pt.es.is_333 ha.un.un_400
  0x2a3b3112, 0x01203fa0, 0x3500550d, 0x06000804,   // az.so.mt_654 af.sq.en_322  rw.zu.un_540 no.de.un_320
  // [09b0]
  0x110417a4, 0x07040a02, 0x19000a09, 0x09292da0,   // sr.ru.ro_433 mk.ru.bg_222  pt.gl.un_440 sk.sl.pl_322
  0x11040713, 0x07001119, 0x64003504, 0x04110607,   // bg.ru.ro_665 ro.bg.un_750  zu.lg.un_320 de.ro.fi_432
  0x07170a0d, 0x05002012, 0x2a00072a, 0x2000051a,   // mk.sr.bg_554 sq.fr.un_640  it.mt.un_970 fr.sq.un_760
  0x131b0ca0, 0x1b001319, 0x28002018, 0x08022aee,   // sv.tr.et_322 et.tr.un_750  sq.sw.un_740 mt.da.no_422
  // [09c0]
  0x1a0c290d, 0x1c0d1302, 0x091c0d0c, 0x35005222,   // sl.sv.tl_554 bh.ne.mr_222  ne.mr.hi_543 ha.zu.un_870
  0x00002103, 0x27001e07, 0x0e061f07, 0x040810a4,   // jw.un.un_300 ms.gd.un_420  cy.de.is_432 be.uk.ru_433
  0x09001c1a, 0x0f1c1fa4, 0x1e001c09, 0x2300251a,   // mr.hi.un_760 cy.id.lv_433  id.ms.un_440 eu.ca.un_760
  0x07113512, 0x0f000519, 0x121b3112, 0x16321713,   // zu.ro.it_654 fr.lv.un_750  az.tr.hu_654 sr.bs.hr_665
  // [09d0]
  0x356b68ad, 0x00001606, 0x04351f0b, 0x055303a0,   // ig.ceb.zu_643 hr.un.un_400  cy.zu.fi_542 nl.ht.fr_322
  0x10283512, 0x171305ad, 0x1e282a04, 0x21001222,   // zu.sw.lt_654 fr.et.sr_643  mt.sw.ms_332 ur.fa.un_870
  0x12006407, 0x10682108, 0x1e001c04, 0x2a681fad,   // lg.hu.un_420 jw.ig.lt_443  id.ms.un_320 cy.ig.mt_643
  0x03202d07, 0x01026ba0, 0x6827180d, 0x0c00121a,   // sk.sq.nl_432 ceb.da.en_322  ga.gd.ig_554 hu.sv.un_760
  // [09e0]
  0x070a11af, 0x1c002109, 0x31121ca0, 0x31001912,   // ro.mk.bg_655 jw.id.un_440  id.hu.az_322 gl.az.un_640
  0x4a286409, 0x3f060308, 0x112d0d0d, 0x080e0608,   // lg.sw.yo_444 nl.de.af_443  cs.sk.ro_554 de.is.no_443
  0x06002507, 0x12000a19, 0x040717ad, 0x011e2107,   // eu.de.un_420 pt.hu.un_750  sr.bg.ru_643 jw.ms.en_432
  0x131e1c05, 0x06006b08, 0x28002014, 0x35271804,   // id.ms.et_333 ceb.de.un_430  sq.sw.un_660 ga.gd.zu_332
  // [09f0]
  0x06033fee, 0x3b6b1a07, 0x0d091311, 0x082102a4,   // af.nl.de_422 tl.ceb.so_432  bh.hi.ne_653 da.jw.no_433
  0x08001e05, 0x1b000811, 0x35211814, 0x08001007,   // ms.no.un_330 no.tr.un_630  ga.jw.zu_666 be.uk.un_420
  0x04001321, 0x104a0408, 0x1312040c, 0x10071208,   // et.fi.un_860 fi.yo.lt_443  fi.hu.et_543 hu.it.lt_443
  0x1f0705ec, 0x0f090da4, 0x080c02ee, 0x03003f04,   // fr.it.cy_644 cs.pl.lv_433  da.sv.no_422 af.nl.un_320
  // [0a00]
  0x112d0d12, 0x1a001b22, 0x3f003202, 0x0000550a,   // cs.sk.ro_654 tr.tl.un_870  bs.af.un_220 rw.un.un_500
  0x32052302, 0x2b000d04, 0x19231807, 0x1f001a04,   // ca.fr.bs_222 cs.vi.un_320  ga.ca.gl_432 tl.cy.un_320
  0x080410a4, 0x12002d09, 0x1c002b05, 0x1b00312c,   // be.ru.uk_433 sk.hu.un_440  vi.id.un_330 az.tr.un_990
  0x01002907, 0x1c000d08, 0x07000414, 0x00000315,   // sl.en.un_420 ne.mr.un_430  ru.bg.un_660 nl.un.un_700
  // [0a10]
  0x3f0603a4, 0x06000314, 0x03001f0d, 0x040a17a4,   // nl.de.af_433 nl.de.un_660  cy.nl.un_540 sr.mk.ru_433
  0x0400100d, 0x01003f04, 0x1c00091b, 0x120519a6,   // be.ru.un_540 af.en.un_320  hi.mr.un_770 gl.fr.hu_521
  0x10000814, 0x1800210c, 0x0f030cee, 0x13003119,   // uk.be.un_660 fa.ar.un_530  sv.nl.lv_422 az.et.un_750
  0x1f2718af, 0x1a352707, 0x1b1101a4, 0x110710ad,   // ga.gd.cy_655 gd.zu.tl_432  en.ro.tr_433 be.bg.ro_643
  // [0a20]
  0x321716af, 0x0d002d19, 0x072a05a7, 0x321723a0,   // hr.sr.bs_655 sk.cs.un_750  fr.mt.it_532 ca.sr.bs_322
  0x2a3555a9, 0x32170faf, 0x11000413, 0x1c000902,   // rw.zu.mt_544 lv.sr.bs_655  ru.ro.un_650 hi.mr.un_220
  0x04001011, 0x08040a08, 0x00002706, 0x20001904,   // be.ru.un_630 mk.ru.uk_443  gd.un.un_400 gl.sq.un_320
  0x0000682d, 0x12290407, 0x0a001714, 0x100f17a4,   // ig.un.un_A00 fi.sl.hu_432  sr.mk.un_660 sr.lv.lt_433
  // [0a30]
  0x040710ee, 0x0f3f3507, 0x1b2a31ad, 0x080c0212,   // be.bg.ru_422 zu.af.lv_432  az.mt.tr_643 da.sv.no_654
  0x03060cee, 0x08020eec, 0x25001604, 0x28010c55,   // sv.de.nl_422 is.da.no_644  hr.eu.un_320 sv.en.sw_442
  0x02000822, 0x1b6b1a12, 0x1c0d090c, 0x17005504,   // no.da.un_870 tl.ceb.tr_654  hi.ne.mr_543 rw.sr.un_320
  0x123204ee, 0x0a001719, 0x0b0a23af, 0x2a000721,   // fi.bs.hu_422 sr.mk.un_750  ca.pt.es_655 it.mt.un_860
  // [0a40]
  0x35006422, 0x04001005, 0x07001004, 0x0d00130d,   // lg.zu.un_870 be.ru.un_330  be.bg.un_320 bh.ne.un_540
  0x31006b04, 0x2a0f0714, 0x0a001c04, 0x182112a9,   // ceb.az.un_320 it.lv.mt_666  id.pt.un_320 ur.fa.ar_544
  0x04000612, 0x00000b24, 0x64001b20, 0x17000119,   // de.fi.un_640 bn.un.un_900  tr.lg.un_850 en.sr.un_750
  0x0800100d, 0x17070d07, 0x166b2dee, 0x6b1e1c05,   // be.uk.un_540 cs.it.sr_432  sk.ceb.hr_422 id.ms.ceb_333
  // [0a50]
  0x0c003104, 0x0c00060d, 0x04033f5a, 0x00003f0a,   // az.sv.un_320 de.sv.un_540  af.nl.fi_553 af.un.un_500
  0x28006812, 0x0a23010c, 0x2d000d23, 0x252d5305,   // ig.sw.un_640 en.ca.pt_543  cs.sk.un_880 ht.sk.eu_333
  0x32000308, 0x19530ba7, 0x2800550d, 0x3b000414,   // nl.bs.un_430 es.ht.gl_532  rw.sw.un_540 fi.so.un_660
  0x0e0d2d12, 0x043b2555, 0x641a53a7, 0x29210909,   // sk.cs.is_654 eu.so.fi_442  ht.tl.lg_532 pl.jw.sl_444
  // [0a60]
  0x283b03ee, 0x091c1311, 0x3f253bad, 0x55001a02,   // nl.so.sw_422 bh.mr.hi_653  so.eu.af_643 tl.rw.un_220
  0x0e080205, 0x2d0d2baf, 0x281c3107, 0x080a170b,   // da.no.is_333 vi.cs.sk_655  az.id.sw_432 sr.mk.uk_542
  0x07110408, 0x10285208, 0x092a280c, 0x25643b11,   // ru.ro.bg_443 ha.sw.lt_443  sw.mt.pl_543 so.lg.eu_653
  0x556428a4, 0x4a005520, 0x04005205, 0x04000304,   // sw.lg.rw_433 rw.yo.un_850  ha.fi.un_330 nl.fi.un_320
  // [0a70]
  0x100b1307, 0x551c5208, 0x1b002819, 0x0000522d,   // et.es.lt_432 ha.id.rw_443  sw.tr.un_750 ha.un.un_A00
  0x0d001308, 0x1c0d13a0, 0x31001c04, 0x642d6807,   // bh.ne.un_430 bh.ne.mr_322  id.az.un_320 ig.sk.lg_432
  0x55006b18, 0x110d3f04, 0x092d0d09, 0x0c2808a0,   // ceb.rw.un_740 af.cs.ro_332  cs.sk.pl_444 no.sw.sv_322
  0x070408a4, 0x2528520c, 0x4a25550c, 0x04001021,   // no.fi.it_433 ha.sw.eu_543  rw.eu.yo_543 be.ru.un_860
  // [0a80]
  0x686407a4, 0x3f130408, 0x31000804, 0x0c002d12,   // it.lg.ig_433 fi.et.af_443  no.az.un_320 sk.sv.un_640
  0x211e1c02, 0x3f000108, 0x2d0d35ec, 0x4a001e04,   // id.ms.jw_222 en.af.un_430  zu.cs.sk_644 ms.yo.un_320
  0x292a5512, 0x09100d08, 0x172a0c08, 0x2d0d3514,   // rw.mt.sl_654 cs.lt.pl_443  sv.mt.sr_443 zu.cs.sk_666
  0x55002823, 0x0b231908, 0x00001024, 0x211b1ea4,   // sw.rw.un_880 gl.ca.es_443  lt.un.un_900 ms.tr.jw_433
  // [0a90]
  0x0a10080c, 0x284a2105, 0x13000423, 0x28211cad,   // uk.be.mk_543 jw.yo.sw_333  fi.et.un_880 id.jw.sw_643
  0x0a040709, 0x1708110c, 0x120b190c, 0x010705a0,   // bg.ru.mk_444 ro.uk.sr_543  gl.es.hu_543 fr.it.en_322
  0x1e521ca4, 0x1a282714, 0x523f1c04, 0x180b280c,   // id.ha.ms_433 gd.sw.tl_666  id.af.ha_332 sw.es.ga_543
  0x1000311b, 0x1b000813, 0x042d0d08, 0x101117ee,   // az.lt.un_770 no.tr.un_650  cs.sk.fi_443 sr.ro.lt_422
  // [0aa0]
  0x231811a4, 0x04522013, 0x08000214, 0x072519a0,   // ro.ga.ca_433 sq.ha.fi_665  da.no.un_660 gl.eu.it_322
  0x2d005207, 0x040c1c04, 0x1e252007, 0x02001b18,   // ha.sk.un_420 id.sv.fi_332  sq.eu.ms_432 tr.da.un_740
  0x20000c08, 0x03233b13, 0x080c020c, 0x11200408,   // sv.sq.un_430 so.ca.nl_665  da.sv.no_543 fi.sq.ro_443
  0x0a17110c, 0x13090d09, 0x2d001904, 0x31321bec,   // ro.sr.mk_543 ne.hi.bh_444  gl.sk.un_320 tr.bs.az_644
  // [0ab0]
  0x250623a0, 0x0b0a290c, 0x0a171109, 0x25000705,   // ca.de.eu_322 sl.pt.es_543  ro.sr.mk_444 it.eu.un_330
  0x35005519, 0x07040a09, 0x08310ca4, 0x0d2d2912,   // rw.zu.un_750 mk.ru.bg_444  sv.az.no_433 sl.sk.cs_654
  0x1b0e2d07, 0x3b1b1aa9, 0x1600350c, 0x04201fa4,   // sk.is.tr_432 tl.tr.so_544  zu.hr.un_530 cy.sq.fi_433
  0x52353b0c, 0x3528550c, 0x170a0713, 0x11001e04,   // so.zu.ha_543 rw.sw.zu_543  bg.mk.sr_665 ms.ro.un_320
  // [0ac0]
  0x160e0da4, 0x042d0d13, 0x2b20110c, 0x1e1c4aa0,   // cs.is.hr_433 cs.sk.fi_665  ro.sq.vi_543 yo.id.ms_322
  0x3b0e0211, 0x063f03a4, 0x0e08020d, 0x2800181a,   // da.is.so_653 nl.af.de_433  da.no.is_554 ga.sw.un_760
  0x080407ad, 0x68182712, 0x100408a7, 0x131035a0,   // bg.ru.uk_643 gd.ga.ig_654  uk.ru.be_532 zu.lt.et_322
  0x680464a9, 0x27111807, 0x20003513, 0x0b0a19af,   // lg.fi.ig_544 ga.ro.gd_432  zu.sq.un_650 gl.pt.es_655
  // [0ad0]
  0x18002722, 0x25131bec, 0x21072aec, 0x2520190c,   // gd.ga.un_870 tr.et.eu_644  mt.it.jw_644 gl.sq.eu_543
  0x00001e0f, 0x13000912, 0x35552512, 0x11271811,   // ms.un.un_600 hi.bh.un_640  eu.rw.zu_654 ga.gd.ro_653
  0x282b6b02, 0x25000623, 0x04000714, 0x0a1711a4,   // ceb.vi.sw_222 de.eu.un_880  bg.ru.un_660 ro.sr.mk_433
  0x041f2013, 0x2b00010c, 0x061e1ca9, 0x111f200c,   // sq.cy.fi_665 en.vi.un_530  id.ms.de_544 sq.cy.ro_543
  // [0ae0]
  0x042520a4, 0x00000224, 0x062718a7, 0x271118af,   // sq.eu.fi_433 da.un.un_900  ga.gd.de_532 ga.ro.gd_655
  0x2309290c, 0x21190b0e, 0x03001c07, 0x17070a13,   // sl.pl.ca_543 es.gl.jw_555  id.nl.un_420 mk.bg.sr_665
  0x1b352104, 0x091c210c, 0x1f000914, 0x23643509,   // jw.zu.tr_332 jw.id.pl_543  pl.cy.un_660 zu.lg.ca_444
  0x0d1c0911, 0x1c0d0914, 0x1f002a07, 0x28553560,   // hi.mr.ne_653 hi.ne.mr_666  mt.cy.un_420 zu.rw.sw_664
  // [0af0]
  0x0a041712, 0x285268a4, 0x040a1709, 0x1c090d0c,   // sr.ru.mk_654 ig.ha.sw_433  sr.mk.ru_444 ne.hi.mr_543
  0x01061fa7, 0x20351104, 0x271118ad, 0x0d0913a6,   // cy.de.en_532 ro.zu.sq_332  ga.ro.gd_643 bh.hi.ne_521
  0x00002901, 0x2700182b, 0x02182711, 0x2818110c,   // sl.un.un_200 ga.gd.un_980  gd.ga.da_653 ro.ga.sw_543
  0x04110aa4, 0x684a55ec, 0x31001b2b, 0x6e006b05,   // mk.ro.ru_433 rw.yo.ig_644  tr.az.un_980 ceb.hmn.un_330
  // [0b00]
  0x161a2d12, 0x0a071108, 0x041710a4, 0x1b3101a4,   // sk.tl.hr_654 ro.bg.mk_443  be.sr.ru_433 en.az.tr_433
  0x09000d1a, 0x01000d0d, 0x31001b2c, 0x2b040707,   // ne.hi.un_760 cs.en.un_540  tr.az.un_990 it.fi.vi_432
  0x1b5225a7, 0x25001a04, 0x294a255a, 0x1b000804,   // eu.ha.tr_532 tl.eu.un_320  eu.yo.sl_553 no.tr.un_320
  0x041310af, 0x1152350c, 0x1225530d, 0x0e0f2a08,   // lt.et.fi_655 zu.ha.ro_543  ht.eu.hu_554 mt.lv.is_443
  // [0b10]
  0x0c1b310c, 0x1b0208a4, 0x25101a0c, 0x1e1c1a05,   // az.tr.sv_543 no.da.tr_433  tl.lt.eu_543 tl.id.ms_333
  0x1307530b, 0x64285560, 0x11311bad, 0x1c002105,   // ht.it.et_542 rw.sw.lg_664  tr.az.ro_643 jw.id.un_330
  0x0000202d, 0x251b4a5a, 0x0c1a6b0c, 0x1e1c520c,   // sq.un.un_A00 yo.tr.eu_553  ceb.tl.sv_543 ha.id.ms_543
  0x1e1c6405, 0x0e2553a0, 0x11136ba4, 0x27350d11,   // lg.id.ms_333 ht.eu.is_322  ceb.et.ro_433 cs.zu.gd_653
  // [0b20]
  0x211e1c05, 0x31000b1b, 0x04211c08, 0x1b000104,   // id.ms.jw_333 es.az.un_770  id.jw.fi_443 en.tr.un_320
  0x2d000d08, 0x282a010c, 0x07001704, 0x172902a7,   // cs.sk.un_430 en.mt.sw_543  sr.bg.un_320 da.sl.sr_532
  0x353b0dad, 0x1e1c2aa9, 0x251206ad, 0x3f0306a4,   // cs.so.zu_643 mt.id.ms_544  de.hu.eu_643 de.nl.af_433
  0x05001905, 0x2a2d6404, 0x3f032507, 0x0c00061a,   // gl.fr.un_330 lg.sk.mt_332  eu.nl.af_432 de.sv.un_760
  // [0b30]
  0x00001724, 0x52121807, 0x6b0a01a4, 0x04110713,   // sr.un.un_900 ga.hu.ha_432  en.pt.ceb_433 bg.ro.ru_665
  0x201107a9, 0x27000e21, 0x05000112, 0x293216ec,   // it.ro.sq_544 is.gd.un_860  en.fr.un_640 hr.bs.sl_644
  0x316b1baf, 0x052301af, 0x1e1c6b0c, 0x0d000922,   // tr.ceb.az_655 en.ca.fr_655  ceb.id.ms_543 hi.ne.un_870
  0x03003f1b, 0x162d1209, 0x25285508, 0x28006407,   // af.nl.un_770 hu.sk.hr_444  rw.sw.eu_443 lg.sw.un_420
  // [0b40]
  0x0200081a, 0x0817045a, 0x25311b0d, 0x2a002d1a,   // no.da.un_760 ru.sr.uk_553  tr.az.eu_554 sk.mt.un_760
  0x2900170e, 0x25311b13, 0x32251b13, 0x1a011bad,   // sr.sl.un_550 tr.az.eu_665  tr.eu.bs_665 tr.en.tl_643
  0x17002d08, 0x130d1cac, 0x64002818, 0x53120cad,   // sk.sr.un_430 mr.ne.bh_632  sw.lg.un_740 sv.hu.ht_643
  0x12004a08, 0x0d001909, 0x12004a05, 0x21011b08,   // yo.hu.un_430 gl.cs.un_440  yo.hu.un_330 tr.en.jw_443
  // [0b50]
  0x211e1ca4, 0x131a10a7, 0x28640507, 0x211218ec,   // id.ms.jw_433 lt.tl.et_532  fr.lg.sw_432 ar.ur.fa_644
  0x18190a04, 0x0b001b0d, 0x16001f08, 0x23000705,   // pt.gl.ga_332 tr.es.un_540  cy.hr.un_430 it.ca.un_330
  0x2500170d, 0x170d0f08, 0x25190b55, 0x07170aa4,   // sr.eu.un_540 lv.cs.sr_443  es.gl.eu_442 mk.sr.bg_433
  0x050601ec, 0x16002d08, 0x64005512, 0x07170a04,   // en.de.fr_644 sk.hr.un_430  rw.lg.un_640 mk.sr.bg_332
  // [0b60]
  0x0c000e02, 0x211c1108, 0x1b000a04, 0x646b12ad,   // is.sv.un_220 ro.id.jw_443  pt.tr.un_320 hu.ceb.lg_643
  0x0c000814, 0x11001f0e, 0x270118a7, 0x32001705,   // no.sv.un_660 cy.ro.un_550  ga.en.gd_532 sr.bs.un_330
  0x231c550b, 0x07001002, 0x1800050d, 0x05190bad,   // rw.id.ca_542 be.bg.un_220  fr.ga.un_540 es.gl.fr_643
  0x190405a0, 0x17001614, 0x2500190c, 0x0d001c0d,   // fr.fi.gl_322 hr.sr.un_660  gl.eu.un_530 mr.ne.un_540
  // [0b70]
  0x251f17a0, 0x04001022, 0x17002d0d, 0x08001019,   // sr.cy.eu_322 be.ru.un_870  sk.sr.un_540 be.uk.un_750
  0x13000e08, 0x090d13ec, 0x18211260, 0x521c1eee,   // is.et.un_430 bh.ne.hi_644  ur.fa.ar_664 ms.id.ha_422
  0x3f066ba0, 0x080410a9, 0x2b002d0c, 0x111a4aa0,   // ceb.de.af_322 be.ru.uk_544  sk.vi.un_530 yo.tl.ro_322
  0x29172da4, 0x080704ec, 0x2a001c02, 0x08021faf,   // sk.sr.sl_433 ru.bg.uk_644  id.mt.un_220 cy.da.no_655
  // [0b80]
  0x32001702, 0x08020ca0, 0x08020fee, 0x0a040702,   // sr.bs.un_220 sv.da.no_322  lv.da.no_422 bg.ru.mk_222
  0x091c0d08, 0x0900131a, 0x0d001c21, 0x07001109,   // ne.mr.hi_443 bh.hi.un_760  mr.ne.un_860 ro.it.un_440
  0x0800041b, 0x17002914, 0x04003b12, 0x13040cad,   // ru.uk.un_770 sl.sr.un_660  so.fi.un_640 sv.fi.et_643
  0x12211813, 0x281b53a4, 0x1b005214, 0x55003b07,   // ar.fa.ur_665 ht.tr.sw_433  ha.tr.un_660 so.rw.un_420
  // [0b90]
  0x06002519, 0x07000d08, 0x07171104, 0x19112308,   // eu.de.un_750 cs.it.un_430  ro.sr.bg_332 ca.ro.gl_443
  0x64205355, 0x20005319, 0x11230760, 0x1b000e13,   // ht.sq.lg_442 ht.sq.un_750  it.ca.ro_664 is.tr.un_650
  0x27001119, 0x00001c0a, 0x32000707, 0x170a04af,   // ro.gd.un_750 id.un.un_500  it.bs.un_420 ru.mk.sr_655
  0x0a081708, 0x18002b07, 0x52003204, 0x09001319,   // sr.uk.mk_443 vi.ga.un_420  bs.ha.un_320 bh.hi.un_750
  // [0ba0]
  0x52000e08, 0x170804a4, 0x080235ec, 0x19000a0e,   // is.ha.un_430 ru.uk.sr_433  zu.da.no_644 pt.gl.un_550
  0x23004a07, 0x0a07040b, 0x1e1c0ea0, 0x07001013,   // yo.ca.un_420 ru.bg.mk_542  is.id.ms_322 be.bg.un_650
  0x170411ee, 0x1f00012a, 0x0b0c0812, 0x27006e08,   // ro.ru.sr_422 en.cy.un_970  no.sv.es_654 hmn.gd.un_430
  0x0708100c, 0x040918a4, 0x2d010d07, 0x11190b04,   // be.uk.bg_543 ga.pl.fi_433  cs.en.sk_432 es.gl.ro_332
  // [0bb0]
  0x1b311ca0, 0x00006b0f, 0x1b07310c, 0x1c130d08,   // id.az.tr_322 ceb.un.un_600  az.it.tr_543 ne.bh.mr_443
  0x1a006e12, 0x1b3b0708, 0x10000f1a, 0x0f001705,   // hmn.tl.un_640 it.so.tr_443  lv.lt.un_760 sr.lv.un_330
  0x13090daf, 0x09121112, 0x07041705, 0x010a2304,   // ne.hi.bh_655 ro.hu.pl_654  sr.ru.bg_333 ca.pt.en_332
  0x090d1c0c, 0x08020c0e, 0x12182112, 0x3f00011a,   // mr.ne.hi_543 sv.da.no_555  fa.ar.ur_654 en.af.un_760
  // [0bc0]
  0x1f070fa4, 0x2900320d, 0x091c0d11, 0x0428250c,   // lv.it.cy_433 bs.sl.un_540  ne.mr.hi_653 eu.sw.fi_543
  0x1325040b, 0x0800021b, 0x2500041b, 0x070a08a4,   // fi.eu.et_542 da.no.un_770  fi.eu.un_770 uk.mk.bg_433
  0x162d29a4, 0x2b001319, 0x2100121b, 0x0e000c08,   // sl.sk.hr_433 et.vi.un_750  ur.fa.un_770 sv.is.un_430
  0x2b0421a4, 0x12054a07, 0x03005204, 0x32161702,   // jw.fi.vi_433 yo.fr.hu_432  ha.nl.un_320 sr.hr.bs_222
  // [0bd0]
  0x042825ad, 0x011308ee, 0x28042508, 0x0b2d1907,   // eu.sw.fi_643 no.et.en_422  eu.fi.sw_443 gl.sk.es_432
  0x04282555, 0x03180612, 0x1b005312, 0x13000c12,   // eu.sw.fi_442 de.ga.nl_654  ht.tr.un_640 sv.et.un_640
  0x280425a9, 0x01000d08, 0x00001706, 0x3b3f01ad,   // eu.fi.sw_544 cs.en.un_430  sr.un.un_400 en.af.so_643
  0x28192512, 0x08020c55, 0x0e003b12, 0x55001b13,   // eu.gl.sw_654 sv.da.no_442  so.is.un_640 tr.rw.un_650
  // [0be0]
  0x351a1bad, 0x08171009, 0x170a07af, 0x063f0ca0,   // tr.tl.zu_643 be.sr.uk_444  bg.mk.sr_655 sv.af.de_322
  0x17001013, 0x110501a4, 0x3b1e1c0e, 0x08023f05,   // lt.sr.un_650 en.fr.ro_433  id.ms.so_555 af.da.no_333
  0x52003121, 0x31003b14, 0x24000121, 0x1c091305,   // az.ha.un_860 so.az.un_660  iw.yi.un_860 bh.hi.mr_333
  0x25042812, 0x061f010b, 0x55256409, 0x27003514,   // sw.fi.eu_654 en.cy.de_542  lg.eu.rw_444 zu.gd.un_660
  // [0bf0]
  0x0400250d, 0x130f64a0, 0x216b1aec, 0x042825ec,   // eu.fi.un_540 lg.lv.et_322  tl.ceb.jw_644 eu.sw.fi_644
  0x6b3b52ee, 0x09001c20, 0x051123af, 0x063f2512,   // ha.so.ceb_422 mr.hi.un_850  ca.ro.fr_655 eu.af.de_654
  0x1f00351b, 0x112305a4, 0x08020c14, 0x552d0d13,   // zu.cy.un_770 fr.ca.ro_433  sv.da.no_666 cs.sk.rw_665
  0x123f3baf, 0x00000303, 0x05005304, 0x1b001f13,   // so.af.hu_655 nl.un.un_300  ht.fr.un_320 cy.tr.un_650

  // [0c00]
  0x3f002109, 0x351a55a4, 0x1f002108, 0x25005507,   // jw.af.un_440 rw.tl.zu_433  jw.cy.un_430 rw.eu.un_420
  0x06000419, 0x0f135504, 0x0b001c02, 0x040710ad,   // fi.de.un_750 rw.et.lv_332  id.es.un_220 be.bg.ru_643
  0x2300030c, 0x213b1c02, 0x52000504, 0x00001f01,   // nl.ca.un_530 id.so.jw_222  fr.ha.un_320 cy.un.un_200
  0x12001f23, 0x551b6bac, 0x17100808, 0x35001308,   // cy.hu.un_880 ceb.tr.rw_632  uk.be.sr_443 et.zu.un_430
  // [0c10]
  0x0d290a0b, 0x3f033baf, 0x55001b19, 0x20013fa0,   // pt.sl.cs_542 so.nl.af_655  tr.rw.un_750 af.en.sq_322
  0x2100351a, 0x19000b1a, 0x110a10ad, 0x05555304,   // zu.jw.un_760 es.gl.un_760  lt.pt.ro_643 ht.rw.fr_332
  0x32161707, 0x063f0307, 0x555305a4, 0x3f0306a9,   // sr.hr.bs_432 nl.af.de_432  fr.ht.rw_433 de.nl.af_544
  0x09000d14, 0x190b0aa0, 0x03003519, 0x033f3bee,   // ne.hi.un_660 pt.es.gl_322  zu.nl.un_750 so.af.nl_422
  // [0c20]
  0x0c07010c, 0x02200807, 0x292d32a0, 0x32125505,   // en.it.sv_543 no.sq.da_432  bs.sk.sl_322 rw.hu.bs_333
  0x080a0708, 0x3b09290c, 0x310420a7, 0x1a006b14,   // bg.mk.uk_443 sl.pl.so_543  sq.fi.az_532 ceb.tl.un_660
  0x1c001304, 0x1a120fa4, 0x182112ec, 0x18122160,   // bh.mr.un_320 lv.hu.tl_433  ur.fa.ar_644 fa.ur.ar_664
  0x1309270b, 0x09001c05, 0x0000640f, 0x07081709,   // gd.pl.et_542 mr.hi.un_330  lg.un.un_600 sr.uk.bg_444
  // [0c30]
  0x3f004a04, 0x170d29a4, 0x13000d14, 0x09130d12,   // yo.af.un_320 sl.cs.sr_433  ne.bh.un_660 ne.bh.hi_654
  0x1f001113, 0x18203b08, 0x321701a4, 0x232501a4,   // ro.cy.un_650 so.sq.ga_443  en.sr.bs_433 en.eu.ca_433
  0x07552a08, 0x11002508, 0x25001120, 0x122118ad,   // mt.rw.it_443 eu.ro.un_430  ro.eu.un_850 ar.fa.ur_643
  0x04000c21, 0x092d08a0, 0x07040813, 0x182701a4,   // sv.fi.un_860 no.sk.pl_322  uk.ru.bg_665 en.gd.ga_433
  // [0c40]
  0x070804af, 0x18002713, 0x3f060eee, 0x25190b02,   // ru.uk.bg_655 gd.ga.un_650  is.de.af_422 es.gl.eu_222
  0x120c08a0, 0x11002502, 0x090d1c14, 0x28355207,   // no.sv.hu_322 eu.ro.un_220  mr.ne.hi_666 ha.zu.sw_432
  0x18122111, 0x18002719, 0x25111c12, 0x2b002513,   // fa.ur.ar_653 gd.ga.un_750  id.ro.eu_654 eu.vi.un_650
  0x0604050c, 0x06003f05, 0x19120a07, 0x08000413,   // fr.fi.de_543 af.de.un_330  pt.hu.gl_432 ru.uk.un_650
  // [0c50]
  0x25001114, 0x170a1107, 0x0b0a19a4, 0x0000280a,   // ro.eu.un_660 ro.mk.sr_432  gl.pt.es_433 sw.un.un_500
  0x06003505, 0x070501a9, 0x00006424, 0x06002304,   // zu.de.un_330 en.fr.it_544  lg.un.un_900 ca.de.un_320
  0x12190b55, 0x533f0304, 0x0900280d, 0x5504280c,   // es.gl.hu_442 nl.af.ht_332  sw.pl.un_540 sw.fi.rw_543
  0x04100813, 0x64216b08, 0x2700181a, 0x0d0f040b,   // uk.be.ru_665 ceb.jw.lg_443  ga.gd.un_760 fi.lv.cs_542
  // [0c60]
  0x3f2b35a0, 0x6b002809, 0x321e1c55, 0x01003508,   // zu.vi.af_322 sw.ceb.un_440  id.ms.bs_442 zu.en.un_430
  0x1800272a, 0x522032a0, 0x041711ee, 0x07110a14,   // gd.ga.un_970 bs.sq.ha_322  ro.sr.ru_422 mk.ro.bg_666
  0x1e211c04, 0x1c1309af, 0x64003519, 0x00000103,   // id.jw.ms_332 hi.bh.mr_655  zu.lg.un_750 en.un.un_300
  0x040a1713, 0x17000a0c, 0x00001124, 0x3564550d,   // sr.mk.ru_665 mk.sr.un_530  ro.un.un_900 rw.lg.zu_554
  // [0c70]
  0x09321604, 0x211c5204, 0x3f031fee, 0x040810ec,   // hr.bs.pl_332 ha.id.jw_332  cy.nl.af_422 be.uk.ru_644
  0x52002d1a, 0x17000807, 0x25001121, 0x033f1f55,   // sk.ha.un_760 uk.sr.un_420  ro.eu.un_860 cy.af.nl_442
  0x091c0d13, 0x32002d07, 0x552853a4, 0x25001112,   // ne.mr.hi_665 sk.bs.un_420  ht.sw.rw_433 ro.eu.un_640
  0x530b1112, 0x13090d13, 0x28355212, 0x100f1707,   // ro.es.ht_654 ne.hi.bh_665  ha.zu.sw_654 sr.lv.lt_432
  // [0c80]
  0x53110b07, 0x3235090c, 0x0e081f07, 0x122d0d0e,   // es.ro.ht_432 pl.zu.bs_543  cy.no.is_432 cs.sk.hu_555
  0x552164a9, 0x033f28a4, 0x081102ec, 0x1c0d13ad,   // lg.jw.rw_544 sw.af.nl_433  da.ro.no_644 bh.ne.mr_643
  0x4a52060c, 0x5521350c, 0x08270607, 0x1a006404,   // de.ha.yo_543 zu.jw.rw_543  de.gd.no_432 lg.tl.un_320
  0x192301a4, 0x06080e07, 0x04000822, 0x201e1c07,   // en.ca.gl_433 is.no.de_432  uk.ru.un_870 id.ms.sq_432
  // [0c90]
  0x28211cee, 0x17040709, 0x050135a0, 0x00002806,   // id.jw.sw_422 bg.ru.sr_444  zu.en.fr_322 sw.un.un_400
  0x081f0204, 0x170f100c, 0x52000d13, 0x5300551a,   // da.cy.no_332 lt.lv.sr_543  cs.ha.un_650 rw.ht.un_760
  0x13210fa4, 0x0807100c, 0x13001c04, 0x170a0705,   // lv.jw.et_433 be.bg.uk_543  id.et.un_320 bg.mk.sr_333
  0x250605a7, 0x080a17a4, 0x28001e08, 0x07002a04,   // fr.de.eu_532 sr.mk.uk_433  ms.sw.un_430 mt.it.un_320
  // [0ca0]
  0x10040812, 0x32000408, 0x3500280d, 0x32000b04,   // uk.ru.be_654 fi.bs.un_430  sw.zu.un_540 es.bs.un_320
  0x0400111a, 0x08000512, 0x08021fa4, 0x6b18270d,   // ro.ru.un_760 fr.no.un_640  cy.da.no_433 gd.ga.ceb_554
  0x68521ea0, 0x07000108, 0x35006807, 0x3f000307,   // ms.ha.ig_322 en.it.un_430  ig.zu.un_420 nl.af.un_420
  0x27001821, 0x52280b07, 0x0a041105, 0x0c1204ad,   // ga.gd.un_860 es.sw.ha_432  ro.ru.mk_333 fi.hu.sv_643
  // [0cb0]
  0x13001814, 0x080704ad, 0x112953a0, 0x1a2a1e0c,   // ga.et.un_660 ru.bg.uk_643  ht.sl.ro_322 ms.mt.tl_543
  0x0c00061b, 0x27001819, 0x07081009, 0x35005512,   // de.sv.un_770 ga.gd.un_750  be.uk.bg_444 rw.zu.un_640
  0x01000618, 0x55642105, 0x550b530c, 0x211c1ead,   // de.en.un_740 jw.lg.rw_333  ht.es.rw_543 ms.id.jw_643
  0x532d3bee, 0x530b11ec, 0x532921ee, 0x230e5255,   // so.sk.ht_422 ro.es.ht_644  jw.sl.ht_422 ha.is.ca_442
  // [0cc0]
  0x1c002113, 0x04071104, 0x210c03ee, 0x0800170b,   // jw.id.un_650 ro.bg.ru_332  nl.sv.jw_422 sr.no.un_520
  0x0c070eee, 0x2d290d0e, 0x0c550611, 0x0900250d,   // is.it.sv_422 cs.sl.sk_555  de.rw.sv_653 eu.pl.un_540
  0x2723180c, 0x0b00110d, 0x1c130902, 0x2d0d0caf,   // ga.ca.gd_543 ro.es.un_540  hi.bh.mr_222 sv.cs.sk_655
  0x0f050408, 0x044a230c, 0x0d000923, 0x213b13ad,   // fi.fr.lv_443 ca.yo.fi_543  hi.ne.un_880 et.so.jw_643
  // [0cd0]
  0x04071709, 0x03053fee, 0x322117a0, 0x161710a6,   // sr.bg.ru_444 af.fr.nl_422  sr.jw.bs_322 lt.sr.hr_521
  0x0b000a0e, 0x3f002105, 0x1b000f0b, 0x020c0807,   // pt.es.un_550 jw.af.un_330  lv.tr.un_520 no.sv.da_432
  0x3b006e0c, 0x2d290d07, 0x03003f0c, 0x0000250a,   // hmn.so.un_530 cs.sl.sk_432  af.nl.un_530 eu.un.un_500
  0x1000292a, 0x27101812, 0x00000824, 0x08041104,   // sl.lt.un_970 ga.lt.gd_654  no.un.un_900 ro.ru.uk_332
  // [0ce0]
  0x2d0d1905, 0x2800211a, 0x0a182712, 0x04211f05,   // gl.cs.sk_333 jw.sw.un_760  gd.ga.pt_654 cy.jw.fi_333
  0x056e0aee, 0x080a1005, 0x07040aa9, 0x09005504,   // pt.hmn.fr_422 be.mk.uk_333  mk.ru.bg_544 rw.pl.un_320
  0x17291f0c, 0x1a006b13, 0x2013075a, 0x0c001121,   // cy.sl.sr_543 ceb.tl.un_650  it.et.sq_553 ro.sv.un_860
  0x0a041704, 0x1f520eec, 0x6b011aa4, 0x1a211e07,   // sr.ru.mk_332 is.ha.cy_644  tl.en.ceb_433 ms.jw.tl_432
  // [0cf0]
  0x09000d19, 0x1c1f21ad, 0x02000818, 0x07081708,   // ne.hi.un_750 jw.cy.id_643  no.da.un_740 sr.uk.bg_443
  0x6b001a14, 0x293120ee, 0x0e001c08, 0x23000108,   // tl.ceb.un_660 sq.az.sl_422  id.is.un_430 en.ca.un_430
  0x11000508, 0x041008a4, 0x03003f13, 0x080b1aa0,   // fr.ro.un_430 uk.be.ru_433  af.nl.un_650 tl.es.no_322
  0x0f2a1f08, 0x09001311, 0x171011a0, 0x536410a7,   // cy.mt.lv_443 bh.hi.un_630  ro.be.sr_322 lt.lg.ht_532
  // [0d00]
  0x1c00250b, 0x06005314, 0x2a000708, 0x01641aee,   // eu.id.un_520 ht.de.un_660  it.mt.un_430 tl.lg.en_422
  0x16111e04, 0x08022105, 0x3b132808, 0x19003f0c,   // ms.ro.hr_332 jw.da.no_333  sw.et.so_443 af.gl.un_530
  0x182753a4, 0x1c1f23a7, 0x2a1629a4, 0x012b1a07,   // ht.gd.ga_433 ca.cy.id_532  sl.hr.mt_433 tl.vi.en_432
  0x6b230b08, 0x3f0753a0, 0x08070413, 0x04111705,   // es.ca.ceb_443 ht.it.af_322  ru.bg.uk_665 sr.ro.ru_333
  // [0d10]
  0x3b00680d, 0x321617ec, 0x1000091b, 0x0800101b,   // ig.so.un_540 sr.hr.bs_644  pl.lt.un_770 be.uk.un_770
  0x0d001c19, 0x10000414, 0x1629120c, 0x181e1c09,   // mr.ne.un_750 ru.be.un_660  hu.sl.hr_543 id.ms.ga_444
  0x1b3f3107, 0x5300110b, 0x02000804, 0x1c211eee,   // az.af.tr_432 ro.ht.un_520  no.da.un_320 ms.jw.id_422
  0x090d1c11, 0x2a091f12, 0x52552355, 0x6b1a210c,   // mr.ne.hi_653 cy.pl.mt_654  ca.rw.ha_442 jw.tl.ceb_543
  // [0d20]
  0x0e6411a7, 0x2b00050c, 0x27230d07, 0x20000804,   // ro.lg.is_532 fr.vi.un_530  cs.ca.gd_432 no.sq.un_320
  0x3b00252a, 0x3b0908a4, 0x32001608, 0x6b1a2511,   // eu.so.un_970 no.pl.so_433  hr.bs.un_430 eu.tl.ceb_653
  0x2a032807, 0x12005312, 0x3f250ea4, 0x09350808,   // sw.nl.mt_432 ht.hu.un_640  is.eu.af_433 no.zu.pl_443
  0x551c1a0c, 0x1b0e2304, 0x212801a0, 0x32171655,   // tl.id.rw_543 ca.is.tr_332  en.sw.jw_322 hr.sr.bs_442
  // [0d30]
  0x2a3201ad, 0x040a0714, 0x1a520ead, 0x0900351a,   // en.bs.mt_643 bg.mk.ru_666  is.ha.tl_643 zu.pl.un_760
  0x2d0a05a4, 0x06000308, 0x2d0d1ea0, 0x1a0a64a0,   // fr.pt.sk_433 nl.de.un_430  ms.cs.sk_322 lg.pt.tl_322
  0x00000924, 0x1c214a11, 0x2b002102, 0x19645513,   // pl.un.un_900 yo.jw.id_653  jw.vi.un_220 rw.lg.gl_665
  0x0917350c, 0x2a07520c, 0x1b281308, 0x556e210c,   // zu.sr.pl_543 ha.it.mt_543  et.sw.tr_443 jw.hmn.rw_543
  // [0d40]
  0x11040a13, 0x551f2809, 0x0900101a, 0x0b214a0c,   // mk.ru.ro_665 sw.cy.rw_444  lt.pl.un_760 yo.jw.es_543
  0x5500041b, 0x100a17a4, 0x0a001004, 0x5235090d,   // fi.rw.un_770 sr.mk.be_433  be.mk.un_320 pl.zu.ha_554
  0x2128350c, 0x52000808, 0x1800212a, 0x4a00202a,   // zu.sw.jw_543 no.ha.un_430  fa.ar.un_970 sq.yo.un_970
  0x21002819, 0x32082da4, 0x641b35a4, 0x1b64280c,   // sw.jw.un_750 sk.no.bs_433  zu.tr.lg_433 sw.lg.tr_543
  // [0d50]
  0x355513ad, 0x21682a07, 0x52281705, 0x1b521c07,   // et.rw.zu_643 mt.ig.jw_432  sr.sw.ha_333 id.ha.tr_432
  0x21000804, 0x10000412, 0x09001c02, 0x4a00551a,   // no.jw.un_320 ru.be.un_640  id.pl.un_220 rw.yo.un_760
  0x11131a08, 0x3f1f09a4, 0x28114a05, 0x3f02080c,   // tl.et.ro_443 pl.cy.af_433  yo.ro.sw_333 no.da.af_543
  0x0e1b2a12, 0x1c0d0955, 0x0e1f2a5a, 0x17040708,   // mt.tr.is_654 hi.ne.mr_442  mt.cy.is_553 bg.ru.sr_443
  // [0d60]
  0x53124a04, 0x1b3508a4, 0x13006819, 0x07531112,   // yo.hu.ht_332 no.zu.tr_433  ig.et.un_750 ro.ht.it_654
  0x281b3513, 0x211c4a04, 0x2a1c1e0c, 0x04110a5a,   // zu.tr.sw_665 yo.id.jw_332  ms.id.mt_543 mk.ro.ru_553
  0x4a2504a4, 0x0a071708, 0x1b00350d, 0x181f2713,   // fi.eu.yo_433 sr.bg.mk_443  zu.tr.un_540 gd.cy.ga_665
  0x13020812, 0x1e1c21ee, 0x25071ca4, 0x0e2a0d07,   // no.da.et_654 jw.id.ms_422  id.it.eu_433 cs.mt.is_432
  // [0d70]
  0x08040712, 0x1300351b, 0x090d1cec, 0x1a6b5513,   // bg.ru.uk_654 zu.et.un_770  mr.ne.hi_644 rw.ceb.tl_665
  0x28033509, 0x2a351f12, 0x23190b0d, 0x081b12a9,   // zu.nl.sw_444 cy.zu.mt_654  es.gl.ca_554 hu.tr.no_544
  0x1700090c, 0x292808a0, 0x641e1c08, 0x08020aa4,   // pl.sr.un_530 no.sw.sl_322  id.ms.lg_443 pt.da.no_433
  0x3b1b060d, 0x2d05210c, 0x3b1b3202, 0x2d0d210c,   // de.tr.so_554 jw.fr.sk_543  bs.tr.so_222 jw.cs.sk_543
  // [0d80]
  0x1b0452ad, 0x0f1b12a7, 0x35041eee, 0x4a2052ec,   // ha.fi.tr_643 hu.tr.lv_532  ms.fi.zu_422 ha.sq.yo_644
  0x1a286455, 0x2a001108, 0x0900130d, 0x2d04680c,   // lg.sw.tl_442 ro.mt.un_430  bh.hi.un_540 ig.fi.sk_543
  0x0f000104, 0x21281c0c, 0x0652350c, 0x21001e04,   // en.lv.un_320 id.sw.jw_543  zu.ha.de_543 ms.jw.un_320
  0x2d6435a4, 0x1e091ca0, 0x1000081a, 0x10070a04,   // zu.lg.sk_433 id.pl.ms_322  uk.be.un_760 mk.bg.be_332
  // [0d90]
  0x07040a0c, 0x08041105, 0x3b1e1c04, 0x352821a0,   // mk.ru.bg_543 ro.ru.uk_333  id.ms.so_332 jw.sw.zu_322
  0x11080705, 0x321b3155, 0x2568060c, 0x1b090d07,   // bg.uk.ro_333 az.tr.bs_442  de.ig.eu_543 cs.pl.tr_432
  0x101c2ba9, 0x0912350c, 0x21534aa7, 0x11001602,   // vi.id.lt_544 zu.hu.pl_543  yo.ht.jw_532 hr.ro.un_220
  0x4a100aa7, 0x0a0711af, 0x070a1705, 0x12351b60,   // pt.lt.yo_532 ro.bg.mk_655  sr.mk.bg_333 tr.zu.hu_664
  // [0da0]
  0x1c0d090d, 0x0b001919, 0x3b1025a4, 0x3f031208,   // hi.ne.mr_554 gl.es.un_750  eu.lt.so_433 hu.nl.af_443
  0x1600320d, 0x201e2104, 0x2d0d520c, 0x2d0d1005,   // bs.hr.un_540 jw.ms.sq_332  ha.cs.sk_543 lt.cs.sk_333
  0x16321704, 0x111b12a9, 0x13124aa4, 0x1c211ea9,   // sr.bs.hr_332 hu.tr.ro_544  yo.hu.et_433 ms.jw.id_544
  0x170804ec, 0x1b112aaf, 0x08070a04, 0x121b0107,   // ru.uk.sr_644 mt.ro.tr_655  mk.bg.uk_332 en.tr.hu_432
  // [0db0]
  0x0e004a0e, 0x00005501, 0x0c120802, 0x081707a4,   // yo.is.un_550 rw.un.un_200  no.hu.sv_222 bg.sr.uk_433
  0x070a04ad, 0x00000f2d, 0x0708110c, 0x0000291c,   // ru.mk.bg_643 lv.un.un_A00  ro.uk.bg_543 sl.un.un_800
  0x233555ee, 0x52133ba0, 0x00000f03, 0x6435550e,   // rw.zu.ca_422 so.et.ha_322  lv.un.un_300 rw.zu.lg_555
  0x09001c0c, 0x0a170409, 0x200f1308, 0x18000e14,   // mr.hi.un_530 ru.sr.mk_444  et.lv.sq_443 is.ga.un_660
  // [0dc0]
  0x0a071107, 0x00000f01, 0x3f060305, 0x0f3b100b,   // ro.bg.mk_432 lv.un.un_200  nl.de.af_333 lt.so.lv_542
  0x55643508, 0x55002813, 0x1e1c1ba4, 0x17000a22,   // zu.lg.rw_443 sw.rw.un_650  tr.id.ms_433 mk.sr.un_870
  0x07041108, 0x110a1705, 0x0a1711ad, 0x052d0d04,   // ro.ru.bg_443 sr.mk.ro_333  ro.sr.mk_643 cs.sk.fr_332
  0x2d001702, 0x17070a5a, 0x101c1ea0, 0x32173ba0,   // sr.sk.un_220 mk.bg.sr_553  ms.id.lt_322 so.sr.bs_322
  // [0dd0]
  0x21001829, 0x11002104, 0x1c091307, 0x0a0704a9,   // ar.fa.un_960 jw.ro.un_320  bh.hi.mr_432 ru.bg.mk_544
  0x01230b05, 0x3b020fa0, 0x35215505, 0x11000b05,   // es.ca.en_333 lv.da.so_322  rw.jw.zu_333 es.ro.un_330
  0x13006b19, 0x030553a0, 0x4a133b55, 0x122813ec,   // ceb.et.un_750 ht.fr.nl_322  so.et.yo_442 et.sw.hu_644
  0x0a001007, 0x3b006b2b, 0x2500130d, 0x1117080c,   // be.mk.un_420 ceb.so.un_980  et.eu.un_540 uk.sr.ro_543
  // [0de0]
  0x11000518, 0x0e02080c, 0x3b6b6412, 0x1a6e200c,   // fr.ro.un_740 no.da.is_543  lg.ceb.so_654 sq.hmn.tl_543
  0x06003b14, 0x08001c05, 0x1c081e08, 0x1b3b1c55,   // so.de.un_660 id.no.un_330  ms.no.id_443 id.so.tr_442
  0x3f03080c, 0x270e0812, 0x070a0808, 0x64005504,   // no.nl.af_543 no.is.gd_654  uk.mk.bg_443 rw.lg.un_320
  0x130e1b55, 0x3500080d, 0x2d000919, 0x64003b18,   // tr.is.et_442 no.zu.un_540  pl.sk.un_750 so.lg.un_740
  // [0df0]
  0x122d1812, 0x10000f1b, 0x0e030604, 0x033f06af,   // ga.sk.hu_654 lv.lt.un_770  de.nl.is_332 de.af.nl_655
  0x1300092a, 0x080c2107, 0x00003b0a, 0x033f25a4,   // hi.bh.un_970 jw.sv.no_432  so.un.un_500 eu.af.nl_433
  0x133b04ec, 0x10093f05, 0x12000e13, 0x033f06ee,   // fi.so.et_644 af.pl.lt_333  is.hu.un_650 de.af.nl_422
  0x023f080c, 0x08041707, 0x12000e0e, 0x0a00070c,   // no.af.da_543 sr.ru.uk_432  is.hu.un_550 bg.mk.un_530
  // [0e00]
  0x0d1c095a, 0x10001a08, 0x04081012, 0x03286404,   // hi.mr.ne_553 tl.lt.un_430  be.uk.ru_654 lg.sw.nl_332
  0x092d0d13, 0x3b006422, 0x0000120a, 0x2d0d01af,   // cs.sk.pl_665 lg.so.un_870  hu.un.un_500 en.cs.sk_655
  0x212305ec, 0x03643ba4, 0x0706010c, 0x11070a09,   // fr.ca.jw_644 so.lg.nl_433  en.de.it_543 mk.bg.ro_444
  0x0b0d2dad, 0x281c21a0, 0x64136b07, 0x20280111,   // sk.cs.es_643 jw.id.sw_322  ceb.et.lg_432 en.sw.sq_653
  // [0e10]
  0x0d091ca4, 0x04001012, 0x07040860, 0x110c08a0,   // mr.hi.ne_433 lt.fi.un_640  uk.ru.bg_664 no.sv.ro_322
  0x12002d1a, 0x0b00190c, 0x31002a1a, 0x17070a0c,   // sk.hu.un_760 gl.es.un_530  mt.az.un_760 mk.bg.sr_543
  0x1c00130e, 0x3f060304, 0x1c00131b, 0x00000b0a,   // bh.mr.un_550 nl.de.af_332  bh.mr.un_770 es.un.un_500
  0x02000807, 0x08001714, 0x3b2127ac, 0x2d18120c,   // no.da.un_420 sr.uk.un_660  gd.jw.so_632 hu.ga.sk_543
  // [0e20]
  0x0e000804, 0x2a080605, 0x050123ee, 0x08020caf,   // no.is.un_320 de.no.mt_333  ca.en.fr_422 sv.da.no_655
  0x0e122d0b, 0x2d0d010c, 0x0f00530d, 0x0e002a2b,   // sk.hu.is_542 en.cs.sk_543  ht.lv.un_540 mt.is.un_980
  0x32170c05, 0x07000e0e, 0x210812ad, 0x3b18640e,   // sv.sr.bs_333 is.it.un_550  hu.no.jw_643 lg.ga.so_555
  0x0e0807af, 0x2900530d, 0x3b290da4, 0x53005202,   // it.no.is_655 ht.sl.un_540  cs.sl.so_433 ha.ht.un_220
  // [0e30]
  0x041128a9, 0x190a1111, 0x092811ec, 0x0d1309ad,   // sw.ro.fi_544 ro.pt.gl_653  ro.sw.pl_644 hi.bh.ne_643
  0x0e080260, 0x01005304, 0x28091112, 0x10000507,   // da.no.is_664 ht.en.un_320  ro.pl.sw_654 fr.lt.un_420
  0x016b1ba0, 0x11003b29, 0x29090da4, 0x060c0204,   // tr.ceb.en_322 so.ro.un_960  cs.pl.sl_433 da.sv.de_332
  0x0e093ba9, 0x281168a0, 0x2a0c3b60, 0x16290da4,   // so.pl.is_544 ig.ro.sw_322  so.sv.mt_664 cs.sl.hr_433
  // [0e40]
  0x18080213, 0x17000608, 0x3b2a09ec, 0x131b0c08,   // da.no.ga_665 de.sr.un_430  pl.mt.so_644 sv.tr.et_443
  0x0d091108, 0x09113baf, 0x080203af, 0x10115208,   // ro.pl.cs_443 so.ro.pl_655  nl.da.no_655 ha.ro.lt_443
  0x23002519, 0x0400110d, 0x170208a4, 0x28316b08,   // eu.ca.un_750 ro.ru.un_540  no.da.sr_433 ceb.az.sw_443
  0x290c0da4, 0x64005522, 0x3b2d115a, 0x03000222,   // cs.sv.sl_433 rw.lg.un_870  ro.sk.so_553 da.nl.un_870
  // [0e50]
  0x3f071208, 0x0e080208, 0x08090207, 0x162a5507,   // hu.it.af_443 da.no.is_443  da.pl.no_432 rw.mt.hr_432
  0x0832165a, 0x0e3b0814, 0x13000e05, 0x5303050c,   // hr.bs.no_553 no.so.is_666  is.et.un_330 fr.nl.ht_543
  0x03193513, 0x4a001c04, 0x35000804, 0x1c0913a9,   // zu.gl.nl_665 id.yo.un_320  no.zu.un_320 bh.hi.mr_544
  0x0c0206af, 0x06080e08, 0x321935a4, 0x25020708,   // de.da.sv_655 is.no.de_443  zu.gl.bs_433 it.da.eu_443
  // [0e60]
  0x21001c12, 0x06033f12, 0x08026eac, 0x10001704,   // id.jw.un_640 af.nl.de_654  hmn.da.no_632 sr.lt.un_320
  0x1b100aaf, 0x19001107, 0x29080260, 0x19000a1b,   // pt.lt.tr_655 ro.gl.un_420  da.no.sl_664 pt.gl.un_770
  0x043b1112, 0x07041002, 0x02061802, 0x04170a05,   // ro.so.fi_654 be.ru.bg_222  ga.de.da_222 mk.sr.ru_333
  0x07001208, 0x21001c0c, 0x09110d11, 0x19230b07,   // hu.it.un_430 id.jw.un_530  cs.ro.pl_653 es.ca.gl_432
  // [0e70]
  0x09000d09, 0x04113ba9, 0x11003202, 0x090411ad,   // ne.hi.un_440 so.ro.fi_544  bs.ro.un_220 ro.fi.pl_643
  0x3f190a14, 0x284a68a9, 0x1805535e, 0x1c1a0a07,   // pt.gl.af_666 ig.yo.sw_544  ht.fr.ga_652 pt.tl.id_432
  0x32171613, 0x20000104, 0x06003b12, 0x11072905,   // hr.sr.bs_665 en.sq.un_320  so.de.un_640 sl.it.ro_333
  0x2a00060e, 0x1f211aee, 0x6b1a53ec, 0x020b08a4,   // de.mt.un_550 tl.jw.cy_422  ht.tl.ceb_644 no.es.da_433
  // [0e80]
  0x09004a04, 0x13091c60, 0x0100240c, 0x0300061a,   // yo.pl.un_320 mr.hi.bh_664  yi.iw.un_530 de.nl.un_760
  0x083b0c04, 0x02080e5a, 0x08000421, 0x1a6b5312,   // sv.so.no_332 is.no.da_553  ru.uk.un_860 ht.ceb.tl_654
  0x090d1312, 0x0c041313, 0x3f031fec, 0x2900091a,   // bh.ne.hi_654 et.fi.sv_665  cy.nl.af_644 pl.sl.un_760
  0x64005505, 0x06001f22, 0x07041107, 0x0f2a53a0,   // rw.lg.un_330 cy.de.un_870  ro.ru.bg_432 ht.mt.lv_322
  // [0e90]
  0x1c0d09ac, 0x3b000c13, 0x0d181209, 0x122d0d60,   // hi.ne.mr_632 sv.so.un_650  hu.ga.cs_444 cs.sk.hu_664
  0x05070aa0, 0x253528a7, 0x0e0c1107, 0x0a0411a4,   // pt.it.fr_322 sw.zu.eu_532  ro.sv.is_432 ro.ru.mk_433
  0x0c270ea9, 0x0500231b, 0x1e1c20a4, 0x0e00251a,   // is.gd.sv_544 ca.fr.un_770  sq.id.ms_433 eu.is.un_760
  0x23033f07, 0x52006b1a, 0x0300011a, 0x10001702,   // af.nl.ca_432 ceb.ha.un_760  en.nl.un_760 sr.lt.un_220
  // [0ea0]
  0x06005514, 0x53002d04, 0x07171107, 0x19062709,   // rw.de.un_660 sk.ht.un_320  ro.sr.bg_432 gd.de.gl_444
  0x11002507, 0x18211214, 0x041008af, 0x532d0dad,   // eu.ro.un_420 ur.fa.ar_666  uk.be.ru_655 cs.sk.ht_643
  0x0c070e08, 0x162d0d64, 0x271808a0, 0x0a10170d,   // is.it.sv_443 cs.sk.hr_762  no.ga.gd_322 sr.be.mk_554
  0x05012a07, 0x2d3f0d11, 0x532d0dec, 0x0e1306a4,   // mt.en.fr_432 cs.af.sk_653  cs.sk.ht_644 de.et.is_433
  // [0eb0]
  0x09202d0c, 0x53002d13, 0x532d0d0c, 0x04100a02,   // sk.sq.pl_543 sk.ht.un_650  cs.sk.ht_543 mk.be.ru_222
  0x0d091c14, 0x522d53a4, 0x0d000904, 0x02050807,   // mr.hi.ne_666 ht.sk.ha_433  hi.ne.un_320 no.fr.da_432
  0x0e080609, 0x12000807, 0x0a000504, 0x3b09110c,   // de.no.is_444 no.hu.un_420  fr.pt.un_320 ro.pl.so_543
  0x13043ba4, 0x2d0d3fa9, 0x2d290909, 0x09000d08,   // so.fi.et_433 af.cs.sk_544  pl.sl.sk_444 ne.hi.un_430
  // [0ec0]
  0x190a2d14, 0x3f005313, 0x0c081308, 0x00000f0a,   // sk.pt.gl_666 ht.af.un_650  et.no.sv_443 lv.un.un_500
  0x1000521a, 0x09000d04, 0x043552a4, 0x1e080c02,   // ha.lt.un_760 ne.hi.un_320  ha.zu.fi_433 sv.no.ms_222
  0x3b00641a, 0x1a006b0d, 0x1800120e, 0x0c1208a4,   // lg.so.un_760 ceb.tl.un_540  ur.ar.un_550 no.hu.sv_433
  0x170304ad, 0x03050cee, 0x0a001908, 0x32092da4,   // fi.nl.sr_643 sv.fr.nl_422  gl.pt.un_430 sk.pl.bs_433
  // [0ed0]
  0x06080205, 0x171635a0, 0x2d3f3bec, 0x013502a0,   // da.no.de_333 zu.hr.sr_322  so.af.sk_644 da.zu.en_322
  0x4a3b640d, 0x250b19ec, 0x16292d0c, 0x0d002d22,   // lg.so.yo_554 gl.es.eu_644  sk.sl.hr_543 sk.cs.un_870
  0x18080209, 0x09251fad, 0x190a5309, 0x53200aa4,   // da.no.ga_444 cy.eu.pl_643  ht.pt.gl_444 pt.sq.ht_433
  0x06005308, 0x08000213, 0x12000e19, 0x230535ee,   // ht.de.un_430 da.no.un_650  is.hu.un_750 zu.fr.ca_422
  // [0ee0]
  0x32002d08, 0x1600290c, 0x251e1c11, 0x3f291b55,   // sk.bs.un_430 sl.hr.un_530  id.ms.eu_653 tr.sl.af_442
  0x07010b08, 0x0a052aee, 0x1c0913ad, 0x051b53ec,   // es.en.it_443 mt.fr.pt_422  bh.hi.mr_643 ht.tr.fr_644
  0x103f0312, 0x1103050b, 0x130464ad, 0x190a0507,   // nl.af.lt_654 fr.nl.ro_542  lg.fi.et_643 fr.pt.gl_432
  0x0a080208, 0x1c090d14, 0x526421af, 0x00001715,   // da.no.pt_443 ne.hi.mr_666  jw.lg.ha_655 sr.un.un_700
  // [0ef0]
  0x1c130905, 0x17290d07, 0x64003b21, 0x0b1918a9,   // hi.bh.mr_333 cs.sl.sr_432  so.lg.un_860 ga.gl.es_544
  0x201b3109, 0x171008a9, 0x13046413, 0x6e311ba9,   // az.tr.sq_444 uk.be.sr_544  lg.fi.et_665 tr.az.hmn_544
  0x20236e12, 0x5535640c, 0x02000c0e, 0x091f6b04,   // hmn.ca.sq_654 lg.zu.rw_543  sv.da.un_550 ceb.cy.pl_332
  0x0d002d1a, 0x16321760, 0x201b1c0c, 0x201025a4,   // sk.cs.un_760 sr.bs.hr_664  id.tr.sq_543 eu.lt.sq_433
  // [0f00]
  0x0d0f10a9, 0x08021214, 0x0c00130e, 0x19530b0c,   // lt.lv.cs_544 hu.da.no_666  et.sv.un_550 es.ht.gl_543
  0x0a171007, 0x3f060c09, 0x0c020812, 0x02000520,   // be.sr.mk_432 sv.de.af_444  no.da.sv_654 fr.da.un_850
  0x55321602, 0x122d0d04, 0x0d1c09a4, 0x1b040e04,   // hr.bs.rw_222 cs.sk.hu_332  hi.mr.ne_433 is.fi.tr_332
  0x03110511, 0x55526408, 0x090d13a6, 0x091c0d07,   // fr.ro.nl_653 lg.ha.rw_443  bh.ne.hi_521 ne.mr.hi_432
  // [0f10]
  0x030205af, 0x11000519, 0x0d001304, 0x0a071112,   // fr.da.nl_655 fr.ro.un_750  bh.ne.un_320 ro.bg.mk_654
  0x4a0811ee, 0x181f27ee, 0x04081109, 0x271f1008,   // ro.no.yo_422 gd.cy.ga_422  ro.uk.ru_444 lt.cy.gd_443
  0x21556411, 0x0f046b0c, 0x3b033fa9, 0x091c0dad,   // lg.rw.jw_653 ceb.fi.lv_543  af.nl.so_544 ne.mr.hi_643
  0x2a350702, 0x6b551aa4, 0x1c100fec, 0x521c6407,   // it.zu.mt_222 tl.rw.ceb_433  lv.lt.id_644 lg.id.ha_432
  // [0f20]
  0x292d0d09, 0x090d1cad, 0x1c001323, 0x0000532d,   // cs.sk.sl_444 mr.ne.hi_643  bh.mr.un_880 ht.un.un_A00
  0x181221ec, 0x17081007, 0x2d1e1c04, 0x04001704,   // fa.ur.ar_644 be.uk.sr_432  id.ms.sk_332 sr.ru.un_320
  0x0900290c, 0x0f001c04, 0x0d002505, 0x1805270c,   // sl.pl.un_530 id.lv.un_320  eu.cs.un_330 gd.fr.ga_543
  0x033f0eee, 0x063225a0, 0x1707110c, 0x17000423,   // is.af.nl_422 eu.bs.de_322  ro.bg.sr_543 ru.sr.un_880
  // [0f30]
  0x1c09120c, 0x04182712, 0x050a2305, 0x53002104,   // hu.pl.id_543 gd.ga.fi_654  ca.pt.fr_333 jw.ht.un_320
  0x27101f0e, 0x00001803, 0x0c110713, 0x180127ec,   // cy.lt.gd_555 ga.un.un_300  it.ro.sv_665 gd.en.ga_644
  0x35001c07, 0x2d0d09ee, 0x09001c11, 0x071108a0,   // id.zu.un_420 pl.cs.sk_422  mr.hi.un_630 no.ro.it_322
  0x1c1035a0, 0x0d000913, 0x00002503, 0x01091fa9,   // zu.lt.id_322 pl.cs.un_650  eu.un.un_300 cy.pl.en_544
  // [0f40]
  0x09001f2a, 0x3b18550c, 0x25521b09, 0x21551c12,   // cy.pl.un_970 rw.ga.so_543  tr.ha.eu_444 id.rw.jw_654
  0x1b0c555a, 0x2864550c, 0x3b21030c, 0x0c4a1105,   // rw.sv.tr_553 rw.lg.sw_543  nl.jw.so_543 ro.yo.sv_333
  0x2d0d04a0, 0x3b28210d, 0x0d092d11, 0x2d2305ad,   // fi.cs.sk_322 jw.sw.so_554  sk.pl.cs_653 fr.ca.sk_643
  0x092d0d14, 0x23520705, 0x32002909, 0x2300191a,   // cs.sk.pl_666 it.ha.ca_333  sl.bs.un_440 gl.ca.un_760
  // [0f50]
  0x68003b22, 0x10170aa9, 0x10000409, 0x09531212,   // so.ig.un_870 mk.sr.be_544  ru.be.un_440 hu.ht.pl_654
  0x0d0805ad, 0x071008ec, 0x04002707, 0x11035508,   // fr.no.cs_643 uk.be.bg_644  gd.fi.un_420 rw.nl.ro_443
  0x1e18270c, 0x286468ad, 0x17071112, 0x1f1101a7,   // gd.ga.ms_543 ig.lg.sw_643  ro.it.sr_654 en.ro.cy_532
  0x523f3baf, 0x21002021, 0x105232a0, 0x250428a9,   // so.af.ha_655 sq.jw.un_860  bs.ha.lt_322 sw.fi.eu_544
  // [0f60]
  0x01002421, 0x521f2509, 0x35212304, 0x552052a0,   // yi.iw.un_860 eu.cy.ha_444  ca.jw.zu_332 ha.sq.rw_322
  0x1a5213ec, 0x282d09af, 0x2d0d09a9, 0x0600030d,   // et.ha.tl_644 pl.sk.sw_655  pl.cs.sk_544 nl.de.un_540
  0x6b1e1ca9, 0x523b55af, 0x121b2804, 0x28076e08,   // id.ms.ceb_544 rw.so.ha_655  sw.tr.hu_332 hmn.it.sw_443
  0x3f062da0, 0x23052aa4, 0x28001002, 0x110c070c,   // sk.de.af_322 mt.fr.ca_433  lt.sw.un_220 it.sv.ro_543
  // [0f70]
  0x1b001f21, 0x321a6b0c, 0x04002822, 0x2a5327a0,   // cy.tr.un_860 ceb.tl.bs_543  sw.fi.un_870 gd.ht.mt_322
  0x2d293ba4, 0x080704a4, 0x5232170c, 0x011105a4,   // so.sl.sk_433 ru.bg.uk_433  sr.bs.ha_543 fr.ro.en_433
  0x230725a9, 0x2a072509, 0x070c110c, 0x033553ac,   // eu.it.ca_544 eu.it.mt_444  ro.sv.it_543 ht.zu.nl_632
  0x53000804, 0x062507a4, 0x11130707, 0x3f000909,   // no.ht.un_320 it.eu.de_433  it.et.ro_432 pl.af.un_440
  // [0f80]
  0x0a0711ad, 0x1308020d, 0x063f0305, 0x250409af,   // ro.bg.mk_643 da.no.et_554  nl.af.de_333 pl.fi.eu_655
  0x0b00280c, 0x13001c0c, 0x1e033f55, 0x12000d0d,   // sw.es.un_530 mr.bh.un_530  af.nl.ms_442 cs.hu.un_540
  0x10040a07, 0x09005204, 0x3f0608af, 0x0c2a0b09,   // mk.ru.be_432 ha.pl.un_320  no.de.af_655 es.mt.sv_444
  0x05201160, 0x1c0d1312, 0x64005514, 0x090b06a7,   // ro.sq.fr_664 bh.ne.mr_654  rw.lg.un_660 de.es.pl_532
  // [0f90]
  0x09003513, 0x0c0208ec, 0x1107250d, 0x16100da7,   // zu.pl.un_650 no.da.sv_644  eu.it.ro_554 cs.lt.hr_532
  0x21251ca0, 0x060b095a, 0x080c02af, 0x13000d05,   // id.eu.jw_322 pl.es.de_553  da.sv.no_655 ne.bh.un_330
  0x09110b09, 0x211218ad, 0x286b4a0b, 0x1c3b1eac,   // es.ro.pl_444 ar.ur.fa_643  yo.ceb.sw_542 ms.so.id_632
  0x07000a19, 0x684a09a9, 0x21002708, 0x11282da9,   // mk.bg.un_750 pl.yo.ig_544  gd.jw.un_430 sk.sw.ro_544
  // [0fa0]
  0x1e1c200c, 0x2d0d68af, 0x64095307, 0x05006402,   // sq.id.ms_543 ig.cs.sk_655  ht.pl.lg_432 lg.fr.un_220
  0x20002705, 0x12641109, 0x21002d0c, 0x0f09060c,   // gd.sq.un_330 ro.lg.hu_444  sk.jw.un_530 de.pl.lv_543
  0x64355204, 0x3b000104, 0x55002109, 0x3f0b0608,   // ha.zu.lg_332 en.so.un_320  jw.rw.un_440 de.es.af_443
  0x1e000223, 0x0f0506a4, 0x04001c02, 0x03063f0e,   // da.ms.un_880 de.fr.lv_433  id.fi.un_220 af.de.nl_555
  // [0fb0]
  0x3f000313, 0x110608a0, 0x1c0913ee, 0x0b06255a,   // nl.af.un_650 no.de.ro_322  bh.hi.mr_422 eu.de.es_553
  0x2d2b0c02, 0x102b1707, 0x060c0808, 0x2864550e,   // sv.vi.sk_222 sr.vi.lt_432  no.sv.de_443 rw.lg.sw_555
  0x0d1c13a4, 0x231f1902, 0x190b0a08, 0x17000a2b,   // bh.mr.ne_433 gl.cy.ca_222  pt.es.gl_443 mk.sr.un_980
  0x0f00030d, 0x1a004a22, 0x11070a0d, 0x08041004,   // nl.lv.un_540 yo.tl.un_870  mk.bg.ro_554 be.ru.uk_332
  // [0fc0]
  0x0e13040c, 0x1f1a250c, 0x136b1a04, 0x0e086ba4,   // fi.et.is_543 eu.tl.cy_543  tl.ceb.et_332 ceb.no.is_433
  0x06003514, 0x18002118, 0x052101a4, 0x1c001e2b,   // zu.de.un_660 fa.ar.un_740  en.jw.fr_433 ms.id.un_980
  0x0a081705, 0x0a0810a0, 0x28001305, 0x080a17a9,   // sr.uk.mk_333 be.uk.mk_322  et.sw.un_330 sr.mk.uk_544
  0x0d130911, 0x051f270d, 0x0d091c0c, 0x0500181a,   // hi.bh.ne_653 gd.cy.fr_554  mr.hi.ne_543 ga.fr.un_760
  // [0fd0]
  0x16520ea7, 0x2900201a, 0x1e002707, 0x21001212,   // is.ha.hr_532 sq.sl.un_760  gd.ms.un_420 ur.fa.un_640
  0x2d002019, 0x1c09130c, 0x18002a02, 0x2a076860,   // sq.sk.un_750 bh.hi.mr_543  mt.ga.un_220 ig.it.mt_664
  0x080c09a4, 0x1b113107, 0x171632ec, 0x0b0a52a4,   // pl.sv.no_433 az.ro.tr_432  bs.hr.sr_644 ha.pt.es_433
  0x281020ee, 0x070411a0, 0x4a0f53ee, 0x1325090b,   // sq.lt.sw_422 ro.ru.bg_322  ht.lv.yo_422 pl.eu.et_542
  // [0fe0]
  0x1200250d, 0x03020807, 0x53000b02, 0x050e06a0,   // eu.hu.un_540 no.da.nl_432  es.ht.un_220 de.is.fr_322
  0x0d001309, 0x100e0fad, 0x04001009, 0x17070a14,   // bh.ne.un_440 lv.is.lt_643  be.ru.un_440 mk.bg.sr_666
  0x1f130414, 0x1f002707, 0x130d09ec, 0x0b001912,   // fi.et.cy_666 gd.cy.un_420  hi.ne.bh_644 gl.es.un_640
  0x230725a4, 0x3f112d0c, 0x2d003204, 0x05002705,   // eu.it.ca_433 sk.ro.af_543  bs.sk.un_320 gd.fr.un_330
  // [0ff0]
  0x0408170d, 0x09002d35, 0x20002909, 0x080725a6,   // sr.uk.ru_554 sk.pl.un_A90  sl.sq.un_440 eu.it.no_521
  0x09000e12, 0x0f004a04, 0x0f09010b, 0x080a1708,   // is.pl.un_640 yo.lv.un_320  en.pl.lv_542 sr.mk.uk_443
  0x680f3f11, 0x04001a08, 0x2a006407, 0x3f0b2d0c,   // af.lv.ig_653 tl.fi.un_430  lg.mt.un_420 sk.es.af_543
  0x3229200c, 0x0e000c14, 0x0d102904, 0x29322008,   // sq.sl.bs_543 sv.is.un_660  sl.lt.cs_332 sq.bs.sl_443

  // [1000]
  0x3f050da4, 0x29002019, 0x2d002007, 0x2d072511,   // cs.fr.af_433 sq.sl.un_750  sq.sk.un_420 eu.it.sk_653
  0x03113faf, 0x2d6809ad, 0x0400101b, 0x09002d2b,   // af.ro.nl_655 pl.ig.sk_643  be.ru.un_770 sk.pl.un_980
  0x1c0d130c, 0x05002704, 0x0b000708, 0x09001219,   // bh.ne.mr_543 gd.fr.un_320  it.es.un_430 hu.pl.un_750
  0x3f1a6b07, 0x1e1c2514, 0x09070da4, 0x091e25a4,   // ceb.tl.af_432 eu.id.ms_666  cs.it.pl_433 eu.ms.pl_433
  // [1010]
  0x1b003122, 0x17162909, 0x052d01a4, 0x0600092b,   // az.tr.un_870 sl.hr.sr_444  en.sk.fr_433 pl.de.un_980
  0x1b003121, 0x2d11030d, 0x0a0408a4, 0x041707a4,   // az.tr.un_860 nl.ro.sk_554  uk.ru.mk_433 bg.sr.ru_433
  0x29003108, 0x2d093f12, 0x3f090d07, 0x13000923,   // az.sl.un_430 af.pl.sk_654  cs.pl.af_432 hi.bh.un_880
  0x13000921, 0x13251904, 0x1c001319, 0x35000c0c,   // hi.bh.un_860 gl.eu.et_332  bh.mr.un_750 sv.zu.un_530
  // [1020]
  0x080c0ea9, 0x040a0805, 0x05120a04, 0x6b1c1e0c,   // is.sv.no_544 uk.mk.ru_333  pt.hu.fr_332 ms.id.ceb_543
  0x29001704, 0x19000e05, 0x1b1a4a13, 0x04170807,   // sr.sl.un_320 is.gl.un_330  yo.tl.tr_665 uk.sr.ru_432
  0x08170aad, 0x00002b03, 0x08001013, 0x0e1b1304,   // mk.sr.uk_643 vi.un.un_300  be.uk.un_650 et.tr.is_332
  0x1f004a02, 0x53000512, 0x1c0d0907, 0x070417a4,   // yo.cy.un_220 fr.ht.un_640  hi.ne.mr_432 sr.ru.bg_433
  // [1030]
  0x03000508, 0x06002a04, 0x1a0e6405, 0x070804a4,   // fr.nl.un_430 mt.de.un_320  lg.is.tl_333 ru.uk.bg_433
  0x1a1b0504, 0x311b1fa9, 0x2b3b52a0, 0x3100520d,   // fr.tr.tl_332 cy.tr.az_544  ha.so.vi_322 ha.az.un_540
  0x3b2001a4, 0x13001c14, 0x3b0419a0, 0x1a1e1c08,   // en.sq.so_433 mr.bh.un_660  gl.fi.so_322 id.ms.tl_443
  0x1f1e1c60, 0x0e001319, 0x1c0913a0, 0x1c080c05,   // id.ms.cy_664 et.is.un_750  bh.hi.mr_322 sv.no.id_333
  // [1040]
  0x1b005204, 0x25001902, 0x0c00190d, 0x076412ad,   // ha.tr.un_320 gl.eu.un_220  gl.sv.un_540 hu.lg.it_643
  0x1f00550d, 0x0c001904, 0x080c5304, 0x4a3f1aa7,   // rw.cy.un_540 gl.sv.un_320  ht.sv.no_332 tl.af.yo_532
  0x0e000a09, 0x6b001a1a, 0x020c08af, 0x040810a0,   // pt.is.un_440 tl.ceb.un_760  no.sv.da_655 be.uk.ru_322
  0x172d290c, 0x0c000823, 0x1e0f1ca0, 0x0d1c0908,   // sl.sk.sr_543 no.sv.un_880  id.lv.ms_322 hi.mr.ne_443
  // [1050]
  0x2b4a1fa7, 0x1c130907, 0x040710a9, 0x0d1c0913,   // cy.yo.vi_532 hi.bh.mr_432  be.bg.ru_544 hi.mr.ne_665
  0x092d0d55, 0x131c0912, 0x07000422, 0x011f6b02,   // cs.sk.pl_442 hi.mr.bh_654  ru.bg.un_870 ceb.cy.en_222
  0x131e0e12, 0x0a1f1955, 0x1e211cec, 0x091218a7,   // is.ms.et_654 gl.cy.pt_442  id.jw.ms_644 ga.hu.pl_532
  0x1000110b, 0x06033f13, 0x2d0d2914, 0x27002807,   // ro.be.un_520 af.nl.de_665  sl.cs.sk_666 sw.gd.un_420
  // [1060]
  0x2a3f3b04, 0x1a005304, 0x1c033f11, 0x050c01a0,   // so.af.mt_332 ht.tl.un_320  af.nl.id_653 en.sv.fr_322
  0x170a0702, 0x0704170d, 0x1a006b22, 0x521e1c08,   // bg.mk.sr_222 sr.ru.bg_554  ceb.tl.un_870 id.ms.ha_443
  0x213b35ec, 0x20003214, 0x3b2128a9, 0x4a002021,   // zu.so.jw_644 bs.sq.un_660  sw.jw.so_544 sq.yo.un_860
  0x190b0aee, 0x5300201b, 0x0700682a, 0x12000804,   // pt.es.gl_422 sq.ht.un_770  ig.it.un_970 no.hu.un_320
  // [1070]
  0x171629a9, 0x0a00071a, 0x53003119, 0x07000a02,   // sl.hr.sr_544 bg.mk.un_760  az.ht.un_750 mk.bg.un_220
  0x080c0eee, 0x2d000d02, 0x09061f07, 0x280768ec,   // is.sv.no_422 cs.sk.un_220  cy.de.pl_432 ig.it.sw_644
  0x120c0809, 0x0c282508, 0x12006804, 0x29200d07,   // no.sv.hu_444 eu.sw.sv_443  ig.hu.un_320 cs.sq.sl_432
  0x05002304, 0x0553110b, 0x6800030e, 0x23190a13,   // ca.fr.un_320 ro.ht.fr_542  nl.ig.un_550 pt.gl.ca_665
  // [1080]
  0x033f12a4, 0x52002018, 0x06076807, 0x00001e15,   // hu.af.nl_433 sq.ha.un_740  ig.it.de_432 ms.un.un_700
  0x31283b0e, 0x20006e19, 0x31005304, 0x31003202,   // so.sw.az_555 hmn.sq.un_750  ht.az.un_320 bs.az.un_220
  0x55006402, 0x172d090c, 0x0d00130c, 0x00003537,   // lg.rw.un_220 pl.sk.sr_543  bh.ne.un_530 zu.un.un_B00
  0x08020cec, 0x0417100c, 0x310452ad, 0x1c291ead,   // sv.da.no_644 be.sr.ru_543  ha.fi.az_643 ms.sl.id_643
  // [1090]
  0x35522812, 0x0410085a, 0x07000a0d, 0x07005322,   // sw.ha.zu_654 uk.be.ru_553  mk.bg.un_540 ht.it.un_870
  0x1c130914, 0x031b1211, 0x0b1223ec, 0x32172a12,   // hi.bh.mr_666 hu.tr.nl_653  ca.hu.es_644 mt.sr.bs_654
  0x0f050107, 0x23190bec, 0x130c12a4, 0x09000d13,   // en.fr.lv_432 es.gl.ca_644  hu.sv.et_433 ne.hi.un_650
  0x311b0caf, 0x03643f08, 0x683f53ec, 0x284a5304,   // sv.tr.az_655 af.lg.nl_443  ht.af.ig_644 ht.yo.sw_332
  // [10a0]
  0x07000402, 0x09000d0e, 0x251827ad, 0x1a04250c,   // ru.bg.un_220 ne.hi.un_550  gd.ga.eu_643 eu.fi.tl_543
  0x4a2d12a9, 0x2006120c, 0x1213040c, 0x353f5207,   // hu.sk.yo_544 hu.de.sq_543  fi.et.hu_543 ha.af.zu_432
  0x1025270d, 0x0c080211, 0x0c000812, 0x00004a1c,   // gd.eu.lt_554 da.no.sv_653  no.sv.un_640 yo.un.un_800
  0x00000801, 0x3100200d, 0x09001f0c, 0x00006e2d,   // no.un.un_200 sq.az.un_540  cy.pl.un_530 hmn.un.un_A00
  // [10b0]
  0x3b033f09, 0x532105ec, 0x121b0ca7, 0x1a2728a4,   // af.nl.so_444 fr.jw.ht_644  sv.tr.hu_532 sw.gd.tl_433
  0x21131cee, 0x3b001319, 0x05000108, 0x6e202a05,   // id.et.jw_422 et.so.un_750  en.fr.un_430 mt.sq.hmn_333
  0x033b3f05, 0x08000608, 0x00003b03, 0x100f25a9,   // af.so.nl_333 de.no.un_430  so.un.un_300 eu.lv.lt_544
  0x080a07a0, 0x3f033b12, 0x091c0d12, 0x11000422,   // bg.mk.uk_322 so.nl.af_654  ne.mr.hi_654 ru.ro.un_870
  // [10c0]
  0x04000f1a, 0x6b001a1b, 0x28521a12, 0x031304a7,   // lv.fi.un_760 tl.ceb.un_770  tl.ha.sw_654 fi.et.nl_532
  0x0f314aa4, 0x0d00090d, 0x524a1fa9, 0x4a033f12,   // yo.az.lv_433 hi.ne.un_540  cy.yo.ha_544 af.nl.yo_654
  0x13090d0c, 0x3f000e05, 0x070a1713, 0x53080208,   // ne.hi.bh_543 is.af.un_330  sr.mk.bg_665 da.no.ht_443
  0x0e080ca4, 0x230b050e, 0x0504250c, 0x0d1c13af,   // sv.no.is_433 fr.es.ca_555  eu.fi.fr_543 bh.mr.ne_655
  // [10d0]
  0x09001c1b, 0x16000d08, 0x3b2a0fec, 0x1632170d,   // mr.hi.un_770 cs.hr.un_430  lv.mt.so_644 sr.bs.hr_554
  0x02080c04, 0x0e001f1b, 0x100a0813, 0x31001b29,   // sv.no.da_332 cy.is.un_770  uk.mk.be_665 tr.az.un_960
  0x04131aec, 0x01080ea4, 0x11003b1a, 0x1e1c3baf,   // tl.et.fi_644 is.no.en_433  so.ro.un_760 so.id.ms_655
  0x1e006b04, 0x190a0b14, 0x03001313, 0x12082104,   // ceb.ms.un_320 es.pt.gl_666  et.nl.un_650 jw.no.hu_332
  // [10e0]
  0x2b001e02, 0x211e1c04, 0x25230112, 0x1a12680e,   // ms.vi.un_220 id.ms.jw_332  en.ca.eu_654 ig.hu.tl_555
  0x2b001c04, 0x0e002808, 0x0b000713, 0x1c0d130e,   // id.vi.un_320 sw.is.un_430  it.es.un_650 bh.ne.mr_555
  0x17000d04, 0x03281355, 0x3b001f0d, 0x18002711,   // cs.sr.un_320 et.sw.nl_442  cy.so.un_540 gd.ga.un_630
  0x1100681b, 0x1b00530d, 0x070a0408, 0x0817110c,   // ig.ro.un_770 ht.tr.un_540  ru.mk.bg_443 ro.sr.uk_543
  // [10f0]
  0x21001114, 0x03113f0c, 0x271718ec, 0x03071808,   // ro.jw.un_660 af.ro.nl_543  ga.sr.gd_644 ga.it.nl_443
  0x03003f22, 0x0e001e04, 0x0e000619, 0x0d001307,   // af.nl.un_870 ms.is.un_320  de.is.un_750 bh.ne.un_420
  0x17070408, 0x081f0607, 0x2000280d, 0x021b0e05,   // ru.bg.sr_443 de.cy.no_432  sw.sq.un_540 is.tr.da_333
  0x04171008, 0x1e002818, 0x52001c04, 0x040711ec,   // be.sr.ru_443 sw.ms.un_740  id.ha.un_320 ro.bg.ru_644
  // [1100]
  0x18002a08, 0x24000113, 0x55202813, 0x02000e22,   // mt.ga.un_430 iw.yi.un_650  sw.sq.rw_665 is.da.un_870
  0x0800120c, 0x06002302, 0x01001f04, 0x1c000d12,   // hu.no.un_530 ca.de.un_220  cy.en.un_320 ne.mr.un_640
  0x2900170d, 0x070811a4, 0x0f001904, 0x080a1107,   // sr.sl.un_540 ro.uk.bg_433  gl.lv.un_320 ro.mk.uk_432
  0x6b100755, 0x2d0d10ec, 0x080417a0, 0x3f00030e,   // it.lt.ceb_442 lt.cs.sk_644  sr.ru.uk_322 nl.af.un_550
  // [1110]
  0x1a00211b, 0x09005512, 0x52004a0c, 0x0e001f13,   // jw.tl.un_770 rw.pl.un_640  yo.ha.un_530 cy.is.un_650
  0x125204ac, 0x0b0a23a9, 0x1f0b2307, 0x29172daf,   // fi.ha.hu_632 ca.pt.es_544  ca.es.cy_432 sk.sr.sl_655
  0x0900530d, 0x2a00550d, 0x25000521, 0x32001609,   // ht.pl.un_540 rw.mt.un_540  fr.eu.un_860 hr.bs.un_440
  0x0a001713, 0x2a000702, 0x1e211ca0, 0x1c002112,   // sr.mk.un_650 it.mt.un_220  id.jw.ms_322 jw.id.un_640
  // [1120]
  0x110827ad, 0x0d001c20, 0x092d0d08, 0x3217160c,   // gd.no.ro_643 mr.ne.un_850  cs.sk.pl_443 hr.sr.bs_543
  0x12002512, 0x12002123, 0x25000b08, 0x1300122b,   // eu.hu.un_640 fa.ur.un_880  es.eu.un_430 hu.et.un_980
  0x1c001f1a, 0x28081f04, 0x13001c0e, 0x16002911,   // cy.id.un_760 cy.no.sw_332  id.et.un_550 sl.hr.un_630
  0x3f1f13ee, 0x64041ca0, 0x00003503, 0x23000419,   // et.cy.af_422 id.fi.lg_322  zu.un.un_300 fi.ca.un_750
  // [1130]
  0x1c0d1305, 0x0a002818, 0x070a0812, 0x07000405,   // bh.ne.mr_333 sw.pt.un_740  uk.mk.bg_654 ru.bg.un_330
  0x0a00042a, 0x06351aa0, 0x051f0408, 0x0500070c,   // ru.mk.un_970 tl.zu.de_322  fi.cy.fr_443 it.fr.un_530
  0x10000819, 0x11000505, 0x2a04020c, 0x00003501,   // uk.be.un_750 fr.ro.un_330  da.fi.mt_543 zu.un.un_200
  0x13000305, 0x1c000922, 0x12082055, 0x04000808,   // nl.et.un_330 hi.mr.un_870  sq.no.hu_442 no.fi.un_430
  // [1140]
  0x0700010d, 0x08021aa0, 0x21001c07, 0x193b0bad,   // en.it.un_540 tl.da.no_322  id.jw.un_420 es.so.gl_643
  0x4a28640c, 0x291b280c, 0x081f0e08, 0x12071ba4,   // lg.sw.yo_543 sw.tr.sl_543  is.cy.no_443 tr.it.hu_433
  0x0000320f, 0x28006b04, 0x0100350e, 0x23001a04,   // bs.un.un_600 ceb.sw.un_320  zu.en.un_550 tl.ca.un_320
  0x556428ad, 0x29003213, 0x0507010c, 0x0d000902,   // sw.lg.rw_643 bs.sl.un_650  en.it.fr_543 hi.ne.un_220
  // [1150]
  0x130410a9, 0x3f000308, 0x64551a08, 0x04091fa9,   // lt.fi.et_544 nl.af.un_430  tl.rw.lg_443 cy.pl.fi_544
  0x01001109, 0x0a000709, 0x070411ad, 0x08110707,   // ro.en.un_440 it.pt.un_440  ro.ru.bg_643 it.ro.no_432
  0x0e0752ee, 0x06031b08, 0x53100908, 0x06033f0d,   // ha.it.is_422 tr.nl.de_443  pl.lt.ht_443 af.nl.de_554
  0x16002912, 0x050c6ba0, 0x2a290aaf, 0x18122114,   // sl.hr.un_640 ceb.sv.fr_322  pt.sl.mt_655 fa.ur.ar_666
  // [1160]
  0x2a096807, 0x06321709, 0x07050107, 0x01106ba0,   // ig.pl.mt_432 sr.bs.de_444  en.fr.it_432 ceb.lt.en_322
  0x1f010604, 0x040601a4, 0x231b0607, 0x2855350d,   // de.en.cy_332 en.de.fi_433  de.tr.ca_432 zu.rw.sw_554
  0x2100182a, 0x351a08a4, 0x070604ad, 0x110a1709,   // ar.fa.un_970 no.tl.zu_433  fi.de.it_643 sr.mk.ro_444
  0x2021280d, 0x052352ac, 0x0d1c1304, 0x25000a1a,   // sw.jw.sq_554 ha.ca.fr_632  bh.mr.ne_332 pt.eu.un_760
  // [1170]
  0x04081704, 0x5500251b, 0x0711040c, 0x28256ba4,   // sr.uk.ru_332 eu.rw.un_770  ru.ro.bg_543 ceb.eu.sw_433
  0x271828a9, 0x06002a0d, 0x53014aee, 0x2a27350c,   // sw.ga.gd_544 mt.de.un_540  yo.en.ht_422 zu.gd.mt_543
  0x25003504, 0x2868180d, 0x6b006408, 0x311b09a4,   // zu.eu.un_320 ga.ig.sw_554  lg.ceb.un_430 pl.tr.az_433
  0x10080460, 0x3b002704, 0x070a11a4, 0x0a0817a0,   // ru.uk.be_664 gd.so.un_320  ro.mk.bg_433 sr.uk.mk_322
  // [1180]
  0x68110708, 0x1c000705, 0x07000a14, 0x0429130d,   // it.ro.ig_443 it.id.un_330  mk.bg.un_660 et.sl.fi_554
  0x130e04ad, 0x0e00101b, 0x060501af, 0x356e20ad,   // fi.is.et_643 lt.is.un_770  en.fr.de_655 sq.hmn.zu_643
  0x16000907, 0x07001828, 0x3b684aa4, 0x13290913,   // pl.hr.un_420 ar.bg.un_950  yo.ig.so_433 pl.sl.et_665
  0x2a090f12, 0x2700350e, 0x1c00042a, 0x162a04a4,   // lv.pl.mt_654 zu.gd.un_550  fi.id.un_970 fi.mt.hr_433
  // [1190]
  0x12002114, 0x55281ea0, 0x4a096407, 0x1f001904,   // fa.ur.un_660 ms.sw.rw_322  lg.pl.yo_432 gl.cy.un_320
  0x0400071a, 0x3b130908, 0x04643b0c, 0x1a003b0d,   // bg.ru.un_760 pl.et.so_443  so.lg.fi_543 so.tl.un_540
  0x081704ad, 0x1c130908, 0x6e6b01a4, 0x08000c0e,   // ru.sr.uk_643 hi.bh.mr_443  en.ceb.hmn_433 sv.no.un_550
  0x3f3b645a, 0x080704a9, 0x2b1f2704, 0x04112355,   // lg.so.af_553 ru.bg.uk_544  gd.cy.vi_332 ca.ro.fi_442
  // [11a0]
  0x0e20060b, 0x0a684a08, 0x29092512, 0x015528a4,   // de.sq.is_542 yo.ig.pt_443  eu.pl.sl_654 sw.rw.en_433
  0x1c133b07, 0x04643f0c, 0x08534aa6, 0x1f003f21,   // so.et.id_432 af.lg.fi_543  yo.ht.no_521 af.cy.un_860
  0x17041007, 0x0e001908, 0x1a643b08, 0x0409290d,   // be.ru.sr_432 gl.is.un_430  so.lg.tl_443 sl.pl.fi_554
  0x1800212b, 0x4a006420, 0x64003b2b, 0x03280507,   // fa.ar.un_980 lg.yo.un_850  so.lg.un_980 fr.sw.nl_432
  // [11b0]
  0x0e5209a9, 0x10040708, 0x06356804, 0x04070a08,   // pl.ha.is_544 bg.ru.be_443  ig.zu.de_332 mk.bg.ru_443
  0x08021ba4, 0x64003b1b, 0x1b290914, 0x6435280c,   // tr.da.no_433 so.lg.un_770  pl.sl.tr_666 sw.zu.lg_543
  0x03003b0b, 0x23190b09, 0x2d003513, 0x2d082908,   // so.nl.un_520 es.gl.ca_444  zu.sk.un_650 sl.no.sk_443
  0x1c0913ec, 0x2d000d11, 0x1c090d5a, 0x1b000c07,   // bh.hi.mr_644 cs.sk.un_630  ne.hi.mr_553 sv.tr.un_420
  // [11c0]
  0x1800201a, 0x641a3b0c, 0x6b1a6812, 0x1929230c,   // sq.ga.un_760 so.tl.lg_543  ig.tl.ceb_654 ca.sl.gl_543
  0x28643b60, 0x31001114, 0x090d1ca0, 0x0a040713,   // so.lg.sw_664 ro.az.un_660  mr.ne.hi_322 bg.ru.mk_665
  0x643b1a09, 0x3b00640d, 0x046b1aa4, 0x070f68a4,   // tl.so.lg_444 lg.so.un_540  tl.ceb.fi_433 ig.lv.it_433
  0x18122113, 0x1f271813, 0x3f000a05, 0x0a0811a0,   // fa.ur.ar_665 ga.gd.cy_665  pt.af.un_330 ro.uk.mk_322
  // [11d0]
  0x04080aa4, 0x6b0a1f08, 0x0400081a, 0x4a00680d,   // mk.uk.ru_433 cy.pt.ceb_443  uk.ru.un_760 ig.yo.un_540
  0x093f0304, 0x17040a05, 0x211c1ea4, 0x17080704,   // nl.af.pl_332 mk.ru.sr_333  ms.id.jw_433 bg.uk.sr_332
  0x05070112, 0x12000e05, 0x0e1918a0, 0x2311100c,   // en.it.fr_654 is.hu.un_330  ga.gl.is_322 lt.ro.ca_543
  0x231119a4, 0x0a002319, 0x0f001318, 0x35001a07,   // gl.ro.ca_433 ca.pt.un_750  et.lv.un_740 tl.zu.un_420
  // [11e0]
  0x2d1009a9, 0x2800682a, 0x08042712, 0x271304ad,   // pl.lt.sk_544 ig.sw.un_970  gd.fi.no_654 fi.et.gd_643
  0x0807120c, 0x270e0655, 0x06000808, 0x21182712,   // hu.it.no_543 de.is.gd_442  no.de.un_430 gd.ga.jw_654
  0x0000352d, 0x04001014, 0x096b35a0, 0x27202114,   // zu.un.un_A00 be.ru.un_660  zu.ceb.pl_322 jw.sq.gd_666
  0x11000d08, 0x0a07100e, 0x21001c05, 0x4a202dee,   // cs.ro.un_430 be.bg.mk_555  id.jw.un_330 sk.sq.yo_422
  // [11f0]
  0x1168270c, 0x101123ac, 0x023b070c, 0x17110a04,   // gd.ig.ro_543 ca.ro.lt_632  it.so.da_543 mk.ro.sr_332
  0x0c19230c, 0x04080aad, 0x1e191108, 0x11092da9,   // ca.gl.sv_543 mk.uk.ru_643  ro.gl.ms_443 sk.pl.ro_544
  0x06000e1a, 0x0c091007, 0x09201702, 0x1200212a,   // is.de.un_760 lt.pl.sv_432  sr.sq.pl_222 fa.ur.un_970
  0x160712a7, 0x536b1aaf, 0x3b006b05, 0x1a6b0705,   // hu.it.hr_532 tl.ceb.ht_655  ceb.so.un_330 it.ceb.tl_333
  // [1200]
  0x132801a0, 0x182721af, 0x350f10af, 0x061e1c08,   // en.sw.et_322 jw.gd.ga_655  lt.lv.zu_655 id.ms.de_443
  0x203b28ad, 0x551a20a4, 0x2d111005, 0x31002023,   // sw.so.sq_643 sq.tl.rw_433  lt.ro.sk_333 sq.az.un_880
  0x010535a0, 0x19002319, 0x35312055, 0x0c02080c,   // zu.fr.en_322 ca.gl.un_750  sq.az.zu_442 no.da.sv_543
  0x08000719, 0x10231108, 0x32001614, 0x20005514,   // bg.uk.un_750 ro.ca.lt_443  hr.bs.un_660 rw.sq.un_660
  // [1210]
  0x53006407, 0x20351812, 0x1168230c, 0x1b1853a0,   // lg.ht.un_420 ga.zu.sq_654  ca.ig.ro_543 ht.ga.tr_322
  0x32166ba0, 0x1e110ba0, 0x20000d04, 0x2b001a04,   // ceb.hr.bs_322 es.ro.ms_322  cs.sq.un_320 tl.vi.un_320
  0x2010110d, 0x0a011a07, 0x3555520d, 0x232d100c,   // ro.lt.sq_554 tl.en.pt_432  ha.rw.zu_554 lt.sk.ca_543
  0x1b05350c, 0x023f08a4, 0x0d000f08, 0x1b132007,   // zu.fr.tr_543 no.af.da_433  lv.cs.un_430 sq.et.tr_432
  // [1220]
  0x19000b21, 0x6b551a08, 0x1a096b09, 0x2b1a6ba0,   // es.gl.un_860 tl.rw.ceb_443  ceb.pl.tl_444 ceb.tl.vi_322
  0x03012aee, 0x0e2a1004, 0x02000404, 0x021a6ba9,   // mt.en.nl_422 lt.mt.is_332  fi.da.un_320 ceb.tl.da_544
  0x1c2952a4, 0x17040705, 0x3f552a55, 0x28352014,   // ha.sl.id_433 bg.ru.sr_333  mt.rw.af_442 sq.zu.sw_666
  0x3531640c, 0x01001e07, 0x09003504, 0x200b1313,   // lg.az.zu_543 ms.en.un_420  zu.pl.un_320 et.es.sq_665
  // [1230]
  0x01060c04, 0x311a10a4, 0x170a0409, 0x05010605,   // sv.de.en_332 lt.tl.az_433  ru.mk.sr_444 de.en.fr_333
  0x292d0d14, 0x0c000813, 0x1f003513, 0x64002704,   // cs.sk.sl_666 no.sv.un_650  zu.cy.un_650 gd.lg.un_320
  0x00001b0a, 0x09003f02, 0x130d0914, 0x290d02a0,   // tr.un.un_500 af.pl.un_220  hi.ne.bh_666 da.cs.sl_322
  0x1c002107, 0x25000b02, 0x4a1a6ba0, 0x2a033fa0,   // jw.id.un_420 es.eu.un_220  ceb.tl.yo_322 af.nl.mt_322
  // [1240]
  0x07080409, 0x101e1c05, 0x04070813, 0x19000a07,   // ru.uk.bg_444 id.ms.lt_333  uk.bg.ru_665 pt.gl.un_420
  0x0d091c0b, 0x0411170d, 0x08001002, 0x0f00100d,   // mr.hi.ne_542 sr.ro.ru_554  be.uk.un_220 lt.lv.un_540
  0x19270aa4, 0x162d0d09, 0x040f18a0, 0x05000702,   // pt.gd.gl_433 cs.sk.hr_444  ga.lv.fi_322 it.fr.un_220
  0x521e25a9, 0x1e1c350c, 0x3b001013, 0x35003b09,   // eu.ms.ha_544 zu.id.ms_543  lt.so.un_650 so.zu.un_440
  // [1250]
  0x09130d11, 0x0d091307, 0x0e000c13, 0x5500100e,   // ne.bh.hi_653 bh.hi.ne_432  sv.is.un_650 lt.rw.un_550
  0x06033f04, 0x040e0ca7, 0x053211ee, 0x072705a0,   // af.nl.de_332 sv.is.fi_532  ro.bs.fr_422 fr.gd.it_322
  0x551e1c05, 0x532a0508, 0x170711af, 0x18002721,   // id.ms.rw_333 fr.mt.ht_443  ro.bg.sr_655 gd.ga.un_860
  0x28005505, 0x1e101c12, 0x27186eee, 0x1c090d08,   // rw.sw.un_330 id.lt.ms_654  hmn.ga.gd_422 ne.hi.mr_443
  // [1260]
  0x080a0709, 0x13090d11, 0x10000b02, 0x07170804,   // bg.mk.uk_444 ne.hi.bh_653  es.lt.un_220 uk.sr.bg_332
  0x08170a09, 0x1a645504, 0x06001b13, 0x35005504,   // mk.sr.uk_444 rw.lg.tl_332  tr.de.un_650 rw.zu.un_320
  0x3b000702, 0x10070409, 0x28001c02, 0x08020c11,   // it.so.un_220 ru.bg.be_444  id.sw.un_220 sv.da.no_653
  0x0c0208a7, 0x23190aa0, 0x1e0f18a0, 0x68003522,   // no.da.sv_532 pt.gl.ca_322  ga.lv.ms_322 zu.ig.un_870
  // [1270]
  0x29100411, 0x2d1b0d55, 0x1f002512, 0x0408100c,   // fi.lt.sl_653 cs.tr.sk_442  eu.cy.un_640 be.uk.ru_543
  0x35536812, 0x0c321ca0, 0x180427af, 0x08000209,   // ig.ht.zu_654 id.bs.sv_322  gd.fi.ga_655 da.no.un_440
  0x1c0d1307, 0x0f2920a4, 0x09000804, 0x3b001c08,   // bh.ne.mr_432 sq.sl.lv_433  no.pl.un_320 id.so.un_430
  0x551e1c0c, 0x3b000d22, 0x1004640c, 0x2d0d0a0c,   // id.ms.rw_543 cs.so.un_870  lg.fi.lt_543 pt.cs.sk_543
  // [1280]
  0x2d0d3bec, 0x55351c08, 0x040e640c, 0x531e1c04,   // so.cs.sk_644 id.zu.rw_443  lg.is.fi_543 id.ms.ht_332
  0x172d0d55, 0x07170a08, 0x1b003204, 0x07041012,   // cs.sk.sr_442 mk.sr.bg_443  bs.tr.un_320 be.ru.bg_654
  0x046408a0, 0x170a070c, 0x00000d0a, 0x0f006409,   // no.lg.fi_322 bg.mk.sr_543  cs.un.un_500 lg.lv.un_440
  0x0d000a08, 0x08000212, 0x19000b22, 0x04086407,   // pt.cs.un_430 da.no.un_640  es.gl.un_870 lg.no.fi_432
  // [1290]
  0x07080a05, 0x211c1aa4, 0x6400681b, 0x08000a12,   // mk.uk.bg_333 tl.id.jw_433  ig.lg.un_770 mk.uk.un_640
  0x0a1707ad, 0x1e1c210e, 0x0c000d1a, 0x1700030c,   // bg.sr.mk_643 jw.id.ms_555  cs.sv.un_760 nl.sr.un_530
  0x2d005304, 0x0d001c08, 0x131c1a04, 0x0f321705,   // ht.sk.un_320 mr.ne.un_430  tl.id.et_332 sr.bs.lv_333
  0x030e12af, 0x13003f07, 0x09250d07, 0x110b5507,   // hu.is.nl_655 af.et.un_420  cs.eu.pl_432 rw.es.ro_432
  // [12a0]
  0x100a1708, 0x0c0601af, 0x2a3b25ad, 0x1b000c04,   // sr.mk.be_443 en.de.sv_655  eu.so.mt_643 sv.tr.un_320
  0x190d0aa7, 0x04001307, 0x0e10640b, 0x050111ee,   // pt.cs.gl_532 et.fi.un_420  lg.lt.is_542 ro.en.fr_422
  0x2a523b12, 0x2d290dec, 0x2d0d0aaf, 0x05000a08,   // so.ha.mt_654 cs.sl.sk_644  pt.cs.sk_655 pt.fr.un_430
  0x11204aa0, 0x04120308, 0x101e1c04, 0x3f000808,   // yo.sq.ro_322 nl.hu.fi_443  id.ms.lt_332 no.af.un_430
  // [12b0]
  0x061e1c04, 0x3200010c, 0x08070408, 0x280f1105,   // id.ms.de_332 en.bs.un_530  ru.bg.uk_443 ro.lv.sw_333
  0x21252a04, 0x3b00311b, 0x5300050b, 0x0c002105,   // mt.eu.jw_332 az.so.un_770  fr.ht.un_520 jw.sv.un_330
  0x100711a7, 0x1700100b, 0x02000612, 0x07002a14,   // ro.bg.be_532 be.sr.un_520  de.da.un_640 mt.it.un_660
  0x170a1108, 0x12190a0c, 0x1f1827ec, 0x25001c04,   // ro.mk.sr_443 pt.gl.hu_543  gd.ga.cy_644 id.eu.un_320
  // [12c0]
  0x08070412, 0x0c0e0da4, 0x3f030204, 0x0c0208ee,   // ru.bg.uk_654 cs.is.sv_433  da.nl.af_332 no.da.sv_422
  0x040f1c04, 0x21001814, 0x1c000912, 0x091c13ad,   // id.lv.fi_332 ar.fa.un_660  hi.mr.un_640 bh.mr.hi_643
  0x1821120d, 0x0b23190c, 0x0b0a19a0, 0x3f072013,   // ur.fa.ar_554 gl.ca.es_543  gl.pt.es_322 sq.it.af_665
  0x23190b0e, 0x09131c10, 0x0d091c05, 0x3b000804,   // es.gl.ca_555 mr.bh.hi_642  mr.hi.ne_333 no.so.un_320
  // [12d0]
  0x07002308, 0x190b1fec, 0x06000c0e, 0x120d2d11,   // ca.it.un_430 cy.es.gl_644  sv.de.un_550 sk.cs.hu_653
  0x280f31a4, 0x553b1a0e, 0x19530507, 0x110408af,   // az.lv.sw_433 tl.so.rw_555  fr.ht.gl_432 uk.ru.ro_655
  0x11041760, 0x041353a0, 0x2d0d0aec, 0x52060eee,   // sr.ru.ro_664 ht.et.fi_322  pt.cs.sk_644 is.de.ha_422
  0x182112af, 0x0c0e29ad, 0x1e1c12a4, 0x080e0408,   // ur.fa.ar_655 sl.is.sv_643  hu.id.ms_433 fi.is.no_443
  // [12e0]
  0x0d1c09ec, 0x0a1704a9, 0x17292808, 0x3f032909,   // hi.mr.ne_644 ru.sr.mk_544  sw.sl.sr_443 sl.nl.af_444
  0x0c1e2504, 0x25006404, 0x080c1fa0, 0x0635080c,   // eu.ms.sv_332 lg.eu.un_320  cy.sv.no_322 no.zu.de_543
  0x216b1aad, 0x0a081004, 0x07040a0d, 0x033f6407,   // tl.ceb.jw_643 be.uk.mk_332  mk.ru.bg_554 lg.af.nl_432
  0x11002007, 0x0e002007, 0x0d0913ec, 0x17100811,   // sq.ro.un_420 sq.is.un_420  bh.hi.ne_644 uk.be.sr_653
  // [12f0]
  0x3f0208a9, 0x08020c09, 0x16000312, 0x01060ca6,   // no.da.af_544 sv.da.no_444  nl.hr.un_640 sv.de.en_521
  0x18013ba0, 0x25001904, 0x121b1807, 0x2d132912,   // so.en.ga_322 gl.eu.un_320  ga.tr.hu_432 sl.et.sk_654
  0x01532707, 0x033f2b07, 0x08020e0c, 0x1c002122,   // gd.ht.en_432 vi.af.nl_432  is.da.no_543 jw.id.un_870
  0x29321ca0, 0x21526bad, 0x061c2104, 0x12286405,   // id.bs.sl_322 ceb.ha.jw_643  jw.id.de_332 lg.sw.hu_333
  // [1300]
  0x11070a08, 0x0000182d, 0x3f000335, 0x0d1a6b08,   // mk.bg.ro_443 ar.un.un_A00  nl.af.un_A90 ceb.tl.cs_443
  0x013b5311, 0x1c0d0913, 0x3b3f030c, 0x0d122dad,   // ht.so.en_653 hi.ne.mr_665  nl.af.so_543 sk.hu.cs_643
  0x09000d2b, 0x3f080c08, 0x06310fa4, 0x0d2d1211,   // ne.hi.un_980 sv.no.af_443  lv.az.de_433 hu.sk.cs_653
  0x52004a04, 0x033b3fa4, 0x64005508, 0x0a07100c,   // yo.ha.un_320 af.so.nl_433  rw.lg.un_430 be.bg.mk_543
  // [1310]
  0x292d25ec, 0x1c0516a0, 0x13004a0d, 0x0b0a1914,   // eu.sk.sl_644 hr.fr.id_322  yo.et.un_540 gl.pt.es_666
  0x1203530c, 0x01005312, 0x033f1313, 0x07080413,   // ht.nl.hu_543 ht.en.un_640  et.af.nl_665 ru.uk.bg_665
  0x290919ee, 0x050a19a0, 0x18002014, 0x16292d07,   // gl.pl.sl_422 gl.pt.fr_322  sq.ga.un_660 sk.sl.hr_432
  0x64001b21, 0x091c135a, 0x2b5206a4, 0x10645304,   // tr.lg.un_860 bh.mr.hi_553  de.ha.vi_433 ht.lg.lt_332
  // [1320]
  0x2d0d1702, 0x3b081aa9, 0x033b01a9, 0x530208af,   // sr.cs.sk_222 tl.no.so_544  en.so.nl_544 no.da.ht_655
  0x0a080705, 0x1e005204, 0x2921120c, 0x1a250e08,   // bg.uk.mk_333 ha.ms.un_320  hu.jw.sl_543 is.eu.tl_443
  0x3f0364a0, 0x10003209, 0x17040aaf, 0x4a1a6bec,   // lg.nl.af_322 bs.lt.un_440  mk.ru.sr_655 ceb.tl.yo_644
  0x6b281a07, 0x2d000714, 0x55003519, 0x1a6b64a4,   // tl.sw.ceb_432 it.sk.un_660  zu.rw.un_750 lg.ceb.tl_433
  // [1330]
  0x170410af, 0x68061f07, 0x1f0453ee, 0x133f035a,   // be.ru.sr_655 cy.de.ig_432  ht.fi.cy_422 nl.af.et_553
  0x1f062305, 0x011f5355, 0x013f0305, 0x01033fa0,   // ca.de.cy_333 ht.cy.en_442  nl.af.en_333 af.nl.en_322
  0x12006423, 0x190b1109, 0x3f00032c, 0x53001c04,   // lg.hu.un_880 ro.es.gl_444  nl.af.un_990 id.ht.un_320
  0x08070a55, 0x1e1c6b0e, 0x18003b12, 0x352b4aa0,   // mk.bg.uk_442 ceb.id.ms_555  so.ga.un_640 yo.vi.zu_322
  // [1340]
  0x28006820, 0x00006b24, 0x1e1c01a0, 0x08171008,   // ig.sw.un_850 ceb.un.un_900  en.id.ms_322 be.sr.uk_443
  0x1c091309, 0x0c033fa0, 0x07100405, 0x07002a19,   // bh.hi.mr_444 af.nl.sv_322  ru.be.bg_333 mt.it.un_750
  0x101f18a9, 0x1f194aa4, 0x283552a0, 0x191f1011,   // ga.cy.lt_544 yo.gl.cy_433  ha.zu.sw_322 lt.cy.gl_653
  0x10522555, 0x120b25ee, 0x04170708, 0x041b3bad,   // eu.ha.lt_442 eu.es.hu_422  bg.sr.ru_443 so.tr.fi_643
  // [1350]
  0x0b124aaf, 0x17321608, 0x12006e11, 0x0b4a120c,   // yo.hu.es_655 hr.bs.sr_443  hmn.hu.un_630 hu.yo.es_543
  0x0a00071b, 0x19120b07, 0x04025204, 0x186b01a7,   // bg.mk.un_770 es.hu.gl_432  ha.da.fi_332 en.ceb.ga_532
  0x100305a0, 0x3b356405, 0x32002908, 0x120b4aec,   // fr.nl.lt_322 lg.zu.so_333  sl.bs.un_430 yo.es.hu_644
  0x0b001221, 0x07190a5a, 0x2800201b, 0x10080414,   // hu.es.un_860 pt.gl.it_553  sq.sw.un_770 ru.uk.be_666
  // [1360]
  0x202a07a4, 0x0a0811af, 0x12230b08, 0x0d002d2b,   // it.mt.sq_433 ro.uk.mk_655  es.ca.hu_443 sk.cs.un_980
  0x1c2164a7, 0x3216095a, 0x080c3ba4, 0x10000712,   // lg.jw.id_532 pl.hr.bs_553  so.sv.no_433 bg.be.un_640
  0x2100181b, 0x642a52a4, 0x32172a08, 0x2d0d21a0,   // ar.fa.un_770 ha.mt.lg_433  mt.sr.bs_443 jw.cs.sk_322
  0x6800101a, 0x121821ad, 0x1f000414, 0x2d000d05,   // lt.ig.un_760 fa.ar.ur_643  fi.cy.un_660 cs.sk.un_330
  // [1370]
  0x1c00090c, 0x1c1304ee, 0x190a1fa4, 0x1f0410ad,   // hi.mr.un_530 fi.et.id_422  cy.pt.gl_433 lt.fi.cy_643
  0x08040707, 0x02080c0c, 0x012d0d0d, 0x53000308,   // bg.ru.uk_432 sv.no.da_543  cs.sk.en_554 nl.ht.un_430
  0x12190bac, 0x080f040c, 0x4a230b05, 0x08171104,   // es.gl.hu_632 fi.lv.no_543  es.ca.yo_333 ro.sr.uk_332
  0x09000113, 0x120b2313, 0x20005523, 0x2a00091b,   // en.pl.un_650 ca.es.hu_665  rw.sq.un_880 pl.mt.un_770
  // [1380]
  0x12003b19, 0x18001214, 0x55001b0c, 0x0704080c,   // so.hu.un_750 ur.ar.un_660  tr.rw.un_530 uk.ru.bg_543
  0x03003f0d, 0x2d000d2c, 0x292a0f55, 0x23060313,   // af.nl.un_540 cs.sk.un_990  lv.mt.sl_442 nl.de.ca_665
  0x08000c04, 0x0d002d2a, 0x283b6407, 0x312a295a,   // sv.no.un_320 sk.cs.un_970  lg.so.sw_432 sl.mt.az_553
  0x040a07a9, 0x0000232d, 0x13000104, 0x04070a14,   // bg.mk.ru_544 ca.un.un_A00  en.et.un_320 mk.bg.ru_666
  // [1390]
  0x05001804, 0x0d1c0912, 0x3f2506ad, 0x01006e07,   // ga.fr.un_320 hi.mr.ne_654  de.eu.af_643 hmn.en.un_420
  0x0e0a23ee, 0x180f2712, 0x03190a04, 0x1a1c1ea9,   // ca.pt.is_422 gd.lv.ga_654  pt.gl.nl_332 ms.id.tl_544
  0x0f1017a4, 0x2d0d090e, 0x2a00071b, 0x13553504,   // sr.lt.lv_433 pl.cs.sk_555  it.mt.un_770 zu.rw.et_332
  0x0f001704, 0x526b3508, 0x0a100808, 0x1f000912,   // sr.lv.un_320 zu.ceb.ha_443  uk.be.mk_443 pl.cy.un_640
  // [13a0]
  0x2300010d, 0x28350908, 0x55352808, 0x0a2755a0,   // en.ca.un_540 pl.zu.sw_443  sw.zu.rw_443 rw.gd.pt_322
  0x35556ba4, 0x1a3555af, 0x641f07ee, 0x554a35ac,   // ceb.rw.zu_433 rw.zu.tl_655  it.cy.lg_422 zu.yo.rw_632
  0x52001004, 0x23001b07, 0x21556ba0, 0x1c1b1e0b,   // lt.ha.un_320 tr.ca.un_420  ceb.rw.jw_322 ms.tr.id_542
  0x0c00060c, 0x1300292a, 0x3b286b09, 0x2300120c,   // de.sv.un_530 sl.et.un_970  ceb.sw.so_444 hu.ca.un_530
  // [13b0]
  0x08001f12, 0x32061ea0, 0x28645560, 0x292d0d07,   // cy.no.un_640 ms.de.bs_322  rw.lg.sw_664 cs.sk.sl_432
  0x07081707, 0x196b64a7, 0x556864a4, 0x64552804,   // sr.uk.bg_432 lg.ceb.gl_532  lg.ig.rw_433 sw.rw.lg_332
  0x1e001c21, 0x29351605, 0x13001c19, 0x35110baf,   // id.ms.un_860 hr.zu.sl_333  mr.bh.un_750 es.ro.zu_655
  0x3f5564a4, 0x10001108, 0x11070808, 0x1000110c,   // lg.rw.af_433 ro.lt.un_430  uk.bg.ro_443 ro.be.un_530
  // [13c0]
  0x250b08a4, 0x071801a0, 0x0c0208a4, 0x25132907,   // no.es.eu_433 en.ga.it_322  no.da.sv_433 sl.et.eu_432
  0x52002519, 0x081f0d0c, 0x10645504, 0x02033f13,   // eu.ha.un_750 cs.cy.no_543  rw.lg.lt_332 af.nl.da_665
  0x3b00550c, 0x2511550c, 0x06080213, 0x100d0508,   // rw.so.un_530 rw.ro.eu_543  da.no.de_665 fr.cs.lt_443
  0x0e352108, 0x10000422, 0x04131ea0, 0x0f002919,   // jw.zu.is_443 ru.be.un_870  ms.et.fi_322 sl.lv.un_750
  // [13d0]
  0x19050b08, 0x08101705, 0x1a006b19, 0x190b1a55,   // es.fr.gl_443 sr.be.uk_333  ceb.tl.un_750 tl.es.gl_442
  0x6b0f1a07, 0x101b0aa0, 0x311b13a7, 0x0804115a,   // tl.lv.ceb_432 pt.tr.lt_322  et.tr.az_532 ro.ru.uk_553
  0x3509250c, 0x00000d2d, 0x31001b20, 0x68643507,   // eu.pl.zu_543 ne.un.un_A00  tr.az.un_850 zu.lg.ig_432
  0x07682ba6, 0x181f35ec, 0x00002006, 0x2300111b,   // vi.ig.it_521 zu.cy.ga_644  sq.un.un_400 ro.ca.un_770
  // [13e0]
  0x2b003512, 0x0302080c, 0x092d0dad, 0x35283ba4,   // zu.vi.un_640 no.da.nl_543  cs.sk.pl_643 so.sw.zu_433
  0x092d19a7, 0x091c1308, 0x2b003519, 0x0e00351b,   // gl.sk.pl_532 bh.mr.hi_443  zu.vi.un_750 zu.is.un_770
  0x3f122811, 0x11001902, 0x272b11ad, 0x3f002104,   // sw.hu.af_653 gl.ro.un_220  ro.vi.gd_643 jw.af.un_320
  0x1100120d, 0x2a001319, 0x32171660, 0x062504ec,   // hu.ro.un_540 et.mt.un_750  hr.sr.bs_664 fi.eu.de_644
  // [13f0]
  0x11002314, 0x0a0407af, 0x033f53a4, 0x1b123112,   // ca.ro.un_660 bg.ru.mk_655  ht.af.nl_433 az.hu.tr_654
  0x12001b1a, 0x0d130912, 0x172d2908, 0x0a001705,   // tr.hu.un_760 hi.bh.ne_654  sl.sk.sr_443 sr.mk.un_330
  0x23005307, 0x121b2d0c, 0x28003504, 0x1b1629a4,   // ht.ca.un_420 sk.tr.hu_543  zu.sw.un_320 sl.hr.tr_433
  0x033f23a9, 0x1e00180d, 0x356829ad, 0x53000504,   // ca.af.nl_544 ga.ms.un_540  sl.ig.zu_643 fr.ht.un_320

  // [1400]
  0x1a006b04, 0x170711a4, 0x0400120e, 0x2500121b,   // ceb.tl.un_320 ro.bg.sr_433  hu.fi.un_550 hu.eu.un_770
  0x1c13090d, 0x09000421, 0x0c3f0312, 0x00003f06,   // hi.bh.mr_554 fi.pl.un_860  nl.af.sv_654 af.un.un_400
  0x29321708, 0x19230aa0, 0x043b3507, 0x04070808,   // sr.bs.sl_443 pt.ca.gl_322  zu.so.fi_432 uk.bg.ru_443
  0x182b27a7, 0x0d091302, 0x05110aa0, 0x0612200c,   // gd.vi.ga_532 bh.hi.ne_222  pt.ro.fr_322 sq.hu.de_543
  // [1410]
  0x09005308, 0x55283b04, 0x3f000309, 0x2500040d,   // ht.pl.un_430 so.sw.rw_332  nl.af.un_440 fi.eu.un_540
  0x0d192d0b, 0x09005309, 0x0a001812, 0x24000134,   // sk.gl.cs_542 ht.pl.un_440  ga.pt.un_640 iw.yi.un_A80
  0x110203ee, 0x20553b07, 0x0a041713, 0x1c09130b,   // nl.da.ro_422 so.rw.sq_432  sr.ru.mk_665 bh.hi.mr_542
  0x3b551307, 0x09001c0b, 0x10041709, 0x2d0d29ee,   // et.rw.so_432 mr.hi.un_520  sr.ru.be_444 sl.cs.sk_422
  // [1420]
  0x17000719, 0x10040a09, 0x553b2113, 0x20553b12,   // bg.sr.un_750 mk.ru.be_444  jw.so.rw_665 so.rw.sq_654
  0x643b310c, 0x03090708, 0x2a000719, 0x120b19ee,   // az.so.lg_543 it.pl.nl_443  it.mt.un_750 gl.es.hu_422
  0x311b3b04, 0x1100070d, 0x1b005321, 0x1206020c,   // so.tr.az_332 it.ro.un_540  ht.tr.un_860 da.de.hu_543
  0x17080aaf, 0x0d001c1b, 0x04170a55, 0x08321604,   // mk.uk.sr_655 mr.ne.un_770  mk.sr.ru_442 hr.bs.no_332
  // [1430]
  0x080211a4, 0x04081011, 0x163217ad, 0x06080255,   // ro.da.no_433 be.uk.ru_653  sr.bs.hr_643 da.no.de_442
  0x00000e03, 0x3b1b6404, 0x520d1a0d, 0x55001c0d,   // is.un.un_300 lg.tr.so_332  tl.cs.ha_554 id.rw.un_540
  0x3f001b12, 0x10000823, 0x1f002013, 0x0800111a,   // tr.af.un_640 uk.be.un_880  sq.cy.un_650 ro.uk.un_760
  0x16001007, 0x040811a4, 0x131c09ec, 0x0a1b2304,   // lt.hr.un_420 ro.uk.ru_433  hi.mr.bh_644 ca.tr.pt_332
  // [1440]
  0x04132013, 0x0a070107, 0x040105ee, 0x08200e0c,   // sq.et.fi_665 en.it.pt_432  fr.en.fi_422 is.sq.no_543
  0x17081005, 0x0a1707ec, 0x2a006434, 0x03003f02,   // be.uk.sr_333 bg.sr.mk_644  lg.mt.un_A80 af.nl.un_220
  0x1710110d, 0x29122a14, 0x1032160d, 0x131b2507,   // ro.be.sr_554 mt.hu.sl_666  hr.bs.lt_554 eu.tr.et_432
  0x04170a12, 0x110825ee, 0x29200e0c, 0x1c120e0c,   // mk.sr.ru_654 eu.no.ro_422  is.sq.sl_543 is.hu.id_543
  // [1450]
  0x1200101b, 0x1f001a08, 0x28532111, 0x13042013,   // lt.hu.un_770 tl.cy.un_430  jw.ht.sw_653 sq.fi.et_665
  0x08000a1a, 0x12292aa4, 0x31040e0c, 0x3f0301a0,   // mk.uk.un_760 mt.sl.hu_433  is.fi.az_543 en.nl.af_322
  0x052311a4, 0x2118120c, 0x081011ee, 0x01552855,   // ro.ca.fr_433 ur.ar.fa_543  ro.be.uk_422 sw.rw.en_442
  0x20000821, 0x6404250c, 0x29091faf, 0x533b4aad,   // no.sq.un_860 eu.fi.lg_543  cy.pl.sl_655 yo.so.ht_643
  // [1460]
  0x202a0908, 0x06251b13, 0x092512ec, 0x09120e07,   // pl.mt.sq_443 tr.eu.de_665  hu.eu.pl_644 is.hu.pl_432
  0x3b00121a, 0x2a1229a4, 0x122a1b0c, 0x112718ad,   // hu.so.un_760 sl.hu.mt_433  tr.mt.hu_543 ga.gd.ro_643
  0x4a216ba0, 0x1f000c13, 0x00006e37, 0x233b1308,   // ceb.jw.yo_322 sv.cy.un_650  hmn.un.un_B00 et.so.ca_443
  0x041708a4, 0x09001305, 0x2a0708a4, 0x07004a08,   // uk.sr.ru_433 bh.hi.un_330  no.it.mt_433 yo.it.un_430
  // [1470]
  0x64110f08, 0x1100521a, 0x09202aa9, 0x25000804,   // lv.ro.lg_443 ha.ro.un_760  mt.sq.pl_544 no.eu.un_320
  0x101308a0, 0x2a2012ec, 0x1c1f1eee, 0x05110807,   // no.et.lt_322 hu.sq.mt_644  ms.cy.id_422 no.ro.fr_432
  0x13030607, 0x11006e22, 0x3b231f07, 0x3125230c,   // de.nl.et_432 hmn.ro.un_870  cy.ca.so_432 ca.eu.az_543
  0x27006e18, 0x051827a9, 0x1c351e0c, 0x2102080c,   // hmn.gd.un_740 gd.ga.fr_544  ms.zu.id_543 no.da.jw_543
  // [1480]
  0x08110414, 0x231e1c08, 0x0f00101b, 0x083f6e07,   // ru.ro.uk_666 id.ms.ca_443  lt.lv.un_770 hmn.af.no_432
  0x3213230c, 0x0708040c, 0x00006b01, 0x3216170c,   // ca.et.bs_543 ru.uk.bg_543  ceb.un.un_200 sr.hr.bs_543
  0x09211f04, 0x0527180d, 0x230b08a0, 0x19233b08,   // cy.jw.pl_332 ga.gd.fr_554  no.es.ca_322 so.ca.gl_443
  0x06000c07, 0x081704a4, 0x55004a04, 0x35006e04,   // sv.de.un_420 ru.sr.uk_433  yo.rw.un_320 hmn.zu.un_320
  // [1490]
  0x1f000c19, 0x321629ec, 0x170a12a4, 0x0b002704,   // sv.cy.un_750 sl.hr.bs_644  hu.pt.sr_433 gd.es.un_320
  0x0a5329ee, 0x09002104, 0x06130314, 0x1f213b11,   // sl.ht.pt_422 jw.pl.un_320  nl.et.de_666 so.jw.cy_653
  0x3b002304, 0x1300092c, 0x6823130c, 0x113507ec,   // ca.so.un_320 hi.bh.un_990  et.ca.ig_543 it.zu.ro_644
  0x0e3f1a07, 0x03063f07, 0x28001013, 0x4a2025a7,   // tl.af.is_432 af.de.nl_432  lt.sw.un_650 eu.sq.yo_532
  // [14a0]
  0x00001206, 0x0c126ba0, 0x0c000214, 0x23553ba4,   // ur.un.un_400 ceb.hu.sv_322  da.sv.un_660 so.rw.ca_433
  0x64100f0c, 0x20003519, 0x2b000c04, 0x1c090dad,   // lv.lt.lg_543 zu.sq.un_750  sv.vi.un_320 ne.hi.mr_643
  0x1200180c, 0x32001104, 0x28352113, 0x06033fa7,   // ga.hu.un_530 ro.bs.un_320  jw.zu.sw_665 af.nl.de_532
  0x230a1ea0, 0x070f1ea0, 0x1c351e11, 0x0a10110c,   // ms.pt.ca_322 ms.lv.it_322  ms.zu.id_653 ro.be.mk_543
  // [14b0]
  0x313f0307, 0x1f001902, 0x070a0405, 0x230b2107,   // nl.af.az_432 gl.cy.un_220  ru.mk.bg_333 jw.es.ca_432
  0x3b211e04, 0x2d0d12af, 0x0c024aad, 0x0a170708,   // ms.jw.so_332 hu.cs.sk_655  yo.da.sv_643 bg.sr.mk_443
  0x170708a4, 0x0e082a12, 0x03023f08, 0x11200212,   // uk.bg.sr_433 mt.no.is_654  af.da.nl_443 da.sq.ro_654
  0x17041004, 0x29002a04, 0x553564a0, 0x1e351c07,   // be.ru.sr_332 mt.sl.un_320  lg.zu.rw_322 id.zu.ms_432
  // [14c0]
  0x093b0da4, 0x0a3f03a4, 0x3f060a09, 0x03040608,   // cs.so.pl_433 nl.af.pt_433  pt.de.af_444 de.fi.nl_443
  0x040807a9, 0x04132012, 0x35286407, 0x0400130d,   // bg.uk.ru_544 sq.et.fi_654  lg.sw.zu_432 et.fi.un_540
  0x53020b05, 0x32006419, 0x20080c08, 0x293208a4,   // es.da.ht_333 lg.bs.un_750  sv.no.sq_443 no.bs.sl_433
  0x033f270c, 0x045331ee, 0x3200160d, 0x06000305,   // gd.af.nl_543 az.ht.fi_422  hr.bs.un_540 nl.de.un_330
  // [14d0]
  0x3f040308, 0x08033faf, 0x0308200c, 0x1f190bad,   // nl.fi.af_443 af.nl.no_655  sq.no.nl_543 es.gl.cy_643
  0x06286405, 0x1c000d14, 0x080417a4, 0x550464a9,   // lg.sw.de_333 ne.mr.un_660  sr.ru.uk_433 lg.fi.rw_544
  0x20000b19, 0x1e1c64a0, 0x2a001704, 0x0f081011,   // es.sq.un_750 lg.id.ms_322  sr.mt.un_320 lt.no.lv_653
  0x2d0d3b14, 0x1106190d, 0x016e0cad, 0x0d000919,   // so.cs.sk_666 gl.de.ro_554  sv.hmn.en_643 hi.ne.un_750
  // [14e0]
  0x08002a0c, 0x18000521, 0x521c21a4, 0x0900010d,   // mt.no.un_530 fr.ga.un_860  jw.id.ha_433 en.pl.un_540
  0x291e1c05, 0x211e1cec, 0x123525a4, 0x0b2307ad,   // id.ms.sl_333 id.ms.jw_644  eu.zu.hu_433 it.ca.es_643
  0x0e0c3f04, 0x29200908, 0x092010ac, 0x5300021a,   // af.sv.is_332 pl.sq.sl_443  lt.sq.pl_632 da.ht.un_760
  0x211e1c60, 0x07001114, 0x35006412, 0x1000040d,   // id.ms.jw_664 ro.it.un_660  lg.zu.un_640 fi.lt.un_540
  // [14f0]
  0x172d0d08, 0x08002919, 0x2700180d, 0x032008a0,   // cs.sk.sr_443 sl.no.un_750  ga.gd.un_540 no.sq.nl_322
  0x2b001119, 0x18273fa4, 0x170a11ee, 0x043509a4,   // ro.vi.un_750 af.gd.ga_433  ro.mk.sr_422 pl.zu.fi_433
  0x28100f05, 0x03063f09, 0x08200309, 0x06003f08,   // lv.lt.sw_333 af.de.nl_444  nl.sq.no_444 af.de.un_430
  0x1c130955, 0x2920030c, 0x1b1168a7, 0x1c001e22,   // hi.bh.mr_442 nl.sq.sl_543  ig.ro.tr_532 ms.id.un_870
  // [1500]
  0x06000a04, 0x08171005, 0x00002903, 0x1f006b04,   // pt.de.un_320 be.sr.uk_333  sl.un.un_300 ceb.cy.un_320
  0x11070509, 0x07040a05, 0x08070a09, 0x07080a13,   // fr.it.ro_444 mk.ru.bg_333  mk.bg.uk_444 mk.uk.bg_665
  0x040a0712, 0x17040804, 0x3555310c, 0x00000b2d,   // bg.mk.ru_654 uk.ru.sr_332  az.rw.zu_543 bn.un.un_A00
  0x551805a4, 0x01000c13, 0x1c00130c, 0x2800550c,   // fr.ga.rw_433 sv.en.un_650  bh.mr.un_530 rw.sw.un_530
  // [1510]
  0x0a111708, 0x0a081109, 0x0506110b, 0x0d091309,   // sr.ro.mk_443 ro.uk.mk_444  ro.de.fr_542 bh.hi.ne_444
  0x1e1c4a09, 0x0800170e, 0x09000d0c, 0x2d000d0c,   // yo.id.ms_444 sr.uk.un_550  cs.pl.un_530 cs.sk.un_530
  0x0d09130b, 0x170811ee, 0x08070aa0, 0x0a170705,   // bh.hi.ne_542 ro.uk.sr_422  mk.bg.uk_322 bg.sr.mk_333
  0x08110704, 0x1b6431a0, 0x01006b07, 0x09000c0d,   // bg.ro.uk_332 az.lg.tr_322  ceb.en.un_420 sv.pl.un_540
  // [1520]
  0x0b000a09, 0x1c1309a9, 0x12001f1a, 0x2700182c,   // pt.es.un_440 hi.bh.mr_544  cy.hu.un_760 ga.gd.un_990
  0x1f136ea0, 0x10081108, 0x0d2d01a7, 0x3f03010c,   // hmn.et.cy_322 ro.uk.be_443  en.sk.cs_532 en.nl.af_543
  0x55645311, 0x0600121a, 0x080a1709, 0x1b3152ad,   // ht.lg.rw_653 hu.de.un_760  sr.mk.uk_444 ha.az.tr_643
  0x00000d01, 0x53521aee, 0x231901a4, 0x18002729,   // ne.un.un_200 tl.ha.ht_422  en.gl.ca_433 gd.ga.un_960
  // [1530]
  0x1e0c1cee, 0x035206a4, 0x01000505, 0x3f032aa9,   // id.sv.ms_422 de.ha.nl_433  fr.en.un_330 mt.nl.af_544
  0x05121155, 0x1f065307, 0x05182711, 0x17110a08,   // ro.hu.fr_442 ht.de.cy_432  gd.ga.fr_653 mk.ro.sr_443
  0x063f2a04, 0x080411a7, 0x2a000a08, 0x2353010c,   // mt.af.de_332 ro.ru.uk_532  pt.mt.un_430 en.ht.ca_543
  0x04003b1b, 0x070a0409, 0x20321bee, 0x06030b02,   // so.fi.un_770 ru.mk.bg_444  tr.bs.sq_422 es.nl.de_222
  // [1540]
  0x3f082a07, 0x040817a4, 0x0c001c07, 0x29033f0c,   // mt.no.af_432 sr.uk.ru_433  id.sv.un_420 af.nl.sl_543
  0x01215302, 0x2b000b02, 0x0e000622, 0x3f211011,   // ht.jw.en_222 es.vi.un_220  de.is.un_870 lt.jw.af_653
  0x25685507, 0x06216ea0, 0x08132aa0, 0x090d130c,   // rw.ig.eu_432 hmn.jw.de_322  mt.et.no_322 bh.ne.hi_543
  0x1800272c, 0x2d0c02a9, 0x0b005507, 0x070417a0,   // gd.ga.un_990 da.sv.sk_544  rw.es.un_420 sr.ru.bg_322
  // [1550]
  0x021e64ad, 0x091c1313, 0x1f1e64a7, 0x1f000419,   // lg.ms.da_643 bh.mr.hi_665  lg.ms.cy_532 fi.cy.un_750
  0x0c022a04, 0x1e1c64ee, 0x351c31a0, 0x110901a4,   // mt.da.sv_332 lg.id.ms_422  az.id.zu_322 en.pl.ro_433
  0x10002a13, 0x031e1fec, 0x190a1aa9, 0x080264af,   // mt.lt.un_650 cy.ms.nl_644  tl.pt.gl_544 lg.da.no_655
  0x08001f19, 0x6e3f1ea4, 0x210a1e07, 0x08001c04,   // cy.no.un_750 ms.af.hmn_433  ms.pt.jw_432 id.no.un_320
  // [1560]
  0x321004a9, 0x3f6e2012, 0x07080460, 0x190b6e60,   // fi.lt.bs_544 sq.hmn.af_654  ru.uk.bg_664 hmn.es.gl_664
  0x29006422, 0x083b1f07, 0x640e1308, 0x05000802,   // lg.sl.un_870 cy.so.no_432  et.is.lg_443 no.fr.un_220
  0x03062007, 0x10001b2a, 0x3f036eac, 0x19000a23,   // sq.de.nl_432 tr.lt.un_970  hmn.nl.af_632 pt.gl.un_880
  0x351f6407, 0x11042505, 0x13000413, 0x01000705,   // lg.cy.zu_432 eu.fi.ro_333  fi.et.un_650 it.en.un_330
  // [1570]
  0x0407105a, 0x0b190a0d, 0x13043b12, 0x04091013,   // be.bg.ru_553 pt.gl.es_554  so.fi.et_654 lt.pl.fi_665
  0x4a0e2307, 0x1c072102, 0x036e3fa9, 0x17070a07,   // ca.is.yo_432 jw.it.id_222  af.hmn.nl_544 mk.bg.sr_432
  0x31006e0c, 0x06353ba4, 0x23190b04, 0x08041702,   // hmn.az.un_530 so.zu.de_433  es.gl.ca_332 sr.ru.uk_222
  0x171632a7, 0x1c3168a7, 0x0b000723, 0x216b0660,   // bs.hr.sr_532 ig.az.id_532  it.es.un_880 de.ceb.jw_664
  // [1580]
  0x08025205, 0x18002708, 0x0200640e, 0x10000609,   // ha.da.no_333 gd.ga.un_430  lg.da.un_550 de.lt.un_440
  0x071108a4, 0x6e003f11, 0x053f0d0c, 0x25080c08,   // uk.ro.bg_433 af.hmn.un_630  cs.af.fr_543 sv.no.eu_443
  0x21006412, 0x102305ec, 0x1b1e1ca9, 0x06092104,   // lg.jw.un_640 fr.ca.lt_644  id.ms.tr_544 jw.pl.de_332
  0x20091ba0, 0x29190b5a, 0x100f6eec, 0x4a1219ec,   // tr.pl.sq_322 es.gl.sl_553  hmn.lv.lt_644 gl.hu.yo_644
  // [1590]
  0x2a002507, 0x03063fa9, 0x2b172102, 0x0a070809,   // eu.mt.un_420 af.de.nl_544  jw.sr.vi_222 uk.bg.mk_444
  0x17040812, 0x0c311b08, 0x1f12100d, 0x070a1007,   // uk.ru.sr_654 tr.az.sv_443  lt.hu.cy_554 be.mk.bg_432
  0x35001107, 0x1b1e1c0d, 0x09001321, 0x2923190c,   // ro.zu.un_420 id.ms.tr_554  bh.hi.un_860 gl.ca.sl_543
  0x072311ee, 0x2300250d, 0x27281a0c, 0x071704a4,   // ro.ca.it_422 eu.ca.un_540  tl.sw.gd_543 ru.sr.bg_433
  // [15a0]
  0x23190b02, 0x0704080e, 0x232b1807, 0x1c106404,   // es.gl.ca_222 uk.ru.bg_555  ga.vi.ca_432 lg.lt.id_332
  0x04000707, 0x2d021112, 0x04000713, 0x0d0913ad,   // bg.ru.un_420 ro.da.sk_654  bg.ru.un_650 bh.hi.ne_643
  0x18002120, 0x21001812, 0x06031fee, 0x09005302,   // fa.ar.un_850 ar.fa.un_640  cy.nl.de_422 ht.pl.un_220
  0x17041105, 0x231901a0, 0x1b321705, 0x0f003f02,   // ro.ru.sr_333 en.gl.ca_322  sr.bs.tr_333 af.lv.un_220
  // [15b0]
  0x112801ee, 0x04081104, 0x1c130904, 0x53016ba0,   // en.sw.ro_422 ro.uk.ru_332  hi.bh.mr_332 ceb.en.ht_322
  0x311828ee, 0x080704af, 0x1a000212, 0x080a1704,   // sw.ga.az_422 ru.bg.uk_655  da.tl.un_640 sr.mk.uk_332
  0x1b4a04ee, 0x100a04af, 0x04004a0c, 0x270b6e04,   // fi.yo.tr_422 ru.mk.be_655  yo.fi.un_530 hmn.es.gd_332
  0x0d130908, 0x211e1c5a, 0x070408a0, 0x0a170405,   // hi.bh.ne_443 id.ms.jw_553  uk.ru.bg_322 ru.sr.mk_333
  // [15c0]
  0x0c040ba7, 0x0b000104, 0x070403af, 0x23353f13,   // es.fi.sv_532 en.es.un_320  nl.fi.it_655 af.zu.ca_665
  0x21000905, 0x0a2007a0, 0x35002514, 0x25190bee,   // pl.jw.un_330 it.sq.pt_322  eu.zu.un_660 es.gl.eu_422
  0x12000419, 0x033f5304, 0x20000323, 0x102d0f14,   // fi.hu.un_750 ht.af.nl_332  nl.sq.un_880 lv.sk.lt_666
  0x356b6404, 0x011105a0, 0x0602080c, 0x640a2aa4,   // lg.ceb.zu_332 fr.ro.en_322  no.da.de_543 mt.pt.lg_433
  // [15d0]
  0x6b001a05, 0x04170a08, 0x040a110c, 0x08006b07,   // tl.ceb.un_330 mk.sr.ru_443  ro.mk.ru_543 ceb.no.un_420
  0x21001a07, 0x1f21640c, 0x25005214, 0x1a002104,   // tl.jw.un_420 lg.jw.cy_543  ha.eu.un_660 jw.tl.un_320
  0x00002d06, 0x2a321604, 0x08100409, 0x1732160d,   // sk.un.un_400 hr.bs.mt_332  ru.be.uk_444 hr.bs.sr_554
  0x32311b60, 0x0900040c, 0x0b532502, 0x201101a4,   // tr.az.bs_664 fi.pl.un_530  eu.ht.es_222 en.ro.sq_433
  // [15e0]
  0x0a070409, 0x11321608, 0x520605a7, 0x04081060,   // ru.bg.mk_444 hr.bs.ro_443  fr.de.ha_532 be.uk.ru_664
  0x1200212b, 0x11321704, 0x1a000b04, 0x531b6b05,   // fa.ur.un_980 sr.bs.ro_332  es.tl.un_320 ceb.tr.ht_333
  0x3b001e08, 0x110231ee, 0x35073207, 0x53094a08,   // ms.so.un_430 az.da.ro_422  bs.it.zu_432 yo.pl.ht_443
  0x0600041a, 0x121b13a7, 0x1e1c25ec, 0x3f040e14,   // fi.de.un_760 et.tr.hu_532  eu.id.ms_644 is.fi.af_666
  // [15f0]
  0x2511130c, 0x2504135a, 0x29162da4, 0x4a640713,   // et.ro.eu_543 et.fi.eu_553  sk.hr.sl_433 it.lg.yo_665
  0x080c5204, 0x03321614, 0x2a00020d, 0x1704080b,   // ha.sv.no_332 hr.bs.nl_666  da.mt.un_540 uk.ru.sr_542
  0x0e080213, 0x12080260, 0x6b211a0c, 0x1c0d1309,   // da.no.is_665 da.no.hu_664  tl.jw.ceb_543 bh.ne.mr_444
  0x11080408, 0x170a0760, 0x07000a05, 0x10040704,   // ru.uk.ro_443 bg.mk.sr_664  mk.bg.un_330 bg.ru.be_332
  // [1600]
  0x1c001e08, 0x32001714, 0x0c000d08, 0x231101a4,   // ms.id.un_430 sr.bs.un_660  cs.sv.un_430 en.ro.ca_433
  0x0764250c, 0x1b252802, 0x0c005214, 0x32291609,   // eu.lg.it_543 sw.eu.tr_222  ha.sv.un_660 hr.sl.bs_444
  0x040f10af, 0x1f5301a4, 0x19000b23, 0x082523a4,   // lt.lv.fi_655 en.ht.cy_433  es.gl.un_880 ca.eu.no_433
  0x19000108, 0x09122509, 0x07081107, 0x17000419,   // en.gl.un_430 eu.hu.pl_444  ro.uk.bg_432 ru.sr.un_750
  // [1610]
  0x3f0802a7, 0x13002508, 0x07170408, 0x3b00190c,   // da.no.af_532 eu.et.un_430  ru.sr.bg_443 gl.so.un_530
  0x06000c0d, 0x0a11010c, 0x09250e55, 0x0a0417a0,   // sv.de.un_540 en.ro.pt_543  is.eu.pl_442 sr.ru.mk_322
  0x1c1e2d07, 0x10000408, 0x04081002, 0x19000b2c,   // sk.ms.id_432 ru.be.un_430  be.uk.ru_222 es.gl.un_990
  0x3525680e, 0x3b2d0d55, 0x03002313, 0x230a25a9,   // ig.eu.zu_555 cs.sk.so_442  ca.nl.un_650 eu.pt.ca_544
  // [1620]
  0x32000d07, 0x0a23075a, 0x120d03a4, 0x203503a7,   // cs.bs.un_420 it.ca.pt_553  nl.cs.hu_433 nl.zu.sq_532
  0x081017ad, 0x1211070e, 0x0d3135ad, 0x27000507,   // sr.be.uk_643 it.ro.hu_555  zu.az.cs_643 fr.gd.un_420
  0x07041708, 0x6b001a21, 0x0a001c02, 0x2b000702,   // sr.ru.bg_443 tl.ceb.un_860  id.pt.un_220 it.vi.un_220
  0x03062508, 0x21011302, 0x2b006b2a, 0x06030a09,   // eu.de.nl_443 et.en.jw_222  ceb.vi.un_970 pt.nl.de_444
  // [1630]
  0x07040aa4, 0x0a0804a4, 0x0e531b0c, 0x1c2055a4,   // mk.ru.bg_433 ru.uk.mk_433  tr.ht.is_543 rw.sq.id_433
  0x04001719, 0x1a006b36, 0x061b0312, 0x10042011,   // sr.ru.un_750 ceb.tl.un_AA0  nl.tr.de_654 sq.fi.lt_653
  0x0a070ba0, 0x04003204, 0x20281305, 0x1e2b1ca0,   // es.it.pt_322 bs.fi.un_320  et.sw.sq_333 id.vi.ms_322
  0x0d162d07, 0x1e313b05, 0x110a070c, 0x10040713,   // sk.hr.cs_432 so.az.ms_333  bg.mk.ro_543 bg.ru.be_665
  // [1640]
  0x2d0d290c, 0x1000042b, 0x3b311fa9, 0x2a3b07a4,   // sl.cs.sk_543 ru.be.un_980  cy.az.so_544 it.so.mt_433
  0x011321a9, 0x0300010c, 0x08163ba0, 0x06000c09,   // jw.et.en_544 en.nl.un_530  so.hr.no_322 sv.de.un_440
  0x13100f5a, 0x073b1307, 0x0600130e, 0x0a001222,   // lv.lt.et_553 et.so.it_432  et.de.un_550 hu.pt.un_870
  0x17080a04, 0x03003513, 0x2d5509ee, 0x17070a0d,   // mk.uk.sr_332 zu.nl.un_650  pl.rw.sk_422 mk.bg.sr_554
  // [1650]
  0x12211860, 0x21000c07, 0x080a1007, 0x0602010c,   // ar.fa.ur_664 sv.jw.un_420  be.mk.uk_432 en.da.de_543
  0x0d040c0c, 0x0f000608, 0x130b2aee, 0x27033fac,   // sv.fi.cs_543 de.lv.un_430  mt.es.et_422 af.nl.gd_632
  0x06171605, 0x1f311b0b, 0x2b001a09, 0x2a0d20ad,   // hr.sr.de_333 tr.az.cy_542  tl.vi.un_440 sq.cs.mt_643
  0x25645508, 0x07040814, 0x0f000709, 0x19250b07,   // rw.lg.eu_443 uk.ru.bg_666  it.lv.un_440 es.eu.gl_432
  // [1660]
  0x0d000918, 0x3100080d, 0x0a00101a, 0x10040813,   // hi.ne.un_740 no.az.un_540  be.mk.un_760 uk.ru.be_665
  0x1c000d1a, 0x31001a07, 0x01171602, 0x2a001705,   // ne.mr.un_760 tl.az.un_420  hr.sr.en_222 sr.mt.un_330
  0x0d5525a4, 0x313b2a0c, 0x28556405, 0x3b2303a0,   // eu.rw.cs_433 mt.so.az_543  lg.rw.sw_333 nl.ca.so_322
  0x2a00180c, 0x132d0d0d, 0x3f2821a4, 0x3f121fa0,   // ga.mt.un_530 cs.sk.et_554  jw.sw.af_433 cy.hu.af_322
  // [1670]
  0x00001f03, 0x210c1708, 0x251101a4, 0x11080405,   // cy.un.un_300 sr.sv.jw_443  en.ro.eu_433 ru.uk.ro_333
  0x00002037, 0x03005202, 0x0710040d, 0x04000a08,   // sq.un.un_B00 ha.nl.un_220  ru.be.bg_554 mk.ru.un_430
  0x070901a7, 0x1325050c, 0x101c2108, 0x110810a4,   // en.pl.it_532 fr.eu.et_543  jw.id.lt_443 be.uk.ro_433
  0x6b2a01a4, 0x52032d0d, 0x1b0812af, 0x10060fad,   // en.mt.ceb_433 sk.nl.ha_554  hu.no.tr_655 lv.de.lt_643
  // [1680]
  0x030412ad, 0x1b12250c, 0x080203a9, 0x202d290c,   // hu.fi.nl_643 eu.hu.tr_543  nl.da.no_544 sl.sk.sq_543
  0x292d0d5a, 0x100f0713, 0x532a2107, 0x11040860,   // cs.sk.sl_553 it.lv.lt_665  jw.mt.ht_432 uk.ru.ro_664
  0x1712010c, 0x120f2907, 0x04081712, 0x04110813,   // en.hu.sr_543 sl.lv.hu_432  sr.uk.ru_654 uk.ro.ru_665
  0x172a10a4, 0x3f100309, 0x02002902, 0x0a0501a9,   // lt.mt.sr_433 nl.lt.af_444  sl.da.un_220 en.fr.pt_544
  // [1690]
  0x13000608, 0x1b001021, 0x2d0d1fee, 0x2a000f1a,   // de.et.un_430 lt.tr.un_860  cy.cs.sk_422 lv.mt.un_760
  0x04033f55, 0x3f000318, 0x20000313, 0x040a170c,   // af.nl.fi_442 nl.af.un_740  nl.sq.un_650 sr.mk.ru_543
  0x4a001a02, 0x3f00030d, 0x0103070c, 0x32002a09,   // tl.yo.un_220 nl.af.un_540  it.nl.en_543 mt.bs.un_440
  0x1803270d, 0x251b3112, 0x10090f12, 0x12001304,   // gd.nl.ga_554 az.tr.eu_654  lv.pl.lt_654 et.hu.un_320
  // [16a0]
  0x06005208, 0x03063faf, 0x25041012, 0x21531e07,   // ha.de.un_430 af.de.nl_655  lt.fi.eu_654 ms.ht.jw_432
  0x11103baf, 0x1200181a, 0x0f292a60, 0x00001e24,   // so.lt.ro_655 ar.ur.un_760  mt.sl.lv_664 ms.un.un_900
  0x032718af, 0x032513a4, 0x0d092d55, 0x3f23030c,   // ga.gd.nl_655 et.eu.nl_433  sk.pl.cs_442 nl.ca.af_543
  0x250c08af, 0x25001221, 0x1e005209, 0x6b081aec,   // no.sv.eu_655 hu.eu.un_860  ha.ms.un_440 tl.no.ceb_644
  // [16b0]
  0x18276ba4, 0x684a53a4, 0x2a001c08, 0x53001f07,   // ceb.gd.ga_433 ht.yo.ig_433  id.mt.un_430 cy.ht.un_420
  0x0b193ba7, 0x0f001014, 0x1e211cac, 0x061125a7,   // so.gl.es_532 lt.lv.un_660  id.jw.ms_632 eu.ro.de_532
  0x292a0f13, 0x1253250c, 0x070a04a4, 0x3b002a1a,   // lv.mt.sl_665 eu.ht.hu_543  ru.mk.bg_433 mt.so.un_760
  0x0400291a, 0x52681ca4, 0x0710040c, 0x19052012,   // sl.fi.un_760 id.ig.ha_433  ru.be.bg_543 sq.fr.gl_654
  // [16c0]
  0x071827ad, 0x290e2aa9, 0x521f2aad, 0x3b531a13,   // gd.ga.it_643 mt.is.sl_544  mt.cy.ha_643 tl.ht.so_665
  0x13292a09, 0x05012304, 0x290f2a12, 0x0a1711ec,   // mt.sl.et_444 ca.en.fr_332  mt.lv.sl_654 ro.sr.mk_644
  0x292117a0, 0x17002508, 0x291721a4, 0x190a23a9,   // sr.jw.sl_322 eu.sr.un_430  jw.sr.sl_433 ca.pt.gl_544
  0x11000a12, 0x130910a4, 0x53002109, 0x070a1712,   // pt.ro.un_640 lt.pl.et_433  jw.ht.un_440 sr.mk.bg_654
  // [16d0]
  0x2a211755, 0x210d200d, 0x04130ca9, 0x033f28af,   // sr.jw.mt_442 sq.cs.jw_554  sv.et.fi_544 sw.af.nl_655
  0x0a0717a9, 0x101e1c08, 0x211e5202, 0x02310804,   // sr.bg.mk_544 id.ms.lt_443  ha.ms.jw_222 no.az.da_332
  0x2900250c, 0x0a071709, 0x25001022, 0x04000a22,   // eu.sl.un_530 sr.bg.mk_444  lt.eu.un_870 mk.ru.un_870
  0x23000a04, 0x10070aa0, 0x07041060, 0x080a04a4,   // pt.ca.un_320 mk.bg.be_322  be.ru.bg_664 ru.mk.uk_433
  // [16e0]
  0x101c1105, 0x10130404, 0x2a53010c, 0x35321602,   // ro.id.lt_333 fi.et.lt_332  en.ht.mt_543 hr.bs.zu_222
  0x07180407, 0x1c005319, 0x19350ba7, 0x0300211b,   // fi.ga.it_432 ht.id.un_750  es.zu.gl_532 jw.nl.un_770
  0x11211c07, 0x04131ba4, 0x3b005208, 0x2000110c,   // id.jw.ro_432 tr.et.fi_433  ha.so.un_430 ro.sq.un_530
  0x6b000913, 0x16202da0, 0x0306250d, 0x13681b09,   // pl.ceb.un_650 sk.sq.hr_322  eu.de.nl_554 tr.ig.et_444
  // [16f0]
  0x05000a04, 0x201b350b, 0x29001604, 0x23190ba0,   // pt.fr.un_320 zu.tr.sq_542  hr.sl.un_320 es.gl.ca_322
  0x1b003f21, 0x07641b08, 0x03120f12, 0x6e6b010c,   // af.tr.un_860 tr.lg.it_443  lv.hu.nl_654 en.ceb.hmn_543
  0x1c521e08, 0x4a111255, 0x3f031b0e, 0x6b001a13,   // ms.ha.id_443 hu.ro.yo_442  tr.nl.af_555 tl.ceb.un_650
  0x0a071004, 0x123b13ad, 0x10000423, 0x062827ad,   // be.bg.mk_332 et.so.hu_643  ru.be.un_880 gd.sw.de_643
  // [1700]
  0x06001f23, 0x01253f08, 0x1f230509, 0x641b5508,   // cy.de.un_880 af.eu.en_443  fr.ca.cy_444 rw.tr.lg_443
  0x0a3b19ee, 0x06001c04, 0x050601a4, 0x0600272b,   // gl.so.pt_422 id.de.un_320  en.de.fr_433 gd.de.un_980
  0x211b1cee, 0x10213507, 0x0e000d14, 0x0e2d0d05,   // id.tr.jw_422 zu.jw.lt_432  cs.is.un_660 cs.sk.is_333
  0x1c0d090e, 0x0f002702, 0x170903a4, 0x2a2032ee,   // hi.ne.mr_555 gd.lv.un_220  nl.pl.sr_433 bs.sq.mt_422
  // [1710]
  0x642006af, 0x04132507, 0x07201b0b, 0x5220040c,   // de.sq.lg_655 eu.et.fi_432  tr.sq.it_542 fi.sq.ha_543
  0x1300550d, 0x040711ee, 0x050723a4, 0x0900110c,   // rw.et.un_540 ro.bg.ru_422  ca.it.fr_433 ro.pl.un_530
  0x683f030c, 0x1b520409, 0x3f000620, 0x102b1107,   // nl.af.ig_543 fi.ha.tr_444  de.af.un_850 ro.vi.lt_432
  0x04000804, 0x0a00060d, 0x520e0409, 0x1b004a1b,   // no.fi.un_320 de.pt.un_540  fi.is.ha_444 yo.tr.un_770
  // [1720]
  0x64211ca7, 0x35002914, 0x080c06a4, 0x130435a4,   // id.jw.lg_532 sl.zu.un_660  de.sv.no_433 zu.fi.et_433
  0x211c68af, 0x19040705, 0x19000b0b, 0x0b001904,   // ig.id.jw_655 it.fi.gl_333  es.gl.un_520 gl.es.un_320
  0x55071b0c, 0x1c000204, 0x110b6e04, 0x092d0d05,   // tr.it.rw_543 da.id.un_320  hmn.es.ro_332 cs.sk.pl_333
  0x0b231911, 0x550f1ba4, 0x2b002821, 0x233b010c,   // gl.ca.es_653 tr.lv.rw_433  sw.vi.un_860 en.so.ca_543
  // [1730]
  0x120428ee, 0x270c010c, 0x52282b0b, 0x0d0506ad,   // sw.fi.hu_422 en.sv.gd_543  vi.sw.ha_542 de.fr.cs_643
  0x17292d12, 0x11000a0e, 0x0300062b, 0x2b280a60,   // sk.sl.sr_654 pt.ro.un_550  de.nl.un_980 pt.sw.vi_664
  0x12002504, 0x08311b0d, 0x0118060b, 0x020618ec,   // eu.hu.un_320 tr.az.no_554  de.ga.en_542 ga.de.da_644
  0x1b003105, 0x0000160f, 0x3b00230d, 0x31556413,   // az.tr.un_330 hr.un.un_600  ca.so.un_540 lg.rw.az_665
  // [1740]
  0x061f5255, 0x20006804, 0x2a3b04a4, 0x04000c07,   // ha.cy.de_442 ig.sq.un_320  fi.so.mt_433 sv.fi.un_420
  0x03003f34, 0x316b1a08, 0x1b0401a4, 0x2331520c,   // af.nl.un_A80 tl.ceb.az_443  en.fi.tr_433 ha.az.ca_543
  0x1b0c2aa4, 0x13200414, 0x040710a0, 0x31000522,   // mt.sv.tr_433 fi.sq.et_666  be.bg.ru_322 fr.az.un_870
  0x0b3b2d07, 0x1a6b0808, 0x25096b07, 0x0811040c,   // sk.so.es_432 no.ceb.tl_443  ceb.pl.eu_432 ru.ro.uk_543
  // [1750]
  0x030608a7, 0x3f0c230c, 0x10002914, 0x12002304,   // no.de.nl_532 ca.sv.af_543  sl.lt.un_660 ca.hu.un_320
  0x281e2a09, 0x03040807, 0x1e282912, 0x0200031b,   // mt.ms.sw_444 no.fi.nl_432  sl.sw.ms_654 nl.da.un_770
  0x64000421, 0x0f006b12, 0x0a002b29, 0x29001b0d,   // fi.lg.un_860 ceb.lv.un_640  vi.pt.un_960 tr.sl.un_540
  0x3f0307a4, 0x1c090d09, 0x17041009, 0x53001608,   // it.nl.af_433 ne.hi.mr_444  be.ru.sr_444 hr.ht.un_430
  // [1760]
  0x0b0a1fec, 0x64001a02, 0x0a002b18, 0x2b001a2a,   // cy.pt.es_644 tl.lg.un_220  vi.pt.un_740 tl.vi.un_970
  0x1b313b12, 0x643f3bad, 0x060c0255, 0x2a3b09af,   // so.az.tr_654 so.af.lg_643  da.sv.de_442 pl.so.mt_655
  0x255535ad, 0x180627ec, 0x0400082c, 0x110f10a4,   // zu.rw.eu_643 gd.de.ga_644  uk.ru.un_990 lt.lv.ro_433
  0x6b3127a4, 0x2d001604, 0x08041012, 0x3f021fa4,   // gd.az.ceb_433 hr.sk.un_320  be.ru.uk_654 cy.da.af_433
  // [1770]
  0x00000601, 0x2a3b31af, 0x2300060d, 0x09080c0d,   // de.un.un_200 az.so.mt_655  de.ca.un_540 sv.no.pl_554
  0x131c09ac, 0x08041704, 0x061335ad, 0x170a11ec,   // hi.mr.bh_632 sr.ru.uk_332  zu.et.de_643 ro.mk.sr_644
  0x05010708, 0x1b313513, 0x030608a4, 0x081306a4,   // it.en.fr_443 zu.az.tr_665  no.de.nl_433 de.et.no_433
  0x6b001a0e, 0x05000621, 0x21321704, 0x040708a6,   // tl.ceb.un_550 de.fr.un_860  sr.bs.jw_332 uk.bg.ru_521
  // [1780]
  0x1a64040c, 0x3f0603af, 0x03082508, 0x25190bec,   // fi.lg.tl_543 nl.de.af_655  eu.no.nl_443 es.gl.eu_644
  0x32162914, 0x01021302, 0x13080e07, 0x13000821,   // sl.hr.bs_666 et.da.en_222  is.no.et_432 no.et.un_860
  0x02550512, 0x06000819, 0x1c2120ad, 0x04001902,   // fr.rw.da_654 no.de.un_750  sq.jw.id_643 gl.fi.un_220
  0x1b133204, 0x08060302, 0x0e00181a, 0x211e1c55,   // bs.et.tr_332 nl.de.no_222  ga.is.un_760 id.ms.jw_442
  // [1790]
  0x1b003513, 0x2900020e, 0x13170855, 0x07006404,   // zu.tr.un_650 da.sl.un_550  no.sr.et_442 lg.it.un_320
  0x08060ea0, 0x131c0907, 0x08130e12, 0x186b1a08,   // is.de.no_322 hi.mr.bh_432  is.et.no_654 tl.ceb.ga_443
  0x311b5502, 0x20000305, 0x0c00082b, 0x1a216bad,   // rw.tr.az_222 nl.sq.un_330  no.sv.un_980 ceb.jw.tl_643
  0x35000619, 0x29001708, 0x040811ec, 0x06003512,   // de.zu.un_750 sr.sl.un_430  ro.uk.ru_644 zu.de.un_640
  // [17a0]
  0x20001a07, 0x081011a6, 0x1e0e0607, 0x09000d1b,   // tl.sq.un_420 ro.be.uk_521  de.is.ms_432 ne.hi.un_770
  0x1b0f0ea0, 0x3b250e0c, 0x08130c11, 0x27161ba0,   // is.lv.tr_322 is.eu.so_543  sv.et.no_653 tr.hr.gd_322
  0x0b002d07, 0x2d0952a4, 0x16292da4, 0x13000808,   // sk.es.un_420 ha.pl.sk_433  sk.sl.hr_433 no.et.un_430
  0x2a000913, 0x23001909, 0x0400100e, 0x080201a4,   // pl.mt.un_650 gl.ca.un_440  be.ru.un_550 en.da.no_433
  // [17b0]
  0x060e1ea9, 0x1f002719, 0x10030fee, 0x0c200fa4,   // ms.is.de_544 gd.cy.un_750  lv.nl.lt_422 lv.sq.sv_433
  0x0e130405, 0x520c1f0c, 0x1801050c, 0x351a6ba7,   // fi.et.is_333 cy.sv.ha_543  fr.en.ga_543 ceb.tl.zu_532
  0x05182bad, 0x6b0a1a07, 0x1c130960, 0x530c08ad,   // vi.ga.fr_643 tl.pt.ceb_432  hi.bh.mr_664 no.sv.ht_643
  0x28005202, 0x1e2d0d0c, 0x0f111205, 0x2d0d02a9,   // ha.sw.un_220 cs.sk.ms_543  hu.ro.lv_333 da.cs.sk_544
  // [17c0]
  0x183b1307, 0x0c086411, 0x0a0f110c, 0x27181a04,   // et.so.ga_432 lg.no.sv_653  ro.lv.pt_543 tl.ga.gd_332
  0x0a3f110c, 0x07033f09, 0x20103fec, 0x07080405,   // ro.af.pt_543 af.nl.it_444  af.lt.sq_644 ru.uk.bg_333
  0x07170a05, 0x00001101, 0x27001820, 0x11080aa7,   // mk.sr.bg_333 ro.un.un_200  ga.gd.un_850 pt.no.ro_532
  0x17290fa4, 0x10123fa4, 0x030b28ad, 0x11000f08,   // lv.sl.sr_433 af.hu.lt_433  sw.es.nl_643 lv.ro.un_430
  // [17d0]
  0x0900160d, 0x021b5307, 0x27351a04, 0x10122508,   // hr.pl.un_540 ht.tr.da_432  tl.zu.gd_332 eu.hu.lt_443
  0x0804100e, 0x55002012, 0x07001104, 0x17001b0c,   // be.ru.uk_555 sq.rw.un_640  ro.it.un_320 tr.sr.un_530
  0x0a3f060c, 0x2d3b6b0c, 0x0f0a11a4, 0x0c08020c,   // de.af.pt_543 ceb.so.sk_543  ro.pt.lv_433 da.no.sv_543
  0x6b0d2dee, 0x09000313, 0x0f6b100c, 0x2d0d310e,   // sk.cs.ceb_422 nl.pl.un_650  lt.ceb.lv_543 az.cs.sk_555
  // [17e0]
  0x531b310c, 0x1b0f190d, 0x6b551a13, 0x0b0a070b,   // az.tr.ht_543 gl.lv.tr_554  tl.rw.ceb_665 it.pt.es_542
  0x063f08a0, 0x1b004a14, 0x102a4aa9, 0x080302ad,   // no.af.de_322 yo.tr.un_660  yo.mt.lt_544 da.nl.no_643
  0x180227a6, 0x03000b04, 0x6b001a19, 0x19110a5a,   // gd.da.ga_521 es.nl.un_320  tl.ceb.un_750 pt.ro.gl_553
  0x100f11a4, 0x033b64ac, 0x0e00521b, 0x1a006b2b,   // ro.lv.lt_433 lg.so.nl_632  ha.is.un_770 ceb.tl.un_980
  // [17f0]
  0x3f0352a0, 0x0c203f55, 0x2a556b11, 0x0c3b6b0d,   // ha.nl.af_322 af.sq.sv_442  ceb.rw.mt_653 ceb.so.sv_554
  0x071711a4, 0x120f11a4, 0x06016ba0, 0x071211a4,   // ro.sr.bg_433 ro.lv.hu_433  ceb.en.de_322 ro.hu.it_433
  0x1e1c0e14, 0x04070aa9, 0x20090805, 0x06001f12,   // is.id.ms_666 mk.bg.ru_544  no.pl.sq_333 cy.de.un_640
  0x02131f60, 0x6b292a04, 0x01004a05, 0x312d0d13,   // cy.et.da_664 mt.sl.ceb_332  yo.en.un_330 cs.sk.az_665

  // [1800]
  0x10072a07, 0x3b006b13, 0x213b4aee, 0x1f2d0d13,   // mt.it.lt_432 ceb.so.un_650  yo.so.jw_422 cs.sk.cy_665
  0x08230ca0, 0x08120ead, 0x0a1105ec, 0x292d0d13,   // sv.ca.no_322 is.hu.no_643  fr.ro.pt_644 cs.sk.sl_665
  0x0e080caf, 0x32002907, 0x130c0807, 0x07001107,   // sv.no.is_655 sl.bs.un_420  no.sv.et_432 ro.bg.un_420
  0x55003202, 0x0f052304, 0x2a072312, 0x071710ee,   // bs.rw.un_220 ca.fr.lv_332  ca.it.mt_654 be.sr.bg_422
  // [1810]
  0x0a1711a0, 0x55126ba7, 0x06080cee, 0x21002704,   // ro.sr.mk_322 ceb.hu.rw_532  sv.no.de_422 gd.jw.un_320
  0x08041108, 0x1c0d09a7, 0x08000c23, 0x53644aee,   // ro.ru.uk_443 hi.ne.mr_532  sv.no.un_880 yo.lg.ht_422
  0x2a190a0d, 0x08000a14, 0x352832a0, 0x08002a1b,   // pt.gl.mt_554 mk.uk.un_660  bs.sw.zu_322 mt.no.un_770
  0x070425a4, 0x07171008, 0x17000c19, 0x0a170713,   // eu.fi.it_433 be.sr.bg_443  sv.sr.un_750 bg.sr.mk_665
  // [1820]
  0x190b0a0c, 0x17040a0c, 0x1b321702, 0x1f005304,   // pt.es.gl_543 mk.ru.sr_543  sr.bs.tr_222 ht.cy.un_320
  0x6b1a0404, 0x17270e04, 0x25030607, 0x6b1a6ea9,   // fi.tl.ceb_332 is.gd.sr_332  de.nl.eu_432 hmn.tl.ceb_544
  0x526b31a4, 0x0b190a0c, 0x0c080304, 0x6e000808,   // az.ceb.ha_433 pt.gl.es_543  nl.no.sv_332 no.hmn.un_430
  0x13003b1e, 0x08040a02, 0x6e6b1a0d, 0x0c005204,   // so.et.un_830 mk.ru.uk_222  tl.ceb.hmn_554 ha.sv.un_320
  // [1830]
  0x0200121a, 0x080206ee, 0x08002012, 0x27190a0d,   // hu.da.un_760 de.da.no_422  sq.no.un_640 pt.gl.gd_554
  0x09001c19, 0x12030655, 0x12000c12, 0x3b286ead,   // mr.hi.un_750 de.nl.hu_442  sv.hu.un_640 hmn.sw.so_643
  0x2d0d01a4, 0x3f000608, 0x071104a4, 0x110208a7,   // en.cs.sk_433 de.af.un_430  ru.ro.bg_433 no.da.ro_532
  0x016e1ca0, 0x02000812, 0x1f190a13, 0x09290a08,   // id.hmn.en_322 no.da.un_640  pt.gl.cy_665 pt.sl.pl_443
  // [1840]
  0x09002918, 0x6e000314, 0x04001020, 0x12060d0c,   // sl.pl.un_740 nl.hmn.un_660  be.ru.un_850 cs.de.hu_543
  0x120e0a0b, 0x2d0d35af, 0x1106230b, 0x1c12040c,   // pt.is.hu_542 zu.cs.sk_655  ca.de.ro_542 fi.hu.id_543
  0x6e200d0c, 0x06006b04, 0x0d1c13ad, 0x06002502,   // cs.sq.hmn_543 ceb.de.un_320  bh.mr.ne_643 eu.de.un_220
  0x0d12290d, 0x27190a60, 0x0c030207, 0x0a001913,   // sl.hu.cs_554 pt.gl.gd_664  da.nl.sv_432 gl.pt.un_650
  // [1850]
  0x530501a0, 0x060a0da9, 0x032506a4, 0x6e193bad,   // en.fr.ht_322 cs.pt.de_544  de.eu.nl_433 so.gl.hmn_643
  0x063f02a4, 0x64005212, 0x1a006b35, 0x13210aad,   // da.af.de_433 ha.lg.un_640  ceb.tl.un_A90 pt.jw.et_643
  0x4a1b5205, 0x6e005308, 0x033f0c55, 0x64005208,   // ha.tr.yo_333 ht.hmn.un_430  sv.af.nl_442 ha.lg.un_430
  0x2d090daf, 0x1f3f1a60, 0x0a230d08, 0x112d0d07,   // cs.pl.sk_655 tl.af.cy_664  cs.ca.pt_443 cs.sk.ro_432
  // [1860]
  0x170a110c, 0x1f0820a6, 0x09001c18, 0x55100cee,   // ro.mk.sr_543 sq.no.cy_521  mr.hi.un_740 sv.lt.rw_422
  0x10190a5a, 0x312d0dee, 0x03001802, 0x00001806,   // pt.gl.lt_553 cs.sk.az_422  ga.nl.un_220 ga.un.un_400
  0x1a001e0d, 0x0d001c12, 0x64523513, 0x64190a5a,   // ms.tl.un_540 mr.ne.un_640  zu.ha.lg_665 pt.gl.lg_553
  0x0a000804, 0x020e0c60, 0x04171007, 0x0a0d2307,   // no.pt.un_320 sv.is.da_664  be.sr.ru_432 ca.cs.pt_432
  // [1870]
  0x18683fee, 0x0a290daf, 0x0c160d07, 0x131a3555,   // af.ig.ga_422 cs.sl.pt_655  cs.hr.sv_432 zu.tl.et_442
  0x17290da4, 0x1a642809, 0x032a0cec, 0x19006b0c,   // cs.sl.sr_433 sw.lg.tl_444  sv.mt.nl_644 ceb.gl.un_530
  0x040a0709, 0x20001705, 0x11070805, 0x29060da4,   // bg.mk.ru_444 sr.sq.un_330  uk.bg.ro_333 cs.de.sl_433
  0x64683507, 0x352564a4, 0x21181211, 0x110a0412,   // zu.ig.lg_432 lg.eu.zu_433  ur.ar.fa_653 ru.mk.ro_654
  // [1880]
  0x00001c2d, 0x19130ba7, 0x00001a24, 0x190b2309,   // mr.un.un_A00 es.et.gl_532  tl.un.un_900 ca.es.gl_444
  0x3f2528ad, 0x09131cad, 0x06005302, 0x06080209,   // sw.eu.af_643 mr.bh.hi_643  ht.de.un_220 da.no.de_444
  0x250564ec, 0x2d0d5209, 0x2d0d0fa4, 0x12190b08,   // lg.fr.eu_644 ha.cs.sk_444  lv.cs.sk_433 es.gl.hu_443
  0x11001a04, 0x292d0d02, 0x11000a0d, 0x170a0755,   // tl.ro.un_320 cs.sk.sl_222  pt.ro.un_540 bg.mk.sr_442
  // [1890]
  0x0f001a04, 0x216435af, 0x351764ad, 0x16290908,   // tl.lv.un_320 zu.lg.jw_655  lg.sr.zu_643 pl.sl.hr_443
  0x31521304, 0x17070808, 0x3500640e, 0x08002708,   // et.ha.az_332 uk.bg.sr_443  lg.zu.un_550 gd.no.un_430
  0x256468ee, 0x27112312, 0x1135640c, 0x1c2a6407,   // ig.lg.eu_422 ca.ro.gd_654  lg.zu.ro_543 lg.mt.id_432
  0x0c000604, 0x0b000504, 0x0f001013, 0x00002b01,   // de.sv.un_320 fr.es.un_320  lt.lv.un_650 vi.un.un_200
  // [18a0]
  0x07000a22, 0x0f080ca0, 0x080a170c, 0x08170aa0,   // mk.bg.un_870 sv.no.lv_322  sr.mk.uk_543 mk.sr.uk_322
  0x1c1309a4, 0x35553112, 0x160d2dee, 0x08020e02,   // hi.bh.mr_433 az.rw.zu_654  sk.cs.hr_422 is.da.no_222
  0x09006411, 0x0d001c14, 0x12180ea9, 0x0400072a,   // lg.pl.un_630 mr.ne.un_660  is.ga.hu_544 bg.ru.un_970
  0x04001a02, 0x00001103, 0x1e1c3b05, 0x2d200907,   // tl.fi.un_220 ro.un.un_300  so.id.ms_333 pl.sq.sk_432
  // [18b0]
  0x07170a0e, 0x091c0da9, 0x68004a12, 0x3b006b0c,   // mk.sr.bg_555 ne.mr.hi_544  yo.ig.un_640 ceb.so.un_530
  0x0c000907, 0x110a0fa7, 0x0e000c0d, 0x533564ec,   // pl.sv.un_420 lv.pt.ro_532  sv.is.un_540 lg.zu.ht_644
  0x1c001313, 0x2528110c, 0x04071105, 0x085523a0,   // bh.mr.un_650 ro.sw.eu_543  ro.bg.ru_333 ca.rw.no_322
  0x11252812, 0x2b001702, 0x0b2511a9, 0x190906ee,   // sw.eu.ro_654 sr.vi.un_220  ro.eu.es_544 de.pl.gl_422
  // [18c0]
  0x685301a4, 0x042513a4, 0x04001312, 0x2500281a,   // en.ht.ig_433 et.eu.fi_433  et.fi.un_640 sw.eu.un_760
  0x0d1125a9, 0x04001323, 0x171108ad, 0x04033fad,   // eu.ro.cs_544 et.fi.un_880  uk.ro.sr_643 af.nl.fi_643
  0x0b033fa0, 0x1e251107, 0x030113a9, 0x252811af,   // af.nl.es_322 ro.eu.ms_432  et.en.nl_544 ro.sw.eu_655
  0x05002d0d, 0x4a001122, 0x3f3b0308, 0x3f3b01ad,   // sk.fr.un_540 ro.yo.un_870  nl.so.af_443 en.so.af_643
  // [18d0]
  0x13006405, 0x07001702, 0x1a000120, 0x6b6811a6,   // lg.et.un_330 sr.bg.un_220  en.tl.un_850 ro.ig.ceb_521
  0x041a0e0c, 0x1b002a04, 0x3f031307, 0x031364a9,   // is.tl.fi_543 mt.tr.un_320  et.nl.af_432 lg.et.nl_544
  0x4a2529a0, 0x1b203bad, 0x016b09ad, 0x3f00032b,   // sl.eu.yo_322 so.sq.tr_643  pl.ceb.en_643 nl.af.un_980
  0x133b64a9, 0x091c2104, 0x190b07ee, 0x12102108,   // lg.so.et_544 jw.id.pl_332  it.es.gl_422 jw.lt.hu_443
  // [18e0]
  0x121821a9, 0x28250d0c, 0x350a110c, 0x55000919,   // fa.ar.ur_544 cs.eu.sw_543  ro.pt.zu_543 pl.rw.un_750
  0x530868a0, 0x2d043205, 0x1c091312, 0x04100fee,   // ig.no.ht_322 bs.fi.sk_333  bh.hi.mr_654 lv.lt.fi_422
  0x12005304, 0x35001113, 0x28251160, 0x10000914,   // ht.hu.un_320 ro.zu.un_650  ro.eu.sw_664 pl.lt.un_660
  0x25001134, 0x11080412, 0x09006402, 0x23132a0c,   // ro.eu.un_A80 ru.uk.ro_654  lg.pl.un_220 mt.et.ca_543
  // [18f0]
  0x3b000307, 0x2d000d07, 0x3f031308, 0x1923530d,   // nl.so.un_420 cs.sk.un_420  et.nl.af_443 ht.ca.gl_554
  0x29001f05, 0x131f0c08, 0x040a11a4, 0x090306ad,   // cy.sl.un_330 sv.cy.et_443  ro.mk.ru_433 de.nl.pl_643
  0x3f0364ec, 0x2d0d0912, 0x25031308, 0x2b3f0112,   // lg.nl.af_644 pl.cs.sk_654  et.nl.eu_443 en.af.vi_654
  0x3b03135a, 0x250411a4, 0x130364a9, 0x110407a9,   // et.nl.so_553 ro.fi.eu_433  lg.nl.et_544 bg.ru.ro_544
  // [1900]
  0x132d290c, 0x0c2d0d13, 0x03136412, 0x25192aa4,   // sl.sk.et_543 cs.sk.sv_665  lg.et.nl_654 mt.gl.eu_433
  0x1a1e1c5a, 0x1c000d05, 0x0c131a02, 0x12002912,   // id.ms.tl_553 ne.mr.un_330  tl.et.sv_222 sl.hu.un_640
  0x0a071008, 0x0d0a23a0, 0x681202ad, 0x09004a02,   // be.bg.mk_443 ca.pt.cs_322  da.hu.ig_643 yo.pl.un_220
  0x1800121a, 0x10001c04, 0x0c3f08ee, 0x16003204,   // ur.ar.un_760 id.lt.un_320  no.af.sv_422 bs.hr.un_320
  // [1910]
  0x03010605, 0x0d00290c, 0x043b0c04, 0x281a2904,   // de.en.nl_333 sl.cs.un_530  sv.so.fi_332 sl.tl.sw_332
  0x25000c04, 0x2d120c12, 0x01002104, 0x0700640d,   // sv.eu.un_320 sv.hu.sk_654  jw.en.un_320 lg.it.un_540
  0x00000c24, 0x2500061a, 0x050c2104, 0x55121007,   // sv.un.un_900 de.eu.un_760  jw.sv.fr_332 lt.hu.rw_432
  0x1b002912, 0x55524a07, 0x110c1607, 0x0b000705,   // sl.tr.un_640 yo.ha.rw_432  hr.sv.ro_432 it.es.un_330
  // [1920]
  0x1f003b19, 0x21001818, 0x131e1c55, 0x2a001307,   // so.cy.un_750 ar.fa.un_740  id.ms.et_442 et.mt.un_420
  0x16122907, 0x17200dee, 0x4a122d12, 0x0a000722,   // sl.hu.hr_432 cs.sq.sr_422  sk.hu.yo_654 bg.mk.un_870
  0x07000409, 0x25002713, 0x6e2301ad, 0x182325a4,   // ru.bg.un_440 gd.eu.un_650  en.ca.hmn_643 eu.ca.ga_433
  0x32171608, 0x0725180c, 0x2a006b21, 0x02232907,   // hr.sr.bs_443 ga.eu.it_543  ceb.mt.un_860 sl.ca.da_432
  // [1930]
  0x6e190bad, 0x12004a12, 0x521323ad, 0x071806a7,   // es.gl.hmn_643 yo.hu.un_640  ca.et.ha_643 de.ga.it_532
  0x1000121a, 0x08111707, 0x3b280304, 0x182725af,   // hu.lt.un_760 sr.ro.uk_432  nl.sw.so_332 eu.gd.ga_655
  0x28680411, 0x04102a11, 0x07003204, 0x32051ea4,   // fi.ig.sw_653 mt.lt.fi_653  bs.it.un_320 ms.fr.bs_433
  0x05236eec, 0x3f07040c, 0x063f090c, 0x27251812,   // hmn.ca.fr_644 fi.it.af_543  pl.af.de_543 ga.eu.gd_654
  // [1940]
  0x190a06af, 0x55002d07, 0x3b686e08, 0x28046814,   // de.pt.gl_655 sk.rw.un_420  hmn.ig.so_443 ig.fi.sw_666
  0x276e5308, 0x250627a4, 0x09000f14, 0x18001114,   // ht.hmn.gd_443 gd.de.eu_433  lv.pl.un_660 ro.ga.un_660
  0x1b1a6b09, 0x03683b07, 0x0e130f0c, 0x09350807,   // ceb.tl.tr_444 so.ig.nl_432  lv.et.is_543 no.zu.pl_432
  0x04004a0d, 0x01035202, 0x1b316eec, 0x090407ee,   // yo.fi.un_540 ha.nl.en_222  hmn.az.tr_644 it.fi.pl_422
  // [1950]
  0x070a08a9, 0x3b003f21, 0x21530412, 0x3b002a0c,   // uk.mk.bg_544 af.so.un_860  fi.ht.jw_654 mt.so.un_530
  0x06090faf, 0x190a130c, 0x350e01a4, 0x0a170709,   // lv.pl.de_655 et.pt.gl_543  en.is.zu_433 bg.sr.mk_444
  0x07171007, 0x21131ca0, 0x21001704, 0x12002812,   // be.sr.bg_432 id.et.jw_322  sr.jw.un_320 sw.hu.un_640
  0x3f3b1104, 0x0f001108, 0x10200511, 0x080e1fa4,   // ro.so.af_332 ro.lv.un_430  fr.sq.lt_653 cy.is.no_433
  // [1960]
  0x1827250c, 0x2a3b6eec, 0x03020e05, 0x0113250c,   // eu.gd.ga_543 hmn.so.mt_644  is.da.nl_333 eu.et.en_543
  0x3f040704, 0x0600012a, 0x04190b0c, 0x271801ad,   // it.fi.af_332 en.de.un_970  es.gl.fi_543 en.ga.gd_643
  0x110328a6, 0x0f2a6e14, 0x07000f21, 0x01003b19,   // sw.nl.ro_521 hmn.mt.lv_666  lv.it.un_860 so.en.un_750
  0x35136ba7, 0x21001802, 0x02030607, 0x0a001704,   // ceb.et.zu_532 ar.fa.un_220  de.nl.da_432 sr.mk.un_320
  // [1970]
  0x1a3f68a7, 0x6b00090d, 0x10190bec, 0x3f133b09,   // ig.af.tl_532 pl.ceb.un_540  es.gl.lt_644 so.et.af_444
  0x17081002, 0x190b2313, 0x17040811, 0x060b04a4,   // be.uk.sr_222 ca.es.gl_665  uk.ru.sr_653 fi.es.de_433
  0x04076807, 0x4a190bee, 0x1f1b0eec, 0x520e3512,   // ig.it.fi_432 es.gl.yo_422  is.tr.cy_644 zu.is.ha_654
  0x12006402, 0x070a17a4, 0x08290c08, 0x6b1a0b0d,   // lg.hu.un_220 sr.mk.bg_433  sv.sl.no_443 es.tl.ceb_554
  // [1980]
  0x0b002a07, 0x52120eaf, 0x07040809, 0x03016b07,   // mt.es.un_420 is.hu.ha_655  uk.ru.bg_444 ceb.en.nl_432
  0x1e315208, 0x08120407, 0x0a190b08, 0x3f2801a4,   // ha.az.ms_443 fi.hu.no_432  es.gl.pt_443 en.sw.af_433
  0x040a1005, 0x0813040b, 0x2d00091a, 0x03003f09,   // be.mk.ru_333 fi.et.no_542  pl.sk.un_760 af.nl.un_440
  0x09001f1a, 0x0c086b09, 0x070817a0, 0x18002705,   // cy.pl.un_760 ceb.no.sv_444  sr.uk.bg_322 gd.ga.un_330
  // [1990]
  0x091c130d, 0x03011f07, 0x53524a07, 0x020306ad,   // bh.mr.hi_554 cy.en.nl_432  yo.ha.ht_432 de.nl.da_643
  0x3f0b6b02, 0x1c091302, 0x036b06ee, 0x18002704,   // ceb.es.af_222 bh.hi.mr_222  de.ceb.nl_422 gd.ga.un_320
  0x4a03680e, 0x191f0b0c, 0x170a11ad, 0x4a006804,   // ig.nl.yo_555 es.cy.gl_543  ro.mk.sr_643 ig.yo.un_320
  0x281c1ea4, 0x2a000214, 0x03004a08, 0x28215204,   // ms.id.sw_433 da.mt.un_660  yo.nl.un_430 ha.jw.sw_332
  // [19a0]
  0x68015307, 0x091c130c, 0x6400550e, 0x1c1b1e08,   // ht.en.ig_432 bh.mr.hi_543  rw.lg.un_550 ms.tr.id_443
  0x0d292d12, 0x52286eee, 0x092d1007, 0x04070805,   // sk.sl.cs_654 hmn.sw.ha_422  lt.sk.pl_432 uk.bg.ru_333
  0x07000413, 0x191f2308, 0x18000519, 0x4a006814,   // fi.it.un_650 ca.cy.gl_443  fr.ga.un_750 ig.yo.un_660
  0x10080c04, 0x08070c09, 0x0a1107af, 0x09292507,   // sv.no.lt_332 sv.it.no_444  bg.ro.mk_655 eu.sl.pl_432
  // [19b0]
  0x1e1c01a4, 0x18000a04, 0x1b0e25ad, 0x1a003b07,   // en.id.ms_433 pt.ga.un_320  eu.is.tr_643 so.tl.un_420
  0x1a006e1a, 0x3b00101b, 0x1227070d, 0x2b076b07,   // hmn.tl.un_760 lt.so.un_770  it.gd.hu_554 ceb.it.vi_432
  0x04101107, 0x00000a2d, 0x29171602, 0x04081008,   // ro.be.ru_432 pt.un.un_A00  hr.sr.sl_222 be.uk.ru_443
  0x3b00530e, 0x190a0baf, 0x3b641f0d, 0x13190b0c,   // ht.so.un_550 es.pt.gl_655  cy.lg.so_554 es.gl.et_543
  // [19c0]
  0x524a3b07, 0x3f1c1aa0, 0x23000719, 0x0f2a3b08,   // so.yo.ha_432 tl.id.af_322  it.ca.un_750 so.mt.lv_443
  0x09531f04, 0x3b00010c, 0x050a0107, 0x6e1f1a12,   // cy.ht.pl_332 en.so.un_530  en.pt.fr_432 tl.cy.hmn_654
  0x0a001e05, 0x1f1807ec, 0x13003204, 0x0c3510a4,   // ms.pt.un_330 it.ga.cy_644  bs.et.un_320 lt.zu.sv_433
  0x0c003202, 0x2d100aee, 0x182d6e02, 0x07052a07,   // bs.sv.un_220 pt.lt.sk_422  hmn.sk.ga_222 mt.fr.it_432
  // [19d0]
  0x1b1231ec, 0x0d001704, 0x02001307, 0x1e100a07,   // az.hu.tr_644 sr.cs.un_320  et.da.un_420 pt.lt.ms_432
  0x061b31af, 0x17090d07, 0x0e4a19a9, 0x311b3b13,   // az.tr.de_655 cs.pl.sr_432  gl.yo.is_544 so.tr.az_665
  0x1b002102, 0x18013bad, 0x35000705, 0x253b1f0c,   // jw.tr.un_220 so.en.ga_643  it.zu.un_330 cy.so.eu_543
  0x040a075a, 0x2d2a0d0c, 0x12311ba4, 0x12002902,   // bg.mk.ru_553 cs.mt.sk_543  tr.az.hu_433 sl.hu.un_220
  // [19e0]
  0x071004ec, 0x6b681204, 0x3f2a07a0, 0x04000d0d,   // ru.be.bg_644 hu.ig.ceb_332  it.mt.af_322 cs.fi.un_540
  0x2d000c0c, 0x310f1ba9, 0x0a00172a, 0x1c1e12ad,   // sv.sk.un_530 tr.lv.az_544  sr.mk.un_970 hu.ms.id_643
  0x09132aa4, 0x2a1f6eec, 0x3b002a12, 0x0d001c09,   // mt.et.pl_433 hmn.cy.mt_644  mt.so.un_640 mr.ne.un_440
  0x0f180a04, 0x1800210e, 0x3b005304, 0x232a01a4,   // pt.ga.lv_332 fa.ar.un_550  ht.so.un_320 en.mt.ca_433
  // [19f0]
  0x04000c19, 0x090d13a7, 0x01533b0c, 0x1e1c0ea4,   // sv.fi.un_750 bh.ne.hi_532  so.ht.en_543 is.id.ms_433
  0x4a255311, 0x122a53a9, 0x0a100707, 0x21001223,   // ht.eu.yo_653 ht.mt.hu_544  bg.be.mk_432 ur.fa.un_880
  0x070a1760, 0x080a0414, 0x13080208, 0x11001e02,   // sr.mk.bg_664 ru.mk.uk_666  da.no.et_443 ms.ro.un_220
  0x110a0714, 0x0a2301a4, 0x100711a0, 0x2000100e,   // bg.mk.ro_666 en.ca.pt_433  ro.bg.be_322 lt.sq.un_550
  // [1a00]
  0x1b123105, 0x23002508, 0x1b123104, 0x04081713,   // az.hu.tr_333 eu.ca.un_430  az.hu.tr_332 sr.uk.ru_665
  0x041020ad, 0x21121814, 0x20321b0e, 0x07041104,   // sq.lt.fi_643 ar.ur.fa_666  tr.bs.sq_555 ro.ru.bg_332
  0x2b005305, 0x03171604, 0x090d13ac, 0x07040a55,   // ht.vi.un_330 hr.sr.nl_332  bh.ne.hi_632 mk.ru.bg_442
  0x05002504, 0x4a001819, 0x643555ee, 0x1b005322,   // eu.fr.un_320 ga.yo.un_750  rw.zu.lg_422 ht.tr.un_870
  // [1a10]
  0x252a0708, 0x04101707, 0x533b280b, 0x106b1aa4,   // it.mt.eu_443 sr.be.ru_432  sw.so.ht_542 tl.ceb.lt_433
  0x52002704, 0x2400012a, 0x211218ac, 0x030f0911,   // gd.ha.un_320 iw.yi.un_970  ar.ur.fa_632 pl.lv.nl_653
  0x100417a4, 0x0f002b0c, 0x00006406, 0x0f000923,   // sr.ru.be_433 vi.lv.un_530  lg.un.un_400 pl.lv.un_880
  0x02000c09, 0x1b006419, 0x200f10a4, 0x17070a12,   // sv.da.un_440 lg.tr.un_750  lt.lv.sq_433 mk.bg.sr_654
  // [1a20]
  0x10070a07, 0x08001702, 0x090d13a9, 0x09000f1a,   // mk.bg.be_432 sr.uk.un_220  bh.ne.hi_544 lv.pl.un_760
  0x043119ee, 0x00000503, 0x0f000c04, 0x1f000c04,   // gl.az.fi_422 fr.un.un_300  sv.lv.un_320 sv.cy.un_320
  0x0f000914, 0x0c083fa4, 0x29000704, 0x64003b1a,   // pl.lv.un_660 af.no.sv_433  it.sl.un_320 so.lg.un_760
  0x27001812, 0x1218210e, 0x2b2d10ee, 0x1800271b,   // ga.gd.un_640 fa.ar.ur_555  lt.sk.vi_422 gd.ga.un_770
  // [1a30]
  0x211310a0, 0x520131ee, 0x1a003204, 0x111c2804,   // lt.et.jw_322 az.en.ha_422  bs.tl.un_320 sw.id.ro_332
  0x01002704, 0x0f002d1a, 0x3100101a, 0x080c1ca0,   // gd.en.un_320 sk.lv.un_760  lt.az.un_760 id.sv.no_322
  0x11040814, 0x0a4a1fad, 0x6b255307, 0x0717110c,   // uk.ru.ro_666 cy.yo.pt_643  ht.eu.ceb_432 ro.sr.bg_543
  0x291632a7, 0x071710ad, 0x18002119, 0x0a001919,   // bs.hr.sl_532 be.sr.bg_643  fa.ar.un_750 gl.pt.un_750
  // [1a40]
  0x1c3b6407, 0x0c041211, 0x0d0913a4, 0x18002114,   // lg.so.id_432 hu.fi.sv_653  bh.hi.ne_433 fa.ar.un_660
  0x3b1f0c02, 0x3f2a010c, 0x04000618, 0x3f080205,   // sv.cy.so_222 en.mt.af_543  de.fi.un_740 da.no.af_333
  0x1b043204, 0x0c001213, 0x060e1304, 0x521e1b07,   // bs.fi.tr_332 hu.sv.un_650  et.is.de_332 tr.ms.ha_432
  0x0e001b21, 0x1c090da9, 0x07000a09, 0x02005307,   // tr.is.un_860 ne.hi.mr_544  mk.bg.un_440 ht.da.un_420
  // [1a50]
  0x12002a0c, 0x0a001002, 0x29130407, 0x04060c0d,   // mt.hu.un_530 be.mk.un_220  fi.et.sl_432 sv.de.fi_554
  0x29005304, 0x061e1c0d, 0x111f0e0c, 0x04000c0d,   // ht.sl.un_320 id.ms.de_554  is.cy.ro_543 sv.fi.un_540
  0x072a1f0b, 0x2a1119a4, 0x042a0708, 0x19311ba4,   // cy.mt.it_542 gl.ro.mt_433  it.mt.fi_443 tr.az.gl_433
  0x29000e12, 0x1b0221ee, 0x25131fee, 0x16103bee,   // is.sl.un_640 jw.da.tr_422  cy.et.eu_422 so.lt.hr_422
  // [1a60]
  0x0b002d08, 0x0e001f08, 0x04120c0c, 0x2112180e,   // sk.es.un_430 cy.is.un_430  sv.hu.fi_543 ar.ur.fa_555
  0x182d0d02, 0x080b1ea0, 0x1a28520c, 0x2a0413a4,   // cs.sk.ga_222 ms.es.no_322  ha.sw.tl_543 et.fi.mt_433
  0x6b1e1a0d, 0x0f000307, 0x00002437, 0x2a080c07,   // tl.ms.ceb_554 nl.lv.un_420  yi.un.un_B00 sv.no.mt_432
  0x0435520b, 0x081707a0, 0x1e001c22, 0x08311b55,   // ha.zu.fi_542 bg.sr.uk_322  id.ms.un_870 tr.az.no_442
  // [1a70]
  0x06003f0c, 0x52282104, 0x0735550c, 0x10040860,   // af.de.un_530 jw.sw.ha_332  rw.zu.it_543 uk.ru.be_664
  0x25000923, 0x556406ec, 0x1a6b01af, 0x6b3128ad,   // pl.eu.un_880 de.lg.rw_644  en.ceb.tl_655 sw.az.ceb_643
  0x080c1214, 0x12110505, 0x646b1a5a, 0x3b005207,   // hu.sv.no_666 fr.ro.hu_333  tl.ceb.lg_553 ha.so.un_420
  0x20003b1b, 0x28002909, 0x02001a05, 0x55521aa9,   // so.sq.un_770 sl.sw.un_440  tl.da.un_330 tl.ha.rw_544
  // [1a80]
  0x5228255a, 0x3b00210e, 0x521b2509, 0x3b001e04,   // eu.sw.ha_553 jw.so.un_550  eu.tr.ha_444 ms.so.un_320
  0x112d0d08, 0x23190a11, 0x350a64a4, 0x0e005209,   // cs.sk.ro_443 pt.gl.ca_653  lg.pt.zu_433 ha.is.un_440
  0x17080aa0, 0x271e1c0d, 0x0925120e, 0x10080a07,   // mk.uk.sr_322 id.ms.gd_554  hu.eu.pl_555 mk.uk.be_432
  0x0800102b, 0x2100520e, 0x645507a9, 0x1300090c,   // be.uk.un_980 ha.jw.un_550  it.rw.lg_544 hi.bh.un_530
  // [1a90]
  0x06080e0c, 0x00002001, 0x12001114, 0x20295307,   // is.no.de_543 sq.un.un_200  ro.hu.un_660 ht.sl.sq_432
  0x682852a4, 0x28524a12, 0x1b043ba4, 0x08041013,   // ha.sw.ig_433 yo.ha.sw_654  so.fi.tr_433 be.ru.uk_665
  0x05004a07, 0x2952350d, 0x1a211c0b, 0x033f05af,   // yo.fr.un_420 zu.ha.sl_554  id.jw.tl_542 fr.af.nl_655
  0x09211aee, 0x1c002704, 0x0a131908, 0x53192304,   // tl.jw.pl_422 gd.id.un_320  gl.et.pt_443 ca.gl.ht_332
  // [1aa0]
  0x201f0e05, 0x1000350c, 0x0e1b0413, 0x3b5228af,   // is.cy.sq_333 zu.lt.un_530  fi.tr.is_665 sw.ha.so_655
  0x03051f0e, 0x2a033ba9, 0x201b09a9, 0x211b1c08,   // cy.fr.nl_555 so.nl.mt_544  pl.tr.sq_544 id.tr.jw_443
  0x042916a0, 0x53003f21, 0x321617a6, 0x0e131baf,   // hr.sl.fi_322 af.ht.un_860  sr.hr.bs_521 tr.et.is_655
  0x0e00351a, 0x1f002704, 0x3f3b03a4, 0x06640811,   // zu.is.un_760 gd.cy.un_320  nl.so.af_433 no.lg.de_653
  // [1ab0]
  0x1f006b02, 0x06120eaf, 0x4a2b1c08, 0x013f050c,   // ceb.cy.un_220 is.hu.de_655  id.vi.yo_443 fr.af.en_543
  0x070f1312, 0x06000112, 0x10000708, 0x32163bee,   // et.lv.it_654 en.de.un_640  bg.be.un_430 so.hr.bs_422
  0x3f0306af, 0x0c09100e, 0x0f000e19, 0x0000210a,   // de.nl.af_655 lt.pl.sv_555  is.lv.un_750 jw.un.un_500
  0x1b0f2955, 0x530d190c, 0x1b1f0612, 0x1a215309,   // sl.lv.tr_442 gl.cs.ht_543  de.cy.tr_654 ht.jw.tl_444
  // [1ac0]
  0x062d0d5a, 0x5300210c, 0x0f2d0e05, 0x640e07ec,   // cs.sk.de_553 jw.ht.un_530  is.sk.lv_333 it.is.lg_644
  0x16095304, 0x230b010c, 0x170408a9, 0x20002a04,   // ht.pl.hr_332 en.es.ca_543  uk.ru.sr_544 mt.sq.un_320
  0x0a1711a7, 0x04110704, 0x35285508, 0x5209640c,   // ro.sr.mk_532 bg.ro.ru_332  rw.sw.zu_443 lg.pl.ha_543
  0x53000909, 0x1a006b0e, 0x05531904, 0x0a040760,   // pl.ht.un_440 ceb.tl.un_550  gl.ht.fr_332 bg.ru.mk_664
  // [1ad0]
  0x010507a0, 0x0618520c, 0x233f0507, 0x08170a05,   // it.fr.en_322 ha.ga.de_543  fr.af.ca_432 mk.sr.uk_333
  0x6e285512, 0x05045307, 0x323555a4, 0x1c0d09a0,   // rw.sw.hmn_654 ht.fi.fr_432  rw.zu.bs_433 hi.ne.mr_322
  0x083f040c, 0x1f002a1a, 0x041711a0, 0x1a6b25a4,   // fi.af.no_543 mt.cy.un_760  ro.sr.ru_322 eu.ceb.tl_433
  0x11170a08, 0x35005514, 0x1e211c0c, 0x10001f13,   // mk.sr.ro_443 rw.zu.un_660  id.jw.ms_543 cy.lt.un_650
  // [1ae0]
  0x6b1b5308, 0x03003f19, 0x08071705, 0x190b4a14,   // ht.tr.ceb_443 af.nl.un_750  sr.bg.uk_333 yo.es.gl_666
  0x31091bec, 0x10000404, 0x17001312, 0x0a0704af,   // tr.pl.az_644 ru.be.un_320  et.sr.un_640 ru.bg.mk_655
  0x0a162804, 0x0c001218, 0x0a071713, 0x0a000721,   // sw.hr.pt_332 hu.sv.un_740  sr.bg.mk_665 bg.mk.un_860
  0x23075555, 0x1004080e, 0x07001805, 0x04002804,   // rw.it.ca_442 uk.ru.be_555  ga.it.un_330 sw.fi.un_320
  // [1af0]
  0x35552812, 0x08001023, 0x04110a13, 0x52642808,   // sw.rw.zu_654 be.uk.un_880  mk.ro.ru_665 sw.lg.ha_443
  0x092d1607, 0x2d4a0e05, 0x0f071007, 0x08020d0c,   // hr.sk.pl_432 is.yo.sk_333  lt.it.lv_432 cs.da.no_543
  0x2d120d12, 0x0c001308, 0x3f000322, 0x132a0755,   // cs.hu.sk_654 et.sv.un_430  nl.af.un_870 it.mt.et_442
  0x2d070d04, 0x04000812, 0x64002822, 0x04000c13,   // cs.it.sk_332 uk.ru.un_640  sw.lg.un_870 sv.fi.un_650
  // [1b00]
  0x01003f07, 0x2d0d6eee, 0x0a0411a0, 0x28005304,   // af.en.un_420 hmn.cs.sk_422  ro.ru.mk_322 ht.sw.un_320
  0x2d045304, 0x190a23ee, 0x0417110c, 0x0a1f23af,   // ht.fi.sk_332 ca.pt.gl_422  ro.sr.ru_543 ca.cy.pt_655
  0x6b235508, 0x551a21a4, 0x23001104, 0x07001a11,   // rw.ca.ceb_443 jw.tl.rw_433  ro.ca.un_320 tl.it.un_630
  0x03005504, 0x0500230c, 0x6400040d, 0x0e001a08,   // rw.nl.un_320 ca.fr.un_530  fi.lg.un_540 tl.is.un_430
  // [1b10]
  0x55001a22, 0x111e1ca0, 0x04130cee, 0x190a230c,   // tl.rw.un_870 id.ms.ro_322  sv.et.fi_422 ca.pt.gl_543
  0x0c000508, 0x2100230c, 0x6b6428ad, 0x1e1c55a9,   // fr.sv.un_430 ca.jw.un_530  sw.lg.ceb_643 rw.id.ms_544
  0x07285505, 0x031c01a4, 0x071e1c02, 0x2d000c0d,   // rw.sw.it_333 en.id.nl_433  id.ms.it_222 sv.sk.un_540
  0x07000421, 0x2b006b04, 0x063101a0, 0x20230a0b,   // fi.it.un_860 ceb.vi.un_320  en.az.de_322 pt.ca.sq_542
  // [1b20]
  0x21270bee, 0x0b6b55a4, 0x11190a13, 0x11001319,   // es.gd.jw_422 rw.ceb.es_433  pt.gl.ro_665 et.ro.un_750
  0x1b201309, 0x64005521, 0x1b351309, 0x0e07640d,   // et.sq.tr_444 rw.lg.un_860  et.zu.tr_444 lg.it.is_554
  0x0a1710ee, 0x252718ad, 0x5228200c, 0x2500110c,   // be.sr.mk_422 ga.gd.eu_643  sq.sw.ha_543 ro.eu.un_530
  0x1200051a, 0x17351355, 0x2800070c, 0x080a1104,   // fr.hu.un_760 et.zu.sr_442  it.sw.un_530 ro.mk.uk_332
  // [1b30]
  0x310106ee, 0x07000d04, 0x23000a14, 0x53010507,   // de.en.az_422 cs.it.un_320  pt.ca.un_660 fr.en.ht_432
  0x526b1aa4, 0x04081105, 0x11030709, 0x32002308,   // tl.ceb.ha_433 ro.uk.ru_333  it.nl.ro_444 ca.bs.un_430
  0x2006010c, 0x0d002d18, 0x080213ec, 0x1f11230c,   // en.de.sq_543 sk.cs.un_740  et.da.no_644 ca.ro.cy_543
  0x070a10a0, 0x110a23ec, 0x281a21a4, 0x213555a6,   // be.mk.bg_322 ca.pt.ro_644  jw.tl.sw_433 rw.zu.jw_521
  // [1b40]
  0x2d0f0dec, 0x3b1f0ca4, 0x1200091b, 0x5500061a,   // cs.lv.sk_644 sv.cy.so_433  pl.hu.un_770 de.rw.un_760
  0x3b003119, 0x522013a9, 0x17002907, 0x312d0d14,   // az.so.un_750 et.sq.ha_544  sl.sr.un_420 cs.sk.az_666
  0x0b00050c, 0x2d0d290e, 0x0f350908, 0x21000c04,   // fr.es.un_530 sl.cs.sk_555  pl.zu.lv_443 sv.jw.un_320
  0x1b6420ec, 0x0a1704a4, 0x292d0d05, 0x0a04070c,   // sq.lg.tr_644 ru.sr.mk_433  cs.sk.sl_333 bg.ru.mk_543
  // [1b50]
  0x02080c5a, 0x1c281ea0, 0x351301a0, 0x21021c07,   // sv.no.da_553 ms.sw.id_322  en.et.zu_322 id.da.jw_432
  0x2b274a0c, 0x25211011, 0x04001108, 0x0c000612,   // yo.gd.vi_543 lt.jw.eu_653  ro.ru.un_430 de.sv.un_640
  0x52116ba7, 0x06020ca4, 0x04100712, 0x2b004a14,   // ceb.ro.ha_532 sv.da.de_433  bg.be.ru_654 yo.vi.un_660
  0x6b101aa0, 0x6b100c07, 0x523b1ea4, 0x172d0da4,   // tl.lt.ceb_322 sv.lt.ceb_432  ms.so.ha_433 cs.sk.sr_433
  // [1b60]
  0x04004a0e, 0x64285255, 0x080411a9, 0x1b190b0c,   // yo.fi.un_550 ha.sw.lg_442  ro.ru.uk_544 es.gl.tr_543
  0x11002819, 0x01000a07, 0x0d005221, 0x2b00270e,   // sw.ro.un_750 pt.en.un_420  ha.cs.un_860 gd.vi.un_550
  0x32236e0c, 0x35010aa6, 0x4a002b21, 0x2d0d1609,   // hmn.ca.bs_543 pt.en.zu_521  vi.yo.un_860 hr.cs.sk_444
  0x05075505, 0x1b00230b, 0x106455ec, 0x170408af,   // rw.it.fr_333 ca.tr.un_520  rw.lg.lt_644 uk.ru.sr_655
  // [1b70]
  0x0a000c05, 0x2d0f17a9, 0x052801a4, 0x0c0864a9,   // sv.pt.un_330 sr.lv.sk_544  en.sw.fr_433 lg.no.sv_544
  0x20283b11, 0x0a080407, 0x05010607, 0x03006804,   // so.sw.sq_653 ru.uk.mk_432  de.en.fr_432 ig.nl.un_320
  0x171011a4, 0x07002a0e, 0x0804105a, 0x02016404,   // ro.be.sr_433 mt.it.un_550  be.ru.uk_553 lg.en.da_332
  0x1e1c2105, 0x01001a02, 0x3b001108, 0x552812a4,   // jw.id.ms_333 tl.en.un_220  ro.so.un_430 hu.sw.rw_433
  // [1b80]
  0x070501a4, 0x3f312008, 0x6411200c, 0x1a6b530c,   // en.fr.it_433 sq.az.af_443  sq.ro.lg_543 ht.ceb.tl_543
  0x07004a0c, 0x351255ad, 0x55002821, 0x35106407,   // yo.it.un_530 rw.hu.zu_643  sw.rw.un_860 lg.lt.zu_432
  0x322d1760, 0x29160da4, 0x10040a08, 0x170a0809,   // sr.sk.bs_664 cs.hr.sl_433  mk.ru.be_443 uk.mk.sr_444
  0x072a11a4, 0x103568ee, 0x1a000d04, 0x27281808,   // ro.mt.it_433 ig.zu.lt_422  cs.tl.un_320 ga.sw.gd_443
  // [1b90]
  0x190b01a4, 0x0d091c12, 0x05060107, 0x0f0a3bee,   // en.es.gl_433 mr.hi.ne_654  en.de.fr_432 so.pt.lv_422
  0x681806ee, 0x6e2028a6, 0x2a110704, 0x55283560,   // de.ga.ig_422 sw.sq.hmn_521  it.ro.mt_332 zu.sw.rw_664
  0x0a00310c, 0x31101b0e, 0x55646808, 0x02000504,   // az.pt.un_530 tr.lt.az_555  ig.lg.rw_443 fr.da.un_320
  0x00001801, 0x1b196bec, 0x64285513, 0x53231c04,   // ga.un.un_200 ceb.gl.tr_644  rw.sw.lg_665 id.ca.ht_332
  // [1ba0]
  0x133b1855, 0x0c1c3f07, 0x556408a0, 0x1a55230c,   // ga.so.et_442 af.id.sv_432  no.lg.rw_322 ca.rw.tl_543
  0x5500351b, 0x061b2507, 0x2a55075a, 0x18000e19,   // zu.rw.un_770 eu.tr.de_432  it.rw.mt_553 is.ga.un_750
  0x0700042b, 0x08110e07, 0x1708070e, 0x3b001813,   // ru.bg.un_980 is.ro.no_432  bg.uk.sr_555 ga.so.un_650
  0x1b001122, 0x13003b08, 0x0d292d04, 0x18002122,   // ro.tr.un_870 so.et.un_430  sk.sl.cs_332 fa.ar.un_870
  // [1bb0]
  0x03083fa9, 0x3b0c1ca0, 0x060c0412, 0x01002422,   // af.no.nl_544 id.sv.so_322  fi.sv.de_654 yi.iw.un_870
  0x112301a9, 0x04254aad, 0x10002013, 0x0a110707,   // en.ca.ro_544 yo.eu.fi_643  sq.lt.un_650 bg.ro.mk_432
  0x033f1e02, 0x16002905, 0x100817a4, 0x0802070c,   // ms.af.nl_222 sl.hr.un_330  sr.uk.be_433 it.da.no_543
  0x326b280c, 0x2d0d295a, 0x09003b05, 0x080411a4,   // sw.ceb.bs_543 sl.cs.sk_553  so.pl.un_330 ro.ru.uk_433
  // [1bc0]
  0x17080707, 0x0c103b12, 0x00001f06, 0x0d092d12,   // bg.uk.sr_432 so.lt.sv_654  cy.un.un_400 sk.pl.cs_654
  0x28041a09, 0x010629a0, 0x041708af, 0x55136ba0,   // tl.fi.sw_444 sl.de.en_322  uk.sr.ru_655 ceb.et.rw_322
  0x0f1011ec, 0x3b1e1c60, 0x55001c02, 0x08070a0c,   // ro.lt.lv_644 id.ms.so_664  id.rw.un_220 mk.bg.uk_543
  0x21005204, 0x0c00530d, 0x2d0d1007, 0x110407af,   // ha.jw.un_320 ht.sv.un_540  lt.cs.sk_432 bg.ru.ro_655
  // [1bd0]
  0x05002802, 0x0c3b130c, 0x1a132804, 0x1a0e1ca4,   // sw.fr.un_220 et.so.sv_543  sw.et.tl_332 id.is.tl_433
  0x20251c07, 0x020306a4, 0x07041013, 0x06000c14,   // id.eu.sq_432 de.nl.da_433  be.ru.bg_665 sv.de.un_660
  0x070408af, 0x03083f05, 0x351f27ad, 0x0d2d4aad,   // uk.ru.bg_655 af.no.nl_333  gd.cy.zu_643 yo.sk.cs_643
  0x04170aaf, 0x07010507, 0x17100a55, 0x3b351a08,   // mk.sr.ru_655 fr.en.it_432  mk.be.sr_442 tl.zu.so_443
  // [1be0]
  0x6b001318, 0x063b1e04, 0x190a03ee, 0x552164af,   // et.ceb.un_740 ms.so.de_332  nl.pt.gl_422 lg.jw.rw_655
  0x070410a0, 0x52002a21, 0x2d0302a4, 0x3200160b,   // be.ru.bg_322 mt.ha.un_860  da.nl.sk_433 hr.bs.un_520
  0x04000e12, 0x0b322807, 0x211c1e07, 0x28171608,   // is.fi.un_640 sw.bs.es_432  ms.id.jw_432 hr.sr.sw_443
  0x25010c0c, 0x066b01a4, 0x2a01250c, 0x25211c07,   // sv.en.eu_543 en.ceb.de_433  eu.en.mt_543 id.jw.eu_432
  // [1bf0]
  0x11013fa0, 0x0f172912, 0x12000e14, 0x13000419,   // af.en.ro_322 sl.sr.lv_654  is.hu.un_660 fi.et.un_750
  0x023b1a0c, 0x17070a05, 0x21001123, 0x3b00680c,   // tl.so.da_543 mk.bg.sr_333  ro.jw.un_880 ig.so.un_530
  0x0e3f0612, 0x09060d14, 0x21003b20, 0x2b3f03ad,   // de.af.is_654 cs.de.pl_666  so.jw.un_850 nl.af.vi_643
  0x02080c11, 0x251a10a4, 0x1000170d, 0x12000d13,   // sv.no.da_653 lt.tl.eu_433  sr.be.un_540 cs.hu.un_650

  // [1c00]
  0x0925350c, 0x20311eee, 0x08000c09, 0x07005204,   // zu.eu.pl_543 ms.az.sq_422  sv.no.un_440 ha.it.un_320
  0x1b002519, 0x23001704, 0x1a210704, 0x04002112,   // eu.tr.un_750 sr.ca.un_320  it.jw.tl_332 jw.fi.un_640
  0x1b003118, 0x2b001e13, 0x04133b0d, 0x10001705,   // az.tr.un_740 ms.vi.un_650  so.et.fi_554 sr.lt.un_330
  0x6b1a180c, 0x25004a04, 0x05190eee, 0x0e0d0aa9,   // ga.tl.ceb_543 yo.eu.un_320  is.gl.fr_422 pt.cs.is_544
  // [1c10]
  0x0b0a13a0, 0x0e0c1c07, 0x062a3b12, 0x0a4a18a9,   // et.pt.es_322 id.sv.is_432  so.mt.de_654 ga.yo.pt_544
  0x06271813, 0x3b001312, 0x4a0e18ec, 0x102d0d08,   // ga.gd.de_665 et.so.un_640  ga.is.yo_644 cs.sk.lt_443
  0x1b001111, 0x64004a07, 0x21351ca4, 0x040b20a7,   // ro.tr.un_630 yo.lg.un_420  id.zu.jw_433 sq.es.fi_532
  0x170a1109, 0x18002b21, 0x2a051faf, 0x2d184a5a,   // ro.mk.sr_444 vi.ga.un_860  cy.fr.mt_655 yo.ga.sk_553
  // [1c20]
  0x07020812, 0x1c000d1b, 0x4a180ead, 0x2a0501ec,   // no.da.it_654 ne.mr.un_770  is.ga.yo_643 en.fr.mt_644
  0x1b002513, 0x4a001822, 0x2b0c10ee, 0x0e1125ad,   // eu.tr.un_650 ga.yo.un_870  lt.sv.vi_422 eu.ro.is_643
  0x0400100b, 0x08250e0c, 0x1f00250c, 0x3f000304,   // be.ru.un_520 is.eu.no_543  eu.cy.un_530 nl.af.un_320
  0x1200181b, 0x4a000e1b, 0x180d4a13, 0x0c00040d,   // ga.hu.un_770 is.yo.un_770  yo.cs.ga_665 fi.sv.un_540
  // [1c30]
  0x2b0e0a08, 0x060810a4, 0x0d002d13, 0x08022aa0,   // pt.is.vi_443 lt.no.de_433  sk.cs.un_650 mt.da.no_322
  0x0a3b11a4, 0x03023513, 0x31522312, 0x0100130d,   // ro.so.pt_433 zu.da.nl_665  ca.ha.az_654 et.en.un_540
  0x03070607, 0x0a1711a9, 0x0f001022, 0x11100408,   // de.it.nl_432 ro.sr.mk_544  lt.lv.un_870 ru.be.ro_443
  0x131201a7, 0x1b105507, 0x2000030d, 0x2d0d10af,   // en.hu.et_532 rw.lt.tr_432  nl.sq.un_540 lt.cs.sk_655
  // [1c40]
  0x53000502, 0x2a00200c, 0x252d0d0d, 0x0900100d,   // fr.ht.un_220 sq.mt.un_530  cs.sk.eu_554 lt.pl.un_540
  0x17000a11, 0x17070aa9, 0x552d01a7, 0x292025ac,   // mk.sr.un_630 mk.bg.sr_544  en.sk.rw_532 eu.sq.sl_632
  0x2d002107, 0x55281008, 0x2d0e0c02, 0x4a0d2d0c,   // jw.sk.un_420 lt.sw.rw_443  sv.is.sk_222 sk.cs.yo_543
  0x09001021, 0x2b001f05, 0x2500641b, 0x01006b05,   // lt.pl.un_860 cy.vi.un_330  lg.eu.un_770 ceb.en.un_330
  // [1c50]
  0x0f1710ad, 0x31002509, 0x2b1801ee, 0x1b002509,   // lt.sr.lv_643 eu.az.un_440  en.ga.vi_422 eu.tr.un_440
  0x5535520c, 0x2d081aa0, 0x07040805, 0x04080aaf,   // ha.zu.rw_543 tl.no.sk_322  uk.ru.bg_333 mk.uk.ru_655
  0x1c090d11, 0x0800022c, 0x102d29ee, 0x120c0213,   // ne.hi.mr_653 da.no.un_990  sl.sk.lt_422 da.sv.hu_665
  0x05013fa0, 0x53002808, 0x04001f02, 0x090d1c0d,   // af.en.fr_322 sw.ht.un_430  cy.fi.un_220 mr.ne.hi_554
  // [1c60]
  0x170a0709, 0x04090b55, 0x0e282a05, 0x030f3fa4,   // bg.mk.sr_444 es.pl.fi_442  mt.sw.is_333 af.lv.nl_433
  0x17040aa4, 0x1a211ca0, 0x08000c2c, 0x0600091b,   // mk.ru.sr_433 id.jw.tl_322  sv.no.un_990 pl.de.un_770
  0x3f2901a4, 0x0e003207, 0x25001907, 0x090f035a,   // en.sl.af_433 bs.is.un_420  gl.eu.un_420 nl.lv.pl_553
  0x17162902, 0x0c0208af, 0x0c3f2a02, 0x1c13095a,   // sl.hr.sr_222 no.da.sv_655  mt.af.sv_222 hi.bh.mr_553
  // [1c70]
  0x0c00040c, 0x012d0d04, 0x55093f12, 0x08005505,   // fi.sv.un_530 cs.sk.en_332  af.pl.rw_654 rw.no.un_330
  0x17070a09, 0x12020ca6, 0x10645308, 0x2d005308,   // mk.bg.sr_444 sv.da.hu_521  ht.lg.lt_443 ht.sk.un_430
  0x04170a09, 0x100711a4, 0x2a060713, 0x09003f07,   // mk.sr.ru_444 ro.bg.be_433  it.de.mt_665 af.pl.un_420
  0x2d102a07, 0x0900201a, 0x3f000908, 0x07000f11,   // mt.lt.sk_432 sq.pl.un_760  pl.af.un_430 lv.it.un_630
  // [1c80]
  0x4a005319, 0x091c21a4, 0x040f2d11, 0x55006419,   // ht.yo.un_750 jw.id.pl_433  sk.lv.fi_653 lg.rw.un_750
  0x09000622, 0x3b00212a, 0x01312aac, 0x09211a12,   // de.pl.un_870 jw.so.un_970  mt.az.en_632 tl.jw.pl_654
  0x1b002a07, 0x3200170e, 0x170708a0, 0x18033fad,   // mt.tr.un_420 sr.bs.un_550  uk.bg.sr_322 af.nl.ga_643
  0x1f2a0e0e, 0x5512640c, 0x1c2a1e04, 0x23121f07,   // is.mt.cy_555 lg.hu.rw_543  ms.mt.id_332 cy.hu.ca_432
  // [1c90]
  0x053f10a0, 0x100223ec, 0x640328ad, 0x130c10a0,   // lt.af.fr_322 ca.da.lt_644  sw.nl.lg_643 lt.sv.et_322
  0x2d004a0e, 0x55080205, 0x010e3fa7, 0x2a11180c,   // yo.sk.un_550 da.no.rw_333  af.is.en_532 ga.ro.mt_543
  0x0c0855a9, 0x0e003f08, 0x0f001707, 0x04070a07,   // rw.no.sv_544 af.is.un_430  sr.lv.un_420 mk.bg.ru_432
  0x10002312, 0x1c0d0905, 0x21000907, 0x05005204,   // ca.lt.un_640 hi.ne.mr_333  pl.jw.un_420 ha.fr.un_320
  // [1ca0]
  0x12032309, 0x133b640d, 0x01005202, 0x1800210d,   // ca.nl.hu_444 lg.so.et_554  ha.en.un_220 fa.ar.un_540
  0x0a1704af, 0x09002702, 0x122318ad, 0x10002012,   // ru.sr.mk_655 gd.pl.un_220  ga.ca.hu_643 sq.lt.un_640
  0x00000e2d, 0x0a001019, 0x55002508, 0x0c08025a,   // is.un.un_A00 lt.pt.un_750  eu.rw.un_430 da.no.sv_553
  0x4a00182b, 0x1c100405, 0x080411ee, 0x10006807,   // ga.yo.un_980 fi.lt.id_333  ro.ru.uk_422 ig.lt.un_420
  // [1cb0]
  0x0000052d, 0x050823a6, 0x03002304, 0x232b4aaf,   // fr.un.un_A00 ca.no.fr_521  ca.nl.un_320 yo.vi.ca_655
  0x1e1c25af, 0x4a211ca9, 0x1200010d, 0x18004a2a,   // eu.id.ms_655 id.jw.yo_544  en.hu.un_540 yo.ga.un_970
  0x111e1cec, 0x01003507, 0x1e3f1ca4, 0x1c21130c,   // id.ms.ro_644 zu.en.un_420  id.af.ms_433 et.jw.id_543
  0x1b311ea0, 0x231e1c07, 0x090d1cee, 0x2a000c12,   // ms.az.tr_322 id.ms.ca_432  mr.ne.hi_422 sv.mt.un_640
  // [1cc0]
  0x1800270b, 0x1b682807, 0x072b6b0d, 0x100a1713,   // gd.ga.un_520 sw.ig.tr_432  ceb.vi.it_554 sr.mk.be_665
  0x12006822, 0x210e4aa0, 0x2d002814, 0x350b5508,   // ig.hu.un_870 yo.is.jw_322  sw.sk.un_660 rw.es.zu_443
  0x521c530c, 0x1b1e1c12, 0x21006b05, 0x28182713,   // ht.id.ha_543 id.ms.tr_654  ceb.jw.un_330 gd.ga.sw_665
  0x18004a21, 0x6429110c, 0x04000c0c, 0x4a0e1812,   // yo.ga.un_860 ro.sl.lg_543  sv.fi.un_530 ga.is.yo_654
  // [1cd0]
  0x080411ad, 0x322d0908, 0x0d4a230d, 0x554a28a4,   // ro.ru.uk_643 pl.sk.bs_443  ca.yo.cs_554 sw.yo.rw_433
  0x55000b04, 0x07000a07, 0x3b1b2a11, 0x030602ee,   // es.rw.un_320 pt.it.un_420  mt.tr.so_653 da.de.nl_422
  0x2000350e, 0x0300060c, 0x100a0507, 0x281c2108,   // zu.sq.un_550 de.nl.un_530  fr.pt.lt_432 jw.id.sw_443
  0x18000921, 0x0f20350c, 0x10001c1a, 0x00001e1c,   // pl.ga.un_860 zu.sq.lv_543  id.lt.un_760 ms.un.un_800
  // [1ce0]
  0x17290fa9, 0x3b002a0b, 0x1100310d, 0x13001f21,   // lv.sl.sr_544 mt.so.un_520  az.ro.un_540 cy.et.un_860
  0x17163211, 0x0e040f0c, 0x523b280d, 0x202a0e0c,   // bs.hr.sr_653 lv.fi.is_543  sw.so.ha_554 is.mt.sq_543
  0x18042712, 0x21005208, 0x53212a0c, 0x0700110e,   // gd.fi.ga_654 ha.jw.un_430  mt.jw.ht_543 ro.bg.un_550
  0x28002022, 0x272111a4, 0x016b11a4, 0x32100f08,   // sq.sw.un_870 ro.jw.gd_433  ro.ceb.en_433 lv.lt.bs_443
  // [1cf0]
  0x1b00680b, 0x070b23a9, 0x04080708, 0x110a0713,   // ig.tr.un_520 ca.es.it_544  bg.uk.ru_443 bg.mk.ro_665
  0x0a070413, 0x170a07ad, 0x100721a4, 0x21091004,   // ru.bg.mk_665 bg.mk.sr_643  jw.it.lt_433 lt.pl.jw_332
  0x170a0714, 0x04001122, 0x0d001c2a, 0x0a0807a9,   // bg.mk.sr_666 ro.fi.un_870  mr.ne.un_970 bg.uk.mk_544
  0x0c000113, 0x080407af, 0x2821640c, 0x230129a9,   // en.sv.un_650 bg.ru.uk_655  lg.jw.sw_543 sl.en.ca_544
  // [1d00]
  0x120e0c08, 0x01000d04, 0x23016b04, 0x07190b09,   // sv.is.hu_443 cs.en.un_320  ceb.en.ca_332 es.gl.it_444
  0x4a2b0e04, 0x35076408, 0x1c0e1ea4, 0x0d004a1b,   // is.vi.yo_332 lg.it.zu_443  ms.is.id_433 yo.cs.un_770
  0x0b184a5a, 0x1e002702, 0x070b0a14, 0x3b073511,   // yo.ga.es_553 gd.ms.un_220  pt.es.it_666 zu.it.so_653
  0x0e1e1c04, 0x18004a35, 0x32091e0b, 0x1600250c,   // id.ms.is_332 yo.ga.un_A90  ms.pl.bs_542 eu.hr.un_530
  // [1d10]
  0x09002909, 0x110e0c0d, 0x1e1c0a05, 0x06020ca0,   // sl.pl.un_440 sv.is.ro_554  pt.id.ms_333 sv.da.de_322
  0x680b520c, 0x3b00521a, 0x19000a1a, 0x1b1f31af,   // ha.es.ig_543 ha.so.un_760  pt.gl.un_760 az.cy.tr_655
  0x2b184aec, 0x09002508, 0x29000d1a, 0x2b184aa7,   // yo.ga.vi_644 eu.pl.un_430  cs.sl.un_760 yo.ga.vi_532
  0x0d002919, 0x08101708, 0x1b3555a4, 0x08000412,   // sl.cs.un_750 sr.be.uk_443  rw.zu.tr_433 ru.uk.un_640
  // [1d20]
  0x0a040712, 0x1c003204, 0x2d684a11, 0x68002813,   // bg.ru.mk_654 bs.id.un_320  yo.ig.sk_653 sw.ig.un_650
  0x040a1002, 0x191064ad, 0x1c002102, 0x07041105,   // be.mk.ru_222 lg.lt.gl_643  jw.id.un_220 ro.ru.bg_333
  0x170410a0, 0x091b530c, 0x1c001314, 0x64125509,   // be.ru.sr_322 ht.tr.pl_543  bh.mr.un_660 rw.hu.lg_444
  0x181a6b12, 0x313b5204, 0x6800252a, 0x31190a60,   // ceb.tl.ga_654 ha.so.az_332  eu.ig.un_970 pt.gl.az_664
  // [1d30]
  0x3f0410a0, 0x1c00210e, 0x23184aad, 0x12106804,   // lt.fi.af_322 jw.id.un_550  yo.ga.ca_643 ig.lt.hu_332
  0x2d0d03a4, 0x1a6b28ee, 0x07531955, 0x6b681ea0,   // nl.cs.sk_433 sw.ceb.tl_422  gl.ht.it_442 ms.ig.ceb_322
  0x070410a4, 0x0c1e1c5a, 0x09002113, 0x0d002b1a,   // be.ru.bg_433 id.ms.sv_553  jw.pl.un_650 vi.cs.un_760
  0x00004a37, 0x2a6b29a0, 0x03006e07, 0x07002707,   // yo.un.un_B00 sl.ceb.mt_322  hmn.nl.un_420 gd.it.un_420
  // [1d40]
  0x196b01ad, 0x0d1c1307, 0x1629680c, 0x64001b18,   // en.ceb.gl_643 bh.mr.ne_432  ig.sl.hr_543 tr.lg.un_740
  0x0a00200e, 0x552864ec, 0x2a0e1008, 0x27002519,   // sq.pt.un_550 lg.sw.rw_644  lt.is.mt_443 eu.gd.un_750
  0x0a001e02, 0x06006812, 0x03000704, 0x2d0d09ec,   // ms.pt.un_220 ig.de.un_640  it.nl.un_320 pl.cs.sk_644
  0x28005514, 0x126b1aa0, 0x23190ba9, 0x0b554a07,   // rw.sw.un_660 tl.ceb.hu_322  es.gl.ca_544 yo.rw.es_432
  // [1d50]
  0x0e3216ad, 0x281c1ea0, 0x1c212855, 0x1a00210c,   // hr.bs.is_643 ms.id.sw_322  sw.jw.id_442 jw.tl.un_530
  0x0e120c07, 0x0b080c05, 0x1b1208a4, 0x2d0c0da4,   // sv.hu.is_432 sv.no.es_333  no.hu.tr_433 cs.sv.sk_433
  0x11121008, 0x04000a1b, 0x0d092d5a, 0x06000c08,   // lt.hu.ro_443 mk.ru.un_770  sk.pl.cs_553 sv.de.un_430
  0x04171107, 0x1f003f0d, 0x04070aad, 0x4a2921a0,   // ro.sr.ru_432 af.cy.un_540  mk.bg.ru_643 jw.sl.yo_322
  // [1d60]
  0x1100550d, 0x0a006e04, 0x52211c55, 0x2d0d2109,   // rw.ro.un_540 hmn.pt.un_320  id.jw.ha_442 jw.cs.sk_444
  0x0a00190d, 0x19110b04, 0x31351baf, 0x070417ee,   // gl.pt.un_540 es.ro.gl_332  tr.zu.az_655 sr.ru.bg_422
  0x10041755, 0x53002a04, 0x09000d12, 0x52101e0c,   // sr.fi.lt_442 mt.ht.un_320  cs.pl.un_640 ms.lt.ha_543
  0x3b3f6ea0, 0x13006e09, 0x20123f04, 0x520f100d,   // hmn.af.so_322 hmn.et.un_440  af.hu.sq_332 lt.lv.ha_554
  // [1d70]
  0x10000f12, 0x1f1b3b07, 0x13201b07, 0x08003f05,   // lv.lt.un_640 so.tr.cy_432  tr.sq.et_432 af.no.un_330
  0x076411a0, 0x100f1ea9, 0x0f00102c, 0x110113a4,   // ro.lg.it_322 ms.lv.lt_544  lt.lv.un_990 et.en.ro_433
  0x2d0d0614, 0x28521ea4, 0x281052a4, 0x0400110e,   // de.cs.sk_666 ms.ha.sw_433  ha.lt.sw_433 ro.ru.un_550
  0x101e1c60, 0x28001e02, 0x11001b1a, 0x19230d04,   // id.ms.lt_664 ms.sw.un_220  tr.ro.un_760 cs.ca.gl_332
  // [1d80]
  0x31000104, 0x520f10ec, 0x0700060b, 0x0f120ca0,   // en.az.un_320 lt.lv.ha_644  de.it.un_520 sv.hu.lv_322
  0x3b311b12, 0x640417a0, 0x1811320c, 0x29122a55,   // tr.az.so_654 sr.fi.lg_322  bs.ro.ga_543 mt.hu.sl_442
  0x00000501, 0x06000a19, 0x1e1c0aa4, 0x3500551a,   // fr.un.un_200 pt.de.un_750  pt.id.ms_433 rw.zu.un_760
  0x08190a55, 0x06136ba0, 0x521012a4, 0x28121ea4,   // pt.gl.no_442 ceb.et.de_322  hu.lt.ha_433 ms.hu.sw_433
  // [1d90]
  0x292d09ad, 0x25006e07, 0x1c1e52ad, 0x120f10ad,   // pl.sk.sl_643 hmn.eu.un_420  ha.ms.id_643 lt.lv.hu_643
  0x25000808, 0x25001222, 0x521008a4, 0x190a010c,   // no.eu.un_430 hu.eu.un_870  no.lt.ha_433 en.pt.gl_543
  0x1000520d, 0x3f000104, 0x091c1355, 0x11202308,   // ha.lt.un_540 en.af.un_320  bh.mr.hi_442 ca.sq.ro_443
  0x18001911, 0x20001012, 0x0b6b1a0d, 0x31001104,   // gl.ga.un_630 lt.sq.un_640  tl.ceb.es_554 ro.az.un_320
  // [1da0]
  0x280335a0, 0x03000619, 0x03070aa0, 0x0c080208,   // zu.nl.sw_322 de.nl.un_750  pt.it.nl_322 da.no.sv_443
  0x170a04a4, 0x10000309, 0x040711a7, 0x13091c14,   // ru.mk.sr_433 nl.lt.un_440  ro.bg.ru_532 mr.hi.bh_666
  0x0b2827ee, 0x18000b05, 0x3b2728ad, 0x0564550e,   // gd.sw.es_422 es.ga.un_330  sw.gd.so_643 rw.lg.fr_555
  0x311b110d, 0x2d0f0913, 0x073f03a4, 0x120c2a11,   // ro.tr.az_554 pl.lv.sk_665  nl.af.it_433 mt.sv.hu_653
  // [1db0]
  0x0a101709, 0x03122a07, 0x272a1112, 0x4a0252a0,   // sr.be.mk_444 mt.hu.nl_432  ro.mt.gd_654 ha.da.yo_322
  0x1c1309ad, 0x1c285207, 0x06020c09, 0x18190b02,   // hi.bh.mr_643 ha.sw.id_432  sv.da.de_444 es.gl.ga_222
  0x0723190d, 0x531811ee, 0x070a110c, 0x1f0518a7,   // gl.ca.it_554 ro.ga.ht_422  ro.mk.bg_543 ga.fr.cy_532
  0x04000809, 0x1f0518ec, 0x68005519, 0x3f001e02,   // uk.ru.un_440 ga.fr.cy_644  rw.ig.un_750 ms.af.un_220
  // [1dc0]
  0x283b52af, 0x2d321602, 0x08530eee, 0x28050aee,   // ha.so.sw_655 hr.bs.sk_222  is.ht.no_422 pt.fr.sw_422
  0x07000814, 0x0e2d0d60, 0x05041fa0, 0x350e280e,   // uk.bg.un_660 cs.sk.is_664  cy.fi.fr_322 sw.is.zu_555
  0x030625ad, 0x041c4a04, 0x1e3b2807, 0x1b3f6ba0,   // eu.de.nl_643 yo.id.fi_332  sw.so.ms_432 ceb.af.tr_322
  0x0f095255, 0x18270513, 0x093b130c, 0x07294a04,   // ha.pl.lv_442 fr.gd.ga_665  et.so.pl_543 yo.sl.it_332
  // [1dd0]
  0x522705a9, 0x3b524aee, 0x121821af, 0x2827180b,   // fr.gd.ha_544 yo.ha.so_422  fa.ar.ur_655 ga.gd.sw_542
  0x521b530c, 0x1700110e, 0x1a2125a0, 0x123f0309,   // ht.tr.ha_543 ro.sr.un_550  eu.jw.tl_322 nl.af.hu_444
  0x53000507, 0x180527ad, 0x1e001c36, 0x35001913,   // fr.ht.un_420 gd.fr.ga_643  id.ms.un_AA0 gl.zu.un_650
  0x1e1c0fa4, 0x0c2b1ca7, 0x1800051a, 0x1e1c310c,   // lv.id.ms_433 id.vi.sv_532  fr.ga.un_760 az.id.ms_543
  // [1de0]
  0x0f000804, 0x1b3b1f13, 0x052d0d13, 0x2327180c,   // no.lv.un_320 cy.so.tr_665  cs.sk.fr_665 ga.gd.ca_543
  0x03003f36, 0x17311bad, 0x080206a0, 0x212d0d0e,   // af.nl.un_AA0 tr.az.sr_643  de.da.no_322 cs.sk.jw_555
  0x1b532d07, 0x0300050d, 0x0000032d, 0x09020c07,   // sk.ht.tr_432 fr.nl.un_540  nl.un.un_A00 sv.da.pl_432
  0x05001823, 0x0d002d21, 0x103f1aa0, 0x1e1c050c,   // ga.fr.un_880 sk.cs.un_860  tl.af.lt_322 fr.id.ms_543
  // [1df0]
  0x1b1a530c, 0x19005504, 0x120427a4, 0x07000a13,   // ht.tl.tr_543 rw.gl.un_320  gd.fi.hu_433 mk.bg.un_650
  0x1a316ea4, 0x2d0d3b0d, 0x312b0aa0, 0x12080207,   // hmn.az.tl_433 so.cs.sk_554  pt.vi.az_322 da.no.hu_432
  0x20033f07, 0x1c2a2104, 0x24000133, 0x022a0bee,   // af.nl.sq_432 jw.mt.id_332  iw.yi.un_A70 es.mt.da_422
  0x3b061012, 0x3200210c, 0x052d0d11, 0x17006e04,   // lt.de.so_654 jw.bs.un_530  cs.sk.fr_653 hmn.sr.un_320
  // [1e00]
  0x4a005204, 0x0800020d, 0x211e1ca7, 0x10003202,   // ha.yo.un_320 da.no.un_540  id.ms.jw_532 bs.lt.un_220
  0x19211f08, 0x0f1613a7, 0x090f10a4, 0x6b1c11ee,   // cy.jw.gl_443 et.hr.lv_532  lt.lv.pl_433 ro.id.ceb_422
  0x32001209, 0x12001819, 0x1a001c07, 0x0a071705,   // hu.bs.un_440 ar.ur.un_750  id.tl.un_420 sr.bg.mk_333
  0x171668ee, 0x1e1c2702, 0x0d0802a0, 0x3216290c,   // ig.hr.sr_422 gd.id.ms_222  da.no.cs_322 sl.hr.bs_543
  // [1e10]
  0x09002914, 0x093f030c, 0x03003f05, 0x3f523205,   // sl.pl.un_660 nl.af.pl_543  af.nl.un_330 bs.ha.af_333
  0x27001807, 0x0a040807, 0x07170a09, 0x0a070808,   // ga.gd.un_420 uk.ru.mk_432  mk.sr.bg_444 uk.bg.mk_443
  0x12000e12, 0x3f1101a4, 0x21100ca4, 0x0a070805,   // is.hu.un_640 en.ro.af_433  sv.lt.jw_433 uk.bg.mk_333
  0x1b1e1c04, 0x03063508, 0x0e0b19a7, 0x2400010e,   // id.ms.tr_332 zu.de.nl_443  gl.es.is_532 iw.yi.un_550
  // [1e20]
  0x17002d12, 0x1f1a6ba4, 0x1b2008a0, 0x19110bec,   // sk.sr.un_640 ceb.tl.cy_433  no.sq.tr_322 es.ro.gl_644
  0x0f2d0912, 0x041711a4, 0x6b190b04, 0x02120455,   // pl.sk.lv_654 ro.sr.ru_433  es.gl.ceb_332 fi.hu.da_442
  0x520e10ee, 0x2d002918, 0x1812210e, 0x026408ac,   // lt.is.ha_422 sl.sk.un_740  fa.ur.ar_555 no.lg.da_632
  0x3518270c, 0x27005302, 0x0e1918a7, 0x04001018,   // gd.ga.zu_543 ht.gd.un_220  ga.gl.is_532 be.ru.un_740
  // [1e30]
  0x03132904, 0x190a0b05, 0x192302a4, 0x350152ee,   // sl.et.nl_332 es.pt.gl_333  da.ca.gl_433 ha.en.zu_422
  0x21002304, 0x0f1710a9, 0x09080213, 0x23000713,   // ca.jw.un_320 lt.sr.lv_544  da.no.pl_665 it.ca.un_650
  0x1f002705, 0x2804130d, 0x23190ba4, 0x3b000423,   // gd.cy.un_330 et.fi.sw_554  es.gl.ca_433 fi.so.un_880
  0x13090dad, 0x2b012aee, 0x0b0a18ec, 0x6b043ba9,   // ne.hi.bh_643 mt.en.vi_422  ga.pt.es_644 so.fi.ceb_544
  // [1e40]
  0x25030608, 0x281b1ea0, 0x1000040c, 0x03090d12,   // de.nl.eu_443 ms.tr.sw_322  ru.be.un_530 cs.pl.nl_654
  0x1800211b, 0x3b280412, 0x061209ad, 0x070410a9,   // fa.ar.un_770 fi.sw.so_654  pl.hu.de_643 be.ru.bg_544
  0x0f280412, 0x18190ba7, 0x10080408, 0x1c090da7,   // fi.sw.lv_654 es.gl.ga_532  ru.uk.be_443 ne.hi.mr_532
  0x02006407, 0x4a002821, 0x0a070408, 0x192d0d13,   // lg.da.un_420 sw.yo.un_860  ru.bg.mk_443 cs.sk.gl_665
  // [1e50]
  0x52003b05, 0x0d002d0d, 0x04100f12, 0x1104100c,   // so.ha.un_330 sk.cs.un_540  lv.lt.fi_654 be.ru.ro_543
  0x0a190ba7, 0x4a683b0c, 0x09000619, 0x1f190b0e,   // es.gl.pt_532 so.ig.yo_543  de.pl.un_750 es.gl.cy_555
  0x04071107, 0x03001f04, 0x1c00250d, 0x10213b04,   // ro.bg.ru_432 cy.nl.un_320  eu.id.un_540 so.jw.lt_332
  0x12002112, 0x1800122a, 0x12000c0d, 0x02001f02,   // fa.ur.un_640 ur.ar.un_970  sv.hu.un_540 cy.da.un_220
  // [1e60]
  0x211b5302, 0x0a0128a7, 0x033f21a0, 0x0c00022a,   // ht.tr.jw_222 sw.en.pt_532  jw.af.nl_322 da.sv.un_970
  0x28000421, 0x4a3b6808, 0x0a001814, 0x0d17160e,   // fi.sw.un_860 ig.so.yo_443  ga.pt.un_660 hr.sr.cs_555
  0x283b040d, 0x11002b11, 0x0b00180e, 0x04003b22,   // fi.so.sw_554 vi.ro.un_630  ga.es.un_550 so.fi.un_870
  0x20532513, 0x18190ba0, 0x3b006809, 0x2b182812,   // eu.ht.sq_665 es.gl.ga_322  ig.so.un_440 sw.ga.vi_654
  // [1e70]
  0x04004a22, 0x521e3ba4, 0x08070a08, 0x281827ec,   // yo.fi.un_870 so.ms.ha_433  mk.bg.uk_443 gd.ga.sw_644
  0x2b271811, 0x2a000707, 0x2a1f2b04, 0x20311ba7,   // ga.gd.vi_653 it.mt.un_420  vi.cy.mt_332 tr.az.sq_532
  0x00000106, 0x355528ad, 0x1800170c, 0x21181260,   // en.un.un_400 sw.rw.zu_643  sr.ga.un_530 ur.ar.fa_664
  0x1c311ead, 0x03045304, 0x17081055, 0x07010602,   // ms.az.id_643 ht.fi.nl_332  be.uk.sr_442 de.en.it_222
  // [1e80]
  0x640e1b0c, 0x17080409, 0x111e6b0c, 0x1b3564ec,   // tr.is.lg_543 ru.uk.sr_444  ceb.ms.ro_543 lg.zu.tr_644
  0x28522a12, 0x2b001907, 0x25190ba9, 0x161328a9,   // mt.ha.sw_654 gl.vi.un_420  es.gl.eu_544 sw.et.hr_544
  0x020c0813, 0x040e2aa4, 0x321752ec, 0x09006412,   // no.sv.da_665 mt.is.fi_433  ha.sr.bs_644 lg.pl.un_640
  0x0c000e2b, 0x0e1a52af, 0x20210755, 0x070b110c,   // is.sv.un_980 ha.tl.is_655  it.jw.sq_442 ro.es.it_543
  // [1e90]
  0x27001836, 0x06005513, 0x211e1c14, 0x063f03a0,   // ga.gd.un_AA0 rw.de.un_650  id.ms.jw_666 nl.af.de_322
  0x68005522, 0x0800200e, 0x0c1308a0, 0x6b680bee,   // rw.ig.un_870 sq.no.un_550  no.et.sv_322 es.ig.ceb_422
  0x6b005208, 0x1b3111a9, 0x08043f05, 0x074a68ad,   // ha.ceb.un_430 ro.az.tr_544  af.fi.no_333 ig.yo.it_643
  0x11101805, 0x641207a7, 0x1f18270d, 0x55000b02,   // ga.lt.ro_333 it.hu.lg_532  gd.ga.cy_554 es.rw.un_220
  // [1ea0]
  0x050701a4, 0x2128680c, 0x205232a0, 0x08020c12,   // en.it.fr_433 ig.sw.jw_543  bs.ha.sq_322 sv.da.no_654
  0x282a27ee, 0x06202307, 0x4a556812, 0x11002521,   // gd.mt.sw_422 ca.sq.de_432  ig.rw.yo_654 eu.ro.un_860
  0x1f311e12, 0x04001319, 0x07001908, 0x1e1c6b02,   // ms.az.cy_654 et.fi.un_750  gl.it.un_430 ceb.id.ms_222
  0x31283b07, 0x030e3f07, 0x0f001f07, 0x28133b55,   // so.sw.az_432 af.is.nl_432  cy.lv.un_420 so.et.sw_442
  // [1eb0]
  0x03060808, 0x200e1f11, 0x3f130308, 0x0e521aa9,   // no.de.nl_443 cy.is.sq_653  nl.et.af_443 tl.ha.is_544
  0x020c08ec, 0x170407a9, 0x13033fa4, 0x5528350c,   // no.sv.da_644 bg.ru.sr_544  af.nl.et_433 zu.sw.rw_543
  0x1e1c250c, 0x12002919, 0x21001a1b, 0x022d0e12,   // eu.id.ms_543 sl.hu.un_750  tl.jw.un_770 is.sk.da_654
  0x04033b04, 0x0c00091a, 0x214a68ad, 0x3b033f55,   // so.nl.fi_332 pl.sv.un_760  ig.yo.jw_643 af.nl.so_442
  // [1ec0]
  0x050a2802, 0x04133b07, 0x4a113f0c, 0x131f2704,   // sw.pt.fr_222 so.et.fi_432  af.ro.yo_543 gd.cy.et_332
  0x28004a08, 0x082a0107, 0x68023b08, 0x28005508,   // yo.sw.un_430 en.mt.no_432  so.da.ig_443 rw.sw.un_430
  0x0a041305, 0x18001219, 0x3f2b1cee, 0x17001304,   // et.fi.pt_333 ur.ar.un_750  id.vi.af_422 et.sr.un_320
  0x033f3baf, 0x12001821, 0x0e126407, 0x190a0505,   // so.af.nl_655 ar.ur.un_860  lg.hu.is_432 fr.pt.gl_333
  // [1ed0]
  0x6455350d, 0x2a212805, 0x122a6407, 0x09000707,   // zu.rw.lg_554 sw.jw.mt_333  lg.mt.hu_432 it.pl.un_420
  0x190a25a9, 0x04170705, 0x05002307, 0x0c0501a4,   // eu.pt.gl_544 bg.sr.ru_333  ca.fr.un_420 en.fr.sv_433
  0x2a1b5208, 0x2b533b05, 0x35645512, 0x530d2d11,   // ha.tr.mt_443 so.ht.vi_333  rw.lg.zu_654 sk.cs.ht_653
  0x08100413, 0x52122aa7, 0x170a10ee, 0x4a001321,   // ru.be.uk_665 mt.hu.ha_532  be.mk.sr_422 et.yo.un_860
  // [1ee0]
  0x04033f09, 0x190f0bec, 0x036813a4, 0x17231fad,   // af.nl.fi_444 es.lv.gl_644  et.ig.nl_433 cy.ca.sr_643
  0x081017a4, 0x3f033b08, 0x64522a60, 0x04133bec,   // sr.be.uk_433 so.nl.af_443  mt.ha.lg_664 so.et.fi_644
  0x23190b05, 0x641201a4, 0x1c211e04, 0x070116a0,   // es.gl.ca_333 en.hu.lg_433  ms.jw.id_332 hr.en.it_322
  0x28002104, 0x29203107, 0x0d000a02, 0x3b64520b,   // jw.sw.un_320 az.sq.sl_432  pt.cs.un_220 ha.lg.so_542
  // [1ef0]
  0x12006414, 0x322d0d55, 0x183f1fad, 0x17005207,   // lg.hu.un_660 cs.sk.bs_442  cy.af.ga_643 ha.sr.un_420
  0x550b18a4, 0x23000509, 0x042835ee, 0x08071012,   // ga.es.rw_433 fr.ca.un_440  zu.sw.fi_422 be.bg.uk_654
  0x022d0d60, 0x180153ee, 0x250328a0, 0x28001705,   // cs.sk.da_664 ht.en.ga_422  sw.nl.eu_322 sr.sw.un_330
  0x64082aad, 0x2a210eee, 0x19230bec, 0x07522aa4,   // mt.no.lg_643 is.jw.mt_422  es.ca.gl_644 mt.ha.it_433
  // [1f00]
  0x0a006408, 0x321655a0, 0x2d170d14, 0x190b6b05,   // lg.pt.un_430 rw.hr.bs_322  cs.sr.sk_666 ceb.es.gl_333
  0x0e001219, 0x291f3ba7, 0x6b685305, 0x292d0d60,   // hu.is.un_750 so.cy.sl_532  ht.ig.ceb_333 cs.sk.sl_664
  0x18092711, 0x55136408, 0x0f321704, 0x063f08a4,   // gd.pl.ga_653 lg.et.rw_443  sr.bs.lv_332 no.af.de_433
  0x25001219, 0x0a07110c, 0x2b002308, 0x02000108,   // hu.eu.un_750 ro.bg.mk_543  ca.vi.un_430 en.da.un_430
  // [1f10]
  0x05000b04, 0x27000912, 0x0e3f0804, 0x0f285255,   // es.fr.un_320 pl.gd.un_640  no.af.is_332 ha.sw.lv_442
  0x29005208, 0x1a6b0c0c, 0x20132807, 0x06050104,   // ha.sl.un_430 sv.ceb.tl_543  sw.et.sq_432 en.fr.de_332
  0x08000718, 0x0a070f04, 0x19050b55, 0x071017ee,   // bg.uk.un_740 lv.it.pt_332  es.fr.gl_442 sr.be.bg_422
  0x0d002d08, 0x1c2128a4, 0x292d1007, 0x2b000b05,   // sk.cs.un_430 sw.jw.id_433  lt.sk.sl_432 es.vi.un_330
  // [1f20]
  0x100a0712, 0x0a000104, 0x12000a14, 0x0a171160,   // bg.mk.be_654 en.pt.un_320  pt.hu.un_660 ro.sr.mk_664
  0x2a203560, 0x01000208, 0x1a002709, 0x07005202,   // zu.sq.mt_664 da.en.un_430  gd.tl.un_440 ha.it.un_220
  0x18190b05, 0x0500110d, 0x2d290d0c, 0x04080711,   // es.gl.ga_333 ro.fr.un_540  cs.sl.sk_543 bg.uk.ru_653
  0x07000813, 0x0964350c, 0x07002712, 0x07040aa0,   // uk.bg.un_650 zu.lg.pl_543  gd.it.un_640 mk.ru.bg_322
  // [1f30]
  0x056b0aa0, 0x18001209, 0x2d001223, 0x18002112,   // pt.ceb.fr_322 ur.ar.un_440  hu.sk.un_880 fa.ar.un_640
  0x17000712, 0x64000119, 0x3b1a6baf, 0x55006409,   // bg.sr.un_640 en.lg.un_750  ceb.tl.so_655 lg.rw.un_440
  0x040817a7, 0x231f3f02, 0x0b2319ec, 0x6b3b01a4,   // sr.uk.ru_532 af.cy.ca_222  gl.ca.es_644 en.so.ceb_433
  0x3b1a6b12, 0x322518ee, 0x322d0da4, 0x092a040c,   // ceb.tl.so_654 ga.eu.bs_422  cs.sk.bs_433 fi.mt.pl_543
  // [1f40]
  0x1a003b35, 0x0f080c55, 0x10002813, 0x04081714,   // so.tl.un_A90 sv.no.lv_442  sw.lt.un_650 sr.uk.ru_666
  0x3f042aa4, 0x1b1e3111, 0x3b000122, 0x27006402,   // mt.fi.af_433 az.ms.tr_653  en.so.un_870 lg.gd.un_220
  0x0c00080e, 0x285201af, 0x07041702, 0x3b531a0d,   // no.sv.un_550 en.ha.sw_655  sr.ru.bg_222 tl.ht.so_554
  0x126b1a02, 0x06000c19, 0x53001a14, 0x2800641a,   // tl.ceb.hu_222 sv.de.un_750  tl.ht.un_660 lg.sw.un_760
  // [1f50]
  0x642835ad, 0x25002721, 0x6b1a3b13, 0x2a3b64a4,   // zu.sw.lg_643 gd.eu.un_860  so.tl.ceb_665 lg.so.mt_433
  0x2118125a, 0x106429ec, 0x0e005512, 0x0b002319,   // ur.ar.fa_553 sl.lg.lt_644  rw.is.un_640 ca.es.un_750
  0x1e004a04, 0x20001b04, 0x05005307, 0x00000906,   // yo.ms.un_320 tr.sq.un_320  ht.fr.un_420 hi.un.un_400
  0x5500290e, 0x1000291a, 0x2d00230d, 0x0c00081b,   // sl.rw.un_550 sl.lt.un_760  ca.sk.un_540 no.sv.un_770
  // [1f60]
  0x016b1a14, 0x31121307, 0x0f530408, 0x6b1a3ba9,   // tl.ceb.en_666 et.hu.az_432  fi.ht.lv_443 so.tl.ceb_544
  0x17080a09, 0x02000835, 0x32002904, 0x0800122c,   // mk.uk.sr_444 no.da.un_A90  sl.bs.un_320 hu.no.un_990
  0x25181b0c, 0x3b000113, 0x1a003b23, 0x531a6ba9,   // tr.ga.eu_543 en.so.un_650  so.tl.un_880 ceb.tl.ht_544
  0x0f2a1012, 0x3f0603a6, 0x1e000607, 0x12530e07,   // lt.mt.lv_654 nl.de.af_521  de.ms.un_420 is.ht.hu_432
  // [1f70]
  0x282110a6, 0x32001e07, 0x2800520e, 0x64005509,   // lt.jw.sw_521 ms.bs.un_420  ha.sw.un_550 rw.lg.un_440
  0x1f3b08ec, 0x3b1204a4, 0x281e52a4, 0x04211c02,   // no.so.cy_644 fi.hu.so_433  ha.ms.sw_433 id.jw.fi_222
  0x08002813, 0x32001708, 0x1f050107, 0x0f191107,   // sw.no.un_650 sr.bs.un_430  en.fr.cy_432 ro.gl.lv_432
  0x52206404, 0x08071709, 0x28171307, 0x020c29a4,   // lg.sq.ha_332 sr.bg.uk_444  et.sr.sw_432 sl.sv.da_433
  // [1f80]
  0x12250da0, 0x524a1aad, 0x270c0ea0, 0x1c5209a4,   // cs.eu.hu_322 tl.yo.ha_643  is.sv.gd_322 pl.ha.id_433
  0x10182aad, 0x23194aee, 0x0e000d1a, 0x033f0c5a,   // mt.ga.lt_643 yo.gl.ca_422  cs.is.un_760 sv.af.nl_553
  0x25190b09, 0x280f1fa4, 0x35006404, 0x06001f21,   // es.gl.eu_444 cy.lv.sw_433  lg.zu.un_320 cy.de.un_860
  0x040a07af, 0x181f2707, 0x3f0e08af, 0x063f0314,   // bg.mk.ru_655 gd.cy.ga_432  no.is.af_655 nl.af.de_666
  // [1f90]
  0x6e001f14, 0x10000707, 0x010825ad, 0x2329120c,   // cy.hmn.un_660 it.lt.un_420  eu.no.en_643 hu.sl.ca_543
  0x0d12040c, 0x1b005202, 0x552035a0, 0x170a070b,   // fi.hu.cs_543 ha.tr.un_220  zu.sq.rw_322 bg.mk.sr_542
  0x3f030eee, 0x2164550c, 0x04122a07, 0x012a1213,   // is.nl.af_422 rw.lg.jw_543  mt.hu.fi_432 hu.mt.en_665
  0x1764520c, 0x060c135a, 0x0a190b5a, 0x12000408,   // ha.lg.sr_543 et.sv.de_553  es.gl.pt_553 fi.hu.un_430
  // [1fa0]
  0x04000a1a, 0x2b00060d, 0x351a6b0b, 0x3b001308,   // mk.ru.un_760 de.vi.un_540  ceb.tl.zu_542 et.so.un_430
  0x35286409, 0x25315204, 0x0d1c135a, 0x1123070c,   // lg.sw.zu_444 ha.az.eu_332  bh.mr.ne_553 it.ca.ro_543
  0x20000612, 0x081a6b0b, 0x041017a4, 0x17005502,   // de.sq.un_640 ceb.tl.no_542  sr.be.ru_433 rw.sr.un_220
  0x101f27ee, 0x3b000c0e, 0x35645504, 0x53000c05,   // gd.cy.lt_422 sv.so.un_550  rw.lg.zu_332 sv.ht.un_330
  // [1fb0]
  0x1b256b05, 0x0a1711af, 0x13005208, 0x28641ea0,   // ceb.eu.tr_333 ro.sr.mk_655  ha.et.un_430 ms.lg.sw_322
  0x2a103b0d, 0x170704a4, 0x644a27ad, 0x3f003b05,   // so.lt.mt_554 ru.bg.sr_433  gd.yo.lg_643 so.af.un_330
  0x534a3ba4, 0x6b1a3b0b, 0x06255507, 0x21005519,   // so.yo.ht_433 so.tl.ceb_542  rw.eu.de_432 rw.jw.un_750
  0x3b002a04, 0x2b3108a0, 0x07100b08, 0x101a5307,   // mt.so.un_320 no.az.vi_322  es.lt.it_443 ht.tl.lt_432
  // [1fc0]
  0x52112a0c, 0x19120707, 0x29080ca9, 0x09001018,   // mt.ro.ha_543 it.hu.gl_432  sv.no.sl_544 lt.pl.un_740
  0x050c2aa4, 0x642a0b08, 0x1a070aa4, 0x08100aa4,   // mt.sv.fr_433 es.mt.lg_443  pt.it.tl_433 mk.be.uk_433
  0x12684aad, 0x551e1c5a, 0x18016ba0, 0x6b2a07ee,   // yo.ig.hu_643 id.ms.rw_553  ceb.en.ga_322 it.mt.ceb_422
  0x6410550c, 0x641a6b05, 0x0f00060d, 0x3b641108,   // rw.lt.lg_543 ceb.tl.lg_333  de.lv.un_540 ro.lg.so_443
  // [1fd0]
  0x01023ba0, 0x06001b12, 0x640c2a0c, 0x190a0ba9,   // so.da.en_322 tr.de.un_640  mt.sv.lg_543 es.pt.gl_544
  0x0a1110ad, 0x12233b07, 0x3f133b07, 0x1f0c0204,   // be.ro.mk_643 so.ca.hu_432  so.et.af_432 da.sv.cy_332
  0x0d002912, 0x07001008, 0x6b010304, 0x0c004a07,   // sl.cs.un_640 lt.it.un_430  nl.en.ceb_332 yo.sv.un_420
  0x102829a4, 0x0e002502, 0x290b07a7, 0x12160d07,   // sl.sw.lt_433 eu.is.un_220  it.es.sl_532 cs.hr.hu_432
  // [1fe0]
  0x190a6402, 0x3f03070c, 0x3b000908, 0x170a10a6,   // lg.pt.gl_222 it.nl.af_543  pl.so.un_430 be.mk.sr_521
  0x17000809, 0x040a11a0, 0x290d2d11, 0x00002506,   // uk.sr.un_440 ro.mk.ru_322  sk.cs.sl_653 eu.un.un_400
  0x07081112, 0x100f1705, 0x250853a9, 0x530d1004,   // ro.uk.bg_654 sr.lv.lt_333  ht.no.eu_544 lt.cs.ht_332
  0x17101108, 0x12290da0, 0x0a001709, 0x0d00180d,   // ro.be.sr_443 cs.sl.hu_322  sr.mk.un_440 ga.cs.un_540
  // [1ff0]
  0x0b072907, 0x096b1f04, 0x1f3b550b, 0x07040808,   // sl.it.es_432 cy.ceb.pl_332  rw.so.cy_542 uk.ru.bg_443
  0x6b000104, 0x2910070c, 0x02001305, 0x07291aa7,   // en.ceb.un_320 it.lt.sl_543  et.da.un_330 tl.sl.it_532
  0x04000819, 0x17101107, 0x0d00020b, 0x35002808,   // uk.ru.un_750 ro.be.sr_432  da.cs.un_520 sw.zu.un_430
  0x28001a04, 0x2b000113, 0x1e1c3509, 0x06002a14,   // tl.sw.un_320 en.vi.un_650  zu.id.ms_444 mt.de.un_660

  // [2000]
  0x1e4a6402, 0x04001121, 0x1f272da4, 0x2100122b,   // lg.yo.ms_222 ro.ru.un_860  sk.gd.cy_433 ur.fa.un_980
  0x0e042a08, 0x122a070c, 0x070a11ad, 0x29002d22,   // mt.fi.is_443 it.mt.hu_543  ro.mk.bg_643 sk.sl.un_870
  0x311b200c, 0x066b1aee, 0x64001219, 0x1a106bad,   // sq.tr.az_543 tl.ceb.de_422  hu.lg.un_750 ceb.lt.tl_643
  0x2a041208, 0x04070a12, 0x10080411, 0x05001a04,   // hu.fi.mt_443 mk.bg.ru_654  ru.uk.be_653 tl.fr.un_320
  // [2010]
  0x55006404, 0x04100814, 0x07000808, 0x28003b09,   // lg.rw.un_320 uk.be.ru_666  no.it.un_430 so.sw.un_440
  0x03073fa0, 0x1200640d, 0x12001b08, 0x11070aaf,   // af.it.nl_322 lg.hu.un_540  tr.hu.un_430 mk.bg.ro_655
  0x190a0bec, 0x13002011, 0x070305a0, 0x2d002909,   // es.pt.gl_644 sq.et.un_630  fr.nl.it_322 sl.sk.un_440
  0x55281ca4, 0x0b002304, 0x3b312a0c, 0x2b001f07,   // id.sw.rw_433 ca.es.un_320  mt.az.so_543 cy.vi.un_420
  // [2020]
  0x25000622, 0x08020112, 0x1a006b09, 0x3f002507,   // de.eu.un_870 en.da.no_654  ceb.tl.un_440 eu.af.un_420
  0x0c000221, 0x04170813, 0x6b1a5214, 0x1b1a6ba4,   // da.sv.un_860 uk.sr.ru_665  ha.tl.ceb_666 ceb.tl.tr_433
  0x321603ec, 0x0c033f55, 0x052a01a0, 0x3f2a0707,   // nl.hr.bs_644 af.nl.sv_442  en.mt.fr_322 it.mt.af_432
  0x2835640e, 0x3f080ca4, 0x2d00291a, 0x251a6b12,   // lg.zu.sw_555 sv.no.af_433  sl.sk.un_760 ceb.tl.eu_654
  // [2030]
  0x321b06ee, 0x0a001112, 0x0e3f4a0c, 0x3b005322,   // de.tr.bs_422 ro.mk.un_640  yo.af.is_543 ht.so.un_870
  0x06006814, 0x060a23a4, 0x0a311b13, 0x0c0e13a0,   // ig.de.un_660 ca.pt.de_433  tr.az.pt_665 et.is.sv_322
  0x09000104, 0x52310c07, 0x04521a04, 0x321116a0,   // en.pl.un_320 sv.az.ha_432  tl.ha.fi_332 hr.ro.bs_322
  0x06080c05, 0x3f042a0c, 0x0752290c, 0x1213040d,   // sv.no.de_333 mt.fi.af_543  sl.ha.it_543 fi.et.hu_554
  // [2040]
  0x10003207, 0x0a170704, 0x11521e0b, 0x0427180c,   // bs.lt.un_420 bg.sr.mk_332  ms.ha.ro_542 ga.gd.fi_543
  0x52002512, 0x2a0f2813, 0x10000f0d, 0x3b0807a9,   // eu.ha.un_640 sw.lv.mt_665  lv.lt.un_540 it.no.so_544
  0x29090dad, 0x55080213, 0x4a2718a4, 0x52002a1a,   // cs.pl.sl_643 da.no.rw_665  ga.gd.yo_433 mt.ha.un_760
  0x08024aee, 0x07001014, 0x6b081005, 0x040313a9,   // yo.da.no_422 be.bg.un_660  lt.no.ceb_333 et.nl.fi_544
  // [2050]
  0x31005204, 0x20001704, 0x12001f05, 0x3f001a02,   // ha.az.un_320 sr.sq.un_320  cy.hu.un_330 tl.af.un_220
  0x060d3f0c, 0x1e181c0c, 0x2a00312a, 0x16006b08,   // af.cs.de_543 id.ga.ms_543  az.mt.un_970 ceb.hr.un_430
  0x193f1f0c, 0x29121604, 0x4a16310c, 0x321607a4,   // cy.af.gl_543 hr.hu.sl_332  az.hr.yo_543 it.hr.bs_433
  0x09520d0b, 0x521807a4, 0x553564af, 0x11231905,   // cs.ha.pl_542 it.ga.ha_433  lg.zu.rw_655 gl.ca.ro_333
  // [2060]
  0x312319a4, 0x1b0f6eee, 0x12114aa4, 0x13001e1a,   // gl.ca.az_433 hmn.lv.tr_422  yo.ro.hu_433 ms.et.un_760
  0x6b1a640c, 0x27251155, 0x051255ad, 0x08230560,   // lg.tl.ceb_543 ro.eu.gd_442  rw.hu.fr_643 fr.ca.no_664
  0x21002505, 0x23122905, 0x55211e08, 0x08033f07,   // eu.jw.un_330 sl.hu.ca_333  ms.jw.rw_443 af.nl.no_432
  0x1f00100d, 0x1a646b12, 0x01000607, 0x0e130608,   // lt.cy.un_540 ceb.lg.tl_654  de.en.un_420 de.et.is_443
  // [2070]
  0x0a04170c, 0x0e002a1a, 0x55001114, 0x05006e34,   // sr.ru.mk_543 mt.is.un_760  ro.rw.un_660 hmn.fr.un_A80
  0x0d0952a0, 0x23060512, 0x05002d04, 0x1709070c,   // ha.pl.cs_322 fr.de.ca_654  sk.fr.un_320 it.pl.sr_543
  0x040e13ec, 0x21001a0d, 0x6e00231a, 0x3f1f0c04,   // et.is.fi_644 tl.jw.un_540  ca.hmn.un_760 sv.cy.af_332
  0x0a0155ee, 0x09072a08, 0x033568a9, 0x2535550c,   // rw.en.pt_422 mt.it.pl_443  ig.zu.nl_544 rw.zu.eu_543
  // [2080]
  0x683b52ec, 0x18276eaf, 0x3f1b050c, 0x2504130c,   // ha.so.ig_644 hmn.gd.ga_655  fr.tr.af_543 et.fi.eu_543
  0x642555ee, 0x4a005205, 0x31206ea7, 0x31536407,   // rw.eu.lg_422 ha.yo.un_330  hmn.sq.az_532 lg.ht.az_432
  0x031b5504, 0x2d0b29a4, 0x3f03190c, 0x53551c0b,   // rw.tr.nl_332 sl.es.sk_433  gl.nl.af_543 id.rw.ht_542
  0x21003f1b, 0x05006e11, 0x6b1a53a4, 0x033f52ee,   // af.jw.un_770 hmn.fr.un_630  ht.tl.ceb_433 ha.af.nl_422
  // [2090]
  0x2a3555ad, 0x03003b08, 0x04071113, 0x13002821,   // rw.zu.mt_643 so.nl.un_430  ro.bg.ru_665 sw.et.un_860
  0x1108170c, 0x3b033fec, 0x3f212aac, 0x52286404,   // sr.uk.ro_543 af.nl.so_644  mt.jw.af_632 lg.sw.ha_332
  0x52065512, 0x521e1fad, 0x1f1e1c12, 0x530c23ee,   // rw.de.ha_654 cy.ms.ha_643  id.ms.cy_654 ca.sv.ht_422
  0x2a002813, 0x08000e0d, 0x2b006e0c, 0x4a182dad,   // sw.mt.un_650 is.no.un_540  hmn.vi.un_530 sk.ga.yo_643
  // [20a0]
  0x130f0602, 0x06101fa9, 0x231301a0, 0x100a1707,   // de.lv.et_222 cy.lt.de_544  en.et.ca_322 sr.mk.be_432
  0x0e080707, 0x550c08a0, 0x06281fad, 0x211c1ea9,   // it.no.is_432 no.sv.rw_322  cy.sw.de_643 ms.id.jw_544
  0x10005208, 0x0717080c, 0x10004a05, 0x08070a0d,   // ha.lt.un_430 uk.sr.bg_543  yo.lt.un_330 mk.bg.uk_554
  0x1e1c10af, 0x07101708, 0x0655520e, 0x00001f2d,   // lt.id.ms_655 sr.be.bg_443  ha.rw.de_555 cy.un.un_A00
  // [20b0]
  0x201b3112, 0x12004a09, 0x23001f1a, 0x08020da4,   // az.tr.sq_654 yo.hu.un_440  cy.ca.un_760 cs.da.no_433
  0x4a6e6ba0, 0x1b162908, 0x23111f13, 0x356420a4,   // ceb.hmn.yo_322 sl.hr.tr_443  cy.ro.ca_665 sq.lg.zu_433
  0x1b315504, 0x06001f1a, 0x3229170b, 0x5564130c,   // rw.az.tr_332 cy.de.un_760  sr.sl.bs_542 et.lg.rw_543
  0x2d000205, 0x311a280c, 0x2d0d0214, 0x1a001f1b,   // da.sk.un_330 sw.tl.az_543  da.cs.sk_666 cy.tl.un_770
  // [20c0]
  0x1c0d09ad, 0x05013f07, 0x11170808, 0x1300040e,   // hi.ne.mr_643 af.en.fr_432  uk.sr.ro_443 fi.et.un_550
  0x64045512, 0x5200280d, 0x13350460, 0x64292807,   // rw.fi.lg_654 sw.ha.un_540  fi.zu.et_664 sw.sl.lg_432
  0x101a130c, 0x64000a07, 0x68004a14, 0x0c033f04,   // et.tl.lt_543 pt.lg.un_420  yo.ig.un_660 af.nl.sv_332
  0x211e1f12, 0x52101fa4, 0x29351307, 0x02000c04,   // cy.ms.jw_654 cy.lt.ha_433  et.zu.sl_432 sv.da.un_320
  // [20d0]
  0x2700180c, 0x551a6b12, 0x0300270d, 0x3f062307,   // ga.gd.un_530 ceb.tl.rw_654  gd.nl.un_540 ca.de.af_432
  0x6b060cad, 0x1c001e12, 0x5535680c, 0x1e1c1f0c,   // sv.de.ceb_643 ms.id.un_640  ig.zu.rw_543 cy.id.ms_543
  0x00003103, 0x2d090d12, 0x0d033fa4, 0x10251fa7,   // az.un.un_300 cs.pl.sk_654  af.nl.cs_433 cy.eu.lt_532
  0x3f2821a0, 0x6b6801ee, 0x07080260, 0x08121b0c,   // jw.sw.af_322 en.ig.ceb_422  da.no.it_664 tr.hu.no_543
  // [20e0]
  0x645228ac, 0x070411a6, 0x07170412, 0x092d3f08,   // sw.ha.lg_632 ro.ru.bg_521  ru.sr.bg_654 af.sk.pl_443
  0x0a170805, 0x08020c05, 0x190b2305, 0x18000713,   // uk.sr.mk_333 sv.da.no_333  ca.es.gl_333 it.ga.un_650
  0x1b001313, 0x013b0ca0, 0x1328350c, 0x2d2913ee,   // et.tr.un_650 sv.so.en_322  zu.sw.et_543 et.sl.sk_422
  0x041310a4, 0x17000a0e, 0x1f27180c, 0x13000108,   // lt.et.fi_433 mk.sr.un_550  ga.gd.cy_543 en.et.un_430
  // [20f0]
  0x130c2aa4, 0x16321707, 0x10521aad, 0x04311304,   // mt.sv.et_433 sr.bs.hr_432  tl.ha.lt_643 et.az.fi_332
  0x640813a4, 0x201801af, 0x02006b04, 0x06002a0c,   // et.no.lg_433 en.ga.sq_655  ceb.da.un_320 mt.de.un_530
  0x01003104, 0x4a005504, 0x64005507, 0x1e006b05,   // az.en.un_320 rw.yo.un_320  rw.lg.un_420 ceb.ms.un_330
  0x061f08a4, 0x2800351a, 0x1a003512, 0x063f0308,   // no.cy.de_433 zu.sw.un_760  zu.tl.un_640 nl.af.de_443
  // [2100]
  0x55284aa7, 0x1c132a10, 0x1f3f2aa0, 0x091b3fa0,   // yo.sw.rw_532 mt.et.id_642  mt.af.cy_322 af.tr.pl_322
  0x35005202, 0x18211209, 0x0f003f05, 0x2a1b53a0,   // ha.zu.un_220 ur.fa.ar_444  af.lv.un_330 ht.tr.mt_322
  0x64321604, 0x07170aaf, 0x1b11530c, 0x2a1b08a4,   // hr.bs.lg_332 mk.sr.bg_655  ht.ro.tr_543 no.tr.mt_433
  0x0e070807, 0x1e1c64a9, 0x3500680c, 0x645528ee,   // no.it.is_432 lg.id.ms_544  ig.zu.un_530 sw.rw.lg_422
  // [2110]
  0x230a05ec, 0x3b125355, 0x1c641eaf, 0x1e1c640c,   // fr.pt.ca_644 ht.hu.so_442  ms.lg.id_655 lg.id.ms_543
  0x072a1fee, 0x532a11a4, 0x35123b05, 0x64551c07,   // cy.mt.it_422 ro.mt.ht_433  so.hu.zu_333 id.rw.lg_432
  0x0a0711a4, 0x2d000b04, 0x1e1c55a0, 0x091e1c08,   // ro.bg.mk_433 es.sk.un_320  rw.id.ms_322 id.ms.pl_443
  0x13000304, 0x4a00211a, 0x211a55a4, 0x0000282d,   // nl.et.un_320 jw.yo.un_760  rw.tl.jw_433 sw.un.un_A00
  // [2120]
  0x0d130913, 0x012a6ea0, 0x64005523, 0x13090da4,   // hi.bh.ne_665 hmn.mt.en_322  rw.lg.un_880 ne.hi.bh_433
  0x1a556b08, 0x170a04ad, 0x08000c02, 0x0c000708,   // ceb.rw.tl_443 ru.mk.sr_643  sv.no.un_220 it.sv.un_430
  0x06040312, 0x553568a9, 0x53052aa0, 0x04131a07,   // nl.fi.de_654 ig.zu.rw_544  mt.fr.ht_322 tl.et.fi_432
  0x0c0308a0, 0x0b00250c, 0x3500280c, 0x033f2aee,   // no.nl.sv_322 eu.es.un_530  sw.zu.un_530 mt.af.nl_422
  // [2130]
  0x0e080c04, 0x082502a0, 0x200f1009, 0x3564550c,   // sv.no.is_332 da.eu.no_322  lt.lv.sq_444 rw.lg.zu_543
  0x08092a07, 0x0d1c09af, 0x6b6803a4, 0x1e1c55a4,   // mt.pl.no_432 hi.mr.ne_655  nl.ig.ceb_433 rw.id.ms_433
  0x111b31af, 0x1700200c, 0x1255640c, 0x070a01a4,   // az.tr.ro_655 sq.sr.un_530  lg.rw.hu_543 en.pt.it_433
  0x0e000c04, 0x5509680d, 0x1c090d13, 0x1c0d13af,   // sv.is.un_320 ig.pl.rw_554  ne.hi.mr_665 bh.ne.mr_655
  // [2140]
  0x1c551e0c, 0x07130455, 0x0f002d13, 0x041b310d,   // ms.rw.id_543 fi.et.it_442  sk.lv.un_650 az.tr.fi_554
  0x1b11290c, 0x16321711, 0x1e1c55ec, 0x531b3160,   // sl.ro.tr_543 sr.bs.hr_653  rw.id.ms_644 az.tr.ht_664
  0x1e641c0c, 0x1828090c, 0x17071105, 0x23001e13,   // id.lg.ms_543 pl.sw.ga_543  ro.bg.sr_333 ms.ca.un_650
  0x02041304, 0x55006b11, 0x29092dad, 0x1c5221a0,   // et.fi.da_332 ceb.rw.un_630  sk.pl.sl_643 jw.ha.id_322
  // [2150]
  0x0a000422, 0x55000104, 0x1f001221, 0x20002902,   // ru.mk.un_870 en.rw.un_320  hu.cy.un_860 sl.sq.un_220
  0x6b6853a4, 0x066b1a07, 0x170a07ee, 0x19211fa4,   // ht.ig.ceb_433 tl.ceb.de_432  bg.mk.sr_422 cy.jw.gl_433
  0x2d3b1108, 0x0a071105, 0x012a07ad, 0x17040855,   // ro.so.sk_443 ro.bg.mk_333  it.mt.en_643 uk.ru.sr_442
  0x28556404, 0x1f002b1b, 0x3f020ea4, 0x2a1118ee,   // lg.rw.sw_332 vi.cy.un_770  is.da.af_433 ga.ro.mt_422
  // [2160]
  0x2b001f0d, 0x2b002302, 0x0c005302, 0x291b0ba4,   // cy.vi.un_540 ca.vi.un_220  ht.sv.un_220 es.tr.sl_433
  0x1f3b3f12, 0x31091b12, 0x31000707, 0x100a0709,   // af.so.cy_654 tr.pl.az_654  it.az.un_420 bg.mk.be_444
  0x64012704, 0x0c1b3108, 0x113129a0, 0x113b0f07,   // gd.en.lg_332 az.tr.sv_443  sl.az.ro_322 lv.so.ro_432
  0x0c530802, 0x23072da4, 0x53005214, 0x080e0c02,   // no.ht.sv_222 sk.it.ca_433  ha.ht.un_660 sv.is.no_222
  // [2170]
  0x013153ee, 0x18052709, 0x1a126bec, 0x05533b05,   // ht.az.en_422 gd.fr.ga_444  ceb.hu.tl_644 so.ht.fr_333
  0x04130c05, 0x12002a05, 0x08000c05, 0x1c00130b,   // sv.et.fi_333 mt.hu.un_330  sv.no.un_330 bh.mr.un_520
  0x10020caf, 0x55531fa7, 0x18002707, 0x07040a07,   // sv.da.lt_655 cy.ht.rw_532  gd.ga.un_420 mk.ru.bg_432
  0x070811ad, 0x060a1ba4, 0x100a08a4, 0x06052304,   // ro.uk.bg_643 tr.pt.de_433  uk.mk.be_433 ca.fr.de_332
  // [2180]
  0x2704180c, 0x12001309, 0x0a001912, 0x08001008,   // ga.fi.gd_543 et.hu.un_440  gl.pt.un_640 be.uk.un_430
  0x0400170e, 0x2555640c, 0x09061f0d, 0x040810af,   // sr.ru.un_550 lg.rw.eu_543  cy.de.pl_554 be.uk.ru_655
  0x55296405, 0x08000411, 0x110817a4, 0x03173fa0,   // lg.sl.rw_333 ru.uk.un_630  sr.uk.ro_433 af.sr.nl_322
  0x0e0802ad, 0x0a2d0d0e, 0x110a07a4, 0x041107ec,   // da.no.is_643 cs.sk.pt_555  bg.mk.ro_433 bg.ro.ru_644
  // [2190]
  0x111e1c0d, 0x0c2301a4, 0x0a230611, 0x28006419,   // id.ms.ro_554 en.ca.sv_433  de.ca.pt_653 lg.sw.un_750
  0x0900200e, 0x320917a4, 0x1f003b13, 0x64550705,   // sq.pl.un_550 sr.pl.bs_433  so.cy.un_650 it.rw.lg_333
  0x010653a0, 0x09290da4, 0x1103250c, 0x05001c02,   // ht.de.en_322 cs.sl.pl_433  eu.nl.ro_543 id.fr.un_220
  0x352011a4, 0x03520607, 0x5201050d, 0x0a080708,   // ro.sq.zu_433 de.ha.nl_432  fr.en.ha_554 bg.uk.mk_443
  // [21a0]
  0x254a11a7, 0x0c0552a0, 0x16066855, 0x280a520c,   // ro.yo.eu_532 ha.fr.sv_322  ig.de.hr_442 ha.pt.sw_543
  0x2d0d11a4, 0x022a070c, 0x0a04100c, 0x08070aa4,   // ro.cs.sk_433 it.mt.da_543  be.ru.mk_543 mk.bg.uk_433
  0x6b2707ad, 0x080e0c07, 0x092d0d12, 0x213f1c07,   // it.gd.ceb_643 sv.is.no_432  cs.sk.pl_654 id.af.jw_432
  0x18012504, 0x033f0ca0, 0x10040809, 0x1132165a,   // eu.en.ga_332 sv.af.nl_322  uk.ru.be_444 hr.bs.ro_553
  // [21b0]
  0x3f192707, 0x0a292d07, 0x171b2107, 0x1b001804,   // gd.gl.af_432 sk.sl.pt_432  jw.tr.sr_432 ga.tr.un_320
  0x0f043202, 0x12553b08, 0x215564ad, 0x01113507,   // bs.fi.lv_222 so.rw.hu_443  lg.rw.jw_643 zu.ro.en_432
  0x353f0313, 0x11072da4, 0x1c002104, 0x64552812,   // nl.af.zu_665 sk.it.ro_433  jw.id.un_320 sw.rw.lg_654
  0x0700521b, 0x1e001f2a, 0x1c003f04, 0x171625ee,   // ha.it.un_770 cy.ms.un_970  af.id.un_320 eu.hr.sr_422
  // [21c0]
  0x0e023fa0, 0x021e1c02, 0x35000307, 0x08023fa4,   // af.da.is_322 id.ms.da_222  nl.zu.un_420 af.da.no_433
  0x1c1b29ee, 0x0e0c120c, 0x25182713, 0x1a35550c,   // sl.tr.id_422 hu.sv.is_543  gd.ga.eu_665 rw.zu.tl_543
  0x03002707, 0x3f030612, 0x290d1baf, 0x01052aa4,   // gd.nl.un_420 de.nl.af_654  tr.cs.sl_655 mt.fr.en_433
  0x32003b05, 0x01000907, 0x21004a07, 0x201f55a4,   // so.bs.un_330 pl.en.un_420  yo.jw.un_420 rw.cy.sq_433
  // [21d0]
  0x09251108, 0x162d0d08, 0x0a0710a4, 0x1f190a14,   // ro.eu.pl_443 cs.sk.hr_443  be.bg.mk_433 pt.gl.cy_666
  0x20253b05, 0x09002a0e, 0x1105010c, 0x21001205,   // so.eu.sq_333 mt.pl.un_550  en.fr.ro_543 ur.fa.un_330
  0x050602a0, 0x0d05010c, 0x0e231e04, 0x07001823,   // da.de.fr_322 en.fr.cs_543  ms.ca.is_332 ga.it.un_880
  0x06353f0c, 0x033f0f0c, 0x252868a7, 0x0b00110b,   // af.zu.de_543 lv.af.nl_543  ig.sw.eu_532 ro.es.un_520
  // [21e0]
  0x2d006e0e, 0x0e53040c, 0x1000111a, 0x531e1ca9,   // hmn.sk.un_550 fi.ht.is_543  ro.be.un_760 id.ms.ht_544
  0x1b356412, 0x12035204, 0x12002102, 0x2d000d2a,   // lg.zu.tr_654 ha.nl.hu_332  jw.hu.un_220 cs.sk.un_970
  0x4a311b11, 0x5535210c, 0x3500190e, 0x106b1a11,   // tr.az.yo_653 jw.zu.rw_543  gl.zu.un_550 tl.ceb.lt_653
  0x13640e09, 0x214a1aad, 0x28553512, 0x28291905,   // is.lg.et_444 tl.yo.jw_643  zu.rw.sw_654 gl.sl.sw_333
  // [21f0]
  0x02006809, 0x27071f0c, 0x040811ad, 0x09002d12,   // ig.da.un_440 cy.it.gd_543  ro.uk.ru_643 sk.pl.un_640
  0x2d093bec, 0x061b03ad, 0x2d0d29af, 0x17110704,   // so.pl.sk_644 nl.tr.de_643  sl.cs.sk_655 bg.ro.sr_332
  0x292d0d08, 0x1c2b0307, 0x09003204, 0x06002509,   // cs.sk.sl_443 nl.vi.id_432  bs.pl.un_320 eu.de.un_440
  0x0d321608, 0x0f020807, 0x08006b0e, 0x3b4a3fad,   // hr.bs.cs_443 no.da.lv_432  ceb.no.un_550 af.yo.so_643
  // [2200]
  0x1007110c, 0x09002d19, 0x04001908, 0x53000b04,   // ro.bg.be_543 sk.pl.un_750  gl.fi.un_430 es.ht.un_320
  0x040a2108, 0x0c000819, 0x07001709, 0x32171309,   // jw.pt.fi_443 no.sv.un_750  sr.bg.un_440 et.sr.bs_444
  0x28351c07, 0x250d2a07, 0x0655645a, 0x0a07040c,   // id.zu.sw_432 mt.cs.eu_432  lg.rw.de_553 ru.bg.mk_543
  0x52082aa0, 0x0c000e08, 0x06680312, 0x0f2852a0,   // mt.no.ha_322 is.sv.un_430  nl.ig.de_654 ha.sw.lv_322
  // [2210]
  0x0c000e1b, 0x10002108, 0x10090f0c, 0x28121b05,   // is.sv.un_770 jw.lt.un_430  lv.pl.lt_543 tr.hu.sw_333
  0x100f32a0, 0x07130411, 0x32000708, 0x20321607,   // bs.lv.lt_322 fi.et.it_653  it.bs.un_430 hr.bs.sq_432
  0x05005308, 0x21181214, 0x08040ea7, 0x25192305,   // ht.fr.un_430 ur.ar.fa_666  is.fi.no_532 ca.gl.eu_333
  0x292d1604, 0x210435ec, 0x52642a07, 0x0f2d0d04,   // hr.sk.sl_332 zu.fi.jw_644  mt.lg.ha_432 cs.sk.lv_332
  // [2220]
  0x32171611, 0x3b005204, 0x1a256bee, 0x6b251ca0,   // hr.sr.bs_653 ha.so.un_320  ceb.eu.tl_422 id.eu.ceb_322
  0x08042aad, 0x0c040807, 0x03001608, 0x1f27010c,   // mt.fi.no_643 no.fi.sv_432  hr.nl.un_430 en.gd.cy_543
  0x64005511, 0x3b3f030e, 0x13040514, 0x2d0d1605,   // rw.lg.un_630 nl.af.so_555  fr.fi.et_666 hr.cs.sk_333
  0x1000081b, 0x0800010d, 0x1e4a6812, 0x090d2d11,   // uk.be.un_770 en.no.un_540  ig.yo.ms_654 sk.cs.pl_653
  // [2230]
  0x35551e0c, 0x18002111, 0x130c04a4, 0x131064ee,   // ms.rw.zu_543 fa.ar.un_630  fi.sv.et_433 lg.lt.et_422
  0x042a0713, 0x0c130ea9, 0x13001707, 0x060364a0,   // it.mt.fi_665 is.et.sv_544  sr.et.un_420 lg.nl.de_322
  0x2d0c0d55, 0x1221180c, 0x100f1e07, 0x2d0d2aee,   // cs.sv.sk_442 ar.fa.ur_543  ms.lv.lt_432 mt.cs.sk_422
  0x0a041705, 0x040901a4, 0x0d091c11, 0x0e645511,   // sr.ru.mk_333 en.pl.fi_433  mr.hi.ne_653 rw.lg.is_653
  // [2240]
  0x1c002108, 0x0c050707, 0x081104a4, 0x3b002a02,   // jw.id.un_430 it.fr.sv_432  ru.ro.uk_433 mt.so.un_220
  0x64041311, 0x211e1cac, 0x3b6455ad, 0x0531010c,   // et.fi.lg_653 id.ms.jw_632  rw.lg.so_643 en.az.fr_543
  0x0e06180c, 0x64685512, 0x3f120205, 0x13000d07,   // ga.de.is_543 rw.ig.lg_654  da.hu.af_333 ne.bh.un_420
  0x3f13080c, 0x13001b18, 0x0e000419, 0x0c0102a0,   // no.et.af_543 tr.et.un_740  fi.is.un_750 da.en.sv_322
  // [2250]
  0x08040a14, 0x09001f0d, 0x1000041a, 0x0e101b08,   // mk.ru.uk_666 cy.pl.un_540  ru.be.un_760 tr.lt.is_443
  0x01281fee, 0x2b004a23, 0x07040c08, 0x0c000e07,   // cy.sw.en_422 yo.vi.un_880  sv.fi.it_443 is.sv.un_420
  0x07682107, 0x27000b04, 0x4a2b2713, 0x3b190b55,   // jw.ig.it_432 es.gd.un_320  gd.vi.yo_665 es.gl.so_442
  0x271f29a4, 0x23312504, 0x35002802, 0x12000c13,   // sl.cy.gd_433 eu.az.ca_332  sw.zu.un_220 sv.hu.un_650
  // [2260]
  0x11231f0c, 0x3100230e, 0x27002b21, 0x091c0d0e,   // cy.ca.ro_543 ca.az.un_550  vi.gd.un_860 ne.mr.hi_555
  0x19072508, 0x0a0411ee, 0x2b002714, 0x55250e0c,   // eu.it.gl_443 ro.ru.mk_422  gd.vi.un_660 is.eu.rw_543
  0x08000b07, 0x551c2108, 0x28003205, 0x553b6404,   // es.no.un_420 jw.id.rw_443  bs.sw.un_330 lg.so.rw_332
  0x060355a9, 0x532925a0, 0x353f080c, 0x3b64130c,   // rw.nl.de_544 eu.sl.ht_322  no.af.zu_543 et.lg.so_543
  // [2270]
  0x0f28090b, 0x17190b05, 0x190b0a04, 0x1100270e,   // pl.sw.lv_542 es.gl.sr_333  pt.es.gl_332 gd.ro.un_550
  0x081710a0, 0x19170a05, 0x202d35a4, 0x1a006b1a,   // be.sr.uk_322 pt.sr.gl_333  zu.sk.sq_433 ceb.tl.un_760
  0x2b004a1b, 0x091f12ad, 0x02001904, 0x0a171005,   // yo.vi.un_770 hu.cy.pl_643  gl.da.un_320 be.sr.mk_333
  0x520425a0, 0x6428550d, 0x0452530c, 0x64003b08,   // eu.fi.ha_322 rw.sw.lg_554  ht.ha.fi_543 so.lg.un_430
  // [2280]
  0x531109a4, 0x3f070fa4, 0x13001817, 0x4a002b14,   // pl.ro.ht_433 lv.it.af_433  ga.et.un_730 vi.yo.un_660
  0x35556ba0, 0x1b312aa4, 0x10020f05, 0x3f001902,   // ceb.rw.zu_322 mt.az.tr_433  lv.da.lt_333 gl.af.un_220
  0x092855ad, 0x19091fa4, 0x12006b08, 0x0802250c,   // rw.sw.pl_643 cy.pl.gl_433  ceb.hu.un_430 eu.da.no_543
  0x290723a0, 0x03001212, 0x03112705, 0x12000921,   // ca.it.sl_322 hu.nl.un_640  gd.ro.nl_333 pl.hu.un_860
  // [2290]
  0x20116e08, 0x036455a4, 0x1700190e, 0x190b1fa4,   // hmn.ro.sq_443 rw.lg.nl_433  gl.sr.un_550 cy.es.gl_433
  0x3f00551a, 0x170f3502, 0x1c090d12, 0x1f190b0c,   // rw.af.un_760 zu.lv.sr_222  ne.hi.mr_654 es.gl.cy_543
  0x282d4aad, 0x056b1104, 0x1b001112, 0x18120805,   // yo.sk.sw_643 ro.ceb.fr_332  ro.tr.un_640 no.hu.ga_333
  0x04080705, 0x033f0aa6, 0x0400531a, 0x1b0804ee,   // bg.uk.ru_333 pt.af.nl_521  ht.fi.un_760 fi.no.tr_422
  // [22a0]
  0x10000714, 0x0f5304ee, 0x0500531a, 0x6b1b0805,   // bg.be.un_660 fi.ht.lv_422  ht.fr.un_760 no.tr.ceb_333
  0x0a0553ad, 0x35001319, 0x52190b02, 0x5300052b,   // ht.fr.pt_643 et.zu.un_750  es.gl.ha_222 fr.ht.un_980
  0x04060c04, 0x10004a04, 0x011606a0, 0x1b1911a7,   // sv.de.fi_332 yo.lt.un_320  de.hr.en_322 ro.gl.tr_532
  0x25001f0c, 0x0e2a0708, 0x05005322, 0x53000807,   // cy.eu.un_530 it.mt.is_443  ht.fr.un_870 no.ht.un_420
  // [22b0]
  0x29002108, 0x17000805, 0x4a006407, 0x090d1c05,   // jw.sl.un_430 uk.sr.un_330  lg.yo.un_420 mr.ne.hi_333
  0x01072aa0, 0x190b01af, 0x0f00201a, 0x0c000204,   // mt.it.en_322 en.es.gl_655  sq.lv.un_760 da.sv.un_320
  0x4a000104, 0x0f3217a4, 0x080c2aa4, 0x3f0c08a4,   // en.yo.un_320 sr.bs.lv_433  mt.sv.no_433 no.sv.af_433
  0x020c3fee, 0x131c09ad, 0x0a110708, 0x0d530514,   // af.sv.da_422 hi.mr.bh_643  bg.ro.mk_443 fr.ht.cs_666
  // [22c0]
  0x53000523, 0x0c3f0309, 0x25004a07, 0x0508025a,   // fr.ht.un_880 nl.af.sv_444  yo.eu.un_420 da.no.fr_553
  0x6b553505, 0x2a1b13ee, 0x200e0608, 0x1600060c,   // zu.rw.ceb_333 et.tr.mt_422  de.is.sq_443 de.hr.un_530
  0x020c0804, 0x08000202, 0x3f006b08, 0x1f033f0d,   // no.sv.da_332 da.no.un_220  ceb.af.un_430 af.nl.cy_554
  0x0e00100c, 0x3b2a6b07, 0x641055a4, 0x2d1f0ba0,   // lt.is.un_530 ceb.mt.so_432  rw.lt.lg_433 es.cy.sk_322
  // [22d0]
  0x1a0e2112, 0x1a1031ad, 0x17001111, 0x200e06a7,   // jw.is.tl_654 az.lt.tl_643  ro.sr.un_630 de.is.sq_532
  0x356b1a12, 0x131c09af, 0x091f0e07, 0x0135640c,   // tl.ceb.zu_654 hi.mr.bh_655  is.cy.pl_432 lg.zu.en_543
  0x13080ca4, 0x0e000b02, 0x2a32165a, 0x0704050c,   // sv.no.et_433 es.is.un_220  hr.bs.mt_553 fr.fi.it_543
  0x1b53520c, 0x21531ca0, 0x3228550c, 0x10002d0d,   // ha.ht.tr_543 id.ht.jw_322  rw.sw.bs_543 sk.lt.un_540
  // [22e0]
  0x0a1707ee, 0x0c081207, 0x35282a02, 0x286425a0,   // bg.sr.mk_422 hu.no.sv_432  mt.sw.zu_222 eu.lg.sw_322
  0x20070460, 0x13122a04, 0x08645512, 0x0c002a07,   // fi.it.sq_664 mt.hu.et_332  rw.lg.no_654 mt.sv.un_420
  0x5235640b, 0x080711a4, 0x020c0812, 0x553564a4,   // lg.zu.ha_542 ro.bg.uk_433  no.sv.da_654 lg.zu.rw_433
  0x0f291b0b, 0x1b081307, 0x2a000c0b, 0x12004a04,   // tr.sl.lv_542 et.no.tr_432  sv.mt.un_520 yo.hu.un_320
  // [22f0]
  0x532555a9, 0x04080760, 0x040613a4, 0x060c0e12,   // rw.eu.ht_544 bg.uk.ru_664  et.de.fi_433 is.sv.de_654
  0x55282308, 0x3f006e04, 0x6400282a, 0x081710a4,   // ca.sw.rw_443 hmn.af.un_320  sw.lg.un_970 be.sr.uk_433
  0x07190b04, 0x1c13090c, 0x1700112a, 0x11190a04,   // es.gl.it_332 hi.bh.mr_543  ro.sr.un_970 pt.gl.ro_332
  0x0200052b, 0x25080e07, 0x1a5564af, 0x25280ea0,   // fr.da.un_980 is.no.eu_432  lg.rw.tl_655 is.sw.eu_322
  // [2300]
  0x08060e0d, 0x52555308, 0x070417af, 0x080c0260,   // is.de.no_554 ht.rw.ha_443  sr.ru.bg_655 da.sv.no_664
  0x645235ad, 0x535535a0, 0x25001304, 0x53000708,   // zu.ha.lg_643 zu.rw.ht_322  et.eu.un_320 it.ht.un_430
  0x09050407, 0x130e0c04, 0x18000419, 0x0d001c0b,   // fi.fr.pl_432 sv.is.et_332  fi.ga.un_750 mr.ne.un_520
  0x11004a0c, 0x05000413, 0x04003508, 0x522a6bad,   // yo.ro.un_530 fi.fr.un_650  zu.fi.un_430 ceb.mt.ha_643
  // [2310]
  0x041305af, 0x273b3fee, 0x1100081a, 0x0c083f04,   // fr.et.fi_655 af.so.gd_422  uk.ro.un_760 af.no.sv_332
  0x05000412, 0x03080255, 0x6400350e, 0x03061307,   // fi.fr.un_640 da.no.nl_442  zu.lg.un_550 et.de.nl_432
  0x05003f1a, 0x1153290c, 0x1f000d04, 0x031306a4,   // af.fr.un_760 sl.ht.ro_543  cs.cy.un_320 de.et.nl_433
  0x08023f0e, 0x040e1307, 0x0a110107, 0x115308a9,   // af.da.no_555 et.is.fi_432  en.ro.pt_432 no.ht.ro_544
  // [2320]
  0x07050112, 0x23004a08, 0x050208a4, 0x050a3b12,   // en.fr.it_654 yo.ca.un_430  no.da.fr_433 so.pt.fr_654
  0x2a0507ec, 0x06000823, 0x041110a4, 0x080c0255,   // it.fr.mt_644 no.de.un_880  be.ro.ru_433 da.sv.no_442
  0x04006807, 0x0c010eee, 0x6b0c0812, 0x1708105a,   // ig.fi.un_420 is.en.sv_422  no.sv.ceb_654 be.uk.sr_553
  0x321b0e0b, 0x0410080c, 0x0a080205, 0x3f0308ac,   // is.tr.bs_542 uk.be.ru_543  da.no.pt_333 no.nl.af_632
  // [2330]
  0x6e00090b, 0x29040da0, 0x041305a4, 0x0b2319a0,   // pl.hmn.un_520 cs.fi.sl_322  fr.et.fi_433 gl.ca.es_322
  0x28130455, 0x21552804, 0x00000937, 0x04080205,   // fi.et.sw_442 sw.rw.jw_332  hi.un.un_B00 da.no.fi_333
  0x6e016b04, 0x1f001320, 0x07000822, 0x07231108,   // ceb.en.hmn_332 et.cy.un_850  uk.bg.un_870 ro.ca.it_443
  0x535528ad, 0x3f1f0212, 0x02030e07, 0x53002b0d,   // sw.rw.ht_643 da.cy.af_654  is.nl.da_432 vi.ht.un_540
  // [2340]
  0x17162d05, 0x1b003514, 0x01000f0b, 0x1e271ca0,   // sk.hr.sr_333 zu.tr.un_660  lv.en.un_520 id.gd.ms_322
  0x21521e04, 0x04170805, 0x18003514, 0x2818270c,   // ms.ha.jw_332 uk.sr.ru_333  zu.ga.un_660 gd.ga.sw_543
  0x04081fee, 0x09291b55, 0x04170aa6, 0x10001112,   // cy.no.fi_422 tr.sl.pl_442  mk.sr.ru_521 ro.be.un_640
  0x016b3507, 0x213f0311, 0x0a000419, 0x1a0953a0,   // zu.ceb.en_432 nl.af.jw_653  ru.mk.un_750 ht.pl.tl_322
  // [2350]
  0x27005204, 0x0a1011a4, 0x1f292d55, 0x31001b0d,   // ha.gd.un_320 ro.be.mk_433  sk.sl.cy_442 tr.az.un_540
  0x1b6b1a08, 0x080717a4, 0x0d292d07, 0x1c005502,   // tl.ceb.tr_443 sr.bg.uk_433  sk.sl.cs_432 rw.id.un_220
  0x041708a9, 0x1b532108, 0x3110110c, 0x040717a9,   // uk.sr.ru_544 jw.ht.tr_443  ro.lt.az_543 sr.bg.ru_544
  0x3f1c03a4, 0x01000f0c, 0x1c130909, 0x290d2dec,   // nl.id.af_433 lv.en.un_530  hi.bh.mr_444 sk.cs.sl_644
  // [2360]
  0x27001808, 0x04000813, 0x28001808, 0x1e2d1c0c,   // ga.gd.un_430 uk.ru.un_650  ga.sw.un_430 id.sk.ms_543
  0x120a2304, 0x2d0d17a0, 0x180e1fa7, 0x1c181ea4,   // ca.pt.hu_332 sr.cs.sk_322  cy.is.ga_532 ms.ga.id_433
  0x09553ba9, 0x0a001721, 0x0d0913a7, 0x0e000c05,   // so.rw.pl_544 sr.mk.un_860  bh.hi.ne_532 sv.is.un_330
  0x1c00090b, 0x29120312, 0x2d1129a7, 0x530a1108,   // hi.mr.un_520 nl.hu.sl_654  sl.ro.sk_532 ro.pt.ht_443
  // [2370]
  0x1b002d04, 0x20002a13, 0x0e120ca9, 0x04110708,   // sk.tr.un_320 mt.sq.un_650  sv.hu.is_544 bg.ro.ru_443
  0x01001f05, 0x1704070b, 0x09001607, 0x051a3555,   // cy.en.un_330 bg.ru.sr_542  hr.pl.un_420 zu.tl.fr_442
  0x03013f02, 0x23000a23, 0x09011f04, 0x00000e06,   // af.en.nl_222 pt.ca.un_880  cy.en.pl_332 is.un.un_400
  0x23050b07, 0x2b001e08, 0x211c1eee, 0x190a6b02,   // es.fr.ca_432 ms.vi.un_430  ms.id.jw_422 ceb.pt.gl_222
  // [2380]
  0x041008ec, 0x1f1118af, 0x180c06ad, 0x11000414,   // uk.be.ru_644 ga.ro.cy_655  de.sv.ga_643 ru.ro.un_660
  0x2d0d1602, 0x0e000612, 0x4a000512, 0x130306ad,   // hr.cs.sk_222 de.is.un_640  fr.yo.un_640 de.nl.et_643
  0x3f000a08, 0x033f0613, 0x0c000822, 0x3100530e,   // pt.af.un_430 de.af.nl_665  no.sv.un_870 ht.az.un_550
  0x0100060b, 0x6b3f0212, 0x29000313, 0x1b002a0c,   // de.en.un_520 da.af.ceb_654  nl.sl.un_650 mt.tr.un_530
  // [2390]
  0x0c0217a4, 0x190b0aec, 0x10000913, 0x10000f23,   // sr.da.sv_433 pt.es.gl_644  pl.lt.un_650 lv.lt.un_880
  0x13643b07, 0x210b075a, 0x21000105, 0x53000713,   // so.lg.et_432 it.es.jw_553  en.jw.un_330 it.ht.un_650
  0x20002b14, 0x0a2319ee, 0x04071111, 0x0b112da4,   // vi.sq.un_660 gl.ca.pt_422  ro.bg.ru_653 sk.ro.es_433
  0x040a08a9, 0x0d001312, 0x25521f13, 0x08041709,   // uk.mk.ru_544 bh.ne.un_640  cy.ha.eu_665 sr.ru.uk_444
  // [23a0]
  0x0a133f04, 0x1e1c1902, 0x01080205, 0x0a110f0c,   // af.et.pt_332 gl.id.ms_222  da.no.en_333 lv.ro.pt_543
  0x0a000719, 0x07001904, 0x06021ea9, 0x08030555,   // bg.mk.un_750 gl.it.un_320  ms.da.de_544 fr.nl.no_442
  0x21001a08, 0x4a1f5307, 0x091253ee, 0x080212af,   // tl.jw.un_430 ht.cy.yo_432  ht.hu.pl_422 hu.da.no_655
  0x0f0410af, 0x00001b2d, 0x071704ec, 0x17002919,   // lt.fi.lv_655 tr.un.un_A00  ru.sr.bg_644 sl.sr.un_750
  // [23b0]
  0x10001707, 0x53190a13, 0x08041055, 0x09002a08,   // sr.lt.un_420 pt.gl.ht_665  be.ru.uk_442 mt.pl.un_430
  0x19000a0b, 0x07002a1a, 0x201953a9, 0x01001f19,   // pt.gl.un_520 mt.it.un_760  ht.gl.sq_544 cy.en.un_750
  0x32001712, 0x2d001907, 0x0f001119, 0x0a0125a0,   // sr.bs.un_640 gl.sk.un_420  ro.lv.un_750 eu.en.pt_322
  0x1c1e1b0d, 0x1e1c2d0c, 0x0a001904, 0x64000a04,   // tr.ms.id_554 sk.id.ms_543  gl.pt.un_320 pt.lg.un_320
  // [23c0]
  0x0a553509, 0x0e00350d, 0x1c000711, 0x29321608,   // zu.rw.pt_444 zu.is.un_540  it.id.un_630 hr.bs.sl_443
  0x10352d0c, 0x1c006804, 0x0f1004a7, 0x0e0608ec,   // sk.zu.lt_543 ig.id.un_320  fi.lt.lv_532 no.de.is_644
  0x3f0e1c04, 0x111b1211, 0x20002307, 0x13003513,   // id.is.af_332 hu.tr.ro_653  ca.sq.un_420 zu.et.un_650
  0x1b644a13, 0x203f0107, 0x101304a6, 0x1a3f03ee,   // yo.lg.tr_665 en.af.sq_432  fi.et.lt_521 nl.af.tl_422
  // [23d0]
  0x1b053b05, 0x2d132905, 0x210a06ee, 0x03173f02,   // so.fr.tr_333 sl.et.sk_333  de.pt.jw_422 af.sr.nl_222
  0x06003f21, 0x0100110c, 0x10211aa9, 0x0d002d0b,   // af.de.un_860 ro.en.un_530  tl.jw.lt_544 sk.cs.un_520
  0x0d003519, 0x08001119, 0x2d0a0da4, 0x12002312,   // zu.cs.un_750 ro.uk.un_750  cs.pt.sk_433 ca.hu.un_640
  0x0a2d190c, 0x06020811, 0x1c020f55, 0x21001811,   // gl.sk.pt_543 no.da.de_653  lv.da.id_442 ar.fa.un_630
  // [23e0]
  0x2100120c, 0x1708040c, 0x071b010c, 0x35001e08,   // ur.fa.un_530 ru.uk.sr_543  en.tr.it_543 ms.zu.un_430
  0x68553513, 0x25190ba7, 0x130411ec, 0x0d001c1a,   // zu.rw.ig_665 es.gl.eu_532  ro.fi.et_644 mr.ne.un_760
  0x1b13040c, 0x01210cee, 0x2a000a07, 0x4a251b07,   // fi.et.tr_543 sv.jw.en_422  pt.mt.un_420 tr.eu.yo_432
  0x06020c05, 0x06000d13, 0x643523ec, 0x1220130c,   // sv.da.de_333 cs.de.un_650  ca.zu.lg_644 et.sq.hu_543
  // [23f0]
  0x08000e0e, 0x68006422, 0x20002d04, 0x130b0c05,   // is.no.un_550 lg.ig.un_870  sk.sq.un_320 sv.es.et_333
  0x2b553504, 0x080c0313, 0x1a3564a9, 0x0f132907,   // zu.rw.vi_332 nl.sv.no_665  lg.zu.tl_544 sl.et.lv_432
  0x072d0d55, 0x03083f08, 0x29002d0d, 0x68003514,   // cs.sk.it_442 af.no.nl_443  sk.sl.un_540 zu.ig.un_660
  0x64001608, 0x0a0c1e04, 0x010802a4, 0x130928a0,   // hr.lg.un_430 ms.sv.pt_332  da.no.en_433 sw.pl.et_322

  // [2400]
  0x0a0908a0, 0x02000e13, 0x13000d0c, 0x55642855,   // no.pl.pt_322 is.da.un_650  ne.bh.un_530 sw.lg.rw_442
  0x6b251b11, 0x0e0827ad, 0x21645504, 0x20005205,   // tr.eu.ceb_653 gd.no.is_643  rw.lg.jw_332 ha.sq.un_330
  0x16000a05, 0x1a2d0a07, 0x2513640c, 0x1a28355a,   // pt.hr.un_330 pt.sk.tl_432  lg.et.eu_543 zu.sw.tl_553
  0x08022a02, 0x64552107, 0x323f030d, 0x03003204,   // mt.da.no_222 jw.rw.lg_432  nl.af.bs_554 bs.nl.un_320
  // [2410]
  0x190b07a0, 0x3f0413a4, 0x321613a4, 0x04163f04,   // it.es.gl_322 et.fi.af_433  et.hr.bs_433 af.hr.fi_332
  0x2a00070e, 0x08006412, 0x05524aee, 0x0704100d,   // it.mt.un_550 lg.no.un_640  yo.ha.fr_422 be.ru.bg_554
  0x1c000d0d, 0x04001c04, 0x180827ee, 0x17005202,   // ne.mr.un_540 id.fi.un_320  gd.no.ga_422 ha.sr.un_220
  0x31001a02, 0x0725130c, 0x25006807, 0x041f01a4,   // tl.az.un_220 et.eu.it_543  ig.eu.un_420 en.cy.fi_433
  // [2420]
  0x526b1a04, 0x0e130408, 0x3f001318, 0x21001807,   // tl.ceb.ha_332 fi.et.is_443  et.af.un_740 ar.fa.un_420
  0x28001e1a, 0x0e001802, 0x12091602, 0x21641c0c,   // ms.sw.un_760 ga.is.un_220  hr.pl.hu_222 id.lg.jw_543
  0x0a1710ec, 0x2b3f21a0, 0x3500061a, 0x0c0f13a4,   // be.sr.mk_644 jw.af.vi_322  de.zu.un_760 et.lv.sv_433
  0x074a10a7, 0x645568ac, 0x0b190a55, 0x19002113,   // lt.yo.it_532 ig.rw.lg_632  pt.gl.es_442 jw.gl.un_650
  // [2430]
  0x641e1ca9, 0x032552a0, 0x08040705, 0x060e0c60,   // id.ms.lg_544 ha.eu.nl_322  bg.ru.uk_333 sv.is.de_664
  0x1a1c6ba9, 0x1a116b07, 0x23251902, 0x521e1c07,   // ceb.id.tl_544 ceb.ro.tl_432  gl.eu.ca_222 id.ms.ha_432
  0x2752280c, 0x64171aa4, 0x033f13a0, 0x17041108,   // sw.ha.gd_543 tl.sr.lg_433  et.af.nl_322 ro.ru.sr_443
  0x030701a4, 0x52250607, 0x17321613, 0x0d000412,   // en.it.nl_433 de.eu.ha_432  hr.bs.sr_665 fi.cs.un_640
  // [2440]
  0x11001034, 0x1c000d09, 0x0400070d, 0x08070a02,   // be.ro.un_A80 ne.mr.un_440  bg.ru.un_540 mk.bg.uk_222
  0x25072a14, 0x08020ea4, 0x04282aee, 0x036b21ee,   // mt.it.eu_666 is.da.no_433  mt.sw.fi_422 jw.ceb.nl_422
  0x06001108, 0x13001107, 0x1a101c07, 0x18006e07,   // ro.de.un_430 ro.et.un_420  id.lt.tl_432 hmn.ga.un_420
  0x060c0708, 0x1c210f0c, 0x21121aa9, 0x6b1f07a4,   // it.sv.de_443 lv.jw.id_543  tl.hu.jw_544 it.cy.ceb_433
  // [2450]
  0x17130ea7, 0x31001319, 0x12002118, 0x0c002504,   // is.et.sr_532 et.az.un_750  fa.ur.un_740 eu.sv.un_320
  0x2d0d29a0, 0x0c000220, 0x1f0c64a4, 0x040a0809,   // sl.cs.sk_322 da.sv.un_850  lg.sv.cy_433 uk.mk.ru_444
  0x1c311ea9, 0x0e000c1a, 0x07006412, 0x1c13010c,   // ms.az.id_544 sv.is.un_760  lg.it.un_640 en.et.id_543
  0x040a11ac, 0x11070a14, 0x12001818, 0x27001c04,   // ro.mk.ru_632 mk.bg.ro_666  ar.ur.un_740 id.gd.un_320
  // [2460]
  0x291325a4, 0x08000e13, 0x2a011fec, 0x032923ad,   // eu.et.sl_433 is.no.un_650  cy.en.mt_644 ca.sl.nl_643
  0x133f0312, 0x2a050707, 0x0a111705, 0x062a0307,   // nl.af.et_654 it.fr.mt_432  sr.ro.mk_333 nl.mt.de_432
  0x03003f23, 0x01521eee, 0x0000082d, 0x0a041709,   // af.nl.un_880 ms.ha.en_422  uk.un.un_A00 sr.ru.mk_444
  0x06001e1a, 0x06006421, 0x553f35a7, 0x12001a02,   // ms.de.un_760 lg.de.un_860  zu.af.rw_532 tl.hu.un_220
  // [2470]
  0x09003b19, 0x13000a07, 0x08020cee, 0x01093fee,   // so.pl.un_750 pt.et.un_420  sv.da.no_422 af.pl.en_422
  0x08000208, 0x0c070107, 0x2a3f35ee, 0x253b050c,   // da.no.un_430 en.it.sv_432  zu.af.mt_422 fr.so.eu_543
  0x130a08a0, 0x033f08ad, 0x19000a0c, 0x0a002807,   // no.pt.et_322 no.af.nl_643  pt.gl.un_530 sw.pt.un_420
  0x6b2928a9, 0x0900121a, 0x19000b11, 0x13002b11,   // sw.sl.ceb_544 hu.pl.un_760  es.gl.un_630 vi.et.un_630
  // [2480]
  0x5200350d, 0x55180508, 0x133b0112, 0x0b001107,   // zu.ha.un_540 fr.ga.rw_443  en.so.et_654 ro.es.un_420
  0x1f001c0d, 0x06093512, 0x6800641a, 0x03283fa7,   // id.cy.un_540 zu.pl.de_654  lg.ig.un_760 af.sw.nl_532
  0x556b1a12, 0x0a07170e, 0x03002a04, 0x6b5520a4,   // tl.ceb.rw_654 sr.bg.mk_555  mt.nl.un_320 sq.rw.ceb_433
  0x27283207, 0x033f1308, 0x11001604, 0x10041704,   // bs.sw.gd_432 et.af.nl_443  hr.ro.un_320 sr.ru.be_332
  // [2490]
  0x1c0d1314, 0x174a1ca0, 0x061132a4, 0x06122514,   // bh.ne.mr_666 id.yo.sr_322  bs.ro.de_433 eu.hu.de_666
  0x21282da7, 0x6b000c04, 0x55351c02, 0x13006404,   // sk.sw.jw_532 sv.ceb.un_320  id.zu.rw_222 lg.et.un_320
  0x352852a4, 0x04281807, 0x1c00130d, 0x06000f19,   // ha.sw.zu_433 ga.sw.fi_432  bh.mr.un_540 lv.de.un_750
  0x20642807, 0x09002a19, 0x311255ec, 0x64001c07,   // sw.lg.sq_432 mt.pl.un_750  rw.hu.az_644 id.lg.un_420
  // [24a0]
  0x3f000e07, 0x0400130c, 0x130409a4, 0x12000919,   // is.af.un_420 et.fi.un_530  pl.fi.et_433 pl.hu.un_750
  0x06040112, 0x2a045208, 0x08110708, 0x2b001704,   // en.fi.de_654 ha.fi.mt_443  bg.ro.uk_443 sr.vi.un_320
  0x19271811, 0x190a18ec, 0x2a0604a4, 0x03000419,   // ga.gd.gl_653 ga.pt.gl_644  fi.de.mt_433 fi.nl.un_750
  0x0807100d, 0x042a0808, 0x17000a20, 0x253f0304,   // be.bg.uk_554 no.mt.fi_443  mk.sr.un_850 nl.af.eu_332
  // [24b0]
  0x1c2025a7, 0x05060707, 0x040717a4, 0x043b0e07,   // eu.sq.id_532 it.de.fr_432  sr.bg.ru_433 is.so.fi_432
  0x10552104, 0x0d172d07, 0x04000814, 0x090c0da7,   // jw.rw.lt_332 sk.sr.cs_432  uk.ru.un_660 cs.sv.pl_532
  0x0f090613, 0x64003522, 0x1f080204, 0x04006405,   // de.pl.lv_665 zu.lg.un_870  da.no.cy_332 lg.fi.un_330
  0x2d0d2909, 0x0410110c, 0x2a00030c, 0x2b001214,   // sl.cs.sk_444 ro.be.ru_543  nl.mt.un_530 hu.vi.un_660
  // [24c0]
  0x040102a0, 0x1700081b, 0x17001905, 0x091c130b,   // da.en.fi_322 uk.sr.un_770  gl.sr.un_330 bh.mr.hi_542
  0x040a11ee, 0x08042a12, 0x040910a4, 0x0400070c,   // ro.mk.ru_422 mt.fi.no_654  lt.pl.fi_433 it.fi.un_530
  0x162d0d04, 0x6408040c, 0x2d001705, 0x2855520c,   // cs.sk.hr_332 fi.no.lg_543  sr.sk.un_330 ha.rw.sw_543
  0x1c3b1e0c, 0x20122a0c, 0x2312050c, 0x23072504,   // ms.so.id_543 mt.hu.sq_543  fr.hu.ca_543 eu.it.ca_332
  // [24d0]
  0x0e006b04, 0x0e006b07, 0x11052307, 0x1e121c0c,   // ceb.is.un_320 ceb.is.un_420  ca.fr.ro_432 id.hu.ms_543
  0x6455280c, 0x322752ee, 0x0b251f0c, 0x0f101ea4,   // sw.rw.lg_543 ha.gd.bs_422  cy.eu.es_543 ms.lt.lv_433
  0x23002709, 0x0813020c, 0x0400132b, 0x3b005223,   // gd.ca.un_440 da.et.no_543  et.fi.un_980 ha.so.un_880
  0x04071705, 0x170a0707, 0x27001904, 0x23190a04,   // sr.bg.ru_333 bg.mk.sr_432  gl.gd.un_320 pt.gl.ca_332
  // [24e0]
  0x07100813, 0x3500281b, 0x27001a08, 0x182701a7,   // uk.be.bg_665 sw.zu.un_770  tl.gd.un_430 en.gd.ga_532
  0x19120baf, 0x6b3f0307, 0x1100132a, 0x091f350c,   // es.hu.gl_655 nl.af.ceb_432  et.ro.un_970 zu.cy.pl_543
  0x0600350e, 0x2a2835ad, 0x55182708, 0x521e1cad,   // zu.de.un_550 zu.sw.mt_643  gd.ga.rw_443 id.ms.ha_643
  0x4a001219, 0x0b0107a0, 0x1b1a640c, 0x29162da0,   // hu.yo.un_750 it.en.es_322  lg.tl.tr_543 sk.hr.sl_322
  // [24f0]
  0x55121f12, 0x08000e1a, 0x6e321604, 0x2d0d2902,   // cy.hu.rw_654 is.no.un_760  hr.bs.hmn_332 sl.cs.sk_222
  0x1200350d, 0x0700110d, 0x64041305, 0x0b0a23a4,   // zu.hu.un_540 ro.bg.un_540  et.fi.lg_333 ca.pt.es_433
  0x091c1e11, 0x1e1f0fee, 0x09110a0c, 0x3200161a,   // ms.id.pl_653 lv.cy.ms_422  pt.ro.pl_543 hr.bs.un_760
  0x0c3f02a0, 0x320625a7, 0x23000b02, 0x070a04a7,   // da.af.sv_322 eu.de.bs_532  es.ca.un_220 ru.mk.bg_532
  // [2500]
  0x01251fee, 0x20001113, 0x120c1ea4, 0x1b006804,   // cy.eu.en_422 ro.sq.un_650  ms.sv.hu_433 ig.tr.un_320
  0x190b12ec, 0x20030807, 0x2111070c, 0x051201a4,   // hu.es.gl_644 no.nl.sq_432  it.ro.jw_543 en.hu.fr_433
  0x0f321702, 0x06080f04, 0x10120911, 0x050401a4,   // sr.bs.lv_222 lv.no.de_332  pl.hu.lt_653 en.fi.fr_433
  0x07552807, 0x17003207, 0x0e00050e, 0x1b12030c,   // sw.rw.it_432 bs.sr.un_420  fr.is.un_550 nl.hu.tr_543
  // [2510]
  0x25003f04, 0x130c2aa7, 0x172a0808, 0x3101050c,   // af.eu.un_320 mt.sv.et_532  no.mt.sr_443 fr.en.az_543
  0x21171604, 0x1300210d, 0x08120208, 0x354a6805,   // hr.sr.jw_332 jw.et.un_540  da.hu.no_443 ig.yo.zu_333
  0x1c000d07, 0x53001907, 0x0c231004, 0x0c000108,   // ne.mr.un_420 gl.ht.un_420  lt.ca.sv_332 en.sv.un_430
  0x0700051b, 0x03003f18, 0x05193f08, 0x0105190c,   // fr.it.un_770 af.nl.un_740  af.gl.fr_443 gl.fr.en_543
  // [2520]
  0x12002a0d, 0x052301ee, 0x09110613, 0x17080aa4,   // mt.hu.un_540 en.ca.fr_422  de.ro.pl_665 mk.uk.sr_433
  0x12053107, 0x09200f08, 0x02093202, 0x05000113,   // az.fr.hu_432 lv.sq.pl_443  bs.pl.da_222 en.fr.un_650
  0x101b28a0, 0x091f68a7, 0x2a000108, 0x20132107,   // sw.tr.lt_322 ig.cy.pl_532  en.mt.un_430 jw.et.sq_432
  0x27351aa0, 0x045319ee, 0x64003523, 0x284a0a12,   // tl.zu.gd_322 gl.ht.fi_422  zu.lg.un_880 pt.yo.sw_654
  // [2530]
  0x050801a4, 0x311b5511, 0x0c1827a7, 0x13212512,   // en.no.fr_433 rw.tr.az_653  gd.ga.sv_532 eu.jw.et_654
  0x010d1904, 0x09005214, 0x011827a4, 0x08001f08,   // gl.cs.en_332 ha.pl.un_660  gd.ga.en_433 cy.no.un_430
  0x21061fad, 0x3f000323, 0x05005305, 0x531e1704,   // cy.de.jw_643 nl.af.un_880  ht.fr.un_330 sr.ms.ht_332
  0x683564a9, 0x28036402, 0x030b3f5a, 0x3b5335ee,   // lg.zu.ig_544 lg.nl.sw_222  af.es.nl_553 zu.ht.so_422
  // [2540]
  0x6452090c, 0x52000918, 0x55006421, 0x29002004,   // pl.ha.lg_543 pl.ha.un_740  lg.rw.un_860 sq.sl.un_320
  0x282a21ec, 0x285564ac, 0x230507a4, 0x281a6b04,   // jw.mt.sw_644 lg.rw.sw_632  it.fr.ca_433 ceb.tl.sw_332
  0x6b1a1b0c, 0x3b00270e, 0x1b5228af, 0x055301a4,   // tr.tl.ceb_543 gd.so.un_550  sw.ha.tr_655 en.ht.fr_433
  0x645528a4, 0x0900640e, 0x2a281ea0, 0x310c28a4,   // sw.rw.lg_433 lg.pl.un_550  ms.sw.mt_322 sw.sv.az_433
  // [2550]
  0x02002714, 0x1a52350c, 0x080c1f0c, 0x28352a13,   // gd.da.un_660 zu.ha.tl_543  cy.sv.no_543 mt.zu.sw_665
  0x09003514, 0x1a553b11, 0x04005223, 0x2500550d,   // zu.pl.un_660 so.rw.tl_653  ha.fi.un_880 rw.eu.un_540
  0x1b1c52ad, 0x09005213, 0x1c2135a7, 0x1e3b0ca0,   // ha.id.tr_643 ha.pl.un_650  zu.jw.id_532 sv.so.ms_322
  0x2852090b, 0x6e641a12, 0x17001108, 0x09521ca4,   // pl.ha.sw_542 tl.lg.hmn_654  ro.sr.un_430 id.ha.pl_433
  // [2560]
  0x216b550c, 0x130408a0, 0x2d0d25a0, 0x110a1313,   // rw.ceb.jw_543 no.fi.et_322  eu.cs.sk_322 et.pt.ro_665
  0x0b001907, 0x13174aa4, 0x0c00021b, 0x28001e22,   // gl.es.un_420 yo.sr.et_433  da.sv.un_770 ms.sw.un_870
  0x1f112713, 0x1a001f07, 0x55281ca0, 0x13552108,   // gd.ro.cy_665 cy.tl.un_420  id.sw.rw_322 jw.rw.et_443
  0x0b00190d, 0x0c000523, 0x13001221, 0x25281ca0,   // gl.es.un_540 fr.sv.un_880  hu.et.un_860 id.sw.eu_322
  // [2570]
  0x200b07a4, 0x04000a09, 0x2a281e07, 0x1f055305,   // it.es.sq_433 mk.ru.un_440  ms.sw.mt_432 ht.fr.cy_333
  0x1b0553a7, 0x07250aad, 0x040a11a6, 0x29002d14,   // ht.fr.tr_532 pt.eu.it_643  ro.mk.ru_521 sk.sl.un_660
  0x0c000e13, 0x32110da0, 0x100721a0, 0x520507a7,   // is.sv.un_650 cs.ro.bs_322  jw.it.lt_322 it.fr.ha_532
  0x3b640413, 0x1b000c12, 0x081711a0, 0x0f201155,   // fi.lg.so_665 sv.tr.un_640  ro.sr.uk_322 ro.sq.lv_442
  // [2580]
  0x3f000302, 0x0d171ead, 0x4a2d0d60, 0x04643ba7,   // nl.af.un_220 ms.sr.cs_643  cs.sk.yo_664 so.lg.fi_532
  0x21641a02, 0x10000f19, 0x09181fad, 0x0413255a,   // tl.lg.jw_222 lv.lt.un_750  cy.ga.pl_643 eu.et.fi_553
  0x00002924, 0x08130eee, 0x05002321, 0x1b0d350c,   // sl.un.un_900 is.et.no_422  ca.fr.un_860 zu.cs.tr_543
  0x1a003b19, 0x05001222, 0x533105a9, 0x1b096ea0,   // so.tl.un_750 hu.fr.un_870  fr.az.ht_544 hmn.pl.tr_322
  // [2590]
  0x08100aa9, 0x190b0709, 0x043b680b, 0x12000508,   // mk.be.uk_544 it.es.gl_444  ig.so.fi_542 fr.hu.un_430
  0x1c000908, 0x0b006e04, 0x121b310c, 0x19000119,   // hi.mr.un_430 hmn.es.un_320  az.tr.hu_543 en.gl.un_750
  0x52005308, 0x100708a4, 0x11040808, 0x01003513,   // ht.ha.un_430 uk.bg.be_433  uk.ru.ro_443 zu.en.un_650
  0x0b0512ad, 0x013f0504, 0x01001c08, 0x23120511,   // hu.fr.es_643 fr.af.en_332  id.en.un_430 fr.hu.ca_653
  // [25a0]
  0x0a006e0b, 0x0b000a21, 0x5305010c, 0x230b0504,   // hmn.pt.un_520 pt.es.un_860  en.fr.ht_543 fr.es.ca_332
  0x1707100c, 0x043b640c, 0x283519ee, 0x64133b0c,   // be.bg.sr_543 lg.so.fi_543  gl.zu.sw_422 so.et.lg_543
  0x0b1219ee, 0x0e686b12, 0x524a3bee, 0x110a1712,   // gl.hu.es_422 ceb.ig.is_654  so.yo.ha_422 sr.mk.ro_654
  0x1300040d, 0x190a3f05, 0x092d02ee, 0x642055a0,   // fi.et.un_540 af.pt.gl_333  da.sk.pl_422 rw.sq.lg_322
  // [25b0]
  0x116418ad, 0x13013ba0, 0x192d1ca0, 0x320829a0,   // ga.lg.ro_643 so.en.et_322  id.sk.gl_322 sl.no.bs_322
  0x0500122c, 0x13005513, 0x0a006e0c, 0x03050111,   // hu.fr.un_990 rw.et.un_650  hmn.pt.un_530 en.fr.nl_653
  0x0a006e08, 0x05001219, 0x1a1e1c04, 0x202925a7,   // hmn.pt.un_430 hu.fr.un_750  id.ms.tl_332 eu.sl.sq_532
  0x070a2513, 0x4a00251a, 0x0b2107ee, 0x2700250e,   // eu.pt.it_665 eu.yo.un_760  it.jw.es_422 eu.gd.un_550
  // [25c0]
  0x532a0704, 0x6b1a2508, 0x640a19a4, 0x072a20a4,   // it.mt.ht_332 eu.tl.ceb_443  gl.pt.lg_433 sq.mt.it_433
  0x0717100e, 0x07000e13, 0x11050ea4, 0x013b3f08,   // be.sr.bg_555 is.it.un_650  is.fr.ro_433 af.so.en_443
  0x060c045a, 0x2a190a08, 0x356828a4, 0x28046e07,   // fi.sv.de_553 pt.gl.mt_443  sw.ig.zu_433 hmn.fi.sw_432
  0x32001308, 0x0e130c04, 0x32172aa4, 0x53000107,   // et.bs.un_430 sv.et.is_332  mt.sr.bs_433 en.ht.un_420
  // [25d0]
  0x1a006b20, 0x0b35130c, 0x1e1c20af, 0x28645512,   // ceb.tl.un_850 et.zu.es_543  sq.id.ms_655 rw.lg.sw_654
  0x25072a08, 0x3b006414, 0x10000f0e, 0x64551ca0,   // mt.it.eu_443 lg.so.un_660  lv.lt.un_550 id.rw.lg_322
  0x3f020ca9, 0x0a17080b, 0x19000804, 0x311b2507,   // sv.da.af_544 uk.sr.mk_542  no.gl.un_320 eu.tr.az_432
  0x10000b05, 0x17002a04, 0x160103ee, 0x190b21ee,   // es.lt.un_330 mt.sr.un_320  nl.en.hr_422 jw.es.gl_422
  // [25e0]
  0x1c215307, 0x25003204, 0x6432280c, 0x6b1a5312,   // ht.jw.id_432 bs.eu.un_320  sw.bs.lg_543 ht.tl.ceb_654
  0x6425550d, 0x0a0408a0, 0x1f001b0c, 0x3f0a06a0,   // rw.eu.lg_554 uk.ru.mk_322  tr.cy.un_530 de.pt.af_322
  0x19010e0c, 0x29002705, 0x322d0d0d, 0x23001908,   // is.en.gl_543 gd.sl.un_330  cs.sk.bs_554 gl.ca.un_430
  0x182311ee, 0x350e2a0d, 0x13010ead, 0x1c090d05,   // ro.ca.ga_422 mt.is.zu_554  is.en.et_643 ne.hi.mr_333
  // [25f0]
  0x06685555, 0x04001105, 0x17001005, 0x0409250d,   // rw.ig.de_442 ro.ru.un_330  be.sr.un_330 eu.pl.fi_554
  0x2a001c04, 0x04001002, 0x25352855, 0x23180eaf,   // id.mt.un_320 be.ru.un_220  sw.zu.eu_442 is.ga.ca_655
  0x0c1102a0, 0x3100522b, 0x280652a4, 0x05004a1a,   // da.ro.sv_322 ha.az.un_980  ha.de.sw_433 yo.fr.un_760
  0x55002521, 0x1107520c, 0x552a5213, 0x080a1f04,   // eu.rw.un_860 ha.it.ro_543  ha.mt.rw_665 cy.pt.no_332
  // [2600]
  0x0b182308, 0x531028a0, 0x190b0a09, 0x23121307,   // ca.ga.es_443 sw.lt.ht_322  pt.es.gl_444 et.hu.ca_432
  0x0b0a20a4, 0x250a23af, 0x0b0a11ee, 0x1a211108,   // sq.pt.es_433 ca.pt.eu_655  ro.pt.es_422 ro.jw.tl_443
  0x03013fa0, 0x3f092da4, 0x080710a4, 0x32002a05,   // af.en.nl_322 sk.pl.af_433  be.bg.uk_433 mt.bs.un_330
  0x0700171a, 0x5500640e, 0x2d3f09a9, 0x230e1907,   // sr.bg.un_760 lg.rw.un_550  pl.af.sk_544 gl.is.ca_432
  // [2610]
  0x12004a0c, 0x11200c11, 0x06002322, 0x041108af,   // yo.hu.un_530 sv.sq.ro_653  ca.de.un_870 uk.ro.ru_655
  0x68083fa4, 0x190b3f12, 0x52002823, 0x06003f18,   // af.no.ig_433 af.es.gl_654  sw.ha.un_880 af.de.un_740
  0x0b093f08, 0x11100812, 0x0b090f04, 0x12080caf,   // af.pl.es_443 uk.be.ro_654  lv.pl.es_332 sv.no.hu_655
  0x2d0d05ec, 0x182d0d1a, 0x3f002305, 0x030f0408,   // fr.cs.sk_644 cs.sk.ga_776  ca.af.un_330 fi.lv.nl_443
  // [2620]
  0x122d0d12, 0x03090613, 0x3f000f09, 0x04171105,   // cs.sk.hu_654 de.pl.nl_665  lv.af.un_440 ro.sr.ru_333
  0x010c3fa7, 0x1123070d, 0x070408ec, 0x0c1101a0,   // af.sv.en_532 it.ca.ro_554  uk.ru.bg_644 en.ro.sv_322
  0x1100101a, 0x190b060c, 0x1e1c0a09, 0x0407530c,   // be.ro.un_760 de.es.gl_543  pt.id.ms_444 ht.it.fi_543
  0x25190b04, 0x35211c55, 0x10006b18, 0x17080908,   // es.gl.eu_332 id.jw.zu_442  ceb.lt.un_740 pl.no.sr_443
  // [2630]
  0x1800270c, 0x120d2da9, 0x3b0620ad, 0x2a033f08,   // gd.ga.un_530 sk.cs.hu_544  sq.de.so_643 af.nl.mt_443
  0x0a000708, 0x1b0b3507, 0x03000513, 0x12001319,   // it.pt.un_430 zu.es.tr_432  fr.nl.un_650 et.hu.un_750
  0x2a0e64ad, 0x0a000713, 0x25002309, 0x1c5521ad,   // lg.is.mt_643 bg.mk.un_650  ca.eu.un_440 jw.rw.id_643
  0x11002321, 0x0f311b5a, 0x2700230d, 0x3b3f07a4,   // ca.ro.un_860 tr.az.lv_553  ca.gd.un_540 it.af.so_433
  // [2640]
  0x29230509, 0x27002302, 0x3f00020c, 0x1c12210d,   // fr.ca.sl_444 ca.gd.un_220  da.af.un_530 jw.hu.id_554
  0x12190a09, 0x041e1c55, 0x0500191a, 0x12190a13,   // pt.gl.hu_444 id.ms.fi_442  gl.fr.un_760 pt.gl.hu_665
  0x64005220, 0x0e0f1055, 0x06000319, 0x2d0d0fee,   // ha.lg.un_850 lt.lv.is_442  nl.de.un_750 lv.cs.sk_422
  0x031205a0, 0x090d13ee, 0x07101faf, 0x102d1ea0,   // fr.hu.nl_322 bh.ne.hi_422  cy.lt.it_655 ms.sk.lt_322
  // [2650]
  0x1e1c28af, 0x01006b04, 0x320e2d08, 0x0e001007,   // sw.id.ms_655 ceb.en.un_320  sk.is.bs_443 lt.is.un_420
  0x01002005, 0x10321605, 0x17041355, 0x190a1305,   // sq.en.un_330 hr.bs.lt_333  et.fi.sr_442 et.pt.gl_333
  0x0f08100c, 0x281e1c08, 0x5500280c, 0x556452ec,   // lt.no.lv_543 id.ms.sw_443  sw.rw.un_530 ha.lg.rw_644
  0x1a6b3f11, 0x0d006e07, 0x1a04520c, 0x53016ba9,   // af.ceb.tl_653 hmn.cs.un_420  ha.fi.tl_543 ceb.en.ht_544
  // [2660]
  0x1c04280c, 0x132a1055, 0x11080aa4, 0x3f2d1f12,   // sw.fi.id_543 lt.mt.et_442  mk.uk.ro_433 cy.sk.af_654
  0x1304050c, 0x2b050107, 0x64556ba9, 0x1f002d0e,   // fr.fi.et_543 en.fr.vi_432  ceb.rw.lg_544 sk.cy.un_550
  0x030908ec, 0x2d00061b, 0x1a133bad, 0x16006805,   // no.pl.nl_644 de.sk.un_770  so.et.tl_643 ig.hr.un_330
  0x3b000c0d, 0x35645513, 0x0a07040d, 0x08005521,   // sv.so.un_540 rw.lg.zu_665  ru.bg.mk_554 rw.no.un_860
  // [2670]
  0x1b310e0c, 0x55133b5a, 0x0a0704ad, 0x323f2da0,   // is.az.tr_543 so.et.rw_553  ru.bg.mk_643 sk.af.bs_322
  0x1a553b08, 0x041319a4, 0x28135505, 0x120e010c,   // so.rw.tl_443 gl.et.fi_433  rw.et.sw_333 en.is.hu_543
  0x07001108, 0x1f002d0c, 0x0c643b09, 0x01040e04,   // ro.bg.un_430 sk.cy.un_530  so.lg.sv_444 is.fi.en_332
  0x1000010d, 0x202d0d60, 0x0f52100c, 0x080417ee,   // en.lt.un_540 cs.sk.sq_664  lt.ha.lv_543 sr.ru.uk_422
  // [2680]
  0x0b19550c, 0x010e1008, 0x10190a13, 0x1a6b5207,   // rw.gl.es_543 lt.is.en_443  pt.gl.lt_665 ha.ceb.tl_432
  0x2521100c, 0x0a6827a4, 0x6e182711, 0x270f10af,   // lt.jw.eu_543 gd.ig.pt_433  gd.ga.hmn_653 lt.lv.gd_655
  0x01005508, 0x13683b0c, 0x08021805, 0x190a0b02,   // rw.en.un_430 so.ig.et_543  ga.da.no_333 es.pt.gl_222
  0x16193bee, 0x120c0ead, 0x0b00070c, 0x1b280909,   // so.gl.hr_422 is.sv.hu_643  it.es.un_530 pl.sw.tr_444
  // [2690]
  0x200f55a4, 0x190b0a12, 0x083f0614, 0x273128a4,   // rw.lv.sq_433 pt.es.gl_654  de.af.no_666 sw.az.gd_433
  0x3b000213, 0x3b00641b, 0x12201704, 0x55000107,   // da.so.un_650 lg.so.un_770  sr.sq.hu_332 en.rw.un_420
  0x130c3b04, 0x0c005304, 0x2a0713ee, 0x2d0d2a0e,   // so.sv.et_332 ht.sv.un_320  et.it.mt_422 mt.cs.sk_555
  0x080711a0, 0x091c1360, 0x130c3ba9, 0x64001b0b,   // ro.bg.uk_322 bh.mr.hi_664  so.sv.et_544 tr.lg.un_520
  // [26a0]
  0x0d062504, 0x553b6408, 0x2d0d12a6, 0x16005504,   // eu.de.cs_332 lg.so.rw_443  hu.cs.sk_521 rw.hr.un_320
  0x12000e1a, 0x04130f0c, 0x05000e13, 0x0e05080c,   // is.hu.un_760 lv.et.fi_543  is.fr.un_650 no.fr.is_543
  0x21041007, 0x06031812, 0x1f003b21, 0x170a10af,   // lt.fi.jw_432 ga.nl.de_654  so.cy.un_860 be.mk.sr_655
  0x1206080c, 0x070501ec, 0x011e28a7, 0x09101aa4,   // no.de.hu_543 en.fr.it_644  sw.ms.en_532 tl.lt.pl_433
  // [26b0]
  0x13005222, 0x06000322, 0x0e1304af, 0x3f3b02af,   // ha.et.un_870 nl.de.un_870  fi.et.is_655 da.so.af_655
  0x28003513, 0x2d0d32a0, 0x02040eec, 0x1a2b3507,   // zu.sw.un_650 bs.cs.sk_322  is.fi.da_644 zu.vi.tl_432
  0x1600280d, 0x0a07085a, 0x231f1213, 0x0411080b,   // sw.hr.un_540 uk.bg.mk_553  hu.cy.ca_665 uk.ro.ru_542
  0x1f3f0312, 0x040813af, 0x13000c04, 0x64041a0c,   // nl.af.cy_654 et.no.fi_655  sv.et.un_320 tl.fi.lg_543
  // [26c0]
  0x3b190a04, 0x0b351a0c, 0x21001822, 0x10003b08,   // pt.gl.so_332 tl.zu.es_543  ar.fa.un_870 so.lt.un_430
  0x4a6e6b08, 0x0704110c, 0x2b003513, 0x0f1b31af,   // ceb.hmn.yo_443 ro.ru.bg_543  zu.vi.un_650 az.tr.lv_655
  0x04000a05, 0x2d052507, 0x19000a0d, 0x2b00271b,   // mk.ru.un_330 eu.fr.sk_432  pt.gl.un_540 gd.vi.un_770
  0x312164ee, 0x06080ca0, 0x1205530c, 0x02000f14,   // lg.jw.az_422 sv.no.de_322  ht.fr.hu_543 lv.da.un_660
  // [26d0]
  0x213f0307, 0x0a001208, 0x011307a0, 0x1f033f0c,   // nl.af.jw_432 hu.pt.un_430  it.et.en_322 af.nl.cy_543
  0x1a043b12, 0x16001707, 0x520e3b60, 0x0d003504,   // so.fi.tl_654 sr.hr.un_420  so.is.ha_664 zu.cs.un_320
  0x11000c0c, 0x53133505, 0x21005508, 0x1c1e21ad,   // sv.ro.un_530 zu.et.ht_333  rw.jw.un_430 jw.ms.id_643
  0x2300270d, 0x081206a4, 0x0a071013, 0x170704ad,   // gd.ca.un_540 de.hu.no_433  be.bg.mk_665 ru.bg.sr_643
  // [26e0]
  0x2d0d1904, 0x0e060805, 0x0a00231b, 0x08063f05,   // gl.cs.sk_332 no.de.is_333  ca.pt.un_770 af.de.no_333
  0x06040355, 0x0c0f080c, 0x00003f2d, 0x23200b02,   // nl.fi.de_442 no.lv.sv_543  af.un.un_A00 es.sq.ca_222
  0x07001113, 0x3b006b08, 0x033f270e, 0x1a001318,   // ro.bg.un_650 ceb.so.un_430  gd.af.nl_555 et.tl.un_740
  0x12023f60, 0x2900030e, 0x182112a4, 0x172d0d0c,   // af.da.hu_664 nl.sl.un_550  ur.fa.ar_433 cs.sk.sr_543
  // [26f0]
  0x121b250d, 0x0b050308, 0x53000513, 0x05002502,   // eu.tr.hu_554 nl.fr.es_443  fr.ht.un_650 eu.fr.un_220
  0x08000c07, 0x180227a0, 0x23000a05, 0x12002513,   // sv.no.un_420 gd.da.ga_322  pt.ca.un_330 eu.hu.un_650
  0x07190b02, 0x250e0ca7, 0x3f000e08, 0x04003b19,   // es.gl.it_222 sv.is.eu_532  is.af.un_430 so.fi.un_750
  0x21001834, 0x043f3b0c, 0x022b010c, 0x3b553504,   // ar.fa.un_A80 so.af.fi_543  en.vi.da_543 zu.rw.so_332
  // [2700]
  0x2d120d09, 0x3b123208, 0x170710a0, 0x556b1aa7,   // cs.hu.sk_444 bs.hu.so_443  be.bg.sr_322 tl.ceb.rw_532
  0x0f000e18, 0x6b001a23, 0x0a122d11, 0x08023f09,   // is.lv.un_740 tl.ceb.un_880  sk.hu.pt_653 af.da.no_444
  0x13000920, 0x05210eb2, 0x6b351aee, 0x04022aa4,   // hi.bh.un_850 is.jw.fr_732  tl.zu.ceb_422 mt.da.fi_433
  0x31203b55, 0x3b6b1aad, 0x6400281b, 0x230d0aee,   // so.sq.az_442 tl.ceb.so_643  sw.lg.un_770 pt.cs.ca_422
  // [2710]
  0x3f031aaf, 0x09080e0c, 0x190a12ac, 0x11001a22,   // tl.nl.af_655 is.no.pl_543  hu.pt.gl_632 tl.ro.un_870
  0x09000d22, 0x0c001e08, 0x6b284a07, 0x3b1a3504,   // ne.hi.un_870 ms.sv.un_430  yo.sw.ceb_432 zu.tl.so_332
  0x1c3b520c, 0x2000320c, 0x230219a6, 0x3b2821af,   // ha.so.id_543 bs.sq.un_530  gl.da.ca_521 jw.sw.so_655
  0x553b6baf, 0x09003f08, 0x133f0307, 0x18076bee,   // ceb.so.rw_655 af.pl.un_430  nl.af.et_432 ceb.it.ga_422
  // [2720]
  0x033f0409, 0x131617ad, 0x3f133b0c, 0x13002105,   // fi.af.nl_444 sr.hr.et_643  so.et.af_543 jw.et.un_330
  0x35002721, 0x050711a4, 0x526b2da4, 0x3b1c1ea4,   // gd.zu.un_860 ro.it.fr_433  sk.ceb.ha_433 ms.id.so_433
  0x04005218, 0x35644a0c, 0x1b2b1ca7, 0x17000721,   // ha.fi.un_740 yo.lg.zu_543  id.vi.tr_532 bg.sr.un_860
  0x19000512, 0x3b321604, 0x08132504, 0x08001705,   // fr.gl.un_640 hr.bs.so_332  eu.et.no_332 sr.uk.un_330
  // [2730]
  0x21004a11, 0x0a2307a4, 0x11006e07, 0x181e0413,   // yo.jw.un_630 it.ca.pt_433  hmn.ro.un_420 fi.ms.ga_665
  0x2a002708, 0x53182707, 0x20123205, 0x05006b07,   // gd.mt.un_430 gd.ga.ht_432  bs.hu.sq_333 ceb.fr.un_420
  0x35002722, 0x05124a0c, 0x211f1107, 0x121a6b5a,   // gd.zu.un_870 yo.hu.fr_543  ro.cy.jw_432 ceb.tl.hu_553
  0x55003522, 0x55000d13, 0x23002012, 0x020535a4,   // zu.rw.un_870 cs.rw.un_650  sq.ca.un_640 zu.fr.da_433
  // [2740]
  0x1e1c2705, 0x523b6b12, 0x2d0d1314, 0x201206ad,   // gd.id.ms_333 ceb.so.ha_654  et.cs.sk_666 de.hu.sq_643
  0x10190f13, 0x0d050aa9, 0x12000507, 0x1b0a0507,   // lv.gl.lt_665 pt.fr.cs_544  fr.hu.un_420 fr.pt.tr_432
  0x35000121, 0x2b002508, 0x20005202, 0x031c5307,   // en.zu.un_860 eu.vi.un_430  ha.sq.un_220 ht.id.nl_432
  0x0d321705, 0x04094aa9, 0x033f0ca9, 0x0d1c130b,   // sr.bs.cs_333 yo.pl.fi_544  sv.af.nl_544 bh.mr.ne_542
  // [2750]
  0x3b0b35a4, 0x1a006804, 0x3217165a, 0x640a350c,   // zu.es.so_433 ig.tl.un_320  hr.sr.bs_553 zu.pt.lg_543
  0x1a056ba7, 0x0b0a1909, 0x52003511, 0x1e1c010c,   // ceb.fr.tl_532 gl.pt.es_444  zu.ha.un_630 en.id.ms_543
  0x23044aaf, 0x122d0d1b, 0x1b215308, 0x351e1c0e,   // yo.fi.ca_655 cs.sk.hu_777  ht.jw.tr_443 id.ms.zu_555
  0x13003b20, 0x64283bec, 0x190a0ba4, 0x3b002821,   // so.et.un_850 so.sw.lg_644  es.pt.gl_433 sw.so.un_860
  // [2760]
  0x53643513, 0x0a00230d, 0x0b2b19a0, 0x353b32a0,   // zu.lg.ht_665 ca.pt.un_540  gl.vi.es_322 bs.so.zu_322
  0x0b0a12b2, 0x3b2152ee, 0x2b4a64ad, 0x3500281a,   // hu.pt.es_732 ha.jw.so_422  lg.yo.vi_643 sw.zu.un_760
  0x041011a7, 0x190b0aa9, 0x3b006407, 0x07000a0c,   // ro.be.ru_532 pt.es.gl_544  lg.so.un_420 pt.it.un_530
  0x053b1c04, 0x2a001e02, 0x1e0728a0, 0x64002804,   // id.so.fr_332 ms.mt.un_220  sw.it.ms_322 sw.lg.un_320
  // [2770]
  0x1c000904, 0x25556b0c, 0x04001709, 0x0b1a3b12,   // hi.mr.un_320 ceb.rw.eu_543  sr.ru.un_440 so.tl.es_654
  0x1c130913, 0x190b110e, 0x1c000913, 0x23190a08,   // hi.bh.mr_665 ro.es.gl_555  hi.mr.un_650 pt.gl.ca_443
  0x6400351a, 0x21001235, 0x2a5268ad, 0x13002a1b,   // zu.lg.un_760 ur.fa.un_A90  ig.ha.mt_643 mt.et.un_770
  0x3b003507, 0x171664a0, 0x0c001314, 0x0e3b05ad,   // zu.so.un_420 lg.hr.sr_322  et.sv.un_660 fr.so.is_643
  // [2780]
  0x03000212, 0x116420a4, 0x64001904, 0x0c083fa0,   // da.nl.un_640 sq.lg.ro_433  gl.lg.un_320 af.no.sv_322
  0x3b6428ec, 0x643b3fa9, 0x00002d03, 0x13250204,   // sw.lg.so_644 af.so.lg_544  sk.un.un_300 da.eu.et_332
  0x0c0f1014, 0x08071008, 0x1c091311, 0x21001c19,   // lt.lv.sv_666 be.bg.uk_443  bh.hi.mr_653 id.jw.un_750
  0x0e0206a4, 0x050716a0, 0x1000290c, 0x100b4a55,   // de.da.is_433 hr.it.fr_322  sl.lt.un_530 yo.es.lt_442
  // [2790]
  0x0a190b55, 0x0800040c, 0x0a0b2908, 0x06002104,   // es.gl.pt_442 ru.uk.un_530  sl.es.pt_443 jw.de.un_320
  0x0802130c, 0x1c211ea7, 0x3f002a04, 0x19000b29,   // et.da.no_543 ms.jw.id_532  mt.af.un_320 es.gl.un_960
  0x104a2913, 0x0c0b200c, 0x0a1017ec, 0x25121fa7,   // sl.yo.lt_665 sq.es.sv_543  sr.be.mk_644 cy.hu.eu_532
  0x10000a21, 0x29104a07, 0x08170405, 0x07006b12,   // mk.be.un_860 yo.lt.sl_432  ru.sr.uk_333 ceb.it.un_640
  // [27a0]
  0x10041aa4, 0x190b0a02, 0x21282011, 0x3f091ca0,   // tl.fi.lt_433 pt.es.gl_222  sq.sw.jw_653 id.pl.af_322
  0x281327a0, 0x18042707, 0x0600520e, 0x190b05a4,   // gd.et.sw_322 gd.fi.ga_432  ha.de.un_550 fr.es.gl_433
  0x09001904, 0x01050da0, 0x10001904, 0x31042505,   // gl.pl.un_320 cs.fr.en_322  gl.lt.un_320 eu.fi.az_333
  0x3b2820a0, 0x11232704, 0x213b2812, 0x0d0913ee,   // sq.sw.so_322 gd.ca.ro_332  sw.so.jw_654 bh.hi.ne_422
  // [27b0]
  0x32090511, 0x211029a4, 0x29000a13, 0x1e1c21a6,   // fr.pl.bs_653 sl.lt.jw_433  pt.sl.un_650 jw.id.ms_521
  0x294a0b07, 0x32291602, 0x05000a12, 0x3b1a21a4,   // es.yo.sl_432 hr.sl.bs_222  pt.fr.un_640 jw.tl.so_433
  0x0a000718, 0x20351ea0, 0x100811a0, 0x6b131a08,   // bg.mk.un_740 ms.zu.sq_322  ro.uk.be_322 tl.et.ceb_443
  0x091c13a7, 0x191009a7, 0x04001212, 0x1b003519,   // bh.mr.hi_532 pl.lt.gl_532  hu.fi.un_640 zu.tr.un_750
  // [27c0]
  0x023b2155, 0x1a352807, 0x32522907, 0x08002722,   // jw.so.da_442 sw.zu.tl_432  sl.ha.bs_432 gd.no.un_870
  0x0a000509, 0x21000518, 0x040127a0, 0x2164280d,   // fr.pt.un_440 fr.jw.un_740  gd.en.fi_322 sw.lg.jw_554
  0x3b002109, 0x1f00011a, 0x162932a7, 0x643528ad,   // jw.so.un_440 en.cy.un_760  bs.sl.hr_532 sw.zu.lg_643
  0x0f01070c, 0x07001b04, 0x64283508, 0x13000d1b,   // it.en.lv_543 tr.it.un_320  zu.sw.lg_443 ne.bh.un_770
  // [27d0]
  0x0c3f2507, 0x35526455, 0x4a53050c, 0x072501a0,   // eu.af.sv_432 lg.ha.zu_442  fr.ht.yo_543 en.eu.it_322
  0x070a170c, 0x0900250c, 0x0a1710a7, 0x0413100e,   // sr.mk.bg_543 eu.pl.un_530  be.sr.mk_532 lt.et.fi_555
  0x0800040e, 0x050625ad, 0x160d2da4, 0x1a6428ad,   // ru.uk.un_550 eu.de.fr_643  sk.cs.hr_433 sw.lg.tl_643
  0x1a00281a, 0x080a07ad, 0x1200010c, 0x17002702,   // sw.tl.un_760 bg.mk.uk_643  en.hu.un_530 gd.sr.un_220
  // [27e0]
  0x3b003519, 0x19070b12, 0x292d1602, 0x123b21a7,   // zu.so.un_750 es.it.gl_654  hr.sk.sl_222 jw.so.hu_532
  0x033f06a4, 0x2a272107, 0x6b682704, 0x0f033fa0,   // de.af.nl_433 jw.gd.mt_432  gd.ig.ceb_332 af.nl.lv_322
  0x29201111, 0x16292aee, 0x351a2708, 0x526853a0,   // ro.sq.sl_653 mt.sl.hr_422  gd.tl.zu_443 ht.ig.ha_322
  0x130d0913, 0x2000251a, 0x0400070e, 0x1b001114,   // hi.ne.bh_665 eu.sq.un_760  bg.ru.un_550 ro.tr.un_660
  // [27f0]
  0x252a04af, 0x10090408, 0x6e00060d, 0x32000d05,   // fi.mt.eu_655 fi.pl.lt_443  de.hmn.un_540 cs.bs.un_330
  0x17001118, 0x13001902, 0x0e1304a4, 0x3b000205,   // ro.sr.un_740 gl.et.un_220  fi.et.is_433 da.so.un_330
  0x2a000c04, 0x100f1602, 0x1f20275a, 0x091c0d5a,   // sv.mt.un_320 hr.lv.lt_222  gd.sq.cy_553 ne.mr.hi_553
  0x041e1cad, 0x28553505, 0x6e0e0ba0, 0x21040ca0,   // id.ms.fi_643 zu.rw.sw_333  es.is.hmn_322 sv.fi.jw_322

  // [2800]
  0x321729a4, 0x53001902, 0x0c3f0204, 0x17000d07,   // sl.sr.bs_433 gl.ht.un_220  da.af.sv_332 cs.sr.un_420
  0x210e1211, 0x20292a60, 0x13041b55, 0x132029ad,   // hu.is.jw_653 mt.sl.sq_664  tr.fi.et_442 sl.sq.et_643
  0x04000104, 0x2904530c, 0x4a00522a, 0x011b6ba0,   // en.fi.un_320 ht.fi.sl_543  ha.yo.un_970 ceb.tr.en_322
  0x091f0405, 0x043b1bac, 0x25201c05, 0x0d001012,   // fi.cy.pl_333 tr.so.fi_632  id.sq.eu_333 lt.cs.un_640
  // [2810]
  0x3f250ba4, 0x08001604, 0x2a070caf, 0x01000d19,   // es.eu.af_433 hr.no.un_320  sv.it.mt_655 cs.en.un_750
  0x191a0a0d, 0x04064aa0, 0x190b07af, 0x080a2705,   // pt.tl.gl_554 yo.de.fi_322  it.es.gl_655 gd.pt.no_333
  0x1c321605, 0x3b1b0e05, 0x254a3ba4, 0x08070ba0,   // hr.bs.id_333 is.tr.so_333  so.yo.eu_433 es.it.no_322
  0x0400250e, 0x29051f0b, 0x011b3ba4, 0x06001f14,   // eu.fi.un_550 cy.fr.sl_542  so.tr.en_433 cy.de.un_660
  // [2820]
  0x03004a1a, 0x01001f0c, 0x1908100c, 0x083502a4,   // yo.nl.un_760 cy.en.un_530  lt.no.gl_543 da.zu.no_433
  0x0b0a35ee, 0x2d0d12ec, 0x20523208, 0x120d0e07,   // zu.pt.es_422 hu.cs.sk_644  bs.ha.sq_443 is.cs.hu_432
  0x00003101, 0x070804ad, 0x040a170d, 0x53071111,   // az.un.un_200 ru.uk.bg_643  sr.mk.ru_554 ro.it.ht_653
  0x3f000320, 0x07002507, 0x03005313, 0x6b00010c,   // nl.af.un_850 eu.it.un_420  ht.nl.un_650 en.ceb.un_530
  // [2830]
  0x3102080c, 0x190a01a9, 0x18002734, 0x3f006b04,   // no.da.az_543 en.pt.gl_544  gd.ga.un_A80 ceb.af.un_320
  0x2d290d14, 0x02001f14, 0x2500070c, 0x182527af,   // cs.sl.sk_666 cy.da.un_660  it.eu.un_530 gd.eu.ga_655
  0x11002513, 0x250a0107, 0x10001305, 0x080a07ee,   // eu.ro.un_650 en.pt.eu_432  et.lt.un_330 bg.mk.uk_422
  0x640d2d07, 0x0d530507, 0x64351fee, 0x170a11a6,   // sk.cs.lg_432 fr.ht.cs_432  cy.zu.lg_422 ro.mk.sr_521
  // [2840]
  0x2d0d29ec, 0x23253ba9, 0x533f030b, 0x32176409,   // sl.cs.sk_644 so.eu.ca_544  nl.af.ht_542 lg.sr.bs_444
  0x080710a0, 0x081007a0, 0x18052713, 0x29001609,   // be.bg.uk_322 bg.be.uk_322  gd.fr.ga_665 hr.sl.un_440
  0x1f100408, 0x25072a12, 0x185532a0, 0x53050d0c,   // fi.lt.cy_443 mt.it.eu_654  bs.rw.ga_322 cs.fr.ht_543
  0x1e001c0d, 0x5264040c, 0x53052912, 0x02060d08,   // id.ms.un_540 fi.lg.ha_543  sl.fr.ht_654 cs.de.da_443
  // [2850]
  0x1008040c, 0x281e1c60, 0x1f251807, 0x1c001e21,   // ru.uk.be_543 id.ms.sw_664  ga.eu.cy_432 ms.id.un_860
  0x0d000920, 0x132053ee, 0x52002a08, 0x2725180b,   // hi.ne.un_850 ht.sq.et_422  mt.ha.un_430 ga.eu.gd_542
  0x1e1c20a6, 0x0600290c, 0x182725ad, 0x3b002a19,   // sq.id.ms_521 sl.de.un_530  eu.gd.ga_643 mt.so.un_750
  0x1f001021, 0x3f0b5504, 0x23001122, 0x07010ba0,   // lt.cy.un_860 rw.es.af_332  ro.ca.un_870 es.en.it_322
  // [2860]
  0x530208ec, 0x12000621, 0x534a05ad, 0x230525a9,   // no.da.ht_644 de.hu.un_860  fr.yo.ht_643 eu.fr.ca_544
  0x282023ee, 0x08040a04, 0x203b2a11, 0x0e0406a7,   // ca.sq.sw_422 mk.ru.uk_332  mt.so.sq_653 de.fi.is_532
  0x06041313, 0x28352104, 0x3f080213, 0x3f0601a4,   // et.fi.de_665 jw.zu.sw_332  da.no.af_665 en.de.af_433
  0x08000205, 0x0d0913ac, 0x2a00131a, 0x18000104,   // da.no.un_330 bh.hi.ne_632  et.mt.un_760 en.ga.un_320
  // [2870]
  0x05002808, 0x550135a0, 0x31121b05, 0x64321704,   // sw.fr.un_430 zu.en.rw_322  tr.hu.az_333 sr.bs.lg_332
  0x6413060c, 0x0e000618, 0x1700270c, 0x0c1a6b07,   // de.et.lg_543 de.is.un_740  gd.sr.un_530 ceb.tl.sv_432
  0x19310aad, 0x281a2aa0, 0x2a000e21, 0x1704100e,   // pt.az.gl_643 mt.tl.sw_322  is.mt.un_860 be.ru.sr_555
  0x311e1c09, 0x02212a07, 0x6b0b07ad, 0x130208a7,   // id.ms.az_444 mt.jw.da_432  it.es.ceb_643 no.da.et_532
  // [2880]
  0x1c101ea0, 0x1f006b07, 0x08202aad, 0x06035307,   // ms.lt.id_322 ceb.cy.un_420  mt.sq.no_643 ht.nl.de_432
  0x35271813, 0x0d000921, 0x2b050a5a, 0x04003b23,   // ga.gd.zu_665 hi.ne.un_860  pt.fr.vi_553 so.fi.un_880
  0x1b002307, 0x13000414, 0x2a060408, 0x12000104,   // ca.tr.un_420 fi.et.un_660  fi.de.mt_443 en.hu.un_320
  0x04001308, 0x28311ba4, 0x13040609, 0x030413ad,   // et.fi.un_430 tr.az.sw_433  de.fi.et_444 et.fi.nl_643
  // [2890]
  0x0a00200c, 0x2d003202, 0x284a0a13, 0x0804100b,   // sq.pt.un_530 bs.sk.un_220  pt.yo.sw_665 be.ru.uk_542
  0x11040a0c, 0x080203a0, 0x28006b0b, 0x3f3b1a07,   // mk.ru.ro_543 nl.da.no_322  ceb.sw.un_520 tl.so.af_432
  0x05000704, 0x2000350c, 0x6b5301ec, 0x041a3b0e,   // it.fr.un_320 zu.sq.un_530  en.ht.ceb_644 so.tl.fi_555
  0x1f00061a, 0x6b270111, 0x110a2308, 0x2d102913,   // de.cy.un_760 en.gd.ceb_653  ca.pt.ro_443 sl.lt.sk_665
  // [28a0]
  0x06643f05, 0x53001f23, 0x07192312, 0x06050fee,   // af.lg.de_333 cy.ht.un_880  ca.gl.it_654 lv.fr.de_422
  0x25000702, 0x1a0768a6, 0x13002518, 0x071704a9,   // it.eu.un_220 ig.it.tl_521  eu.et.un_740 ru.sr.bg_544
  0x2500110d, 0x3f0403a4, 0x1b2a31a4, 0x070a08ec,   // ro.eu.un_540 nl.fi.af_433  az.mt.tr_433 uk.mk.bg_644
  0x3b033f12, 0x04061008, 0x133f03ec, 0x19005521,   // af.nl.so_654 lt.de.fi_443  nl.af.et_644 rw.gl.un_860
  // [28b0]
  0x05001a0d, 0x2d002008, 0x35002822, 0x53074a0c,   // tl.fr.un_540 sq.sk.un_430  sw.zu.un_870 yo.it.ht_543
  0x0a1708a4, 0x10002811, 0x060e1a07, 0x0e35520c,   // uk.sr.mk_433 sw.lt.un_630  tl.is.de_432 ha.zu.is_543
  0x55002819, 0x211352ee, 0x5500281a, 0x053f03a9,   // sw.rw.un_750 ha.et.jw_422  sw.rw.un_760 nl.af.fr_544
  0x2500010d, 0x01002102, 0x081304a4, 0x09001c14,   // en.eu.un_540 jw.en.un_220  fi.et.no_433 mr.hi.un_660
  // [28c0]
  0x13000c0c, 0x683b3104, 0x0d352d13, 0x11032dee,   // sv.et.un_530 az.so.ig_332  sk.zu.cs_665 sk.nl.ro_422
  0x17071007, 0x08000708, 0x1c0d13a6, 0x09001102,   // be.bg.sr_432 bg.uk.un_430  bh.ne.mr_521 ro.pl.un_220
  0x35000311, 0x201125a0, 0x10070a08, 0x130c06a7,   // nl.zu.un_630 eu.ro.sq_322  mk.bg.be_443 de.sv.et_532
  0x1100250b, 0x11005308, 0x190f0ba4, 0x0b2519a7,   // eu.ro.un_520 ht.ro.un_430  es.lv.gl_433 gl.eu.es_532
  // [28d0]
  0x200603ec, 0x190b0a55, 0x3217160d, 0x19111804,   // nl.de.sq_644 pt.es.gl_442  hr.sr.bs_554 ga.ro.gl_332
  0x13033f60, 0x190a0b09, 0x12000513, 0x13000d0d,   // af.nl.et_664 es.pt.gl_444  fr.hu.un_650 ne.bh.un_540
  0x04000802, 0x550464a0, 0x1100530d, 0x641955ad,   // no.fi.un_220 lg.fi.rw_322  ht.ro.un_540 rw.gl.lg_643
  0x11120107, 0x0f090760, 0x193f0308, 0x283152a9,   // en.hu.ro_432 it.pl.lv_664  nl.af.gl_443 ha.az.sw_544
  // [28e0]
  0x530413a4, 0x091c0da0, 0x25126bad, 0x0802060b,   // et.fi.ht_433 ne.mr.hi_322  ceb.hu.eu_643 de.da.no_542
  0x55531aa4, 0x68002820, 0x0a041007, 0x0b070209,   // tl.ht.rw_433 sw.ig.un_850  be.ru.mk_432 da.it.es_444
  0x53002821, 0x1e180705, 0x1b273b07, 0x2800010d,   // sw.ht.un_860 it.ga.ms_333  so.gd.tr_432 en.sw.un_540
  0x2806030c, 0x0b005508, 0x292d0da9, 0x07190bee,   // nl.de.sw_543 rw.es.un_430  cs.sk.sl_544 es.gl.it_422
  // [28f0]
  0x0900270e, 0x280627ee, 0x64080707, 0x2d096407,   // gd.pl.un_550 gd.de.sw_422  it.no.lg_432 lg.pl.sk_432
  0x4a190b08, 0x23531f0c, 0x2a081ba0, 0x03070b09,   // es.gl.yo_443 cy.ht.ca_543  tr.no.mt_322 es.it.nl_444
  0x190b23a9, 0x07081055, 0x31001e0d, 0x0a0410a0,   // ca.es.gl_544 be.uk.bg_442  ms.az.un_540 be.ru.mk_322
  0x644a5505, 0x1012110c, 0x040a21ee, 0x04000702,   // rw.yo.lg_333 ro.hu.lt_543  jw.pt.fi_422 bg.ru.un_220
  // [2900]
  0x0a284a07, 0x283503ad, 0x08041111, 0x17000413,   // yo.sw.pt_432 nl.zu.sw_643  ro.ru.uk_653 ru.sr.un_650
  0x201101a0, 0x64321fa7, 0x2d0d06af, 0x08520e12,   // en.ro.sq_322 cy.bs.lg_532  de.cs.sk_655 is.ha.no_654
  0x0b00121a, 0x2000351b, 0x00000f06, 0x0600271a,   // hu.es.un_760 zu.sq.un_770  lv.un.un_400 gd.de.un_760
  0x070601a4, 0x355206ad, 0x3f030212, 0x06010508,   // en.de.it_433 de.ha.zu_643  da.nl.af_654 fr.en.de_443
  // [2910]
  0x05102807, 0x272501a4, 0x112d0d13, 0x232719ec,   // sw.lt.fr_432 en.eu.gd_433  cs.sk.ro_665 gl.gd.ca_644
  0x21531008, 0x0e190b60, 0x11072508, 0x20001123,   // lt.ht.jw_443 es.gl.is_664  eu.it.ro_443 ro.sq.un_880
  0x112507ee, 0x3f050313, 0x0b55520c, 0x11252dad,   // it.eu.ro_422 nl.fr.af_665  ha.rw.es_543 sk.eu.ro_643
  0x290d2daf, 0x10081708, 0x01060808, 0x1c1e2560,   // sk.cs.sl_655 sr.uk.be_443  no.de.en_443 eu.ms.id_664
  // [2920]
  0x080c25ee, 0x17000104, 0x251107a9, 0x28000c0e,   // eu.sv.no_422 en.sr.un_320  it.ro.eu_544 sv.sw.un_550
  0x0c080202, 0x12000f04, 0x19001104, 0x1a350712,   // da.no.sv_222 lv.hu.un_320  ro.gl.un_320 it.zu.tl_654
  0x53001a07, 0x0e2d4a07, 0x52552809, 0x1c2123a0,   // tl.ht.un_420 yo.sk.is_432  sw.rw.ha_444 ca.jw.id_322
  0x31001b2a, 0x1100071a, 0x0b271904, 0x0f001f19,   // tr.az.un_970 it.ro.un_760  gl.gd.es_332 cy.lv.un_750
  // [2930]
  0x022108a4, 0x31122805, 0x1e1c12af, 0x1a286b07,   // no.jw.da_433 sw.hu.az_333  hu.id.ms_655 ceb.sw.tl_432
  0x070a11a0, 0x0a1708a9, 0x1a12285a, 0x07202507,   // ro.mk.bg_322 uk.sr.mk_544  sw.hu.tl_553 eu.sq.it_432
  0x07000612, 0x10000834, 0x1a286b0c, 0x2a033f5a,   // de.it.un_640 uk.be.un_A80  ceb.sw.tl_543 af.nl.mt_553
  0x0f092d12, 0x116864ee, 0x11252dee, 0x21001e0d,   // sk.pl.lv_654 lg.ig.ro_422  sk.eu.ro_422 ms.jw.un_540
  // [2940]
  0x55354a07, 0x35000808, 0x130b1aa0, 0x2800640d,   // yo.zu.rw_432 no.zu.un_430  tl.es.et_322 lg.sw.un_540
  0x31006b08, 0x0207055a, 0x21000305, 0x1f003521,   // ceb.az.un_430 fr.it.da_553  nl.jw.un_330 zu.cy.un_860
  0x35556413, 0x08553508, 0x07642a14, 0x0e18190d,   // lg.rw.zu_665 zu.rw.no_443  mt.lg.it_666 gl.ga.is_554
  0x0627180d, 0x01002420, 0x21001809, 0x033f2007,   // ga.gd.de_554 yi.iw.un_850  ar.fa.un_440 sq.af.nl_432
  // [2950]
  0x172d0d0d, 0x0c3b1ea4, 0x3f1123a0, 0x231110a4,   // cs.sk.sr_554 ms.so.sv_433  ca.ro.af_322 lt.ro.ca_433
  0x17131ca0, 0x07041760, 0x01036b04, 0x250b64a4,   // id.et.sr_322 sr.ru.bg_664  ceb.nl.en_332 lg.es.eu_433
  0x13002722, 0x182127a0, 0x190b6409, 0x051e1c0c,   // gd.et.un_870 gd.jw.ga_322  lg.es.gl_444 id.ms.fr_543
  0x0e0c04a9, 0x1b02230c, 0x53002819, 0x641c1e0c,   // fi.sv.is_544 ca.da.tr_543  sw.ht.un_750 ms.id.lg_543
  // [2960]
  0x311c0bee, 0x3b1025a9, 0x070b6455, 0x1e1c1aaf,   // es.id.az_422 eu.lt.so_544  lg.es.it_442 tl.id.ms_655
  0x1a216b05, 0x0b271812, 0x550764a4, 0x131c0913,   // ceb.jw.tl_333 ga.gd.es_654  lg.it.rw_433 hi.mr.bh_665
  0x530121a0, 0x18272813, 0x0f002722, 0x2552530c,   // jw.en.ht_322 sw.gd.ga_665  gd.lv.un_870 ht.ha.eu_543
  0x2a000e1a, 0x6b0e275a, 0x554a070c, 0x4a645207,   // is.mt.un_760 gd.is.ceb_553  it.yo.rw_543 ha.lg.yo_432
  // [2970]
  0x210103a0, 0x01532712, 0x1f3f010c, 0x05001105,   // nl.en.jw_322 gd.ht.en_654  en.af.cy_543 ro.fr.un_330
  0x3f1a6b11, 0x3f102509, 0x3f1235a0, 0x04531e07,   // ceb.tl.af_653 eu.lt.af_444  zu.hu.af_322 ms.ht.fi_432
  0x10002d14, 0x232b1ca0, 0x18001f08, 0x55524a12,   // sk.lt.un_660 id.vi.ca_322  cy.ga.un_430 yo.ha.rw_654
  0x25000307, 0x18005305, 0x27131ca0, 0x01193b04,   // nl.eu.un_420 ht.ga.un_330  id.et.gd_322 so.gl.en_332
  // [2980]
  0x27041307, 0x12311bad, 0x68000a1b, 0x0e3f0807,   // et.fi.gd_432 tr.az.hu_643  pt.ig.un_770 no.af.is_432
  0x296455a4, 0x0f13100b, 0x0c005307, 0x2d0d6ea4,   // rw.lg.sl_433 lt.et.lv_542  ht.sv.un_420 hmn.cs.sk_433
  0x0b55645a, 0x18090d0c, 0x18000418, 0x5208550c,   // lg.rw.es_553 cs.pl.ga_543  fi.ga.un_740 rw.no.ha_543
  0x28051e07, 0x64000b05, 0x32001709, 0x3f311ba9,   // ms.fr.sw_432 es.lg.un_330  sr.bs.un_440 tr.az.af_544
  // [2990]
  0x12132708, 0x17043f08, 0x101b2108, 0x211309a0,   // gd.et.hu_443 af.fi.sr_443  jw.tr.lt_443 pl.et.jw_322
  0x17001c08, 0x081711ee, 0x190a1814, 0x3200171b,   // id.sr.un_430 ro.sr.uk_422  ga.pt.gl_666 sr.bs.un_770
  0x20533511, 0x286455ec, 0x1c0720ee, 0x2d120d0e,   // zu.ht.sq_653 rw.lg.sw_644  sq.it.id_422 cs.hu.sk_555
  0x2d0f2904, 0x0a0553ee, 0x32172955, 0x1b0931a4,   // sl.lv.sk_332 ht.fr.pt_422  sl.sr.bs_442 az.pl.tr_433
  // [29a0]
  0x2d0d1f0c, 0x062d0309, 0x2305211d, 0x0d091cac,   // cy.cs.sk_543 nl.sk.de_444  jw.fr.ca_852 mr.hi.ne_632
  0x20002a09, 0x2a001212, 0x080c0204, 0x55061305,   // mt.sq.un_440 hu.mt.un_640  da.sv.no_332 et.de.rw_333
  0x13002908, 0x2d0920ec, 0x6b080cec, 0x12206e04,   // sl.et.un_430 sq.pl.sk_644  sv.no.ceb_644 hmn.sq.hu_332
  0x12052108, 0x171629a0, 0x64043bee, 0x19000a08,   // jw.fr.hu_443 sl.hr.sr_322  so.fi.lg_422 pt.gl.un_430
  // [29b0]
  0x03060508, 0x041b3107, 0x04643bad, 0x07000a21,   // fr.de.nl_443 az.tr.fi_432  so.lg.fi_643 mk.bg.un_860
  0x16002d05, 0x06003f13, 0x170708a9, 0x3b022712,   // sk.hr.un_330 af.de.un_650  uk.bg.sr_544 gd.da.so_654
  0x0c002704, 0x3b046404, 0x100417ad, 0x10000429,   // gd.sv.un_320 lg.fi.so_332  sr.ru.be_643 ru.be.un_960
  0x210518ac, 0x190a07af, 0x0c081f07, 0x03000521,   // ga.fr.jw_632 it.pt.gl_655  cy.no.sv_432 fr.nl.un_860
  // [29c0]
  0x290c08ee, 0x19001804, 0x20002a0d, 0x0c12170c,   // no.sv.sl_422 ga.gl.un_320  mt.sq.un_540 sr.hu.sv_543
  0x0f120c0c, 0x6e1720a4, 0x010c0aa6, 0x32000d08,   // sv.hu.lv_543 sq.sr.hmn_433  pt.sv.en_521 cs.bs.un_430
  0x20006e13, 0x0700290d, 0x2a0c25a0, 0x08001f02,   // hmn.sq.un_650 sl.it.un_540  eu.sv.mt_322 cy.no.un_220
  0x120c2a07, 0x13043bad, 0x08010c04, 0x21001e02,   // mt.sv.hu_432 so.fi.et_643  sv.en.no_332 ms.jw.un_220
  // [29d0]
  0x08053f08, 0x04006b04, 0x281a6407, 0x20001318,   // af.fr.no_443 ceb.fi.un_320  lg.tl.sw_432 et.sq.un_740
  0x3b131e07, 0x06190504, 0x0608020d, 0x2d0f100c,   // ms.et.so_432 fr.gl.de_332  da.no.de_554 lt.lv.sk_543
  0x08021bee, 0x1000091a, 0x07000104, 0x04002513,   // tr.da.no_422 pl.lt.un_760  en.it.un_320 eu.fi.un_650
  0x10170405, 0x3f0604a4, 0x0b006404, 0x350107ee,   // ru.sr.be_333 fi.de.af_433  lg.es.un_320 it.en.zu_422
  // [29e0]
  0x080204a9, 0x19000709, 0x27186ba7, 0x0c0802a7,   // fi.da.no_544 it.gl.un_440  ceb.ga.gd_532 da.no.sv_532
  0x08070405, 0x08110408, 0x09001f14, 0x20006e0c,   // ru.bg.uk_333 ru.ro.uk_443  cy.pl.un_660 hmn.sq.un_530
  0x1c5535a9, 0x213f23a4, 0x29001304, 0x35001302,   // zu.rw.id_544 ca.af.jw_433  et.sl.un_320 et.zu.un_220
  0x04181760, 0x06001b21, 0x040853a4, 0x1b110a07,   // sr.ar.ru_664 tr.de.un_860  ht.no.fi_433 pt.ro.tr_432
  // [29f0]
  0x520e3b07, 0x083f06a0, 0x11000a07, 0x1b003205,   // so.is.ha_432 de.af.no_322  pt.ro.un_420 bs.tr.un_330
  0x0b113107, 0x08523b12, 0x3f001f04, 0x0803130c,   // az.ro.es_432 so.ha.no_654  cy.af.un_320 et.nl.no_543
  0x0f2864ee, 0x2300251b, 0x10256404, 0x211c1eaf,   // lg.sw.lv_422 eu.ca.un_770  lg.eu.lt_332 ms.id.jw_655
  0x230511a4, 0x080601a0, 0x2d1720a6, 0x23100509,   // ro.fr.ca_433 en.de.no_322  sq.sr.sk_521 fr.lt.ca_444
  // [2a00]
  0x130412ec, 0x0f2d0908, 0x1f122713, 0x0b00641a,   // hu.fi.et_644 pl.sk.lv_443  gd.hu.cy_665 lg.es.un_760
  0x070a040c, 0x28082007, 0x29171605, 0x2300101a,   // ru.mk.bg_543 sq.no.sw_432  hr.sr.sl_333 lt.ca.un_760
  0x10230c08, 0x0e00130c, 0x03002a08, 0x2a005207,   // sv.ca.lt_443 et.is.un_530  mt.nl.un_430 ha.mt.un_420
  0x230e0aee, 0x1013230c, 0x085320ec, 0x1a006b0c,   // pt.is.ca_422 ca.et.lt_543  sq.ht.no_644 ceb.tl.un_530
  // [2a10]
  0x05230355, 0x170a1fad, 0x05012308, 0x0a00100d,   // nl.ca.fr_442 cy.pt.sr_643  ca.en.fr_443 be.mk.un_540
  0x640701a0, 0x1b136407, 0x1e1b31a0, 0x0f1b1a0c,   // en.it.lg_322 lg.et.tr_432  az.tr.ms_322 tl.tr.lv_543
  0x2300252b, 0x04005222, 0x53001104, 0x682864af,   // eu.ca.un_980 ha.fi.un_870  ro.ht.un_320 lg.sw.ig_655
  0x1f5305a4, 0x10041e05, 0x23000523, 0x12000923,   // fr.ht.cy_433 ms.fi.lt_333  fr.ca.un_880 pl.hu.un_880
  // [2a20]
  0x6b4a680c, 0x64120f0c, 0x28000f22, 0x13283b60,   // ig.yo.ceb_543 lv.hu.lg_543  lv.sw.un_870 so.sw.et_664
  0x13003b19, 0x03041308, 0x3f0523a9, 0x52282012,   // so.et.un_750 et.fi.nl_443  ca.fr.af_544 sq.sw.ha_654
  0x0a04080c, 0x2b014a0b, 0x1123050c, 0x20285508,   // uk.ru.mk_543 yo.en.vi_542  fr.ca.ro_543 rw.sw.sq_443
  0x121304ec, 0x3b060514, 0x0a0419a0, 0x01090cee,   // fi.et.hu_644 fr.de.so_666  gl.fi.pt_322 sv.pl.en_422
  // [2a30]
  0x3b00282a, 0x1e1c08a0, 0x52202808, 0x31015505,   // sw.so.un_970 no.id.ms_322  sw.sq.ha_443 rw.en.az_333
  0x35006813, 0x034a3ba4, 0x0828350c, 0x0c003b08,   // ig.zu.un_650 so.yo.nl_433  zu.sw.no_543 so.sv.un_430
  0x0d0929ad, 0x27002522, 0x04001214, 0x1c00352a,   // sl.pl.cs_643 eu.gd.un_870  hu.fi.un_660 zu.id.un_970
  0x1a0e3b08, 0x1b040eaf, 0x11050355, 0x5220550c,   // so.is.tl_443 is.fi.tr_655  nl.fr.ro_442 rw.sq.ha_543
  // [2a40]
  0x1002080c, 0x11183baf, 0x6800520e, 0x35641ca0,   // no.da.lt_543 so.ga.ro_655  ha.ig.un_550 id.lg.zu_322
  0x12184a04, 0x1101130c, 0x550f6404, 0x01130455,   // yo.ga.hu_332 et.en.ro_543  lg.lv.rw_332 fi.et.en_442
  0x03133b08, 0x10251faf, 0x3b041311, 0x31111ba9,   // so.et.nl_443 cy.eu.lt_655  et.fi.so_653 tr.ro.az_544
  0x28096bad, 0x6b356855, 0x13080e08, 0x311b4a11,   // ceb.pl.sw_643 ig.zu.ceb_442  is.no.et_443 yo.tr.az_653
  // [2a50]
  0x310764ee, 0x051b3bad, 0x52205511, 0x170229a9,   // lg.it.az_422 so.tr.fr_643  rw.sq.ha_653 sl.da.sr_544
  0x056435a6, 0x23110508, 0x100f17ee, 0x20002a07,   // zu.lg.fr_521 fr.ro.ca_443  sr.lv.lt_422 mt.sq.un_420
  0x521e1c04, 0x06311baf, 0x55642811, 0x2d096e08,   // id.ms.ha_332 tr.az.de_655  sw.lg.rw_653 hmn.pl.sk_443
  0x09003f19, 0x0d001902, 0x05126804, 0x06256405,   // af.pl.un_750 gl.cs.un_220  ig.hu.fr_332 lg.eu.de_333
  // [2a60]
  0x214a5204, 0x0e04135a, 0x3f2016a0, 0x06110704,   // ha.yo.jw_332 et.fi.is_553  hr.sq.af_322 it.ro.de_332
  0x0b121908, 0x071b110c, 0x25120412, 0x0864130c,   // gl.hu.es_443 ro.tr.it_543  fi.hu.eu_654 et.lg.no_543
  0x0f0625a4, 0x21050ea4, 0x121304a4, 0x2d00170d,   // eu.de.lv_433 is.fr.jw_433  fi.et.hu_433 sr.sk.un_540
  0x210e1c0c, 0x1f000919, 0x07060dad, 0x3b1e1c14,   // id.is.jw_543 pl.cy.un_750  cs.de.it_643 id.ms.so_666
  // [2a70]
  0x171029a9, 0x2300112a, 0x1f1c1eec, 0x030f0502,   // sl.lt.sr_544 ro.ca.un_970  ms.id.cy_644 fr.lv.nl_222
  0x28006b05, 0x3b026e11, 0x2000031a, 0x2d0f090c,   // ceb.sw.un_330 hmn.da.so_653  nl.sq.un_760 pl.lv.sk_543
  0x3f320702, 0x1200110c, 0x642855ad, 0x100419ad,   // it.bs.af_222 ro.hu.un_530  rw.sw.lg_643 gl.fi.lt_643
  0x2d001013, 0x53321708, 0x35282155, 0x0c00021f,   // lt.sk.un_650 sr.bs.ht_443  jw.sw.zu_442 da.sv.un_840
  // [2a80]
  0x13000d0e, 0x23002521, 0x6b002a05, 0x64001905,   // ne.bh.un_550 eu.ca.un_860  mt.ceb.un_330 gl.lg.un_330
  0x13002a02, 0x0b0f1012, 0x12640713, 0x12000913,   // mt.et.un_220 lt.lv.es_654  it.lg.hu_665 pl.hu.un_650
  0x190b0c05, 0x23062560, 0x640503ee, 0x4a2155a0,   // sv.es.gl_333 eu.de.ca_664  nl.fr.lg_422 rw.jw.yo_322
  0x3f006e08, 0x0b190a04, 0x12000922, 0x0e001902,   // hmn.af.un_430 pt.gl.es_332  pl.hu.un_870 gl.is.un_220
  // [2a90]
  0x09001c07, 0x1b00210c, 0x0c000208, 0x0c000619,   // mr.hi.un_420 jw.tr.un_530  da.sv.un_430 de.sv.un_750
  0x0f000d12, 0x0b25190c, 0x040811a9, 0x03010602,   // cs.lv.un_640 gl.eu.es_543  ro.uk.ru_544 de.en.nl_222
  0x2a004a05, 0x0e042aa0, 0x255228ad, 0x040e4a12,   // yo.mt.un_330 mt.fi.is_322  sw.ha.eu_643 yo.is.fi_654
  0x06000c1a, 0x2b0801ad, 0x1c00131a, 0x0c0801a7,   // sv.de.un_760 en.no.vi_643  bh.mr.un_760 en.no.sv_532
  // [2aa0]
  0x07001f0c, 0x06000111, 0x3f031f0d, 0x2000680e,   // cy.it.un_530 en.de.un_630  cy.nl.af_554 ig.sq.un_550
  0x6b113fa0, 0x5300050e, 0x3f000a04, 0x06205505,   // af.ro.ceb_322 fr.ht.un_550  pt.af.un_320 rw.sq.de_333
  0x040a11ec, 0x06003f02, 0x4a006813, 0x036e13ad,   // ro.mk.ru_644 af.de.un_220  ig.yo.un_650 et.hmn.nl_643
  0x35005521, 0x0507030b, 0x0c001f08, 0x06040c08,   // rw.zu.un_860 nl.it.fr_542  cy.sv.un_430 sv.fi.de_443
  // [2ab0]
  0x18001119, 0x2008520c, 0x1008040e, 0x2d0d1faf,   // ro.ga.un_750 ha.no.sq_543  ru.uk.be_555 cy.cs.sk_655
  0x351a6b08, 0x3216290d, 0x1800272b, 0x0c006412,   // ceb.tl.zu_443 sl.hr.bs_554  gd.ga.un_980 lg.sv.un_640
  0x232b19ee, 0x28522a0c, 0x08526407, 0x2a131ea4,   // gl.vi.ca_422 mt.ha.sw_543  lg.ha.no_432 ms.et.mt_433
  0x192a1ea0, 0x0b003521, 0x350b6ba9, 0x19020b08,   // ms.mt.gl_322 zu.es.un_860  ceb.es.zu_544 es.da.gl_443
  // [2ac0]
  0x06000c1b, 0x18252705, 0x4a55640d, 0x211c6409,   // sv.de.un_770 gd.eu.ga_333  lg.rw.yo_554 lg.id.jw_444
  0x041011ee, 0x0e000621, 0x081207a7, 0x0e642504,   // ro.be.ru_422 de.is.un_860  it.hu.no_532 eu.lg.is_332
  0x0d122d0c, 0x3b2a10a9, 0x0328350c, 0x21001c09,   // sk.hu.cs_543 lt.mt.so_544  zu.sw.nl_543 id.jw.un_440
  0x556435ec, 0x3b000a04, 0x64531008, 0x130e4a04,   // zu.lg.rw_644 pt.so.un_320  lt.ht.lg_443 yo.is.et_332
  // [2ad0]
  0x10001c08, 0x0805115a, 0x170d2d0c, 0x212a01ac,   // id.lt.un_430 ro.fr.no_553  sk.cs.sr_543 en.mt.jw_632
  0x13110ca4, 0x116435a9, 0x13211ea4, 0x25004a19,   // sv.ro.et_433 zu.lg.ro_544  ms.jw.et_433 yo.eu.un_750
  0x3f2808a0, 0x01212da0, 0x13321602, 0x01003b13,   // no.sw.af_322 sk.jw.en_322  hr.bs.et_222 so.en.un_650
  0x0c2d0d08, 0x4a002a13, 0x11000c07, 0x292d25a7,   // cs.sk.sv_443 mt.yo.un_650  sv.ro.un_420 eu.sk.sl_532
  // [2ae0]
  0x0a000b07, 0x325535a4, 0x100f3f05, 0x04001721,   // es.pt.un_420 zu.rw.bs_433  af.lv.lt_333 sr.ru.un_860
  0x3b001b19, 0x6b0f13a0, 0x013f28a0, 0x13001021,   // tr.so.un_750 et.lv.ceb_322  sw.af.en_322 lt.et.un_860
  0x311b3b12, 0x10000307, 0x020b0a0d, 0x0a0717ad,   // so.tr.az_654 nl.lt.un_420  pt.es.da_554 sr.bg.mk_643
  0x3104010c, 0x0700111a, 0x6b5305ec, 0x1c000d22,   // en.fi.az_543 ro.bg.un_760  fr.ht.ceb_644 ne.mr.un_870
  // [2af0]
  0x353b2808, 0x55002822, 0x04251008, 0x101302a7,   // sw.so.zu_443 sw.rw.un_870  lt.eu.fi_443 da.et.lt_532
  0x0e021307, 0x11001318, 0x0e000608, 0x07000412,   // et.da.is_432 et.ro.un_740  de.is.un_430 ru.bg.un_640
  0x1c00090d, 0x2b003b09, 0x3b001314, 0x03643b08,   // hi.mr.un_540 so.vi.un_440  et.so.un_660 so.lg.nl_443
  0x4a002102, 0x1a3b6b12, 0x016b6804, 0x13100fad,   // jw.yo.un_220 ceb.so.tl_654  ig.ceb.en_332 lv.lt.et_643
  // [2b00]
  0x0d00092c, 0x0f0313a6, 0x35043f04, 0x03133ba4,   // hi.ne.un_990 et.nl.lv_521  af.fi.zu_332 so.et.nl_433
  0x0c040eee, 0x1000110d, 0x32173fee, 0x0d1c0955,   // is.fi.sv_422 ro.lt.un_540  af.sr.bs_422 hi.mr.ne_442
  0x0708040d, 0x55126409, 0x08111013, 0x2d0c1fa4,   // ru.uk.bg_554 lg.hu.rw_444  be.ro.uk_665 cy.sv.sk_433
  0x3f031aee, 0x29001705, 0x02006e04, 0x2d0c09ec,   // tl.nl.af_422 sr.sl.un_330  hmn.da.un_320 pl.sv.sk_644
  // [2b10]
  0x3f3b035a, 0x0c003f04, 0x12003205, 0x2a0129a6,   // nl.so.af_553 af.sv.un_320  bs.hu.un_330 sl.en.mt_521
  0x3f07230c, 0x31130407, 0x04000c12, 0x1b005213,   // ca.it.af_543 fi.et.az_432  sv.fi.un_640 ha.tr.un_650
  0x033f13a4, 0x6b0523a0, 0x0b03050c, 0x033f1305,   // et.af.nl_433 ca.fr.ceb_322  fr.nl.es_543 et.af.nl_333
  0x6800551b, 0x3f00131a, 0x04020812, 0x0b0a190c,   // rw.ig.un_770 et.af.un_760  no.da.fi_654 gl.pt.es_543
  // [2b20]
  0x68002d05, 0x11100107, 0x2a00680e, 0x162d29a0,   // sk.ig.un_330 en.lt.ro_432  ig.mt.un_550 sl.sk.hr_322
  0x10190b13, 0x046b25a0, 0x275231a4, 0x081104ec,   // es.gl.lt_665 eu.ceb.fi_322  az.ha.gd_433 ru.ro.uk_644
  0x0d1c13ee, 0x19001008, 0x12060407, 0x2307125a,   // bh.mr.ne_422 lt.gl.un_430  fi.de.hu_432 hu.it.ca_553
  0x64006808, 0x0a0701a9, 0x0c0e08a0, 0x68004a13,   // ig.lg.un_430 en.it.pt_544  no.is.sv_322 yo.ig.un_650
  // [2b30]
  0x09002a0d, 0x2a000713, 0x18000a08, 0x08020e05,   // mt.pl.un_540 it.mt.un_650  pt.ga.un_430 is.da.no_333
  0x100b0a08, 0x2d0d060e, 0x0300020c, 0x030c06a0,   // pt.es.lt_443 de.cs.sk_555  da.nl.un_530 de.sv.nl_322
  0x13090d0e, 0x121b2512, 0x23050313, 0x133f3b07,   // ne.hi.bh_555 eu.tr.hu_654  nl.fr.ca_665 so.af.et_432
  0x2b3b010c, 0x0f041355, 0x0e2d0daf, 0x52102814,   // en.so.vi_543 et.fi.lv_442  cs.sk.is_655 sw.lt.ha_666
  // [2b40]
  0x10000a09, 0x321755af, 0x0f100807, 0x0a002314,   // pt.lt.un_440 rw.sr.bs_655  no.lt.lv_432 ca.pt.un_660
  0x521a210b, 0x0e100f0c, 0x131011a4, 0x0f00101a,   // jw.tl.ha_542 lv.lt.is_543  ro.lt.et_433 lt.lv.un_760
  0x0a1a010c, 0x190a0b0e, 0x25000f2b, 0x0c033fee,   // en.tl.pt_543 es.pt.gl_555  lv.eu.un_980 af.nl.sv_422
  0x08026ba4, 0x1e3f25ec, 0x10252313, 0x0e1a6b12,   // ceb.da.no_433 eu.af.ms_644  ca.eu.lt_665 ceb.tl.is_654
  // [2b50]
  0x2a0810a4, 0x25000f1a, 0x2b190b09, 0x271806a4,   // lt.no.mt_433 lv.eu.un_760  es.gl.vi_444 de.ga.gd_433
  0x04003f07, 0x2723010c, 0x0a000108, 0x0807110c,   // af.fi.un_420 en.ca.gd_543  en.pt.un_430 ro.bg.uk_543
  0x53211ca9, 0x6b2a01ee, 0x31202a0c, 0x3b061f09,   // id.jw.ht_544 en.mt.ceb_422  mt.sq.az_543 cy.de.so_444
  0x2864555a, 0x25646b0c, 0x062552ec, 0x3f230607,   // rw.lg.sw_553 ceb.lg.eu_543  ha.eu.de_644 de.ca.af_432
  // [2b60]
  0x521b2a0c, 0x01531e02, 0x3f230505, 0x0e06075a,   // mt.tr.ha_543 ms.ht.en_222  fr.ca.af_333 it.de.is_553
  0x1b21550c, 0x12080e13, 0x05645307, 0x1a1b64a7,   // rw.jw.tr_543 is.no.hu_665  ht.lg.fr_432 lg.tr.tl_532
  0x3f321604, 0x0c1329a4, 0x13002702, 0x21002522,   // hr.bs.af_332 sl.et.sv_433  gd.et.un_220 eu.jw.un_870
  0x131c0d12, 0x1e1c68ec, 0x091155a7, 0x21646bad,   // ne.mr.bh_654 ig.id.ms_644  rw.ro.pl_532 ceb.lg.jw_643
  // [2b70]
  0x19000b18, 0x210609a9, 0x5255640c, 0x3b13120d,   // es.gl.un_740 pl.de.jw_544  lg.rw.ha_543 hu.et.so_554
  0x0e190b5a, 0x35556407, 0x1200640e, 0x3b282507,   // es.gl.is_553 lg.rw.zu_432  lg.hu.un_550 eu.sw.so_432
  0x556b1a13, 0x55091aee, 0x0d001702, 0x01002411,   // tl.ceb.rw_665 tl.pl.rw_422  sr.cs.un_220 yi.iw.un_630
  0x122164a9, 0x23000113, 0x55521ea4, 0x12012307,   // lg.jw.hu_544 en.ca.un_650  ms.ha.rw_433 ca.en.hu_432
  // [2b80]
  0x6b230108, 0x12006404, 0x060325a7, 0x0a00041b,   // en.ca.ceb_443 lg.hu.un_320  eu.nl.de_532 ru.mk.un_770
  0x120123ee, 0x050123a7, 0x0e000613, 0x0f0410a4,   // ca.en.hu_422 ca.en.fr_532  de.is.un_650 lt.fi.lv_433
  0x110f1055, 0x1f00170c, 0x3f2d250c, 0x0803010c,   // lt.lv.ro_442 sr.cy.un_530  eu.sk.af_543 en.nl.no_543
  0x00002803, 0x04252105, 0x08100f05, 0x07002307,   // sw.un.un_300 jw.eu.fi_333  lv.lt.no_333 ca.it.un_420
  // [2b90]
  0x1600020c, 0x230b11a4, 0x1e1c6ea4, 0x20356404,   // da.hr.un_530 ro.es.ca_433  hmn.id.ms_433 lg.zu.sq_332
  0x0e060f13, 0x12000d18, 0x25132355, 0x1000040e,   // lv.de.is_665 cs.hu.un_740  ca.et.eu_442 ru.be.un_550
  0x55182704, 0x12006419, 0x25001a02, 0x080e0207,   // gd.ga.rw_332 lg.hu.un_750  tl.eu.un_220 da.is.no_432
  0x12211c02, 0x250711a7, 0x1f000a04, 0x08051e04,   // id.jw.hu_222 ro.it.eu_532  pt.cy.un_320 ms.fr.no_332
  // [2ba0]
  0x64006802, 0x6b012307, 0x1c1e2a08, 0x19000a02,   // ig.lg.un_220 ca.en.ceb_432  mt.ms.id_443 pt.gl.un_220
  0x060f10ad, 0x04001712, 0x091c0d02, 0x12641aa0,   // lt.lv.de_643 sr.ru.un_640  ne.mr.hi_222 tl.lg.hu_322
  0x2300050e, 0x0b2d0207, 0x6b1a0212, 0x01036ba4,   // fr.ca.un_550 da.sk.es_432  da.tl.ceb_654 ceb.nl.en_433
  0x0e04130c, 0x04001705, 0x283b55ad, 0x030113a7,   // et.fi.is_543 sr.ru.un_330  rw.so.sw_643 et.en.nl_532
  // [2bb0]
  0x0b1827ad, 0x191c0aee, 0x0d091c0e, 0x1e00550e,   // gd.ga.es_643 pt.id.gl_422  mr.hi.ne_555 rw.ms.un_550
  0x64555313, 0x6b1a53a9, 0x1f0729ee, 0x2d1b3111,   // ht.rw.lg_665 ht.tl.ceb_544  sl.it.cy_422 az.tr.sk_653
  0x351a6bad, 0x5568350e, 0x5500522a, 0x3f5364ad,   // ceb.tl.zu_643 zu.ig.rw_555  ha.rw.un_970 lg.ht.af_643
  0x062718a0, 0x0e00131a, 0x1b6b53a6, 0x53351c0c,   // ga.gd.de_322 et.is.un_760  ht.ceb.tr_521 id.zu.ht_543
  // [2bc0]
  0x1200641b, 0x05271808, 0x1f000104, 0x284a3ba7,   // lg.hu.un_770 ga.gd.fr_443  en.cy.un_320 so.yo.sw_532
  0x0e00200d, 0x0e072a08, 0x05002109, 0x1c006b04,   // sq.is.un_540 mt.it.is_443  jw.fr.un_440 ceb.id.un_320
  0x1e1c04ec, 0x16004a07, 0x3b6b1a09, 0x3f030408,   // fi.id.ms_644 yo.hr.un_420  tl.ceb.so_444 fi.nl.af_443
  0x133f040c, 0x3b55520e, 0x170f13ee, 0x1b31520d,   // fi.af.et_543 ha.rw.so_555  et.lv.sr_422 ha.az.tr_554
  // [2bd0]
  0x551b530e, 0x533564ee, 0x212d1107, 0x0d002d11,   // ht.tr.rw_555 lg.zu.ht_422  ro.sk.jw_432 sk.cs.un_630
  0x0a0710ee, 0x042153a4, 0x2b00680d, 0x0f092aa4,   // be.bg.mk_422 ht.jw.fi_433  ig.vi.un_540 mt.pl.lv_433
  0x55356413, 0x645352a9, 0x20005322, 0x0c2168a0,   // lg.zu.rw_665 ha.ht.lg_544  ht.sq.un_870 ig.jw.sv_322
  0x0100050e, 0x13006b0e, 0x2d0d04a4, 0x03080205,   // fr.en.un_550 ceb.et.un_550  fi.cs.sk_433 da.no.nl_333
  // [2be0]
  0x170a040b, 0x080a0713, 0x08003f13, 0x112d0d05,   // ru.mk.sr_542 bg.mk.uk_665  af.no.un_650 cs.sk.ro_333
  0x0b000704, 0x1f006413, 0x1b006821, 0x04321702,   // it.es.un_320 lg.cy.un_650  ig.tr.un_860 sr.bs.fi_222
  0x071101a4, 0x11001c0d, 0x2b003504, 0x685228ec,   // en.ro.it_433 id.ro.un_540  zu.vi.un_320 sw.ha.ig_644
  0x192528ad, 0x0c001f05, 0x0c051fee, 0x0400102b,   // sw.eu.gl_643 cy.sv.un_330  cy.fr.sv_422 be.ru.un_980
  // [2bf0]
  0x536b2012, 0x0e0521a0, 0x01002429, 0x2d1e1c08,   // sq.ceb.ht_654 jw.fr.is_322  yi.iw.un_960 id.ms.sk_443
  0x203552ad, 0x04000c0e, 0x3f1c3105, 0x01001f08,   // ha.zu.sq_643 sv.fi.un_550  az.id.af_333 cy.en.un_430
  0x0a2a520c, 0x4a1152a4, 0x3f006b0c, 0x0a005204,   // ha.mt.pt_543 ha.ro.yo_433  ceb.af.un_530 ha.pt.un_320
  0x282008a0, 0x1b213508, 0x321629af, 0x0e3506a9,   // no.sq.sw_322 zu.jw.tr_443  sl.hr.bs_655 de.zu.is_544

  // [2c00]
  0x312018a7, 0x0300200e, 0x0c000e0d, 0x130e1855,   // ga.sq.az_532 sq.nl.un_550  is.sv.un_540 ga.is.et_442
  0x2100201b, 0x23070b02, 0x1c002119, 0x1c090d0d,   // sq.jw.un_770 es.it.ca_222  jw.id.un_750 ne.hi.mr_554
  0x3f0306ac, 0x2b0601a6, 0x251e1c13, 0x2800350c,   // de.nl.af_632 en.de.vi_521  id.ms.eu_665 zu.sw.un_530
  0x033f1bee, 0x2a1a6b12, 0x291304ad, 0x200401a4,   // tr.af.nl_422 ceb.tl.mt_654  fi.et.sl_643 en.fi.sq_433
  // [2c10]
  0x04001c0d, 0x2a6b20ee, 0x17005512, 0x0f04130d,   // id.fi.un_540 sq.ceb.mt_422  rw.sr.un_640 et.fi.lv_554
  0x17321611, 0x08000c08, 0x190b4a05, 0x1c000d19,   // hr.bs.sr_653 sv.no.un_430  yo.es.gl_333 ne.mr.un_750
  0x0700041b, 0x05040709, 0x05002902, 0x53130808,   // ru.bg.un_770 it.fi.fr_444  sl.fr.un_220 no.et.ht_443
  0x0800121b, 0x5500641a, 0x1e1c4aa4, 0x06010407,   // hu.no.un_770 lg.rw.un_760  yo.id.ms_433 fi.en.de_432
  // [2c20]
  0x050704a9, 0x21081ca4, 0x1f000613, 0x3b205212,   // fi.it.fr_544 id.no.jw_433  de.cy.un_650 ha.sq.so_654
  0x1207045a, 0x17100805, 0x1c001321, 0x200852a0,   // fi.it.hu_553 uk.be.sr_333  bh.mr.un_860 ha.no.sq_322
  0x0d641308, 0x20106804, 0x29004a0d, 0x11202aa4,   // et.lg.cs_443 ig.lt.sq_332  yo.sl.un_540 mt.sq.ro_433
  0x12070408, 0x135525af, 0x21005514, 0x2a000722,   // fi.it.hu_443 eu.rw.et_655  rw.jw.un_660 it.mt.un_870
  // [2c30]
  0x1c211ea4, 0x521b3109, 0x12000721, 0x64552555,   // ms.jw.id_433 az.tr.ha_444  it.hu.un_860 eu.rw.lg_442
  0x06001308, 0x06071b04, 0x05000722, 0x1b001f19,   // et.de.un_430 tr.it.de_332  it.fr.un_870 cy.tr.un_750
  0x13041aa4, 0x04071007, 0x04004a05, 0x1b211e0c,   // tl.fi.et_433 be.bg.ru_432  yo.fi.un_330 ms.jw.tr_543
  0x1c006805, 0x1b002019, 0x10002512, 0x05641b07,   // ig.id.un_330 sq.tr.un_750  eu.lt.un_640 tr.lg.fr_432
  // [2c40]
  0x311a6bec, 0x041207a4, 0x2a063fa4, 0x6b081a0d,   // ceb.tl.az_644 it.hu.fi_433  af.de.mt_433 tl.no.ceb_554
  0x071204ec, 0x12000814, 0x35003112, 0x2a000c09,   // fi.hu.it_644 no.hu.un_660  az.zu.un_640 sv.mt.un_440
  0x013b2005, 0x072a08a0, 0x032d0d05, 0x081e25a4,   // sq.so.en_333 no.mt.it_322  cs.sk.nl_333 eu.ms.no_433
  0x130d0909, 0x2a040709, 0x32290908, 0x061331a0,   // hi.ne.bh_444 it.fi.mt_444  pl.sl.bs_443 az.et.de_322
  // [2c50]
  0x1e68200c, 0x3f04130b, 0x3b4a290c, 0x2a070214,   // sq.ig.ms_543 et.fi.af_542  sl.yo.so_543 da.it.mt_666
  0x07000a0b, 0x20311bec, 0x31005211, 0x19005207,   // mk.bg.un_520 tr.az.sq_644  ha.az.un_630 ha.gl.un_420
  0x082a4a04, 0x2a0705ad, 0x53004a04, 0x233f0207,   // yo.mt.no_332 fr.it.mt_643  yo.ht.un_320 da.af.ca_432
  0x03080ca4, 0x1c0d13a4, 0x27050da0, 0x061b12a4,   // sv.no.nl_433 bh.ne.mr_433  cs.fr.gd_322 hu.tr.de_433
  // [2c60]
  0x1707040c, 0x08021ba0, 0x1700291a, 0x204a27ec,   // ru.bg.sr_543 tr.da.no_322  sl.sr.un_760 gd.yo.sq_644
  0x06002102, 0x0400080e, 0x6b066ea0, 0x20003b04,   // jw.de.un_220 uk.ru.un_550  hmn.de.ceb_322 so.sq.un_320
  0x4a250504, 0x1a6b55ee, 0x3b00110c, 0x0b051904,   // fr.eu.yo_332 rw.ceb.tl_422  ro.so.un_530 gl.fr.es_332
  0x04080507, 0x2a0412ec, 0x1708045a, 0x52313b0c,   // fr.no.fi_432 hu.fi.mt_644  ru.uk.sr_553 so.az.ha_543
  // [2c70]
  0x0a190b13, 0x523b2113, 0x68002b21, 0x32291712,   // es.gl.pt_665 jw.so.ha_665  vi.ig.un_860 sr.sl.bs_654
  0x2a001b0c, 0x0708100d, 0x31521aa9, 0x2d001c02,   // tr.mt.un_530 be.uk.bg_554  tl.ha.az_544 id.sk.un_220
  0x216b0a07, 0x230f1304, 0x3b1a52a9, 0x1c211aa9,   // pt.ceb.jw_432 et.lv.ca_332  ha.tl.so_544 tl.jw.id_544
  0x5321520c, 0x18001204, 0x0c0a08ee, 0x52003b1a,   // ha.jw.ht_543 ur.ar.un_320  no.pt.sv_422 so.ha.un_760
  // [2c80]
  0x4a643505, 0x31523b0c, 0x17164a0c, 0x282b04ec,   // zu.lg.yo_333 so.ha.az_543  yo.hr.sr_543 fi.vi.sw_644
  0x313b52ec, 0x5221310c, 0x2d00040c, 0x170811a4,   // ha.so.az_644 az.jw.ha_543  fi.sk.un_530 ro.uk.sr_433
  0x2b04280c, 0x4a3b5208, 0x2b000421, 0x111f070c,   // sw.fi.vi_543 ha.so.yo_443  fi.vi.un_860 it.cy.ro_543
  0x2b001a08, 0x0e1308a4, 0x07001a23, 0x530e1ca4,   // tl.vi.un_430 no.et.is_433  tl.it.un_880 id.is.ht_433
  // [2c90]
  0x355231a4, 0x06053f04, 0x10002b1a, 0x0400050c,   // az.ha.zu_433 af.fr.de_332  vi.lt.un_760 fr.fi.un_530
  0x206b070c, 0x110410a4, 0x31003b19, 0x091f52a4,   // it.ceb.sq_543 be.ru.ro_433  so.az.un_750 ha.cy.pl_433
  0x09075508, 0x0704115a, 0x531b3109, 0x0807110e,   // rw.it.pl_443 ro.ru.bg_553  az.tr.ht_444 ro.bg.uk_555
  0x3b005519, 0x08001a0b, 0x3b1a31ec, 0x0e000808,   // rw.so.un_750 tl.no.un_520  az.tl.so_644 no.is.un_430
  // [2ca0]
  0x6b001a2c, 0x08530408, 0x01681f04, 0x13000d2a,   // tl.ceb.un_990 fi.ht.no_443  cy.ig.en_332 ne.bh.un_970
  0x68280755, 0x042b0712, 0x1a000213, 0x0f521355,   // it.sw.ig_442 it.vi.fi_654  da.tl.un_650 et.ha.lv_442
  0x2b000419, 0x020e08ad, 0x28042b13, 0x17000a14,   // fi.vi.un_750 no.is.da_643  vi.fi.sw_665 mk.sr.un_660
  0x133b06a7, 0x06003f0e, 0x06180e04, 0x311e1c5a,   // de.so.et_532 af.de.un_550  is.ga.de_332 id.ms.az_553
  // [2cb0]
  0x2917070c, 0x21101fee, 0x642809ad, 0x0a0728ad,   // it.sr.sl_543 cy.lt.jw_422  pl.sw.lg_643 sw.it.pt_643
  0x23200a14, 0x2a0f52ec, 0x27060207, 0x1a006b2c,   // pt.sq.ca_666 ha.lv.mt_644  da.de.gd_432 ceb.tl.un_990
  0x00000a37, 0x0a190b12, 0x070a04ac, 0x1a0755a4,   // pt.un.un_B00 es.gl.pt_654  ru.mk.bg_632 rw.it.tl_433
  0x0b09060c, 0x28005205, 0x1e1c100c, 0x1a126ba7,   // de.pl.es_543 ha.sw.un_330  lt.id.ms_543 ceb.hu.tl_532
  // [2cc0]
  0x521206ad, 0x2d0a23ee, 0x0103250c, 0x0f0a4aa0,   // de.hu.ha_643 ca.pt.sk_422  eu.nl.en_543 yo.pt.lv_322
  0x18001f1a, 0x1e3b04ee, 0x041c1ead, 0x35000d04,   // cy.ga.un_760 fi.so.ms_422  ms.id.fi_643 cs.zu.un_320
  0x07041f5a, 0x2100550c, 0x1a0f35ad, 0x29170aaf,   // cy.fi.it_553 rw.jw.un_530  zu.lv.tl_643 pt.sr.sl_655
  0x080204a4, 0x1e006b07, 0x35006b21, 0x17002921,   // fi.da.no_433 ceb.ms.un_420  ceb.zu.un_860 sl.sr.un_860
  // [2cd0]
  0x52311ea4, 0x081004af, 0x1e001904, 0x28000805,   // ms.az.ha_433 ru.be.uk_655  gl.ms.un_320 no.sw.un_330
  0x082b010c, 0x19070aa0, 0x190b200c, 0x02002913,   // en.vi.no_543 pt.it.gl_322  sq.es.gl_543 sl.da.un_650
  0x3b2355a0, 0x10002821, 0x686b1a0d, 0x6400552a,   // rw.ca.so_322 sw.lt.un_860  tl.ceb.ig_554 rw.lg.un_970
  0x01002307, 0x066e0405, 0x35005507, 0x251e1ca7,   // ca.en.un_420 fi.hmn.de_333  rw.zu.un_420 id.ms.eu_532
  // [2ce0]
  0x1708100c, 0x0e002108, 0x0e000509, 0x0a135207,   // be.uk.sr_543 jw.is.un_430  fr.is.un_440 ha.et.pt_432
  0x6e001c13, 0x130823a9, 0x2800351b, 0x12001e0d,   // id.hmn.un_650 ca.no.et_544  zu.sw.un_770 ms.hu.un_540
  0x07190f04, 0x0300041a, 0x040711af, 0x52042008,   // lv.gl.it_332 fi.nl.un_760  ro.bg.ru_655 sq.fi.ha_443
  0x190a23af, 0x292555a9, 0x551c1e11, 0x21003b22,   // ca.pt.gl_655 rw.eu.sl_544  ms.id.rw_653 so.jw.un_870
  // [2cf0]
  0x6b556412, 0x04002022, 0x6455350c, 0x3b293204,   // lg.rw.ceb_654 sq.fi.un_870  zu.rw.lg_543 bs.sl.so_332
  0x64002922, 0x09001008, 0x321716ee, 0x64005513,   // sl.lg.un_870 lt.pl.un_430  hr.sr.bs_422 rw.lg.un_650
  0x29200d0c, 0x090501a4, 0x080e040c, 0x1f001008,   // cs.sq.sl_543 en.fr.pl_433  fi.is.no_543 lt.cy.un_430
  0x090d13ad, 0x111827ad, 0x01001f02, 0x17114aa0,   // bh.ne.hi_643 gd.ga.ro_643  cy.en.un_220 yo.ro.sr_322
  // [2d00]
  0x351e1c04, 0x07170a0b, 0x1f006e0c, 0x253216ee,   // id.ms.zu_332 mk.sr.bg_542  hmn.cy.un_530 hr.bs.eu_422
  0x520412a9, 0x0f1b1307, 0x2d0d16a4, 0x08061f0c,   // hu.fi.ha_544 et.tr.lv_432  hr.cs.sk_433 cy.de.no_543
  0x25002314, 0x21002329, 0x0a1704a7, 0x0300252a,   // ca.eu.un_660 ca.jw.un_960  ru.sr.mk_532 eu.nl.un_970
  0x2a002321, 0x1f183b0c, 0x29000307, 0x35005502,   // ca.mt.un_860 so.ga.cy_543  nl.sl.un_420 rw.zu.un_220
  // [2d10]
  0x1b05010c, 0x23002513, 0x0b000108, 0x3b003511,   // en.fr.tr_543 eu.ca.un_650  en.es.un_430 zu.so.un_630
  0x010b18ee, 0x2800680e, 0x3200170c, 0x1e1c13af,   // ga.es.en_422 ig.sw.un_550  sr.bs.un_530 et.id.ms_655
  0x04080e05, 0x35096412, 0x13100412, 0x1328030b,   // is.no.fi_333 lg.pl.zu_654  fi.lt.et_654 nl.sw.et_542
  0x03040ca4, 0x0b3b28af, 0x070817ee, 0x21001a13,   // sv.fi.nl_433 sw.so.es_655  sr.uk.bg_422 tl.jw.un_650
  // [2d20]
  0x280364ee, 0x21203fa0, 0x55286404, 0x3500680d,   // lg.nl.sw_422 af.sq.jw_322  lg.sw.rw_332 ig.zu.un_540
  0x3f000c07, 0x1a354a07, 0x21001e07, 0x55006807,   // sv.af.un_420 yo.zu.tl_432  ms.jw.un_420 ig.rw.un_420
  0x03006402, 0x3f1a6b08, 0x03061b07, 0x0d2d190d,   // lg.nl.un_220 ceb.tl.af_443  tr.de.nl_432 gl.sk.cs_554
  0x1a3b4a0b, 0x13080c04, 0x534a52a0, 0x521a1e07,   // yo.so.tl_542 sv.no.et_332  ha.yo.ht_322 ms.tl.ha_432
  // [2d30]
  0x312a3b0d, 0x13000118, 0x0c006b07, 0x033f530c,   // so.mt.az_554 en.et.un_740  ceb.sv.un_420 ht.af.nl_543
  0x10040a05, 0x1a4a52a6, 0x1e1c2d02, 0x3f040ea0,   // mk.ru.be_333 ha.yo.tl_521  sk.id.ms_222 is.fi.af_322
  0x10000f09, 0x52003104, 0x1704080e, 0x091c13af,   // lv.lt.un_440 az.ha.un_320  uk.ru.sr_555 bh.mr.hi_655
  0x04001329, 0x190b0fee, 0x09000c07, 0x3255350b,   // et.fi.un_960 lv.es.gl_422  sv.pl.un_420 zu.rw.bs_542
  // [2d40]
  0x13030407, 0x1e1c5214, 0x3b136e05, 0x06201ea4,   // fi.nl.et_432 ha.id.ms_666  hmn.et.so_333 ms.sq.de_433
  0x080211ec, 0x27181f05, 0x0c0827a4, 0x281e3bac,   // ro.da.no_644 cy.ga.gd_333  gd.no.sv_433 so.ms.sw_632
  0x13190a13, 0x08170413, 0x2d000614, 0x080e6ba0,   // pt.gl.et_665 ru.sr.uk_665  de.sk.un_660 ceb.is.no_322
  0x070810a0, 0x4a685208, 0x04060cee, 0x036b68ec,   // be.uk.bg_322 ha.ig.yo_443  sv.de.fi_422 ig.ceb.nl_644
  // [2d50]
  0x4a6413ec, 0x64552114, 0x35001912, 0x522a4a55,   // et.lg.yo_644 jw.rw.lg_666  gl.zu.un_640 yo.mt.ha_442
  0x0a10170c, 0x053f230d, 0x642713a9, 0x6800031a,   // sr.be.mk_543 ca.af.fr_554  et.gd.lg_544 nl.ig.un_760
  0x641c2104, 0x1c0d13ec, 0x08026b02, 0x0c101f07,   // jw.id.lg_332 bh.ne.mr_644  ceb.da.no_222 cy.lt.sv_432
  0x2b121ca0, 0x08000419, 0x0e100855, 0x6e1f53ec,   // id.hu.vi_322 ru.uk.un_750  no.lt.is_442 ht.cy.hmn_644
  // [2d60]
  0x316407a9, 0x16190a55, 0x1e003119, 0x1c130daf,   // it.lg.az_544 pt.gl.hr_442  az.ms.un_750 ne.bh.mr_655
  0x1b1c1e07, 0x0664035a, 0x033f0414, 0x2a0a1802,   // ms.id.tr_432 nl.lg.de_553  fi.af.nl_666 ga.pt.mt_222
  0x28003b20, 0x090b3507, 0x1a4a6b02, 0x1e1b2aee,   // so.sw.un_850 zu.es.pl_432  ceb.yo.tl_222 mt.tr.ms_422
  0x0b283512, 0x190a1105, 0x0704180c, 0x2d000613,   // zu.sw.es_654 ro.pt.gl_333  ga.fi.it_543 de.sk.un_650
  // [2d70]
  0x6b000704, 0x0206085a, 0x2d321605, 0x23000a12,   // it.ceb.un_320 no.de.da_553  hr.bs.sk_333 pt.ca.un_640
  0x3f0e080b, 0x080210a4, 0x27646ba7, 0x0f001019,   // no.is.af_542 lt.da.no_433  ceb.lg.gd_532 lt.lv.un_750
  0x286b52ee, 0x16352d55, 0x0a1710af, 0x04001718,   // ha.ceb.sw_422 sk.zu.hr_442  be.sr.mk_655 sr.ru.un_740
  0x17003504, 0x11002719, 0x3f03040c, 0x2800552a,   // zu.sr.un_320 gd.ro.un_750  fi.nl.af_543 rw.sw.un_970
  // [2d80]
  0x04102511, 0x04000f04, 0x64000413, 0x18001905,   // eu.lt.fi_653 lv.fi.un_320  fi.lg.un_650 gl.ga.un_330
  0x0b001908, 0x536b0102, 0x134a350c, 0x29000713,   // gl.es.un_430 en.ceb.ht_222  zu.yo.et_543 it.sl.un_650
  0x643f0305, 0x3f3b4aa0, 0x09100412, 0x1e1c6ba0,   // nl.af.lg_333 yo.so.af_322  fi.lt.pl_654 ceb.id.ms_322
  0x13271104, 0x1100681a, 0x6b181108, 0x02006b0d,   // ro.gd.et_332 ig.ro.un_760  ro.ga.ceb_443 ceb.da.un_540
  // [2d90]
  0x13000b07, 0x190b28ec, 0x13091cad, 0x55280ba4,   // es.et.un_420 sw.es.gl_644  mr.hi.bh_643 es.sw.rw_433
  0x11000419, 0x35060eaf, 0x12006e12, 0x1b230aee,   // ru.ro.un_750 is.de.zu_655  hmn.hu.un_640 pt.ca.tr_422
  0x6400031b, 0x04006422, 0x5321070c, 0x3b060ea4,   // nl.lg.un_770 lg.fi.un_870  it.jw.ht_543 is.de.so_433
  0x1107080c, 0x07002a1b, 0x21054a04, 0x11001607,   // uk.bg.ro_543 mt.it.un_770  yo.fr.jw_332 hr.ro.un_420
  // [2da0]
  0x64130412, 0x64046804, 0x12311b55, 0x19001f1b,   // fi.et.lg_654 ig.fi.lg_332  tr.az.hu_442 cy.gl.un_770
  0x35001904, 0x31000308, 0x18004a07, 0x53000517,   // gl.zu.un_320 nl.az.un_430  yo.ga.un_420 fr.ht.un_730
  0x2500531a, 0x1c001a02, 0x321710a4, 0x10000f14,   // ht.eu.un_760 tl.id.un_220  lt.sr.bs_433 lv.lt.un_660
  0x08021902, 0x2d0d16a0, 0x3f00030c, 0x64002820,   // gl.da.no_222 hr.cs.sk_322  nl.af.un_530 sw.lg.un_850
  // [2db0]
  0x190b23a4, 0x070417a7, 0x320a0304, 0x090627a7,   // ca.es.gl_433 sr.ru.bg_532  nl.pt.bs_332 gd.de.pl_532
  0x0a001605, 0x041a6ba0, 0x20000312, 0x1c1e0655,   // hr.pt.un_330 ceb.tl.fi_322  nl.sq.un_640 de.ms.id_442
  0x13000907, 0x4a00250e, 0x181127a4, 0x35004a0d,   // hi.bh.un_420 eu.yo.un_550  gd.ro.ga_433 yo.zu.un_540
  0x11270108, 0x6b190b0d, 0x2300190c, 0x1c001f05,   // en.gd.ro_443 es.gl.ceb_554  gl.ca.un_530 cy.id.un_330
  // [2dc0]
  0x231811a7, 0x0a041055, 0x020c080c, 0x016b18ee,   // ro.ga.ca_532 be.ru.mk_442  no.sv.da_543 ga.ceb.en_422
  0x08033f0c, 0x073f0308, 0x0500111a, 0x2d180da4,   // af.nl.no_543 nl.af.it_443  ro.fr.un_760 cs.ga.sk_433
  0x01000504, 0x64001104, 0x21000d04, 0x032a2013,   // fr.en.un_320 ro.lg.un_320  cs.jw.un_320 sq.mt.nl_665
  0x0e1f640d, 0x056b5204, 0x072710ad, 0x17000d08,   // lg.cy.is_554 ha.ceb.fr_332  lt.gd.it_643 cs.sr.un_430
  // [2dd0]
  0x05042005, 0x016b6ea0, 0x05041307, 0x080a17ad,   // sq.fi.fr_333 hmn.ceb.en_322  et.fi.fr_432 sr.mk.uk_643
  0x31041312, 0x21005304, 0x01530c09, 0x1200091a,   // et.fi.az_654 ht.jw.un_320  sv.ht.en_444 pl.hu.un_760
  0x0c061313, 0x13251107, 0x31020807, 0x09001602,   // et.de.sv_665 ro.eu.et_432  no.da.az_432 hr.pl.un_220
  0x1300070e, 0x1813040c, 0x04182708, 0x0f254aec,   // it.et.un_550 fi.et.ga_543  gd.ga.fi_443 yo.eu.lv_644
  // [2de0]
  0x3f000b02, 0x11001b13, 0x07033f13, 0x29032da9,   // es.af.un_220 tr.ro.un_650  af.nl.it_665 sk.nl.sl_544
  0x063f230c, 0x2500041a, 0x2829130b, 0x0e3f06a4,   // ca.af.de_543 fi.eu.un_760  et.sl.sw_542 de.af.is_433
  0x190e0107, 0x553528af, 0x08001807, 0x13001914,   // en.is.gl_432 sw.zu.rw_655  ga.no.un_420 gl.et.un_660
  0x01043b04, 0x2a002908, 0x3200290c, 0x0f1e3f0c,   // so.fi.en_332 sl.mt.un_430  sl.bs.un_530 af.ms.lv_543
  // [2df0]
  0x2900551b, 0x20002519, 0x050a23ec, 0x2a031f07,   // rw.sl.un_770 eu.sq.un_750  ca.pt.fr_644 cy.nl.mt_432
  0x3b000b05, 0x08041fec, 0x553b100b, 0x05000a21,   // es.so.un_330 cy.fi.no_644  lt.so.rw_542 pt.fr.un_860
  0x0810170c, 0x055255a4, 0x4a6b6813, 0x08021fa0,   // sr.be.uk_543 rw.ha.fr_433  ig.ceb.yo_665 cy.da.no_322
  0x29090fa4, 0x05001005, 0x080225a0, 0x0e002922,   // lv.pl.sl_433 lt.fr.un_330  eu.da.no_322 sl.is.un_870
  // [2e00]
  0x0f3b550b, 0x5529130c, 0x16000804, 0x07104a0c,   // rw.so.lv_542 et.sl.rw_543  no.hr.un_320 yo.lt.it_543
  0x0000132d, 0x6e04680c, 0x13552908, 0x0500530e,   // bh.un.un_A00 ig.fi.hmn_543  sl.rw.et_443 ht.fr.un_550
  0x20005308, 0x04032aee, 0x16005507, 0x09001604,   // ht.sq.un_430 mt.nl.fi_422  rw.hr.un_420 hr.pl.un_320
  0x190527ec, 0x0c12060c, 0x13003f02, 0x04074a0c,   // gd.fr.gl_644 de.hu.sv_543  af.et.un_220 yo.it.fi_543
  // [2e10]
  0x190a0414, 0x036404ad, 0x2a645204, 0x1b033b07,   // fi.pt.gl_666 fi.lg.nl_643  ha.lg.mt_332 so.nl.tr_432
  0x07000a34, 0x02085307, 0x100b5507, 0x04000514,   // mk.bg.un_A80 ht.no.da_432  rw.es.lt_432 fr.fi.un_660
  0x3f002d08, 0x05640709, 0x553b52af, 0x23050708,   // sk.af.un_430 it.lg.fr_444  ha.so.rw_655 it.fr.ca_443
  0x3f1a6b0c, 0x1c132a04, 0x2d003207, 0x0506520c,   // ceb.tl.af_543 mt.et.id_332  bs.sk.un_420 ha.de.fr_543
  // [2e20]
  0x1c0935ad, 0x311b0aa0, 0x0c020608, 0x0c080e04,   // zu.pl.id_643 pt.tr.az_322  de.da.sv_443 is.no.sv_332
  0x08190b04, 0x030c3f04, 0x31001904, 0x08001704,   // es.gl.no_332 af.sv.nl_332  gl.az.un_320 sr.uk.un_320
  0x030c08a4, 0x1f2708a4, 0x130752ad, 0x13080205,   // no.sv.nl_433 no.gd.cy_433  ha.it.et_643 da.no.et_333
  0x2a0e05a4, 0x3f130407, 0x0d1c130c, 0x032a060c,   // fr.is.mt_433 fi.et.af_432  bh.mr.ne_543 de.mt.nl_543
  // [2e30]
  0x3b3f040c, 0x07002a09, 0x3f080c04, 0x23000a1b,   // fi.af.so_543 mt.it.un_440  sv.no.af_332 pt.ca.un_770
  0x032d2a04, 0x08101713, 0x1b0131ee, 0x2a063f0c,   // mt.sk.nl_332 sr.be.uk_665  az.en.tr_422 af.de.mt_543
  0x1632170b, 0x070a1008, 0x0c086ba0, 0x4a006819,   // sr.bs.hr_542 be.mk.bg_443  ceb.no.sv_322 ig.yo.un_750
  0x23190b13, 0x0c003f05, 0x09001f22, 0x2a006e19,   // es.gl.ca_665 af.sv.un_330  cy.pl.un_870 hmn.mt.un_750
  // [2e40]
  0x030c3f02, 0x060d05a0, 0x250b19ee, 0x5200230d,   // af.sv.nl_222 fr.cs.de_322  gl.es.eu_422 ca.ha.un_540
  0x20102912, 0x130d09a9, 0x2319050c, 0x07001011,   // sl.lt.sq_654 hi.ne.bh_544  fr.gl.ca_543 lt.it.un_630
  0x05002314, 0x290d1602, 0x284a5514, 0x2d1029ad,   // ca.fr.un_660 hr.cs.sl_222  rw.yo.sw_666 sl.lt.sk_643
  0x0c052704, 0x28211ca0, 0x20190bee, 0x27000802,   // gd.fr.sv_332 id.jw.sw_322  es.gl.sq_422 no.gd.un_220
  // [2e50]
  0x281e6ba0, 0x1a28640c, 0x05083ba0, 0x13171608,   // ceb.ms.sw_322 lg.sw.tl_543  so.no.fr_322 hr.sr.et_443
  0x530405ad, 0x121e1c04, 0x290413a4, 0x09001613,   // fr.fi.ht_643 id.ms.hu_332  et.fi.sl_433 hr.pl.un_650
  0x0b001e04, 0x29130911, 0x2a001904, 0x07001604,   // ms.es.un_320 pl.et.sl_653  gl.mt.un_320 hr.it.un_320
  0x16001308, 0x35004a04, 0x0e003b1b, 0x4a25520c,   // et.hr.un_430 yo.zu.un_320  so.is.un_770 ha.eu.yo_543
  // [2e60]
  0x1f100fa0, 0x352a075a, 0x04002522, 0x4a6b10a4,   // lv.lt.cy_322 it.mt.zu_553  eu.fi.un_870 lt.ceb.yo_433
  0x3252080c, 0x18522813, 0x100f1eee, 0x64003202,   // no.ha.bs_543 sw.ha.ga_665  ms.lv.lt_422 bs.lg.un_220
  0x1b533255, 0x131c1e07, 0x2a5220a7, 0x20006e0d,   // bs.ht.tr_442 ms.id.et_432  sq.ha.mt_532 hmn.sq.un_540
  0x35005523, 0x050307a6, 0x161364a0, 0x10066e04,   // rw.zu.un_880 it.nl.fr_521  lg.et.hr_322 hmn.de.lt_332
  // [2e70]
  0x3f022aec, 0x080419a0, 0x6e002019, 0x06032702,   // mt.da.af_644 gl.fi.no_322  sq.hmn.un_750 gd.nl.de_222
  0x0f291ca4, 0x2d0f10ec, 0x1b00121b, 0x060e0c05,   // id.sl.lv_433 lt.lv.sk_644  hu.tr.un_770 sv.is.de_333
  0x071711ee, 0x3b000419, 0x0e1b3bad, 0x1b214a05,   // ro.sr.bg_422 fi.so.un_750  so.tr.is_643 yo.jw.tr_333
  0x07002a0d, 0x0f0313a0, 0x07046408, 0x030c13a4,   // mt.it.un_540 et.nl.lv_322  lg.fi.it_443 et.sv.nl_433
  // [2e80]
  0x0d1309a7, 0x291703af, 0x2a001f1a, 0x0b0323ee,   // hi.bh.ne_532 nl.sr.sl_655  cy.mt.un_760 ca.nl.es_422
  0x230a6e07, 0x063f0e05, 0x12033fa4, 0x0a0711a0,   // hmn.pt.ca_432 is.af.de_333  af.nl.hu_433 ro.bg.mk_322
  0x2520040b, 0x0a00230c, 0x28000119, 0x6b55640c,   // fi.sq.eu_542 ca.pt.un_530  en.sw.un_750 lg.rw.ceb_543
  0x08000713, 0x641e290c, 0x1c1e2712, 0x10041304,   // bg.uk.un_650 sl.ms.lg_543  gd.ms.id_654 et.fi.lt_332
  // [2e90]
  0x190b05ee, 0x082a07af, 0x13001e05, 0x2b000704,   // fr.es.gl_422 it.mt.no_655  ms.et.un_330 it.vi.un_320
  0x20321605, 0x3b1304ad, 0x193223a6, 0x1f211ea0,   // hr.bs.sq_333 fi.et.so_643  ca.bs.gl_521 ms.jw.cy_322
  0x281752a0, 0x0c000805, 0x070a2809, 0x211a1ea7,   // ha.sr.sw_322 no.sv.un_330  sw.pt.it_444 ms.tl.jw_532
  0x20001e04, 0x033f0ea9, 0x23002d19, 0x0800171b,   // ms.sq.un_320 is.af.nl_544  sk.ca.un_750 sr.uk.un_770
  // [2ea0]
  0x06231108, 0x3200290e, 0x103f06ac, 0x20001f12,   // ro.ca.de_443 sl.bs.un_550  de.af.lt_632 cy.sq.un_640
  0x2b000e05, 0x20000413, 0x646b53a4, 0x17192907,   // is.vi.un_330 fi.sq.un_650  ht.ceb.lg_433 sl.gl.sr_432
  0x13015304, 0x0e0c31af, 0x18255204, 0x232007a4,   // ht.en.et_332 az.sv.is_655  ha.eu.ga_332 it.sq.ca_433
  0x0400130e, 0x070f25ad, 0x13310eb2, 0x10684a55,   // et.fi.un_550 eu.lv.it_643  is.az.et_732 yo.ig.lt_442
  // [2eb0]
  0x21001107, 0x281168a6, 0x172d2912, 0x190a28af,   // ro.jw.un_420 ig.ro.sw_521  sl.sk.sr_654 sw.pt.gl_655
  0x0a106b04, 0x64001a08, 0x3b006e04, 0x4a0b2507,   // ceb.lt.pt_332 tl.lg.un_430  hmn.so.un_320 eu.es.yo_432
  0x100a19a4, 0x35555205, 0x0c080e08, 0x0c000418,   // gl.pt.lt_433 ha.rw.zu_333  is.no.sv_443 fi.sv.un_740
  0x1b00350e, 0x06002a13, 0x0802060c, 0x4a001218,   // zu.tr.un_550 mt.de.un_650  de.da.no_543 hu.yo.un_740
  // [2ec0]
  0x531b52a6, 0x6800070e, 0x1e250704, 0x032805a7,   // ha.tr.ht_521 it.ig.un_550  it.eu.ms_332 fr.sw.nl_532
  0x0b003b21, 0x20005513, 0x31001e04, 0x040806a0,   // so.es.un_860 rw.sq.un_650  ms.az.un_320 de.no.fi_322
  0x6435120c, 0x12000a20, 0x08020ea0, 0x0a1811a4,   // hu.zu.lg_543 pt.hu.un_850  is.da.no_322 ro.ga.pt_433
  0x1e2d0d55, 0x3f000412, 0x1b310cec, 0x21134aa0,   // cs.sk.ms_442 fi.af.un_640  sv.az.tr_644 yo.et.jw_322
  // [2ed0]
  0x061332ad, 0x23251904, 0x1100070c, 0x0b0103ad,   // bs.et.de_643 gl.eu.ca_332  it.ro.un_530 nl.en.es_643
  0x0c0e0107, 0x2d0d32a4, 0x13000509, 0x0d000a07,   // en.is.sv_432 bs.cs.sk_433  fr.et.un_440 pt.cs.un_420
  0x063f1bee, 0x081e3155, 0x193b1212, 0x13000712,   // tr.af.de_422 az.ms.no_442  hu.so.gl_654 it.et.un_640
  0x203117a0, 0x0c076ba0, 0x2a005321, 0x3f1a6ba0,   // sr.az.sq_322 ceb.it.sv_322  ht.mt.un_860 ceb.tl.af_322
  // [2ee0]
  0x0b052108, 0x022835ec, 0x1b2d0d05, 0x231107af,   // jw.fr.es_443 zu.sw.da_644  cs.sk.tr_333 it.ro.ca_655
  0x16002909, 0x2d12205a, 0x02080c60, 0x252d6807,   // sl.hr.un_440 sq.hu.sk_553  sv.no.da_664 ig.sk.eu_432
  0x0a071012, 0x323b0808, 0x19000618, 0x0c006408,   // be.bg.mk_654 no.so.bs_443  de.gl.un_740 lg.sv.un_430
  0x04001e08, 0x2d122912, 0x290e1905, 0x5300051b,   // ms.fi.un_430 sl.hu.sk_654  gl.is.sl_333 fr.ht.un_770
  // [2ef0]
  0x13000518, 0x09553512, 0x321620ad, 0x212852ee,   // fr.et.un_740 zu.rw.pl_654  sq.hr.bs_643 ha.sw.jw_422
  0x120208a4, 0x522128a7, 0x02000c05, 0x64285211,   // no.da.hu_433 sw.jw.ha_532  sv.da.un_330 ha.sw.lg_653
  0x52002114, 0x130f21a4, 0x1f00550e, 0x6b190a0d,   // jw.ha.un_660 jw.lv.et_433  rw.cy.un_550 pt.gl.ceb_554
  0x1e281c04, 0x17002a07, 0x1c211e11, 0x1f000121,   // id.sw.ms_332 mt.sr.un_420  ms.jw.id_653 en.cy.un_860
  // [2f00]
  0x051109ad, 0x1c2113ad, 0x070a1005, 0x17000814,   // pl.ro.fr_643 et.jw.id_643  be.mk.bg_333 uk.sr.un_660
  0x1e1c52ec, 0x3f090f08, 0x11093fa0, 0x100411ad,   // ha.id.ms_644 lv.pl.af_443  af.pl.ro_322 ro.ru.be_643
  0x16000d07, 0x09002912, 0x10001113, 0x0419210c,   // cs.hr.un_420 sl.pl.un_640  ro.be.un_650 jw.gl.fi_543
  0x0400111b, 0x09000d0b, 0x070905a4, 0x53001a02,   // ro.ru.un_770 ne.hi.un_520  fr.pl.it_433 tl.ht.un_220
  // [2f10]
  0x4a006821, 0x351a4a0c, 0x1c211bad, 0x2a25350c,   // ig.yo.un_860 yo.tl.zu_543  tr.jw.id_643 zu.eu.mt_543
  0x19680b0c, 0x6b001a08, 0x1704100c, 0x0a1c21a7,   // es.ig.gl_543 tl.ceb.un_430  be.ru.sr_543 jw.id.pt_532
  0x091217a0, 0x25001e13, 0x0c021ca0, 0x032511ee,   // sr.hu.pl_322 ms.eu.un_650  id.da.sv_322 ro.eu.nl_422
  0x12050907, 0x08001e0d, 0x4a002b13, 0x553b20ec,   // pl.fr.hu_432 ms.no.un_540  vi.yo.un_650 sq.so.rw_644
  // [2f20]
  0x0a100408, 0x135564a0, 0x6b132aa0, 0x05070b08,   // fi.lt.pt_443 lg.rw.et_322  mt.et.ceb_322 es.it.fr_443
  0x0b311b1d, 0x28006b0d, 0x0e031bec, 0x212035a4,   // tr.az.es_852 ceb.sw.un_540  tr.nl.is_644 zu.sq.jw_433
  0x100a520d, 0x550e350c, 0x12000d0e, 0x082331ad,   // ha.pt.lt_554 zu.is.rw_543  cs.hu.un_550 az.ca.no_643
  0x13002104, 0x113f6404, 0x030618a9, 0x3b000707,   // jw.et.un_320 lg.af.ro_332  ga.de.nl_544 it.so.un_420
  // [2f30]
  0x643f030c, 0x12001f14, 0x070b0a09, 0x08001709,   // nl.af.lg_543 cy.hu.un_660  pt.es.it_444 sr.uk.un_440
  0x35062511, 0x1a070e0d, 0x07081104, 0x10190b02,   // eu.de.zu_653 is.it.tl_554  ro.uk.bg_332 es.gl.lt_222
  0x042028a0, 0x04136408, 0x04004a19, 0x13060c04,   // sw.sq.fi_322 lg.et.fi_443  yo.fi.un_750 sv.de.et_332
  0x12006b0d, 0x0e1206ec, 0x1e1c2014, 0x10201107,   // ceb.hu.un_540 de.hu.is_644  sq.id.ms_666 ro.sq.lt_432
  // [2f40]
  0x2a112014, 0x13001f1a, 0x13100f12, 0x011e68a0,   // sq.ro.mt_666 cy.et.un_760  lv.lt.et_654 ig.ms.en_322
  0x080253a0, 0x0400181a, 0x312a21a0, 0x061a2808,   // ht.da.no_322 ga.fi.un_760  jw.mt.az_322 sw.tl.de_443
  0x21061c07, 0x6b2d0dad, 0x641c21a0, 0x285206af,   // id.de.jw_432 cs.sk.ceb_643  jw.id.lg_322 de.ha.sw_655
  0x1700090b, 0x2a292704, 0x6b00210d, 0x170408ad,   // pl.sr.un_520 gd.sl.mt_332  jw.ceb.un_540 uk.ru.sr_643
  // [2f50]
  0x64280da0, 0x04002812, 0x09001c22, 0x13006b08,   // cs.sw.lg_322 sw.fi.un_640  mr.hi.un_870 ceb.et.un_430
  0x051e1c04, 0x13640408, 0x17321607, 0x041355a4,   // id.ms.fr_332 fi.lg.et_443  hr.bs.sr_432 rw.et.fi_433
  0x5564200c, 0x296435ee, 0x20551c07, 0x64005520,   // sq.lg.rw_543 zu.lg.sl_422  id.rw.sq_432 rw.lg.un_850
  0x040313ee, 0x062832a0, 0x64003f08, 0x23002a08,   // et.nl.fi_422 bs.sw.de_322  af.lg.un_430 mt.ca.un_430
  // [2f60]
  0x19000d19, 0x52283513, 0x07000823, 0x10170a05,   // cs.gl.un_750 zu.sw.ha_665  uk.bg.un_880 mk.sr.be_333
  0x2a003533, 0x1e555208, 0x25352807, 0x04293507,   // zu.mt.un_A70 ha.rw.ms_443  sw.zu.eu_432 zu.sl.fi_432
  0x5204100c, 0x201235a0, 0x01000511, 0x12003f05,   // lt.fi.ha_543 zu.hu.sq_322  fr.en.un_630 af.hu.un_330
  0x02031ca0, 0x64523b08, 0x03001f20, 0x320d2aa4,   // id.nl.da_322 so.ha.lg_443  cy.nl.un_850 mt.cs.bs_433
  // [2f70]
  0x28526405, 0x050f55a0, 0x25001913, 0x08001029,   // lg.ha.sw_333 rw.lv.fr_322  gl.eu.un_650 be.uk.un_960
  0x0e001819, 0x55200c05, 0x05005309, 0x17202a04,   // ga.is.un_750 sv.sq.rw_333  ht.fr.un_440 mt.sq.sr_332
  0x3b006813, 0x350664a0, 0x190b2308, 0x13001c22,   // ig.so.un_650 lg.de.zu_322  ca.es.gl_443 mr.bh.un_870
  0x113218ee, 0x551228a4, 0x0800100b, 0x0b002507,   // ga.bs.ro_422 sw.hu.rw_433  be.uk.un_520 eu.es.un_420
  // [2f80]
  0x13000934, 0x1653280b, 0x3b285204, 0x530c1208,   // hi.bh.un_A80 sw.ht.hr_542  ha.sw.so_332 hu.sv.ht_443
  0x10000413, 0x28531309, 0x0b0a05a9, 0x041e1c5a,   // ru.be.un_650 et.ht.sw_444  fr.pt.es_544 id.ms.fi_553
  0x01270511, 0x0b321704, 0x29172a07, 0x206455ad,   // fr.gd.en_653 sr.bs.es_332  mt.sr.sl_432 rw.lg.sq_643
  0x05001c04, 0x08001012, 0x06111704, 0x12000914,   // id.fr.un_320 be.uk.un_640  sr.ro.de_332 pl.hu.un_660
  // [2f90]
  0x53643512, 0x1e1c09ec, 0x190b050e, 0x355355a9,   // zu.lg.ht_654 pl.id.ms_644  fr.es.gl_555 rw.ht.zu_544
  0x2a002909, 0x20285511, 0x3f5228ad, 0x55351cad,   // sl.mt.un_440 rw.sw.sq_653  sw.ha.af_643 id.zu.rw_643
  0x4a133b5a, 0x68001e04, 0x6800090d, 0x4a0313a4,   // so.et.yo_553 ms.ig.un_320  pl.ig.un_540 et.nl.yo_433
  0x64133b11, 0x64092a0d, 0x55005319, 0x160f0da7,   // so.et.lg_653 mt.pl.lg_554  ht.rw.un_750 cs.lv.hr_532
  // [2fa0]
  0x686455a9, 0x680603a4, 0x07080205, 0x25000f1b,   // rw.lg.ig_544 nl.de.ig_433  da.no.it_333 lv.eu.un_770
  0x35005308, 0x040817ad, 0x2800641b, 0x552864af,   // ht.zu.un_430 sr.uk.ru_643  lg.sw.un_770 lg.sw.rw_655
  0x03556405, 0x230128ee, 0x040a07a7, 0x3f1f030e,   // lg.rw.nl_333 sw.en.ca_422  bg.mk.ru_532 nl.cy.af_555
  0x0802010c, 0x250301a6, 0x1f063fa4, 0x3f6b0304,   // en.da.no_543 en.nl.eu_521  af.de.cy_433 nl.ceb.af_332
  // [2fb0]
  0x21001902, 0x55283514, 0x553509a4, 0x64003f19,   // gl.jw.un_220 zu.sw.rw_666  pl.zu.rw_433 af.lg.un_750
  0x0c061302, 0x5500530e, 0x1f006e2a, 0x03133f12,   // et.de.sv_222 ht.rw.un_550  hmn.cy.un_970 af.et.nl_654
  0x190512ac, 0x28006405, 0x52645512, 0x092835a0,   // hu.fr.gl_632 lg.sw.un_330  rw.lg.ha_654 zu.sw.pl_322
  0x28351c0c, 0x531a2813, 0x09000f0c, 0x1c351e12,   // id.zu.sw_543 sw.tl.ht_665  lv.pl.un_530 ms.zu.id_654
  // [2fc0]
  0x0a0704a0, 0x2a3f03a9, 0x033f06a9, 0x033f06ad,   // ru.bg.mk_322 nl.af.mt_544  de.af.nl_544 de.af.nl_643
  0x311b2a17, 0x033f6b02, 0x3b00211b, 0x12000c04,   // mt.tr.az_753 ceb.af.nl_222  jw.so.un_770 sv.hu.un_320
  0x13000c19, 0x55285202, 0x236b0e04, 0x23200b13,   // sv.et.un_750 ha.sw.rw_222  is.ceb.ca_332 es.sq.ca_665
  0x2a6b1a0c, 0x041017ad, 0x19641355, 0x011f2aee,   // tl.ceb.mt_543 sr.be.ru_643  et.lg.gl_442 mt.cy.en_422
  // [2fd0]
  0x3b3508a4, 0x18000611, 0x204a1a0b, 0x080c1fec,   // no.zu.so_433 de.ga.un_630  tl.yo.sq_542 cy.sv.no_644
  0x645255a4, 0x4a526807, 0x11040708, 0x3f044a09,   // rw.ha.lg_433 ig.ha.yo_432  bg.ru.ro_443 yo.fi.af_444
  0x216b1a05, 0x095213a0, 0x216b1a08, 0x08000c21,   // tl.ceb.jw_333 et.ha.pl_322  tl.ceb.jw_443 sv.no.un_860
  0x0b032ba7, 0x3f321cee, 0x0a006b05, 0x3b285513,   // vi.nl.es_532 id.bs.af_422  ceb.pt.un_330 rw.sw.so_665
  // [2fe0]
  0x1c1f1aa4, 0x070408a7, 0x2535640c, 0x28005204,   // tl.cy.id_433 uk.ru.bg_532  lg.zu.eu_543 ha.sw.un_320
  0x3b130e0c, 0x190b2314, 0x2a2007ee, 0x0e351c07,   // is.et.so_543 ca.es.gl_666  it.sq.mt_422 id.zu.is_432
  0x2b0c0507, 0x6b211a13, 0x1f061a07, 0x680d06a7,   // fr.sv.vi_432 tl.jw.ceb_665  tl.de.cy_432 de.cs.ig_532
  0x6b002108, 0x11000e13, 0x111a6bad, 0x1f2a550c,   // jw.ceb.un_430 is.ro.un_650  ceb.tl.ro_643 rw.mt.cy_543
  // [2ff0]
  0x20285204, 0x643f35ad, 0x2100352b, 0x12001908,   // ha.sw.sq_332 zu.af.lg_643  zu.jw.un_980 gl.hu.un_430
  0x32005504, 0x553568ec, 0x09522a11, 0x6418275a,   // rw.bs.un_320 ig.zu.rw_644  mt.ha.pl_653 gd.ga.lg_553
  0x0410530b, 0x535535af, 0x01093507, 0x3f080308,   // ht.lt.fi_542 zu.rw.ht_655  zu.pl.en_432 nl.no.af_443
  0x01070513, 0x68556408, 0x0d063b0c, 0x093b285a,   // fr.it.en_665 lg.rw.ig_443  so.de.cs_543 sw.so.pl_553

  // [3000]
  0x27001321, 0x283b64a9, 0x09000309, 0x5500642a,   // et.gd.un_860 lg.so.sw_544  nl.pl.un_440 lg.rw.un_970
  0x0000292d, 0x16640955, 0x1b002512, 0x0300640d,   // sl.un.un_A00 pl.lg.hr_442  eu.tr.un_640 lg.nl.un_540
  0x16530ca0, 0x23000b07, 0x55000108, 0x07100409,   // sv.ht.hr_322 es.ca.un_420  en.rw.un_430 ru.be.bg_444
  0x13061ea0, 0x0d001f1a, 0x55006407, 0x03520107,   // ms.de.et_322 cy.cs.un_760  lg.rw.un_420 en.ha.nl_432
  // [3010]
  0x3b231907, 0x5500352b, 0x0807045a, 0x18002b2b,   // gl.ca.so_432 zu.rw.un_980  ru.bg.uk_553 vi.ga.un_980
  0x102531a0, 0x232a0da7, 0x10000d13, 0x52002104,   // az.eu.lt_322 cs.mt.ca_532  cs.lt.un_650 jw.ha.un_320
  0x25521313, 0x21063f12, 0x55251a12, 0x1300121a,   // et.ha.eu_665 af.de.jw_654  tl.eu.rw_654 hu.et.un_760
  0x3b211c07, 0x08002a05, 0x643f55af, 0x01005507,   // id.jw.so_432 mt.no.un_330  rw.af.lg_655 rw.en.un_420
  // [3020]
  0x1c001904, 0x32000f08, 0x55003521, 0x07110405,   // gl.id.un_320 lv.bs.un_430  zu.rw.un_860 ru.ro.bg_333
  0x0d005208, 0x043b03ee, 0x0a110f11, 0x033f0205,   // ha.cs.un_430 nl.so.fi_422  lv.ro.pt_653 da.af.nl_333
  0x063f2b0b, 0x1f190704, 0x09003202, 0x05013b02,   // vi.af.de_542 it.gl.cy_332  bs.pl.un_220 so.en.fr_222
  0x3f350da7, 0x101117a0, 0x1f090d07, 0x0c001b19,   // cs.zu.af_532 sr.ro.lt_322  cs.pl.cy_432 tr.sv.un_750
  // [3030]
  0x28004a21, 0x201b1008, 0x08000c12, 0x20001008,   // yo.sw.un_860 lt.tr.sq_443  sv.no.un_640 lt.sq.un_430
  0x1c1e2111, 0x53281602, 0x2b001f09, 0x1b10200b,   // jw.ms.id_653 hr.sw.ht_222  cy.vi.un_440 sq.lt.tr_542
  0x29002007, 0x21004a23, 0x6b2b280d, 0x4a000a19,   // sq.sl.un_420 yo.jw.un_880  sw.vi.ceb_554 pt.yo.un_750
  0x17110808, 0x55213511, 0x13052008, 0x233f6b07,   // uk.ro.sr_443 zu.jw.rw_653  sq.fr.et_443 ceb.af.ca_432
  // [3040]
  0x2700051b, 0x2a084aa0, 0x2d1b20ee, 0x05001914,   // fr.gd.un_770 yo.no.mt_322  sq.tr.sk_422 gl.fr.un_660
  0x19230f5a, 0x5255350d, 0x35005522, 0x0e2a0faf,   // lv.ca.gl_553 zu.rw.ha_554  rw.zu.un_870 lv.mt.is_655
  0x3f180b5a, 0x0a55280c, 0x16110da4, 0x19116407,   // es.ga.af_553 sw.rw.pt_543  cs.ro.hr_433 lg.ro.gl_432
  0x05230b02, 0x6b6428a4, 0x2b003521, 0x162b32ee,   // es.ca.fr_222 sw.lg.ceb_433  zu.vi.un_860 bs.vi.hr_422
  // [3050]
  0x2000190d, 0x09283507, 0x13033f05, 0x0d12090c,   // gl.sq.un_540 zu.sw.pl_432  af.nl.et_333 pl.hu.cs_543
  0x20101304, 0x116b35a9, 0x06093f02, 0x0f006404,   // et.lt.sq_332 zu.ceb.ro_544  af.pl.de_222 lg.lv.un_320
  0x0a001712, 0x52002813, 0x201013a9, 0x182705af,   // sr.mk.un_640 sw.ha.un_650  et.lt.sq_544 fr.gd.ga_655
  0x1a002813, 0x3b121107, 0x2500111a, 0x3b1e550e,   // sw.tl.un_650 ro.hu.so_432  ro.eu.un_760 rw.ms.so_555
  // [3060]
  0x12642811, 0x16192307, 0x202a07a7, 0x0c1306ac,   // sw.lg.hu_653 ca.gl.hr_432  it.mt.sq_532 de.et.sv_632
  0x0d091c08, 0x64003204, 0x68352804, 0x11100412,   // mr.hi.ne_443 bs.lg.un_320  sw.zu.ig_332 ru.be.ro_654
  0x070810ee, 0x0f2a0d07, 0x551321ad, 0x08022da4,   // be.uk.bg_422 cs.mt.lv_432  jw.et.rw_643 sk.da.no_433
  0x520e09a7, 0x1a0e6ba4, 0x17000e08, 0x18001221,   // pl.is.ha_532 ceb.is.tl_433  is.sr.un_430 ur.ar.un_860
  // [3070]
  0x645568a4, 0x0112130c, 0x35006814, 0x2300052a,   // ig.rw.lg_433 et.hu.en_543  ig.zu.un_660 fr.ca.un_970
  0x64352855, 0x32100ea7, 0x0700230c, 0x53001921,   // sw.zu.lg_442 is.lt.bs_532  ca.it.un_530 gl.ht.un_860
  0x35001e02, 0x201b32a0, 0x5364550c, 0x281e35ad,   // ms.zu.un_220 bs.tr.sq_322  rw.lg.ht_543 zu.ms.sw_643
  0x09001c04, 0x07001708, 0x09001e04, 0x55680aa4,   // mr.hi.un_320 sr.bg.un_430  ms.pl.un_320 pt.ig.rw_433
  // [3080]
  0x6b5325a0, 0x08021eee, 0x071108a7, 0x3f530511,   // eu.ht.ceb_322 ms.da.no_422  uk.ro.bg_532 fr.ht.af_653
  0x05002112, 0x18000e08, 0x00002a2d, 0x0e1025a6,   // jw.fr.un_640 is.ga.un_430  mt.un.un_A00 eu.lt.is_521
  0x4a0e130d, 0x32000e08, 0x18001604, 0x191355a0,   // et.is.yo_554 is.bs.un_430  hr.ga.un_320 rw.et.gl_322
  0x0d4a1902, 0x03003202, 0x3b000304, 0x55351bee,   // gl.yo.cs_222 bs.nl.un_220  nl.so.un_320 tr.zu.rw_422
  // [3090]
  0x0c002104, 0x290f0d07, 0x086455ad, 0x060a25ad,   // jw.sv.un_320 cs.lv.sl_432  rw.lg.no_643 eu.pt.de_643
  0x21311b5a, 0x2d1e1c02, 0x1c0f01ee, 0x1a006b21,   // tr.az.jw_553 id.ms.sk_222  en.lv.id_422 ceb.tl.un_860
  0x10005305, 0x3b275508, 0x08170aaf, 0x0b00230d,   // ht.lt.un_330 rw.gd.so_443  mk.sr.uk_655 ca.es.un_540
  0x1f1c21a0, 0x100a0805, 0x1800170e, 0x03002013,   // jw.id.cy_322 uk.mk.be_333  sr.ga.un_550 sq.nl.un_650
  // [30a0]
  0x3b311b13, 0x20002a05, 0x0400250c, 0x17000813,   // tr.az.so_665 mt.sq.un_330  eu.fi.un_530 uk.sr.un_650
  0x0a0410a7, 0x1e1c230c, 0x64001021, 0x2a071ca9,   // be.ru.mk_532 ca.id.ms_543  lt.lg.un_860 id.it.mt_544
  0x28556413, 0x100e64a4, 0x25001c13, 0x2d292008,   // lg.rw.sw_665 lg.is.lt_433  id.eu.un_650 sq.sl.sk_443
  0x1b003b04, 0x05011e07, 0x2a1168a4, 0x04000708,   // so.tr.un_320 ms.en.fr_432  ig.ro.mt_433 bg.ru.un_430
  // [30b0]
  0x20000e05, 0x52284a0b, 0x1a6b1e0c, 0x1c2d0d14,   // is.sq.un_330 yo.sw.ha_542  ms.ceb.tl_543 cs.sk.id_666
  0x080407a9, 0x13110707, 0x06040305, 0x2a103b04,   // bg.ru.uk_544 it.ro.et_432  nl.fi.de_333 so.lt.mt_332
  0x0d11230e, 0x2a070413, 0x2a1264ad, 0x0a001708,   // ca.ro.cs_555 fi.it.mt_665  lg.hu.mt_643 sr.mk.un_430
  0x071117a4, 0x101225ad, 0x04100707, 0x0e001022,   // sr.ro.bg_433 eu.hu.lt_643  bg.be.ru_432 lt.is.un_870
  // [30c0]
  0x042a0712, 0x1e1c3505, 0x64282a12, 0x0b000a29,   // it.mt.fi_654 zu.id.ms_333  mt.sw.lg_654 pt.es.un_960
  0x52136e04, 0x3f030c04, 0x1e001012, 0x08033f08,   // hmn.et.ha_332 sv.nl.af_332  lt.ms.un_640 af.nl.no_443
  0x08066b02, 0x1f006e19, 0x083f25a0, 0x2a645509,   // ceb.de.no_222 hmn.cy.un_750  eu.af.no_322 rw.lg.mt_444
  0x196e1a12, 0x061252a4, 0x13072a5a, 0x31002704,   // tl.hmn.gl_654 ha.hu.de_433  mt.it.et_553 gd.az.un_320
  // [30d0]
  0x6e001f22, 0x1a0b6ea7, 0x12000705, 0x1108040c,   // cy.hmn.un_870 hmn.es.tl_532  it.hu.un_330 ru.uk.ro_543
  0x120802ee, 0x2d003205, 0x310e1a07, 0x3500201a,   // da.no.hu_422 bs.sk.un_330  tl.is.az_432 sq.zu.un_760
  0x0d292daf, 0x1a0e270c, 0x640a3507, 0x110a1012,   // sk.sl.cs_655 gd.is.tl_543  zu.pt.lg_432 lt.pt.ro_654
  0x02002704, 0x1600090c, 0x1f04050c, 0x0b190a08,   // gd.da.un_320 pl.hr.un_530  fr.fi.cy_543 pt.gl.es_443
  // [30e0]
  0x6e00050d, 0x5500111b, 0x0d000a12, 0x313b1ea0,   // fr.hmn.un_540 ro.rw.un_770  pt.cs.un_640 ms.so.az_322
  0x113f25ad, 0x6b001a12, 0x072916a9, 0x1000130c,   // eu.af.ro_643 tl.ceb.un_640  hr.sl.it_544 et.lt.un_530
  0x11004a02, 0x123f6ba4, 0x103127ad, 0x2d1307a0,   // yo.ro.un_220 ceb.af.hu_433  gd.az.lt_643 it.et.sk_322
  0x35080c0d, 0x04000705, 0x1300090d, 0x1e00640d,   // sv.no.zu_554 bg.ru.un_330  hi.bh.un_540 lg.ms.un_540
  // [30f0]
  0x081104af, 0x03006b08, 0x3b00110d, 0x051c21a0,   // ru.ro.uk_655 ceb.nl.un_430  ro.so.un_540 jw.id.fr_322
  0x18032307, 0x190d2d0c, 0x18002109, 0x2b2a25a0,   // ca.nl.ga_432 sk.cs.gl_543  fa.ar.un_440 eu.mt.vi_322
  0x2d0d0ba0, 0x2d0f0704, 0x2a072013, 0x4a5325ad,   // es.cs.sk_322 it.lv.sk_332  sq.it.mt_665 eu.ht.yo_643
  0x2d002911, 0x1b0464a4, 0x08001108, 0x0717045a,   // sl.sk.un_630 lg.fi.tr_433  ro.uk.un_430 ru.sr.bg_553
  // [3100]
  0x0410170c, 0x191f0b12, 0x53552811, 0x0f001313,   // sr.be.ru_543 es.cy.gl_654  sw.rw.ht_653 et.lv.un_650
  0x2d001214, 0x10001122, 0x0d0f2807, 0x526428ad,   // hu.sk.un_660 ro.be.un_870  sw.lv.cs_432 sw.lg.ha_643
  0x0e6b64a0, 0x211204a9, 0x132855af, 0x0b001004,   // lg.ceb.is_322 fi.hu.jw_544  rw.sw.et_655 lt.es.un_320
  0x0804070d, 0x1f005502, 0x19000302, 0x111355a9,   // bg.ru.uk_554 rw.cy.un_220  nl.gl.un_220 rw.et.ro_544
  // [3110]
  0x19000104, 0x4a00250d, 0x190b1005, 0x32000808,   // en.gl.un_320 eu.yo.un_540  lt.es.gl_333 no.bs.un_430
  0x1a352804, 0x03001804, 0x200552a4, 0x0e0c0807,   // sw.zu.tl_332 ga.nl.un_320  ha.fr.sq_433 no.sv.is_432
  0x03055508, 0x0f28130c, 0x20003204, 0x03023f05,   // rw.fr.nl_443 et.sw.lv_543  bs.sq.un_320 af.da.nl_333
  0x050311a4, 0x062a250c, 0x0f5210a4, 0x10002520,   // ro.nl.fr_433 eu.mt.de_543  lt.ha.lv_433 eu.lt.un_850
  // [3120]
  0x05003b05, 0x521b2860, 0x3b002519, 0x6b28350c,   // so.fr.un_330 sw.tr.ha_664  eu.so.un_750 zu.sw.ceb_543
  0x35100f08, 0x06002513, 0x213f06ee, 0x4a100f11,   // lv.lt.zu_443 eu.de.un_650  de.af.jw_422 lv.lt.yo_653
  0x20321ca0, 0x1b1013a6, 0x1e4a52ac, 0x0805230c,   // id.bs.sq_322 et.lt.tr_521  ha.yo.ms_632 ca.fr.no_543
  0x0f1335a4, 0x100e0f09, 0x2a2855ec, 0x130f25a4,   // zu.et.lv_433 lv.is.lt_444  rw.sw.mt_644 eu.lv.et_433
  // [3130]
  0x10282104, 0x35002504, 0x12190b04, 0x1c35210c,   // jw.sw.lt_332 eu.zu.un_320  es.gl.hu_332 jw.zu.id_543
  0x1e1c64a4, 0x251e1c0d, 0x52006822, 0x1c1b10a4,   // lg.id.ms_433 id.ms.eu_554  ig.ha.un_870 lt.tr.id_433
  0x6b001e08, 0x3f000804, 0x06001f1b, 0x1b3b5512,   // ms.ceb.un_430 no.af.un_320  cy.de.un_770 rw.so.tr_654
  0x080255a4, 0x551352a9, 0x2800551a, 0x551b3b08,   // rw.da.no_433 ha.et.rw_544  rw.sw.un_760 so.tr.rw_443
  // [3140]
  0x52001a22, 0x641a52ad, 0x101708a4, 0x52211cac,   // tl.ha.un_870 ha.tl.lg_643  uk.sr.be_433 id.jw.ha_632
  0x4a1b5512, 0x31003b12, 0x1100071b, 0x130f1013,   // rw.tr.yo_654 so.az.un_640  bg.ro.un_770 lt.lv.et_665
  0x5228350c, 0x1b005521, 0x1a552105, 0x6b001a35,   // zu.sw.ha_543 rw.tr.un_860  jw.rw.tl_333 tl.ceb.un_A90
  0x1100130c, 0x1a001b20, 0x523b1bad, 0x55281e0b,   // et.ro.un_530 tr.tl.un_850  tr.so.ha_643 ms.sw.rw_542
  // [3150]
  0x550c64ec, 0x211a1e07, 0x1107685a, 0x110f2104,   // lg.sv.rw_644 ms.tl.jw_432  ig.it.ro_553 jw.lv.ro_332
  0x25005221, 0x0f11285a, 0x3b001b08, 0x2811680c,   // ha.eu.un_860 sw.ro.lv_553  tr.so.un_430 ig.ro.sw_543
  0x21356eee, 0x3b520f08, 0x12001107, 0x28521b08,   // hmn.zu.jw_422 lv.ha.so_443  ro.hu.un_420 tr.ha.sw_443
  0x64041055, 0x35531a08, 0x556428a9, 0x0418130d,   // lt.fi.lg_442 tl.ht.zu_443  sw.lg.rw_544 et.ga.fi_554
  // [3160]
  0x2a005205, 0x1e21280c, 0x1b041ead, 0x210f520c,   // ha.mt.un_330 sw.jw.ms_543  ms.fi.tr_643 ha.lv.jw_543
  0x0812185a, 0x0528010c, 0x1c0f1e0c, 0x281a55a4,   // ga.hu.no_553 en.sw.fr_543  ms.lv.id_543 rw.tl.sw_433
  0x1b5355ad, 0x181125ad, 0x08170a02, 0x030f10a9,   // rw.ht.tr_643 eu.ro.ga_643  mk.sr.uk_222 lt.lv.nl_544
  0x120f3b0c, 0x3b1b55ec, 0x09642811, 0x351b550c,   // so.lv.hu_543 rw.tr.so_644  sw.lg.pl_653 rw.tr.zu_543
  // [3170]
  0x1204525a, 0x11090709, 0x1e1c030c, 0x522a3bec,   // ha.fi.hu_553 it.pl.ro_444  nl.id.ms_543 so.mt.ha_644
  0x1318040c, 0x2700042a, 0x281e68a4, 0x2009520c,   // fi.ga.et_543 fi.gd.un_970  ig.ms.sw_433 ha.pl.sq_543
  0x29001c13, 0x033f6404, 0x2500031a, 0x182702a0,   // id.sl.un_650 lg.af.nl_332  nl.eu.un_760 da.gd.ga_322
  0x0518040c, 0x1b0c0208, 0x02123f0c, 0x180768a0,   // fi.ga.fr_543 da.sv.tr_443  af.hu.da_543 ig.it.ga_322
  // [3180]
  0x181f23a4, 0x0b230508, 0x180427ec, 0x07001902,   // ca.cy.ga_433 fr.ca.es_443  gd.fi.ga_644 gl.it.un_220
  0x0f1a04ad, 0x100e3ba4, 0x281304ad, 0x31000a0d,   // fi.tl.lv_643 so.is.lt_433  fi.et.sw_643 pt.az.un_540
  0x23002514, 0x3f2527a0, 0x133f2904, 0x0f1827ec,   // eu.ca.un_660 gd.eu.af_322  sl.af.et_332 gd.ga.lv_644
  0x2a003b14, 0x131e0ea0, 0x07045208, 0x12055205,   // so.mt.un_660 is.ms.et_322  ha.fi.it_443 ha.fr.hu_333
  // [3190]
  0x642855a4, 0x0a2a070e, 0x0d1c0907, 0x1200251a,   // rw.sw.lg_433 it.mt.pt_555  hi.mr.ne_432 eu.hu.un_760
  0x10182704, 0x10040f08, 0x0c0229a4, 0x111e21a9,   // gd.ga.lt_332 lv.fi.lt_443  sl.da.sv_433 jw.ms.ro_544
  0x211c52ec, 0x03136e05, 0x3b202aa7, 0x2b001113,   // ha.id.jw_644 hmn.et.nl_333  mt.sq.so_532 ro.vi.un_650
  0x32055212, 0x11081708, 0x253f100c, 0x12290e12,   // ha.fr.bs_654 sr.uk.ro_443  lt.af.eu_543 is.sl.hu_654
  // [31a0]
  0x230f0aa4, 0x53000702, 0x12132a08, 0x100f0413,   // pt.lv.ca_433 it.ht.un_220  mt.et.hu_443 fi.lv.lt_665
  0x20115504, 0x0f052709, 0x06040f0b, 0x00001201,   // rw.ro.sq_332 gd.fr.lv_444  lv.fi.de_542 ur.un.un_200
  0x0a2b010c, 0x17001004, 0x05232907, 0x35000421,   // en.vi.pt_543 be.sr.un_320  sl.ca.fr_432 fi.zu.un_860
  0x29643504, 0x0a00070e, 0x3b003f09, 0x0f0428ee,   // zu.lg.sl_332 bg.mk.un_550  af.so.un_440 sw.fi.lv_422
  // [31b0]
  0x3f3b0304, 0x3b046ba9, 0x6e00010d, 0x1017080c,   // nl.so.af_332 ceb.fi.so_544  en.hmn.un_540 uk.sr.be_543
  0x07002105, 0x530c1ba4, 0x2d090d0d, 0x20001819,   // jw.it.un_330 tr.sv.ht_433  cs.pl.sk_554 ga.sq.un_750
  0x20001702, 0x3f1a03a9, 0x0b0a03a4, 0x3b000b04,   // sr.sq.un_220 nl.tl.af_544  nl.pt.es_433 es.so.un_320
  0x0a250ead, 0x1b00201a, 0x060b270c, 0x016b31a0,   // is.eu.pt_643 sq.tr.un_760  gd.es.de_543 az.ceb.en_322
  // [31c0]
  0x64003b22, 0x0b3b5512, 0x1f53080b, 0x3f000c04,   // so.lg.un_870 rw.so.es_654  no.ht.cy_542 sv.af.un_320
  0x6b1a550d, 0x031827a4, 0x100725a7, 0x133b070c,   // rw.tl.ceb_554 gd.ga.nl_433  eu.it.lt_532 it.so.et_543
  0x05190b13, 0x3b211308, 0x321c2107, 0x2d0d23a0,   // es.gl.fr_665 et.jw.so_443  jw.id.bs_432 ca.cs.sk_322
  0x1a201208, 0x0b0c64a4, 0x53272012, 0x05001907,   // hu.sq.tl_443 lg.sv.es_433  sq.gd.ht_654 gl.fr.un_420
  // [31d0]
  0x216b1a5a, 0x091f5304, 0x27001108, 0x1e1c10ec,   // tl.ceb.jw_553 ht.cy.pl_332  ro.gd.un_430 lt.id.ms_644
  0x17001308, 0x1e1c11ec, 0x551a530d, 0x13003f08,   // et.sr.un_430 ro.id.ms_644  ht.tl.rw_554 af.et.un_430
  0x6435550c, 0x321725ec, 0x21003b05, 0x080c3ba9,   // rw.zu.lg_543 eu.sr.bs_644  so.jw.un_330 so.sv.no_544
  0x06023fa9, 0x0711100c, 0x1107010c, 0x0602230c,   // af.da.de_544 lt.ro.it_543  en.it.ro_543 ca.da.de_543
  // [31e0]
  0x21521aa4, 0x0c083107, 0x0511180c, 0x10002809,   // tl.ha.jw_433 az.no.sv_432  ga.ro.fr_543 sw.lt.un_440
  0x04031ca0, 0x1709520c, 0x281053a4, 0x0c0708a0,   // id.nl.fi_322 ha.pl.sr_543  ht.lt.sw_433 no.it.sv_322
  0x0710230c, 0x3f3b03af, 0x106455a4, 0x061225ad,   // ca.lt.it_543 nl.so.af_655  rw.lg.lt_433 eu.hu.de_643
  0x25001e08, 0x1e130409, 0x0800290d, 0x2310110c,   // ms.eu.un_430 fi.et.ms_444  sl.no.un_540 ro.lt.ca_543
  // [31f0]
  0x5212070c, 0x06000508, 0x16113107, 0x10006407,   // it.hu.ha_543 fr.de.un_430  az.ro.hr_432 lg.lt.un_420
  0x0f0a100d, 0x03006e19, 0x2564550d, 0x06055311,   // lt.pt.lv_554 hmn.nl.un_750  rw.lg.eu_554 ht.fr.de_653
  0x28645505, 0x0f1a130d, 0x3f351307, 0x2d000a09,   // rw.lg.sw_333 et.tl.lv_554  et.zu.af_432 pt.sk.un_440
  0x6e686b05, 0x0e001707, 0x1e1c130c, 0x1b282a55,   // ceb.ig.hmn_333 sr.is.un_420  et.id.ms_543 mt.sw.tr_442
  // [3200]
  0x11001009, 0x04101c07, 0x11050404, 0x070a2355,   // lt.ro.un_440 id.lt.fi_432  fi.fr.ro_332 ca.pt.it_442
  0x08023fa0, 0x08115308, 0x16530408, 0x1768130c,   // af.da.no_322 ht.ro.no_443  fi.ht.hr_443 et.ig.sr_543
  0x6b0913a4, 0x04133508, 0x1a64280b, 0x04081702,   // et.pl.ceb_433 zu.et.fi_443  sw.lg.tl_542 sr.uk.ru_222
  0x09131c11, 0x17002109, 0x08033f0d, 0x31321708,   // mr.bh.hi_653 jw.sr.un_440  af.nl.no_554 sr.bs.az_443
  // [3210]
  0x32080c04, 0x21000a08, 0x32003b08, 0x35002011,   // sv.no.bs_332 pt.jw.un_430  so.bs.un_430 sq.zu.un_630
  0x0b6b3ba0, 0x213b1ca4, 0x21006b04, 0x2b001c0b,   // so.ceb.es_322 id.so.jw_433  ceb.jw.un_320 id.vi.un_520
  0x0a003b19, 0x5500350c, 0x0a0717a0, 0x55003b18,   // so.pt.un_750 zu.rw.un_530  sr.bg.mk_322 so.rw.un_740
  0x3b1e1c08, 0x210c13af, 0x6e00210c, 0x35285512,   // id.ms.so_443 et.sv.jw_655  jw.hmn.un_530 rw.sw.zu_654
  // [3220]
  0x0e000412, 0x4a6e6804, 0x28553b60, 0x232811a7,   // fi.is.un_640 ig.hmn.yo_332  so.rw.sw_664 ro.sw.ca_532
  0x1004085a, 0x32170fec, 0x0b2d0d0d, 0x041710a7,   // uk.ru.be_553 lv.sr.bs_644  cs.sk.es_554 be.sr.ru_532
  0x09000108, 0x0a071002, 0x6e016ba7, 0x0a524aee,   // en.pl.un_430 be.bg.mk_222  ceb.en.hmn_532 yo.ha.pt_422
  0x28006414, 0x0d00041a, 0x0d2928a6, 0x13001f04,   // lg.sw.un_660 fi.cs.un_760  sw.sl.cs_521 cy.et.un_320
  // [3230]
  0x25000a07, 0x3b0b210c, 0x0e002a04, 0x112305ad,   // pt.eu.un_420 jw.es.so_543  mt.is.un_320 fr.ca.ro_643
  0x211c1113, 0x2d0d01ee, 0x0e001c1a, 0x35213b08,   // ro.id.jw_665 en.cs.sk_422  id.is.un_760 so.jw.zu_443
  0x2b170ba0, 0x1e1c0ea9, 0x3f20090c, 0x32170ead,   // es.sr.vi_322 is.id.ms_544  pl.sq.af_543 is.sr.bs_643
  0x08022014, 0x1b680e09, 0x01001e04, 0x4a643b08,   // sq.da.no_666 is.ig.tr_444  ms.en.un_320 so.lg.yo_443
  // [3240]
  0x12004a0d, 0x182b20a4, 0x2d00190e, 0x13643b0b,   // yo.hu.un_540 sq.vi.ga_433  gl.sk.un_550 so.lg.et_542
  0x0a000e2a, 0x081f0c0c, 0x2d0d28a0, 0x02003504,   // is.pt.un_970 sv.cy.no_543  sw.cs.sk_322 zu.da.un_320
  0x643b13a4, 0x1f18270c, 0x0a040855, 0x04000908,   // et.so.lg_433 gd.ga.cy_543  uk.ru.mk_442 pl.fi.un_430
  0x133b6407, 0x1031110c, 0x012d0d55, 0x27002018,   // lg.so.et_432 ro.az.lt_543  cs.sk.en_442 sq.gd.un_740
  // [3250]
  0x06110302, 0x0a170811, 0x64133baf, 0x0335285a,   // nl.ro.de_222 uk.sr.mk_653  so.et.lg_655 sw.zu.nl_553
  0x10110708, 0x32171ca0, 0x0f000922, 0x02000619,   // it.ro.lt_443 id.sr.bs_322  pl.lv.un_870 de.da.un_750
  0x3b136408, 0x316b1ba4, 0x2d0d01a9, 0x1900010c,   // lg.et.so_443 tr.ceb.az_433  en.cs.sk_544 en.gl.un_530
  0x19122d55, 0x0e2a200c, 0x21001220, 0x6b000919,   // sk.hu.gl_442 sq.mt.is_543  ur.fa.un_850 pl.ceb.un_750
  // [3260]
  0x531c0e04, 0x1f11070b, 0x680d04ad, 0x03000705,   // is.id.ht_332 it.ro.cy_542  fi.cs.ig_643 it.nl.un_330
  0x53050e05, 0x02000a04, 0x0e1b010c, 0x11080a0c,   // is.fr.ht_333 pt.da.un_320  en.tr.is_543 mk.uk.ro_543
  0x13280e0c, 0x201b3b07, 0x1b001e13, 0x23002b2b,   // is.sw.et_543 so.tr.sq_432  ms.tr.un_650 vi.ca.un_980
  0x04080707, 0x4a643b0c, 0x072a1309, 0x043b6408,   // bg.uk.ru_432 so.lg.yo_543  et.mt.it_444 lg.so.fi_443
  // [3270]
  0x2b1c1e12, 0x2a550e0c, 0x230a0b5a, 0x13643b13,   // ms.id.vi_654 is.rw.mt_543  es.pt.ca_553 so.lg.et_665
  0x10000807, 0x32001619, 0x12290fad, 0x230a0108,   // uk.be.un_420 hr.bs.un_750  lv.sl.hu_643 en.pt.ca_443
  0x13121f12, 0x6b010607, 0x29091309, 0x20120304,   // cy.hu.et_654 de.en.ceb_432  et.pl.sl_444 nl.hu.sq_332
  0x0e641aec, 0x6b1f06ac, 0x3f1e01a7, 0x1f000619,   // tl.lg.is_644 de.cy.ceb_632  en.ms.af_532 de.cy.un_750
  // [3280]
  0x52355504, 0x1e1c5509, 0x310e2da4, 0x192d1205,   // rw.zu.ha_332 rw.id.ms_444  sk.is.az_433 hu.sk.gl_333
  0x2d1b53ad, 0x1c2120af, 0x180e12b4, 0x3b1355af,   // ht.tr.sk_643 sq.jw.id_655  hu.is.ga_754 rw.et.so_655
  0x0e071c0c, 0x032b1cee, 0x11132813, 0x07130e55,   // id.it.is_543 id.vi.nl_422  sw.et.ro_665 is.et.it_442
  0x1f0e2512, 0x0b231904, 0x3b002808, 0x29072da0,   // eu.is.cy_654 gl.ca.es_332  sw.so.un_430 sk.it.sl_322
  // [3290]
  0x17000422, 0x2a180911, 0x13002805, 0x28094a0d,   // ru.sr.un_870 pl.ga.mt_653  sw.et.un_330 yo.pl.sw_554
  0x6400551b, 0x1a645311, 0x13111aee, 0x2d3b550c,   // rw.lg.un_770 ht.lg.tl_653  tl.ro.et_422 rw.so.sk_543
  0x2100281a, 0x0e092907, 0x0f002913, 0x253555ad,   // sw.jw.un_760 sl.pl.is_432  sl.lv.un_650 rw.zu.eu_643
  0x3b64550c, 0x0e002a13, 0x0500010c, 0x1b553507,   // rw.lg.so_543 mt.is.un_650  en.fr.un_530 zu.rw.tr_432
  // [32a0]
  0x641a55a4, 0x13003b1a, 0x6421550c, 0x53000719,   // rw.tl.lg_433 so.et.un_760  rw.jw.lg_543 it.ht.un_750
  0x281e1c11, 0x130e55a4, 0x6e25040d, 0x0810070c,   // id.ms.sw_653 rw.is.et_433  fi.eu.hmn_554 bg.be.uk_543
  0x35285514, 0x03063fec, 0x042528a9, 0x25002823,   // rw.sw.zu_666 af.de.nl_644  sw.eu.fi_544 sw.eu.un_880
  0x2a00290e, 0x644a68a4, 0x12006413, 0x1c352112,   // sl.mt.un_550 ig.yo.lg_433  lg.hu.un_650 jw.zu.id_654
  // [32b0]
  0x25282308, 0x0c070805, 0x171629ee, 0x21002504,   // ca.sw.eu_443 no.it.sv_333  sl.hr.sr_422 eu.jw.un_320
  0x4a28680c, 0x080e1011, 0x02002504, 0x2a00291a,   // ig.sw.yo_543 lt.is.no_653  eu.da.un_320 sl.mt.un_760
  0x10000d12, 0x06005304, 0x18002804, 0x1e001c13,   // cs.lt.un_640 ht.de.un_320  sw.ga.un_320 id.ms.un_650
  0x282025af, 0x6e280407, 0x2500230d, 0x28251e0c,   // eu.sq.sw_655 fi.sw.hmn_432  ca.eu.un_540 ms.eu.sw_543
  // [32c0]
  0x29190707, 0x17071002, 0x07291604, 0x1b125204,   // it.gl.sl_432 be.bg.sr_222  hr.sl.it_332 ha.hu.tr_332
  0x202825ad, 0x2104250c, 0x25130707, 0x04001c08,   // eu.sw.sq_643 eu.fi.jw_543  it.et.eu_432 id.fi.un_430
  0x2b00191b, 0x2d00180e, 0x35004a09, 0x25000c05,   // gl.vi.un_770 ga.sk.un_550  yo.zu.un_440 sv.eu.un_330
  0x162a2904, 0x521e4aa7, 0x080a02a0, 0x1600320c,   // sl.mt.hr_332 yo.ms.ha_532  da.pt.no_322 bs.hr.un_530
  // [32d0]
  0x1f006e09, 0x29100faf, 0x162905a7, 0x133116ee,   // hmn.cy.un_440 lv.lt.sl_655  fr.sl.hr_532 hr.az.et_422
  0x6b0501a4, 0x201a6b12, 0x1f0918a4, 0x08000a02,   // en.fr.ceb_433 ceb.tl.sq_654  ga.pl.cy_433 mk.uk.un_220
  0x2d000914, 0x2d0d120e, 0x09213f07, 0x10002812,   // pl.sk.un_660 hu.cs.sk_555  af.jw.pl_432 sw.lt.un_640
  0x23002902, 0x07000819, 0x08000414, 0x1c0d0908,   // sl.ca.un_220 uk.bg.un_750  ru.uk.un_660 hi.ne.mr_443
  // [32e0]
  0x55286b04, 0x4a005308, 0x282a180c, 0x28002a04,   // ceb.sw.rw_332 ht.yo.un_430  ga.mt.sw_543 mt.sw.un_320
  0x130802ee, 0x120a1fee, 0x18011f04, 0x19180bee,   // da.no.et_422 cy.pt.hu_422  cy.en.ga_332 es.ga.gl_422
  0x1f520b04, 0x1a005502, 0x10202504, 0x111c1ead,   // es.ha.cy_332 rw.tl.un_220  eu.sq.lt_332 ms.id.ro_643
  0x20523fa4, 0x20216b60, 0x683520ee, 0x5528200c,   // af.ha.sq_433 ceb.jw.sq_664  sq.zu.ig_422 sq.sw.rw_543
  // [32f0]
  0x0a0711a6, 0x031101a4, 0x09103fa4, 0x0b0603af,   // ro.bg.mk_521 en.ro.nl_433  af.lt.pl_433 nl.de.es_655
  0x2809040c, 0x20003507, 0x2500201a, 0x100904ac,   // fi.pl.sw_543 zu.sq.un_420  sq.eu.un_760 fi.pl.lt_632
  0x180711af, 0x072025ee, 0x1b1120a6, 0x28521e0c,   // ro.it.ga_655 eu.sq.it_422  sq.ro.tr_521 ms.ha.sw_543
  0x553f20ec, 0x050401a6, 0x1e2025a9, 0x09022d0c,   // sq.af.rw_644 en.fi.fr_521  eu.sq.ms_544 sk.da.pl_543
  // [3300]
  0x1b523507, 0x051f2308, 0x252307a7, 0x21006b09,   // zu.ha.tr_432 ca.cy.fr_443  it.ca.eu_532 ceb.jw.un_440
  0x52004a13, 0x07092d0b, 0x04000a02, 0x2d070ba4,   // yo.ha.un_650 sk.pl.it_542  mk.ru.un_220 es.it.sk_433
  0x286b1a08, 0x0e3b52a0, 0x213b1e11, 0x6b1a1fad,   // tl.ceb.sw_443 ha.so.is_322  ms.so.jw_653 cy.tl.ceb_643
  0x3f010704, 0x1c1a1ea9, 0x2b0128a0, 0x1a003b20,   // it.en.af_332 ms.tl.id_544  sw.en.vi_322 so.tl.un_850
  // [3310]
  0x213b1e08, 0x1200640b, 0x170a1004, 0x03060912,   // ms.so.jw_443 lg.hu.un_520  be.mk.sr_332 pl.de.nl_654
  0x04003b13, 0x25002013, 0x521a6b5a, 0x083f27a0,   // so.fi.un_650 sq.eu.un_650  ceb.tl.ha_553 gd.af.no_322
  0x0e6b1a07, 0x1c3568ee, 0x52280960, 0x13000412,   // tl.ceb.is_432 ig.zu.id_422  pl.sw.ha_664 fi.et.un_640
  0x64005222, 0x28002019, 0x2d0a050c, 0x0b072304,   // ha.lg.un_870 sq.sw.un_750  fr.pt.sk_543 ca.it.es_332
  // [3320]
  0x03133f04, 0x103f0412, 0x640c520c, 0x09110f14,   // af.et.nl_332 fi.af.lt_654  ha.sv.lg_543 lv.ro.pl_666
  0x0400062b, 0x1c521e0b, 0x200a07a4, 0x03000929,   // de.fi.un_980 ms.ha.id_542  it.pt.sq_433 pl.nl.un_960
  0x0d0105a4, 0x18120e08, 0x2d042a0c, 0x531a2107,   // fr.en.cs_433 is.hu.ga_443  mt.fi.sk_543 jw.tl.ht_432
  0x010608a0, 0x25071807, 0x1200050e, 0x18311b0d,   // no.de.en_322 ga.it.eu_432  fr.hu.un_550 tr.az.ga_554
  // [3330]
  0x04131104, 0x20002504, 0x35281c08, 0x20050204,   // ro.et.fi_332 eu.sq.un_320  id.sw.zu_443 da.fr.sq_332
  0x0e00230e, 0x1a521e0c, 0x2d0d1105, 0x100e120c,   // ca.is.un_550 ms.ha.tl_543  ro.cs.sk_333 hu.is.lt_543
  0x1e210107, 0x0c0711a7, 0x0a050112, 0x122a2008,   // en.jw.ms_432 ro.it.sv_532  en.fr.pt_654 sq.mt.hu_443
  0x12080c0d, 0x2a6425a9, 0x0c006404, 0x180a0ca9,   // sv.no.hu_554 eu.lg.mt_544  lg.sv.un_320 sv.pt.ga_544
  // [3340]
  0x6b3b1aec, 0x17111055, 0x116820a9, 0x3f0902a0,   // tl.so.ceb_644 be.ro.sr_442  sq.ig.ro_544 da.pl.af_322
  0x080223a0, 0x06006408, 0x03063fee, 0x3f120c07,   // ca.da.no_322 lg.de.un_430  af.de.nl_422 sv.hu.af_432
  0x1a080205, 0x111e1c04, 0x53351204, 0x0c6408a0,   // da.no.tl_333 id.ms.ro_332  hu.zu.ht_332 no.lg.sv_322
  0x6b1a0ba4, 0x25190b0d, 0x050a3f08, 0x110410af,   // es.tl.ceb_433 es.gl.eu_554  af.pt.fr_443 be.ru.ro_655
  // [3350]
  0x06005204, 0x29003204, 0x2d000e20, 0x1a311ead,   // ha.de.un_320 bs.sl.un_320  is.sk.un_850 ms.az.tl_643
  0x12001e13, 0x162d68a0, 0x28001219, 0x12071108,   // ms.hu.un_650 ig.sk.hr_322  hu.sw.un_750 ro.it.hu_443
  0x281a180c, 0x5200641a, 0x120a2d0d, 0x12072a12,   // ga.tl.sw_543 lg.ha.un_760  sk.pt.hu_554 mt.it.hu_654
  0x1b0e0c0c, 0x6b1a5212, 0x252164a6, 0x0b182707,   // sv.is.tr_543 ha.tl.ceb_654  lg.jw.eu_521 gd.ga.es_432
  // [3360]
  0x0b071107, 0x1c2155a9, 0x11251ea0, 0x09251813,   // ro.it.es_432 rw.jw.id_544  ms.eu.ro_322 ga.eu.pl_665
  0x553564ad, 0x6b1a520d, 0x551a64a4, 0x0e00190e,   // lg.zu.rw_643 ha.tl.ceb_554  lg.tl.rw_433 gl.is.un_550
  0x2a0f2155, 0x6b645509, 0x272d0d0e, 0x6b000712,   // jw.lv.mt_442 rw.lg.ceb_444  cs.sk.gd_555 it.ceb.un_640
  0x64001008, 0x040f25af, 0x04002504, 0x254a6407,   // lt.lg.un_430 eu.lv.fi_655  eu.fi.un_320 lg.yo.eu_432
  // [3370]
  0x293b520c, 0x13002022, 0x64555211, 0x322a1712,   // ha.so.sl_543 sq.et.un_870  ha.rw.lg_653 sr.mt.bs_654
  0x20005504, 0x64551ba9, 0x211b520c, 0x0d001604,   // rw.sq.un_320 tr.rw.lg_544  ha.tr.jw_543 hr.cs.un_320
  0x1600170c, 0x35084aee, 0x110625a4, 0x1c001f08,   // sr.hr.un_530 yo.no.zu_422  eu.de.ro_433 cy.id.un_430
  0x1335520b, 0x046425a7, 0x023f1f12, 0x1c281ea9,   // ha.zu.et_542 eu.lg.fi_532  cy.af.da_654 ms.sw.id_544
  // [3380]
  0x09001222, 0x0b0407ec, 0x0f101c0c, 0x0c071f07,   // hu.pl.un_870 it.fi.es_644  id.lt.lv_543 cy.it.sv_432
  0x1e3b2a11, 0x04071109, 0x130f100d, 0x28204aa0,   // mt.so.ms_653 ro.bg.ru_444  lt.lv.et_554 yo.sq.sw_322
  0x1f3b52a9, 0x1e1c3109, 0x1e1c52ee, 0x13041ba9,   // ha.so.cy_544 az.id.ms_444  ha.id.ms_422 tr.fi.et_544
  0x210a0b05, 0x252d0d60, 0x1b00320c, 0x0a2319a0,   // es.pt.jw_333 cs.sk.eu_664  bs.tr.un_530 gl.ca.pt_322
  // [3390]
  0x20001f02, 0x0f254aee, 0x2d010209, 0x06006e22,   // cy.sq.un_220 yo.eu.lv_422  da.en.sk_444 hmn.de.un_870
  0x13250d0c, 0x1c0e6ead, 0x6b001c13, 0x0c311b13,   // cs.eu.et_543 hmn.is.id_643  id.ceb.un_650 tr.az.sv_665
  0x6b1a0107, 0x01250307, 0x1100171a, 0x10040e08,   // en.tl.ceb_432 nl.eu.en_432  sr.ro.un_760 is.fi.lt_443
  0x1a6b4a13, 0x3b4a070c, 0x6b1a1e0c, 0x1f001214,   // yo.ceb.tl_665 it.yo.so_543  ms.tl.ceb_543 hu.cy.un_660
  // [33a0]
  0x18050807, 0x1c3f030c, 0x08031ca0, 0x52216b13,   // no.fr.ga_432 nl.af.id_543  id.nl.no_322 ceb.jw.ha_665
  0x2d1806a7, 0x021208ee, 0x161b5255, 0x203202ad,   // de.ga.sk_532 no.hu.da_422  ha.tr.hr_442 da.bs.sq_643
  0x216b1a11, 0x13211ca6, 0x1b0705a9, 0x271218a6,   // tl.ceb.jw_653 id.jw.et_521  fr.it.tr_544 ga.hu.gd_521
  0x5521280c, 0x4a64040c, 0x2b002104, 0x2b211c08,   // sw.jw.rw_543 fi.lg.yo_543  jw.vi.un_320 id.jw.vi_443
  // [33b0]
  0x110701a4, 0x08271307, 0x071209a7, 0x0b232da4,   // en.it.ro_433 et.gd.no_432  pl.hu.it_532 sk.ca.es_433
  0x21041c11, 0x2d0d20af, 0x321019ee, 0x0e0208af,   // id.fi.jw_653 sq.cs.sk_655  gl.lt.bs_422 no.da.is_655
  0x08002504, 0x1e1b3111, 0x170710ee, 0x31201c07,   // eu.no.un_320 az.tr.ms_653  be.bg.sr_422 id.sq.az_432
  0x1c5255a6, 0x52002502, 0x190b11a6, 0x080321a0,   // rw.ha.id_521 eu.ha.un_220  ro.es.gl_521 jw.nl.no_322
  // [33c0]
  0x0c216ea7, 0x073b1c07, 0x122008a9, 0x316e3b12,   // hmn.jw.sv_532 id.so.it_432  no.sq.hu_544 so.hmn.az_654
  0x2b3b120c, 0x530a05a9, 0x10002a21, 0x11074aa0,   // hu.so.vi_543 fr.pt.ht_544  mt.lt.un_860 yo.it.ro_322
  0x07112304, 0x0100080d, 0x1a000808, 0x29005205,   // ca.ro.it_332 no.en.un_540  no.tl.un_430 ha.sl.un_330
  0x28270ba4, 0x6b1c1aa4, 0x52351a13, 0x162307a0,   // es.gd.sw_433 tl.id.ceb_433  tl.zu.ha_665 it.ca.hr_322
  // [33d0]
  0x1a522113, 0x0e3b0da0, 0x09000705, 0x092852ad,   // jw.ha.tl_665 cs.so.is_322  it.pl.un_330 ha.sw.pl_643
  0x03071105, 0x2864100c, 0x3b285212, 0x290f32ee,   // ro.it.nl_333 lt.lg.sw_543  ha.sw.so_654 bs.lv.sl_422
  0x0600640b, 0x68002a08, 0x68005214, 0x52281aa9,   // lg.de.un_520 mt.ig.un_430  ha.ig.un_660 tl.sw.ha_544
  0x313b2a08, 0x533b28a0, 0x2d0d100c, 0x0e6b1aa7,   // mt.so.az_443 sw.so.ht_322  lt.cs.sk_543 tl.ceb.is_532
  // [33e0]
  0x3f005205, 0x13043b0c, 0x02090512, 0x3f113507,   // ha.af.un_330 so.fi.et_543  fr.pl.da_654 zu.ro.af_432
  0x285209ad, 0x0810110c, 0x3b3521ec, 0x27282504,   // pl.ha.sw_643 ro.be.uk_543  jw.zu.so_644 eu.sw.gd_332
  0x211a2807, 0x2b040804, 0x020906a0, 0x64354a07,   // sw.tl.jw_432 no.fi.vi_332  de.pl.da_322 yo.zu.lg_432
  0x13003b0d, 0x21095212, 0x2d0306ec, 0x281a520c,   // so.et.un_540 ha.pl.jw_654  de.nl.sk_644 ha.tl.sw_543
  // [33f0]
  0x52002804, 0x0c1c31a0, 0x230205ad, 0x215535ee,   // sw.ha.un_320 az.id.sv_322  fr.da.ca_643 zu.rw.jw_422
  0x553f2dee, 0x2d090607, 0x35643ba7, 0x18000514,   // sk.af.rw_422 de.pl.sk_432  so.lg.zu_532 fr.ga.un_660
  0x01005308, 0x010335a0, 0x110408a4, 0x31536405,   // ht.en.un_430 zu.nl.en_322  uk.ru.ro_433 lg.ht.az_333
  0x2d001707, 0x3b130408, 0x0c350205, 0x0413110c,   // sr.sk.un_420 fi.et.so_443  da.zu.sv_333 ro.et.fi_543

  // [3400]
  0x20071b55, 0x03060204, 0x01190bee, 0x311b0107,   // tr.it.sq_442 da.de.nl_332  es.gl.en_422 en.tr.az_432
  0x21090107, 0x64321708, 0x051364af, 0x10110712,   // en.pl.jw_432 sr.bs.lg_443  lg.et.fr_655 it.ro.lt_654
  0x31001b05, 0x08321609, 0x2a52280c, 0x53132a04,   // tr.az.un_330 hr.bs.no_444  sw.ha.mt_543 mt.et.ht_332
  0x2a6b010c, 0x3b000108, 0x293f0107, 0x2a00010d,   // en.ceb.mt_543 en.so.un_430  en.af.sl_432 en.mt.un_540
  // [3410]
  0x0d1c0904, 0x081f28a9, 0x030121a0, 0x530d3fee,   // hi.mr.ne_332 sw.cy.no_544  jw.en.nl_322 af.cs.ht_422
  0x07005313, 0x0f6b01ad, 0x106b55ee, 0x23070508,   // ht.it.un_650 en.ceb.lv_643  rw.ceb.lt_422 fr.it.ca_443
  0x050c0809, 0x35001c02, 0x1b5501ee, 0x686b010c,   // no.sv.fr_444 id.zu.un_220  en.rw.tr_422 en.ceb.ig_543
  0x091c13ee, 0x13002a13, 0x3b001c0d, 0x09070a04,   // bh.mr.hi_422 mt.et.un_650  id.so.un_540 pt.it.pl_332
  // [3420]
  0x1c0d095a, 0x281c6402, 0x18006b09, 0x0727010c,   // hi.ne.mr_553 lg.id.sw_222  ceb.ga.un_440 en.gd.it_543
  0x686b350c, 0x0a2305a4, 0x35001704, 0x0c2a01a4,   // zu.ceb.ig_543 fr.ca.pt_433  sr.zu.un_320 en.mt.sv_433
  0x072301a4, 0x130108a4, 0x181127a7, 0x122a0708,   // en.ca.it_433 no.en.et_433  gd.ro.ga_532 it.mt.hu_443
  0x160932ee, 0x1c001329, 0x04003f04, 0x2a003114,   // bs.pl.hr_422 bh.mr.un_960  af.fi.un_320 az.mt.un_660
  // [3430]
  0x05001702, 0x523b2855, 0x0d091312, 0x051a01a4,   // sr.fr.un_220 sw.so.ha_442  bh.hi.ne_654 en.tl.fr_433
  0x1e1c1714, 0x05090707, 0x191729a9, 0x12001c04,   // sr.id.ms_666 it.pl.fr_432  sl.sr.gl_544 id.hu.un_320
  0x211e290c, 0x08100aec, 0x21352711, 0x3b0464a4,   // sl.ms.jw_543 mk.be.uk_644  gd.zu.jw_653 lg.fi.so_433
  0x35002908, 0x08022005, 0x64352111, 0x1f3f0408,   // sl.zu.un_430 sq.da.no_333  jw.zu.lg_653 fi.af.cy_443
  // [3440]
  0x1635290c, 0x0b190a13, 0x3b00352a, 0x1e3b0d12,   // sl.zu.hr_543 pt.gl.es_665  zu.so.un_970 cs.so.ms_654
  0x08170712, 0x06130c0c, 0x0f131005, 0x18060e07,   // bg.sr.uk_654 sv.et.de_543  lt.et.lv_333 is.de.ga_432
  0x0a00110c, 0x190b0c09, 0x641e2505, 0x29000f05,   // ro.mk.un_530 sv.es.gl_444  eu.ms.lg_333 lv.sl.un_330
  0x03003b18, 0x171b250b, 0x080e1f05, 0x0a0710a0,   // so.nl.un_740 eu.tr.sr_542  cy.is.no_333 be.bg.mk_322
  // [3450]
  0x554a6460, 0x4a2d0d14, 0x16291ca0, 0x061304ec,   // lg.yo.rw_664 cs.sk.yo_666  id.sl.hr_322 fi.et.de_644
  0x04080c0c, 0x640a3b11, 0x23000609, 0x6b2127a0,   // sv.no.fi_543 so.pt.lg_653  de.ca.un_440 gd.jw.ceb_322
  0x0f3f0807, 0x1c0904a7, 0x11000709, 0x27132dad,   // no.af.lv_432 fi.pl.id_532  it.ro.un_440 sk.et.gd_643
  0x0b0c0255, 0x310c080c, 0x0e6b2714, 0x29003519,   // da.sv.es_442 no.sv.az_543  gd.ceb.is_666 zu.sl.un_750
  // [3460]
  0x1c111e0c, 0x31002a13, 0x10090fac, 0x12002721,   // ms.ro.id_543 mt.az.un_650  lv.pl.lt_632 gd.hu.un_860
  0x3f120207, 0x2017290c, 0x20322a02, 0x02066bee,   // da.hu.af_432 sl.sr.sq_543  mt.bs.sq_222 ceb.de.da_422
  0x4a1a64a0, 0x1a6b3b12, 0x10002d19, 0x1e000305,   // lg.tl.yo_322 so.ceb.tl_654  sk.lt.un_750 nl.ms.un_330
  0x27555209, 0x06000702, 0x0c0a04ec, 0x11000c1b,   // ha.rw.gd_444 it.de.un_220  fi.pt.sv_644 sv.ro.un_770
  // [3470]
  0x10070413, 0x041b3f08, 0x523b550c, 0x04003f1a,   // ru.bg.be_665 af.tr.fi_443  rw.so.ha_543 af.fi.un_760
  0x31002a0e, 0x0f310c02, 0x04271813, 0x080e29a4,   // mt.az.un_550 sv.az.lv_222  ga.gd.fi_665 sl.is.no_433
  0x020611ee, 0x13030c05, 0x2a1e5205, 0x101827ad,   // ro.de.da_422 sv.nl.et_333  ha.ms.mt_333 gd.ga.lt_643
  0x0e001222, 0x2705010c, 0x0d1e1c04, 0x04001822,   // hu.is.un_870 en.fr.gd_543  id.ms.cs_332 ga.fi.un_870
  // [3480]
  0x06000104, 0x2d100faf, 0x1c2b640c, 0x11002809,   // en.de.un_320 lv.lt.sk_655  lg.vi.id_543 sw.ro.un_440
  0x1f091855, 0x3b2b04a7, 0x16291704, 0x08006b02,   // ga.pl.cy_442 fi.vi.so_532  sr.sl.hr_332 ceb.no.un_220
  0x21552860, 0x1a6b1e07, 0x4a113b04, 0x68271813,   // sw.rw.jw_664 ms.ceb.tl_432  so.ro.yo_332 ga.gd.ig_665
  0x28000423, 0x1f5311a4, 0x681a6b12, 0x130410a4,   // fi.sw.un_880 ro.ht.cy_433  ceb.tl.ig_654 lt.fi.et_433
  // [3490]
  0x08003f02, 0x071a100c, 0x271107a4, 0x0b00520d,   // af.no.un_220 lt.tl.it_543  it.ro.gd_433 ha.es.un_540
  0x11002a04, 0x00006b2d, 0x3b002814, 0x0d001318,   // mt.ro.un_320 ceb.un.un_A00  sw.so.un_660 bh.ne.un_740
  0x180e2702, 0x0e003204, 0x062a680b, 0x64130f08,   // gd.is.ga_222 bs.is.un_320  ig.mt.de_542 lv.et.lg_443
  0x1c214aa0, 0x3507640c, 0x04201305, 0x0f111313,   // yo.jw.id_322 lg.it.zu_543  et.sq.fi_333 et.ro.lv_665
  // [34a0]
  0x081e1c04, 0x052701a4, 0x2100100d, 0x1f6b35ee,   // id.ms.no_332 en.gd.fr_433  lt.jw.un_540 zu.ceb.cy_422
  0x041801a4, 0x35130f09, 0x011827ad, 0x28133514,   // en.ga.fi_433 lv.et.zu_444  gd.ga.en_643 zu.et.sw_666
  0x073b27ad, 0x171a5255, 0x281f200c, 0x0f136408,   // gd.so.it_643 ha.tl.sr_442  sq.cy.sw_543 lg.et.lv_443
  0x043b1c07, 0x07100a07, 0x6b2a2713, 0x1e04130c,   // id.so.fi_432 mk.be.bg_432  gd.mt.ceb_665 et.fi.ms_543
  // [34b0]
  0x68041312, 0x0a28350c, 0x021b1808, 0x080201af,   // et.fi.ig_654 zu.sw.pt_543  ga.tr.da_443 en.da.no_655
  0x1000011a, 0x533f010c, 0x180506a9, 0x0c00030c,   // en.lt.un_760 en.af.ht_543  de.fr.ga_544 nl.sv.un_530
  0x32160909, 0x27061e05, 0x17232102, 0x533f13ad,   // pl.hr.bs_444 ms.de.gd_333  jw.ca.sr_222 et.af.ht_643
  0x20000219, 0x25033f09, 0x023f13a4, 0x0f642805,   // da.sq.un_750 af.nl.eu_444  et.af.da_433 sw.lg.lv_333
  // [34c0]
  0x521328ad, 0x1a0c6ba4, 0x3f1327a4, 0x0420130c,   // sw.et.ha_643 ceb.sv.tl_433  gd.et.af_433 et.sq.fi_543
  0x19001012, 0x11000121, 0x10001f23, 0x09004a08,   // lt.gl.un_640 en.ro.un_860  cy.lt.un_880 yo.pl.un_430
  0x12002008, 0x2a001e07, 0x0c2552a4, 0x091827af,   // sq.hu.un_430 ms.mt.un_420  ha.eu.sv_433 gd.ga.pl_655
  0x19530b08, 0x070e08a0, 0x09271812, 0x35006822,   // es.ht.gl_443 no.is.it_322  ga.gd.pl_654 ig.zu.un_870
  // [34d0]
  0x0c081704, 0x3b3f1b08, 0x04111708, 0x051f18a4,   // sr.no.sv_332 tr.af.so_443  sr.ro.ru_443 ga.cy.fr_433
  0x0d001e07, 0x10070a13, 0x5300682a, 0x041355ec,   // ms.cs.un_420 mk.bg.be_665  ig.ht.un_970 rw.et.fi_644
  0x642855af, 0x065301a4, 0x19050107, 0x0603530c,   // rw.sw.lg_655 en.ht.de_433  en.fr.gl_432 ht.nl.de_543
  0x2a182709, 0x2d0d06a9, 0x3f1320a9, 0x18092713,   // gd.ga.mt_444 de.cs.sk_544  sq.et.af_544 gd.pl.ga_665
  // [34e0]
  0x35002313, 0x040d2dad, 0x0600280e, 0x09270605,   // ca.zu.un_650 sk.cs.fi_643  sw.de.un_550 de.gd.pl_333
  0x18272a0c, 0x0306270c, 0x12003508, 0x64003508,   // mt.gd.ga_543 gd.de.nl_543  zu.hu.un_430 zu.lg.un_430
  0x195306a4, 0x0f006819, 0x06003b19, 0x2500530c,   // de.ht.gl_433 ig.lv.un_750  so.de.un_750 ht.eu.un_530
  0x01003f02, 0x1e1c3ba4, 0x270918af, 0x091827a9,   // af.en.un_220 so.id.ms_433  ga.pl.gd_655 gd.ga.pl_544
  // [34f0]
  0x21000c0c, 0x6805060c, 0x32172aa9, 0x0e020c0c,   // sv.jw.un_530 de.fr.ig_543  mt.sr.bs_544 sv.da.is_543
  0x53030507, 0x0e1b3107, 0x0603285a, 0x181f270c,   // fr.nl.ht_432 az.tr.is_432  sw.nl.de_553 gd.cy.ga_543
  0x4a1e1ca4, 0x64006814, 0x16001208, 0x2a001f34,   // id.ms.yo_433 ig.lg.un_660  hu.hr.un_430 cy.mt.un_A80
  0x181327ee, 0x08170408, 0x21002011, 0x0e000818,   // gd.et.ga_422 ru.sr.uk_443  sq.jw.un_630 no.is.un_740
  // [3500]
  0x23000708, 0x02131a08, 0x250e52ee, 0x2a001e04,   // it.ca.un_430 tl.et.da_443  ha.is.eu_422 ms.mt.un_320
  0x080a1109, 0x0f1f2aa4, 0x644a2aa4, 0x2a321704,   // ro.mk.uk_444 mt.cy.lv_433  mt.yo.lg_433 sr.bs.mt_332
  0x2000051f, 0x2b093f07, 0x1b001108, 0x550964a0,   // fr.sq.un_840 af.pl.vi_432  ro.tr.un_430 lg.pl.rw_322
  0x68172aa4, 0x131923ad, 0x68052b05, 0x25321704,   // mt.sr.ig_433 ca.gl.et_643  vi.fr.ig_333 sr.bs.eu_332
  // [3510]
  0x64551c0b, 0x0328090c, 0x080e2504, 0x08101711,   // id.rw.lg_542 pl.sw.nl_543  eu.is.no_332 sr.be.uk_653
  0x4a002312, 0x4a3f090b, 0x21004a04, 0x64004a2c,   // ca.yo.un_640 pl.af.yo_542  yo.jw.un_320 yo.lg.un_990
  0x2d001902, 0x05104a09, 0x02002718, 0x32121707,   // gl.sk.un_220 yo.lt.fr_444  gd.da.un_740 sr.hu.bs_432
  0x11132aa4, 0x6400532a, 0x3b065305, 0x0a0407ac,   // mt.et.ro_433 ht.lg.un_970  ht.de.so_333 bg.ru.mk_632
  // [3520]
  0x18013fee, 0x12001012, 0x010809a7, 0x18000512,   // af.en.ga_422 lt.hu.un_640  pl.no.en_532 fr.ga.un_640
  0x1204060d, 0x116b1a07, 0x13041155, 0x32001719,   // de.fi.hu_554 tl.ceb.ro_432  ro.fi.et_442 sr.bs.un_750
  0x11286404, 0x351b31ee, 0x0406110c, 0x640428a4,   // lg.sw.ro_332 az.tr.zu_422  ro.de.fi_543 sw.fi.lg_433
  0x1f1a3507, 0x64006b08, 0x3f0428ac, 0x1b001a09,   // zu.tl.cy_432 ceb.lg.un_430  sw.fi.af_632 tl.tr.un_440
  // [3530]
  0x641e5207, 0x180627a7, 0x033f3b05, 0x2a002108,   // ha.ms.lg_432 gd.de.ga_532  so.af.nl_333 jw.mt.un_430
  0x05292aee, 0x3f003b1b, 0x1a006e04, 0x53001913,   // mt.sl.fr_422 so.af.un_770  hmn.tl.un_320 gl.ht.un_650
  0x25136bec, 0x643528a4, 0x04100eec, 0x1e002021,   // ceb.et.eu_644 sw.zu.lg_433  is.lt.fi_644 sq.ms.un_860
  0x291107ee, 0x0f002a29, 0x2a0752ec, 0x1c005307,   // it.ro.sl_422 mt.lv.un_960  ha.it.mt_644 ht.id.un_420
  // [3540]
  0x045203a0, 0x2d121902, 0x11521008, 0x2d000e13,   // nl.ha.fi_322 gl.hu.sk_222  lt.ha.ro_443 is.sk.un_650
  0x03001b21, 0x1c041aa0, 0x111735a7, 0x0e000a0c,   // tr.nl.un_860 tl.fi.id_322  zu.sr.ro_532 pt.is.un_530
  0x10000a04, 0x08002102, 0x283b1a07, 0x040e23a6,   // mk.be.un_320 jw.no.un_220  tl.so.sw_432 ca.is.fi_521
  0x6b0425a0, 0x16045204, 0x533f03a4, 0x0d35040e,   // eu.fi.ceb_322 ha.fi.hr_332  nl.af.ht_433 fi.zu.cs_555
  // [3550]
  0x0e001004, 0x02041308, 0x03533fa4, 0x170a100c,   // lt.is.un_320 et.fi.da_443  af.ht.nl_433 be.mk.sr_543
  0x12001808, 0x04321704, 0x0c00110c, 0x040f2aec,   // ga.hu.un_430 sr.bs.fi_332  ro.sv.un_530 mt.lv.fi_644
  0x1310115a, 0x533f03a0, 0x111704a4, 0x01003504,   // ro.lt.et_553 nl.af.ht_322  ru.sr.ro_433 zu.en.un_320
  0x3b1712ec, 0x55006b04, 0x2a060112, 0x13080ca0,   // hu.sr.so_644 ceb.rw.un_320  en.de.mt_654 sv.no.et_322
  // [3560]
  0x0e000104, 0x1b533504, 0x350403a0, 0x08020ea9,   // en.is.un_320 zu.ht.tr_332  nl.fi.zu_322 is.da.no_544
  0x080207a0, 0x080223ac, 0x0503640c, 0x09000321,   // it.da.no_322 ca.da.no_632  lg.nl.fr_543 nl.pl.un_860
  0x28006b20, 0x19050b0c, 0x190a05a6, 0x20002802,   // ceb.sw.un_850 es.fr.gl_543  fr.pt.gl_521 sw.sq.un_220
  0x045528a0, 0x070f5207, 0x190a13ee, 0x08013fa7,   // sw.rw.fi_322 ha.lv.it_432  et.pt.gl_422 af.en.no_532
  // [3570]
  0x27001112, 0x1a066ba0, 0x082913a4, 0x2d0d0a05,   // ro.gd.un_640 ceb.de.tl_322  et.sl.no_433 pt.cs.sk_333
  0x5313350c, 0x2a0c08a4, 0x352513a4, 0x18002504,   // zu.et.ht_543 no.sv.mt_433  et.eu.zu_433 eu.ga.un_320
  0x29096804, 0x04323507, 0x68131f07, 0x25202109,   // ig.pl.sl_332 zu.bs.fi_432  cy.et.ig_432 jw.sq.eu_444
  0x3f00680d, 0x3b136413, 0x29323b04, 0x06350c08,   // ig.af.un_540 lg.et.so_665  so.bs.sl_332 sv.zu.de_443
  // [3580]
  0x230d1213, 0x13552507, 0x354a5207, 0x10003204,   // hu.cs.ca_665 eu.rw.et_432  ha.yo.zu_432 bs.lt.un_320
  0x2064130c, 0x03553555, 0x040a19ee, 0x093125a9,   // et.lg.sq_543 zu.rw.nl_442  gl.pt.fi_422 eu.az.pl_544
  0x2a4a28ad, 0x2b211cee, 0x25001c08, 0x12002508,   // sw.yo.mt_643 id.jw.vi_422  id.eu.un_430 eu.hu.un_430
  0x53002004, 0x28000404, 0x080e0c0b, 0x28002a02,   // sq.ht.un_320 fi.sw.un_320  sv.is.no_542 mt.sw.un_220
  // [3590]
  0x35202507, 0x55125309, 0x08071004, 0x644a3baf,   // eu.sq.zu_432 ht.hu.rw_444  be.bg.uk_332 so.yo.lg_655
  0x0a051107, 0x130c35a7, 0x3b23250c, 0x3b001a02,   // ro.fr.pt_432 zu.sv.et_532  eu.ca.so_543 tl.so.un_220
  0x641f28ad, 0x03211e0b, 0x282a6ba4, 0x25041108,   // sw.cy.lg_643 ms.jw.nl_542  ceb.mt.sw_433 ro.fi.eu_443
  0x1a00011a, 0x020c0808, 0x2835640c, 0x53000104,   // en.tl.un_760 no.sv.da_443  lg.zu.sw_543 en.ht.un_320
  // [35a0]
  0x02100807, 0x0e081fad, 0x011a2114, 0x1e1c52a4,   // no.lt.da_432 cy.no.is_643  jw.tl.en_666 ha.id.ms_433
  0x130427ad, 0x211e04a4, 0x3f030113, 0x18000622,   // gd.fi.et_643 fi.ms.jw_433  en.nl.af_665 de.ga.un_870
  0x1300641a, 0x0600101a, 0x08000408, 0x030f3f08,   // lg.et.un_760 lt.de.un_760  ru.uk.un_430 af.lv.nl_443
  0x3f1a010b, 0x1300640e, 0x321617ad, 0x640413ad,   // en.tl.af_542 lg.et.un_550  sr.hr.bs_643 et.fi.lg_643
  // [35b0]
  0x2b001a0d, 0x0e061faf, 0x21000108, 0x23031908,   // tl.vi.un_540 cy.de.is_655  en.jw.un_430 gl.nl.ca_443
  0x4a005518, 0x3b530555, 0x00002d2d, 0x1a002821,   // rw.yo.un_740 fr.ht.so_442  sk.un.un_A00 sw.tl.un_860
  0x03080113, 0x290b530c, 0x031a0112, 0x25216bad,   // en.no.nl_665 ht.es.sl_543  en.tl.nl_654 ceb.jw.eu_643
  0x282055a4, 0x28005229, 0x550a2307, 0x551a6b08,   // rw.sq.sw_433 ha.sw.un_960  ca.pt.rw_432 ceb.tl.rw_443
  // [35c0]
  0x1a01210c, 0x3b5528ec, 0x2a104aa9, 0x06190a09,   // jw.en.tl_543 sw.rw.so_644  yo.lt.mt_544 pt.gl.de_444
  0x3b20520c, 0x1e001119, 0x092d0faf, 0x030e0607,   // ha.sq.so_543 ro.ms.un_750  lv.sk.pl_655 de.is.nl_432
  0x040609b3, 0x55251a05, 0x12000302, 0x52552012,   // pl.de.fi_743 tl.eu.rw_333  nl.hu.un_220 sq.rw.ha_654
  0x1c6425a0, 0x063f030c, 0x6b013ba7, 0x2000010d,   // eu.lg.id_322 nl.af.de_543  so.en.ceb_532 en.sq.un_540
  // [35d0]
  0x03250a02, 0x3b015208, 0x083f12a9, 0x10182755,   // pt.eu.nl_222 ha.en.so_443  hu.af.no_544 gd.ga.lt_442
  0x52553ba9, 0x00002d24, 0x53050c11, 0x283555ac,   // so.rw.ha_544 sk.un.un_900  sv.fr.ht_653 rw.zu.sw_632
  0x6b001a29, 0x07080aa4, 0x051f28ee, 0x121c6405,   // tl.ceb.un_960 mk.uk.bg_433  sw.cy.fr_422 lg.id.hu_333
  0x036406a0, 0x255213ec, 0x2b1827af, 0x0c060107,   // de.lg.nl_322 et.ha.eu_644  gd.ga.vi_655 en.de.sv_432
  // [35e0]
  0x1113320d, 0x6b3b2007, 0x680f20a6, 0x0c060407,   // bs.et.ro_554 sq.so.ceb_432  sq.lv.ig_521 fi.de.sv_432
  0x1e211c07, 0x07203b07, 0x20683f05, 0x06000412,   // id.jw.ms_432 so.sq.it_432  af.ig.sq_333 fi.de.un_640
  0x080c02a9, 0x552801a4, 0x2800200d, 0x5535280c,   // da.sv.no_544 en.sw.rw_433  sq.sw.un_540 sw.zu.rw_543
  0x072108a0, 0x070a11a6, 0x114a18a0, 0x0e062705,   // no.jw.it_322 ro.mk.bg_521  ga.yo.ro_322 gd.de.is_333
  // [35f0]
  0x19280aa0, 0x18005312, 0x1f0306ad, 0x2d1b0107,   // pt.sw.gl_322 ht.ga.un_640  de.nl.cy_643 en.tr.sk_432
  0x1b0f52ee, 0x12051f0c, 0x27181f0c, 0x161732a7,   // ha.lv.tr_422 cy.fr.hu_543  cy.ga.gd_543 bs.sr.hr_532
  0x2a0653ec, 0x6b182708, 0x061827ec, 0x213f6807,   // ht.de.mt_644 gd.ga.ceb_443  gd.ga.de_644 ig.af.jw_432
  0x252a2907, 0x29002a1b, 0x12003f08, 0x0e000707,   // sl.mt.eu_432 mt.sl.un_770  af.hu.un_430 it.is.un_420
  // [3600]
  0x09130408, 0x063b55a4, 0x1e1c2a14, 0x13002905,   // fi.et.pl_443 rw.so.de_433  mt.id.ms_666 sl.et.un_330
  0x05640107, 0x20002a22, 0x17040809, 0x55286413,   // en.lg.fr_432 mt.sq.un_870  uk.ru.sr_444 lg.sw.rw_665
  0x2a2029af, 0x070501a0, 0x09080e07, 0x6b000108,   // sl.sq.mt_655 en.fr.it_322  is.no.pl_432 en.ceb.un_430
  0x53010ca0, 0x12180804, 0x00001a2d, 0x01006419,   // sv.en.ht_322 no.ga.hu_332  tl.un.un_A00 lg.en.un_750
  // [3610]
  0x20092d11, 0x03006422, 0x0a18050c, 0x0c00080c,   // sk.pl.sq_653 lg.nl.un_870  fr.ga.pt_543 no.sv.un_530
  0x10052704, 0x2518270e, 0x31182709, 0x0a002814,   // gd.fr.lt_332 gd.ga.eu_555  gd.ga.az_444 sw.pt.un_660
  0x29071805, 0x0200060c, 0x1b091ca0, 0x0e3b1fa4,   // ga.it.sl_333 de.da.un_530  id.pl.tr_322 cy.so.is_433
  0x081013a4, 0x55356e0c, 0x08020f05, 0x31191fec,   // et.lt.no_433 hmn.zu.rw_543  lv.da.no_333 cy.gl.az_644
  // [3620]
  0x1f68200c, 0x04050112, 0x053f060c, 0x28684aaf,   // sq.ig.cy_543 en.fr.fi_654  de.af.fr_543 yo.ig.sw_655
  0x08040c04, 0x0f0e52a9, 0x061e1ca4, 0x521a6414,   // sv.fi.no_332 ha.is.lv_544  id.ms.de_433 lg.tl.ha_666
  0x681f4aa9, 0x042a0e11, 0x1304290c, 0x12033fa0,   // yo.cy.ig_544 is.mt.fi_653  sl.fi.et_543 af.nl.hu_322
  0x04132107, 0x20042a0c, 0x18030655, 0x25132104,   // jw.et.fi_432 mt.fi.sq_543  de.nl.ga_442 jw.et.eu_332
  // [3630]
  0x13290413, 0x11070408, 0x041312a4, 0x283b130c,   // fi.sl.et_665 ru.bg.ro_443  hu.et.fi_433 et.so.sw_543
  0x3f3b09ec, 0x12000c08, 0x1732160c, 0x1e1c53ee,   // pl.so.af_644 sv.hu.un_430  hr.bs.sr_543 ht.id.ms_422
  0x100c0807, 0x1a643511, 0x16006808, 0x2b001308,   // no.sv.lt_432 zu.lg.tl_653  ig.hr.un_430 et.vi.un_430
  0x0d001602, 0x1b3b2804, 0x2b0301ad, 0x5200282c,   // hr.cs.un_220 sw.so.tr_332  en.nl.vi_643 sw.ha.un_990
  // [3640]
  0x1b005208, 0x28002513, 0x21532508, 0x21005312,   // ha.tr.un_430 eu.sw.un_650  eu.ht.jw_443 ht.jw.un_640
  0x10002102, 0x126e1b04, 0x322d1702, 0x03020107,   // jw.lt.un_220 tr.hmn.hu_332  sr.sk.bs_222 en.da.nl_432
  0x1b0129a0, 0x103f5211, 0x28531cad, 0x0a000809,   // sl.en.tr_322 ha.af.lt_653  id.ht.sw_643 no.pt.un_440
  0x1e0c1ca0, 0x190b01a9, 0x12064a07, 0x35002134,   // id.sv.ms_322 en.es.gl_544  yo.de.hu_432 jw.zu.un_A80
  // [3650]
  0x180a0560, 0x0802210e, 0x1e006812, 0x19230b08,   // fr.pt.ga_664 jw.da.no_555  ig.ms.un_640 es.ca.gl_443
  0x1f00070b, 0x351a21a9, 0x11003505, 0x6b091a07,   // it.cy.un_520 jw.tl.zu_544  zu.ro.un_330 tl.pl.ceb_432
  0x321701ee, 0x1b000420, 0x3b00041b, 0x2b016b0c,   // en.sr.bs_422 fi.tr.un_850  fi.so.un_770 ceb.en.vi_543
  0x0a112704, 0x1f2718a4, 0x551b1aec, 0x20211ca4,   // gd.ro.pt_332 ga.gd.cy_433  tl.tr.rw_644 id.jw.sq_433
  // [3660]
  0x020e08a4, 0x1b1a1ea9, 0x21183555, 0x110b0907,   // no.is.da_433 ms.tl.tr_544  zu.ga.jw_442 pl.es.ro_432
  0x1c000a04, 0x1b351ea4, 0x3528520c, 0x3564280c,   // pt.id.un_320 ms.zu.tr_433  ha.sw.zu_543 sw.lg.zu_543
  0x0c201f0c, 0x28551e07, 0x0a236b02, 0x1a521ea0,   // cy.sq.sv_543 ms.rw.sw_432  ceb.ca.pt_222 ms.ha.tl_322
  0x13103bec, 0x1b022907, 0x061c6ea6, 0x35001a09,   // so.lt.et_644 sl.da.tr_432  hmn.id.de_521 tl.zu.un_440
  // [3670]
  0x530c0208, 0x5328050c, 0x1100010c, 0x23000b04,   // da.sv.ht_443 fr.sw.ht_543  en.ro.un_530 es.ca.un_320
  0x06056eee, 0x21642809, 0x20131eee, 0x2b6452a0,   // hmn.fr.de_422 sw.lg.jw_444  ms.et.sq_422 ha.lg.vi_322
  0x13121b0c, 0x32211c04, 0x011852a4, 0x1f006e12,   // tr.hu.et_543 id.jw.bs_332  ha.ga.en_433 hmn.cy.un_640
  0x1b35550c, 0x101104ad, 0x3b203112, 0x0b0501a4,   // rw.zu.tr_543 ru.ro.be_643  az.sq.so_654 en.fr.es_433
  // [3680]
  0x2d0d0ba4, 0x25070cec, 0x100413ad, 0x121e25a0,   // es.cs.sk_433 sv.it.eu_644  et.fi.lt_643 eu.ms.hu_322
  0x2a1e310c, 0x08000220, 0x6b110c07, 0x132820ad,   // az.ms.mt_543 da.no.un_850  sv.ro.ceb_432 sq.sw.et_643
  0x3511550c, 0x0b4a1908, 0x55271ea4, 0x1a001c04,   // rw.ro.zu_543 gl.yo.es_443  ms.gd.rw_433 id.tl.un_320
  0x0a002d0d, 0x312b1c0c, 0x353b1e04, 0x0f0c1304,   // sk.pt.un_540 id.vi.az_543  ms.so.zu_332 et.sv.lv_332
  // [3690]
  0x0c063f02, 0x21356408, 0x0b0f0ca4, 0x085327a4,   // af.de.sv_222 lg.zu.jw_443  sv.lv.es_433 gd.ht.no_433
  0x13211ca0, 0x27180c0b, 0x1004070c, 0x3f1b13af,   // id.jw.et_322 sv.ga.gd_542  bg.ru.be_543 et.tr.af_655
  0x050413ee, 0x18283fa9, 0x3f1b1260, 0x12000a07,   // et.fi.fr_422 af.sw.ga_544  hu.tr.af_664 pt.hu.un_420
  0x17110aa4, 0x08004a04, 0x13190a04, 0x321617ac,   // mk.ro.sr_433 yo.no.un_320  pt.gl.et_332 sr.hr.bs_632
  // [36a0]
  0x1b006404, 0x1c211eec, 0x100417a9, 0x03131902,   // lg.tr.un_320 ms.jw.id_644  sr.ru.be_544 gl.et.nl_222
  0x12001707, 0x251e1c08, 0x0d091c60, 0x28122507,   // sr.hu.un_420 id.ms.eu_443  mr.hi.ne_664 eu.hu.sw_432
  0x6b095507, 0x6e2718ad, 0x0a000307, 0x082706ad,   // rw.pl.ceb_432 ga.gd.hmn_643  nl.pt.un_420 de.gd.no_643
  0x08171107, 0x0a1e25ad, 0x270d0607, 0x12002d04,   // ro.sr.uk_432 eu.ms.pt_643  de.cs.gd_432 sk.hu.un_320
  // [36b0]
  0x1c1e2511, 0x3b000619, 0x210a25ee, 0x4a2d18af,   // eu.ms.id_653 de.so.un_750  eu.pt.jw_422 ga.sk.yo_655
  0x12131b08, 0x21000507, 0x03211b0c, 0x163217a7,   // tr.et.hu_443 fr.jw.un_420  tr.jw.nl_543 sr.bs.hr_532
  0x0708170c, 0x12000708, 0x06130a05, 0x191327a9,   // sr.uk.bg_543 it.hu.un_430  pt.et.de_333 gd.et.gl_544
  0x031a3f04, 0x06000521, 0x1e002514, 0x1f00210e,   // af.tl.nl_332 fr.de.un_860  eu.ms.un_660 jw.cy.un_550
  // [36c0]
  0x230b19ee, 0x03001f19, 0x130627a0, 0x06001a04,   // gl.es.ca_422 cy.nl.un_750  gd.de.et_322 tl.de.un_320
  0x2a00040c, 0x053217a0, 0x31135204, 0x13000e18,   // fi.mt.un_530 sr.bs.fr_322  ha.et.az_332 is.et.un_740
  0x033f1b08, 0x13000b02, 0x1f001807, 0x521b1ea4,   // tr.af.nl_443 es.et.un_220  ga.cy.un_420 ms.tr.ha_433
  0x19001a02, 0x23070e0c, 0x0f001b12, 0x13091c12,   // tl.gl.un_220 is.it.ca_543  tr.lv.un_640 mr.hi.bh_654
  // [36d0]
  0x081107a9, 0x1732520c, 0x1c292aaf, 0x04061311,   // bg.ro.uk_544 ha.bs.sr_543  mt.sl.id_655 et.de.fi_653
  0x08020e09, 0x13060508, 0x2b1e1c0d, 0x2b0221a0,   // is.da.no_444 fr.de.et_443  id.ms.vi_554 jw.da.vi_322
  0x0f002813, 0x171629af, 0x1b072a09, 0x05110111,   // sw.lv.un_650 sl.hr.sr_655  mt.it.tr_444 en.ro.fr_653
  0x19211a0d, 0x2b115204, 0x070a10a7, 0x6b003513,   // tl.jw.gl_554 ha.ro.vi_332  be.mk.bg_532 zu.ceb.un_650
  // [36e0]
  0x32005207, 0x070c0412, 0x050201ee, 0x170f0404,   // ha.bs.un_420 fi.sv.it_654  en.da.fr_422 fi.lv.sr_332
  0x0100070e, 0x0d001818, 0x29132a12, 0x2d0d0905,   // it.en.un_550 ga.cs.un_740  mt.et.sl_654 pl.cs.sk_333
  0x0b231208, 0x646b1a14, 0x213b2804, 0x05073f08,   // hu.ca.es_443 tl.ceb.lg_666  sw.so.jw_332 af.it.fr_443
  0x13041207, 0x0d2a5312, 0x180427a0, 0x07003512,   // hu.fi.et_432 ht.mt.cs_654  gd.fi.ga_322 zu.it.un_640
  // [36f0]
  0x18000408, 0x09000f20, 0x643b28a4, 0x1a040fec,   // fi.ga.un_430 lv.pl.un_850  sw.so.lg_433 lv.fi.tl_644
  0x041707a9, 0x28003b1a, 0x3b21520c, 0x19120b0c,   // bg.sr.ru_544 so.sw.un_760  ha.jw.so_543 es.hu.gl_543
  0x6b160807, 0x2703180e, 0x2511285a, 0x2a002012,   // no.hr.ceb_432 ga.nl.gd_555  sw.ro.eu_553 sq.mt.un_640
  0x2d002a09, 0x10000e18, 0x1218270d, 0x28003114,   // mt.sk.un_440 is.lt.un_740  gd.ga.hu_554 az.sw.un_660
  // [3700]
  0x033f02af, 0x030a07a0, 0x0e0906a0, 0x170908a0,   // da.af.nl_655 it.pt.nl_322  de.pl.is_322 no.pl.sr_322
  0x27062a55, 0x0f1629a9, 0x03011855, 0x642810ad,   // mt.de.gd_442 sl.hr.lv_544  ga.en.nl_442 lt.sw.lg_643
  0x23285502, 0x35092805, 0x061e1c14, 0x07000804,   // rw.sw.ca_222 sw.pl.zu_333  id.ms.de_666 uk.bg.un_320
  0x32002108, 0x64201ea4, 0x0f060704, 0x1732160b,   // jw.bs.un_430 ms.sq.lg_433  it.de.lv_332 hr.bs.sr_542
  // [3710]
  0x0500270c, 0x09033f11, 0x5304050c, 0x16290d12,   // gd.fr.un_530 af.nl.pl_653  fr.fi.ht_543 cs.sl.hr_654
  0x20171ea0, 0x2a1e3108, 0x6b131c07, 0x2d0d4aa9,   // ms.sr.sq_322 az.ms.mt_443  id.et.ceb_432 yo.cs.sk_544
  0x1a2564a4, 0x1b3268a4, 0x11000f19, 0x31356404,   // lg.eu.tl_433 ig.bs.tr_433  lv.ro.un_750 lg.zu.az_332
  0x68001a13, 0x030f2a07, 0x0b2d1008, 0x35033f0c,   // tl.ig.un_650 mt.lv.nl_432  lt.sk.es_443 af.nl.zu_543
  // [3720]
  0x06130855, 0x0d122d08, 0x0b2319a9, 0x062b27a6,   // no.et.de_442 sk.hu.cs_443  gl.ca.es_544 gd.vi.de_521
  0x351b64ec, 0x21102d07, 0x52000208, 0x2000210d,   // lg.tr.zu_644 sk.lt.jw_432  da.ha.un_430 jw.sq.un_540
  0x06085308, 0x20356408, 0x2a071ea4, 0x12002a19,   // ht.no.de_443 lg.zu.sq_443  ms.it.mt_433 mt.hu.un_750
  0x1604530c, 0x11041312, 0x1e6807ad, 0x52000221,   // ht.fi.hr_543 et.fi.ro_654  it.ig.ms_643 da.ha.un_860
  // [3730]
  0x211a4a0c, 0x0d1c0960, 0x1304640c, 0x29641b0c,   // yo.tl.jw_543 hi.mr.ne_664  lg.fi.et_543 tr.lg.sl_543
  0x12001e04, 0x190553a0, 0x2d0d1ba4, 0x041301a0,   // ms.hu.un_320 ht.fr.gl_322  tr.cs.sk_433 en.et.fi_322
  0x293217ee, 0x020c080d, 0x1300350c, 0x35551308,   // sr.bs.sl_422 no.sv.da_554  zu.et.un_530 et.rw.zu_443
  0x53002b14, 0x286435a4, 0x2a003107, 0x0600021b,   // vi.ht.un_660 zu.lg.sw_433  az.mt.un_420 da.de.un_770
  // [3740]
  0x27083f0c, 0x0d092d08, 0x35041307, 0x2a230c5a,   // af.no.gd_543 sk.pl.cs_443  et.fi.zu_432 sv.ca.mt_553
  0x0c001704, 0x1e1c2109, 0x050418ad, 0x033f0605,   // sr.sv.un_320 jw.id.ms_444  ga.fi.fr_643 de.af.nl_333
  0x10002a0c, 0x093216a4, 0x0c1b1304, 0x04131b0c,   // mt.lt.un_530 hr.bs.pl_433  et.tr.sv_332 tr.et.fi_543
  0x1c1e2155, 0x3f311ba4, 0x080201a0, 0x3f1c21a0,   // jw.ms.id_442 tr.az.af_433  en.da.no_322 jw.id.af_322
  // [3750]
  0x0c13040c, 0x132a3f09, 0x0425030c, 0x0e002121,   // fi.et.sv_543 af.mt.et_444  nl.eu.fi_543 jw.is.un_860
  0x35081355, 0x1013350c, 0x25120709, 0x4a232107,   // et.no.zu_442 zu.et.lt_543  it.hu.eu_444 jw.ca.yo_432
  0x1a6b3f13, 0x013f060c, 0x180b190b, 0x08004a02,   // af.ceb.tl_665 de.af.en_543  gl.es.ga_542 yo.no.un_220
  0x53231f55, 0x072501a4, 0x2a000121, 0x283568a7,   // cy.ca.ht_442 en.eu.it_433  en.mt.un_860 ig.zu.sw_532
  // [3760]
  0x04000b07, 0x033f060d, 0x1c272107, 0x253f0655,   // es.fi.un_420 de.af.nl_554  jw.gd.id_432 de.af.eu_442
  0x64286860, 0x0428130c, 0x53000322, 0x642868af,   // ig.sw.lg_664 et.sw.fi_543  nl.ht.un_870 ig.sw.lg_655
  0x07042a0c, 0x071868a0, 0x212a20ad, 0x27006b05,   // mt.fi.it_543 ig.ga.it_322  sq.mt.jw_643 ceb.gd.un_330
  0x080e2012, 0x6404680e, 0x103f13a7, 0x20000e1b,   // sq.is.no_654 ig.fi.lg_555  et.af.lt_532 is.sq.un_770
  // [3770]
  0x311b3f13, 0x3f01130c, 0x112a01a4, 0x114a6407,   // af.tr.az_665 et.en.af_543  en.mt.ro_433 lg.yo.ro_432
  0x533f2aa9, 0x041321a7, 0x16004a04, 0x046821ad,   // mt.af.ht_544 jw.et.fi_532  yo.hr.un_320 jw.ig.fi_643
  0x21006e07, 0x27190b02, 0x171632a6, 0x25033f07,   // hmn.jw.un_420 es.gl.gd_222  bs.hr.sr_521 af.nl.eu_432
  0x1f103b0c, 0x64011f05, 0x1f071907, 0x20006e08,   // so.lt.cy_543 cy.en.lg_333  gl.it.cy_432 hmn.sq.un_430
  // [3780]
  0x033f01a7, 0x033f6ead, 0x0b0f29ee, 0x6e00202b,   // en.af.nl_532 hmn.af.nl_643  sl.lv.es_422 sq.hmn.un_980
  0x07100411, 0x1a003509, 0x080e235a, 0x352164a4,   // ru.be.bg_653 zu.tl.un_440  ca.is.no_553 lg.jw.zu_433
  0x281e1c02, 0x6e033f13, 0x0e0f1fad, 0x3f2d16a0,   // id.ms.sw_222 af.nl.hmn_665  cy.lv.is_643 hr.sk.af_322
  0x53001605, 0x19002104, 0x644a21ec, 0x033f6ea4,   // hr.ht.un_330 jw.gl.un_320  jw.yo.lg_644 hmn.af.nl_433
  // [3790]
  0x172a1104, 0x3b003f19, 0x1f6828a9, 0x04001e02,   // ro.mt.sr_332 af.so.un_750  sw.ig.cy_544 ms.fi.un_220
  0x10280405, 0x101f1105, 0x1200551b, 0x10001c02,   // fi.sw.lt_333 ro.cy.lt_333  rw.hu.un_770 id.lt.un_220
  0x27001f19, 0x17001007, 0x08250411, 0x25006b07,   // cy.gd.un_750 lt.sr.un_420  fi.eu.no_653 ceb.eu.un_420
  0x27001f07, 0x12000713, 0x4a1235ec, 0x13036eee,   // cy.gd.un_420 it.hu.un_650  zu.hu.yo_644 hmn.nl.et_422
  // [37a0]
  0x00006837, 0x13006e13, 0x173216a7, 0x1c3b1e07,   // ig.un.un_B00 hmn.et.un_650  hr.bs.sr_532 ms.so.id_432
  0x08040a11, 0x0f006e02, 0x0f0e1005, 0x1f030ca0,   // mk.ru.uk_653 hmn.lv.un_220  lt.is.lv_333 sv.nl.cy_322
  0x1b351105, 0x64135202, 0x080c1bec, 0x13041004,   // ro.zu.tr_333 ha.et.lg_222  tr.sv.no_644 lt.fi.et_332
  0x01180eee, 0x0e4a0609, 0x55211e05, 0x68002508,   // is.ga.en_422 de.yo.is_444  ms.jw.rw_333 eu.ig.un_430
  // [37b0]
  0x16002004, 0x073f6e0c, 0x27002a08, 0x202d17a0,   // sq.hr.un_320 hmn.af.it_543  mt.gd.un_430 sr.sk.sq_322
  0x311b3b0d, 0x32002804, 0x0000240a, 0x271e1fa4,   // so.tr.az_554 sw.bs.un_320  yi.un.un_500 cy.ms.gd_433
  0x1e1b0609, 0x080205af, 0x1f232512, 0x1f060812,   // de.tr.ms_444 fr.da.no_655  eu.ca.cy_654 no.de.cy_654
  0x0000160a, 0x2768530c, 0x170407af, 0x0f2b0308,   // hr.un.un_500 ht.ig.gd_543  bg.ru.sr_655 nl.vi.lv_443
  // [37c0]
  0x080252a4, 0x20000f14, 0x19181104, 0x5500682a,   // ha.da.no_433 lv.sq.un_660  ro.ga.gl_332 ig.rw.un_970
  0x4a001a2b, 0x0f1a530b, 0x0c3b3fa0, 0x271808a9,   // tl.yo.un_980 ht.tl.lv_542  af.so.sv_322 no.ga.gd_544
  0x1b250c07, 0x3b001921, 0x13352905, 0x0c1153ad,   // sv.eu.tr_432 gl.so.un_860  sl.zu.et_333 ht.ro.sv_643
  0x03133f07, 0x2b000108, 0x4a0f1ca0, 0x190701a4,   // af.et.nl_432 en.vi.un_430  id.lv.yo_322 en.it.gl_433
  // [37d0]
  0x10311b5a, 0x20136807, 0x0a0723a9, 0x1a311b09,   // tr.az.lt_553 ig.et.sq_432  ca.it.pt_544 tr.az.tl_444
  0x09023fa0, 0x6413040c, 0x1b001012, 0x1a3b1e12,   // af.da.pl_322 fi.et.lg_543  lt.tr.un_640 ms.so.tl_654
  0x04106eee, 0x101b3113, 0x3b6b1a0c, 0x0d5553ee,   // hmn.lt.fi_422 az.tr.lt_665  tl.ceb.so_543 ht.rw.cs_422
  0x6e00531a, 0x050729a0, 0x3b6b1ca4, 0x184a6e04,   // ht.hmn.un_760 sl.it.fr_322  id.ceb.so_433 hmn.yo.ga_332
  // [37e0]
  0x6b080108, 0x12316ead, 0x3b1a1c07, 0x53311b14,   // en.no.ceb_443 hmn.az.hu_643  id.tl.so_432 tr.az.ht_666
  0x036b3fa0, 0x21003b13, 0x12002819, 0x2a0452ad,   // af.ceb.nl_322 so.jw.un_650  sw.hu.un_750 ha.fi.mt_643
  0x0f1b2555, 0x29000607, 0x12211aa0, 0x0a000412,   // eu.tr.lv_442 de.sl.un_420  tl.jw.hu_322 ru.mk.un_640
  0x643b1a0c, 0x13270eec, 0x16006b04, 0x2a101b13,   // tl.so.lg_543 is.gd.et_644  ceb.hr.un_320 tr.lt.mt_665
  // [37f0]
  0x28211a0c, 0x1e1a03ec, 0x52003b0c, 0x521a1b09,   // tl.jw.sw_543 nl.tl.ms_644  so.ha.un_530 tr.tl.ha_444
  0x0d090bba, 0x1e6b1a13, 0x06002119, 0x01002702,   // bn.hi.ne_843 tl.ceb.ms_665  jw.de.un_750 gd.en.un_220
  0x27060ead, 0x081805ad, 0x1e3b1cec, 0x321b53a0,   // is.de.gd_643 fr.ga.no_643  id.so.ms_644 ht.tr.bs_322
  0x25001b22, 0x52123104, 0x230a010c, 0x01686b04,   // tr.eu.un_870 az.hu.ha_332  en.pt.ca_543 ceb.ig.en_332

  // [3800]
  0x0a00050c, 0x1716290c, 0x055507a4, 0x1b00120d,   // fr.pt.un_530 sl.hr.sr_543  it.rw.fr_433 hu.tr.un_540
  0x29001702, 0x0c0608a4, 0x10061f0b, 0x64031aa7,   // sr.sl.un_220 no.de.sv_433  cy.de.lt_542 tl.nl.lg_532
  0x18270eaf, 0x103b520c, 0x09000d02, 0x27180ead,   // is.gd.ga_655 ha.so.lt_543  ne.hi.un_220 is.ga.gd_643
  0x0b231913, 0x0d190ba7, 0x0e2a270c, 0x0a1f25a4,   // gl.ca.es_665 es.gl.cs_532  gd.mt.is_543 eu.cy.pt_433
  // [3810]
  0x271811a0, 0x081011a0, 0x1e554a04, 0x20020555,   // ro.ga.gd_322 ro.be.uk_322  yo.rw.ms_332 fr.da.sq_442
  0x19001307, 0x3f0a01ad, 0x13201005, 0x1e3b1ca4,   // et.gl.un_420 en.pt.af_643  lt.sq.et_333 id.so.ms_433
  0x2835550c, 0x53000119, 0x1118270c, 0x23201ca0,   // rw.zu.sw_543 en.ht.un_750  gd.ga.ro_543 id.sq.ca_322
  0x2a1b13a7, 0x11202304, 0x281b2aa0, 0x523b1e05,   // et.tr.mt_532 ca.sq.ro_332  mt.tr.sw_322 ms.so.ha_333
  // [3820]
  0x1b005519, 0x201b5312, 0x3f002119, 0x176e20ad,   // rw.tr.un_750 ht.tr.sq_654  jw.af.un_750 sq.hmn.sr_643
  0x17002102, 0x06000f02, 0x13006e04, 0x3b001909,   // jw.sr.un_220 lv.de.un_220  hmn.et.un_320 gl.so.un_440
  0x210520ad, 0x3f0b23a4, 0x27310c02, 0x1c000920,   // sq.fr.jw_643 ca.es.af_433  sv.az.gd_222 hi.mr.un_850
  0x52001702, 0x1b005513, 0x2d0d21af, 0x1600080c,   // sr.ha.un_220 rw.tr.un_650  jw.cs.sk_655 no.hr.un_530
  // [3830]
  0x6b0607ee, 0x20285208, 0x1e1c13a4, 0x0b05210b,   // it.de.ceb_422 ha.sw.sq_443  et.id.ms_433 jw.fr.es_542
  0x0e001b2b, 0x28202108, 0x00002a37, 0x551b53ad,   // tr.is.un_980 jw.sq.sw_443  mt.un.un_B00 ht.tr.rw_643
  0x16001c04, 0x11051707, 0x0c003204, 0x1a000713,   // id.hr.un_320 sr.fr.ro_432  bs.sv.un_320 it.tl.un_650
  0x3f1f0707, 0x35061faf, 0x11000704, 0x0d004a08,   // it.cy.af_432 cy.de.zu_655  it.ro.un_320 yo.cs.un_430
  // [3840]
  0x1b0d31a0, 0x130d1c11, 0x02000c13, 0x3b1c1ea0,   // az.cs.tr_322 mr.ne.bh_653  sv.da.un_650 ms.id.so_322
  0x1b3f0311, 0x28355512, 0x3f000704, 0x0a0807af,   // nl.af.tr_653 rw.zu.sw_654  it.af.un_320 bg.uk.mk_655
  0x100e1aee, 0x07282008, 0x281c2104, 0x0e311b11,   // tl.is.lt_422 sq.sw.it_443  jw.id.sw_332 tr.az.is_653
  0x20070ca4, 0x2d0d130c, 0x64205508, 0x162d29a9,   // sv.it.sq_433 et.cs.sk_543  rw.sq.lg_443 sl.sk.hr_544
  // [3850]
  0x0213290c, 0x21051007, 0x11003105, 0x19060a0c,   // sl.et.da_543 lt.fr.jw_432  az.ro.un_330 pt.de.gl_543
  0x322a53a0, 0x04001305, 0x6e00062a, 0x52211ea4,   // ht.mt.bs_322 et.fi.un_330  de.hmn.un_970 ms.jw.ha_433
  0x10060107, 0x4a1e1c08, 0x076e27ad, 0x113f0312,   // en.de.lt_432 id.ms.yo_443  gd.hmn.it_643 nl.af.ro_654
  0x1b53120c, 0x080225a4, 0x23000a08, 0x1e2535ee,   // hu.ht.tr_543 eu.da.no_433  pt.ca.un_430 zu.eu.ms_422
  // [3860]
  0x0c68120c, 0x03096ead, 0x21001904, 0x52352907,   // hu.ig.sv_543 hmn.pl.nl_643  gl.jw.un_320 sl.zu.ha_432
  0x03063f13, 0x201b320c, 0x19110b12, 0x0f6e11ad,   // af.de.nl_665 bs.tr.sq_543  es.ro.gl_654 ro.hmn.lv_643
  0x6e000512, 0x3b00350d, 0x351e1c55, 0x27000419,   // fr.hmn.un_640 zu.so.un_540  id.ms.zu_442 fi.gd.un_750
  0x28352dad, 0x0400251a, 0x17250302, 0x122b2107,   // sk.zu.sw_643 eu.fi.un_760  nl.eu.sr_222 jw.vi.hu_432
  // [3870]
  0x132355ee, 0x04004a11, 0x0a0708ad, 0x55283ba4,   // rw.ca.et_422 yo.fi.un_630  uk.bg.mk_643 so.sw.rw_433
  0x122a6e02, 0x2a00051b, 0x1f52070d, 0x060e04a9,   // hmn.mt.hu_222 fr.mt.un_770  it.ha.cy_554 fi.is.de_544
  0x4a2d0d0e, 0x043b2aa4, 0x0e2d0d0e, 0x08030e0c,   // cs.sk.yo_555 mt.so.fi_433  cs.sk.is_555 is.nl.no_543
  0x27531c07, 0x640e2a05, 0x0408020d, 0x172a0f04,   // id.ht.gd_432 mt.is.lg_333  da.no.fi_554 lv.mt.sr_332
  // [3880]
  0x2b002702, 0x313b640c, 0x170f29ad, 0x0b001008,   // gd.vi.un_220 lg.so.az_543  sl.lv.sr_643 lt.es.un_430
  0x0d160fa0, 0x230501af, 0x041011ec, 0x29000d0d,   // lv.hr.cs_322 en.fr.ca_655  ro.be.ru_644 cs.sl.un_540
  0x09002d07, 0x070e5208, 0x52001704, 0x27001a05,   // sk.pl.un_420 ha.is.it_443  sr.ha.un_320 tl.gd.un_330
  0x0e080ca7, 0x0553010c, 0x03056407, 0x17552907,   // sv.no.is_532 en.ht.fr_543  lg.fr.nl_432 sl.rw.sr_432
  // [3890]
  0x2a352d09, 0x313b3507, 0x040f27a9, 0x12190ba4,   // sk.zu.mt_444 zu.so.az_432  gd.lv.fi_544 es.gl.hu_433
  0x022a0808, 0x281b3112, 0x180e27a9, 0x201e1c0c,   // no.mt.da_443 az.tr.sw_654  gd.is.ga_544 id.ms.sq_543
  0x0e3b5209, 0x29003208, 0x20111b0d, 0x050713a4,   // ha.so.is_444 bs.sl.un_430  tr.ro.sq_554 et.it.fr_433
  0x21002702, 0x35641ea4, 0x05312aa6, 0x0e350807,   // gd.jw.un_220 ms.lg.zu_433  mt.az.fr_521 no.zu.is_432
  // [38a0]
  0x07081208, 0x033f52ad, 0x0f1f5309, 0x095564ad,   // hu.no.it_443 ha.af.nl_643  ht.cy.lv_444 lg.rw.pl_643
  0x281b3204, 0x0e6408a0, 0x171107a4, 0x530b1ca4,   // bs.tr.sw_332 no.lg.is_322  bg.ro.sr_433 id.es.ht_433
  0x0b0e2a07, 0x10000719, 0x3f2106af, 0x2b005308,   // mt.is.es_432 it.lt.un_750  de.jw.af_655 ht.vi.un_430
  0x271f1813, 0x31001b07, 0x27180e0c, 0x18000c1a,   // ga.cy.gd_665 tr.az.un_420  is.ga.gd_543 sv.ga.un_760
  // [38b0]
  0x18002b1a, 0x191c1e0c, 0x100429a0, 0x17351a55,   // vi.ga.un_760 ms.id.gl_543  sl.fi.lt_322 tl.zu.sr_442
  0x1f003202, 0x13092504, 0x35005208, 0x0f190ba4,   // bs.cy.un_220 eu.pl.et_332  ha.zu.un_430 es.gl.lv_433
  0x16000e19, 0x08000e21, 0x171c0807, 0x320f0a08,   // is.hr.un_750 is.no.un_860  no.id.sr_432 pt.lv.bs_443
  0x03004a04, 0x081a2111, 0x19230aaf, 0x17092d09,   // yo.nl.un_320 jw.tl.no_653  pt.ca.gl_655 sk.pl.sr_444
  // [38c0]
  0x2000530e, 0x32001612, 0x281035ad, 0x25190aad,   // ht.sq.un_550 hr.bs.un_640  zu.lt.sw_643 pt.gl.eu_643
  0x2a001604, 0x17122902, 0x3b201fa7, 0x03000202,   // hr.mt.un_320 sl.hu.sr_222  cy.sq.so_532 da.nl.un_220
  0x35080205, 0x182d3507, 0x202a06ad, 0x27212a07,   // da.no.zu_333 zu.sk.ga_432  de.mt.sq_643 mt.jw.gd_432
  0x13003511, 0x3500250c, 0x17162aa0, 0x18013f07,   // zu.et.un_630 eu.zu.un_530  mt.hr.sr_322 af.en.ga_432
  // [38d0]
  0x2700011a, 0x31001b35, 0x2d0d0e14, 0x1f23060c,   // en.gd.un_760 tr.az.un_A90  is.cs.sk_666 de.ca.cy_543
  0x270f1ea0, 0x110a05af, 0x16002808, 0x271f0ea0,   // ms.lv.gd_322 fr.pt.ro_655  sw.hr.un_430 is.cy.gd_322
  0x642916a0, 0x0a192312, 0x2d0d10a4, 0x06000f12,   // hr.sl.lg_322 ca.gl.pt_654  lt.cs.sk_433 lv.de.un_640
  0x553507af, 0x182711ee, 0x08190aa0, 0x1c216411,   // it.zu.rw_655 ro.gd.ga_422  pt.gl.no_322 lg.jw.id_653
  // [38e0]
  0x041e1c05, 0x1f00062a, 0x016b5307, 0x28002d0d,   // id.ms.fi_333 de.cy.un_970  ht.ceb.en_432 sk.sw.un_540
  0x0e3f0812, 0x6b086404, 0x17071011, 0x28176407,   // no.af.is_654 lg.no.ceb_332  be.bg.sr_653 lg.sr.sw_432
  0x3f3135af, 0x28556b04, 0x35092113, 0x55355307,   // zu.az.af_655 ceb.rw.sw_332  jw.pl.zu_665 ht.zu.rw_432
  0x182d0d20, 0x641035ee, 0x32291604, 0x2b000707,   // cs.sk.ga_875 zu.lt.lg_422  hr.sl.bs_332 it.vi.un_420
  // [38f0]
  0x2d0d6e0e, 0x12101a08, 0x013f030b, 0x3f1a6bec,   // hmn.cs.sk_555 tl.lt.hu_443  nl.af.en_542 ceb.tl.af_644
  0x0f6435a6, 0x05012bee, 0x041108a9, 0x1b0612ee,   // zu.lg.lv_521 vi.en.fr_422  uk.ro.ru_544 hu.de.tr_422
  0x01001902, 0x0911120c, 0x0d001904, 0x23060a02,   // gl.en.un_220 hu.ro.pl_543  gl.cs.un_320 pt.de.ca_222
  0x07110aa4, 0x05002122, 0x060d0960, 0x64001012,   // mk.ro.bg_433 jw.fr.un_870  pl.cs.de_664 lt.lg.un_640
  // [3900]
  0x12002914, 0x056b6804, 0x0f2d2912, 0x3f1827ad,   // sl.hu.un_660 ig.ceb.fr_332  sl.sk.lv_654 gd.ga.af_643
  0x080205ec, 0x3f1168a4, 0x27002a13, 0x31006e14,   // fr.da.no_644 ig.ro.af_433  mt.gd.un_650 hmn.az.un_660
  0x2a0720a4, 0x01083bee, 0x3f006e14, 0x120b1911,   // sq.it.mt_433 so.no.en_422  hmn.af.un_660 gl.es.hu_653
  0x31056eee, 0x12002a14, 0x3f030208, 0x0d091205,   // hmn.fr.az_422 mt.hu.un_660  da.nl.af_443 hu.pl.cs_333
  // [3910]
  0x4a001212, 0x3b1e31a7, 0x23056ea0, 0x2700061a,   // hu.yo.un_640 az.ms.so_532  hmn.fr.ca_322 de.gd.un_760
  0x21192312, 0x110717a4, 0x0e31520b, 0x27000513,   // ca.gl.jw_654 sr.bg.ro_433  ha.az.is_542 fr.gd.un_650
  0x1c130912, 0x3f00270e, 0x12000404, 0x09293508,   // hi.bh.mr_654 gd.af.un_550  fi.hu.un_320 zu.sl.pl_443
  0x3209290c, 0x64351a08, 0x0c2d0d0c, 0x09041313,   // sl.pl.bs_543 tl.zu.lg_443  cs.sk.sv_543 et.fi.pl_665
  // [3920]
  0x3f190b55, 0x071108ad, 0x353128ee, 0x2a251e07,   // es.gl.af_442 uk.ro.bg_643  sw.az.zu_422 ms.eu.mt_432
  0x6e005321, 0x21640408, 0x1a006408, 0x04080cec,   // ht.hmn.un_860 fi.lg.jw_443  lg.tl.un_430 sv.no.fi_644
  0x11190b08, 0x11170aa4, 0x04000e1a, 0x030c0f07,   // es.gl.ro_443 mk.sr.ro_433  is.fi.un_760 lv.sv.nl_432
  0x080602af, 0x03003b12, 0x05000205, 0x18002102,   // da.de.no_655 so.nl.un_640  da.fr.un_330 jw.ga.un_220
  // [3930]
  0x190b53a0, 0x092d0d0c, 0x1c001e1a, 0x35001708,   // ht.es.gl_322 cs.sk.pl_543  ms.id.un_760 sr.zu.un_430
  0x6b041a0c, 0x170929a4, 0x092d29a4, 0x0f2d0d08,   // tl.fi.ceb_543 sl.pl.sr_433  sl.sk.pl_433 cs.sk.lv_443
  0x646b1a55, 0x08171604, 0x32162905, 0x4a110709,   // tl.ceb.lg_442 hr.sr.no_332  sl.hr.bs_333 it.ro.yo_444
  0x04002808, 0x0b000a07, 0x11071005, 0x200f4aa0,   // sw.fi.un_430 pt.es.un_420  lt.it.ro_333 yo.lv.sq_322
  // [3940]
  0x13072007, 0x08001005, 0x0d6b1a0c, 0x64002807,   // sq.it.et_432 be.uk.un_330  tl.ceb.cs_543 sw.lg.un_420
  0x11000702, 0x211812a0, 0x28683bec, 0x1a290ea0,   // it.ro.un_220 ur.ar.fa_322  so.ig.sw_644 is.sl.tl_322
  0x32175307, 0x2d120aac, 0x2a6b1a04, 0x4a00530e,   // ht.sr.bs_432 pt.hu.sk_632  tl.ceb.mt_332 ht.yo.un_550
  0x1a203bee, 0x1a043b09, 0x6421685a, 0x09006421,   // so.sq.tl_422 so.fi.tl_444  ig.jw.lg_553 lg.pl.un_860
  // [3950]
  0x075552a4, 0x0b2d0aa0, 0x21190ba4, 0x05000b0e,   // ha.rw.it_433 pt.sk.es_322  es.gl.jw_433 es.fr.un_550
  0x53000916, 0x270e1f07, 0x2a351a0c, 0x0d091c5a,   // pl.ht.un_720 cy.is.gd_432  tl.zu.mt_543 mr.hi.ne_553
  0x0d001219, 0x0305070c, 0x04080a08, 0x080a1714,   // hu.cs.un_750 it.fr.nl_543  mk.uk.ru_443 sr.mk.uk_666
  0x1c311ea0, 0x53005204, 0x130d1c0d, 0x0413640c,   // ms.az.id_322 ha.ht.un_320  mr.ne.bh_554 lg.et.fi_543
  // [3960]
  0x642a350d, 0x12046408, 0x091a6bec, 0x28006e07,   // zu.mt.lg_554 lg.fi.hu_443  ceb.tl.pl_644 hmn.sw.un_420
  0x291613a4, 0x6b042a04, 0x13200f07, 0x0d002a04,   // et.hr.sl_433 mt.fi.ceb_332  lv.sq.et_432 mt.cs.un_320
  0x0c0e6bee, 0x120b1814, 0x351a4aee, 0x0800110c,   // ceb.is.sv_422 ga.es.hu_666  yo.tl.zu_422 ro.uk.un_530
  0x10000f21, 0x21000b04, 0x13043fa0, 0x120b23af,   // lv.lt.un_860 es.jw.un_320  af.fi.et_322 ca.es.hu_655
  // [3970]
  0x015305ad, 0x0802055a, 0x25000912, 0x00002337,   // fr.ht.en_643 fr.da.no_553  pl.eu.un_640 ca.un.un_B00
  0x03043f08, 0x68001222, 0x25005522, 0x4a006412,   // af.fi.nl_443 hu.ig.un_870  rw.eu.un_870 lg.yo.un_640
  0x11002012, 0x2a29120c, 0x35000907, 0x55001c1a,   // sq.ro.un_640 hu.sl.mt_543  pl.zu.un_420 id.rw.un_760
  0x27524a55, 0x062308a4, 0x551b1a0c, 0x1100680d,   // yo.ha.gd_442 no.ca.de_433  tl.tr.rw_543 ig.ro.un_540
  // [3980]
  0x1f520d07, 0x3f0d53a9, 0x110a230e, 0x1a526ba4,   // cs.ha.cy_432 ht.cs.af_544  ca.pt.ro_555 ceb.ha.tl_433
  0x201b530c, 0x1a3f2912, 0x080c0d0c, 0x0f103507,   // ht.tr.sq_543 sl.af.tl_654  cs.sv.no_543 zu.lt.lv_432
  0x0c021008, 0x2d003505, 0x08201f12, 0x11105507,   // lt.da.sv_443 zu.sk.un_330  cy.sq.no_654 rw.lt.ro_432
  0x6b3b21a4, 0x0504530c, 0x231107a0, 0x531a100c,   // jw.so.ceb_433 ht.fi.fr_543  it.ro.ca_322 lt.tl.ht_543
  // [3990]
  0x20110a07, 0x033f6807, 0x31201e04, 0x322a070b,   // pt.ro.sq_432 ig.af.nl_432  ms.sq.az_332 it.mt.bs_542
  0x2d0f17a0, 0x64135508, 0x271118ee, 0x0d000508,   // sr.lv.sk_322 rw.et.lg_443  ga.ro.gd_422 fr.cs.un_430
  0x180127ee, 0x08100aa7, 0x29003202, 0x0a1f19af,   // gd.en.ga_422 mk.be.uk_532  bs.sl.un_220 gl.cy.pt_655
  0x29002d08, 0x31002819, 0x2b005205, 0x0b1819ee,   // sk.sl.un_430 sw.az.un_750  ha.vi.un_330 gl.ga.es_422
  // [39a0]
  0x286b1aec, 0x091c13ec, 0x681827a7, 0x531b6b55,   // tl.ceb.sw_644 bh.mr.hi_644  gd.ga.ig_532 ceb.tr.ht_442
  0x2801130b, 0x27000919, 0x03190bad, 0x1e3168a0,   // et.en.sw_542 pl.gd.un_750  es.gl.nl_643 ig.az.ms_322
  0x23001e04, 0x0f64130c, 0x2a005219, 0x07002819,   // ms.ca.un_320 et.lg.lv_543  ha.mt.un_750 sw.it.un_750
  0x1f090ba4, 0x6855280c, 0x683b280c, 0x35061fee,   // es.pl.cy_433 sw.rw.ig_543  sw.so.ig_543 cy.de.zu_422
  // [39b0]
  0x0b072312, 0x033f640d, 0x250e1a04, 0x28004a04,   // ca.it.es_654 lg.af.nl_554  tl.is.eu_332 yo.sw.un_320
  0x0d531f0b, 0x0f001c08, 0x55001907, 0x521b1ca0,   // cy.ht.cs_542 id.lv.un_430  gl.rw.un_420 id.tr.ha_322
  0x531b680c, 0x04006413, 0x53214aa7, 0x12076409,   // ig.tr.ht_543 lg.fi.un_650  yo.jw.ht_532 lg.it.hu_444
  0x1a6b2102, 0x53003507, 0x11002b13, 0x0d1b1ca4,   // jw.ceb.tl_222 zu.ht.un_420  vi.ro.un_650 id.tr.cs_433
  // [39c0]
  0x0c0e64a7, 0x0306050d, 0x115306a4, 0x0b19535a,   // lg.is.sv_532 fr.de.nl_554  de.ht.ro_433 ht.gl.es_553
  0x0c553507, 0x21001e13, 0x0a190b0d, 0x03001119,   // zu.rw.sv_432 ms.jw.un_650  es.gl.pt_554 ro.nl.un_750
  0x1100190c, 0x55282009, 0x53202812, 0x05005302,   // gl.ro.un_530 sq.sw.rw_444  sw.sq.ht_654 ht.fr.un_220
  0x550c08ad, 0x08020ca6, 0x1c311e0b, 0x4a001b2b,   // no.sv.rw_643 sv.da.no_521  ms.az.id_542 tr.yo.un_980
  // [39d0]
  0x0700040d, 0x286455ee, 0x1c00210c, 0x136404ec,   // ru.bg.un_540 rw.lg.sw_422  jw.id.un_530 fi.lg.et_644
  0x17000d0d, 0x6400041a, 0x1c2b1eee, 0x35001121,   // cs.sr.un_540 fi.lg.un_760  ms.vi.id_422 ro.zu.un_860
  0x12556408, 0x25553b12, 0x17100460, 0x1c080ea0,   // lg.rw.hu_443 so.rw.eu_654  ru.be.sr_664 is.no.id_322
  0x1b686455, 0x52122860, 0x2d0d0a0e, 0x1704110e,   // lg.ig.tr_442 sw.hu.ha_664  pt.cs.sk_555 ro.ru.sr_555
  // [39e0]
  0x55000307, 0x21001e09, 0x4a350e0d, 0x1e211cee,   // nl.rw.un_420 ms.jw.un_440  is.zu.yo_554 id.jw.ms_422
  0x28352aa0, 0x3f3b13a9, 0x4a0b1aee, 0x680128a6,   // mt.zu.sw_322 et.so.af_544  tl.es.yo_422 sw.en.ig_521
  0x1c1621ee, 0x20003208, 0x0a0623af, 0x121819a0,   // jw.hr.id_422 bs.sq.un_430  ca.de.pt_655 gl.ga.hu_322
  0x0817070c, 0x6b1a0faf, 0x060325ee, 0x230b0a08,   // bg.sr.uk_543 lv.tl.ceb_655  eu.nl.de_422 pt.es.ca_443
  // [39f0]
  0x1729280c, 0x07170860, 0x283153a4, 0x1b110709,   // sw.sl.sr_543 uk.sr.bg_664  ht.az.sw_433 it.ro.tr_444
  0x20550707, 0x3b1f3555, 0x0c001c04, 0x082d0d05,   // it.rw.sq_432 zu.cy.so_442  id.sv.un_320 cs.sk.no_333
  0x21053ba4, 0x0b18190c, 0x172935a0, 0x3b122107,   // so.fr.jw_433 gl.ga.es_543  zu.sl.sr_322 jw.hu.so_432
  0x3564310d, 0x0e0801a0, 0x0a5227a4, 0x6e290fa4,   // az.lg.zu_554 en.no.is_322  gd.ha.pt_433 lv.sl.hmn_433
  // [3a00]
  0x2b001e04, 0x09003213, 0x4a230707, 0x0a110705,   // ms.vi.un_320 bs.pl.un_650  it.ca.yo_432 bg.ro.mk_333
  0x28311b5a, 0x311b3509, 0x3520310c, 0x2b001602,   // tr.az.sw_553 zu.tr.az_444  az.sq.zu_543 hr.vi.un_220
  0x3b001f1a, 0x2d000f13, 0x04000c05, 0x2a2d1f07,   // cy.so.un_760 lv.sk.un_650  sv.fi.un_330 cy.sk.mt_432
  0x09190eee, 0x122111a7, 0x0d2d0e11, 0x3b003505,   // is.gl.pl_422 ro.jw.hu_532  is.sk.cs_653 zu.so.un_330
  // [3a10]
  0x29000804, 0x1f002d1a, 0x31005214, 0x536b1aad,   // no.sl.un_320 sk.cy.un_760  ha.az.un_660 tl.ceb.ht_643
  0x09131012, 0x6b6823ee, 0x0c001902, 0x1b001c08,   // lt.et.pl_654 ca.ig.ceb_422  gl.sv.un_220 id.tr.un_430
  0x09286408, 0x551b4a07, 0x1f000808, 0x0a1f2da4,   // lg.sw.pl_443 yo.tr.rw_432  no.cy.un_430 sk.cy.pt_433
  0x6b01110c, 0x55004a1a, 0x232a0709, 0x2b211ca0,   // ro.en.ceb_543 yo.rw.un_760  it.mt.ca_444 id.jw.vi_322
  // [3a20]
  0x312855ee, 0x311c52ad, 0x0c0901ad, 0x09250307,   // rw.sw.az_422 ha.id.az_643  en.pl.sv_643 nl.eu.pl_432
  0x0f1c1ea4, 0x112d1207, 0x1b1f530c, 0x1a063b07,   // ms.id.lv_433 hu.sk.ro_432  ht.cy.tr_543 so.de.tl_432
  0x3f100f09, 0x1b066baf, 0x1b000e1a, 0x1f2a53ec,   // lv.lt.af_444 ceb.de.tr_655  is.tr.un_760 ht.mt.cy_644
  0x2d1a230c, 0x1200111a, 0x683f100c, 0x521b0ea0,   // ca.tl.sk_543 ro.hu.un_760  lt.af.ig_543 is.tr.ha_322
  // [3a30]
  0x0a005507, 0x1b0a0e0c, 0x350c16a0, 0x2a313bad,   // rw.pt.un_420 is.pt.tr_543  hr.sv.zu_322 so.az.mt_643
  0x234a28a7, 0x351a11a4, 0x350613af, 0x08021309,   // sw.yo.ca_532 ro.tl.zu_433  et.de.zu_655 et.da.no_444
  0x1b003b1b, 0x0f006e13, 0x530b21a9, 0x13062a12,   // so.tr.un_770 hmn.lv.un_650  jw.es.ht_544 mt.de.et_654
  0x2a6425ad, 0x18041155, 0x6e000113, 0x18005321,   // eu.lg.mt_643 ro.fi.ga_442  en.hmn.un_650 ht.ga.un_860
  // [3a40]
  0x0a2923a0, 0x28001104, 0x2a0320ee, 0x23000d0e,   // ca.sl.pt_322 ro.sw.un_320  sq.nl.mt_422 cs.ca.un_550
  0x2a0f6e12, 0x203217a4, 0x040710af, 0x6e00011a,   // hmn.lv.mt_654 sr.bs.sq_433  be.bg.ru_655 en.hmn.un_760
  0x012005ee, 0x0d001213, 0x100925ad, 0x06110da0,   // fr.sq.en_422 hu.cs.un_650  eu.pl.lt_643 cs.ro.de_322
  0x212b010c, 0x02000c07, 0x29172da9, 0x1b200a05,   // en.vi.jw_543 sv.da.un_420  sk.sr.sl_544 pt.sq.tr_333
  // [3a50]
  0x23000a0c, 0x0510270c, 0x232119a0, 0x68552813,   // pt.ca.un_530 gd.lt.fr_543  gl.jw.ca_322 sw.rw.ig_665
  0x101c1e0c, 0x6b003109, 0x1a283bac, 0x1e1c25ee,   // ms.id.lt_543 az.ceb.un_440  so.sw.tl_632 eu.id.ms_422
  0x033b08a0, 0x311b3b08, 0x201b0f04, 0x282a2307,   // no.so.nl_322 so.tr.az_443  lv.tr.sq_332 ca.mt.sw_432
  0x11011f0c, 0x01002807, 0x0a033f07, 0x3f005505,   // cy.en.ro_543 sw.en.un_420  af.nl.pt_432 rw.af.un_330
  // [3a60]
  0x0d091ca9, 0x040d2d0c, 0x321608a4, 0x031b19a0,   // mr.hi.ne_544 sk.cs.fi_543  no.hr.bs_433 gl.tr.nl_322
  0x0d202d12, 0x6800251b, 0x3b1f210c, 0x1e00530c,   // sk.sq.cs_654 eu.ig.un_770  jw.cy.so_543 ht.ms.un_530
  0x130d090e, 0x25210405, 0x13090d12, 0x1320040d,   // hi.ne.bh_555 fi.jw.eu_333  ne.hi.bh_654 fi.sq.et_554
  0x0c00210c, 0x13002505, 0x090164ee, 0x2d040daf,   // jw.sv.un_530 eu.et.un_330  lg.en.pl_422 cs.fi.sk_655
  // [3a70]
  0x0b271a12, 0x12355555, 0x121f53a0, 0x55001b22,   // tl.gd.es_654 rw.zu.hu_442  ht.cy.hu_322 tr.rw.un_870
  0x21001a19, 0x210d0908, 0x02083f07, 0x08002d0d,   // tl.jw.un_750 pl.cs.jw_443  af.no.da_432 sk.no.un_540
  0x641325a7, 0x0c080e13, 0x2a006807, 0x0b55680c,   // eu.et.lg_532 is.no.sv_665  ig.mt.un_420 ig.rw.es_543
  0x6b001e04, 0x170a10a0, 0x1b120c0c, 0x06036ba0,   // ms.ceb.un_320 be.mk.sr_322  sv.hu.tr_543 ceb.nl.de_322
  // [3a80]
  0x1f004a08, 0x120d2d0b, 0x0b1e25a0, 0x0e061207,   // yo.cy.un_430 sk.cs.hu_542  eu.ms.es_322 hu.de.is_432
  0x23001c02, 0x1200231a, 0x6b551a04, 0x2800681a,   // id.ca.un_220 ca.hu.un_760  tl.rw.ceb_332 ig.sw.un_760
  0x0e190b08, 0x29050107, 0x1b0e0cad, 0x2a2016a4,   // es.gl.is_443 en.fr.sl_432  sv.is.tr_643 hr.sq.mt_433
  0x1c21100c, 0x17521a12, 0x126b1faf, 0x6b1f1a60,   // lt.jw.id_543 tl.ha.sr_654  cy.ceb.hu_655 tl.cy.ceb_664
  // [3a90]
  0x311b28a9, 0x1e272007, 0x291f0d07, 0x6b1a1e12,   // sw.tr.az_544 sq.gd.ms_432  cs.cy.sl_432 ms.tl.ceb_654
  0x080a17a0, 0x55311b11, 0x20002819, 0x1a216ba9,   // sr.mk.uk_322 tr.az.rw_653  sw.sq.un_750 ceb.jw.tl_544
  0x3b002018, 0x121a6bad, 0x05001022, 0x642853ad,   // sq.so.un_740 ceb.tl.hu_643  lt.fr.un_870 ht.sw.lg_643
  0x3f031313, 0x356423a4, 0x310c1b12, 0x1a6b120c,   // et.nl.af_665 ca.lg.zu_433  tr.sv.az_654 hu.ceb.tl_543
  // [3aa0]
  0x5564350e, 0x0b120505, 0x3564135a, 0x205535ee,   // zu.lg.rw_555 fr.hu.es_333  et.lg.zu_553 zu.rw.sq_422
  0x0264010c, 0x0e130411, 0x6431250d, 0x0600200d,   // en.lg.da_543 fi.et.is_653  eu.az.lg_554 sq.de.un_540
  0x2d190b0d, 0x08060fee, 0x25071b0c, 0x3f001a08,   // es.gl.sk_554 lv.de.no_422  tr.it.eu_543 tl.af.un_430
  0x31125304, 0x1f190a05, 0x250c0307, 0x03000214,   // ht.hu.az_332 pt.gl.cy_333  nl.sv.eu_432 da.nl.un_660
  // [3ab0]
  0x6b6468a7, 0x131f6b0d, 0x2800352a, 0x31110dee,   // ig.lg.ceb_532 ceb.cy.et_554  zu.sw.un_970 cs.ro.az_422
  0x1f1a1ea0, 0x01205255, 0x190b25a0, 0x072555a7,   // ms.tl.cy_322 ha.sq.en_442  eu.es.gl_322 rw.eu.it_532
  0x1110310c, 0x20351c05, 0x13190b07, 0x68002019,   // az.lt.ro_543 id.zu.sq_333  es.gl.et_432 sq.ig.un_750
  0x2d0d29ac, 0x351b3114, 0x1c101e07, 0x04001a05,   // sl.cs.sk_632 az.tr.zu_666  ms.lt.id_432 tl.fi.un_330
  // [3ac0]
  0x5320110d, 0x036b20a7, 0x64280208, 0x29161ca0,   // ro.sq.ht_554 sq.ceb.nl_532  da.sw.lg_443 id.hr.sl_322
  0x29321614, 0x20282d07, 0x19120ba4, 0x100208a4,   // hr.bs.sl_666 sk.sw.sq_432  es.hu.gl_433 no.da.lt_433
  0x19000a2a, 0x0f003504, 0x25122aa0, 0x6b0b1a05,   // pt.gl.un_970 zu.lv.un_320  mt.hu.eu_322 tl.es.ceb_333
  0x121a6b05, 0x211c1ea0, 0x121a0cad, 0x0b006412,   // ceb.tl.hu_333 ms.id.jw_322  sv.tl.hu_643 lg.es.un_640
  // [3ad0]
  0x120c1aa7, 0x3b1b355a, 0x06201107, 0x180e12ad,   // tl.sv.hu_532 zu.tr.so_553  ro.sq.de_432 hu.is.ga_643
  0x12194a04, 0x64004a02, 0x12000b02, 0x2d0d19a0,   // yo.gl.hu_332 yo.lg.un_220  es.hu.un_220 gl.cs.sk_322
  0x02063f05, 0x17162905, 0x196468ad, 0x1a001308,   // af.de.da_333 sl.hr.sr_333  ig.lg.gl_643 et.tl.un_430
  0x3555640d, 0x0d122dec, 0x55000c07, 0x041a6b07,   // lg.rw.zu_554 sk.hu.cs_644  sv.rw.un_420 ceb.tl.fi_432
  // [3ae0]
  0x2d3520a4, 0x350413af, 0x131c04ad, 0x080c0ead,   // sq.zu.sk_433 et.fi.zu_655  fi.id.et_643 is.sv.no_643
  0x120c1313, 0x281213a4, 0x09131c13, 0x0c1e0ba4,   // et.sv.hu_665 et.hu.sw_433  mr.bh.hi_665 es.ms.sv_433
  0x2d1355a7, 0x29071cee, 0x130c080c, 0x110108a0,   // rw.et.sk_532 id.it.sl_422  no.sv.et_543 no.en.ro_322
  0x13041e12, 0x133b1a09, 0x2b005521, 0x05190b04,   // ms.fi.et_654 tl.so.et_444  rw.vi.un_860 es.gl.fr_332
  // [3af0]
  0x0a0c0607, 0x0c061f0c, 0x0e063f04, 0x01192304,   // de.sv.pt_432 cy.de.sv_543  af.de.is_332 ca.gl.en_332
  0x0e231905, 0x52006e0e, 0x643f68a4, 0x55352811,   // gl.ca.is_333 hmn.ha.un_550  ig.af.lg_433 sw.zu.rw_653
  0x2d033504, 0x0f0c13a4, 0x682835a4, 0x2d00351a,   // zu.nl.sk_332 et.sv.lv_433  zu.sw.ig_433 zu.sk.un_760
  0x0811100c, 0x2d10130c, 0x2b4a5204, 0x1b085308,   // be.ro.uk_543 et.lt.sk_543  ha.yo.vi_332 ht.no.tr_443
  // [3b00]
  0x09172907, 0x55103ba0, 0x31086811, 0x05002317,   // sl.sr.pl_432 so.lt.rw_322  ig.no.az_653 ca.fr.un_730
  0x35551e0e, 0x2000121b, 0x13001a08, 0x00001c37,   // ms.rw.zu_555 hu.sq.un_770  tl.et.un_430 mr.un.un_B00
  0x0f003204, 0x0a000512, 0x645568a9, 0x0e285504,   // bs.lv.un_320 fr.pt.un_640  ig.rw.lg_544 rw.sw.is_332
  0x31521b08, 0x312a0a07, 0x10286813, 0x0e1218af,   // tr.ha.az_443 pt.mt.az_432  ig.sw.lt_665 ga.hu.is_655
  // [3b10]
  0x52281fa6, 0x06033fa0, 0x091e1c04, 0x28356807,   // cy.sw.ha_521 af.nl.de_322  id.ms.pl_332 ig.zu.sw_432
  0x13000e0e, 0x642868ad, 0x291735ee, 0x32291707,   // is.et.un_550 ig.sw.lg_643  zu.sr.sl_422 sr.sl.bs_432
  0x01646ba4, 0x17005304, 0x21001105, 0x290828ee,   // ceb.lg.en_433 ht.sr.un_320  ro.jw.un_330 sw.no.sl_422
  0x21003512, 0x012518a4, 0x210420a4, 0x2055280d,   // zu.jw.un_640 ga.eu.en_433  sq.fi.jw_433 sw.rw.sq_554
  // [3b20]
  0x311168a4, 0x161f4aa6, 0x09072aee, 0x20681a07,   // ig.ro.az_433 yo.cy.hr_521  mt.it.pl_422 tl.ig.sq_432
  0x191a6b08, 0x092a1eee, 0x170708a6, 0x205228a4,   // ceb.tl.gl_443 ms.mt.pl_422  uk.bg.sr_521 sw.ha.sq_433
  0x21112707, 0x28136809, 0x21003509, 0x0c001e04,   // gd.ro.jw_432 ig.et.sw_444  zu.jw.un_440 ms.sv.un_320
  0x53683bad, 0x6864285a, 0x216420a4, 0x1131280c,   // so.ig.ht_643 sw.lg.ig_553  sq.lg.jw_433 sw.az.ro_543
  // [3b30]
  0x1c020e12, 0x1f0c06a9, 0x18102755, 0x551b31a9,   // is.da.id_654 de.sv.cy_544  gd.lt.ga_442 az.tr.rw_544
  0x0a171009, 0x06182708, 0x64684a12, 0x17000f08,   // be.sr.mk_444 gd.ga.de_443  yo.ig.lg_654 lv.sr.un_430
  0x081f270c, 0x09002102, 0x17005508, 0x292d170c,   // gd.cy.no_543 jw.pl.un_220  rw.sr.un_430 sr.sk.sl_543
  0x64311bad, 0x4a251ca0, 0x121b100c, 0x316828af,   // tr.az.lg_643 id.eu.yo_322  lt.tr.hu_543 sw.ig.az_655
  // [3b40]
  0x19040b07, 0x282a3504, 0x3b18010b, 0x2a200e0c,   // es.fi.gl_432 zu.mt.sw_332  en.ga.so_542 is.sq.mt_543
  0x1800010c, 0x100b070c, 0x21002829, 0x2b092a04,   // en.ga.un_530 it.es.lt_543  sw.jw.un_960 mt.pl.vi_332
  0x18031311, 0x1700550c, 0x28002a1a, 0x642868a9,   // et.nl.ga_653 rw.sr.un_530  mt.sw.un_760 ig.sw.lg_544
  0x13002119, 0x52006409, 0x5264680c, 0x292d35af,   // jw.et.un_750 lg.ha.un_440  ig.lg.ha_543 zu.sk.sl_655
  // [3b50]
  0x1e6b1aaf, 0x0a0923a0, 0x2d001208, 0x10045308,   // tl.ceb.ms_655 ca.pl.pt_322  hu.sk.un_430 ht.fi.lt_443
  0x1304110c, 0x1e551fa4, 0x1e2864a4, 0x3f0913a4,   // ro.fi.et_543 cy.rw.ms_433  lg.sw.ms_433 et.pl.af_433
  0x18273ba4, 0x114a1704, 0x02080ca7, 0x68170911,   // so.gd.ga_433 sr.yo.ro_332  sv.no.da_532 pl.sr.ig_653
  0x35120708, 0x1100291a, 0x0e1310ec, 0x1a1e5507,   // it.hu.zu_443 sl.ro.un_760  lt.et.is_644 rw.ms.tl_432
  // [3b60]
  0x0a181210, 0x270521ad, 0x16003b08, 0x0f2a250c,   // hu.ga.pt_642 jw.fr.gd_643  so.hr.un_430 eu.mt.lv_543
  0x111e1c13, 0x0d190b08, 0x2d17290d, 0x4a3b1a0c,   // id.ms.ro_665 es.gl.cs_443  sl.sr.sk_554 tl.so.yo_543
  0x042d0d5a, 0x251135a0, 0x0c0208a0, 0x091c0d04,   // cs.sk.fi_553 zu.ro.eu_322  no.da.sv_322 ne.mr.hi_332
  0x52092d08, 0x27002007, 0x09003507, 0x13110413,   // sk.pl.ha_443 sq.gd.un_420  zu.pl.un_420 fi.ro.et_665
  // [3b70]
  0x6b061a02, 0x12230a07, 0x0f2a280c, 0x1e0a5204,   // tl.de.ceb_222 pt.ca.hu_432  sw.mt.lv_543 ha.pt.ms_332
  0x551628a7, 0x3121520c, 0x0d171602, 0x1e003b07,   // sw.hr.rw_532 ha.jw.az_543  hr.sr.cs_222 so.ms.un_420
  0x070a1104, 0x271805a4, 0x0410280c, 0x352864a9,   // ro.mk.bg_332 fr.ga.gd_433  sw.lt.fi_543 lg.sw.zu_544
  0x1f0e0b04, 0x07111705, 0x32031ca0, 0x0e003202,   // es.is.cy_332 sr.ro.bg_333  id.nl.bs_322 bs.is.un_220
  // [3b80]
  0x04201312, 0x551a350c, 0x1c090d55, 0x18201e07,   // et.sq.fi_654 zu.tl.rw_543  ne.hi.mr_442 ms.sq.ga_432
  0x3b135304, 0x030635ad, 0x171107a9, 0x211a270c,   // ht.et.so_332 zu.de.nl_643  bg.ro.sr_544 gd.tl.jw_543
  0x07002313, 0x20553507, 0x06002707, 0x190b68a4,   // ca.it.un_650 zu.rw.sq_432  gd.de.un_420 ig.es.gl_433
  0x20002305, 0x4a3f03a4, 0x12000f1a, 0x01006404,   // ca.sq.un_330 nl.af.yo_433  lv.hu.un_760 lg.en.un_320
  // [3b90]
  0x35100708, 0x10004a0d, 0x1b182712, 0x642835a9,   // it.lt.zu_443 yo.lt.un_540  gd.ga.tr_654 zu.sw.lg_544
  0x060302ee, 0x05120aa4, 0x112a070c, 0x0b182807,   // da.nl.de_422 pt.hu.fr_433  it.mt.ro_543 sw.ga.es_432
  0x0a000819, 0x180111a7, 0x3b1b31a4, 0x0500210e,   // uk.mk.un_750 ro.en.ga_532  az.tr.so_433 jw.fr.un_550
  0x28003508, 0x12350308, 0x3f126b04, 0x271f2a12,   // zu.sw.un_430 nl.zu.hu_443  ceb.hu.af_332 mt.cy.gd_654
  // [3ba0]
  0x0e001122, 0x0a0817a4, 0x0c002007, 0x11530b05,   // ro.is.un_870 sr.uk.mk_433  sq.sv.un_420 es.ht.ro_333
  0x03005307, 0x1b033f07, 0x21311b12, 0x53311b07,   // ht.nl.un_420 af.nl.tr_432  tr.az.jw_654 tr.az.ht_432
  0x3f1264a4, 0x2a3f1a08, 0x022a03ec, 0x033f35a9,   // lg.hu.af_433 tl.af.mt_443  nl.mt.da_644 zu.af.nl_544
  0x1b315312, 0x033f01a4, 0x1800521a, 0x5521350e,   // ht.az.tr_654 en.af.nl_433  ha.ga.un_760 zu.jw.rw_555
  // [3bb0]
  0x04063f05, 0x0a0810a9, 0x0e001f05, 0x080e270c,   // af.de.fi_333 be.uk.mk_544  cy.is.un_330 gd.is.no_543
  0x6b531a0c, 0x280255a7, 0x120335af, 0x081b0c0b,   // tl.ht.ceb_543 rw.da.sw_532  zu.nl.hu_655 sv.tr.no_542
  0x1c00520c, 0x06002a07, 0x110155a4, 0x25005512,   // ha.id.un_530 mt.de.un_420  rw.en.ro_433 rw.eu.un_640
  0x08001212, 0x1c1b1aa9, 0x03642812, 0x02080e0b,   // hu.no.un_640 tl.tr.id_544  sw.lg.nl_654 is.no.da_542
  // [3bc0]
  0x2a020eee, 0x033f55a9, 0x3f215305, 0x1c1a21ad,   // is.da.mt_422 rw.af.nl_544  ht.jw.af_333 jw.tl.id_643
  0x6412350c, 0x122d0aee, 0x082812a4, 0x081a2155,   // zu.hu.lg_543 pt.sk.hu_422  hu.sw.no_433 jw.tl.no_442
  0x3217520c, 0x35211a04, 0x6811275a, 0x1f033faf,   // ha.sr.bs_543 tl.jw.zu_332  gd.ro.ig_553 af.nl.cy_655
  0x13211aa7, 0x6828030e, 0x1f00181b, 0x1c0e21ad,   // tl.jw.et_532 nl.sw.ig_555  ga.cy.un_770 jw.is.id_643
  // [3bd0]
  0x2300011a, 0x0f190bec, 0x092d11a4, 0x321711af,   // en.ca.un_760 es.gl.lv_644  ro.sk.pl_433 ro.sr.bs_655
  0x641a2814, 0x3f031aa0, 0x21003522, 0x12001c0d,   // sw.tl.lg_666 tl.nl.af_322  zu.jw.un_870 id.hu.un_540
  0x3b041e05, 0x2855110c, 0x0900190d, 0x553268a7,   // ms.fi.so_333 ro.rw.sw_543  gl.pl.un_540 ig.bs.rw_532
  0x1a1e2104, 0x09190b02, 0x1e1c210c, 0x1c3f21a0,   // jw.ms.tl_332 es.gl.pl_222  jw.id.ms_543 jw.af.id_322
  // [3be0]
  0x25001105, 0x08021a05, 0x2d001019, 0x23033f60,   // ro.eu.un_330 tl.da.no_333  lt.sk.un_750 af.nl.ca_664
  0x103f1307, 0x090f2813, 0x121e5504, 0x311c1e07,   // et.af.lt_432 sw.lv.pl_665  rw.ms.hu_332 ms.id.az_432
  0x32291ca0, 0x08041113, 0x12002b22, 0x072001ee,   // id.sl.bs_322 ro.ru.uk_665  vi.hu.un_870 en.sq.it_422
  0x122b4a0c, 0x55642005, 0x04083f12, 0x28356412,   // yo.vi.hu_543 sq.lg.rw_333  af.no.fi_654 lg.zu.sw_654
  // [3bf0]
  0x355564ad, 0x2d0d6ba0, 0x64524aa4, 0x3f030655,   // lg.rw.zu_643 ceb.cs.sk_322  yo.ha.lg_433 de.nl.af_442
  0x0e0d2b11, 0x0f2a2905, 0x072a010c, 0x3f001219,   // vi.cs.is_653 sl.mt.lv_333  en.mt.it_543 hu.af.un_750
  0x283564a0, 0x0a6455ad, 0x353b5512, 0x355206a4,   // lg.zu.sw_322 rw.lg.pt_643  rw.so.zu_654 de.ha.zu_433
  0x0a6410ee, 0x6e0b5307, 0x2d0d1ca0, 0x553b28ec,   // lt.lg.pt_422 ht.es.hmn_432  id.cs.sk_322 sw.so.rw_644

  // [3c00]
  0x3b5255ad, 0x6b040f0c, 0x0e002714, 0x4a2855a9,   // rw.ha.so_643 lv.fi.ceb_543  gd.is.un_660 rw.sw.yo_544
  0x211b29a9, 0x030625ee, 0x290e1e08, 0x120f1a08,   // sl.tr.jw_544 eu.de.nl_422  ms.is.sl_443 tl.lv.hu_443
  0x120f040d, 0x01190b05, 0x0c0813a7, 0x121a0ca9,   // fi.lv.hu_554 es.gl.en_333  et.no.sv_532 sv.tl.hu_544
  0x52681b08, 0x030601a0, 0x04005323, 0x3f0635a4,   // tr.ig.ha_443 en.de.nl_322  ht.fi.un_880 zu.de.af_433
  // [3c10]
  0x0800110e, 0x12230f05, 0x32055307, 0x525355a4,   // ro.uk.un_550 lv.ca.hu_333  ht.fr.bs_432 rw.ht.ha_433
  0x05000e07, 0x55086407, 0x19530b5a, 0x3b554a05,   // is.fr.un_420 lg.no.rw_432  es.ht.gl_553 yo.rw.so_333
  0x03001204, 0x07001f05, 0x5305520b, 0x6b05530c,   // hu.nl.un_320 cy.it.un_330  ha.fr.ht_542 ht.fr.ceb_543
  0x201b0fee, 0x12531a04, 0x295305a4, 0x3b2864a0,   // lv.tr.sq_422 tl.ht.hu_332  fr.ht.sl_433 lg.sw.so_322
  // [3c20]
  0x07530507, 0x0c520a04, 0x2a001f14, 0x0f001209,   // fr.ht.it_432 pt.ha.sv_332  cy.mt.un_660 hu.lv.un_440
  0x28002004, 0x06000e14, 0x121a0fa4, 0x2800030c,   // sq.sw.un_320 is.de.un_660  lv.tl.hu_433 nl.sw.un_530
  0x6412550c, 0x1a356b02, 0x12000819, 0x64551b13,   // rw.hu.lg_543 ceb.zu.tl_222  no.hu.un_750 tr.rw.lg_665
  0x06036408, 0x083f03ad, 0x05530d12, 0x53020508,   // lg.nl.de_443 nl.af.no_643  cs.ht.fr_654 fr.da.ht_443
  // [3c30]
  0x55641060, 0x04003502, 0x53000121, 0x0d53050c,   // lt.lg.rw_664 zu.fi.un_220  en.ht.un_860 fr.ht.cs_543
  0x531b0e0d, 0x0f000e12, 0x0435110c, 0x08000c19,   // is.tr.ht_554 is.lv.un_640  ro.zu.fi_543 sv.no.un_750
  0x356455ec, 0x3b1b0e55, 0x32311b05, 0x10006422,   // rw.lg.zu_644 is.tr.so_442  tr.az.bs_333 lg.lt.un_870
  0x352852ad, 0x13292da4, 0x273b2aee, 0x21002308,   // ha.sw.zu_643 sk.sl.et_433  mt.so.gd_422 ca.jw.un_430
  // [3c40]
  0x0b2319a4, 0x02002108, 0x212a200c, 0x0f162907,   // gl.ca.es_433 jw.da.un_430  sq.mt.jw_543 sl.hr.lv_432
  0x1f000b1b, 0x09112da0, 0x041b0f0c, 0x09010d05,   // es.cy.un_770 sk.ro.pl_322  lv.tr.fi_543 cs.en.pl_333
  0x10130b08, 0x35001f21, 0x05074aa0, 0x2d2319a0,   // es.et.lt_443 cy.zu.un_860  yo.it.fr_322 gl.ca.sk_322
  0x35552814, 0x530a110c, 0x2300271b, 0x0a1e1c0c,   // sw.rw.zu_666 ro.pt.ht_543  gd.ca.un_770 id.ms.pt_543
  // [3c50]
  0x0a073507, 0x08000108, 0x281a11a4, 0x280107a0,   // zu.it.pt_432 en.no.un_430  ro.tl.sw_433 it.en.sw_322
  0x060e0ca4, 0x1c080205, 0x0b001b08, 0x105335a4,   // sv.is.de_433 da.no.id_333  tr.es.un_430 zu.ht.lt_433
  0x2a0a04ee, 0x32170da4, 0x53003121, 0x2835530e,   // fi.pt.mt_422 cs.sr.bs_433  az.ht.un_860 ht.zu.sw_555
  0x2a0c3204, 0x2a013207, 0x311b35a0, 0x29530107,   // bs.sv.mt_332 bs.en.mt_432  zu.tr.az_322 en.ht.sl_432
  // [3c60]
  0x05013507, 0x2a3b1fa7, 0x311b21af, 0x03026e0c,   // zu.en.fr_432 cy.so.mt_532  jw.tr.az_655 hmn.da.nl_543
  0x043f0eec, 0x0e0f0807, 0x29322d14, 0x530a1c0c,   // is.af.fi_644 no.lv.is_432  sk.bs.sl_666 id.pt.ht_543
  0x291153ac, 0x35003b19, 0x08122aa0, 0x19003504,   // ht.ro.sl_632 so.zu.un_750  mt.hu.no_322 zu.gl.un_320
  0x1700101b, 0x53002704, 0x3b1a6ba4, 0x16090d07,   // be.sr.un_770 gd.ht.un_320  ceb.tl.so_433 cs.pl.hr_432
  // [3c70]
  0x2a0e06a4, 0x0d3b13ad, 0x11311b0d, 0x076435ec,   // de.is.mt_433 et.so.cs_643  tr.az.ro_554 zu.lg.it_644
  0x281e1cad, 0x1c1f1e55, 0x52001e04, 0x01036ba0,   // id.ms.sw_643 ms.cy.id_442  ms.ha.un_320 ceb.nl.en_322
  0x1a2807af, 0x190a0709, 0x2d0d55af, 0x1c1a2508,   // it.sw.tl_655 it.pt.gl_444  rw.cs.sk_655 eu.tl.id_443
  0x2d0d250d, 0x645525af, 0x0e2b120c, 0x31130808,   // eu.cs.sk_554 eu.rw.lg_655  hu.vi.is_543 no.et.az_443
  // [3c80]
  0x0b1029a9, 0x1b3529a7, 0x0a002d04, 0x170a0813,   // sl.lt.es_544 sl.zu.tr_532  sk.pt.un_320 uk.mk.sr_665
  0x13205202, 0x3512280e, 0x55002809, 0x06000814,   // ha.sq.et_222 sw.hu.zu_555  sw.rw.un_440 no.de.un_660
  0x0c1306a4, 0x01311ba4, 0x55352d0d, 0x21230512,   // de.et.sv_433 tr.az.en_433  sk.zu.rw_554 fr.ca.jw_654
  0x1b1152a7, 0x520f1c07, 0x522855ee, 0x0e0464a0,   // ha.ro.tr_532 id.lv.ha_432  rw.sw.ha_422 lg.fi.is_322
  // [3c90]
  0x160f2d08, 0x061f0e04, 0x1364040c, 0x3b0a19a9,   // sk.lv.hr_443 is.cy.de_332  fi.lg.et_543 gl.pt.so_544
  0x53000608, 0x1100520d, 0x4a35640e, 0x11210f0c,   // de.ht.un_430 ha.ro.un_540  lg.zu.yo_555 lv.jw.ro_543
  0x04130c09, 0x0b64350d, 0x06210913, 0x1c215205,   // sv.et.fi_444 zu.lg.es_554  pl.jw.de_665 ha.jw.id_333
  0x1f023f55, 0x12002302, 0x070c08a0, 0x0c192aee,   // af.da.cy_442 ca.hu.un_220  no.sv.it_322 mt.gl.sv_422
  // [3ca0]
  0x3b001c02, 0x130f01a4, 0x17202d07, 0x2d2318ad,   // id.so.un_220 en.lv.et_433  sk.sq.sr_432 ga.ca.sk_643
  0x05000d1a, 0x080c0207, 0x1e52250c, 0x03000121,   // cs.fr.un_760 da.sv.no_432  eu.ha.ms_543 en.nl.un_860
  0x273f010c, 0x25114aa4, 0x212728a7, 0x1c090dee,   // en.af.gd_543 yo.ro.eu_433  sw.gd.jw_532 ne.hi.mr_422
  0x0c000614, 0x1c2a1e07, 0x6b0a010b, 0x0c00030e,   // de.sv.un_660 ms.mt.id_432  en.pt.ceb_542 nl.sv.un_550
  // [3cb0]
  0x6b03010c, 0x0f062d08, 0x556b1a07, 0x2a063fad,   // en.nl.ceb_543 sk.de.lv_443  tl.ceb.rw_432 af.de.mt_643
  0x0e171355, 0x0e00280c, 0x112a2308, 0x03066b02,   // et.sr.is_442 sw.is.un_530  ca.mt.ro_443 ceb.de.nl_222
  0x182b1c04, 0x1f004a04, 0x321e1c04, 0x183f03a0,   // id.vi.ga_332 yo.cy.un_320  id.ms.bs_332 nl.af.ga_322
  0x01033fa9, 0x0f291f08, 0x100c6bad, 0x073512a9,   // af.nl.en_544 cy.sl.lv_443  ceb.sv.lt_643 hu.zu.it_544
  // [3cc0]
  0x01002a04, 0x1e1c23a4, 0x1c2a210c, 0x0700230e,   // mt.en.un_320 ca.id.ms_433  jw.mt.id_543 ca.it.un_550
  0x09000a07, 0x1a1f13a9, 0x321721a4, 0x01032704,   // pt.pl.un_420 et.cy.tl_544  jw.sr.bs_433 gd.nl.en_332
  0x16285507, 0x1f033f09, 0x6b132da4, 0x18000a13,   // rw.sw.hr_432 af.nl.cy_444  sk.et.ceb_433 pt.ga.un_650
  0x2100250d, 0x17292d0e, 0x1e1a13a4, 0x3f172913,   // eu.jw.un_540 sk.sl.sr_555  et.tl.ms_433 sl.sr.af_665
  // [3cd0]
  0x01002521, 0x281e3bee, 0x1c1f21a4, 0x4a1b17a0,   // eu.en.un_860 so.ms.sw_422  jw.cy.id_433 sr.tr.yo_322
  0x1211070c, 0x28311b08, 0x060c0304, 0x065308a7,   // it.ro.hu_543 tr.az.sw_443  nl.sv.de_332 no.ht.de_532
  0x16060e12, 0x0d192011, 0x03131fac, 0x29005214,   // is.de.hr_654 sq.gl.cs_653  cy.et.nl_632 ha.sl.un_660
  0x1a1b535a, 0x53003521, 0x1b1119ee, 0x052d0912,   // ht.tr.tl_553 zu.ht.un_860  gl.ro.tr_422 pl.sk.fr_654
  // [3ce0]
  0x2a000421, 0x190b11a0, 0x11162da7, 0x311e3b0c,   // fi.mt.un_860 ro.es.gl_322  sk.hr.ro_532 so.ms.az_543
  0x10120407, 0x06113ba0, 0x312a1c09, 0x641620ee,   // fi.hu.lt_432 so.ro.de_322  id.mt.az_444 sq.hr.lg_422
  0x3f1a1f11, 0x10000809, 0x5300200e, 0x271e130c,   // cy.tl.af_653 uk.be.un_440  sq.ht.un_550 et.ms.gd_543
  0x32172daf, 0x21555204, 0x08350c07, 0x531b4aee,   // sk.sr.bs_655 ha.rw.jw_332  sv.zu.no_432 yo.tr.ht_422
  // [3cf0]
  0x04005307, 0x1c0f21a0, 0x190b4a0c, 0x083f6412,   // ht.fi.un_420 jw.lv.id_322  yo.es.gl_543 lg.af.no_654
  0x1b125307, 0x531219a0, 0x2b003204, 0x016b020c,   // ht.hu.tr_432 gl.hu.ht_322  bs.vi.un_320 da.ceb.en_543
  0x3f005520, 0x551b5304, 0x1b005314, 0x090d2013,   // rw.af.un_850 ht.tr.rw_332  ht.tr.un_660 sq.cs.pl_665
  0x02036409, 0x1b006412, 0x111b3113, 0x1100250e,   // lg.nl.da_444 lg.tr.un_640  az.tr.ro_665 eu.ro.un_550
  // [3d00]
  0x08041713, 0x55352813, 0x0c000412, 0x0c040614,   // sr.ru.uk_665 sw.zu.rw_665  fi.sv.un_640 de.fi.sv_666
  0x3f001208, 0x033f1f60, 0x52002a05, 0x11170a05,   // hu.af.un_430 cy.af.nl_664  mt.ha.un_330 mk.sr.ro_333
  0x12002705, 0x0d001e04, 0x04036405, 0x201e270c,   // gd.hu.un_330 ms.cs.un_320  lg.nl.fi_333 gd.ms.sq_543
  0x08071155, 0x080a110c, 0x1a21275a, 0x3f1b0607,   // ro.bg.uk_442 ro.mk.uk_543  gd.jw.tl_553 de.tr.af_432
  // [3d10]
  0x0b002a04, 0x1b001e02, 0x0721270c, 0x05271811,   // mt.es.un_320 ms.tr.un_220  gd.jw.it_543 ga.gd.fr_653
  0x2810010b, 0x2a1106ee, 0x1b2a03ee, 0x1e271f0d,   // en.lt.sw_542 de.ro.mt_422  nl.mt.tr_422 cy.gd.ms_554
  0x102718a4, 0x081c1ea9, 0x05001e08, 0x18082704,   // ga.gd.lt_433 ms.id.no_544  ms.fr.un_430 gd.no.ga_332
  0x03201b14, 0x0600320c, 0x21005302, 0x1b121ea9,   // tr.sq.nl_666 bs.de.un_530  ht.jw.un_220 ms.hu.tr_544
  // [3d20]
  0x27230ba0, 0x28003f14, 0x1e283f08, 0x08070aad,   // es.ca.gd_322 af.sw.un_660  af.sw.ms_443 mk.bg.uk_643
  0x180504ee, 0x0d130955, 0x0125050c, 0x27050107,   // fi.fr.ga_422 hi.bh.ne_442  fr.eu.en_543 en.fr.gd_432
  0x07000e11, 0x1b273114, 0x3f350311, 0x0c002304,   // is.it.un_630 az.gd.tr_666  nl.zu.af_653 ca.sv.un_320
  0x033f01a0, 0x3b2d29ee, 0x071008a4, 0x04170aa9,   // en.af.nl_322 sl.sk.so_422  uk.be.bg_433 mk.sr.ru_544
  // [3d30]
  0x1e1c280e, 0x04000c1b, 0x29091104, 0x21001022,   // sw.id.ms_555 sv.fi.un_770  ro.pl.sl_332 lt.jw.un_870
  0x202813a4, 0x6b11130c, 0x3f000204, 0x041113af,   // et.sw.sq_433 et.ro.ceb_543  da.af.un_320 et.ro.fi_655
  0x32170f14, 0x35030a04, 0x2511135a, 0x23022da0,   // lv.sr.bs_666 pt.nl.zu_332  et.ro.eu_553 sk.da.ca_322
  0x0e2811ee, 0x1e291cec, 0x01000805, 0x052a3b04,   // ro.sw.is_422 id.sl.ms_644  no.en.un_330 so.mt.fr_332
  // [3d40]
  0x21131160, 0x2300350c, 0x08041304, 0x3b033f60,   // ro.et.jw_664 zu.ca.un_530  et.fi.no_332 af.nl.so_664
  0x112017ee, 0x13042009, 0x190b05ad, 0x0e041308,   // sr.sq.ro_422 sq.fi.et_444  fr.es.gl_643 et.fi.is_443
  0x0f202855, 0x16072a07, 0x070d4a05, 0x6428130c,   // sw.sq.lv_442 mt.it.hr_432  yo.cs.it_333 et.sw.lg_543
  0x01112aee, 0x1b120608, 0x05003119, 0x23003f07,   // mt.ro.en_422 de.hu.tr_443  az.fr.un_750 af.ca.un_420
  // [3d50]
  0x1c292860, 0x061e1cec, 0x081213ad, 0x2301050c,   // sw.sl.id_664 id.ms.de_644  et.hu.no_643 fr.en.ca_543
  0x4a001a05, 0x1e1c6b09, 0x050701ec, 0x120e0cad,   // tl.yo.un_330 ceb.id.ms_444  en.it.fr_644 sv.is.hu_643
  0x03080cad, 0x216b13ee, 0x05101f0c, 0x06001f09,   // sv.no.nl_643 et.ceb.jw_422  cy.lt.fr_543 cy.de.un_440
  0x13004a07, 0x161e1c55, 0x6b293507, 0x19201107,   // yo.et.un_420 id.ms.hr_442  zu.sl.ceb_432 ro.sq.gl_432
  // [3d60]
  0x0e005313, 0x28133f0d, 0x05005317, 0x1c061e04,   // ht.is.un_650 af.et.sw_554  ht.fr.un_730 ms.de.id_332
  0x200911a9, 0x1e1c6ba4, 0x136b0e04, 0x11002a13,   // ro.pl.sq_544 ceb.id.ms_433  is.ceb.et_332 mt.ro.un_650
  0x080e1fec, 0x1e1c06a9, 0x120964ad, 0x2812350b,   // cy.is.no_644 de.id.ms_544  lg.pl.hu_643 zu.hu.sw_542
  0x53190ba7, 0x130d09ad, 0x1f001a13, 0x0f08120c,   // es.gl.ht_532 hi.ne.bh_643  tl.cy.un_650 hu.no.lv_543
  // [3d70]
  0x6e6b68a0, 0x643506ec, 0x03050108, 0x2808120c,   // ig.ceb.hmn_322 de.zu.lg_644  en.fr.nl_443 hu.no.sw_543
  0x3b002819, 0x21082007, 0x255513a4, 0x132112ee,   // sw.so.un_750 sq.no.jw_432  et.rw.eu_433 hu.jw.et_422
  0x27126b07, 0x10321704, 0x6b080204, 0x0e1e1c0d,   // ceb.hu.gd_432 sr.bs.lt_332  da.no.ceb_332 id.ms.is_554
  0x1b100cad, 0x13002308, 0x352768af, 0x040c0608,   // sv.lt.tr_643 ca.et.un_430  ig.gd.zu_655 de.sv.fi_443
  // [3d80]
  0x0c00041a, 0x01000c04, 0x060c0107, 0x1f0e0ca0,   // fi.sv.un_760 sv.en.un_320  en.sv.de_432 sv.is.cy_322
  0x120523af, 0x040a1008, 0x27352812, 0x1b002104,   // ca.fr.hu_655 be.mk.ru_443  sw.zu.gd_654 jw.tr.un_320
  0x080c0e13, 0x64043505, 0x203f0313, 0x12006b12,   // is.sv.no_665 zu.fi.lg_333  nl.af.sq_665 ceb.hu.un_640
  0x130821a4, 0x0200551a, 0x3b55350c, 0x0c0608ec,   // jw.no.et_433 rw.da.un_760  zu.rw.so_543 no.de.sv_644
  // [3d90]
  0x120e08a0, 0x0413125a, 0x55006413, 0x131c2104,   // no.is.hu_322 hu.et.fi_553  lg.rw.un_650 jw.id.et_332
  0x0f3f0308, 0x64060e5a, 0x211c310c, 0x6b3f0355,   // nl.af.lv_443 is.de.lg_553  az.id.jw_543 nl.af.ceb_442
  0x1b092da4, 0x18005507, 0x02001f1a, 0x5364120c,   // sk.pl.tr_433 rw.ga.un_420  cy.da.un_760 hu.lg.ht_543
  0x071f0213, 0x01060ca4, 0x230b05ac, 0x08040307,   // da.cy.it_665 sv.de.en_433  fr.es.ca_632 nl.fi.no_432
  // [3da0]
  0x10321708, 0x131a3b14, 0x2d0d3b0e, 0x2d0d0702,   // sr.bs.lt_443 so.tl.et_666  so.cs.sk_555 it.cs.sk_222
  0x28043ba9, 0x3b130311, 0x060e08a0, 0x643f1aa4,   // so.fi.sw_544 nl.et.so_653  no.is.de_322 tl.af.lg_433
  0x011353a0, 0x041e5205, 0x166b2008, 0x321608ec,   // ht.et.en_322 ha.ms.fi_333  sq.ceb.hr_443 no.hr.bs_644
  0x12080209, 0x3b4a64ad, 0x03683b12, 0x033f3bad,   // da.no.hu_444 lg.yo.so_643  so.ig.nl_654 so.af.nl_643
  // [3db0]
  0x641a6b60, 0x1c000d20, 0x0a070811, 0x1c033bee,   // ceb.tl.lg_664 ne.mr.un_850  uk.bg.mk_653 so.nl.id_422
  0x190b23a0, 0x686b0107, 0x1e1b1a08, 0x0c000622,   // ca.es.gl_322 en.ceb.ig_432  tl.tr.ms_443 de.sv.un_870
  0x051f01af, 0x531827af, 0x681b1a55, 0x64133b05,   // en.cy.fr_655 gd.ga.ht_655  tl.tr.ig_442 so.et.lg_333
  0x1300280c, 0x270401a9, 0x043f1aee, 0x2d090da0,   // sw.et.un_530 en.fi.gd_544  tl.af.fi_422 cs.pl.sk_322
  // [3dc0]
  0x1a6b1b0d, 0x133f0411, 0x032a2da0, 0x07171155,   // tr.ceb.tl_554 fi.af.et_653  sk.mt.nl_322 ro.sr.it_442
  0x0d1f3102, 0x04311bad, 0x206b1a55, 0x32001c04,   // az.cy.cs_222 tr.az.fi_643  tl.ceb.sq_442 id.bs.un_320
  0x190a0b0c, 0x0500230e, 0x06000f08, 0x2d0d0ea0,   // es.pt.gl_543 ca.fr.un_550  lv.de.un_430 is.cs.sk_322
  0x283132a0, 0x290d3504, 0x230b19ad, 0x01001313,   // bs.az.sw_322 zu.cs.sl_332  gl.es.ca_643 et.en.un_650
  // [3dd0]
  0x16000b07, 0x07052107, 0x1a1f0111, 0x1a002702,   // es.hr.un_420 jw.fr.it_432  en.cy.tl_653 gd.tl.un_220
  0x1c211e07, 0x53041e0c, 0x0c0106a9, 0x071f1804,   // ms.jw.id_432 ms.fi.ht_543  de.en.sv_544 ga.cy.it_332
  0x170a1160, 0x3f0603a9, 0x1a011f0d, 0x1a6b0407,   // ro.mk.sr_664 nl.de.af_544  cy.en.tl_554 fi.ceb.tl_432
  0x211228a4, 0x08020309, 0x13201002, 0x1b003209,   // sw.hu.jw_433 nl.da.no_444  lt.sq.et_222 bs.tr.un_440
  // [3de0]
  0x054a6b0c, 0x04002312, 0x5207210c, 0x0e00180e,   // ceb.yo.fr_543 ca.fi.un_640  jw.it.ha_543 ga.is.un_550
  0x06001e08, 0x283b1ea4, 0x190b1105, 0x0d131c0d,   // ms.de.un_430 ms.so.sw_433  ro.es.gl_333 mr.bh.ne_554
  0x55283509, 0x1b000f21, 0x29181eee, 0x53680707,   // zu.sw.rw_444 lv.tr.un_860  ms.ga.sl_422 it.ig.ht_432
  0x0c131b07, 0x310910af, 0x040e0c07, 0x170f1ba7,   // tr.et.sv_432 lt.pl.az_655  sv.is.fi_432 tr.lv.sr_532
  // [3df0]
  0x29283512, 0x20001a02, 0x21181208, 0x051c0e02,   // zu.sw.sl_654 tl.sq.un_220  ur.ar.fa_443 is.id.fr_222
  0x641a53ad, 0x130f1207, 0x190b120c, 0x12000b04,   // ht.tl.lg_643 hu.lv.et_432  hu.es.gl_543 es.hu.un_320
  0x3b1e280c, 0x23000507, 0x12230507, 0x6b2001a0,   // sw.ms.so_543 fr.ca.un_420  fr.ca.hu_432 en.sq.ceb_322
  0x32200faf, 0x13060707, 0x210f1b11, 0x190b2da9,   // lv.sq.bs_655 it.de.et_432  tr.lv.jw_653 sk.es.gl_544
  // [3e00]
  0x53000f08, 0x0e1f250c, 0x02033f07, 0x1a001c13,   // lv.ht.un_430 eu.cy.is_543  af.nl.da_432 id.tl.un_650
  0x23111855, 0x13040f08, 0x040d2055, 0x2a100f12,   // ga.ro.ca_442 lv.fi.et_443  sq.cs.fi_442 lv.lt.mt_654
  0x680d01a4, 0x25100f13, 0x35006b12, 0x3f2a28a4,   // en.cs.ig_433 lv.lt.eu_665  ceb.zu.un_640 sw.mt.af_433
  0x1f000e1a, 0x230c1aa9, 0x0407175a, 0x53080eec,   // is.cy.un_760 tl.sv.ca_544  sr.bg.ru_553 is.no.ht_644
  // [3e10]
  0x351a5302, 0x0f13170c, 0x25171b0c, 0x00002737,   // ht.tl.zu_222 sr.et.lv_543  tr.sr.eu_543 gd.un.un_B00
  0x131017a0, 0x116b0f07, 0x18005302, 0x6b071aaf,   // sr.lt.et_322 lv.ceb.ro_432  ht.ga.un_220 tl.it.ceb_655
  0x08001b0e, 0x18005307, 0x3b040e04, 0x0c002508,   // tr.no.un_550 ht.ga.un_420  is.fi.so_332 eu.sv.un_430
  0x040a1755, 0x190b68a0, 0x11200d0c, 0x53281b05,   // sr.mk.ru_442 ig.es.gl_322  cs.sq.ro_543 tr.sw.ht_333
  // [3e20]
  0x100411a0, 0x200c2304, 0x64190bad, 0x1a5321a9,   // ro.ru.be_322 ca.sv.sq_332  es.gl.lg_643 jw.ht.tl_544
  0x05532012, 0x04250fee, 0x1120010c, 0x0a124aa7,   // sq.ht.fr_654 lv.eu.fi_422  en.sq.ro_543 yo.hu.pt_532
  0x2d0d27af, 0x06521b0c, 0x191a0b0b, 0x10001602,   // gd.cs.sk_655 tr.ha.de_543  es.tl.gl_542 hr.lt.un_220
  0x2a005314, 0x0e013b04, 0x23190ba7, 0x1e281c0c,   // ht.mt.un_660 so.en.is_332  es.gl.ca_532 id.sw.ms_543
  // [3e30]
  0x0f003207, 0x0b190aad, 0x170a1104, 0x0e022507,   // bs.lv.un_420 pt.gl.es_643  ro.mk.sr_332 eu.da.is_432
  0x01001a04, 0x3152280d, 0x0b0a0714, 0x131a28ac,   // tl.en.un_320 sw.ha.az_554  it.pt.es_666 sw.tl.et_632
  0x09190b0c, 0x25006813, 0x011b20a4, 0x232d0d55,   // es.gl.pl_543 ig.eu.un_650  sq.tr.en_433 cs.sk.ca_442
  0x2d001a05, 0x12002105, 0x3500641a, 0x013b6bad,   // tl.sk.un_330 jw.hu.un_330  lg.zu.un_760 ceb.so.en_643
  // [3e40]
  0x35201aa4, 0x09001334, 0x0b290d0c, 0x13000c08,   // tl.sq.zu_433 bh.hi.un_A80  cs.sl.es_543 sv.et.un_430
  0x0b0a0c11, 0x10001605, 0x2d0d1014, 0x232d0deb,   // sv.pt.es_653 hr.lt.un_330  lt.cs.sk_666 cs.sk.ca_662
  0x3b526408, 0x1a3b6b0c, 0x3f031c04, 0x211a6b0c,   // lg.ha.so_443 ceb.so.tl_543  id.nl.af_332 ceb.tl.jw_543
  0x3b001a19, 0x16005512, 0x2900090e, 0x35131a07,   // tl.so.un_750 rw.hr.un_640  pl.sl.un_550 tl.et.zu_432
  // [3e50]
  0x0911200c, 0x0a0d2dec, 0x17292aa4, 0x2d29200d,   // sq.ro.pl_543 sk.cs.pt_644  mt.sl.sr_433 sq.sl.sk_554
  0x06001707, 0x32080255, 0x11081008, 0x1600100d,   // sr.de.un_420 da.no.bs_442  be.uk.ro_443 lt.hr.un_540
  0x02001213, 0x07283513, 0x23111905, 0x35003204,   // hu.da.un_650 zu.sw.it_665  gl.ro.ca_333 bs.zu.un_320
  0x3f351c04, 0x3f112514, 0x53521ea0, 0x2b3f10ec,   // id.zu.af_332 eu.ro.af_666  ms.ha.ht_322 lt.af.vi_644
  // [3e60]
  0x1b07120c, 0x21033f0c, 0x23271f0c, 0x6b3b1a0c,   // hu.it.tr_543 af.nl.jw_543  cy.gd.ca_543 tl.so.ceb_543
  0x31002d08, 0x060f1fa7, 0x3b521a0c, 0x03001004,   // sk.az.un_430 cy.lv.de_532  tl.ha.so_543 lt.nl.un_320
  0x28000d04, 0x3b281a0c, 0x120a4aaf, 0x28131aa0,   // cs.sw.un_320 tl.sw.so_543  yo.pt.hu_655 tl.et.sw_322
  0x05230b08, 0x4a002522, 0x64003b13, 0x553b1aad,   // es.ca.fr_443 eu.yo.un_870  so.lg.un_650 tl.so.rw_643
  // [3e70]
  0x3b312008, 0x2055310c, 0x181f0807, 0x04000214,   // sq.az.so_443 az.rw.sq_543  no.cy.ga_432 da.fi.un_660
  0x1b6468ee, 0x4a202955, 0x29200f04, 0x1a043b05,   // ig.lg.tr_422 sl.sq.yo_442  lv.sq.sl_332 so.fi.tl_333
  0x2d321655, 0x3b521b0c, 0x230319a0, 0x12000f13,   // hr.bs.sk_442 tr.ha.so_543  gl.nl.ca_322 lv.hu.un_650
  0x0a120ea0, 0x02011207, 0x11100460, 0x0e1321a7,   // is.hu.pt_322 hu.en.da_432  ru.be.ro_664 jw.et.is_532
  // [3e80]
  0x232d0daf, 0x0e000d0d, 0x041028a4, 0x0a250b07,   // cs.sk.ca_655 cs.is.un_540  sw.lt.fi_433 es.eu.pt_432
  0x0f0413af, 0x0d091cad, 0x6b683107, 0x351c2a0c,   // et.fi.lv_655 mr.hi.ne_643  az.ig.ceb_432 mt.id.zu_543
  0x060a0308, 0x23060704, 0x29001122, 0x20253b07,   // nl.pt.de_443 it.de.ca_332  ro.sl.un_870 so.eu.sq_432
  0x1e050807, 0x55001e13, 0x1c13090e, 0x03112d08,   // no.fr.ms_432 ms.rw.un_650  hi.bh.mr_555 sk.ro.nl_443
  // [3e90]
  0x18003202, 0x122003ee, 0x0b002307, 0x283f0a12,   // bs.ga.un_220 nl.sq.hu_422  ca.es.un_420 pt.af.sw_654
  0x07011fa0, 0x31283b0c, 0x230b12ad, 0x353b28ad,   // cy.en.it_322 so.sw.az_543  hu.es.ca_643 sw.so.zu_643
  0x4a530708, 0x1b0c3ba0, 0x042523af, 0x3b3510a4,   // it.ht.yo_443 so.sv.tr_322  ca.eu.fi_655 lt.zu.so_433
  0x1f351bec, 0x552835ad, 0x0e521bec, 0x18000704,   // tr.zu.cy_644 zu.sw.rw_643  tr.ha.is_644 it.ga.un_320
  // [3ea0]
  0x181b27a4, 0x0e000a04, 0x35642809, 0x06553512,   // gd.tr.ga_433 pt.is.un_320  sw.lg.zu_444 zu.rw.de_654
  0x1004170d, 0x282d3513, 0x0800020b, 0x1e313504,   // sr.ru.be_554 zu.sk.sw_665  da.no.un_520 zu.az.ms_332
  0x020e550c, 0x32006807, 0x53112a04, 0x0f002921,   // rw.is.da_543 ig.bs.un_420  mt.ro.ht_332 sl.lv.un_860
  0x35311ba4, 0x050713a0, 0x120b23a4, 0x0f00680c,   // tr.az.zu_433 et.it.fr_322  ca.es.hu_433 ig.lv.un_530
  // [3eb0]
  0x09000d33, 0x6e003b20, 0x29000d22, 0x0e190b04,   // ne.hi.un_A70 so.hmn.un_850  cs.sl.un_870 es.gl.is_332
  0x1a6b4a0c, 0x2b0c0611, 0x040208ec, 0x186e64a4,   // yo.ceb.tl_543 de.sv.vi_653  no.da.fi_644 lg.hmn.ga_433
  0x2d00092a, 0x17071004, 0x1a013b07, 0x030c3fa0,   // pl.sk.un_970 be.bg.sr_332  so.en.tl_432 af.sv.nl_322
  0x07006e08, 0x2d091fec, 0x23214a05, 0x2b136ba0,   // hmn.it.un_430 cy.pl.sk_644  yo.jw.ca_333 ceb.et.vi_322
  // [3ec0]
  0x2d0d12b2, 0x21002821, 0x682917a4, 0x120c0f0c,   // hu.cs.sk_732 sw.jw.un_860  sr.sl.ig_433 lv.sv.hu_543
  0x10070804, 0x25351905, 0x2d0d23af, 0x3113640d,   // uk.bg.be_332 gl.zu.eu_333  ca.cs.sk_655 lg.et.az_554
  0x1b003202, 0x133b3fa4, 0x0235680c, 0x293b6e07,   // bs.tr.un_220 af.so.et_433  ig.zu.da_543 hmn.so.sl_432
  0x6b2318a4, 0x3b003102, 0x01006b02, 0x28012aa4,   // ga.ca.ceb_433 az.so.un_220  ceb.en.un_220 mt.en.sw_433
  // [3ed0]
  0x121e1c07, 0x32033fa0, 0x322d2905, 0x07005508,   // id.ms.hu_432 af.nl.bs_322  sl.sk.bs_333 rw.it.un_430
  0x16006e08, 0x191223a7, 0x1c2a2102, 0x2300070d,   // hmn.hr.un_430 ca.hu.gl_532  jw.mt.id_222 it.ca.un_540
  0x31181b14, 0x030635a7, 0x28006b08, 0x03061812,   // tr.ga.az_666 zu.de.nl_532  ceb.sw.un_430 ga.de.nl_654
  0x07100a05, 0x32101655, 0x0c000608, 0x1900230c,   // mk.be.bg_333 hr.lt.bs_442  de.sv.un_430 ca.gl.un_530
  // [3ee0]
  0x06040c12, 0x1b2531a4, 0x012a0704, 0x64551ea0,   // sv.fi.de_654 az.eu.tr_433  it.mt.en_332 ms.rw.lg_322
  0x090c0808, 0x082835ee, 0x53000509, 0x1b00230e,   // no.sv.pl_443 zu.sw.no_422  fr.ht.un_440 ca.tr.un_550
  0x1a041ea0, 0x1a356ba4, 0x2b6b1c11, 0x0d00290e,   // ms.fi.tl_322 ceb.zu.tl_433  id.ceb.vi_653 sl.cs.un_550
  0x356864ec, 0x3b355555, 0x64253513, 0x19121307,   // lg.ig.zu_644 rw.zu.so_442  zu.eu.lg_665 et.hu.gl_432
  // [3ef0]
  0x0c001f2b, 0x131c0911, 0x1b1321a4, 0x3f001e04,   // cy.sv.un_980 hi.mr.bh_653  jw.et.tr_433 ms.af.un_320
  0x6b001c05, 0x110708a4, 0x20250807, 0x073f010c,   // id.ceb.un_330 uk.bg.ro_433  no.eu.sq_432 en.af.it_543
  0x251819a0, 0x080204ee, 0x2d120513, 0x531907af,   // gl.ga.eu_322 fi.da.no_422  fr.hu.sk_665 it.gl.ht_655
  0x191a5511, 0x6b01060c, 0x1c211ea0, 0x23055312,   // rw.tl.gl_653 de.en.ceb_543  ms.jw.id_322 ht.fr.ca_654
  // [3f00]
  0x52126b02, 0x08060c55, 0x190b070e, 0x200f5505,   // ceb.hu.ha_222 sv.de.no_442  it.es.gl_555 rw.lv.sq_333
  0x10294aec, 0x551f4a0c, 0x2d551908, 0x16000d0c,   // yo.sl.lt_644 yo.cy.rw_543  gl.rw.sk_443 cs.hr.un_530
  0x1b27530b, 0x2a23060c, 0x202b5304, 0x4a051905,   // ht.gd.tr_542 de.ca.mt_543  ht.vi.sq_332 gl.fr.yo_333
  0x531e0307, 0x19283555, 0x00005337, 0x0e182712,   // nl.ms.ht_432 zu.sw.gl_442  ht.un.un_B00 gd.ga.is_654
  // [3f10]
  0x1f071104, 0x1b000521, 0x550a07a4, 0x171629a4,   // ro.it.cy_332 fr.tr.un_860  it.pt.rw_433 sl.hr.sr_433
  0x19002004, 0x250602af, 0x07005208, 0x20521aa0,   // sq.gl.un_320 da.de.eu_655  ha.it.un_430 tl.ha.sq_322
  0x200b2704, 0x05000104, 0x0b004a02, 0x060313ee,   // gd.es.sq_332 en.fr.un_320  yo.es.un_220 et.nl.de_422
  0x5552280c, 0x10003b14, 0x3f31050c, 0x2a0c060c,   // sw.ha.rw_543 so.lt.un_660  fr.az.af_543 de.sv.mt_543
  // [3f20]
  0x07191aa4, 0x0a081009, 0x3500130d, 0x0c0628a0,   // tl.gl.it_433 be.uk.mk_444  et.zu.un_540 sw.de.sv_322
  0x1a1011a4, 0x21251eee, 0x551364ec, 0x526455ee,   // ro.lt.tl_433 ms.eu.jw_422  lg.et.rw_644 rw.lg.ha_422
  0x081c1e11, 0x64211ca4, 0x1f3b0413, 0x52131b13,   // ms.id.no_653 id.jw.lg_433  fi.so.cy_665 tr.et.ha_665
  0x131021a0, 0x16006b0c, 0x27066ea0, 0x1a553513,   // jw.lt.et_322 ceb.hr.un_530  hmn.de.gd_322 zu.rw.tl_665
  // [3f30]
  0x6e005314, 0x64121fa0, 0x070168a0, 0x01006e05,   // ht.hmn.un_660 cy.hu.lg_322  ig.en.it_322 hmn.en.un_330
  0x6b1b53a4, 0x17066e07, 0x0718270c, 0x6b1b1a11,   // ht.tr.ceb_433 hmn.de.sr_432  gd.ga.it_543 tl.tr.ceb_653
  0x291a6eee, 0x3f6408a4, 0x12091812, 0x280855a4,   // hmn.tl.sl_422 no.lg.af_433  ga.pl.hu_654 rw.no.sw_433
  0x351b5505, 0x12182312, 0x09002008, 0x12006e04,   // rw.tr.zu_333 ca.ga.hu_654  sq.pl.un_430 hmn.hu.un_320
  // [3f40]
  0x64520304, 0x53001c08, 0x111b13a4, 0x0d043f04,   // nl.ha.lg_332 id.ht.un_430  et.tr.ro_433 af.fi.cs_332
  0x0f1123ad, 0x53003519, 0x10251113, 0x13041a0c,   // ca.ro.lv_643 zu.ht.un_750  ro.eu.lt_665 tl.fi.et_543
  0x106b1a05, 0x043f52a4, 0x130825ad, 0x170a080c,   // tl.ceb.lt_333 ha.af.fi_433  eu.no.et_643 uk.mk.sr_543
  0x29000a08, 0x1f006e23, 0x3f0308af, 0x111e0707,   // pt.sl.un_430 hmn.cy.un_880  no.nl.af_655 it.ms.ro_432
  // [3f50]
  0x64033f12, 0x040208a4, 0x23001216, 0x1c0d0911,   // af.nl.lg_654 no.da.fi_433  hu.ca.un_720 hi.ne.mr_653
  0x2d190a55, 0x1b190aa4, 0x0d122d07, 0x3f1b2512,   // pt.gl.sk_442 pt.gl.tr_433  sk.hu.cs_432 eu.tr.af_654
  0x1e523b04, 0x1b1e1c08, 0x551c21a0, 0x17042a07,   // so.ha.ms_332 id.ms.tr_443  jw.id.rw_322 mt.fi.sr_432
  0x100b1912, 0x4a2112a7, 0x0e032daf, 0x6e000f08,   // gl.es.lt_654 hu.jw.yo_532  sk.nl.is_655 lv.hmn.un_430
  // [3f60]
  0x3b001a07, 0x0a001702, 0x120655a4, 0x13160da4,   // tl.so.un_420 sr.mk.un_220  rw.de.hu_433 cs.hr.et_433
  0x0c0d2912, 0x0b23110c, 0x35001a0c, 0x1e13200c,   // sl.cs.sv_654 ro.ca.es_543  tl.zu.un_530 sq.et.ms_543
  0x0d190aa9, 0x3f181f0d, 0x2d002302, 0x55200f0c,   // pt.gl.cs_544 cy.ga.af_554  ca.sk.un_220 lv.sq.rw_543
  0x3b551b60, 0x4a006802, 0x351a6b13, 0x01003b04,   // tr.rw.so_664 ig.yo.un_220  ceb.tl.zu_665 so.en.un_320
  // [3f70]
  0x0e041304, 0x0c0325ee, 0x1e1c55ee, 0x28556b12,   // et.fi.is_332 eu.nl.sv_422  rw.id.ms_422 ceb.rw.sw_654
  0x25213513, 0x1a6b5555, 0x350321af, 0x19100bec,   // zu.jw.eu_665 rw.ceb.tl_442  jw.nl.zu_655 es.lt.gl_644
  0x0f190b0d, 0x32006b08, 0x130d2da0, 0x55212511,   // es.gl.lv_554 ceb.bs.un_430  sk.cs.et_322 eu.jw.rw_653
  0x171325ee, 0x02033f0e, 0x0e000213, 0x4a5231af,   // eu.et.sr_422 af.nl.da_555  da.is.un_650 az.ha.yo_655
  // [3f80]
  0x28213b12, 0x35003b07, 0x190a0f0e, 0x32162907,   // so.jw.sw_654 so.zu.un_420  lv.pt.gl_555 sl.hr.bs_432
  0x276e2a07, 0x190a0ba0, 0x6b1e1c0d, 0x181923a4,   // mt.hmn.gd_432 es.pt.gl_322  id.ms.ceb_554 ca.gl.ga_433
  0x271801af, 0x18010505, 0x4a135507, 0x1c3b1e0d,   // en.ga.gd_655 fr.en.ga_333  rw.et.yo_432 ms.so.id_554
  0x030e3f04, 0x250c3f08, 0x081a6bad, 0x06182713,   // af.is.nl_332 af.sv.eu_443  ceb.tl.no_643 gd.ga.de_665
  // [3f90]
  0x19122da7, 0x0312250c, 0x1b251ea9, 0x060328a0,   // sk.hu.gl_532 eu.hu.nl_543  ms.eu.tr_544 sw.nl.de_322
  0x1e1a1c11, 0x0e082108, 0x04252108, 0x0c210812,   // id.tl.ms_653 jw.no.is_443  jw.eu.fi_443 no.jw.sv_654
  0x181b35ad, 0x271f01a9, 0x25092da0, 0x0c530e13,   // zu.tr.ga_643 en.cy.gd_544  sk.pl.eu_322 is.ht.sv_665
  0x211c6804, 0x29001712, 0x272001a9, 0x271918ee,   // ig.id.jw_332 sr.sl.un_640  en.sq.gd_544 ga.gl.gd_422
  // [3fa0]
  0x06081355, 0x026b1a0d, 0x08003f1a, 0x02001a12,   // et.no.de_442 tl.ceb.da_554  af.no.un_760 tl.da.un_640
  0x1100181a, 0x1e211ca9, 0x20110fa4, 0x0e020c55,   // ga.ro.un_760 id.jw.ms_544  lv.ro.sq_433 sv.da.is_442
  0x6b1b28ac, 0x212a28a4, 0x132928a4, 0x1e3b280c,   // sw.tr.ceb_632 sw.mt.jw_433  sw.sl.et_433 sw.so.ms_543
  0x08230611, 0x3b1f5202, 0x6b3b1307, 0x03002513,   // de.ca.no_653 ha.cy.so_222  et.so.ceb_432 eu.nl.un_650
  // [3fb0]
  0x27011f07, 0x642718ec, 0x1900311b, 0x313b5207,   // cy.en.gd_432 ga.gd.lg_644  az.gl.un_770 ha.so.az_432
  0x6b002508, 0x0d1c130d, 0x64285555, 0x190b11a4,   // eu.ceb.un_430 bh.mr.ne_554  rw.sw.lg_442 ro.es.gl_433
  0x09135555, 0x06000821, 0x52000f1a, 0x01072d05,   // rw.et.pl_442 no.de.un_860  lv.ha.un_760 sk.it.en_333
  0x11050708, 0x124a1308, 0x230d2da9, 0x23011b0c,   // it.fr.ro_443 et.yo.hu_443  sk.cs.ca_544 tr.en.ca_543
  // [3fc0]
  0x19002d0d, 0x251b3104, 0x01000921, 0x12046baf,   // sk.gl.un_540 az.tr.eu_332  pl.en.un_860 ceb.fi.hu_655
  0x02180607, 0x040a0702, 0x25190aa4, 0x19521a0d,   // de.ga.da_432 bg.mk.ru_222  pt.gl.eu_433 tl.ha.gl_554
  0x06030f07, 0x0e190b10, 0x080e03ad, 0x28004a13,   // lv.nl.de_432 es.gl.is_642  nl.is.no_643 yo.sw.un_650
  0x0d006814, 0x315528a4, 0x080218ee, 0x20285304,   // ig.cs.un_660 sw.rw.az_433  ga.da.no_422 ht.sw.sq_332
  // [3fd0]
  0x0f001709, 0x0205010c, 0x031c08ad, 0x3b3564af,   // sr.lv.un_440 en.fr.da_543  no.id.nl_643 lg.zu.so_655
  0x324a5508, 0x2d0d4aa6, 0x0c0a0809, 0x0a002108,   // rw.yo.bs_443 yo.cs.sk_521  no.pt.sv_444 jw.pt.un_430
  0x0a00010c, 0x550128a4, 0x025508af, 0x100a04ee,   // en.pt.un_530 sw.en.rw_433  no.rw.da_655 fi.pt.lt_422
  0x060c010c, 0x350255af, 0x190b070c, 0x19002d08,   // en.sv.de_543 rw.da.zu_655  it.es.gl_543 sk.gl.un_430
  // [3fe0]
  0x2d0d0cee, 0x08001122, 0x190b18ec, 0x020c08ee,   // sv.cs.sk_422 ro.uk.un_870  ga.es.gl_644 no.sv.da_422
  0x01001904, 0x050a3b04, 0x07170808, 0x1a53010c,   // gl.en.un_320 so.pt.fr_332  uk.sr.bg_443 en.ht.tl_543
  0x01133b07, 0x64531a02, 0x0c06030c, 0x1055010c,   // so.et.en_432 tl.ht.lg_222  nl.de.sv_543 en.rw.lt_543
  0x0a005519, 0x6455050b, 0x234a050b, 0x23004a0d,   // rw.pt.un_750 fr.rw.lg_542  fr.yo.ca_542 yo.ca.un_540
  // [3ff0]
  0x64030607, 0x550c025a, 0x041110af, 0x1f354a05,   // de.nl.lg_432 da.sv.rw_553  be.ro.ru_655 yo.zu.cy_333
  0x23004a12, 0x28001c04, 0x3b040ea0, 0x283b35ad,   // yo.ca.un_640 id.sw.un_320  is.fi.so_322 zu.so.sw_643
  0x4a000708, 0x1300030c, 0x0e0f1011, 0x2168200c,   // it.yo.un_430 nl.et.un_530  lt.lv.is_653 sq.ig.jw_543
  0x08005304, 0x10000f2b, 0x0e03100c, 0x35644aa4,   // ht.no.un_320 lv.lt.un_980  lt.nl.is_543 yo.lg.zu_433

  // [4000]
  0x05006e04, 0x1b001e08, 0x35010607, 0x0b191812,   // hmn.fr.un_320 ms.tr.un_430  de.en.zu_432 ga.gl.es_654
  0x08132a0e, 0x643568af, 0x0e002d13, 0x3f036e08,   // mt.et.no_555 ig.zu.lg_655  sk.is.un_650 hmn.nl.af_443
  0x04001a0e, 0x07002322, 0x136b1a07, 0x085528ee,   // tl.fi.un_550 ca.it.un_870  tl.ceb.et_432 sw.rw.no_422
  0x01060c0c, 0x31041b21, 0x1e026407, 0x1f131aee,   // sv.de.en_543 tr.fi.az_876  lg.da.ms_432 tl.et.cy_422
  // [4010]
  0x3b000a12, 0x061b310b, 0x28011805, 0x3b0d52a0,   // pt.so.un_640 az.tr.de_542  ga.en.sw_333 ha.cs.so_322
  0x1a3b6ba0, 0x550664a0, 0x120635a4, 0x126b1a60,   // ceb.so.tl_322 lg.de.rw_322  zu.de.hu_433 tl.ceb.hu_664
  0x06093f04, 0x291135a9, 0x3f060c14, 0x0a000616,   // af.pl.de_332 zu.ro.sl_544  sv.de.af_666 de.pt.un_720
  0x070511af, 0x100c1307, 0x1a036ba4, 0x0c251e0c,   // ro.fr.it_655 et.sv.lt_432  ceb.nl.tl_433 ms.eu.sv_543
  // [4020]
  0x171110a4, 0x190a2305, 0x28352008, 0x04080305,   // be.ro.sr_433 ca.pt.gl_333  sq.zu.sw_443 nl.no.fi_333
  0x041a6b0c, 0x284a350c, 0x0e060ca9, 0x5300350d,   // ceb.tl.fi_543 zu.yo.sw_543  sv.de.is_544 zu.ht.un_540
  0x13211aad, 0x29552808, 0x6b102904, 0x0d253b11,   // tl.jw.et_643 sw.rw.sl_443  sl.lt.ceb_332 so.eu.cs_653
  0x17081105, 0x4a003522, 0x3f0112a9, 0x350952a0,   // ro.uk.sr_333 zu.yo.un_870  hu.en.af_544 ha.pl.zu_322
  // [4030]
  0x27001f09, 0x0e2a080d, 0x2a070c07, 0x35115504,   // cy.gd.un_440 no.mt.is_554  sv.it.mt_432 rw.ro.zu_332
  0x1f283512, 0x32002911, 0x253f01a4, 0x19230aa9,   // zu.sw.cy_654 sl.bs.un_630  en.af.eu_433 pt.ca.gl_544
  0x3b003521, 0x010c1f05, 0x08291607, 0x2821120c,   // zu.so.un_860 cy.sv.en_333  hr.sl.no_432 hu.jw.sw_543
  0x29001f14, 0x1004110c, 0x6b033f05, 0x20251b0c,   // cy.sl.un_660 ro.ru.be_543  af.nl.ceb_333 tr.eu.sq_543
  // [4040]
  0x1c062107, 0x1c1b1ea0, 0x1e061ca4, 0x250c08a4,   // jw.de.id_432 ms.tr.id_322  id.de.ms_433 no.sv.eu_433
  0x35646813, 0x556428af, 0x0e08010c, 0x52311b60,   // ig.lg.zu_665 sw.lg.rw_655  en.no.is_543 tr.az.ha_664
  0x123f0305, 0x1100062b, 0x0c002908, 0x18001e02,   // nl.af.hu_333 de.ro.un_980  sl.sv.un_430 ms.ga.un_220
  0x2907090c, 0x531827ad, 0x0c0729a4, 0x1e1c27a4,   // pl.it.sl_543 gd.ga.ht_643  sl.it.sv_433 gd.id.ms_433
  // [4050]
  0x1b6b1a0e, 0x21521eee, 0x2d100d14, 0x2a031a07,   // tl.ceb.tr_555 ms.ha.jw_422  cs.lt.sk_666 tl.nl.mt_432
  0x083521a4, 0x35000a0d, 0x28006412, 0x0e120aee,   // jw.zu.no_433 pt.zu.un_540  lg.sw.un_640 pt.hu.is_422
  0x2d121aa0, 0x090a18ec, 0x03643f12, 0x12003504,   // tl.hu.sk_322 ga.pt.pl_644  af.lg.nl_654 zu.hu.un_320
  0x213568ee, 0x04006407, 0x290c5307, 0x0a00121b,   // ig.zu.jw_422 lg.fi.un_420  ht.sv.sl_432 hu.pt.un_770
  // [4060]
  0x17000a04, 0x11231e07, 0x0400280c, 0x0b230a07,   // mk.sr.un_320 ms.ca.ro_432  sw.fi.un_530 pt.ca.es_432
  0x121301af, 0x0264680c, 0x130e2007, 0x68526413,   // en.et.hu_655 ig.lg.da_543  sq.is.et_432 lg.ha.ig_665
  0x12002108, 0x0d001c04, 0x3b312aac, 0x20130807,   // jw.hu.un_430 id.cs.un_320  mt.az.so_632 no.et.sq_432
  0x02000122, 0x23001219, 0x130e0ca4, 0x1c002502,   // en.da.un_870 hu.ca.un_750  sv.is.et_433 eu.id.un_220
  // [4070]
  0x08026eee, 0x13106e07, 0x0a002310, 0x230b01a4,   // hmn.da.no_422 hmn.lt.et_432  ca.pt.un_620 en.es.ca_433
  0x19251f07, 0x52352812, 0x6e080209, 0x3f005302,   // cy.eu.gl_432 sw.zu.ha_654  da.no.hmn_444 ht.af.un_220
  0x190b25a6, 0x0200130d, 0x17100412, 0x21001302,   // eu.es.gl_521 et.da.un_540  ru.be.sr_654 et.jw.un_220
  0x170f3204, 0x28006421, 0x04000a33, 0x09290f0c,   // bs.lv.sr_332 lg.sw.un_860  mk.ru.un_A70 lv.sl.pl_543
  // [4080]
  0x4a005322, 0x352555a9, 0x0600071a, 0x3f0c0302,   // ht.yo.un_870 rw.eu.zu_544  it.de.un_760 nl.sv.af_222
  0x12001814, 0x18111eee, 0x0f103202, 0x3f016402,   // ga.hu.un_660 ms.ro.ga_422  bs.lt.lv_222 lg.en.af_222
  0x16062508, 0x0c006e0c, 0x19002302, 0x2b006e0e,   // eu.de.hr_443 hmn.sv.un_530  ca.gl.un_220 hmn.vi.un_550
  0x162d0d0d, 0x03000c08, 0x19060bee, 0x3f036eee,   // cs.sk.hr_554 sv.nl.un_430  es.de.gl_422 hmn.nl.af_422
  // [4090]
  0x050b07ee, 0x16001702, 0x1b082502, 0x53645555,   // it.es.fr_422 sr.hr.un_220  eu.no.tr_222 rw.lg.ht_442
  0x040817a9, 0x1b002809, 0x53004a19, 0x07534a5a,   // sr.uk.ru_544 sw.tr.un_440  yo.ht.un_750 yo.ht.it_553
  0x0a100704, 0x180a1902, 0x120420ac, 0x3f0c0313,   // bg.be.mk_332 gl.pt.ga_222  sq.fi.hu_632 nl.sv.af_665
  0x131b0e07, 0x192d0bec, 0x190e0a0c, 0x19000b36,   // is.tr.et_432 es.sk.gl_644  pt.is.gl_543 es.gl.un_AA0
  // [40a0]
  0x5306020e, 0x19120b04, 0x18001902, 0x11283511,   // da.de.ht_555 es.hu.gl_332  gl.ga.un_220 zu.sw.ro_653
  0x31002919, 0x1b003b12, 0x0410080e, 0x05003208,   // sl.az.un_750 so.tr.un_640  uk.be.ru_555 bs.fr.un_430
  0x13040d0b, 0x21231ca9, 0x1b682513, 0x524a68a9,   // cs.fi.et_542 id.ca.jw_544  eu.ig.tr_665 ig.yo.ha_544
  0x31003b0c, 0x4a000713, 0x09282107, 0x35314a07,   // so.az.un_530 it.yo.un_650  jw.sw.pl_432 yo.az.zu_432
  // [40b0]
  0x6b121007, 0x203564ac, 0x12000f18, 0x02005204,   // lt.hu.ceb_432 lg.zu.sq_632  lv.hu.un_740 ha.da.un_320
  0x3b020c0c, 0x16251aa0, 0x3b352107, 0x21190bad,   // sv.da.so_543 tl.eu.hr_322  jw.zu.so_432 es.gl.jw_643
  0x060d35a4, 0x20002513, 0x552804a4, 0x68005513,   // zu.cs.de_433 eu.sq.un_650  fi.sw.rw_433 rw.ig.un_650
  0x21106ba4, 0x17080aa7, 0x09253511, 0x0413080c,   // ceb.lt.jw_433 mk.uk.sr_532  zu.eu.pl_653 no.et.fi_543
  // [40c0]
  0x5511280c, 0x25000f21, 0x2a6b13a9, 0x10531ca4,   // sw.ro.rw_543 lv.eu.un_860  et.ceb.mt_544 id.ht.lt_433
  0x642555a9, 0x11126807, 0x1e1c3b04, 0x1a075307,   // rw.eu.lg_544 ig.hu.ro_432  so.id.ms_332 ht.it.tl_432
  0x02000314, 0x07004a11, 0x033f2102, 0x4a00070d,   // nl.da.un_660 yo.it.un_630  jw.af.nl_222 it.yo.un_540
  0x1a6b1308, 0x52251a0d, 0x53255514, 0x07005305,   // et.ceb.tl_443 tl.eu.ha_554  rw.eu.ht_666 ht.it.un_330
  // [40d0]
  0x20002104, 0x1a00070d, 0x0325130c, 0x52001907,   // jw.sq.un_320 it.tl.un_540  et.eu.nl_543 gl.ha.un_420
  0x18315304, 0x0c082a0d, 0x4a0964a9, 0x0f130408,   // ht.az.ga_332 mt.no.sv_554  lg.pl.yo_544 fi.et.lv_443
  0x0955290c, 0x03095308, 0x1100031b, 0x230511af,   // sl.rw.pl_543 ht.pl.nl_443  nl.ro.un_770 ro.fr.ca_655
  0x68162da4, 0x6b002304, 0x031f0604, 0x093f2da4,   // sk.hr.ig_433 ca.ceb.un_320  de.cy.nl_332 sk.af.pl_433
  // [40e0]
  0x192a0714, 0x04000108, 0x0f212aa4, 0x101a530c,   // it.mt.gl_666 en.fi.un_430  mt.jw.lv_433 ht.tl.lt_543
  0x010435a0, 0x281853ee, 0x04101308, 0x08020cad,   // zu.fi.en_322 ht.ga.sw_422  et.lt.fi_443 sv.da.no_643
  0x5228640b, 0x2825135a, 0x2d001814, 0x230701a0,   // lg.sw.ha_542 et.eu.sw_553  ga.sk.un_660 en.it.ca_322
  0x1125130c, 0x070a1113, 0x1e251a08, 0x10111fee,   // et.eu.ro_543 ro.mk.bg_665  tl.eu.ms_443 cy.ro.lt_422
  // [40f0]
  0x09291604, 0x2d002902, 0x322d29a4, 0x2535130c,   // hr.sl.pl_332 sl.sk.un_220  sl.sk.bs_433 et.zu.eu_543
  0x350f130c, 0x2800131b, 0x1b01130c, 0x35042805,   // et.lv.zu_543 et.sw.un_770  et.en.tr_543 sw.fi.zu_333
  0x011f0b12, 0x04133205, 0x641e1c0d, 0x3200090c,   // es.cy.en_654 bs.et.fi_333  id.ms.lg_554 pl.bs.un_530
  0x23001112, 0x5364280c, 0x1c0e10ad, 0x28001a07,   // ro.ca.un_640 sw.lg.ht_543  lt.is.id_643 tl.sw.un_420
  // [4100]
  0x01002434, 0x13350ead, 0x09131c12, 0x12182dad,   // yi.iw.un_A80 is.zu.et_643  mr.bh.hi_654 sk.ga.hu_643
  0x03061ca4, 0x061803a0, 0x032b3f07, 0x070811a0,   // id.de.nl_433 nl.ga.de_322  af.vi.nl_432 ro.uk.bg_322
  0x162d2908, 0x0b0105af, 0x28351b0c, 0x0e043504,   // sl.sk.hr_443 fr.en.es_655  tr.zu.sw_543 zu.fi.is_332
  0x23006408, 0x040721a9, 0x04132105, 0x1e041307,   // lg.ca.un_430 jw.it.fi_544  jw.et.fi_333 et.fi.ms_432
  // [4110]
  0x043513a4, 0x040d11ee, 0x01040ea0, 0x2b001a02,   // et.zu.fi_433 ro.cs.fi_422  is.fi.en_322 tl.vi.un_220
  0x21006b02, 0x28213b07, 0x03051105, 0x32126e0c,   // ceb.jw.un_220 so.jw.sw_432  ro.fr.nl_333 hmn.hu.bs_543
  0x2b0b27a0, 0x0900180c, 0x166e2912, 0x256409a4,   // gd.es.vi_322 ga.pl.un_530  sl.hmn.hr_654 pl.lg.eu_433
  0x0a000705, 0x53006e22, 0x0a1b530c, 0x2d6e2912,   // bg.mk.un_330 hmn.ht.un_870  ht.tr.pt_543 sl.hmn.sk_654
  // [4120]
  0x07081014, 0x28641f0c, 0x6e001e0d, 0x0b000808,   // be.uk.bg_666 cy.lg.sw_543  ms.hmn.un_540 no.es.un_430
  0x11000b0c, 0x12206eec, 0x1c645512, 0x2d0f110c,   // es.ro.un_530 hmn.sq.hu_644  rw.lg.id_654 ro.lv.sk_543
  0x1b0604ad, 0x040f2aa6, 0x08060208, 0x28555207,   // fi.de.tr_643 mt.lv.fi_521  da.de.no_443 ha.rw.sw_432
  0x0c18275a, 0x25000412, 0x1c641e0c, 0x0f002105,   // gd.ga.sv_553 fi.eu.un_640  ms.lg.id_543 jw.lv.un_330
  // [4130]
  0x070a1011, 0x29002023, 0x011311ad, 0x061c1e12,   // be.mk.bg_653 sq.sl.un_880  ro.et.en_643 ms.id.de_654
  0x29001e08, 0x6e00532c, 0x0f5511ad, 0x2d12110c,   // ms.sl.un_430 ht.hmn.un_990  ro.rw.lv_643 ro.hu.sk_543
  0x4a11020b, 0x1e002a04, 0x01001804, 0x02292da9,   // da.ro.yo_542 mt.ms.un_320  ga.en.un_320 sk.sl.da_544
  0x2b521807, 0x0e321713, 0x3b6864a0, 0x29551e0d,   // ga.ha.vi_432 sr.bs.is_665  lg.ig.so_322 ms.rw.sl_554
  // [4140]
  0x550711af, 0x08206ba0, 0x1e1c040e, 0x231120a4,   // ro.it.rw_655 ceb.sq.no_322  fi.id.ms_555 sq.ro.ca_433
  0x4a121902, 0x060e1713, 0x192021a0, 0x213f6ba0,   // gl.hu.yo_222 sr.is.de_665  jw.sq.gl_322 ceb.af.jw_322
  0x25000414, 0x1217290c, 0x1104170c, 0x13040660,   // fi.eu.un_660 sl.sr.hu_543  sr.ru.ro_543 de.fi.et_664
  0x1e001b05, 0x205329a9, 0x2a3120a7, 0x112805a7,   // tr.ms.un_330 sl.ht.sq_544  sq.az.mt_532 fr.sw.ro_532
  // [4150]
  0x06521107, 0x18252804, 0x081a0c02, 0x09006e2c,   // ro.ha.de_432 sw.eu.ga_332  sv.tl.no_222 hmn.pl.un_990
  0x06046411, 0x2a2852ad, 0x080204ec, 0x55281aa4,   // lg.fi.de_653 ha.sw.mt_643  fi.da.no_644 tl.sw.rw_433
  0x1f001814, 0x0e4a120c, 0x03000621, 0x17002a13,   // ga.cy.un_660 hu.yo.is_543  de.nl.un_860 mt.sr.un_650
  0x2a640412, 0x350f1fa7, 0x55211c02, 0x201232af,   // fi.lg.mt_654 cy.lv.zu_532  id.jw.rw_222 bs.hu.sq_655
  // [4160]
  0x6421200c, 0x13351e02, 0x23004a05, 0x19001f19,   // sq.jw.lg_543 ms.zu.et_222  yo.ca.un_330 cy.gl.un_750
  0x20000113, 0x281b64a4, 0x10000805, 0x2d006e08,   // en.sq.un_650 lg.tr.sw_433  no.lt.un_330 hmn.sk.un_430
  0x1f006421, 0x29002d05, 0x2b1e1c04, 0x2500030d,   // lg.cy.un_860 sk.sl.un_330  id.ms.vi_332 nl.eu.un_540
  0x4a000804, 0x530601ad, 0x0e004a13, 0x0c000104,   // no.yo.un_320 en.de.ht_643  yo.is.un_650 en.sv.un_320
  // [4170]
  0x1c1e1a07, 0x2000131a, 0x255321ad, 0x08201ba4,   // tl.ms.id_432 et.sq.un_760  jw.ht.eu_643 tr.sq.no_433
  0x2b27180e, 0x522753ec, 0x35006409, 0x3b033f14,   // ga.gd.vi_555 ht.gd.ha_644  lg.zu.un_440 af.nl.so_666
  0x52122ba9, 0x07045205, 0x2a1e1c12, 0x1c2b21a0,   // vi.hu.ha_544 ha.fi.it_333  id.ms.mt_654 jw.vi.id_322
  0x0000161c, 0x13042aec, 0x2706250c, 0x2b230107,   // hr.un.un_800 mt.fi.et_644  eu.de.gd_543 en.ca.vi_432
  // [4180]
  0x1300520c, 0x1c0f1fa9, 0x640452ad, 0x09130d0d,   // ha.et.un_530 cy.lv.id_544  ha.fi.lg_643 ne.bh.hi_554
  0x6b073b07, 0x25002d13, 0x532552af, 0x1202080b,   // so.it.ceb_432 sk.eu.un_650  ha.eu.ht_655 no.da.hu_542
  0x4a1a52ec, 0x0c000309, 0x31072a55, 0x022d17a4,   // ha.tl.yo_644 nl.sv.un_440  mt.it.az_442 sr.sk.da_433
  0x200408a0, 0x521f4aaf, 0x270355ee, 0x2d04290b,   // no.fi.sq_322 yo.cy.ha_655  rw.nl.gd_422 sl.fi.sk_542
  // [4190]
  0x02050702, 0x29205504, 0x0e060305, 0x1627010c,   // it.fr.da_222 rw.sq.sl_332  nl.de.is_333 en.gd.hr_543
  0x17000708, 0x123f0360, 0x52531e04, 0x2a5301a0,   // it.sr.un_430 nl.af.hu_664  ms.ht.ha_332 en.ht.mt_322
  0x042012a7, 0x1c1827ee, 0x0b1a6bee, 0x1b000619,   // hu.sq.fi_532 gd.ga.id_422  ceb.tl.es_422 de.tr.un_750
  0x0e4a12b6, 0x3f1b1e14, 0x1b001a14, 0x130c0255,   // hu.yo.is_766 ms.tr.af_666  tl.tr.un_660 da.sv.et_442
  // [41a0]
  0x31201b0c, 0x130f010c, 0x32292dee, 0x321707a4,   // tr.sq.az_543 en.lv.et_543  sk.sl.bs_422 it.sr.bs_433
  0x0a00170d, 0x6e3b060c, 0x6b0c0455, 0x6e001c0d,   // sr.mk.un_540 de.so.hmn_543  fi.sv.ceb_442 id.hmn.un_540
  0x2d000f1a, 0x1f006e21, 0x10171104, 0x1c002904,   // lv.sk.un_760 hmn.cy.un_860  ro.sr.be_332 sl.id.un_320
  0x55000a12, 0x320d2955, 0x31003205, 0x130208a4,   // pt.rw.un_640 sl.cs.bs_442  bs.az.un_330 no.da.et_433
  // [41b0]
  0x011f6ea7, 0x02100609, 0x2a006b19, 0x520f06af,   // hmn.cy.en_532 de.lt.da_444  ceb.mt.un_750 de.lv.ha_655
  0x1c002508, 0x6400350c, 0x130e0caf, 0x20230509,   // eu.id.un_430 zu.lg.un_530  sv.is.et_655 fr.ca.sq_444
  0x1e006e05, 0x203f10a0, 0x01006808, 0x0e271860,   // hmn.ms.un_330 lt.af.sq_322  ig.en.un_430 ga.gd.is_664
  0x2a091b07, 0x161e6ea7, 0x23130960, 0x0c136ea7,   // tr.pl.mt_432 hmn.ms.hr_532  pl.et.ca_664 hmn.et.sv_532
  // [41c0]
  0x27185305, 0x020c1fa4, 0x6e011107, 0x0c0e53ad,   // ht.ga.gd_333 cy.sv.da_433  ro.en.hmn_432 ht.is.sv_643
  0x060e180c, 0x23001021, 0x53050eaf, 0x070a040e,   // ga.is.de_543 lt.ca.un_860  is.fr.ht_655 ru.mk.bg_555
  0x351c1ead, 0x0f1f130c, 0x271853af, 0x01522802,   // ms.id.zu_643 et.cy.lv_543  ht.ga.gd_655 sw.ha.en_222
  0x03643fa4, 0x08090e07, 0x271f0e0c, 0x18290111,   // af.lg.nl_433 is.pl.no_432  is.cy.gd_543 en.sl.ga_653
  // [41d0]
  0x0d1c090d, 0x3f2903a4, 0x182708a4, 0x1e1c35a4,   // hi.mr.ne_554 nl.sl.af_433  no.gd.ga_433 zu.id.ms_433
  0x27190b07, 0x18030605, 0x080e6b02, 0x0e27250c,   // es.gl.gd_432 de.nl.ga_333  ceb.is.no_222 eu.gd.is_543
  0x080c53af, 0x122164a0, 0x53000612, 0x320e17a9,   // ht.sv.no_655 lg.jw.hu_322  de.ht.un_640 sr.is.bs_544
  0x180e53a4, 0x4a086ba9, 0x182753ec, 0x0818530b,   // ht.is.ga_433 ceb.no.yo_544  ht.gd.ga_644 ht.ga.no_542
  // [41e0]
  0x0c185307, 0x13180407, 0x29002121, 0x024a6bee,   // ht.ga.sv_432 fi.ga.et_432  jw.sl.un_860 ceb.yo.da_422
  0x1a206e07, 0x03003504, 0x083f0308, 0x6b213512,   // hmn.sq.tl_432 zu.nl.un_320  nl.af.no_443 zu.jw.ceb_654
  0x52030607, 0x1318060c, 0x074a2107, 0x09005502,   // de.nl.ha_432 de.ga.et_543  jw.yo.it_432 rw.pl.un_220
  0x12060a13, 0x213555a4, 0x3b1e2104, 0x1b293202,   // pt.de.hu_665 rw.zu.jw_433  jw.ms.so_332 bs.sl.tr_222
  // [41f0]
  0x646b1a09, 0x070b0a05, 0x522d5508, 0x0420080c,   // tl.ceb.lg_444 pt.es.it_333  rw.sk.ha_443 no.sq.fi_543
  0x35070b07, 0x3b190bad, 0x55641b55, 0x55216411,   // es.it.zu_432 es.gl.so_643  tr.lg.rw_442 lg.jw.rw_653
  0x10005307, 0x1c282104, 0x060e1ca0, 0x1b201312,   // ht.lt.un_420 jw.sw.id_332  id.is.de_322 et.sq.tr_654
  0x0f001907, 0x286452a4, 0x3b5221a0, 0x131a6b12,   // gl.lv.un_420 ha.lg.sw_433  jw.ha.so_322 ceb.tl.et_654
  // [4200]
  0x0e001f18, 0x29521ea0, 0x11532aec, 0x29002105,   // cy.is.un_740 ms.ha.sl_322  mt.ht.ro_644 jw.sl.un_330
  0x06291eee, 0x0b0a1ea0, 0x21291711, 0x083b2a55,   // ms.sl.de_422 ms.pt.es_322  sr.sl.jw_653 mt.so.no_442
  0x1a6b210c, 0x52552855, 0x0100180e, 0x55062805,   // jw.ceb.tl_543 sw.rw.ha_442  ga.en.un_550 sw.de.rw_333
  0x64006b19, 0x2d0d21ec, 0x21281fa4, 0x64520909,   // ceb.lg.un_750 jw.cs.sk_644  cy.sw.jw_433 pl.ha.lg_444
  // [4210]
  0x212d0d13, 0x1c005221, 0x5500170e, 0x1f030e55,   // cs.sk.jw_665 ha.id.un_860  sr.rw.un_550 is.nl.cy_442
  0x20000e0d, 0x100811a4, 0x556435a7, 0x1e211ca4,   // is.sq.un_540 ro.uk.be_433  zu.lg.rw_532 id.jw.ms_433
  0x12190b5a, 0x10211ca4, 0x2135520c, 0x32160eee,   // es.gl.hu_553 id.jw.lt_433  ha.zu.jw_543 is.hr.bs_422
  0x0d2d2110, 0x1e1c2104, 0x033f04ec, 0x32000702,   // jw.sk.cs_642 jw.id.ms_332  fi.af.nl_644 it.bs.un_220
  // [4220]
  0x180705a0, 0x2d003f13, 0x20311ea0, 0x550719a6,   // fr.it.ga_322 af.sk.un_650  ms.az.sq_322 gl.it.rw_521
  0x04033f07, 0x171304ec, 0x0a000304, 0x55005304,   // af.nl.fi_432 fi.et.sr_644  nl.pt.un_320 ht.rw.un_320
  0x04000308, 0x2a0405ee, 0x0d2d2111, 0x11001705,   // nl.fi.un_430 fr.fi.mt_422  jw.sk.cs_653 sr.ro.un_330
  0x2a051907, 0x2d002119, 0x071a0caf, 0x03000707,   // gl.fr.mt_432 jw.sk.un_750  sv.tl.it_655 it.nl.un_420
  // [4230]
  0x211b0b12, 0x1e111b07, 0x531b2aee, 0x12000a05,   // es.tr.jw_654 tr.ro.ms_432  mt.tr.ht_422 pt.hu.un_330
  0x25186808, 0x6e001e12, 0x083b0e04, 0x3b001323,   // ig.ga.eu_443 ms.hmn.un_640  is.so.no_332 et.so.un_880
  0x35000f07, 0x212a1e07, 0x270e1808, 0x09006409,   // lv.zu.un_420 ms.mt.jw_432  ga.is.gd_443 lg.pl.un_440
  0x283f35ad, 0x09006414, 0x091b53ad, 0x120f0607,   // zu.af.sw_643 lg.pl.un_660  ht.tr.pl_643 de.lv.hu_432
  // [4240]
  0x31001118, 0x211f135a, 0x0321080b, 0x53000a21,   // ro.az.un_740 et.cy.jw_553  no.jw.nl_542 pt.ht.un_860
  0x18122d60, 0x1a284aa6, 0x311b0aac, 0x2a001f09,   // sk.hu.ga_664 yo.sw.tl_521  pt.tr.az_632 cy.mt.un_440
  0x110c03ec, 0x1a281012, 0x080a1702, 0x64001f1b,   // nl.sv.ro_644 lt.sw.tl_654  sr.mk.uk_222 cy.lg.un_770
  0x2d0d4aee, 0x2a000104, 0x013b2d0b, 0x0a062512,   // yo.cs.sk_422 en.mt.un_320  sk.so.en_542 eu.de.pt_654
  // [4250]
  0x52003202, 0x133f06a4, 0x31121b11, 0x231127a0,   // bs.ha.un_220 de.af.et_433  tr.hu.az_653 gd.ro.ca_322
  0x28062a07, 0x094a6404, 0x120a01af, 0x3b000223,   // mt.de.sw_432 lg.yo.pl_332  en.pt.hu_655 da.so.un_880
  0x0d3f01a4, 0x68000104, 0x011335a7, 0x061b13ec,   // en.af.cs_433 en.ig.un_320  zu.et.en_532 et.tr.de_644
  0x215352ee, 0x6b1a5505, 0x04070aee, 0x04000e20,   // ha.ht.jw_422 rw.tl.ceb_333  mk.bg.ru_422 is.fi.un_850
  // [4260]
  0x28680313, 0x0e0c1fad, 0x0c1f6ba0, 0x0b1123ee,   // nl.ig.sw_665 cy.sv.is_643  ceb.cy.sv_322 ca.ro.es_422
  0x53022507, 0x1f002911, 0x21121c11, 0x09003b12,   // eu.da.ht_432 sl.cy.un_630  id.hu.jw_653 so.pl.un_640
  0x1029040b, 0x2d3528a0, 0x0b00010c, 0x10000812,   // fi.sl.lt_542 sw.zu.sk_322  en.es.un_530 uk.be.un_640
  0x311a3507, 0x012911a4, 0x6b124a04, 0x0b072aa0,   // zu.tl.az_432 ro.sl.en_433  yo.hu.ceb_332 mt.it.es_322
  // [4270]
  0x524a6407, 0x01122a07, 0x642a3512, 0x6435210d,   // lg.yo.ha_432 mt.hu.en_432  zu.mt.lg_654 jw.zu.lg_554
  0x083b0caf, 0x081f310c, 0x1f000408, 0x06033f08,   // sv.so.no_655 az.cy.no_543  fi.cy.un_430 af.nl.de_443
  0x20006407, 0x322d10a0, 0x28003521, 0x083f0313,   // lg.sq.un_420 lt.sk.bs_322  zu.sw.un_860 nl.af.no_665
  0x19200b5a, 0x2d001e0c, 0x31182712, 0x081c0e08,   // es.sq.gl_553 ms.sk.un_530  gd.ga.az_654 is.id.no_443
  // [4280]
  0x4a18270c, 0x554a6408, 0x0c1c530c, 0x3f1e64a9,   // gd.ga.yo_543 lg.yo.rw_443  ht.id.sv_543 lg.ms.af_544
  0x0802190c, 0x080417ad, 0x2d0d1614, 0x192718ad,   // gl.da.no_543 sr.ru.uk_643  hr.cs.sk_666 ga.gd.gl_643
  0x1304280c, 0x2864350c, 0x1c0464a6, 0x20310fad,   // sw.fi.et_543 zu.lg.sw_543  lg.fi.id_521 lv.az.sq_643
  0x13000617, 0x552a530c, 0x0c080655, 0x1e001308,   // de.et.un_730 ht.mt.rw_543  de.no.sv_442 et.ms.un_430
  // [4290]
  0x52006e07, 0x07041307, 0x160b1104, 0x351e64a9,   // hmn.ha.un_420 et.fi.it_432  ro.es.hr_332 lg.ms.zu_544
  0x0c2916a4, 0x64001304, 0x521a250c, 0x0c232008,   // hr.sl.sv_433 et.lg.un_320  eu.tl.ha_543 sq.ca.sv_443
  0x040e0c12, 0x2d320aa0, 0x166e1707, 0x12001829,   // sv.is.fi_654 pt.bs.sk_322  sr.hmn.hr_432 ar.ur.un_960
  0x1923010b, 0x0c6b1a07, 0x29211c08, 0x11231e04,   // en.ca.gl_542 tl.ceb.sv_432  id.jw.sl_443 ms.ca.ro_332
  // [42a0]
  0x0b0a2daf, 0x0a07080c, 0x18271112, 0x0b2507a0,   // sk.pt.es_655 uk.bg.mk_543  ro.gd.ga_654 it.eu.es_322
  0x020c08a0, 0x3f2125ac, 0x0b2d0a07, 0x55032a07,   // no.sv.da_322 eu.jw.af_632  pt.sk.es_432 mt.nl.rw_432
  0x316428a6, 0x07235205, 0x2d0d4aa4, 0x29000c04,   // sw.lg.az_521 ha.ca.it_333  yo.cs.sk_433 sv.sl.un_320
  0x31272a08, 0x1f29010c, 0x05080205, 0x1e1c1aee,   // mt.gd.az_443 en.sl.cy_543  da.no.fr_333 tl.id.ms_422
  // [42b0]
  0x3f0f0da4, 0x01072a11, 0x12004a19, 0x190a11a0,   // cs.lv.af_433 mt.it.en_653  yo.hu.un_750 ro.pt.gl_322
  0x2810110d, 0x3f00110c, 0x312029a0, 0x13000209,   // ro.lt.sw_554 ro.af.un_530  sl.sq.az_322 da.et.un_440
  0x522a6808, 0x4a122d07, 0x32162a09, 0x273b06a4,   // ig.mt.ha_443 sk.hu.yo_432  mt.hr.bs_444 de.so.gd_433
  0x0a041755, 0x4a523b5a, 0x6b006e0c, 0x23003b11,   // sr.ru.mk_442 so.ha.yo_553  hmn.ceb.un_530 so.ca.un_630
  // [42c0]
  0x64004a05, 0x250411af, 0x530a05af, 0x556453a4,   // yo.lg.un_330 ro.fi.eu_655  fr.pt.ht_655 ht.lg.rw_433
  0x102d0d04, 0x12131bee, 0x4a6421a0, 0x3b252a0c,   // cs.sk.lt_332 tr.et.hu_422  jw.lg.yo_322 mt.eu.so_543
  0x05000f36, 0x0910250c, 0x32162d0c, 0x17290d0c,   // lv.fr.un_AA0 eu.lt.pl_543  sk.hr.bs_543 cs.sl.sr_543
  0x19280ba7, 0x0c0e0812, 0x0d0a0b60, 0x0e3f030c,   // es.sw.gl_532 no.is.sv_654  es.pt.cs_664 nl.af.is_543
  // [42d0]
  0x10252da4, 0x12090111, 0x18002a0d, 0x68132514,   // sk.eu.lt_433 en.pl.hu_653  mt.ga.un_540 eu.et.ig_666
  0x0425640c, 0x68006b13, 0x536b1107, 0x2a1f01ec,   // lg.eu.fi_543 ceb.ig.un_650  ro.ceb.ht_432 en.cy.mt_644
  0x20002507, 0x2d0d0eee, 0x1f006404, 0x1f000112,   // eu.sq.un_420 is.cs.sk_422  lg.cy.un_320 en.cy.un_640
  0x20092509, 0x5513255a, 0x532a6404, 0x6b00680d,   // eu.pl.sq_444 eu.et.rw_553  lg.mt.ht_332 ig.ceb.un_540
  // [42e0]
  0x010511af, 0x194a0ba0, 0x202910a9, 0x0c0625af,   // ro.fr.en_655 es.yo.gl_322  lt.sl.sq_544 eu.de.sv_655
  0x1e1c0e0e, 0x251355a4, 0x070417ad, 0x10252a0d,   // is.id.ms_555 rw.et.eu_433  sr.ru.bg_643 mt.eu.lt_554
  0x0e002d18, 0x1c3b210c, 0x2a002509, 0x2a020812,   // sk.is.un_740 jw.so.id_543  eu.mt.un_440 no.da.mt_654
  0x20040607, 0x31190a0c, 0x092a0711, 0x080c23a7,   // de.fi.sq_432 pt.gl.az_543  it.mt.pl_653 ca.sv.no_532
  // [42f0]
  0x05000712, 0x02040804, 0x2b002313, 0x53002a02,   // it.fr.un_640 no.fi.da_332  ca.vi.un_650 mt.ht.un_220
  0x1b080214, 0x072d0a55, 0x050453ee, 0x3f031304,   // da.no.tr_666 pt.sk.it_442  ht.fi.fr_422 et.nl.af_332
  0x1300350e, 0x12060c02, 0x0c0801a4, 0x250c2aec,   // zu.et.un_550 sv.de.hu_222  en.no.sv_433 mt.sv.eu_644
  0x270511ad, 0x010a1f0c, 0x2a00250d, 0x07534aa7,   // ro.fr.gd_643 cy.pt.en_543  eu.mt.un_540 yo.ht.it_532
  // [4300]
  0x05006b02, 0x230208ee, 0x10000c08, 0x030802ec,   // ceb.fr.un_220 no.da.ca_422  sv.lt.un_430 da.no.nl_644
  0x5300060c, 0x03080213, 0x10002d08, 0x3b002322,   // de.ht.un_530 da.no.nl_665  sk.lt.un_430 ca.so.un_870
  0x4a000e19, 0x08026e14, 0x64206805, 0x3b2a18a4,   // is.yo.un_750 hmn.da.no_666  ig.sq.lg_333 ga.mt.so_433
  0x02311bad, 0x05003f02, 0x136416a4, 0x64001312,   // tr.az.da_643 af.fr.un_220  hr.lg.et_433 et.lg.un_640
  // [4310]
  0x21033b0c, 0x020408ee, 0x04212304, 0x1e1a1ca0,   // so.nl.jw_543 no.fi.da_422  ca.jw.fi_332 id.tl.ms_322
  0x08022a05, 0x18002d0d, 0x2a0d1e0b, 0x1008170c,   // mt.da.no_333 sk.ga.un_540  ms.cs.mt_542 sr.uk.be_543
  0x121a6b0c, 0x3b52250c, 0x07001f1a, 0x203b2aad,   // ceb.tl.hu_543 eu.ha.so_543  cy.it.un_760 mt.so.sq_643
  0x120420a4, 0x01080260, 0x18272313, 0x3b1b3108,   // sq.fi.hu_433 da.no.en_664  ca.gd.ga_665 az.tr.so_443
  // [4320]
  0x04102304, 0x02080c07, 0x326e10a4, 0x53106e08,   // ca.lt.fi_332 sv.no.da_432  lt.hmn.bs_433 hmn.lt.ht_443
  0x040a100c, 0x080203ec, 0x07256ea7, 0x06000207,   // be.mk.ru_543 nl.da.no_644  hmn.eu.it_532 da.de.un_420
  0x2b006e04, 0x0d131c04, 0x12003f0d, 0x3f0c080c,   // hmn.vi.un_320 mr.bh.ne_332  af.hu.un_540 no.sv.af_543
  0x100a11ee, 0x293f53ee, 0x1c090d07, 0x20002805,   // ro.mk.be_422 ht.af.sl_422  ne.hi.mr_432 sw.sq.un_330
  // [4330]
  0x08000302, 0x06311bad, 0x1b211ea4, 0x20001804,   // nl.no.un_220 tr.az.de_643  ms.jw.tr_433 ga.sq.un_320
  0x6b1f0507, 0x0a2120a7, 0x3b001a04, 0x21531c07,   // fr.cy.ceb_432 sq.jw.pt_532  tl.so.un_320 id.ht.jw_432
  0x0a291a09, 0x19182755, 0x050127a0, 0x13061e04,   // tl.sl.pt_444 gd.ga.gl_442  gd.en.fr_322 ms.de.et_332
  0x0e000f1b, 0x3b1a55a0, 0x641a55ad, 0x0408105a,   // lv.is.un_770 rw.tl.so_322  rw.tl.lg_643 be.uk.ru_553
  // [4340]
  0x0b23180e, 0x321b2055, 0x6b2a18a4, 0x0f091014,   // ga.ca.es_555 sq.tr.bs_442  ga.mt.ceb_433 lt.pl.lv_666
  0x0a190bad, 0x6b1935ee, 0x21230b09, 0x521e3b0c,   // es.gl.pt_643 zu.gl.ceb_422  es.ca.jw_444 so.ms.ha_543
  0x18002812, 0x352864af, 0x020608a0, 0x12000505,   // sw.ga.un_640 lg.sw.zu_655  no.de.da_322 fr.hu.un_330
  0x19250b0c, 0x32171ea4, 0x35004a13, 0x100a0408,   // es.eu.gl_543 ms.sr.bs_433  yo.zu.un_650 ru.mk.be_443
  // [4350]
  0x23180ba0, 0x290c090c, 0x230b0ea4, 0x080a040c,   // es.ga.ca_322 pl.sv.sl_543  is.es.ca_433 ru.mk.uk_543
  0x273b250c, 0x1000190e, 0x3f030807, 0x55003108,   // eu.so.gd_543 gl.lt.un_550  no.nl.af_432 az.rw.un_430
  0x11190ba4, 0x28072d08, 0x3f3b010b, 0x290207ee,   // es.gl.ro_433 sk.it.sw_443  en.so.af_542 it.da.sl_422
  0x190b4a0e, 0x07063b07, 0x53001e04, 0x31523ba4,   // yo.es.gl_555 so.de.it_432  ms.ht.un_320 so.ha.az_433
  // [4360]
  0x3f3b01a9, 0x0c0803ec, 0x3b271f12, 0x31035512,   // en.so.af_544 nl.no.sv_644  cy.gd.so_654 rw.nl.az_654
  0x16210507, 0x192d0d5a, 0x2a3b2112, 0x03061f07,   // fr.jw.hr_432 cs.sk.gl_553  jw.so.mt_654 cy.de.nl_432
  0x0920070b, 0x28041313, 0x190b0a13, 0x29002d18,   // it.sq.pl_542 et.fi.sw_665  pt.es.gl_665 sk.sl.un_740
  0x3b042813, 0x1300110e, 0x066407a4, 0x64072aec,   // sw.fi.so_665 ro.et.un_550  it.lg.de_433 mt.it.lg_644
  // [4370]
  0x23060407, 0x286b1a60, 0x05004a0d, 0x271f010b,   // fi.de.ca_432 tl.ceb.sw_664  yo.fr.un_540 en.cy.gd_542
  0x19252aa4, 0x03122755, 0x201068ee, 0x2135640c,   // mt.eu.gl_433 gd.hu.nl_442  ig.lt.sq_422 lg.zu.jw_543
  0x1f3525a9, 0x2012070c, 0x29161904, 0x230a0707,   // eu.zu.cy_544 it.hu.sq_543  gl.hr.sl_332 it.pt.ca_432
  0x01001907, 0x03001c04, 0x23012aa4, 0x20351108,   // gl.en.un_420 id.nl.un_320  mt.en.ca_433 ro.zu.sq_443
  // [4380]
  0x11001f0c, 0x13040555, 0x25001a07, 0x071101a0,   // cy.ro.un_530 fr.fi.et_442  tl.eu.un_420 en.ro.it_322
  0x3f08040c, 0x0500120d, 0x05110708, 0x1f1a5212,   // fi.no.af_543 hu.fr.un_540  it.ro.fr_443 ha.tl.cy_654
  0x27002b13, 0x53004a34, 0x01060708, 0x2b534aad,   // vi.gd.un_650 yo.ht.un_A80  it.de.en_443 yo.ht.vi_643
  0x3b001e0d, 0x21203bad, 0x1a685307, 0x1e1c3ba9,   // ms.so.un_540 so.sq.jw_643  ht.ig.tl_432 so.id.ms_544
  // [4390]
  0x23281fac, 0x2b4a5360, 0x1a356407, 0x051a6ba9,   // cy.sw.ca_632 ht.yo.vi_664  lg.zu.tl_432 ceb.tl.fr_544
  0x2b002719, 0x0500190d, 0x53004a22, 0x1a2009a4,   // gd.vi.un_750 gl.fr.un_540  yo.ht.un_870 pl.sq.tl_433
  0x175535a4, 0x1013040c, 0x19230707, 0x07110a55,   // zu.rw.sr_433 fi.et.lt_543  it.ca.gl_432 mk.ro.bg_442
  0x206b1c07, 0x12002309, 0x2119120c, 0x53004a20,   // id.ceb.sq_432 ca.hu.un_440  hu.gl.jw_543 yo.ht.un_850
  // [43a0]
  0x07004a29, 0x121b0908, 0x64001b14, 0x3f03210c,   // yo.it.un_960 pl.tr.hu_443  tr.lg.un_660 jw.nl.af_543
  0x28001604, 0x21171aa4, 0x0b070107, 0x6b121107,   // hr.sw.un_320 tl.sr.jw_433  en.it.es_432 ro.hu.ceb_432
  0x0b0a1a02, 0x03023f02, 0x2900281a, 0x210620a0,   // tl.pt.es_222 af.da.nl_222  sw.sl.un_760 sq.de.jw_322
  0x10641aa4, 0x231b1108, 0x2d002819, 0x4a2852ee,   // tl.lg.lt_433 ro.tr.ca_443  sw.sk.un_750 ha.sw.yo_422
  // [43b0]
  0x284a5212, 0x1c1e280c, 0x29352811, 0x17005204,   // ha.yo.sw_654 sw.ms.id_543  sw.zu.sl_653 ha.sr.un_320
  0x2953280c, 0x190b64a0, 0x0b0a230e, 0x04005314,   // sw.ht.sl_543 lg.es.gl_322  ca.pt.es_555 ht.fi.un_660
  0x0a230b0b, 0x4a52280c, 0x35645304, 0x0e551b08,   // es.ca.pt_542 sw.ha.yo_543  ht.lg.zu_332 tr.rw.is_443
  0x091c13a0, 0x291c210b, 0x285568a0, 0x05520aee,   // bh.mr.hi_322 jw.id.sl_542  ig.rw.sw_322 pt.ha.fr_422
  // [43c0]
  0x08002121, 0x1e2d6411, 0x1b3b6412, 0x2800100d,   // jw.no.un_860 lg.sk.ms_653  lg.so.tr_654 lt.sw.un_540
  0x10086b55, 0x07022da0, 0x28005213, 0x0a190b60,   // ceb.no.lt_442 sk.da.it_322  ha.sw.un_650 es.gl.pt_664
  0x041e6b07, 0x0c001f0c, 0x03006418, 0x0a173507,   // ceb.ms.fi_432 cy.sv.un_530  lg.nl.un_740 zu.sr.pt_432
  0x1e1c5205, 0x1e006e0c, 0x101e1c0e, 0x03043fa4,   // ha.id.ms_333 hmn.ms.un_530  id.ms.lt_555 af.fi.nl_433
  // [43d0]
  0x29000b02, 0x286e6812, 0x2a070aa4, 0x6400521b,   // es.sl.un_220 ig.hmn.sw_654  pt.it.mt_433 ha.lg.un_770
  0x13043b60, 0x2d001307, 0x2100190c, 0x1c251e60,   // so.fi.et_664 et.sk.un_420  gl.jw.un_530 ms.eu.id_664
  0x041e1c14, 0x53002016, 0x136b0412, 0x203f040d,   // id.ms.fi_666 sq.ht.un_720  fi.ceb.et_654 fi.af.sq_554
  0x01033faf, 0x2a3b29a9, 0x3f003b0c, 0x4a030c0b,   // af.nl.en_655 sl.so.mt_544  so.af.un_530 sv.nl.yo_542
  // [43e0]
  0x05002104, 0x090c13a4, 0x0a4a0707, 0x0f00092b,   // jw.fr.un_320 et.sv.pl_433  it.yo.pt_432 pl.lv.un_980
  0x283b2514, 0x0600131a, 0x1e1b0e08, 0x0f00520c,   // eu.so.sw_666 et.de.un_760  is.tr.ms_443 ha.lv.un_530
  0x07001019, 0x12200812, 0x1a6452af, 0x200812a9,   // lt.it.un_750 no.sq.hu_654  ha.lg.tl_655 hu.no.sq_544
  0x0c1c1e0b, 0x05201eaf, 0x6455520b, 0x6b1b35a9,   // ms.id.sv_542 ms.sq.fr_655  ha.rw.lg_542 zu.tr.ceb_544
  // [43f0]
  0x201b05a4, 0x643555ad, 0x115228a9, 0x1311040e,   // fr.tr.sq_433 rw.zu.lg_643  sw.ha.ro_544 fi.ro.et_555
  0x522102a9, 0x19005204, 0x55213509, 0x13321604,   // da.jw.ha_544 ha.gl.un_320  zu.jw.rw_444 hr.bs.et_332
  0x64121aad, 0x1a216b11, 0x211c29a0, 0x355228a9,   // tl.hu.lg_643 ceb.jw.tl_653  sl.id.jw_322 sw.ha.zu_544
  0x190807a4, 0x05110d05, 0x55042a0c, 0x2d0d02ee,   // it.no.gl_433 cs.ro.fr_333  mt.fi.rw_543 da.cs.sk_422

  // [4400]
  0x230b0a14, 0x235564a9, 0x2003120c, 0x2b121b0c,   // pt.es.ca_666 lg.rw.ca_544  hu.nl.sq_543 tr.hu.vi_543
  0x354a52ad, 0x12000e2a, 0x09041805, 0x21001119,   // ha.yo.zu_643 is.hu.un_970  ga.fi.pl_333 ro.jw.un_750
  0x21641a07, 0x1a356413, 0x3f21090c, 0x2835645a,   // tl.lg.jw_432 lg.zu.tl_665  pl.jw.af_543 lg.zu.sw_553
  0x1821270c, 0x030502ee, 0x200802a9, 0x3b00181a,   // gd.jw.ga_543 da.fr.nl_422  da.no.sq_544 ga.so.un_760
  // [4410]
  0x1017070c, 0x31001c02, 0x642a0712, 0x1c21520c,   // bg.sr.be_543 id.az.un_220  it.mt.lg_654 ha.jw.id_543
  0x25072a0c, 0x01271802, 0x07321709, 0x2a2507af,   // mt.it.eu_543 ga.gd.en_222  sr.bs.it_444 it.eu.mt_655
  0x356b28a4, 0x28551209, 0x6b1f1a09, 0x0f1352a0,   // sw.ceb.zu_433 hu.rw.sw_444  tl.cy.ceb_444 ha.et.lv_322
  0x211629a9, 0x06003b0d, 0x21001e22, 0x10001221,   // sl.hr.jw_544 so.de.un_540  ms.jw.un_870 hu.lt.un_860
  // [4420]
  0x27000b08, 0x0a1c1eec, 0x3f002722, 0x211c04a4,   // es.gd.un_430 ms.id.pt_644  gd.af.un_870 fi.id.jw_433
  0x1e3b10a4, 0x044a1ca4, 0x1b190b13, 0x0d0f28ee,   // lt.so.ms_433 id.yo.fi_433  es.gl.tr_665 sw.lv.cs_422
  0x101b3508, 0x0e004a21, 0x351b1ca4, 0x02000312,   // zu.tr.lt_443 yo.is.un_860  id.tr.zu_433 nl.da.un_640
  0x4a000e29, 0x171e1c5a, 0x12001702, 0x32161ca9,   // is.yo.un_960 id.ms.sr_553  sr.hu.un_220 id.hr.bs_544
  // [4430]
  0x080a07a9, 0x171b290c, 0x0e2b4a11, 0x11030a07,   // bg.mk.uk_544 sl.tr.sr_543  yo.vi.is_653 pt.nl.ro_432
  0x0a001105, 0x64005518, 0x101303a9, 0x09033f0d,   // ro.mk.un_330 rw.lg.un_740  nl.et.lt_544 af.nl.pl_554
  0x28521aa9, 0x033f64a0, 0x2d090dee, 0x64351aaf,   // tl.ha.sw_544 lg.af.nl_322  cs.pl.sk_422 tl.zu.lg_655
  0x3f080ea4, 0x0e03080c, 0x1b52120c, 0x3b0f25a9,   // is.no.af_433 no.nl.is_543  hu.ha.tr_543 eu.lv.so_544
  // [4440]
  0x35101ba4, 0x0f0b04ee, 0x28351b07, 0x4a0e2dec,   // tr.lt.zu_433 fi.es.lv_422  tr.zu.sw_432 sk.is.yo_644
  0x31002904, 0x0b4a18ac, 0x551a6455, 0x0e08135a,   // sl.az.un_320 ga.yo.es_632  lg.tl.rw_442 et.no.is_553
  0x3b13290c, 0x1a0f2a0d, 0x13351aad, 0x13356b02,   // sl.et.so_543 mt.lv.tl_554  tl.zu.et_643 ceb.zu.et_222
  0x2a313b11, 0x1b281ea4, 0x1b002713, 0x55001f0c,   // so.az.mt_653 ms.sw.tr_433  gd.tr.un_650 cy.rw.un_530
  // [4450]
  0x1807010c, 0x25033fa9, 0x090d1307, 0x6b552d07,   // en.it.ga_543 af.nl.eu_544  bh.ne.hi_432 sk.rw.ceb_432
  0x350e2511, 0x31003f0d, 0x042511a4, 0x686404a4,   // eu.is.zu_653 af.az.un_540  ro.eu.fi_433 fi.lg.ig_433
  0x19052305, 0x080a17a6, 0x27033f08, 0x01192102,   // ca.fr.gl_333 sr.mk.uk_521  af.nl.gd_443 jw.gl.en_222
  0x0b3568a9, 0x04006419, 0x04642108, 0x68216414,   // ig.zu.es_544 lg.fi.un_750  jw.lg.fi_443 lg.jw.ig_666
  // [4460]
  0x080e25a4, 0x55000804, 0x3b0a19af, 0x10250707,   // eu.is.no_433 no.rw.un_320  gl.pt.so_655 it.eu.lt_432
  0x29000f1b, 0x053f015a, 0x0f6b11af, 0x23000511,   // lv.sl.un_770 en.af.fr_553  ro.ceb.lv_655 fr.ca.un_630
  0x3135200b, 0x556435ee, 0x0a110808, 0x190a21a0,   // sq.zu.az_542 zu.lg.rw_422  uk.ro.mk_443 jw.pt.gl_322
  0x17006e08, 0x040d3b0c, 0x0a1117a4, 0x111a04ee,   // hmn.sr.un_430 so.cs.fi_543  sr.ro.mk_433 fi.tl.ro_422
  // [4470]
  0x3f033b0c, 0x2d006402, 0x0a015502, 0x0e122307,   // so.nl.af_543 lg.sk.un_220  rw.en.pt_222 ca.hu.is_432
  0x03203505, 0x032a0412, 0x3f033ba4, 0x19050ba4,   // zu.sq.nl_333 fi.mt.nl_654  so.nl.af_433 es.fr.gl_433
  0x6b0468a4, 0x206b1aa4, 0x281e3207, 0x080220a9,   // ig.fi.ceb_433 tl.ceb.sq_433  bs.ms.sw_432 sq.da.no_544
  0x100f13ad, 0x0c020e0c, 0x3f0301a4, 0x042d0da9,   // et.lv.lt_643 is.da.sv_543  en.nl.af_433 cs.sk.fi_544
  // [4480]
  0x1e1c0ca4, 0x02090808, 0x0c3f180c, 0x0e1f0c12,   // sv.id.ms_433 no.pl.da_443  ga.af.sv_543 sv.cy.is_654
  0x3b181ba0, 0x0c6b2305, 0x041a13a4, 0x043f1308,   // tr.ga.so_322 ca.ceb.sv_333  et.tl.fi_433 et.af.fi_443
  0x13001a21, 0x120413af, 0x04134aa0, 0x1a001e02,   // tl.et.un_860 et.fi.hu_655  yo.et.fi_322 ms.tl.un_220
  0x1c212708, 0x3b0108a7, 0x1b000108, 0x031f1b0c,   // gd.jw.id_443 no.en.so_532  en.tr.un_430 tr.cy.nl_543
  // [4490]
  0x0e0803ec, 0x112a2313, 0x1b531f0c, 0x642035a4,   // nl.no.is_644 ca.mt.ro_665  cy.ht.tr_543 zu.sq.lg_433
  0x0800030c, 0x252820af, 0x112706ee, 0x1c0913a6,   // nl.no.un_530 sq.sw.eu_655  de.gd.ro_422 bh.hi.mr_521
  0x3f2a1fa4, 0x3f3b6404, 0x2555355a, 0x552868a4,   // cy.mt.af_433 lg.so.af_332  zu.rw.eu_553 ig.sw.rw_433
  0x68281b09, 0x20356402, 0x0f64280d, 0x1e646808,   // tr.sw.ig_444 lg.zu.sq_222  sw.lg.lv_554 ig.lg.ms_443
  // [44a0]
  0x1e07280c, 0x04131114, 0x1f170608, 0x072531a9,   // sw.it.ms_543 ro.et.fi_666  de.sr.cy_443 az.eu.it_544
  0x0b1905a9, 0x64355514, 0x3f036412, 0x35255508,   // fr.gl.es_544 rw.zu.lg_666  lg.nl.af_654 rw.eu.zu_443
  0x11313205, 0x060a31a4, 0x280a5307, 0x20171ba4,   // bs.az.ro_333 az.pt.de_433  ht.pt.sw_432 tr.sr.sq_433
  0x10000e05, 0x090306a0, 0x1b002807, 0x11291e09,   // is.lt.un_330 de.nl.pl_322  sw.tr.un_420 ms.sl.ro_444
  // [44b0]
  0x53003523, 0x53202aa9, 0x194a010c, 0x20552508,   // zu.ht.un_880 mt.sq.ht_544  en.yo.gl_543 eu.rw.sq_443
  0x35310f0c, 0x10070f0c, 0x52061c0c, 0x250f0611,   // lv.az.zu_543 lv.it.lt_543  id.de.ha_543 de.lv.eu_653
  0x64033fa4, 0x11073155, 0x0d0906a0, 0x64003b0d,   // af.nl.lg_433 az.it.ro_442  de.pl.cs_322 so.lg.un_540
  0x0d120607, 0x1b005308, 0x1b02080c, 0x0a250705,   // de.hu.cs_432 ht.tr.un_430  no.da.tr_543 it.eu.pt_333
  // [44c0]
  0x092d06a7, 0x1711080c, 0x06003209, 0x20062aac,   // de.sk.pl_532 uk.ro.sr_543  bs.de.un_440 mt.de.sq_632
  0x27000612, 0x2b001a12, 0x01530504, 0x016b0207,   // de.gd.un_640 tl.vi.un_640  fr.ht.en_332 da.ceb.en_432
  0x2b6b31a0, 0x010e64a4, 0x31001704, 0x0d000612,   // az.ceb.vi_322 lg.is.en_433  sr.az.un_320 de.cs.un_640
  0x0e030613, 0x3b526404, 0x122d10a4, 0x06000e0e,   // de.nl.is_665 lg.ha.so_332  lt.sk.hu_433 is.de.un_550
  // [44d0]
  0x643f1ba0, 0x1b3b3113, 0x0c041c04, 0x11000807,   // tr.af.lg_322 az.so.tr_665  id.fi.sv_332 no.ro.un_420
  0x682135a9, 0x17000820, 0x01073104, 0x27186408,   // zu.jw.ig_544 uk.sr.un_850  az.it.en_332 lg.ga.gd_443
  0x0100531b, 0x2a060460, 0x0f102daf, 0x35531105,   // ht.en.un_770 fi.de.mt_664  sk.lt.lv_655 ro.ht.zu_333
  0x0900030c, 0x092a2504, 0x68006e21, 0x19052307,   // nl.pl.un_530 eu.mt.pl_332  hmn.ig.un_860 ca.fr.gl_432
  // [44e0]
  0x06003f1b, 0x3b00021a, 0x162901a0, 0x5313045a,   // af.de.un_770 da.so.un_760  en.sl.hr_322 fi.et.ht_553
  0x070f1009, 0x06030e0c, 0x013528a0, 0x060f0c13,   // lt.lv.it_444 is.nl.de_543  sw.zu.en_322 sv.lv.de_665
  0x2a2307a4, 0x20000719, 0x3b251a05, 0x033f0fa4,   // it.ca.mt_433 it.sq.un_750  tl.eu.so_333 lv.af.nl_433
  0x0b072d0c, 0x102a0f0c, 0x2b100f0d, 0x04002d1a,   // sk.it.es_543 lv.mt.lt_543  lv.lt.vi_554 sk.fi.un_760
  // [44f0]
  0x11006b04, 0x17000a07, 0x641e350c, 0x0e001313,   // ceb.ro.un_320 mk.sr.un_420  zu.ms.lg_543 et.is.un_650
  0x23555208, 0x07252aa9, 0x1c281ea4, 0x28002d04,   // ha.rw.ca_443 mt.eu.it_544  ms.sw.id_433 sk.sw.un_320
  0x111e1c08, 0x1e00070c, 0x21534a08, 0x1b1c210d,   // id.ms.ro_443 it.ms.un_530  yo.ht.jw_443 jw.id.tr_554
  0x21101a5a, 0x311035a0, 0x0f000312, 0x21351ca7,   // tl.lt.jw_553 zu.lt.az_322  nl.lv.un_640 id.zu.jw_532
  // [4500]
  0x1a004a12, 0x191007a0, 0x3b25550c, 0x11522812,   // yo.tl.un_640 it.lt.gl_322  rw.eu.so_543 sw.ha.ro_654
  0x0a1011a0, 0x5500110e, 0x21071e0c, 0x21006805,   // ro.be.mk_322 ro.rw.un_550  ms.it.jw_543 ig.jw.un_330
  0x3b520ea9, 0x0d292d0c, 0x23111c07, 0x13091c0c,   // is.ha.so_544 sk.sl.cs_543  id.ro.ca_432 mr.hi.bh_543
  0x18001019, 0x0700291a, 0x55522da7, 0x25521114,   // lt.ga.un_750 sl.it.un_760  sk.ha.rw_532 ro.ha.eu_666
  // [4510]
  0x55281aa9, 0x3b003121, 0x2000250c, 0x01063fa0,   // tl.sw.rw_544 az.so.un_860  eu.sq.un_530 af.de.en_322
  0x1c0927a0, 0x23201108, 0x25231109, 0x1a001e04,   // gd.pl.id_322 ro.sq.ca_443  ro.ca.eu_444 ms.tl.un_320
  0x21251a11, 0x2b1f6bac, 0x312a3bee, 0x1c1b1e07,   // tl.eu.jw_653 ceb.cy.vi_632  so.mt.az_422 ms.tr.id_432
  0x04100805, 0x3f0302ec, 0x311b1ea9, 0x1200100d,   // uk.be.ru_333 da.nl.af_644  ms.tr.az_544 lt.hu.un_540
  // [4520]
  0x200727ad, 0x25105504, 0x0e183f07, 0x07112daf,   // gd.it.sq_643 rw.lt.eu_332  af.ga.is_432 sk.ro.it_655
  0x11002312, 0x1a536b13, 0x01061fa9, 0x036e53ee,   // ca.ro.un_640 ceb.ht.tl_665  cy.de.en_544 ht.hmn.nl_422
  0x190b230b, 0x13112312, 0x0e6b3fee, 0x090d20ad,   // ca.es.gl_542 ca.ro.et_654  af.ceb.is_422 sq.cs.pl_643
  0x2a002514, 0x28006b18, 0x0e04105a, 0x10000e07,   // eu.mt.un_660 ceb.sw.un_740  lt.fi.is_553 is.lt.un_420
  // [4530]
  0x0b192355, 0x3b0506ad, 0x040652a9, 0x060e3fa9,   // ca.gl.es_442 de.fr.so_643  ha.de.fi_544 af.is.de_544
  0x3f002b1b, 0x64125204, 0x10040faf, 0x1c0d0902,   // vi.af.un_770 ha.hu.lg_332  lv.fi.lt_655 hi.ne.mr_222
  0x216e1ea7, 0x2b000a19, 0x11202904, 0x4a000c12,   // ms.hmn.jw_532 pt.vi.un_750  sl.sq.ro_332 sv.yo.un_640
  0x08006404, 0x230b180c, 0x110a10a4, 0x11000a1a,   // lg.no.un_320 ga.es.ca_543  be.mk.ro_433 mk.ro.un_760
  // [4540]
  0x64325202, 0x23120513, 0x132a2805, 0x17001113,   // ha.bs.lg_222 fr.hu.ca_665  sw.mt.et_333 ro.sr.un_650
  0x0500180d, 0x040f1013, 0x2b000a12, 0x070823a4,   // ga.fr.un_540 lt.lv.fi_665  pt.vi.un_640 ca.no.it_433
  0x0f082aa4, 0x083f2aa7, 0x235201a4, 0x0a056413,   // mt.no.lv_433 mt.af.no_532  en.ha.ca_433 lg.fr.pt_665
  0x2a0f08a4, 0x041f6b55, 0x100a11a0, 0x076b13ee,   // no.lv.mt_433 ceb.cy.fi_442  ro.mk.be_322 et.ceb.it_422
  // [4550]
  0x01191ea4, 0x1c231eee, 0x25001807, 0x06092a14,   // ms.gl.en_433 ms.ca.id_422  ga.eu.un_420 mt.pl.de_666
  0x1e041ca4, 0x0c081f0c, 0x20030f07, 0x2a3216a4,   // id.fi.ms_433 cy.no.sv_543  lv.nl.sq_432 hr.bs.mt_433
  0x19004a07, 0x030c2bee, 0x0f080214, 0x0b003504,   // yo.gl.un_420 vi.sv.nl_422  da.no.lv_666 zu.es.un_320
  0x050119a7, 0x2b0727a0, 0x0c1c03a4, 0x020c0fa7,   // gl.en.fr_532 gd.it.vi_322  nl.id.sv_433 lv.sv.da_532
  // [4560]
  0x1e1c2107, 0x3b04130c, 0x0c0704af, 0x2d1f2509,   // jw.id.ms_432 et.fi.so_543  fi.it.sv_655 eu.cy.sk_444
  0x25002702, 0x0e00110d, 0x1c1f2007, 0x180a055e,   // gd.eu.un_220 ro.is.un_540  sq.cy.id_432 fr.pt.ga_652
  0x10170a13, 0x16000f0c, 0x16003211, 0x09101b08,   // mk.sr.be_665 lv.hr.un_530  bs.hr.un_630 tr.lt.pl_443
  0x1c3b64a6, 0x28211aa0, 0x10001713, 0x062a07ac,   // lg.so.id_521 tl.jw.sw_322  sr.be.un_650 it.mt.de_632
  // [4570]
  0x1b3b1311, 0x0e040ca4, 0x113b010c, 0x06253ba0,   // et.so.tr_653 sv.fi.is_433  en.so.ro_543 so.eu.de_322
  0x1e6e1cad, 0x190b08a4, 0x6e6b4a04, 0x6e1e2108,   // id.hmn.ms_643 no.es.gl_433  yo.ceb.hmn_332 jw.ms.hmn_443
  0x0f252da4, 0x350b070b, 0x023f08a9, 0x2123050c,   // sk.eu.lv_433 it.es.zu_542  no.af.da_544 fr.ca.jw_543
  0x55216413, 0x1b1c1ead, 0x3f003507, 0x2964550c,   // lg.jw.rw_665 ms.id.tr_643  zu.af.un_420 rw.lg.sl_543
  // [4580]
  0x4a00270c, 0x27005322, 0x29003f1a, 0x174a290c,   // gd.yo.un_530 ht.gd.un_870  af.sl.un_760 sl.yo.sr_543
  0x0e130855, 0x02060c0d, 0x12202508, 0x180e050b,   // no.et.is_442 sv.de.da_554  eu.sq.hu_443 fr.is.ga_542
  0x03060f12, 0x285520ec, 0x0c060eaf, 0x530221a4,   // lv.de.nl_654 sq.rw.sw_644  is.de.sv_655 jw.da.ht_433
  0x110a0da4, 0x3f082107, 0x351664ec, 0x351820af,   // cs.pt.ro_433 jw.no.af_432  lg.hr.zu_644 sq.ga.zu_655
  // [4590]
  0x1c3f1aa7, 0x642021a4, 0x28165504, 0x23006405,   // tl.af.id_532 jw.sq.lg_433  rw.hr.sw_332 lg.ca.un_330
  0x4a0f07a4, 0x28253108, 0x281b2905, 0x28001b18,   // it.lv.yo_433 az.eu.sw_443  sl.tr.sw_333 tr.sw.un_740
  0x1b006808, 0x04201112, 0x18282707, 0x3125200c,   // ig.tr.un_430 ro.sq.fi_654  gd.sw.ga_432 sq.eu.az_543
  0x030f06a7, 0x060e0309, 0x181e2707, 0x0b0a2360,   // de.lv.nl_532 nl.is.de_444  gd.ms.ga_432 ca.pt.es_664
  // [45a0]
  0x180b270c, 0x0e001c04, 0x0c130b07, 0x08131ea4,   // gd.es.ga_543 id.is.un_320  es.et.sv_432 ms.et.no_433
  0x2d0d4a09, 0x251801a4, 0x2711180d, 0x00000203,   // yo.cs.sk_444 en.ga.eu_433  ga.ro.gd_554 da.un.un_300
  0x181227ee, 0x1200351b, 0x066b0c08, 0x281227a0,   // gd.hu.ga_422 zu.hu.un_770  sv.ceb.de_443 gd.hu.sw_322
  0x11072a0c, 0x1e1c1aa9, 0x6b211ea9, 0x063f5507,   // mt.it.ro_543 tl.id.ms_544  ms.jw.ceb_544 rw.af.de_432
  // [45b0]
  0x0b001114, 0x29130908, 0x08021f0c, 0x07101fa7,   // ro.es.un_660 pl.et.sl_443  cy.da.no_543 cy.lt.it_532
  0x1021010c, 0x6b1a130e, 0x17352004, 0x2d120e12,   // en.jw.lt_543 et.tl.ceb_555  sq.zu.sr_332 is.hu.sk_654
  0x04002105, 0x321609ec, 0x10001f05, 0x0d0855ec,   // jw.fi.un_330 pl.hr.bs_644  cy.lt.un_330 rw.no.cs_644
  0x681b35a7, 0x03000612, 0x1c642107, 0x29121e07,   // zu.tr.ig_532 de.nl.un_640  jw.lg.id_432 ms.hu.sl_432
  // [45c0]
  0x12070fa7, 0x250f1a02, 0x193b3104, 0x3f04035a,   // lv.it.hu_532 tl.lv.eu_222  az.so.gl_332 nl.fi.af_553
  0x320c020c, 0x1e3f130d, 0x531901a9, 0x3f0c6ea4,   // da.sv.bs_543 et.af.ms_554  en.gl.ht_544 hmn.sv.af_433
  0x0a08170c, 0x02006e19, 0x6e002d1a, 0x0c310611,   // sr.uk.mk_543 hmn.da.un_750  sk.hmn.un_760 de.az.sv_653
  0x32001008, 0x2a001708, 0x5500522c, 0x270208a4,   // lt.bs.un_430 sr.mt.un_430  ha.rw.un_990 no.da.gd_433
  // [45d0]
  0x27006b0d, 0x3f6b6eec, 0x1c130911, 0x6428520c,   // ceb.gd.un_540 hmn.ceb.af_644  hi.bh.mr_653 ha.sw.lg_543
  0x0932310d, 0x64555202, 0x3f6e1fa9, 0x1f02030c,   // az.bs.pl_554 ha.rw.lg_222  cy.hmn.af_544 nl.da.cy_543
  0x1e1c1aa4, 0x04003513, 0x042028a4, 0x35186b0c,   // tl.id.ms_433 zu.fi.un_650  sw.sq.fi_433 ceb.ga.zu_543
  0x036e270e, 0x04081eee, 0x096e2d11, 0x04130fad,   // gd.hmn.nl_555 ms.no.fi_422  sk.hmn.pl_653 lv.et.fi_643
  // [45e0]
  0x6b3513a4, 0x6b100aa4, 0x021a6bad, 0x126410a0,   // et.zu.ceb_433 pt.lt.ceb_433  ceb.tl.da_643 lt.lg.hu_322
  0x53001904, 0x19051108, 0x520821a0, 0x060819a0,   // gl.ht.un_320 ro.fr.gl_443  jw.no.ha_322 gl.no.de_322
  0x10093507, 0x04110aad, 0x04002a07, 0x6b281a0c,   // zu.pl.lt_432 mk.ro.ru_643  mt.fi.un_420 tl.sw.ceb_543
  0x64001e02, 0x64033fec, 0x1e1c0414, 0x1c3b1ea4,   // ms.lg.un_220 af.nl.lg_644  fi.id.ms_666 ms.so.id_433
  // [45f0]
  0x4a64280c, 0x10641305, 0x2a645208, 0x12211ea4,   // sw.lg.yo_543 et.lg.lt_333  ha.lg.mt_443 ms.jw.hu_433
  0x0a35040d, 0x231228a0, 0x531f35a4, 0x080f1012,   // fi.zu.pt_554 sw.hu.ca_322  zu.cy.ht_433 lt.lv.no_654
  0x08021a14, 0x1c201e11, 0x551a6bee, 0x0802270d,   // tl.da.no_666 ms.sq.id_653  ceb.tl.rw_422 gd.da.no_554
  0x25001c02, 0x281e3b07, 0x2a6407af, 0x1b000613,   // id.eu.un_220 so.ms.sw_432  it.lg.mt_655 de.tr.un_650
  // [4600]
  0x04071009, 0x13002502, 0x182821ad, 0x03001c0c,   // be.bg.ru_444 eu.et.un_220  jw.sw.ga_643 id.nl.un_530
  0x2d162804, 0x203f1ca4, 0x03021faf, 0x121e2a08,   // sw.hr.sk_332 id.af.sq_433  cy.da.nl_655 mt.ms.hu_443
  0x6e033fa4, 0x201b3208, 0x2d050da6, 0x0f041aee,   // af.nl.hmn_433 bs.tr.sq_443  cs.fr.sk_521 tl.fi.lv_422
  0x08001f0c, 0x0a0410ad, 0x25351207, 0x1012040c,   // cy.no.un_530 be.ru.mk_643  hu.zu.eu_432 fi.hu.lt_543
  // [4610]
  0x04231208, 0x352b1fa0, 0x0b000a02, 0x0120270c,   // hu.ca.fi_443 cy.vi.zu_322  pt.es.un_220 gd.sq.en_543
  0x3b131e12, 0x0f291705, 0x02002a14, 0x1a000104,   // ms.et.so_654 sr.sl.lv_333  mt.da.un_660 en.tl.un_320
  0x1b041c05, 0x12002012, 0x3b133f08, 0x040c3f07,   // id.fi.tr_333 sq.hu.un_640  af.et.so_443 af.sv.fi_432
  0x1a6b0bec, 0x0c19040d, 0x1f3b18ec, 0x1a6b0f0c,   // es.ceb.tl_644 fi.gl.sv_554  ga.so.cy_644 lv.ceb.tl_543
  // [4620]
  0x1f523fa4, 0x6b003b09, 0x11256b0c, 0x68213b08,   // af.ha.cy_433 so.ceb.un_440  ceb.eu.ro_543 so.jw.ig_443
  0x0e355512, 0x0f101f02, 0x3b0b6b04, 0x1c11210c,   // rw.zu.is_654 cy.lt.lv_222  ceb.es.so_332 jw.ro.id_543
  0x21005214, 0x0a291cee, 0x090d13a0, 0x351f0311,   // ha.jw.un_660 id.sl.pt_422  bh.ne.hi_322 nl.cy.zu_653
  0x1f6b1a08, 0x13083f09, 0x1c1e6ea7, 0x3b1f0cec,   // tl.ceb.cy_443 af.no.et_444  hmn.ms.id_532 sv.cy.so_644
  // [4630]
  0x05550208, 0x13002d04, 0x19236eee, 0x23190a0d,   // da.rw.fr_443 sk.et.un_320  hmn.ca.gl_422 pt.gl.ca_554
  0x160d175a, 0x09002a13, 0x313b2a12, 0x6e001e08,   // sr.cs.hr_553 mt.pl.un_650  mt.so.az_654 ms.hmn.un_430
  0x10006e08, 0x19005308, 0x10190b0c, 0x6406550c,   // hmn.lt.un_430 ht.gl.un_430  es.gl.lt_543 rw.de.lg_543
  0x1b3125a9, 0x183b27a4, 0x08061805, 0x0f136ead,   // eu.az.tr_544 gd.so.ga_433  ga.de.no_333 hmn.et.lv_643
  // [4640]
  0x061f0ea4, 0x52556bad, 0x522a285a, 0x124a530e,   // is.cy.de_433 ceb.rw.ha_643  sw.mt.ha_553 ht.yo.hu_555
  0x080c1a09, 0x05001f13, 0x0c21200c, 0x55112aec,   // tl.sv.no_444 cy.fr.un_650  sq.jw.sv_543 mt.ro.rw_644
  0x13000520, 0x526b1805, 0x11311baf, 0x083f030c,   // fr.et.un_850 ga.ceb.ha_333  tr.az.ro_655 nl.af.no_543
  0x080e0660, 0x52006b0e, 0x64063507, 0x32092807,   // de.is.no_664 ceb.ha.un_550  zu.de.lg_432 sw.pl.bs_432
  // [4650]
  0x3500520d, 0x1200201a, 0x17001122, 0x27000a02,   // ha.zu.un_540 sq.hu.un_760  ro.sr.un_870 pt.gd.un_220
  0x6b004a0d, 0x28065202, 0x20211205, 0x646b3509,   // yo.ceb.un_540 ha.de.sw_222  hu.jw.sq_333 zu.ceb.lg_444
  0x551718a4, 0x12080c60, 0x0c181a08, 0x2106550c,   // ga.sr.rw_433 sv.no.hu_664  tl.ga.sv_443 rw.de.jw_543
  0x080c200c, 0x07001718, 0x13033f0c, 0x02133f0c,   // sq.sv.no_543 sr.bg.un_740  af.nl.et_543 af.et.da_543
  // [4660]
  0x07111708, 0x523b1a07, 0x1f001014, 0x1f2d1807,   // sr.ro.bg_443 tl.so.ha_432  lt.cy.un_660 ga.sk.cy_432
  0x0b1008a0, 0x0f2d2107, 0x1e1c3bec, 0x0b1b19a0,   // no.lt.es_322 jw.sk.lv_432  so.id.ms_644 gl.tr.es_322
  0x06005519, 0x06002821, 0x1e6b1a0d, 0x201f03a0,   // rw.de.un_750 sw.de.un_860  tl.ceb.ms_554 nl.cy.sq_322
  0x20001f19, 0x530e1f05, 0x05003113, 0x2d013b07,   // cy.sq.un_750 cy.is.ht_333  az.fr.un_650 so.en.sk_432
  // [4670]
  0x100f09ee, 0x2a041a0b, 0x0f005304, 0x13534aa4,   // pl.lv.lt_422 tl.fi.mt_542  ht.lv.un_320 yo.ht.et_433
  0x311b5208, 0x0a170808, 0x231a210c, 0x1b315204,   // ha.tr.az_443 uk.sr.mk_443  jw.tl.ca_543 ha.az.tr_332
  0x25000113, 0x0f00170d, 0x20000309, 0x2d0d29a9,   // en.eu.un_650 sr.lv.un_540  nl.sq.un_440 sl.cs.sk_544
  0x102d01a4, 0x17111fec, 0x644a2808, 0x1f001602,   // en.sk.lt_433 cy.ro.sr_644  sw.yo.lg_443 hr.cy.un_220
  // [4680]
  0x2500642b, 0x3b6b100d, 0x2a0c3bad, 0x0c001318,   // lg.eu.un_980 lt.ceb.so_554  so.sv.mt_643 et.sv.un_740
  0x0c2012a7, 0x07190b13, 0x29004a1a, 0x2a001b19,   // hu.sq.sv_532 es.gl.it_665  yo.sl.un_760 tr.mt.un_750
  0x04641eee, 0x1e1c1a0c, 0x28000a0d, 0x35004a19,   // ms.lg.fi_422 tl.id.ms_543  pt.sw.un_540 yo.zu.un_750
  0x2500200e, 0x1729100c, 0x19002d04, 0x04171112,   // sq.eu.un_550 lt.sl.sr_543  sk.gl.un_320 ro.sr.ru_654
  // [4690]
  0x351a6ba4, 0x110305a0, 0x291055ad, 0x2b206eee,   // ceb.tl.zu_433 fr.nl.ro_322  rw.lt.sl_643 hmn.sq.vi_422
  0x3b1364a4, 0x04033f0c, 0x0f000707, 0x0c040dee,   // lg.et.so_433 af.nl.fi_543  it.lv.un_420 cs.fi.sv_422
  0x210906a7, 0x0900311a, 0x1827280c, 0x250407ad,   // de.pl.jw_532 az.pl.un_760  sw.gd.ga_543 it.fi.eu_643
  0x1b002813, 0x25002022, 0x0125200c, 0x11006b08,   // sw.tr.un_650 sq.eu.un_870  sq.eu.en_543 ceb.ro.un_430
  // [46a0]
  0x1b002a11, 0x3f0e0214, 0x3f355505, 0x19520bee,   // mt.tr.un_630 da.is.af_666  rw.zu.af_333 es.ha.gl_422
  0x53231807, 0x2b2718a4, 0x12645308, 0x0c000414,   // ga.ca.ht_432 ga.gd.vi_433  ht.lg.hu_443 fi.sv.un_660
  0x32291711, 0x080219a0, 0x233b13ec, 0x3500031a,   // sr.sl.bs_653 gl.da.no_322  et.so.ca_644 nl.zu.un_760
  0x64353104, 0x4a00521b, 0x09120da0, 0x52006420,   // az.zu.lg_332 ha.yo.un_770  cs.hu.pl_322 lg.ha.un_850
  // [46b0]
  0x0000642d, 0x0864350b, 0x11170aa9, 0x256b4aee,   // lg.un.un_A00 zu.lg.no_542  mk.sr.ro_544 yo.ceb.eu_422
  0x35063f13, 0x12211c08, 0x1e061c04, 0x321629a4,   // af.de.zu_665 id.jw.hu_443  id.de.ms_332 sl.hr.bs_433
  0x644a3504, 0x3f2d29a4, 0x0d292d10, 0x290d2d0c,   // zu.yo.lg_332 sl.sk.af_433  sk.sl.cs_642 sk.cs.sl_543
  0x35204aa0, 0x35006420, 0x01310204, 0x3f000702,   // yo.sq.zu_322 lg.zu.un_850  da.az.en_332 it.af.un_220
  // [46c0]
  0x06130c11, 0x250c1304, 0x272d0d05, 0x104a6808,   // sv.et.de_653 et.sv.eu_332  cs.sk.gd_333 ig.yo.lt_443
  0x121c1ea4, 0x12001a2a, 0x080205ac, 0x0c00011a,   // ms.id.hu_433 tl.hu.un_970  fr.da.no_632 en.sv.un_760
  0x28005502, 0x2d0e0a0b, 0x11001721, 0x0e1a1205,   // rw.sw.un_220 pt.is.sk_542  sr.ro.un_860 hu.tl.is_333
  0x1c1a1e12, 0x536b1a08, 0x2a011308, 0x291320ad,   // ms.tl.id_654 tl.ceb.ht_443  et.en.mt_443 sq.et.sl_643
  // [46d0]
  0x1a005509, 0x20531212, 0x1c3b6ba4, 0x0c190b0d,   // rw.tl.un_440 hu.ht.sq_654  ceb.so.id_433 es.gl.sv_554
  0x212b3509, 0x3f034a04, 0x2a07270c, 0x1e000619,   // zu.vi.jw_444 yo.nl.af_332  gd.it.mt_543 de.ms.un_750
  0x52000707, 0x190b2360, 0x190b230e, 0x0e645204,   // it.ha.un_420 ca.es.gl_664  ca.es.gl_555 ha.lg.is_332
  0x0b0a1811, 0x08070a14, 0x07100a14, 0x080201a9,   // ga.pt.es_653 mk.bg.uk_666  mk.be.bg_666 en.da.no_544
  // [46e0]
  0x29001904, 0x096b1a12, 0x05070e04, 0x55293505,   // gl.sl.un_320 tl.ceb.pl_654  is.it.fr_332 zu.sl.rw_333
  0x1b190a08, 0x033f1fac, 0x0a006b22, 0x1f1811af,   // pt.gl.tr_443 cy.af.nl_632  ceb.pt.un_870 ro.ga.cy_655
  0x0c080ea4, 0x080253a4, 0x3b3f0309, 0x1f0f1112,   // is.no.sv_433 ht.da.no_433  nl.af.so_444 ro.lv.cy_654
  0x02060807, 0x0e00232b, 0x1f000c22, 0x0a004a07,   // no.de.da_432 ca.is.un_980  sv.cy.un_870 yo.pt.un_420
  // [46f0]
  0x04001904, 0x0f001604, 0x3f311aad, 0x2528640c,   // gl.fi.un_320 hr.lv.un_320  tl.az.af_643 lg.sw.eu_543
  0x6853010b, 0x090627ec, 0x11051b5a, 0x3100531b,   // en.ht.ig_542 gd.de.pl_644  tr.fr.ro_553 ht.az.un_770
  0x4a005304, 0x190b5205, 0x1807110d, 0x23000804,   // ht.yo.un_320 ha.es.gl_333  ro.it.ga_554 no.ca.un_320
  0x20072313, 0x1a252307, 0x1000282a, 0x18270112,   // ca.it.sq_665 ca.eu.tl_432  sw.lt.un_970 en.gd.ga_654
  // [4700]
  0x190a29a9, 0x190b0a60, 0x28186ba7, 0x060c27a4,   // sl.pt.gl_544 pt.es.gl_664  ceb.ga.sw_532 gd.sv.de_433
  0x53041012, 0x08020fa9, 0x1a6b2511, 0x35641a0c,   // lt.fi.ht_654 lv.da.no_544  eu.ceb.tl_653 tl.lg.zu_543
  0x1f090d0c, 0x100411ee, 0x311e1c0c, 0x08252855,   // cs.pl.cy_543 ro.ru.be_422  id.ms.az_543 sw.eu.no_442
  0x18270608, 0x1c4a210b, 0x1f0601ec, 0x1e1c1a0e,   // de.gd.ga_443 jw.yo.id_542  en.de.cy_644 tl.id.ms_555
  // [4710]
  0x1c121ea9, 0x0a110405, 0x201304a9, 0x033f0d12,   // ms.hu.id_544 ru.ro.mk_333  fi.et.sq_544 cs.af.nl_654
  0x3b030f0d, 0x231a1109, 0x554a530b, 0x21091f07,   // lv.nl.so_554 ro.tl.ca_444  ht.yo.rw_542 cy.pl.jw_432
  0x2a1f0111, 0x20001305, 0x2b6455a4, 0x091f2aa0,   // en.cy.mt_653 et.sq.un_330  rw.lg.vi_433 mt.cy.pl_322
  0x23000c08, 0x55001a0d, 0x1b113113, 0x0e1220ee,   // sv.ca.un_430 tl.rw.un_540  az.ro.tr_665 sq.hu.is_422
  // [4720]
  0x12250da4, 0x0203060b, 0x0a000f08, 0x0c0d0412,   // cs.eu.hu_433 de.nl.da_542  lv.pt.un_430 fi.cs.sv_654
  0x060b25ad, 0x112a23ec, 0x051123a0, 0x641a01ad,   // eu.es.de_643 ca.mt.ro_644  ca.ro.fr_322 en.tl.lg_643
  0x1812200c, 0x19002513, 0x1f00092a, 0x08002512,   // sq.hu.ga_543 eu.gl.un_650  pl.cy.un_970 eu.no.un_640
  0x1e2a310c, 0x2a091f0c, 0x08002534, 0x01006e0c,   // az.mt.ms_543 cy.pl.mt_543  eu.no.un_A80 hmn.en.un_530
  // [4730]
  0x1b1f0b0c, 0x016b68a0, 0x6e003f0e, 0x07190a09,   // es.cy.tr_543 ig.ceb.en_322  af.hmn.un_550 pt.gl.it_444
  0x053f0312, 0x3f0364a4, 0x19110a0e, 0x5264060c,   // nl.af.fr_654 lg.nl.af_433  pt.ro.gl_555 de.lg.ha_543
  0x2a002314, 0x6e0a3108, 0x136b3b12, 0x06000523,   // ca.mt.un_660 az.pt.hmn_443  so.ceb.et_654 fr.de.un_880
  0x040c13a4, 0x20050b0c, 0x03001021, 0x0a002508,   // et.sv.fi_433 es.fr.sq_543  lt.nl.un_860 eu.pt.un_430
  // [4740]
  0x12024aa6, 0x1713520c, 0x28643b08, 0x1b6e0fa7,   // yo.da.hu_521 ha.et.sr_543  so.lg.sw_443 lv.hmn.tr_532
  0x64080205, 0x1a106ba9, 0x6b1a1ea4, 0x55685209,   // da.no.lg_333 ceb.lt.tl_544  ms.tl.ceb_433 ha.ig.rw_444
  0x6e000f1a, 0x1f000b04, 0x0d002502, 0x3f072aa4,   // lv.hmn.un_760 es.cy.un_320  eu.cs.un_220 mt.it.af_433
  0x101711a4, 0x0c001804, 0x27004a07, 0x03000623,   // ro.sr.be_433 ga.sv.un_320  yo.gd.un_420 de.nl.un_880
  // [4750]
  0x5216280c, 0x321f07ad, 0x3564530c, 0x0b0a11ec,   // sw.hr.ha_543 it.cy.bs_643  ht.lg.zu_543 ro.pt.es_644
  0x10002a02, 0x11041013, 0x3b313511, 0x64553ba7,   // mt.lt.un_220 be.ru.ro_665  zu.az.so_653 so.rw.lg_532
  0x04030f04, 0x3b28550c, 0x1e000a07, 0x11070111,   // lv.nl.fi_332 rw.sw.so_543  pt.ms.un_420 en.it.ro_653
  0x25643513, 0x11070412, 0x64282514, 0x6b0d3ba9,   // zu.lg.eu_665 ru.bg.ro_654  eu.sw.lg_666 so.cs.ceb_544
  // [4760]
  0x06040cec, 0x25003507, 0x01000302, 0x6452280d,   // sv.fi.de_644 zu.eu.un_420  nl.en.un_220 sw.ha.lg_554
  0x2a1806ee, 0x3b1c04ad, 0x1b001607, 0x35251212,   // de.ga.mt_422 fi.id.so_643  hr.tr.un_420 hu.eu.zu_654
  0x3100060c, 0x051f0713, 0x3f00100e, 0x0413060c,   // de.az.un_530 it.cy.fr_665  lt.af.un_550 de.et.fi_543
  0x12090307, 0x08182712, 0x3b551a04, 0x11271808,   // nl.pl.hu_432 gd.ga.no_654  tl.rw.so_332 ga.gd.ro_443
  // [4770]
  0x0a081013, 0x132811a4, 0x0a35640d, 0x6b31550c,   // be.uk.mk_665 ro.sw.et_433  lg.zu.pt_554 rw.az.ceb_543
  0x352a3b0c, 0x173216ad, 0x23000702, 0x13002707,   // so.mt.zu_543 hr.bs.sr_643  it.ca.un_220 gd.et.un_420
  0x5300280d, 0x1b0306ad, 0x1c001a04, 0x211a28ee,   // sw.ht.un_540 de.nl.tr_643  tl.id.un_320 sw.tl.jw_422
  0x55281a08, 0x0c001809, 0x251a3114, 0x211a6b5a,   // tl.sw.rw_443 ga.sv.un_440  az.tl.eu_666 ceb.tl.jw_553
  // [4780]
  0x04292aee, 0x041a6bee, 0x232a20a4, 0x19230aa7,   // mt.sl.fi_422 ceb.tl.fi_422  sq.mt.ca_433 pt.ca.gl_532
  0x110118a7, 0x05130808, 0x3f1e1c08, 0x1200210d,   // ga.en.ro_532 no.et.fr_443  id.ms.af_443 jw.hu.un_540
  0x18080cad, 0x35002008, 0x050a0ba0, 0x35002121,   // sv.no.ga_643 sq.zu.un_430  es.pt.fr_322 jw.zu.un_860
  0x25001b0d, 0x0e1009a0, 0x320f21a4, 0x1b210112,   // tr.eu.un_540 pl.lt.is_322  jw.lv.bs_433 en.jw.tr_654
  // [4790]
  0x043f2a05, 0x1f003f05, 0x00000403, 0x214a3b0c,   // mt.af.fi_333 af.cy.un_330  fi.un.un_300 so.yo.jw_543
  0x13006b04, 0x2500320c, 0x3f0e0205, 0x2a0c0408,   // ceb.et.un_320 bs.eu.un_530  da.is.af_333 fi.sv.mt_443
  0x04191c07, 0x01000304, 0x07000508, 0x1e1c2814,   // id.gl.fi_432 nl.en.un_320  fr.it.un_430 sw.id.ms_666
  0x3f523ba4, 0x071c1ead, 0x0a003b0e, 0x3f3b0408,   // so.ha.af_433 ms.id.it_643  so.pt.un_550 fi.so.af_443
  // [47a0]
  0x103b19a4, 0x070511a4, 0x123b280c, 0x0a003b07,   // gl.so.lt_433 ro.fr.it_433  sw.so.hu_543 so.pt.un_420
  0x3b003f12, 0x131b0c0d, 0x0a0807ad, 0x0600180c,   // af.so.un_640 sv.tr.et_554  bg.uk.mk_643 ga.de.un_530
  0x3f0108ee, 0x07251907, 0x08023baf, 0x080f0ea4,   // no.en.af_422 gl.eu.it_432  so.da.no_655 is.lv.no_433
  0x351f4a09, 0x0700200c, 0x2b001102, 0x04100705,   // yo.cy.zu_444 sq.it.un_530  ro.vi.un_220 bg.be.ru_333
  // [47b0]
  0x2d000104, 0x2d0d310c, 0x1a000e13, 0x6b1e1c11,   // en.sk.un_320 az.cs.sk_543  is.tl.un_650 id.ms.ceb_653
  0x23001c08, 0x5200680e, 0x0c640808, 0x27002b0d,   // id.ca.un_430 ig.ha.un_550  no.lg.sv_443 vi.gd.un_540
  0x04133f0c, 0x13640414, 0x04132511, 0x0719200c,   // af.et.fi_543 fi.lg.et_666  eu.et.fi_653 sq.gl.it_543
  0x2d0d20ee, 0x230a520b, 0x1e1c4aec, 0x4a532104,   // sq.cs.sk_422 ha.pt.ca_542  yo.id.ms_644 jw.ht.yo_332
  // [47c0]
  0x6e0b4aa4, 0x080420ee, 0x35006434, 0x311b1211,   // yo.es.hmn_433 sq.fi.no_422  lg.zu.un_A80 hu.tr.az_653
  0x20320413, 0x1300200c, 0x212d2808, 0x20003202,   // fi.bs.sq_665 sq.et.un_530  sw.sk.jw_443 bs.sq.un_220
  0x1b001a04, 0x0e2807a9, 0x321a4aa7, 0x170a0405,   // tl.tr.un_320 it.sw.is_544  yo.tl.bs_532 ru.mk.sr_333
  0x0c092da0, 0x2a051308, 0x0b1b5205, 0x53311e0c,   // sk.pl.sv_322 et.fr.mt_443  ha.tr.es_333 ms.az.ht_543
  // [47d0]
  0x1c000b04, 0x311b0ba0, 0x0b002904, 0x321620a9,   // es.id.un_320 es.tr.az_322  sl.es.un_320 sq.hr.bs_544
  0x643b6b13, 0x4a643b13, 0x290820ee, 0x1b042012,   // ceb.so.lg_665 so.lg.yo_665  sq.no.sl_422 sq.fi.tr_654
  0x08201608, 0x3b2864af, 0x0e1b3160, 0x272a1804,   // hr.sq.no_443 lg.sw.so_655  az.tr.is_664 ga.mt.gd_332
  0x0410070c, 0x311b0eee, 0x17071108, 0x04170702,   // bg.be.ru_543 is.tr.az_422  ro.bg.sr_443 bg.sr.ru_222
  // [47e0]
  0x1e524a02, 0x35213fa0, 0x6e000619, 0x27070308,   // yo.ha.ms_222 af.jw.zu_322  de.hmn.un_750 nl.it.gd_443
  0x532513ec, 0x0600270d, 0x0600291a, 0x1a643b12,   // et.eu.ht_644 gd.de.un_540  sl.de.un_760 so.lg.tl_654
  0x0f1006a9, 0x2d0d06ec, 0x06000302, 0x0c1906a7,   // de.lt.lv_544 de.cs.sk_644  nl.de.un_220 de.gl.sv_532
  0x3f062507, 0x52006e22, 0x1a002a08, 0x0a000404,   // eu.de.af_432 hmn.ha.un_870  mt.tl.un_430 ru.mk.un_320
  // [47f0]
  0x25000914, 0x354a1aa4, 0x555364ec, 0x082902a4,   // pl.eu.un_660 tl.yo.zu_433  lg.ht.rw_644 da.sl.no_433
  0x03133fa0, 0x13000420, 0x235321a9, 0x1b002504,   // af.et.nl_322 fi.et.un_850  jw.ht.ca_544 eu.tr.un_320
  0x04003b08, 0x28002304, 0x03060e0c, 0x01103fa4,   // so.fi.un_430 ca.sw.un_320  is.de.nl_543 af.lt.en_433
  0x0916290c, 0x0b23010c, 0x123152ee, 0x32290d55,   // sl.hr.pl_543 en.ca.es_543  ha.az.hu_422 cs.sl.bs_442

  // [4800]
  0x08006402, 0x06250c05, 0x1e000c08, 0x21000512,   // lg.no.un_220 sv.eu.de_333  sv.ms.un_430 fr.jw.un_640
  0x19070aec, 0x0e202a0d, 0x2a00072c, 0x07000a36,   // pt.it.gl_644 mt.sq.is_554  it.mt.un_990 mk.bg.un_AA0
  0x18000808, 0x0d042d0c, 0x230701a9, 0x03001602,   // no.ga.un_430 sk.fi.cs_543  en.it.ca_544 hr.nl.un_220
  0x0605010c, 0x1c000305, 0x1e1c35a9, 0x53050607,   // en.fr.de_543 nl.id.un_330  zu.id.ms_544 de.fr.ht_432
  // [4810]
  0x18001708, 0x1100290d, 0x0e0c2aad, 0x160d29ad,   // sr.ga.un_430 sl.ro.un_540  mt.sv.is_643 sl.cs.hr_643
  0x53002707, 0x25001f1b, 0x190a07a4, 0x10000721,   // gd.ht.un_420 cy.eu.un_770  it.pt.gl_433 bg.be.un_860
  0x13002314, 0x2a00112a, 0x64551a0c, 0x52553b08,   // ca.et.un_660 ro.mt.un_970  tl.rw.lg_543 so.rw.ha_443
  0x2d000921, 0x6b1a01ee, 0x1e1c2112, 0x04292da4,   // pl.sk.un_860 en.tl.ceb_422  jw.id.ms_654 sk.sl.fi_433
  // [4820]
  0x1a536b09, 0x25102807, 0x273f53a0, 0x2b004a09,   // ceb.ht.tl_444 sw.lt.eu_432  ht.af.gd_322 yo.vi.un_440
  0x53001e0d, 0x3b640f08, 0x3f001904, 0x2700290e,   // ms.ht.un_540 lv.lg.so_443  gl.af.un_320 sl.gd.un_550
  0x3f080c0d, 0x062a6e12, 0x643b5204, 0x0e2b4a0c,   // sv.no.af_554 hmn.mt.de_654  ha.so.lg_332 yo.vi.is_543
  0x2a12080b, 0x2d1819a0, 0x271007a0, 0x06001607,   // no.hu.mt_542 gl.ga.sk_322  it.lt.gd_322 hr.de.un_420
  // [4830]
  0x0600020c, 0x550531ad, 0x28121fec, 0x2b004a21,   // da.de.un_530 az.fr.rw_643  cy.hu.sw_644 yo.vi.un_860
  0x01032a02, 0x21011aee, 0x21251fad, 0x0f000702,   // mt.nl.en_222 tl.en.jw_422  cy.eu.jw_643 it.lv.un_220
  0x07252904, 0x0b05010c, 0x13091c09, 0x64001a19,   // sl.eu.it_332 en.fr.es_543  mr.hi.bh_444 tl.lg.un_750
  0x1b2855a9, 0x3b523108, 0x19001c04, 0x1a1c6b08,   // rw.sw.tr_544 az.ha.so_443  id.gl.un_320 ceb.id.tl_443
  // [4840]
  0x02040807, 0x02063112, 0x132025a4, 0x3b21640b,   // no.fi.da_432 az.de.da_654  eu.sq.et_433 lg.jw.so_542
  0x01001104, 0x17200907, 0x31351b08, 0x13002a0e,   // ro.en.un_320 pl.sq.sr_432  tr.zu.az_443 mt.et.un_550
  0x191b350c, 0x0c0821a0, 0x5531350c, 0x6431520c,   // zu.tr.gl_543 jw.no.sv_322  zu.az.rw_543 ha.az.lg_543
  0x19003118, 0x1f001b13, 0x283f06a4, 0x3f010310,   // az.gl.un_740 tr.cy.un_650  de.af.sw_433 nl.en.af_642
  // [4850]
  0x203117ee, 0x55311b0d, 0x0d0553a7, 0x351b310d,   // sr.az.sq_422 tr.az.rw_554  ht.fr.cs_532 az.tr.zu_554
  0x1121280c, 0x21031f04, 0x3217290c, 0x1e1c1a14,   // sw.jw.ro_543 cy.nl.jw_332  sl.sr.bs_543 tl.id.ms_666
  0x1b0f1008, 0x04123fa9, 0x52214a07, 0x1e002504,   // lt.lv.tr_443 af.hu.fi_544  yo.jw.ha_432 eu.ms.un_320
  0x08101104, 0x08022714, 0x1f031804, 0x0f1004a4,   // ro.be.uk_332 gd.da.no_666  ga.nl.cy_332 fi.lt.lv_433
  // [4860]
  0x232153ec, 0x190b18a0, 0x131004a4, 0x4a1f2855,   // ht.jw.ca_644 ga.es.gl_322  fi.lt.et_433 sw.cy.yo_442
  0x066b1a0c, 0x1b0f1012, 0x0655350c, 0x2b182702,   // tl.ceb.de_543 lt.lv.tr_654  zu.rw.de_543 gd.ga.vi_222
  0x1835555a, 0x0b232708, 0x28004a0e, 0x0a001e0c,   // rw.zu.ga_553 gd.ca.es_443  yo.sw.un_550 ms.pt.un_530
  0x1710040c, 0x040a08a7, 0x6b121aaf, 0x01020fa0,   // ru.be.sr_543 uk.mk.ru_532  tl.hu.ceb_655 lv.da.en_322
  // [4870]
  0x1253050e, 0x2010040c, 0x1935640c, 0x0f002d04,   // fr.ht.hu_555 fi.lt.sq_543  lg.zu.gl_543 sk.lv.un_320
  0x0429200e, 0x17081012, 0x31063b07, 0x3b003204,   // sq.sl.fi_555 be.uk.sr_654  so.de.az_432 bs.so.un_320
  0x53180ba0, 0x21002b08, 0x136e2512, 0x111e1912,   // es.ga.ht_322 vi.jw.un_430  eu.hmn.et_654 gl.ms.ro_654
  0x13000708, 0x05124aee, 0x0307350c, 0x2d002020,   // it.et.un_430 yo.hu.fr_422  zu.it.nl_543 sq.sk.un_850
  // [4880]
  0x100f35ad, 0x05640704, 0x06350314, 0x27001804,   // zu.lv.lt_643 it.lg.fr_332  nl.zu.de_666 ga.gd.un_320
  0x09105305, 0x061b030c, 0x1f000705, 0x4a5504af,   // ht.lt.pl_333 nl.tr.de_543  it.cy.un_330 fi.rw.yo_655
  0x191a2107, 0x122b19ad, 0x051103a9, 0x291055a4,   // jw.tl.gl_432 gl.vi.hu_643  nl.ro.fr_544 rw.lt.sl_433
  0x1a4a3504, 0x2011530c, 0x07003522, 0x0a1c2dee,   // zu.yo.tl_332 ht.ro.sq_543  zu.it.un_870 sk.id.pt_422
  // [4890]
  0x05011111, 0x05110304, 0x311b04a4, 0x11000322,   // ro.en.fr_653 nl.ro.fr_332  fi.tr.az_433 nl.ro.un_870
  0x31003512, 0x32006407, 0x32212d07, 0x13033fad,   // zu.az.un_640 lg.bs.un_420  sk.jw.bs_432 af.nl.et_643
  0x08170a0c, 0x021a3f0d, 0x2307110e, 0x21001a04,   // mk.sr.uk_543 af.tl.da_554  ro.it.ca_555 tl.jw.un_320
  0x190b230c, 0x52102907, 0x206b35ad, 0x35094aa7,   // ca.es.gl_543 sl.lt.ha_432  zu.ceb.sq_643 yo.pl.zu_532
  // [48a0]
  0x20051305, 0x3b063f0c, 0x1c211360, 0x022b250c,   // et.fr.sq_333 af.de.so_543  et.jw.id_664 eu.vi.da_543
  0x11052da4, 0x2a290fa4, 0x03001113, 0x03010505,   // sk.fr.ro_433 lv.sl.mt_433  ro.nl.un_650 fr.en.nl_333
  0x16000108, 0x2d290d05, 0x641a1c07, 0x2505010d,   // en.hr.un_430 cs.sl.sk_333  id.tl.lg_432 en.fr.eu_554
  0x10001105, 0x281a01af, 0x3b203108, 0x12061305,   // ro.be.un_330 en.tl.sw_655  az.sq.so_443 et.de.hu_333
  // [48b0]
  0x08040309, 0x5553350c, 0x0d002a0d, 0x042113af,   // nl.fi.no_444 zu.ht.rw_543  mt.cs.un_540 et.jw.fi_655
  0x02003f12, 0x32006b02, 0x0c005208, 0x0d0f2d0c,   // af.da.un_640 ceb.bs.un_220  ha.sv.un_430 sk.lv.cs_543
  0x02003f1a, 0x0723095a, 0x10001a04, 0x1c35250c,   // af.da.un_760 pl.ca.it_553  tl.lt.un_320 eu.zu.id_543
  0x04292809, 0x3f0208a4, 0x35000912, 0x11005212,   // sw.sl.fi_444 no.da.af_433  pl.zu.un_640 ha.ro.un_640
  // [48c0]
  0x080201ee, 0x08023f0c, 0x17680cee, 0x132311ec,   // en.da.no_422 af.da.no_543  sv.ig.sr_422 ro.ca.et_644
  0x252813a9, 0x020e08af, 0x3b6435ee, 0x072368a7,   // et.sw.eu_544 no.is.da_655  zu.lg.so_422 ig.ca.it_532
  0x1103010c, 0x13281a08, 0x013f09ad, 0x101a1e0c,   // en.nl.ro_543 tl.sw.et_443  pl.af.en_643 ms.tl.lt_543
  0x122d6ba0, 0x17002312, 0x35001a04, 0x11012307,   // ceb.sk.hu_322 ca.sr.un_640  tl.zu.un_320 ca.en.ro_432
  // [48d0]
  0x212a1ca4, 0x10041155, 0x2d0d20a4, 0x0c001302,   // id.mt.jw_433 ro.ru.be_442  sq.cs.sk_433 et.sv.un_220
  0x2829175a, 0x12003514, 0x0a130413, 0x18002304,   // sr.sl.sw_553 zu.hu.un_660  fi.et.pt_665 ca.ga.un_320
  0x2800521b, 0x06000122, 0x200803ee, 0x1e131ca4,   // ha.sw.un_770 en.de.un_870  nl.no.sq_422 id.et.ms_433
  0x21006407, 0x0700112a, 0x12060cac, 0x21003204,   // lg.jw.un_420 ro.bg.un_970  sv.de.hu_632 bs.jw.un_320
  // [48e0]
  0x07170812, 0x3b1b52af, 0x0f001214, 0x23051fa9,   // uk.sr.bg_654 ha.tr.so_655  hu.lv.un_660 cy.fr.ca_544
  0x5200531b, 0x0118270c, 0x0e00270d, 0x321610a4,   // ht.ha.un_770 gd.ga.en_543  gd.is.un_540 lt.hr.bs_433
  0x311b0e07, 0x1e1c1a09, 0x180111ee, 0x1c031ea9,   // is.tr.az_432 tl.id.ms_444  ro.en.ga_422 ms.nl.id_544
  0x0d005305, 0x12001a04, 0x2a000802, 0x1e000c05,   // ht.cs.un_330 tl.hu.un_320  no.mt.un_220 sv.ms.un_330
  // [48f0]
  0x3b112da4, 0x29006804, 0x1b00041b, 0x060e10a9,   // sk.ro.so_433 ig.sl.un_320  fi.tr.un_770 lt.is.de_544
  0x352827ee, 0x18551f07, 0x31202511, 0x1e00531a,   // gd.sw.zu_422 cy.rw.ga_432  eu.sq.az_653 ht.ms.un_760
  0x1c521eee, 0x1f0627a4, 0x0c042a0b, 0x04072a04,   // ms.ha.id_422 gd.de.cy_433  mt.fi.sv_542 mt.it.fi_332
  0x18002822, 0x1200061a, 0x2a000711, 0x07100a09,   // sw.ga.un_870 de.hu.un_760  it.mt.un_630 mk.be.bg_444
  // [4900]
  0x090a0ba0, 0x3b110fa4, 0x01002a0d, 0x0c000407,   // es.pt.pl_322 lv.ro.so_433  mt.en.un_540 fi.sv.un_420
  0x0a112a08, 0x0a1004ee, 0x2d0d18ec, 0x1a536b07,   // mt.ro.pt_443 ru.be.mk_422  ga.cs.sk_644 ceb.ht.tl_432
  0x281e35a4, 0x1f0701a4, 0x09006e0e, 0x060301a0,   // zu.ms.sw_433 en.it.cy_433  hmn.pl.un_550 en.nl.de_322
  0x3f011804, 0x03000604, 0x532b180b, 0x0e2d2a07,   // ga.en.af_332 de.nl.un_320  ga.vi.ht_542 mt.sk.is_432
  // [4910]
  0x063f2705, 0x0a070ba4, 0x17163207, 0x0c005504,   // gd.af.de_333 es.it.pt_433  bs.hr.sr_432 rw.sv.un_320
  0x52002807, 0x0100061a, 0x17041060, 0x1e3f035a,   // sw.ha.un_420 de.en.un_760  be.ru.sr_664 nl.af.ms_553
  0x3f00050d, 0x06121b1e, 0x35002919, 0x28002702,   // fr.af.un_540 tr.hu.de_863  sl.zu.un_750 gd.sw.un_220
  0x210a3bad, 0x19070b60, 0x11033f08, 0x16003507,   // so.pt.jw_643 es.it.gl_664  af.nl.ro_443 zu.hr.un_420
  // [4920]
  0x0805010c, 0x0107050d, 0x0300280c, 0x0b18070b,   // en.fr.no_543 fr.it.en_554  sw.nl.un_530 it.ga.es_542
  0x08130207, 0x12001b14, 0x0200111b, 0x060c030c,   // da.et.no_432 tr.hu.un_660  ro.da.un_770 nl.sv.de_543
  0x052a01a4, 0x12231804, 0x190b28a4, 0x353f4a04,   // en.mt.fr_433 ga.ca.hu_332  sw.es.gl_433 yo.af.zu_332
  0x1b000702, 0x09112da4, 0x11030707, 0x3f001c02,   // it.tr.un_220 sk.ro.pl_433  it.nl.ro_432 id.af.un_220
  // [4930]
  0x1800060c, 0x01352107, 0x23006b08, 0x020428ee,   // de.ga.un_530 jw.zu.en_432  ceb.ca.un_430 sw.fi.da_422
  0x2d1629a4, 0x100f29ec, 0x3f082007, 0x190b1aa9,   // sl.hr.sk_433 sl.lv.lt_644  sq.no.af_432 tl.es.gl_544
  0x21132909, 0x13040c02, 0x10130f0c, 0x321713ee,   // sl.et.jw_444 sv.fi.et_222  lv.et.lt_543 et.sr.bs_422
  0x06040eee, 0x07002302, 0x31000b02, 0x0a041702,   // is.fi.de_422 ca.it.un_220  es.az.un_220 sr.ru.mk_222
  // [4940]
  0x21050aa9, 0x1b0f5302, 0x1652090c, 0x12060812,   // pt.fr.jw_544 ht.lv.tr_222  pl.ha.hr_543 no.de.hu_654
  0x1b020812, 0x27120e07, 0x050601a9, 0x293b3202,   // no.da.tr_654 is.hu.gd_432  en.de.fr_544 bs.so.sl_222
  0x08000619, 0x1c3231a4, 0x055325a0, 0x0e000c0b,   // de.no.un_750 az.bs.id_433  eu.ht.fr_322 sv.is.un_520
  0x2a102505, 0x04171011, 0x1e1c280c, 0x29001607,   // eu.lt.mt_333 be.sr.ru_653  sw.id.ms_543 hr.sl.un_420
  // [4950]
  0x03643b0c, 0x2a000807, 0x08002308, 0x3b006412,   // so.lg.nl_543 no.mt.un_420  ca.no.un_430 lg.so.un_640
  0x11003f13, 0x321716ac, 0x163528a6, 0x271206a4,   // af.ro.un_650 hr.sr.bs_632  sw.zu.hr_521 de.hu.gd_433
  0x6b211a11, 0x043264a0, 0x0900270c, 0x0435280d,   // tl.jw.ceb_653 lg.bs.fi_322  gd.pl.un_530 sw.zu.fi_554
  0x55046412, 0x1727110b, 0x19250b55, 0x3f06080c,   // lg.fi.rw_654 ro.gd.sr_542  es.eu.gl_442 no.de.af_543
  // [4960]
  0x3f100c0b, 0x28003b13, 0x3f0320a4, 0x521c1eec,   // sv.lt.af_542 so.sw.un_650  sq.nl.af_433 ms.id.ha_644
  0x32291612, 0x203b520c, 0x100d2d12, 0x21255307,   // hr.sl.bs_654 ha.so.sq_543  sk.cs.lt_654 ht.eu.jw_432
  0x2112180c, 0x0c031355, 0x2d001218, 0x020e08a9,   // ar.ur.fa_543 et.nl.sv_442  hu.sk.un_740 no.is.da_544
  0x0d001708, 0x0e003118, 0x120603a0, 0x233555af,   // sr.cs.un_430 az.is.un_740  nl.de.hu_322 rw.zu.ca_655
  // [4970]
  0x10081713, 0x21002312, 0x31001014, 0x18130411,   // sr.uk.be_665 ca.jw.un_640  lt.az.un_660 fi.et.ga_653
  0x191755ac, 0x11006413, 0x19000721, 0x211c6ea7,   // rw.sr.gl_632 lg.ro.un_650  it.gl.un_860 hmn.id.jw_532
  0x52132555, 0x320f1707, 0x081004ad, 0x0c060e09,   // eu.et.ha_442 sr.lv.bs_432  ru.be.uk_643 is.de.sv_444
  0x3113040c, 0x181e1c0c, 0x0d00530d, 0x645511ee,   // fi.et.az_543 id.ms.ga_543  ht.cs.un_540 ro.rw.lg_422
  // [4980]
  0x1a046b13, 0x196e0aad, 0x6b1a1c07, 0x3b0925ad,   // ceb.fi.tl_665 pt.hmn.gl_643  id.tl.ceb_432 eu.pl.so_643
  0x251155a4, 0x2a093b12, 0x020108ad, 0x12000318,   // rw.ro.eu_433 so.pl.mt_654  no.en.da_643 nl.hu.un_740
  0x03172a07, 0x115320a9, 0x04080aa0, 0x55356807,   // mt.sr.nl_432 sq.ht.ro_544  mk.uk.ru_322 ig.zu.rw_432
  0x23001911, 0x2810640c, 0x1c0a6e08, 0x09532aa4,   // gl.ca.un_630 lg.lt.sw_543  hmn.pt.id_443 mt.ht.pl_433
  // [4990]
  0x27180a13, 0x0a0401a4, 0x0c085507, 0x0a186ea0,   // pt.ga.gd_665 en.fi.pt_433  rw.no.sv_432 hmn.ga.pt_322
  0x3b090eec, 0x16002a08, 0x073f1111, 0x04006409,   // is.pl.so_644 mt.hr.un_430  ro.af.it_653 lg.fi.un_440
  0x1c5521a4, 0x0e085511, 0x4a5568a0, 0x123f030d,   // jw.rw.id_433 rw.no.is_653  ig.rw.yo_322 nl.af.hu_554
  0x06293fa4, 0x17311baf, 0x55002a0e, 0x1f00231a,   // af.sl.de_433 tr.az.sr_655  mt.rw.un_550 ca.cy.un_760
  // [49a0]
  0x29002507, 0x32000305, 0x026b1aa9, 0x281a6b12,   // eu.sl.un_420 nl.bs.un_330  tl.ceb.da_544 ceb.tl.sw_654
  0x1e230ba9, 0x256455a9, 0x01033fa4, 0x28000d19,   // es.ca.ms_544 rw.lg.eu_544  af.nl.en_433 cs.sw.un_750
  0x6b190b09, 0x1a002112, 0x106b280c, 0x3b001019,   // es.gl.ceb_444 jw.tl.un_640  sw.ceb.lt_543 lt.so.un_750
  0x0a2a0709, 0x131a280c, 0x0e191012, 0x160f29a9,   // it.mt.pt_444 sw.tl.et_543  lt.gl.is_654 sl.lv.hr_544
  // [49b0]
  0x0f000421, 0x27002312, 0x181b31a7, 0x25072704,   // fi.lv.un_860 ca.gd.un_640  az.tr.ga_532 gd.it.eu_332
  0x17551304, 0x20033f5a, 0x25000613, 0x68003535,   // et.rw.sr_332 af.nl.sq_553  de.eu.un_650 zu.ig.un_A90
  0x683b6407, 0x0100090c, 0x27115509, 0x2a0427a0,   // lg.so.ig_432 pl.en.un_530  rw.ro.gd_444 gd.fi.mt_322
  0x212a07a0, 0x52211aa9, 0x19090aaf, 0x050d1905,   // it.mt.jw_322 tl.jw.ha_544  pt.pl.gl_655 gl.cs.fr_333
  // [49c0]
  0x2d0d0aa9, 0x0e2b2808, 0x1e181ca4, 0x031a2107,   // pt.cs.sk_544 sw.vi.is_443  id.ga.ms_433 jw.tl.nl_432
  0x2809550b, 0x10002119, 0x1e032a04, 0x310e0cee,   // rw.pl.sw_542 jw.lt.un_750  mt.nl.ms_332 sv.is.az_422
  0x2d0d11a0, 0x32172009, 0x532305ad, 0x040a17ad,   // ro.cs.sk_322 sq.sr.bs_444  fr.ca.ht_643 sr.mk.ru_643
  0x644a52ee, 0x6412230c, 0x3b290f0c, 0x68004a07,   // ha.yo.lg_422 ca.hu.lg_543  lv.sl.so_543 yo.ig.un_420
  // [49d0]
  0x3b211a08, 0x01002707, 0x6b04010c, 0x3b006e12,   // tl.jw.so_443 gd.en.un_420  en.fi.ceb_543 hmn.so.un_640
  0x18062707, 0x0e002b19, 0x05002302, 0x13006e22,   // gd.de.ga_432 vi.is.un_750  ca.fr.un_220 hmn.et.un_870
  0x08002905, 0x1c532860, 0x1300120d, 0x0f071e05,   // sl.no.un_330 sw.ht.id_664  hu.et.un_540 ms.it.lv_333
  0x21111707, 0x0f312907, 0x041353a4, 0x52000d0d,   // sr.ro.jw_432 sl.az.lv_432  ht.et.fi_433 cs.ha.un_540
  // [49e0]
  0x2a0b0405, 0x010e08a4, 0x0b64110c, 0x18000909,   // fi.es.mt_333 no.is.en_433  ro.lg.es_543 pl.ga.un_440
  0x2a1f1109, 0x2d170da4, 0x16073b07, 0x321c1e0c,   // ro.cy.mt_444 cs.sr.sk_433  so.it.hr_432 ms.id.bs_543
  0x23002014, 0x3f000207, 0x4a170b07, 0x21001f02,   // sq.ca.un_660 da.af.un_420  es.sr.yo_432 cy.jw.un_220
  0x0d004a19, 0x02003f14, 0x03001f07, 0x2928040c,   // yo.cs.un_750 af.da.un_660  cy.nl.un_420 fi.sw.sl_543
  // [49f0]
  0x12081fad, 0x1f002722, 0x032928a7, 0x06130c13,   // cy.no.hu_643 gd.cy.un_870  sw.sl.nl_532 sv.et.de_665
  0x550368a6, 0x051108af, 0x06000108, 0x13000307,   // ig.nl.rw_521 no.ro.fr_655  en.de.un_430 nl.et.un_420
  0x06000c29, 0x311b1220, 0x23000610, 0x291302ee,   // sv.de.un_960 hu.tr.az_875  de.ca.un_620 da.et.sl_422
  0x03043f5a, 0x1f003f14, 0x0c002004, 0x27003b04,   // af.fi.nl_553 af.cy.un_660  sq.sv.un_320 so.gd.un_320
  // [4a00]
  0x4a00351b, 0x060108a4, 0x3f060f12, 0x03000614,   // zu.yo.un_770 no.en.de_433  lv.de.af_654 de.nl.un_660
  0x31001702, 0x232a0514, 0x01003f09, 0x52283fa9,   // sr.az.un_220 fr.mt.ca_666  af.en.un_440 af.sw.ha_544
  0x1a4a680c, 0x64312808, 0x030501a4, 0x271819a9,   // ig.yo.tl_543 sw.az.lg_443  en.fr.nl_433 gl.ga.gd_544
  0x326428a6, 0x283b520c, 0x130e0b04, 0x1e1c28ee,   // sw.lg.bs_521 ha.so.sw_543  es.is.et_332 sw.id.ms_422
  // [4a10]
  0x04002109, 0x0764550c, 0x3100061b, 0x3f0f10ad,   // jw.fi.un_440 rw.lg.it_543  de.az.un_770 lt.lv.af_643
  0x1e003b0d, 0x0f2d10af, 0x112d64ad, 0x18190b5a,   // so.ms.un_540 lt.sk.lv_655  lg.sk.ro_643 es.gl.ga_553
  0x20071aad, 0x190b280c, 0x556b2508, 0x06030204,   // tl.it.sq_643 sw.es.gl_543  eu.ceb.rw_443 da.nl.de_332
  0x13551e07, 0x111b0b02, 0x0e5220ee, 0x1c090d0b,   // ms.rw.et_432 es.tr.ro_222  sq.ha.is_422 ne.hi.mr_542
  // [4a20]
  0x35080208, 0x0d1c090b, 0x4a00281a, 0x180301a6,   // da.no.zu_443 hi.mr.ne_542  sw.yo.un_760 en.nl.ga_521
  0x190b07a4, 0x20001e02, 0x35091f05, 0x211a6b14,   // it.es.gl_433 ms.sq.un_220  cy.pl.zu_333 ceb.tl.jw_666
  0x6b001109, 0x0f3f035a, 0x0108020d, 0x0c25020c,   // ro.ceb.un_440 nl.af.lv_553  da.no.en_554 da.eu.sv_543
  0x066b550d, 0x08251108, 0x09000f22, 0x130d09a4,   // rw.ceb.de_554 ro.eu.no_443  lv.pl.un_870 hi.ne.bh_433
  // [4a30]
  0x3b3f35ad, 0x2d00290b, 0x1b643b5a, 0x021a1213,   // zu.af.so_643 sl.sk.un_520  so.lg.tr_553 hu.tl.da_665
  0x5525520c, 0x082d0d0b, 0x0e2d19af, 0x3b126bad,   // ha.eu.rw_543 cs.sk.no_542  gl.sk.is_655 ceb.hu.so_643
  0x09002304, 0x523b2a07, 0x09001121, 0x3b3f64af,   // ca.pl.un_320 mt.so.ha_432  ro.pl.un_860 lg.af.so_655
  0x285355ec, 0x353b1aa4, 0x251203a7, 0x2801180c,   // rw.ht.sw_644 tl.so.zu_433  nl.hu.eu_532 ga.en.sw_543
  // [4a40]
  0x2300531a, 0x17292d0c, 0x1c163bee, 0x3b1e1c0c,   // ht.ca.un_760 sk.sl.sr_543  so.hr.id_422 id.ms.so_543
  0x0000042d, 0x19230ba0, 0x0e003f14, 0x29006b21,   // ru.un.un_A00 es.ca.gl_322  af.is.un_660 ceb.sl.un_860
  0x110417af, 0x552864a4, 0x23001114, 0x081b0c11,   // sr.ru.ro_655 lg.sw.rw_433  ro.ca.un_660 sv.tr.no_653
  0x1300031a, 0x250a280c, 0x17000702, 0x0c003509,   // nl.et.un_760 sw.pt.eu_543  bg.sr.un_220 zu.sv.un_440
  // [4a50]
  0x04170802, 0x072305a4, 0x0d004a0d, 0x02000d08,   // uk.sr.ru_222 fr.ca.it_433  yo.cs.un_540 cs.da.un_430
  0x2d091f11, 0x04190a13, 0x28011807, 0x11033f0c,   // cy.pl.sk_653 pt.gl.fi_665  ga.en.sw_432 af.nl.ro_543
  0x6b68010c, 0x4a2b0ead, 0x040a08ad, 0x133f0aaf,   // en.ig.ceb_543 is.vi.yo_643  uk.mk.ru_643 pt.af.et_655
  0x2d191008, 0x532d090c, 0x182704ad, 0x23072004,   // lt.gl.sk_443 pl.sk.ht_543  fi.gd.ga_643 sq.it.ca_332
  // [4a60]
  0x120c28a4, 0x05000422, 0x0c521b0c, 0x04130ca6,   // sw.sv.hu_433 fi.fr.un_870  tr.ha.sv_543 sv.et.fi_521
  0x3b281aad, 0x283b6412, 0x04170a02, 0x05033f0c,   // tl.sw.so_643 lg.so.sw_654  mk.sr.ru_222 af.nl.fr_543
  0x2010530c, 0x55005212, 0x322852a7, 0x2800520c,   // ht.lt.sq_543 ha.rw.un_640  ha.sw.bs_532 ha.sw.un_530
  0x16090dad, 0x68641a11, 0x52003b21, 0x09282d09,   // cs.pl.hr_643 tl.lg.ig_653  so.ha.un_860 sk.sw.pl_444
  // [4a70]
  0x1a556bad, 0x06005212, 0x1200200d, 0x531a6baf,   // ceb.rw.tl_643 ha.de.un_640  sq.hu.un_540 ceb.tl.ht_655
  0x3f001819, 0x4a005202, 0x212852ec, 0x35211e0c,   // ga.af.un_750 ha.yo.un_220  ha.sw.jw_644 ms.jw.zu_543
  0x533528ad, 0x0f13040d, 0x6b092107, 0x07271808,   // sw.zu.ht_643 fi.et.lv_554  jw.pl.ceb_432 ga.gd.it_443
  0x04006b08, 0x55643513, 0x1a282105, 0x5200101a,   // ceb.fi.un_430 zu.lg.rw_665  jw.sw.tl_333 lt.ha.un_760
  // [4a80]
  0x25001309, 0x23001f05, 0x1000080e, 0x0f002808,   // et.eu.un_440 cy.ca.un_330  uk.be.un_550 sw.lv.un_430
  0x122d0d08, 0x320e280c, 0x35645204, 0x28005533,   // cs.sk.hu_443 sw.is.bs_543  ha.lg.zu_332 rw.sw.un_A70
  0x12001e11, 0x10001321, 0x10040805, 0x4a6825af,   // ms.hu.un_630 et.lt.un_860  uk.ru.be_333 eu.ig.yo_655
  0x18002307, 0x6e001022, 0x21321608, 0x0c1f08a9,   // ca.ga.un_420 lt.hmn.un_870  hr.bs.jw_443 no.cy.sv_544
  // [4a90]
  0x190b5505, 0x0a1b2355, 0x210e1fa0, 0x645228a9,   // rw.es.gl_333 ca.tr.pt_442  cy.is.jw_322 sw.ha.lg_544
  0x0c2a0208, 0x5528680c, 0x55645213, 0x35642755,   // da.mt.sv_443 ig.sw.rw_543  ha.lg.rw_665 gd.lg.zu_442
  0x05000309, 0x2a1e32a0, 0x13680fa4, 0x52285508,   // nl.fr.un_440 bs.ms.mt_322  lv.ig.et_433 rw.sw.ha_443
  0x521e31a7, 0x13002514, 0x286855a4, 0x2012550c,   // az.ms.ha_532 eu.et.un_660  rw.ig.sw_433 rw.hu.sq_543
  // [4aa0]
  0x21003b0b, 0x25006821, 0x522755ee, 0x133564ee,   // so.jw.un_520 ig.eu.un_860  rw.gd.ha_422 lg.zu.et_422
  0x1f033f13, 0x10081705, 0x3b2a0712, 0x2d0d5205,   // af.nl.cy_665 sr.uk.be_333  it.mt.so_654 ha.cs.sk_333
  0x641a550c, 0x11200e0c, 0x075564ad, 0x21000312,   // rw.tl.lg_543 is.sq.ro_543  lg.rw.it_643 nl.jw.un_640
  0x0a081104, 0x311e55ee, 0x02080c13, 0x213f1355,   // ro.uk.mk_332 rw.ms.az_422  sv.no.da_665 et.af.jw_442
  // [4ab0]
  0x110805a4, 0x2a001b13, 0x1a003b1b, 0x230e0c12,   // fr.no.ro_433 tr.mt.un_650  so.tl.un_770 sv.is.ca_654
  0x0c1827a9, 0x2303010c, 0x17100a0b, 0x1c090d02,   // gd.ga.sv_544 en.nl.ca_543  mk.be.sr_542 ne.hi.mr_222
  0x1e00250e, 0x04002d04, 0x20001e08, 0x06020304,   // eu.ms.un_550 sk.fi.un_320  ms.sq.un_430 nl.da.de_332
  0x28002a0b, 0x17100704, 0x20000c0c, 0x032b0804,   // mt.sw.un_520 bg.be.sr_332  sv.sq.un_530 no.vi.nl_332
  // [4ac0]
  0x0e002304, 0x3b122a02, 0x1a1e0804, 0x321629a0,   // ca.is.un_320 mt.hu.so_222  no.ms.tl_332 sl.hr.bs_322
  0x32170fa4, 0x132a12ad, 0x08000e07, 0x0e081f0b,   // lv.sr.bs_433 hu.mt.et_643  is.no.un_420 cy.no.is_542
  0x08112bee, 0x0c104aa7, 0x163168a4, 0x11041005,   // vi.ro.no_422 yo.lt.sv_532  ig.az.hr_433 be.ru.ro_333
  0x01001307, 0x1f080208, 0x212d05a7, 0x130f04ec,   // et.en.un_420 da.no.cy_443  fr.sk.jw_532 fi.lv.et_644
  // [4ad0]
  0x32552907, 0x64001c02, 0x012123ee, 0x23311bad,   // sl.rw.bs_432 id.lg.un_220  ca.jw.en_422 tr.az.ca_643
  0x2b000302, 0x64080ca7, 0x1b321608, 0x3b0117a0,   // nl.vi.un_220 sv.no.lg_532  hr.bs.tr_443 sr.en.so_322
  0x100f01a4, 0x082d1f07, 0x21251eaf, 0x13351ea4,   // en.lv.lt_433 cy.sk.no_432  ms.eu.jw_655 ms.zu.et_433
  0x5500130e, 0x10190a09, 0x12351bee, 0x070553a4,   // et.rw.un_550 pt.gl.lt_444  tr.zu.hu_422 ht.fr.it_433
  // [4ae0]
  0x1f283504, 0x6400550b, 0x12172004, 0x6b2a0a55,   // zu.sw.cy_332 rw.lg.un_520  sq.sr.hu_332 pt.mt.ceb_442
  0x32350607, 0x12205508, 0x12645512, 0x2d172304,   // de.zu.bs_432 rw.sq.hu_443  rw.lg.hu_654 ca.sr.sk_332
  0x211a250c, 0x18002b04, 0x553b2da0, 0x3f001608,   // eu.tl.jw_543 vi.ga.un_320  sk.so.rw_322 hr.af.un_430
  0x1213100c, 0x521b3112, 0x20323507, 0x1664555a,   // lt.et.hu_543 az.tr.ha_654  zu.bs.sq_432 rw.lg.hr_553
  // [4af0]
  0x23120dee, 0x01190a0c, 0x4a64550d, 0x1f521aa4,   // cs.hu.ca_422 pt.gl.en_543  rw.lg.yo_554 tl.ha.cy_433
  0x1a525508, 0x6400552c, 0x523b1e12, 0x2a000919,   // rw.ha.tl_443 rw.lg.un_990  ms.so.ha_654 pl.mt.un_750
  0x3264250c, 0x20002102, 0x64251ba4, 0x25645511,   // eu.lg.bs_543 jw.sq.un_220  tr.eu.lg_433 rw.lg.eu_653
  0x09000c19, 0x29556412, 0x08025302, 0x32005508,   // sv.pl.un_750 lg.rw.sl_654  ht.da.no_222 rw.bs.un_430
  // [4b00]
  0x213b1ea4, 0x033f10a4, 0x1900130d, 0x0c4a5208,   // ms.so.jw_433 lt.af.nl_433  et.gl.un_540 ha.yo.sv_443
  0x2b120608, 0x16645508, 0x09000319, 0x03133f0d,   // de.hu.vi_443 rw.lg.hr_443  nl.pl.un_750 af.et.nl_554
  0x01061f07, 0x5500642c, 0x4a686b07, 0x534a5512,   // cy.de.en_432 lg.rw.un_990  ceb.ig.yo_432 rw.yo.ht_654
  0x1900050b, 0x112955a4, 0x120e2d12, 0x011905a4,   // fr.gl.un_520 rw.sl.ro_433  sk.is.hu_654 fr.gl.en_433
  // [4b10]
  0x31203b07, 0x010a0455, 0x0a3b200c, 0x09001012,   // so.sq.az_432 fi.pt.en_442  sq.so.pt_543 lt.pl.un_640
  0x1a001e08, 0x25550407, 0x16041312, 0x13045505,   // ms.tl.un_430 fi.rw.eu_432  et.fi.hr_654 rw.fi.et_333
  0x213b1aa7, 0x32002a07, 0x20352107, 0x553513ee,   // tl.so.jw_532 mt.bs.un_420  jw.zu.sq_432 et.zu.rw_422
  0x52201312, 0x1c00092c, 0x0a17080d, 0x531a1255,   // et.sq.ha_654 hi.mr.un_990  uk.sr.mk_554 hu.tl.ht_442
  // [4b20]
  0x35125505, 0x103217a6, 0x19520ea4, 0x35251a05,   // rw.hu.zu_333 sr.bs.lt_521  is.ha.gl_433 tl.eu.zu_333
  0x0a04085a, 0x0a190b11, 0x293203ee, 0x534a52ee,   // uk.ru.mk_553 es.gl.pt_653  nl.bs.sl_422 ha.yo.ht_422
  0x3b211c0d, 0x01040555, 0x07000c0e, 0x64006805,   // id.jw.so_554 fr.fi.en_442  sv.it.un_550 ig.lg.un_330
  0x3500251a, 0x17100a11, 0x68641aa4, 0x19230b0b,   // eu.zu.un_760 mk.be.sr_653  tl.lg.ig_433 es.ca.gl_542
  // [4b30]
  0x193b0bee, 0x13005504, 0x1b001902, 0x2004550c,   // es.so.gl_422 rw.et.un_320  gl.tr.un_220 rw.fi.sq_543
  0x21006404, 0x1e271813, 0x643529a4, 0x35001314,   // lg.jw.un_320 ga.gd.ms_665  sl.zu.lg_433 et.zu.un_660
  0x64191aa0, 0x17352904, 0x162d07a0, 0x086420a0,   // tl.gl.lg_322 sl.zu.sr_332  it.sk.hr_322 sq.lg.no_322
  0x1e0903a4, 0x031b53ad, 0x31080205, 0x68001b04,   // nl.pl.ms_433 ht.tr.nl_643  da.no.az_333 tr.ig.un_320
  // [4b40]
  0x10005204, 0x2d0d1aee, 0x291613a7, 0x6b1a3bec,   // ha.lt.un_320 tl.cs.sk_422  et.hr.sl_532 so.tl.ceb_644
  0x052d0d0d, 0x123f0c0c, 0x321855a4, 0x35001e04,   // cs.sk.fr_554 sv.af.hu_543  rw.ga.bs_433 ms.zu.un_320
  0x55290713, 0x060b2004, 0x29160407, 0x28295507,   // it.sl.rw_665 sq.es.de_332  fi.hr.sl_432 rw.sl.sw_432
  0x23190507, 0x28642307, 0x0e6b1a02, 0x01000507,   // fr.gl.ca_432 ca.lg.sw_432  tl.ceb.is_222 fr.en.un_420
  // [4b50]
  0x2d250a05, 0x0a23050b, 0x190b0e05, 0x11001904,   // pt.eu.sk_333 fr.ca.pt_542  is.es.gl_333 gl.ro.un_320
  0x08120c05, 0x080e2aec, 0x04101713, 0x1b000b05,   // sv.hu.no_333 mt.is.no_644  sr.be.ru_665 es.tr.un_330
  0x35006402, 0x55093bee, 0x3b002714, 0x0d292dec,   // lg.zu.un_220 so.pl.rw_422  gd.so.un_660 sk.sl.cs_644
  0x28011fee, 0x2a042da9, 0x2b006b12, 0x321c2aee,   // cy.en.sw_422 sk.fi.mt_544  ceb.vi.un_640 mt.id.bs_422
  // [4b60]
  0x1c2b0aac, 0x1923050b, 0x3f27280c, 0x0b0928a4,   // pt.vi.id_632 fr.ca.gl_542  sw.gd.af_543 sw.pl.es_433
  0x2d292aec, 0x6b1a6807, 0x27006b08, 0x6b2d07a0,   // mt.sl.sk_644 ig.tl.ceb_432  ceb.gd.un_430 it.sk.ceb_322
  0x06000e21, 0x25000b04, 0x020c0855, 0x01000602,   // is.de.un_860 es.eu.un_320  no.sv.da_442 de.en.un_220
  0x013f03ad, 0x2d2029ad, 0x2a080e07, 0x2a002b05,   // nl.af.en_643 sl.sq.sk_643  is.no.mt_432 vi.mt.un_330
  // [4b70]
  0x033f4aac, 0x29000f0e, 0x09002d0d, 0x64076802,   // yo.af.nl_632 lv.sl.un_550  sk.pl.un_540 ig.it.lg_222
  0x0d2d290d, 0x64000307, 0x022b0aec, 0x0e030ca7,   // sl.sk.cs_554 nl.lg.un_420  pt.vi.da_644 sv.nl.is_532
  0x13080260, 0x0a1e0113, 0x012b3bee, 0x0c1009a4,   // da.no.et_664 en.ms.pt_665  so.vi.en_422 pl.lt.sv_433
  0x13000d19, 0x016b08a0, 0x3b033f05, 0x290d17a9,   // ne.bh.un_750 no.ceb.en_322  af.nl.so_333 sr.cs.sl_544
  // [4b80]
  0x07093fa4, 0x3f000e14, 0x022b1207, 0x0e002d1a,   // af.pl.it_433 is.af.un_660  hu.vi.da_432 sk.is.un_760
  0x27080e04, 0x233101a4, 0x230a01a4, 0x21250e05,   // is.no.gd_332 en.az.ca_433  en.pt.ca_433 is.eu.jw_333
  0x181f280c, 0x2d0d28a9, 0x0f351304, 0x031827ec,   // sw.cy.ga_543 sw.cs.sk_544  et.zu.lv_332 gd.ga.nl_644
  0x0f0706a9, 0x13001907, 0x05275307, 0x6811060c,   // de.it.lv_544 gl.et.un_420  ht.gd.fr_432 de.ro.ig_543
  // [4b90]
  0x04191113, 0x190a05a4, 0x0a051912, 0x641f3504,   // ro.gl.fi_665 fr.pt.gl_433  gl.fr.pt_654 zu.cy.lg_332
  0x3f035309, 0x0f2913ee, 0x0c2927a7, 0x6400280c,   // ht.nl.af_444 et.sl.lv_422  gd.sl.sv_532 sw.lg.un_530
  0x11033f12, 0x032b010c, 0x2d0d06ac, 0x060501a4,   // af.nl.ro_654 en.vi.nl_543  de.cs.sk_632 en.fr.de_433
  0x05010d09, 0x050d53ad, 0x6800060d, 0x030928a0,   // cs.en.fr_444 ht.cs.fr_643  de.ig.un_540 sw.pl.nl_322
  // [4ba0]
  0x526b1a60, 0x0d2d1213, 0x0d555209, 0x6b4a350d,   // tl.ceb.ha_664 hu.sk.cs_665  ha.rw.cs_444 zu.yo.ceb_554
  0x25005304, 0x256b1ca0, 0x0f003b12, 0x291e1c08,   // ht.eu.un_320 id.ceb.eu_322  so.lv.un_640 id.ms.sl_443
  0x1f0135a4, 0x210f1c09, 0x21551f0c, 0x6b250a07,   // zu.en.cy_433 id.lv.jw_444  cy.rw.jw_543 pt.eu.ceb_432
  0x3b072a11, 0x0b0a01ee, 0x12322804, 0x2d001211,   // mt.it.so_653 en.pt.es_422  sw.bs.hu_332 hu.sk.un_630
  // [4bb0]
  0x0a0c3b0b, 0x53006e07, 0x201a280c, 0x080206a9,   // so.sv.pt_542 hmn.ht.un_420  sw.tl.sq_543 de.da.no_544
  0x64045211, 0x35250ba4, 0x2800270e, 0x31002308,   // ha.fi.lg_653 es.eu.zu_433  gd.sw.un_550 ca.az.un_430
  0x042d0da4, 0x02000513, 0x2a290f12, 0x09006404,   // cs.sk.fi_433 fr.da.un_650  lv.sl.mt_654 lg.pl.un_320
  0x073125a9, 0x281b2007, 0x2168280c, 0x25120107,   // eu.az.it_544 sq.tr.sw_432  sw.ig.jw_543 en.hu.eu_432
  // [4bc0]
  0x1b072a5a, 0x3f020312, 0x0a071ca4, 0x10000a02,   // mt.it.tr_553 nl.da.af_654  id.it.pt_433 mk.be.un_220
  0x17000822, 0x06070413, 0x17101112, 0x0500070e,   // uk.sr.un_870 fi.it.de_665  ro.be.sr_654 it.fr.un_550
  0x17111012, 0x3516280c, 0x2a080e11, 0x033f01af,   // be.ro.sr_654 sw.hr.zu_543  is.no.mt_653 en.af.nl_655
  0x1c1353ee, 0x0a2d19a0, 0x1b093bad, 0x64000f19,   // ht.et.id_422 gl.sk.pt_322  so.pl.tr_643 lv.lg.un_750
  // [4bd0]
  0x12001e02, 0x1b2d090c, 0x64356b07, 0x0b0a2305,   // ms.hu.un_220 pl.sk.tr_543  ceb.zu.lg_432 ca.pt.es_333
  0x6b003505, 0x046b130c, 0x0c1e3511, 0x4a5535ad,   // zu.ceb.un_330 et.ceb.fi_543  zu.ms.sv_653 zu.rw.yo_643
  0x0d092da0, 0x1c0d1ea0, 0x211e1b07, 0x55352804,   // sk.pl.cs_322 ms.cs.id_322  tr.ms.jw_432 sw.zu.rw_332
  0x04000711, 0x55316407, 0x322b12ad, 0x0c235507,   // bg.ru.un_630 lg.az.rw_432  hu.vi.bs_643 rw.ca.sv_432
  // [4be0]
  0x55003512, 0x32290fa4, 0x1900120b, 0x093b5213,   // zu.rw.un_640 lv.sl.bs_433  hu.gl.un_520 ha.so.pl_665
  0x046b1a0c, 0x1f00180d, 0x526b090c, 0x4a2135ec,   // tl.ceb.fi_543 ga.cy.un_540  pl.ceb.ha_543 zu.jw.yo_644
  0x35002707, 0x53006b08, 0x211b53ee, 0x3b001c04,   // gd.zu.un_420 ceb.ht.un_430  ht.tr.jw_422 id.so.un_320
  0x0f2305a4, 0x05000c1a, 0x2b001c09, 0x171007af,   // fr.ca.lv_433 sv.fr.un_760  id.vi.un_440 bg.be.sr_655
  // [4bf0]
  0x182729ad, 0x2a531c0c, 0x171104a4, 0x1c006b0d,   // sl.gd.ga_643 id.ht.mt_543  ru.ro.sr_433 ceb.id.un_540
  0x08000f12, 0x2d100d05, 0x320f2308, 0x11002905,   // lv.no.un_640 cs.lt.sk_333  ca.lv.bs_443 sl.ro.un_330
  0x03133f09, 0x13211a04, 0x023f08a6, 0x133f1f04,   // af.et.nl_444 tl.jw.et_332  no.af.da_521 cy.af.et_332
  0x292d1607, 0x290f1f12, 0x64000305, 0x35131a09,   // hr.sk.sl_432 cy.lv.sl_654  nl.lg.un_330 tl.et.zu_444

  // [4c00]
  0x1e1c27a0, 0x233f2aee, 0x230f05a4, 0x20121fec,   // gd.id.ms_322 mt.af.ca_422  fr.lv.ca_433 cy.hu.sq_644
  0x230105a4, 0x0f1035ac, 0x1b3f060c, 0x19211c0c,   // fr.en.ca_433 zu.lt.lv_632  de.af.tr_543 id.jw.gl_543
  0x25005514, 0x23000b1b, 0x17001f0c, 0x1b000d04,   // rw.eu.un_660 es.ca.un_770  cy.sr.un_530 cs.tr.un_320
  0x1b3113ad, 0x0a0e2855, 0x13001e20, 0x0c6b08a4,   // et.az.tr_643 sw.is.pt_442  ms.et.un_850 no.ceb.sv_433
  // [4c10]
  0x0e10250c, 0x2800350e, 0x5300281b, 0x5335090c,   // eu.lt.is_543 zu.sw.un_550  sw.ht.un_770 pl.zu.ht_543
  0x0b23190d, 0x0e0b02ad, 0x11100da0, 0x0f002522,   // gl.ca.es_554 da.es.is_643  cs.lt.ro_322 eu.lv.un_870
  0x3b286407, 0x08101112, 0x2d091aaf, 0x52002504,   // lg.sw.so_432 ro.be.uk_654  tl.pl.sk_655 eu.ha.un_320
  0x55641b04, 0x07101705, 0x0f1008a0, 0x232d0704,   // tr.lg.rw_332 sr.be.bg_333  no.lt.lv_322 it.sk.ca_332
  // [4c20]
  0x093f06a4, 0x2b00350c, 0x55004a0d, 0x11000707,   // de.af.pl_433 zu.vi.un_530  yo.rw.un_540 it.ro.un_420
  0x1a1b1f0c, 0x3f2b2107, 0x2500131a, 0x020c0a0c,   // cy.tr.tl_543 jw.vi.af_432  et.eu.un_760 pt.sv.da_543
  0x1f001e22, 0x042853af, 0x100f130c, 0x102518ad,   // ms.cy.un_870 ht.sw.fi_655  et.lv.lt_543 ga.eu.lt_643
  0x096b3bee, 0x121a05ad, 0x080203ee, 0x170a08af,   // so.ceb.pl_422 fr.tl.hu_643  nl.da.no_422 uk.mk.sr_655
  // [4c30]
  0x6b181aee, 0x11270555, 0x521e25ad, 0x295310a4,   // tl.ga.ceb_422 fr.gd.ro_442  eu.ms.ha_643 lt.ht.sl_433
  0x1f002522, 0x12056b07, 0x190f2512, 0x06041207,   // eu.cy.un_870 ceb.fr.hu_432  eu.lv.gl_654 hu.fi.de_432
  0x080e2b02, 0x20251a13, 0x04002a0c, 0x3b000411,   // vi.is.no_222 tl.eu.sq_665  mt.fi.un_530 fi.so.un_630
  0x20352813, 0x270f04a0, 0x681f0faf, 0x1c002a04,   // sw.zu.sq_665 fi.lv.gd_322  lv.cy.ig_655 mt.id.un_320
  // [4c40]
  0x122005ad, 0x1f04180d, 0x05001213, 0x0a0804af,   // fr.sq.hu_643 ga.fi.cy_554  hu.fr.un_650 ru.uk.mk_655
  0x3b003202, 0x203b5555, 0x12310513, 0x6b1a2105,   // bs.so.un_220 rw.so.sq_442  fr.az.hu_665 jw.tl.ceb_333
  0x52002021, 0x09002b14, 0x2000552a, 0x131c0960,   // sq.ha.un_860 vi.pl.un_660  rw.sq.un_970 hi.mr.bh_664
  0x321729a0, 0x13000902, 0x033f0e55, 0x6b2128ee,   // sl.sr.bs_322 hi.bh.un_220  is.af.nl_442 sw.jw.ceb_422
  // [4c50]
  0x202852ec, 0x2b0d2da7, 0x1104085a, 0x23002b1a,   // ha.sw.sq_644 sk.cs.vi_532  uk.ru.ro_553 vi.ca.un_760
  0x0c000b02, 0x21642807, 0x2a001a0c, 0x20132311,   // es.sv.un_220 sw.lg.jw_432  tl.mt.un_530 ca.et.sq_653
  0x2500351a, 0x550f050b, 0x080207ee, 0x2d1029a4,   // zu.eu.un_760 fr.lv.rw_542  it.da.no_422 sl.lt.sk_433
  0x0107030c, 0x2a000e12, 0x3521280c, 0x08003b2c,   // nl.it.en_543 is.mt.un_640  sw.jw.zu_543 so.no.un_990
  // [4c60]
  0x643b52af, 0x04351313, 0x05032308, 0x201f27af,   // ha.so.lg_655 et.zu.fi_665  ca.nl.fr_443 gd.cy.sq_655
  0x28002133, 0x17000b08, 0x32001a07, 0x0604180c,   // jw.sw.un_A70 es.sr.un_430  tl.bs.un_420 ga.fi.de_543
  0x1a0507a4, 0x4a000a12, 0x100f0c11, 0x0c0e0405,   // it.fr.tl_433 pt.yo.un_640  sv.lv.lt_653 fi.is.sv_333
  0x03181c02, 0x316452ad, 0x1205010c, 0x0a08110c,   // id.ga.nl_222 ha.lg.az_643  en.fr.hu_543 ro.uk.mk_543
  // [4c70]
  0x06200705, 0x070e1fa4, 0x20005313, 0x190a1fa9,   // it.sq.de_333 cy.is.it_433  ht.sq.un_650 cy.pt.gl_544
  0x643b5213, 0x07001f0e, 0x3255520c, 0x01003204,   // ha.so.lg_665 cy.it.un_550  ha.rw.bs_543 bs.en.un_320
  0x101107a4, 0x0a006b07, 0x16205507, 0x033f64ee,   // bg.ro.be_433 ceb.pt.un_420  rw.sq.hr_432 lg.af.nl_422
  0x210a1ba0, 0x20000108, 0x13001f07, 0x2a001222,   // tr.pt.jw_322 en.sq.un_430  cy.et.un_420 hu.mt.un_870
  // [4c80]
  0x13040aa0, 0x1b03060c, 0x06001c02, 0x0a190b0b,   // pt.fi.et_322 de.nl.tr_543  id.de.un_220 es.gl.pt_542
  0x052307ee, 0x17291e05, 0x5200352c, 0x06006b0e,   // it.ca.fr_422 ms.sl.sr_333  zu.ha.un_990 ceb.de.un_550
  0x1000061b, 0x29001613, 0x641c2113, 0x1c091310,   // de.lt.un_770 hr.sl.un_650  jw.id.lg_665 bh.hi.mr_642
  0x2b6b01ee, 0x212027ee, 0x2d050a55, 0x3f2301ad,   // en.ceb.vi_422 gd.sq.jw_422  pt.fr.sk_442 en.ca.af_643
  // [4c90]
  0x1a2b6b04, 0x17001608, 0x082701ad, 0x271f1808,   // ceb.vi.tl_332 hr.sr.un_430  en.gd.no_643 ga.cy.gd_443
  0x01076b08, 0x0c522155, 0x253f3b11, 0x136804ee,   // ceb.it.en_443 jw.ha.sv_442  so.af.eu_653 fi.ig.et_422
  0x03041ea4, 0x04000322, 0x045210a7, 0x1a1364ee,   // ms.fi.nl_433 nl.fi.un_870  lt.ha.fi_532 lg.et.tl_422
  0x0e1806ad, 0x4a351308, 0x19170b55, 0x32291605,   // de.ga.is_643 et.zu.yo_443  es.sr.gl_442 hr.sl.bs_333
  // [4ca0]
  0x3f13030d, 0x0e6b1a5a, 0x10000a23, 0x3f001c08,   // nl.et.af_554 tl.ceb.is_553  mk.be.un_880 id.af.un_430
  0x1c3b1ea0, 0x1a64115a, 0x08354aad, 0x1e1a110c,   // ms.so.id_322 ro.lg.tl_553  yo.zu.no_643 ro.tl.ms_543
  0x0d001008, 0x025208a0, 0x290d17a4, 0x6b1a110c,   // lt.cs.un_430 no.ha.da_322  sr.cs.sl_433 ro.tl.ceb_543
  0x3f1b21ad, 0x1b000312, 0x6b1a350d, 0x1c2111a7,   // jw.tr.af_643 nl.tr.un_640  zu.tl.ceb_554 ro.jw.id_532
  // [4cb0]
  0x211c35ee, 0x6b112108, 0x25002802, 0x11006419,   // zu.id.jw_422 jw.ro.ceb_443  sw.eu.un_220 lg.ro.un_750
  0x111a640c, 0x13044aa4, 0x0e6421a9, 0x643b280e,   // lg.tl.ro_543 yo.fi.et_433  jw.lg.is_544 sw.so.lg_555
  0x046864af, 0x3125110c, 0x1b3f030c, 0x1a0b6b04,   // lg.ig.fi_655 ro.eu.az_543  nl.af.tr_543 ceb.es.tl_332
  0x041e1c07, 0x311135a4, 0x1c006e08, 0x03130604,   // id.ms.fi_432 zu.ro.az_433  hmn.id.un_430 de.et.nl_332
  // [4cc0]
  0x25005504, 0x2100110c, 0x08021ca0, 0x201b0e09,   // rw.eu.un_320 ro.jw.un_530  id.da.no_322 is.tr.sq_444
  0x311b1112, 0x111e520d, 0x11002504, 0x28070605,   // ro.tr.az_654 ha.ms.ro_554  eu.ro.un_320 de.it.sw_333
  0x03001705, 0x2506130c, 0x0a0208a4, 0x52002012,   // sr.nl.un_330 et.de.eu_543  no.da.pt_433 sq.ha.un_640
  0x08012307, 0x64000104, 0x04130c0d, 0x0f002a07,   // ca.en.no_432 en.lg.un_320  sv.et.fi_554 mt.lv.un_420
  // [4cd0]
  0x06232511, 0x08320c07, 0x030a2560, 0x1c1b0ea4,   // eu.ca.de_653 sv.bs.no_432  eu.pt.nl_664 is.tr.id_433
  0x64550b08, 0x0000192d, 0x1a004a0c, 0x1b2a25a0,   // es.rw.lg_443 gl.un.un_A00  yo.tl.un_530 eu.mt.tr_322
  0x200208a4, 0x6b061fa7, 0x063f6413, 0x0b681805,   // no.da.sq_433 cy.de.ceb_532  lg.af.de_665 ga.ig.es_333
  0x2a002807, 0x201205af, 0x551a6b0c, 0x2d0d0b14,   // sw.mt.un_420 fr.hu.sq_655  ceb.tl.rw_543 es.cs.sk_666
  // [4ce0]
  0x6452210c, 0x130520ad, 0x3f0123a7, 0x085507a0,   // jw.ha.lg_543 sq.fr.et_643  ca.en.af_532 it.rw.no_322
  0x03160ea0, 0x16170dad, 0x04283504, 0x0e270813,   // is.hr.nl_322 cs.sr.hr_643  zu.sw.fi_332 no.gd.is_665
  0x0b2d0d14, 0x13043555, 0x01006407, 0x13004a02,   // cs.sk.es_666 zu.fi.et_442  lg.en.un_420 yo.et.un_220
  0x030805a0, 0x13002005, 0x35132811, 0x08250e04,   // fr.no.nl_322 sq.et.un_330  sw.et.zu_653 is.eu.no_332
  // [4cf0]
  0x68005219, 0x0c552812, 0x1f353f12, 0x105525af,   // ha.ig.un_750 sw.rw.sv_654  af.zu.cy_654 eu.rw.lt_655
  0x1a316b09, 0x68100f07, 0x2507130c, 0x256b290c,   // ceb.az.tl_444 lv.lt.ig_432  et.it.eu_543 sl.ceb.eu_543
  0x0b000718, 0x07286b08, 0x25106ba4, 0x06211e12,   // it.es.un_740 ceb.sw.it_443  ceb.lt.eu_433 ms.jw.de_654
  0x0600210e, 0x08006b04, 0x2b210612, 0x4a0b20af,   // jw.de.un_550 ceb.no.un_320  de.jw.vi_654 sq.es.yo_655
  // [4d00]
  0x09532da4, 0x25002813, 0x32040f05, 0x2a04100c,   // sk.ht.pl_433 sw.eu.un_650  lv.fi.bs_333 lt.fi.mt_543
  0x532a6ba0, 0x530f0405, 0x13256bac, 0x13042a0d,   // ceb.mt.ht_322 fi.lv.ht_333  ceb.eu.et_632 mt.fi.et_554
  0x0e00201b, 0x1e0425ad, 0x0f2853a4, 0x52002123,   // sq.is.un_770 eu.fi.ms_643  ht.sw.lv_433 jw.ha.un_880
  0x1f000307, 0x310c02ad, 0x321653ee, 0x1c121ea0,   // nl.cy.un_420 da.sv.az_643  ht.hr.bs_422 ms.hu.id_322
  // [4d10]
  0x080229ec, 0x061c21ad, 0x2100060c, 0x2100060e,   // sl.da.no_644 jw.id.de_643  de.jw.un_530 de.jw.un_550
  0x1c351e08, 0x1e211cad, 0x55001a09, 0x3b3513ee,   // ms.zu.id_443 id.jw.ms_643  tl.rw.un_440 et.zu.so_422
  0x530304ad, 0x04523bad, 0x10032aaf, 0x250f4aa4,   // fi.nl.ht_643 so.ha.fi_643  mt.nl.lt_655 yo.lv.eu_433
  0x521a1c07, 0x1e002102, 0x1f00090d, 0x27011804,   // id.tl.ha_432 jw.ms.un_220  pl.cy.un_540 ga.en.gd_332
  // [4d20]
  0x0b6b4aee, 0x17162da4, 0x200a0b07, 0x0d001614,   // yo.ceb.es_422 sk.hr.sr_433  es.pt.sq_432 hr.cs.un_660
  0x2b182d07, 0x3b12350c, 0x02001e02, 0x11001907,   // sk.ga.vi_432 zu.hu.so_543  ms.da.un_220 gl.ro.un_420
  0x2d0d32a9, 0x21093ba0, 0x12002b0c, 0x6b6831ad,   // bs.cs.sk_544 so.pl.jw_322  vi.hu.un_530 az.ig.ceb_643
  0x1104530c, 0x0e06035a, 0x31250fa9, 0x4a0b28a4,   // ht.fi.ro_543 nl.de.is_553  lv.eu.az_544 sw.es.yo_433
  // [4d30]
  0x190b11af, 0x2d0d0b0e, 0x08004a07, 0x0f00031a,   // ro.es.gl_655 es.cs.sk_555  yo.no.un_420 nl.lv.un_760
  0x526b25ee, 0x12003f19, 0x02285514, 0x09291fa4,   // eu.ceb.ha_422 af.hu.un_750  rw.sw.da_666 cy.sl.pl_433
  0x25004a13, 0x080210a0, 0x026b08a9, 0x07186e02,   // yo.eu.un_650 lt.da.no_322  no.ceb.da_544 hmn.ga.it_222
  0x1a6b0e07, 0x0223110c, 0x1108100c, 0x0f102a13,   // is.ceb.tl_432 ro.ca.da_543  be.uk.ro_543 mt.lt.lv_665
  // [4d40]
  0x1800110c, 0x55041aee, 0x0f000621, 0x08071713,   // ro.ga.un_530 tl.fi.rw_422  de.lv.un_860 sr.bg.uk_665
  0x041711ec, 0x4a042a0c, 0x231807ad, 0x0b000919,   // ro.sr.ru_644 mt.fi.yo_543  it.ga.ca_643 pl.es.un_750
  0x180a2304, 0x19530b07, 0x0c0108a0, 0x55530708,   // ca.pt.ga_332 es.ht.gl_432  no.en.sv_322 it.ht.rw_443
  0x110c68ee, 0x6b2504ad, 0x5200251b, 0x051101a4,   // ig.sv.ro_422 fi.eu.ceb_643  eu.ha.un_770 en.ro.fr_433
  // [4d50]
  0x062a08a4, 0x07000f1a, 0x23132513, 0x25002009,   // no.mt.de_433 lv.it.un_760  eu.et.ca_665 sq.eu.un_440
  0x09001c2a, 0x08130e09, 0x03126e07, 0x0405250d,   // mr.hi.un_970 is.et.no_444  hmn.hu.nl_432 eu.fr.fi_554
  0x1218050c, 0x0f1a040c, 0x0c052305, 0x04286b0d,   // fr.ga.hu_543 fi.tl.lv_543  ca.fr.sv_333 ceb.sw.fi_554
  0x1a012aad, 0x04000608, 0x0a0817af, 0x0d0b18a4,   // mt.en.tl_643 de.fi.un_430  sr.uk.mk_655 ga.es.cs_433
  // [4d60]
  0x1119520c, 0x02000b05, 0x3f002a0d, 0x0e002b13,   // ha.gl.ro_543 es.da.un_330  mt.af.un_540 vi.is.un_650
  0x061152a4, 0x2a120ca4, 0x29182302, 0x00001924,   // ha.ro.de_433 sv.hu.mt_433  ca.ga.sl_222 gl.un.un_900
  0x083f100b, 0x110f1305, 0x061308a4, 0x0f0603a0,   // lt.af.no_542 et.lv.ro_333  no.et.de_433 nl.de.lv_322
  0x110e04ee, 0x0552280d, 0x120e180e, 0x521e28a4,   // fi.is.ro_422 sw.ha.fr_554  ga.is.hu_555 sw.ms.ha_433
  // [4d70]
  0x0511230c, 0x4a12180c, 0x1c100f0c, 0x02110e0c,   // ca.ro.fr_543 ga.hu.yo_543  lv.lt.id_543 is.ro.da_543
  0x05000e29, 0x0e121808, 0x0a680704, 0x12041302,   // is.fr.un_960 ga.hu.is_443  it.ig.pt_332 et.fi.hu_222
  0x20005208, 0x054a5312, 0x0a3553ad, 0x07110413,   // ha.sq.un_430 ht.yo.fr_654  ht.zu.pt_643 ru.ro.bg_665
  0x313555ad, 0x53054a0c, 0x21281c04, 0x190b1009,   // rw.zu.az_643 yo.fr.ht_543  id.sw.jw_332 lt.es.gl_444
  // [4d80]
  0x0a001308, 0x12002904, 0x292d0f0c, 0x1118010c,   // et.pt.un_430 sl.hu.un_320  lv.sk.sl_543 en.ga.ro_543
  0x1e251cad, 0x0c13045a, 0x08040ca4, 0x0c0e13ac,   // id.eu.ms_643 fi.et.sv_553  sv.fi.no_433 et.is.sv_632
  0x13006e07, 0x0f001702, 0x356407a4, 0x11201eee,   // hmn.et.un_420 sr.lv.un_220  it.lg.zu_433 ms.sq.ro_422
  0x12002807, 0x1b00130c, 0x1100100c, 0x07350408,   // sw.hu.un_420 et.tr.un_530  lt.ro.un_530 fi.zu.it_443
  // [4d90]
  0x2a190b05, 0x21002013, 0x0b1912ac, 0x190a0702,   // es.gl.mt_333 sq.jw.un_650  hu.gl.es_632 it.pt.gl_222
  0x06001214, 0x131220a4, 0x12285508, 0x32160d14,   // hu.de.un_660 sq.hu.et_433  rw.sw.hu_443 cs.hr.bs_666
  0x12001f0e, 0x53002913, 0x55311aa4, 0x3b002102,   // cy.hu.un_550 sl.ht.un_650  tl.az.rw_433 jw.so.un_220
  0x0300060e, 0x0308010c, 0x29160ca6, 0x1b002302,   // de.nl.un_550 en.no.nl_543  sv.hr.sl_521 ca.tr.un_220
  // [4da0]
  0x08020605, 0x063f03ad, 0x130c1012, 0x35002d08,   // de.da.no_333 nl.af.de_643  lt.sv.et_654 sk.zu.un_430
  0x0c00132a, 0x042813ec, 0x0c3f1f5a, 0x06020508,   // et.sv.un_970 et.sw.fi_644  cy.af.sv_553 fr.da.de_443
  0x13091c11, 0x12132aa0, 0x2b011b5a, 0x536431ad,   // mr.hi.bh_653 mt.et.hu_322  tr.en.vi_553 az.lg.ht_643
  0x11100f05, 0x19003b02, 0x0217080c, 0x2a554a07,   // lv.lt.ro_333 so.gl.un_220  no.sr.da_543 yo.rw.mt_432
  // [4db0]
  0x100e020c, 0x050601a7, 0x216468a4, 0x1b3106ec,   // da.is.lt_543 en.de.fr_532  ig.lg.jw_433 de.az.tr_644
  0x64211c05, 0x2d0d1e02, 0x10000e21, 0x101c1ea6,   // id.jw.lg_333 ms.cs.sk_222  is.lt.un_860 ms.id.lt_521
  0x040f21a4, 0x120f1304, 0x0802310c, 0x0c5204a9,   // jw.lv.fi_433 et.lv.hu_332  az.da.no_543 fi.ha.sv_544
  0x050b070d, 0x07530413, 0x1f1108a4, 0x07170a02,   // it.es.fr_554 fi.ht.it_665  no.ro.cy_433 mk.sr.bg_222
  // [4dc0]
  0x1a002d1a, 0x201b130d, 0x530802a9, 0x200f2507,   // sk.tl.un_760 et.tr.sq_554  da.no.ht_544 eu.lv.sq_432
  0x08071104, 0x0e063560, 0x35281e04, 0x641b5208,   // ro.bg.uk_332 zu.de.is_664  ms.sw.zu_332 ha.tr.lg_443
  0x17001133, 0x273b180c, 0x0e1227a9, 0x3b041112,   // ro.sr.un_A70 ga.so.gd_543  gd.hu.is_544 ro.fi.so_654
  0x1f00110c, 0x3b1b2109, 0x52002802, 0x1f002304,   // ro.cy.un_530 jw.tr.so_444  sw.ha.un_220 ca.cy.un_320
  // [4dd0]
  0x53520413, 0x08352812, 0x19122dec, 0x212a1a04,   // fi.ha.ht_665 sw.zu.no_654  sk.hu.gl_644 tl.mt.jw_332
  0x04181f08, 0x3b1b250c, 0x21003b2a, 0x53042108,   // cy.ga.fi_443 eu.tr.so_543  so.jw.un_970 jw.fi.ht_443
  0x0c0e2aa7, 0x25000707, 0x641a280c, 0x3f002113,   // mt.is.sv_532 it.eu.un_420  sw.tl.lg_543 jw.af.un_650
  0x290e2d0c, 0x08022905, 0x1e1f52a4, 0x131018a4,   // sk.is.sl_543 sl.da.no_333  ha.cy.ms_433 ga.lt.et_433
  // [4de0]
  0x072a550c, 0x64552aaf, 0x27190a08, 0x3b046802,   // rw.mt.it_543 mt.rw.lg_655  pt.gl.gd_443 ig.fi.so_222
  0x2d29020e, 0x2a00060c, 0x06250f13, 0x07186804,   // da.sl.sk_555 de.mt.un_530  lv.eu.de_665 ig.ga.it_332
  0x4a0455a6, 0x55641a08, 0x190b0509, 0x16001a0c,   // rw.fi.yo_521 tl.lg.rw_443  fr.es.gl_444 tl.hr.un_530
  0x5528130b, 0x2d0d0eaf, 0x2a3531ec, 0x1a311baf,   // et.sw.rw_542 is.cs.sk_655  az.zu.mt_644 tr.az.tl_655
  // [4df0]
  0x0e000311, 0x271835af, 0x0e292d13, 0x320f17a4,   // nl.is.un_630 zu.ga.gd_655  sk.sl.is_665 sr.lv.bs_433
  0x120e0aa4, 0x17041111, 0x28063505, 0x3f0c1fee,   // pt.is.hu_433 ro.ru.sr_653  zu.de.sw_333 cy.sv.af_422
  0x125364a0, 0x131b1207, 0x25521a0c, 0x043f4aad,   // lg.ht.hu_322 hu.tr.et_432  tl.ha.eu_543 yo.af.fi_643
  0x3f2503af, 0x3b122011, 0x20000521, 0x0f293ba4,   // nl.eu.af_655 sq.hu.so_653  fr.sq.un_860 so.sl.lv_433
  // [4e00]
  0x160f55a4, 0x1b315314, 0x081113ad, 0x05005212,   // rw.lv.hr_433 ht.az.tr_666  et.ro.no_643 ha.fr.un_640
  0x53070560, 0x350e130c, 0x0f00290c, 0x16293ba4,   // fr.it.ht_664 et.is.zu_543  sl.lv.un_530 so.sl.hr_433
  0x0a001319, 0x0b1819a4, 0x2300110d, 0x5202310b,   // et.pt.un_750 gl.ga.es_433  ro.ca.un_540 az.da.ha_542
  0x11202313, 0x0802040c, 0x321655a4, 0x053f0314,   // ca.sq.ro_665 fi.da.no_543  rw.hr.bs_433 nl.af.fr_666
  // [4e10]
  0x102a1e0b, 0x07002304, 0x021a1355, 0x23002a04,   // ms.mt.lt_542 ca.it.un_320  et.tl.da_442 mt.ca.un_320
  0x101716ac, 0x11000919, 0x2900550c, 0x0f092905,   // hr.sr.lt_632 pl.ro.un_750  rw.sl.un_530 sl.pl.lv_333
  0x061a09a7, 0x6b201a07, 0x282535a7, 0x2011010c,   // pl.tl.de_532 tl.sq.ceb_432  zu.eu.sw_532 en.ro.sq_543
  0x131104ec, 0x0813680c, 0x2d0d04af, 0x17110460,   // fi.ro.et_644 ig.et.no_543  fi.cs.sk_655 ru.ro.sr_664
  // [4e20]
  0x6425130c, 0x64092aad, 0x0e520813, 0x110f0404,   // et.eu.lg_543 mt.pl.lg_643  no.ha.is_665 fi.lv.ro_332
  0x20112313, 0x1e005307, 0x321753ee, 0x64095511,   // ca.ro.sq_665 ht.ms.un_420  ht.sr.bs_422 rw.pl.lg_653
  0x1e1c28a4, 0x25315307, 0x18000308, 0x19004a04,   // sw.id.ms_433 ht.az.eu_432  nl.ga.un_430 yo.gl.un_320
  0x1c201eec, 0x2d0d1c05, 0x68190a13, 0x1a2a53af,   // ms.sq.id_644 id.cs.sk_333  pt.gl.ig_665 ht.mt.tl_655
  // [4e30]
  0x19110b08, 0x014a03a0, 0x1e52280c, 0x014a08a4,   // es.ro.gl_443 nl.yo.en_322  sw.ha.ms_543 no.yo.en_433
  0x0e0825ee, 0x082b0ea4, 0x103228a4, 0x0327180c,   // eu.no.is_422 is.vi.no_433  sw.bs.lt_433 ga.gd.nl_543
  0x08005204, 0x0b000507, 0x27033f05, 0x31201ba4,   // ha.no.un_320 fr.es.un_420  af.nl.gd_333 tr.sq.az_433
  0x27185214, 0x201e52ad, 0x20002302, 0x35003b14,   // ha.ga.gd_666 ha.ms.sq_643  ca.sq.un_220 so.zu.un_660
  // [4e40]
  0x640c080c, 0x52001b09, 0x130401a9, 0x55033f60,   // no.sv.lg_543 tr.ha.un_440  en.fi.et_544 af.nl.rw_664
  0x1b202a07, 0x4a001214, 0x53002802, 0x2d0802a0,   // mt.sq.tr_432 hu.yo.un_660  sw.ht.un_220 da.no.sk_322
  0x070f110e, 0x081e3b07, 0x2d0d4a0c, 0x12313f07,   // ro.lv.it_555 so.ms.no_432  yo.cs.sk_543 af.az.hu_432
  0x07030fee, 0x04102104, 0x21000707, 0x110f0307,   // lv.nl.it_422 jw.lt.fi_332  it.jw.un_420 nl.lv.ro_432
  // [4e50]
  0x6b55280c, 0x122903a0, 0x131e1c0c, 0x080252a0,   // sw.rw.ceb_543 nl.sl.hu_322  id.ms.et_543 ha.da.no_322
  0x09003f04, 0x1c5523a4, 0x08020da9, 0x2700071b,   // af.pl.un_320 ca.rw.id_433  cs.da.no_544 it.gd.un_770
  0x251a01af, 0x28271804, 0x5200070e, 0x272118a0,   // en.tl.eu_655 ga.gd.sw_332  it.ha.un_550 ga.jw.gd_322
  0x18001223, 0x0b11235a, 0x12003b13, 0x52000712,   // ur.ar.un_880 ca.ro.es_553  so.hu.un_650 it.ha.un_640
  // [4e60]
  0x1a003b05, 0x060c20a4, 0x2025115a, 0x230c0e12,   // so.tl.un_330 sq.sv.de_433  ro.eu.sq_553 is.sv.ca_654
  0x210b190c, 0x3b001919, 0x550921ec, 0x0425230c,   // gl.es.jw_543 gl.so.un_750  jw.pl.rw_644 ca.eu.fi_543
  0x27185207, 0x23040aa0, 0x08064a08, 0x1b531c04,   // ha.ga.gd_432 pt.fi.ca_322  yo.de.no_443 id.ht.tr_332
  0x25000104, 0x3f051312, 0x2a280707, 0x28040aa4,   // en.eu.un_320 et.fr.af_654  it.sw.mt_432 pt.fi.sw_433
  // [4e70]
  0x041329ee, 0x18002702, 0x522a07a7, 0x2a0609ad,   // sl.et.fi_422 gd.ga.un_220  it.mt.ha_532 pl.de.mt_643
  0x2d001f08, 0x0e004a08, 0x35686b12, 0x29000b09,   // cy.sk.un_430 yo.is.un_430  ceb.ig.zu_654 es.sl.un_440
  0x3f092a12, 0x040717a7, 0x17110a0e, 0x640107ee,   // mt.pl.af_654 sr.bg.ru_532  mk.ro.sr_555 it.en.lg_422
  0x29006429, 0x092a3f12, 0x09006804, 0x3f31100c,   // lg.sl.un_960 af.mt.pl_654  ig.pl.un_320 lt.az.af_543
  // [4e80]
  0x033f6412, 0x05033f08, 0x4a3568ec, 0x102a07a0,   // lg.af.nl_654 af.nl.fr_443  ig.zu.yo_644 it.mt.lt_322
  0x08040aa6, 0x12041aad, 0x53211ca4, 0x0f131bad,   // mk.ru.uk_521 tl.fi.hu_643  id.jw.ht_433 tr.et.lv_643
  0x136b11ad, 0x04281a0c, 0x2b004a19, 0x18010ca7,   // ro.ceb.et_643 tl.sw.fi_543  yo.vi.un_750 sv.en.ga_532
  0x1e002813, 0x1c132107, 0x3500010d, 0x09001329,   // sw.ms.un_650 jw.et.id_432  en.zu.un_540 bh.hi.un_960
  // [4e90]
  0x3f003504, 0x12000422, 0x0a640702, 0x0f102a0e,   // zu.af.un_320 fi.hu.un_870  it.lg.pt_222 mt.lt.lv_555
  0x07001712, 0x161b1a08, 0x08020302, 0x13282507,   // sr.bg.un_640 tl.tr.hr_443  nl.da.no_222 eu.sw.et_432
  0x11170a13, 0x041a1ea4, 0x0a00040e, 0x286825ee,   // mk.sr.ro_665 ms.tl.fi_433  ru.mk.un_550 eu.ig.sw_422
  0x130425ee, 0x1f001912, 0x02133b05, 0x01082a07,   // eu.fi.et_422 gl.cy.un_640  so.et.da_333 mt.no.en_432
  // [4ea0]
  0x19230ba9, 0x04006b2a, 0x19001216, 0x3f10040c,   // es.ca.gl_544 ceb.fi.un_970  hu.gl.un_720 fi.lt.af_543
  0x04000735, 0x170911a4, 0x1f353f02, 0x0d092dee,   // bg.ru.un_A90 ro.pl.sr_433  af.zu.cy_222 sk.pl.cs_422
  0x3b005302, 0x17250d0c, 0x315235a6, 0x190b2304,   // ht.so.un_220 cs.eu.sr_543  zu.ha.az_521 ca.es.gl_332
  0x0e000705, 0x270e08a7, 0x0700250d, 0x3b062bee,   // it.is.un_330 no.is.gd_532  eu.it.un_540 vi.de.so_422
  // [4eb0]
  0x19005304, 0x03643f05, 0x03023f5a, 0x28130460,   // ht.gl.un_320 af.lg.nl_333  af.da.nl_553 fi.et.sw_664
  0x0a002a12, 0x1c00350d, 0x2d0d3bee, 0x3b1a3513,   // mt.pt.un_640 zu.id.un_540  so.cs.sk_422 zu.tl.so_665
  0x1a00350c, 0x0a002a0d, 0x283b3560, 0x050235ee,   // zu.tl.un_530 mt.pt.un_540  zu.so.sw_664 zu.da.fr_422
  0x17080208, 0x286435ad, 0x18010502, 0x182007af,   // da.no.sr_443 zu.lg.sw_643  fr.en.ga_222 it.sq.ga_655
  // [4ec0]
  0x0c131e07, 0x0b001819, 0x311711ec, 0x11003b1e,   // ms.et.sv_432 ga.es.un_750  ro.sr.az_644 so.ro.un_830
  0x35556404, 0x645235a4, 0x3b005520, 0x08003f0e,   // lg.rw.zu_332 zu.ha.lg_433  rw.so.un_850 af.no.un_550
  0x06013505, 0x03002504, 0x321c2508, 0x0b2319a7,   // zu.en.de_333 eu.nl.un_320  eu.id.bs_443 gl.ca.es_532
  0x07080a11, 0x3f3110ec, 0x2d0d120c, 0x522520a6,   // mk.uk.bg_653 lt.az.af_644  hu.cs.sk_543 sq.eu.ha_521
  // [4ed0]
  0x2a190709, 0x1a6b3b07, 0x0f003209, 0x3b351ca0,   // it.gl.mt_444 so.ceb.tl_432  bs.lv.un_440 id.zu.so_322
  0x05190b0c, 0x013f06a4, 0x0f04050c, 0x18001c02,   // es.gl.fr_543 de.af.en_433  fr.fi.lv_543 id.ga.un_220
  0x190b0a0d, 0x2809070b, 0x0b000513, 0x060c0eec,   // pt.es.gl_554 it.pl.sw_542  fr.es.un_650 is.sv.de_644
  0x190b055a, 0x0b005304, 0x3f000f19, 0x17160fee,   // fr.es.gl_553 ht.es.un_320  lv.af.un_750 lv.hr.sr_422
  // [4ee0]
  0x073b6404, 0x041a2107, 0x0e002012, 0x311003a7,   // lg.so.it_332 jw.tl.fi_432  sq.is.un_640 nl.lt.az_532
  0x011853a0, 0x09006818, 0x0e326405, 0x55000a08,   // ht.ga.en_322 ig.pl.un_740  lg.bs.is_333 pt.rw.un_430
  0x133b6455, 0x2b1f0755, 0x090f04a9, 0x06040f14,   // lg.so.et_442 it.cy.vi_442  fi.lv.pl_544 lv.fi.de_666
  0x03065504, 0x12001902, 0x07100f12, 0x130e0f0c,   // rw.de.nl_332 gl.hu.un_220  lv.lt.it_654 lv.is.et_543
  // [4ef0]
  0x190b25a4, 0x3f2a0bad, 0x0f2d1007, 0x3f000f04,   // eu.es.gl_433 es.mt.af_643  lt.sk.lv_432 lv.af.un_320
  0x033f25ec, 0x310418a4, 0x6400030d, 0x18010604,   // eu.af.nl_644 ga.fi.az_433  nl.lg.un_540 de.en.ga_332
  0x133f3ba0, 0x0e04090c, 0x190d35ec, 0x040f52ad,   // so.af.et_322 pl.fi.is_543  zu.cs.gl_644 ha.lv.fi_643
  0x0c0f03a4, 0x101c0404, 0x27282008, 0x35053f07,   // nl.lv.sv_433 fi.id.lt_332  sq.sw.gd_443 af.fr.zu_432
  // [4f00]
  0x32002708, 0x3b061908, 0x193555ec, 0x0e3b2708,   // gd.bs.un_430 gl.de.so_443  rw.zu.gl_644 gd.so.is_443
  0x09182705, 0x2928550c, 0x113b10ec, 0x0f096ba6,   // gd.ga.pl_333 rw.sw.sl_543  lt.so.ro_644 ceb.pl.lv_521
  0x55086ba4, 0x18000720, 0x0a180709, 0x18271c07,   // ceb.no.rw_433 it.ga.un_850  it.ga.pt_444 id.gd.ga_432
  0x162d32a0, 0x07182708, 0x4a176407, 0x10170413,   // bs.sk.hr_322 gd.ga.it_443  lg.sr.yo_432 ru.sr.be_665
  // [4f10]
  0x64190b08, 0x091e1cad, 0x0e556807, 0x213b0911,   // es.gl.lg_443 id.ms.pl_643  ig.rw.is_432 pl.so.jw_653
  0x0a271055, 0x190b2805, 0x162953a4, 0x18192708,   // lt.gd.pt_442 sw.es.gl_333  ht.sl.hr_433 gd.gl.ga_443
  0x1c1125a7, 0x6400071a, 0x2800271b, 0x1b002829,   // eu.ro.id_532 it.lg.un_760  gd.sw.un_770 sw.tr.un_960
  0x112855af, 0x070511ac, 0x1c521e0c, 0x053f5505,   // rw.sw.ro_655 ro.fr.it_632  ms.ha.id_543 rw.af.fr_333
  // [4f20]
  0x230e0bee, 0x0f1a09a7, 0x2021520c, 0x07230608,   // es.is.ca_422 pl.tl.lv_532  ha.jw.sq_543 de.ca.it_443
  0x07000120, 0x0a170814, 0x644a5312, 0x52001122,   // en.it.un_850 uk.sr.mk_666  ht.yo.lg_654 ro.ha.un_870
  0x0c0a11a4, 0x32281bee, 0x524a1aa7, 0x1e010c02,   // ro.pt.sv_433 tr.sw.bs_422  tl.yo.ha_532 sv.en.ms_222
  0x0700102b, 0x0e002d08, 0x03002102, 0x2a030605,   // be.bg.un_980 sk.is.un_430  jw.nl.un_220 de.nl.mt_333
  // [4f30]
  0x0e005204, 0x23072a08, 0x0f080ea7, 0x1f0b1a07,   // ha.is.un_320 mt.it.ca_443  is.no.lv_532 tl.es.cy_432
  0x100a07a6, 0x21231ca0, 0x25091b07, 0x19100ba0,   // it.pt.lt_521 id.ca.jw_322  tr.pl.eu_432 es.lt.gl_322
  0x3b0e0b04, 0x0d0e2da4, 0x0d0e0ba0, 0x170752ee,   // es.is.so_332 sk.is.cs_433  es.is.cs_322 ha.it.sr_422
  0x271223ee, 0x52005314, 0x20190b08, 0x20001807,   // ca.hu.gd_422 ht.ha.un_660  es.gl.sq_443 ga.sq.un_420
  // [4f40]
  0x070b3104, 0x2d0d2a02, 0x19120b12, 0x200c1a08,   // az.es.it_332 mt.cs.sk_222  es.hu.gl_654 tl.sv.sq_443
  0x122152ee, 0x0b0a2da7, 0x080e1212, 0x080402a4,   // ha.jw.hu_422 sk.pt.es_532  hu.is.no_654 da.fi.no_433
  0x21035207, 0x0a086405, 0x25200b07, 0x105207ac,   // ha.nl.jw_432 lg.no.pt_333  es.sq.eu_432 it.ha.lt_632
  0x0717100b, 0x3b202811, 0x55002102, 0x28553ba0,   // be.sr.bg_542 sw.sq.so_653  jw.rw.un_220 so.rw.sw_322
  // [4f50]
  0x0e000405, 0x0b030e55, 0x190c0bad, 0x28000c07,   // fi.is.un_330 is.nl.es_442  es.sv.gl_643 sv.sw.un_420
  0x17282d07, 0x310f2504, 0x093f0aa7, 0x2000290c,   // sk.sw.sr_432 eu.lv.az_332  pt.af.pl_532 sl.sq.un_530
  0x1b042a12, 0x062a35a4, 0x551b520c, 0x6400250d,   // mt.fi.tr_654 zu.mt.de_433  ha.tr.rw_543 eu.lg.un_540
  0x0413680d, 0x25000b14, 0x01031fa7, 0x0725555a,   // ig.et.fi_554 es.eu.un_660  cy.nl.en_532 rw.eu.it_553
  // [4f60]
  0x28000313, 0x55642513, 0x64555204, 0x200c08ee,   // nl.sw.un_650 eu.lg.rw_665  ha.rw.lg_332 no.sv.sq_422
  0x07005214, 0x1c11310c, 0x0d002904, 0x0a0704ee,   // ha.it.un_660 az.ro.id_543  sl.cs.un_320 ru.bg.mk_422
  0x0f004a07, 0x3f1352ee, 0x64255512, 0x1f052308,   // yo.lv.un_420 ha.et.af_422  rw.eu.lg_654 ca.fr.cy_443
  0x3f076407, 0x16002a04, 0x55250da4, 0x532a07a4,   // lg.it.af_432 mt.hr.un_320  cs.eu.rw_433 it.mt.ht_433
  // [4f70]
  0x283b68ac, 0x1b1029ec, 0x23192512, 0x1703110c,   // ig.so.sw_632 sl.lt.tr_644  eu.gl.ca_654 ro.nl.sr_543
  0x280a6808, 0x554a64af, 0x525528ad, 0x0c64550d,   // ig.pt.sw_443 lg.yo.rw_655  sw.rw.ha_643 rw.lg.sv_554
  0x040807ad, 0x2a090ba0, 0x01051307, 0x0a180e04,   // bg.uk.ru_643 es.pl.mt_322  et.fr.en_432 is.ga.pt_332
  0x13090d08, 0x2d3b0d0c, 0x6b3b5512, 0x160d32a7,   // ne.hi.bh_443 cs.so.sk_543  rw.so.ceb_654 bs.cs.hr_532
  // [4f80]
  0x1c182755, 0x2868010c, 0x27001e04, 0x55041308,   // gd.ga.id_442 en.ig.sw_543  ms.gd.un_320 et.fi.rw_443
  0x0e002804, 0x02355212, 0x09681fa0, 0x2100200b,   // sw.is.un_320 ha.zu.da_654  cy.ig.pl_322 sq.jw.un_520
  0x16001f04, 0x01081fa0, 0x2a0712ec, 0x270907a0,   // cy.hr.un_320 cy.no.en_322  hu.it.mt_644 it.pl.gd_322
  0x11053509, 0x27351807, 0x1b00280b, 0x10000a1a,   // zu.fr.ro_444 ga.zu.gd_432  sw.tr.un_520 mk.be.un_760
  // [4f90]
  0x12080ea4, 0x23043504, 0x020b0a05, 0x3f3508a4,   // is.no.hu_433 zu.fi.ca_332  pt.es.da_333 no.zu.af_433
  0x0b0813a9, 0x0a0c5211, 0x0f02290c, 0x081704af,   // et.no.es_544 ha.sv.pt_653  sl.da.lv_543 ru.sr.uk_655
  0x0c1f0ea7, 0x551a6412, 0x2d0d10a9, 0x293517ee,   // is.cy.sv_532 lg.tl.rw_654  lt.cs.sk_544 sr.zu.sl_422
  0x6b551b08, 0x0b2d05a4, 0x2a052107, 0x55282aa4,   // tr.rw.ceb_443 fr.sk.es_433  jw.fr.mt_432 mt.sw.rw_433
  // [4fa0]
  0x0713110c, 0x2013110c, 0x11122112, 0x6431550c,   // ro.et.it_543 ro.et.sq_543  jw.hu.ro_654 rw.az.lg_543
  0x110f29a4, 0x130223a7, 0x55641ca0, 0x1a2b010b,   // sl.lv.ro_433 ca.da.et_532  id.lg.rw_322 en.vi.tl_542
  0x323529a4, 0x52213ba4, 0x23102da4, 0x0e03250c,   // sl.zu.bs_433 so.jw.ha_433  sk.lt.ca_433 eu.nl.is_543
  0x0f00130c, 0x1b1325a9, 0x0e052d0c, 0x2d291607,   // et.lv.un_530 eu.et.tr_544  sk.fr.is_543 hr.sl.sk_432
  // [4fb0]
  0x320d295e, 0x29081ba7, 0x10001b04, 0x231121a4,   // sl.cs.bs_652 tr.no.sl_532  tr.lt.un_320 jw.ro.ca_433
  0x3500070d, 0x2d07110c, 0x031b2512, 0x04100a5a,   // it.zu.un_540 ro.it.sk_543  eu.tr.nl_654 mk.be.ru_553
  0x101b20ec, 0x01251804, 0x29071705, 0x05132a07,   // sq.tr.lt_644 ga.eu.en_332  sr.it.sl_333 mt.et.fr_432
  0x1e061213, 0x25031b09, 0x530602a0, 0x060c5307,   // hu.de.ms_665 tr.nl.eu_444  da.de.ht_322 ht.sv.de_432
  // [4fc0]
  0x21686b11, 0x2a002d08, 0x3f0103ee, 0x1c0f3512,   // ceb.ig.jw_653 sk.mt.un_430  nl.en.af_422 zu.lv.id_654
  0x0d001114, 0x20001b21, 0x090e100c, 0x18002a04,   // ro.cs.un_660 tr.sq.un_860  lt.is.pl_543 mt.ga.un_320
  0x04003504, 0x3f080e08, 0x1700041b, 0x521f3baf,   // zu.fi.un_320 is.no.af_443  ru.sr.un_770 so.cy.ha_655
  0x1204080c, 0x11281360, 0x030e1b04, 0x0a1301a4,   // no.fi.hu_543 et.sw.ro_664  tr.is.nl_332 en.et.pt_433
  // [4fd0]
  0x6b131aa4, 0x1900060b, 0x270b23a4, 0x061b2a07,   // tl.et.ceb_433 de.gl.un_520  ca.es.gd_433 mt.tr.de_432
  0x2d0d180c, 0x3b286ba7, 0x25232aaf, 0x120e1f55,   // ga.cs.sk_543 ceb.sw.so_532  mt.ca.eu_655 cy.is.hu_442
  0x18012aad, 0x525328a4, 0x1c0853ee, 0x1f180f5a,   // mt.en.ga_643 sw.ht.ha_433  ht.no.id_422 lv.ga.cy_553
  0x21002019, 0x0e18270d, 0x02003202, 0x1c282107,   // sq.jw.un_750 gd.ga.is_554  bs.da.un_220 jw.sw.id_432
  // [4fe0]
  0x07006b21, 0x162935ee, 0x0b0a2314, 0x111b310d,   // ceb.it.un_860 zu.sl.hr_422  ca.pt.es_666 az.tr.ro_554
  0x286b52a0, 0x10060e55, 0x04110805, 0x323b21ad,   // ha.ceb.sw_322 is.de.lt_442  uk.ro.ru_333 jw.so.bs_643
  0x18190a09, 0x35001605, 0x2a5220ac, 0x1e5528ee,   // pt.gl.ga_444 hr.zu.un_330  sq.ha.mt_632 sw.rw.ms_422
  0x1a6b1b60, 0x041306ad, 0x06001902, 0x131a2012,   // tr.ceb.tl_664 de.et.fi_643  gl.de.un_220 sq.tl.et_654
  // [4ff0]
  0x033b3f0c, 0x116b64ee, 0x08000723, 0x23190da0,   // af.so.nl_543 lg.ceb.ro_422  bg.uk.un_880 cs.gl.ca_322
  0x0e001904, 0x2d00120c, 0x0c006b04, 0x1225270d,   // gl.is.un_320 hu.sk.un_530  ceb.sv.un_320 gd.eu.hu_554
  0x1800351a, 0x0308350c, 0x2835185a, 0x32082aa0,   // zu.ga.un_760 zu.no.nl_543  ga.zu.sw_553 mt.no.bs_322
  0x1a550455, 0x35001819, 0x2b000808, 0x1e1c020e,   // fi.rw.tl_442 ga.zu.un_750  no.vi.un_430 da.id.ms_555

  // [5000]
  0x182827af, 0x212835ad, 0x291617a9, 0x0d006b07,   // gd.sw.ga_655 zu.sw.jw_643  sr.hr.sl_544 ceb.cs.un_420
  0x31646ba0, 0x1820280c, 0x321716ec, 0x05004a12,   // ceb.lg.az_322 sw.sq.ga_543  hr.sr.bs_644 yo.fr.un_640
  0x28001e13, 0x28642107, 0x21283b0c, 0x64040b02,   // ms.sw.un_650 jw.lg.sw_432  so.sw.jw_543 es.fi.lg_222
  0x0e0c210d, 0x18352155, 0x233511ad, 0x685564a9,   // jw.sv.is_554 jw.zu.ga_442  ro.zu.ca_643 lg.rw.ig_544
  // [5010]
  0x041117a4, 0x64215508, 0x2a006e08, 0x271e1cac,   // sr.ro.ru_433 rw.jw.lg_443  hmn.mt.un_430 id.ms.gd_632
  0x033f3105, 0x0d1029a4, 0x29171614, 0x125564a4,   // az.af.nl_333 sl.lt.cs_433  hr.sr.sl_666 lg.rw.hu_433
  0x1f0b19ad, 0x02001f21, 0x18003521, 0x10001e0c,   // gl.es.cy_643 cy.da.un_860  zu.ga.un_860 ms.lt.un_530
  0x2d004a07, 0x01000802, 0x2b000122, 0x55211e0c,   // yo.sk.un_420 no.en.un_220  en.vi.un_870 ms.jw.rw_543
  // [5020]
  0x356b1f0b, 0x080c0e0d, 0x1c1e2112, 0x2b086404,   // cy.ceb.zu_542 is.sv.no_554  jw.ms.id_654 lg.no.vi_332
  0x201b2508, 0x2a002705, 0x131228a4, 0x351b2a07,   // eu.tr.sq_443 gd.mt.un_330  sw.hu.et_433 mt.tr.zu_432
  0x19230b0c, 0x1f3568a0, 0x4a271ba4, 0x0c1f3b0e,   // es.ca.gl_543 ig.zu.cy_322  tr.gd.yo_433 so.cy.sv_555
  0x071c05a0, 0x190a2509, 0x1c27200c, 0x11053f0c,   // fr.id.it_322 eu.pt.gl_444  sq.gd.id_543 af.fr.ro_543
  // [5030]
  0x03006404, 0x0b122305, 0x6b033511, 0x3b232104,   // lg.nl.un_320 ca.hu.es_333  zu.nl.ceb_653 jw.ca.so_332
  0x23001205, 0x0e081309, 0x190b20ee, 0x056b0c08,   // hu.ca.un_330 et.no.is_444  sq.es.gl_422 sv.ceb.fr_443
  0x04136807, 0x35642811, 0x646813a7, 0x6b2a070c,   // ig.et.fi_432 sw.lg.zu_653  et.ig.lg_532 it.mt.ceb_543
  0x18000305, 0x190a2307, 0x180135a7, 0x23132807,   // nl.ga.un_330 ca.pt.gl_432  zu.en.ga_532 sw.et.ca_432
  // [5040]
  0x05110309, 0x64134a5a, 0x28072a0c, 0x04212804,   // nl.ro.fr_444 yo.et.lg_553  mt.it.sw_543 sw.jw.fi_332
  0x1c003202, 0x113128a4, 0x0e6455ec, 0x06001104,   // bs.id.un_220 sw.az.ro_433  rw.lg.is_644 ro.de.un_320
  0x17100813, 0x171632ac, 0x13215204, 0x06012007,   // uk.be.sr_665 bs.hr.sr_632  ha.jw.et_332 sq.en.de_432
  0x352a2012, 0x285535ec, 0x2a131aa4, 0x6e1b53a9,   // sq.mt.zu_654 zu.rw.sw_644  tl.et.mt_433 ht.tr.hmn_544
  // [5050]
  0x3f000913, 0x55001f02, 0x190b0505, 0x28686412,   // pl.af.un_650 cy.rw.un_220  fr.es.gl_333 lg.ig.sw_654
  0x0e0c0809, 0x645328ec, 0x080c12a4, 0x20121304,   // no.sv.is_444 sw.ht.lg_644  hu.sv.no_433 et.hu.sq_332
  0x27000104, 0x072028ee, 0x2a00351a, 0x060e0c0c,   // en.gd.un_320 sw.sq.it_422  zu.mt.un_760 sv.is.de_543
  0x35181c07, 0x3f3528ad, 0x09000413, 0x3f6b5507,   // id.ga.zu_432 sw.zu.af_643  fi.pl.un_650 rw.ceb.af_432
  // [5060]
  0x070a64ad, 0x28000b02, 0x060c0fa4, 0x0f290707,   // lg.pt.it_643 es.sw.un_220  lv.sv.de_433 it.sl.lv_432
  0x13001a04, 0x06190bec, 0x350968a9, 0x29071c07,   // tl.et.un_320 es.gl.de_644  ig.pl.zu_544 id.it.sl_432
  0x17000a02, 0x112123a4, 0x2a07180c, 0x022825a4,   // mk.sr.un_220 ca.jw.ro_433  ga.it.mt_543 eu.sw.da_433
  0x0c0e3fee, 0x02005305, 0x1a640914, 0x102313a9,   // af.is.sv_422 ht.da.un_330  pl.lg.tl_666 et.ca.lt_544
  // [5070]
  0x10052855, 0x3f1053ec, 0x1b000305, 0x521e0f13,   // sw.fr.lt_442 ht.lt.af_644  nl.tr.un_330 lv.ms.ha_665
  0x03073fa9, 0x1a5568a0, 0x0d1c09ac, 0x1f3b1a07,   // af.it.nl_544 ig.rw.tl_322  hi.mr.ne_632 tl.so.cy_432
  0x190b0aa6, 0x0a000507, 0x0a0810ad, 0x53102509,   // pt.es.gl_521 fr.pt.un_420  be.uk.mk_643 eu.lt.ht_444
  0x55005221, 0x311b55a9, 0x082a25ad, 0x0e001f22,   // ha.rw.un_860 rw.tr.az_544  eu.mt.no_643 cy.is.un_870
  // [5080]
  0x29080ca4, 0x3f27100b, 0x4a001a12, 0x04532507,   // sv.no.sl_433 lt.gd.af_542  tl.yo.un_640 eu.ht.fi_432
  0x0a004a05, 0x281225af, 0x0c060404, 0x25006422,   // yo.pt.un_330 eu.hu.sw_655  fi.de.sv_332 lg.eu.un_870
  0x100f2508, 0x3b2a6812, 0x231b3ba4, 0x11310d07,   // eu.lv.lt_443 ig.mt.so_654  so.tr.ca_433 cs.az.ro_432
  0x201b6e08, 0x08311804, 0x10286413, 0x1b293102,   // hmn.tr.sq_443 ga.az.no_332  lg.sw.lt_665 az.sl.tr_222
  // [5090]
  0x08020a09, 0x32251f08, 0x52064a08, 0x08252707,   // pt.da.no_444 cy.eu.bs_443  yo.de.ha_443 gd.eu.no_432
  0x1f3105a4, 0x6b1f05ee, 0x3f021bad, 0x1c642809,   // fr.az.cy_433 fr.cy.ceb_422  tr.da.af_643 sw.lg.id_444
  0x2a1f05ec, 0x1f002104, 0x01550507, 0x1b07350c,   // fr.cy.mt_644 jw.cy.un_320  fr.rw.en_432 zu.it.tr_543
  0x111335ec, 0x1e251ba4, 0x090d2da9, 0x521f645a,   // zu.et.ro_644 tr.eu.ms_433  sk.cs.pl_544 lg.cy.ha_553
  // [50a0]
  0x13351108, 0x10000619, 0x3b080260, 0x1700082c,   // ro.zu.et_443 de.lt.un_750  da.no.so_664 uk.sr.un_990
  0x13000409, 0x171608a0, 0x32133508, 0x12000212,   // fi.et.un_440 no.hr.sr_322  zu.et.bs_443 da.hu.un_640
  0x08000a09, 0x210b1ca4, 0x2818010c, 0x093216a7,   // mk.uk.un_440 id.es.jw_433  en.ga.sw_543 hr.bs.pl_532
  0x35070508, 0x13000314, 0x1f010611, 0x2b1c13a4,   // fr.it.zu_443 nl.et.un_660  de.en.cy_653 et.id.vi_433
  // [50b0]
  0x555364a7, 0x05002b0c, 0x03052307, 0x531135a4,   // lg.ht.rw_532 vi.fr.un_530  ca.fr.nl_432 zu.ro.ht_433
  0x1a643bee, 0x01002302, 0x13003507, 0x046452a4,   // so.lg.tl_422 ca.en.un_220  zu.et.un_420 ha.lg.fi_433
  0x130711a4, 0x11005207, 0x101e250c, 0x130711ec,   // ro.it.et_433 ha.ro.un_420  eu.ms.lt_543 ro.it.et_644
  0x07110808, 0x114a3508, 0x0d003202, 0x28005302,   // uk.ro.bg_443 zu.yo.ro_443  bs.cs.un_220 ht.sw.un_220
  // [50c0]
  0x2500290d, 0x55001c04, 0x13031a14, 0x1a133b60,   // sl.eu.un_540 id.rw.un_320  tl.nl.et_666 so.et.tl_664
  0x0a080460, 0x6b133b04, 0x130e08a9, 0x530428ad,   // ru.uk.mk_664 so.et.ceb_332  no.is.et_544 sw.fi.ht_643
  0x3b2a25a9, 0x03642502, 0x211c2a05, 0x02065204,   // eu.mt.so_544 eu.lg.nl_222  mt.id.jw_333 ha.de.da_332
  0x1a6b35a4, 0x17000714, 0x19206408, 0x13091ca4,   // zu.ceb.tl_433 bg.sr.un_660  lg.sq.gl_443 mr.hi.bh_433
  // [50d0]
  0x063153a4, 0x2b250cad, 0x20321ba0, 0x1f101ea9,   // ht.az.de_433 sv.eu.vi_643  tr.bs.sq_322 ms.lt.cy_544
  0x190b06ba, 0x0b0a2302, 0x044a550c, 0x25000813,   // de.es.gl_843 ca.pt.es_222  rw.yo.fi_543 no.eu.un_650
  0x64095504, 0x68005322, 0x100a1108, 0x351355a7,   // rw.pl.lg_332 ht.ig.un_870  ro.mk.be_443 rw.et.zu_532
  0x1f001018, 0x18272b5a, 0x1f00101a, 0x060c2a07,   // lt.cy.un_740 vi.gd.ga_553  lt.cy.un_760 mt.sv.de_432
  // [50e0]
  0x3b2720ec, 0x11521b08, 0x0710080c, 0x31000e13,   // sq.gd.so_644 tr.ha.ro_443  uk.be.bg_543 is.az.un_650
  0x13110ca0, 0x311b4aa7, 0x13086eec, 0x05001704,   // sv.ro.et_322 yo.tr.az_532  hmn.no.et_644 sr.fr.un_320
  0x20002a02, 0x10001f1b, 0x27185204, 0x3f201ca0,   // mt.sq.un_220 cy.lt.un_770  ha.ga.gd_332 id.sq.af_322
  0x10001f21, 0x050a1fa0, 0x13040c07, 0x234a0b02,   // cy.lt.un_860 cy.pt.fr_322  sv.fi.et_432 es.yo.ca_222
  // [50f0]
  0x0a005305, 0x04311b0c, 0x6b000120, 0x64080208,   // ht.pt.un_330 tr.az.fi_543  en.ceb.un_850 da.no.lg_443
  0x1f00182c, 0x28002312, 0x1812270c, 0x64251307,   // ga.cy.un_990 ca.sw.un_640  gd.hu.ga_543 et.eu.lg_432
  0x3b110407, 0x0e522105, 0x0c120207, 0x0f120eee,   // fi.ro.so_432 jw.ha.is_333  da.hu.sv_432 is.hu.lv_422
  0x25001f08, 0x251b520c, 0x0c000307, 0x1e231fa0,   // cy.eu.un_430 ha.tr.eu_543  nl.sv.un_420 cy.ca.ms_322
  // [5100]
  0x28001f07, 0x0e0501a4, 0x05351308, 0x6b554a55,   // cy.sw.un_420 en.fr.is_433  et.zu.fr_443 yo.rw.ceb_442
  0x04130d0c, 0x3528555a, 0x251b13ec, 0x13080c0c,   // cs.et.fi_543 rw.sw.zu_553  et.tr.eu_644 sv.no.et_543
  0x3b640707, 0x1b25130c, 0x552053a4, 0x324a3504,   // it.lg.so_432 et.eu.tr_543  ht.sq.rw_433 zu.yo.bs_332
  0x13040a0c, 0x4a000520, 0x28006818, 0x13114aa0,   // pt.fi.et_543 fr.yo.un_850  ig.sw.un_740 yo.ro.et_322
  // [5110]
  0x284a55a4, 0x27011807, 0x18310812, 0x280155a4,   // rw.yo.sw_433 ga.en.gd_432  no.az.ga_654 rw.en.sw_433
  0x043564ad, 0x2b030508, 0x180603a4, 0x31200f05,   // lg.zu.fi_643 fr.nl.vi_443  nl.de.ga_433 lv.sq.az_333
  0x2a00551a, 0x135568a0, 0x680d2da7, 0x0835010c,   // rw.mt.un_760 ig.rw.et_322  sk.cs.ig_532 en.zu.no_543
  0x01003b09, 0x01131ba4, 0x1a6b2513, 0x25000508,   // so.en.un_440 tr.et.en_433  eu.ceb.tl_665 fr.eu.un_430
  // [5120]
  0x640f5512, 0x2a180604, 0x35641e04, 0x6b520c07,   // rw.lv.lg_654 de.ga.mt_332  ms.lg.zu_332 sv.ha.ceb_432
  0x01000b05, 0x21054a0c, 0x033555af, 0x352528ee,   // es.en.un_330 yo.fr.jw_543  rw.zu.nl_655 sw.eu.zu_422
  0x18001f20, 0x061c0502, 0x32000612, 0x55002a1a,   // cy.ga.un_850 fr.id.de_222  de.bs.un_640 mt.rw.un_760
  0x3b211aec, 0x2a0764ec, 0x35000d13, 0x3b205208,   // tl.jw.so_644 lg.it.mt_644  cs.zu.un_650 ha.sq.so_443
  // [5130]
  0x211c3104, 0x1c0921ee, 0x1e120607, 0x2100251b,   // az.id.jw_332 jw.pl.id_422  de.hu.ms_432 eu.jw.un_770
  0x205511a4, 0x2a00111b, 0x291c1a0c, 0x091827ad,   // ro.rw.sq_433 ro.mt.un_770  tl.id.sl_543 gd.ga.pl_643
  0x1a2a11ec, 0x202855a4, 0x281e1ca4, 0x35040805,   // ro.mt.tl_644 rw.sw.sq_433  id.ms.sw_433 no.fi.zu_333
  0x28551b0d, 0x20525508, 0x1c111ea4, 0x52112a08,   // tr.rw.sw_554 rw.ha.sq_443  ms.ro.id_433 mt.ro.ha_443
  // [5140]
  0x213b5508, 0x3b531808, 0x1a0b3b09, 0x55011fee,   // rw.so.jw_443 ga.ht.so_443  so.es.tl_444 cy.en.rw_422
  0x28521108, 0x205211a4, 0x010b0a09, 0x126b1a12,   // ro.ha.sw_443 ro.ha.sq_433  pt.es.en_444 tl.ceb.hu_654
  0x01313bee, 0x55281108, 0x20213b0c, 0x273f030c,   // so.az.en_422 ro.sw.rw_443  so.jw.sq_543 nl.af.gd_543
  0x0e000702, 0x31211b0c, 0x2b181fa4, 0x16202912,   // it.is.un_220 tr.jw.az_543  cy.ga.vi_433 sl.sq.hr_654
  // [5150]
  0x2a000307, 0x02120c04, 0x0c085204, 0x17005221,   // nl.mt.un_420 sv.hu.da_332  ha.no.sv_332 ha.sr.un_860
  0x106b1a0d, 0x551128ad, 0x250668ee, 0x25001108,   // tl.ceb.lt_554 sw.ro.rw_643  ig.de.eu_422 ro.eu.un_430
  0x04112aa4, 0x1c6b1e0c, 0x102a1160, 0x640a3505,   // mt.ro.fi_433 ms.ceb.id_543  ro.mt.lt_664 zu.pt.lg_333
  0x03002307, 0x3100111a, 0x201a110c, 0x041a110c,   // ca.nl.un_420 ro.az.un_760  ro.tl.sq_543 ro.tl.fi_543
  // [5160]
  0x68211307, 0x552864a0, 0x021008a4, 0x55682107,   // et.jw.ig_432 lg.sw.rw_322  no.lt.da_433 jw.ig.rw_432
  0x0e1729ac, 0x3f32290c, 0x1c231107, 0x10020f13,   // sl.sr.is_632 sl.bs.af_543  ro.ca.id_432 lv.da.lt_665
  0x271107ad, 0x16351aad, 0x172007a9, 0x026b3f07,   // it.ro.gd_643 tl.zu.hr_643  it.sq.sr_544 af.ceb.da_432
  0x1e1c1309, 0x23530560, 0x0e290f0c, 0x230e3f04,   // et.id.ms_444 fr.ht.ca_664  lv.sl.is_543 af.is.ca_332
  // [5170]
  0x29001e21, 0x0e006419, 0x0a230c04, 0x23290bee,   // ms.sl.un_860 lg.is.un_750  sv.ca.pt_332 es.sl.ca_422
  0x182027ad, 0x28135213, 0x0f64250c, 0x23005305,   // gd.sq.ga_643 ha.et.sw_665  eu.lg.lv_543 ht.ca.un_330
  0x07002504, 0x120364ee, 0x1b0a4a60, 0x523b0b55,   // eu.it.un_320 lg.nl.hu_422  yo.pt.tr_664 es.so.ha_442
  0x4a046407, 0x13001602, 0x32003105, 0x12062507,   // lg.fi.yo_432 hr.et.un_220  az.bs.un_330 eu.de.hu_432
  // [5180]
  0x3568640c, 0x64001f02, 0x0a00640c, 0x3f090804,   // lg.ig.zu_543 cy.lg.un_220  lg.pt.un_530 no.pl.af_332
  0x01002d04, 0x0e0d2dec, 0x08021b02, 0x3b041309,   // sk.en.un_320 sk.cs.is_644  tr.da.no_222 et.fi.so_444
  0x171321ad, 0x2a0918ee, 0x07170405, 0x12002809,   // jw.et.sr_643 ga.pl.mt_422  ru.sr.bg_333 sw.hu.un_440
  0x12005204, 0x0f001323, 0x18051108, 0x190b27a0,   // ha.hu.un_320 et.lv.un_880  ro.fr.ga_443 gd.es.gl_322
  // [5190]
  0x080a0408, 0x1e04640c, 0x06001008, 0x352855ec,   // ru.mk.uk_443 lg.fi.ms_543  lt.de.un_430 rw.sw.zu_644
  0x211c4aad, 0x100407ec, 0x322129a0, 0x5300680c,   // yo.id.jw_643 bg.ru.be_644  sl.jw.bs_322 ig.ht.un_530
  0x121a27a7, 0x352168a9, 0x28214a07, 0x1228640c,   // gd.tl.hu_532 ig.jw.zu_544  yo.jw.sw_432 lg.sw.hu_543
  0x2b00180c, 0x06185307, 0x07000114, 0x550a1bee,   // ga.vi.un_530 ht.ga.de_432  en.it.un_660 tr.pt.rw_422
  // [51a0]
  0x525528af, 0x2d3b1ea6, 0x0d001a04, 0x3b1f1e05,   // sw.rw.ha_655 ms.so.sk_521  tl.cs.un_320 ms.cy.so_333
  0x07211c0c, 0x55000d08, 0x0501110c, 0x64001f19,   // id.jw.it_543 cs.rw.un_430  ro.en.fr_543 cy.lg.un_750
  0x181127af, 0x252023a0, 0x1c1e3f0c, 0x053b2704,   // gd.ro.ga_655 ca.sq.eu_322  af.ms.id_543 gd.so.fr_332
  0x6423350d, 0x25556808, 0x122952a6, 0x06002704,   // zu.ca.lg_554 ig.rw.eu_443  ha.sl.hu_521 gd.de.un_320
  // [51b0]
  0x0b1f5208, 0x285255a0, 0x55020812, 0x0455280d,   // ha.cy.es_443 rw.ha.sw_322  no.da.rw_654 sw.rw.fi_554
  0x3f001e07, 0x1728290d, 0x0d003520, 0x3f000d04,   // ms.af.un_420 sl.sw.sr_554  zu.cs.un_850 cs.af.un_320
  0x550f0708, 0x01681b0d, 0x042111a4, 0x10270408,   // it.lv.rw_443 tr.ig.en_554  ro.jw.fi_433 fi.gd.lt_443
  0x11282009, 0x13525513, 0x2a0955a7, 0x041c550c,   // sq.sw.ro_444 rw.ha.et_665  rw.pl.mt_532 rw.id.fi_543
  // [51c0]
  0x646b550c, 0x02045208, 0x3555280c, 0x1f52280c,   // rw.ceb.lg_543 ha.fi.da_443  sw.rw.zu_543 sw.ha.cy_543
  0x273f02ad, 0x080255ee, 0x523b21a4, 0x31113bec,   // da.af.gd_643 rw.da.no_422  jw.so.ha_433 so.ro.az_644
  0x28006b22, 0x0f283504, 0x190b35ad, 0x17551e0d,   // ceb.sw.un_870 zu.sw.lv_332  zu.es.gl_643 ms.rw.sr_554
  0x080205a4, 0x553f1f07, 0x070408ac, 0x13210c05,   // fr.da.no_433 cy.af.rw_432  uk.ru.bg_632 sv.jw.et_333
  // [51d0]
  0x353f0311, 0x190a23a4, 0x100c08af, 0x0821350c,   // nl.af.zu_653 ca.pt.gl_433  no.sv.lt_655 zu.jw.no_543
  0x29072aee, 0x1113350c, 0x35281a07, 0x190b1aee,   // mt.it.sl_422 zu.et.ro_543  tl.sw.zu_432 tl.es.gl_422
  0x25350308, 0x2d521aee, 0x291705ad, 0x0c2925a9,   // nl.zu.eu_443 tl.ha.sk_422  fr.sr.sl_643 eu.sl.sv_544
  0x0c08290c, 0x64001902, 0x551a2812, 0x1a641c0c,   // sl.no.sv_543 gl.lg.un_220  sw.tl.rw_654 id.lg.tl_543
  // [51e0]
  0x11351fee, 0x28016405, 0x6b1a2814, 0x35003b0d,   // cy.zu.ro_422 lg.en.sw_333  sw.tl.ceb_666 so.zu.un_540
  0x0f0c08af, 0x01350ba4, 0x171108a4, 0x3b1052a9,   // no.sv.lv_655 es.zu.en_433  uk.ro.sr_433 ha.lt.so_544
  0x09352513, 0x1a3b5212, 0x1e1c2155, 0x0a072d05,   // eu.zu.pl_665 ha.so.tl_654  jw.id.ms_442 sk.it.pt_333
  0x293525a9, 0x190b55ec, 0x35645509, 0x170a2d07,   // eu.zu.sl_544 rw.es.gl_644  rw.lg.zu_444 sk.pt.sr_432
  // [51f0]
  0x0c0f040c, 0x19003b19, 0x0a3b190c, 0x0e1f0c0d,   // fi.lv.sv_543 so.gl.un_750  gl.so.pt_543 sv.cy.is_554
  0x082a07a7, 0x1c351ea4, 0x28321613, 0x21006e0d,   // it.mt.no_532 ms.zu.id_433  hr.bs.sw_665 hmn.jw.un_540
  0x1b64350d, 0x31000a19, 0x020c08a9, 0x3b281e0c,   // zu.lg.tr_554 pt.az.un_750  no.sv.da_544 ms.sw.so_543
  0x17003512, 0x642a550c, 0x0a0b190b, 0x6b184a11,   // zu.sr.un_640 rw.mt.lg_543  gl.es.pt_542 yo.ga.ceb_653
  // [5200]
  0x321729af, 0x083f0c0c, 0x084a6b02, 0x20000807,   // sl.sr.bs_655 sv.af.no_543  ceb.yo.no_222 no.sq.un_420
  0x211a350b, 0x35000b04, 0x53522807, 0x050b0a04,   // zu.tl.jw_542 es.zu.un_320  sw.ha.ht_432 pt.es.fr_332
  0x0d000221, 0x0e3f1f04, 0x3f0d11ee, 0x012523ad,   // da.cs.un_860 cy.af.is_332  ro.cs.af_422 ca.eu.en_643
  0x35002818, 0x0c082905, 0x09010da4, 0x130c010b,   // sw.zu.un_740 sl.no.sv_333  cs.en.pl_433 en.sv.et_542
  // [5210]
  0x28310b05, 0x3b012aee, 0x2a3b11ad, 0x010309a6,   // es.az.sw_333 mt.en.so_422  ro.so.mt_643 pl.nl.en_521
  0x11350502, 0x121311ec, 0x0500271b, 0x0d1218ad,   // fr.zu.ro_222 ro.et.hu_644  gd.fr.un_770 ga.hu.cs_643
  0x2a0201a4, 0x1f312308, 0x52270c12, 0x10131108,   // en.da.mt_433 ca.az.cy_443  sv.gd.ha_654 ro.et.lt_443
  0x1e005202, 0x00001b06, 0x286b35a0, 0x211b310c,   // ha.ms.un_220 tr.un.un_400  zu.ceb.sw_322 az.tr.jw_543
  // [5220]
  0x1053680d, 0x35520eee, 0x233b01a4, 0x1e0413a0,   // ig.ht.lt_554 is.ha.zu_422  en.so.ca_433 et.fi.ms_322
  0x68086b0c, 0x55116807, 0x251211ad, 0x3f001108,   // ceb.no.ig_543 ig.ro.rw_432  ro.hu.eu_643 ro.af.un_430
  0x200c080c, 0x1e2a11ec, 0x0d0a0ea9, 0x0511290c,   // no.sv.sq_543 ro.mt.ms_644  is.pt.cs_544 sl.ro.fr_543
  0x21005307, 0x1327110c, 0x23101307, 0x0a251108,   // ht.jw.un_420 ro.gd.et_543  et.lt.ca_432 ro.eu.pt_443
  // [5230]
  0x062a3f55, 0x0c0a080b, 0x2109550d, 0x0e283508,   // af.mt.de_442 no.pt.sv_542  rw.pl.jw_554 zu.sw.is_443
  0x020c2305, 0x32002a19, 0x19110a05, 0x17001c04,   // ca.sv.da_333 mt.bs.un_750  pt.ro.gl_333 id.sr.un_320
  0x16520c07, 0x160b1fa7, 0x080e3f0c, 0x0a53030c,   // sv.ha.hr_432 cy.es.hr_532  af.is.no_543 nl.ht.pt_543
  0x250b2307, 0x081220ad, 0x212a1c12, 0x3b081ca7,   // ca.es.eu_432 sq.hu.no_643  id.mt.jw_654 id.no.so_532
  // [5240]
  0x102017ee, 0x5500121b, 0x32001b0d, 0x16553508,   // sr.sq.lt_422 hu.rw.un_770  tr.bs.un_540 zu.rw.hr_443
  0x280f520c, 0x27190b11, 0x1752290c, 0x1b18270c,   // ha.lv.sw_543 es.gl.gd_653  sl.ha.sr_543 gd.ga.tr_543
  0x072327a0, 0x202832a0, 0x190b11ec, 0x0f105208,   // gd.ca.it_322 bs.sw.sq_322  ro.es.gl_644 ha.lt.lv_443
  0x0800031b, 0x04000835, 0x0b292d12, 0x53551bec,   // nl.no.un_770 uk.ru.un_A90  sk.sl.es_654 tr.rw.ht_644
  // [5250]
  0x1b553504, 0x0d132d12, 0x21003108, 0x10280da4,   // zu.rw.tr_332 sk.et.cs_654  az.jw.un_430 cs.sw.lt_433
  0x3100281b, 0x0b090709, 0x28013504, 0x09122707,   // sw.az.un_770 it.pl.es_444  zu.en.sw_332 gd.hu.pl_432
  0x18072707, 0x3b002104, 0x1725280c, 0x17001e07,   // gd.it.ga_432 jw.so.un_320  sw.eu.sr_543 ms.sr.un_420
  0x04282560, 0x28555312, 0x32171b0c, 0x28001905,   // eu.sw.fi_664 ht.rw.sw_654  tr.sr.bs_543 gl.sw.un_330
  // [5260]
  0x0c0f1005, 0x0d290912, 0x01190b13, 0x081218af,   // lt.lv.sv_333 pl.sl.cs_654  es.gl.en_665 ga.hu.no_655
  0x25640c55, 0x25211ca9, 0x641a4aaf, 0x00000737,   // sv.lg.eu_442 id.jw.eu_544  yo.tl.lg_655 it.un.un_B00
  0x01000707, 0x1e1c29af, 0x0b070aee, 0x09006e04,   // it.en.un_420 sl.id.ms_655  pt.it.es_422 hmn.pl.un_320
  0x1a1c6ba4, 0x2b00181b, 0x050820af, 0x31000712,   // ceb.id.tl_433 ga.vi.un_770  sq.no.fr_655 it.az.un_640
  // [5270]
  0x31041ba9, 0x3b131f0c, 0x130b6bec, 0x202a13a4,   // tr.fi.az_544 cy.et.so_543  ceb.es.et_644 et.mt.sq_433
  0x060c1205, 0x6b001334, 0x08006b13, 0x6b130d11,   // hu.sv.de_333 et.ceb.un_A80  ceb.no.un_650 cs.et.ceb_653
  0x64352108, 0x1e3b1312, 0x352955a4, 0x0a07310c,   // jw.zu.lg_443 et.so.ms_654  rw.sl.zu_433 az.it.pt_543
  0x0964550c, 0x1b23310c, 0x080213ee, 0x06000504,   // rw.lg.pl_543 az.ca.tr_543  et.da.no_422 fr.de.un_320
  // [5280]
  0x6b112004, 0x106428a4, 0x1a6452a7, 0x55311ba4,   // sq.ro.ceb_332 sw.lg.lt_433  ha.lg.tl_532 tr.az.rw_433
  0x23181f12, 0x0c356b55, 0x1a006b02, 0x12001c02,   // cy.ga.ca_654 ceb.zu.sv_442  ceb.tl.un_220 id.hu.un_220
  0x10000104, 0x200f10af, 0x08120c02, 0x19001813,   // en.lt.un_320 lt.lv.sq_655  sv.hu.no_222 ga.gl.un_650
  0x2800680c, 0x6b000d13, 0x13006b13, 0x1a1255ee,   // ig.sw.un_530 cs.ceb.un_650  ceb.et.un_650 rw.hu.tl_422
  // [5290]
  0x190b13a0, 0x53124a02, 0x08001304, 0x0a002a08,   // et.es.gl_322 yo.hu.ht_222  et.no.un_320 mt.pt.un_430
  0x1a002102, 0x35002307, 0x0a11175a, 0x0e1308ec,   // jw.tl.un_220 ca.zu.un_420  sr.ro.mk_553 no.et.is_644
  0x09000e09, 0x050c11a4, 0x136b2aa0, 0x211c01a9,   // is.pl.un_440 ro.sv.fr_433  mt.ceb.et_322 en.id.jw_544
  0x2a5204ad, 0x2100170c, 0x11521a0d, 0x0b004a1a,   // fi.ha.mt_643 sr.jw.un_530  tl.ha.ro_554 yo.es.un_760
  // [52a0]
  0x0911230b, 0x082302ee, 0x6b521aa9, 0x21232aee,   // ca.ro.pl_542 da.ca.no_422  tl.ha.ceb_544 mt.ca.jw_422
  0x520e2805, 0x4a005213, 0x21551ea9, 0x090b2508,   // sw.is.ha_333 ha.yo.un_650  ms.rw.jw_544 eu.es.pl_443
  0x28684a0d, 0x550b1bee, 0x0d092a04, 0x063b1ca4,   // yo.ig.sw_554 tr.es.rw_422  mt.pl.cs_332 id.so.de_433
  0x28104aec, 0x08031208, 0x25552808, 0x1b55310e,   // yo.lt.sw_644 hu.nl.no_443  sw.rw.eu_443 az.rw.tr_555
  // [52b0]
  0x4a55520c, 0x012305ad, 0x23070207, 0x0c120808,   // ha.rw.yo_543 fr.ca.en_643  da.it.ca_432 no.hu.sv_443
  0x1b312012, 0x21006812, 0x522555a4, 0x2d1218af,   // sq.az.tr_654 ig.jw.un_640  rw.eu.ha_433 ga.hu.sk_655
  0x522168ec, 0x1e212a12, 0x31003b2b, 0x130f0409,   // ig.jw.ha_644 mt.jw.ms_654  so.az.un_980 fi.lv.et_444
  0x21553bad, 0x521b0807, 0x20282755, 0x1b3504a4,   // so.rw.jw_643 no.tr.ha_432  gd.sw.sq_442 fi.zu.tr_433
  // [52c0]
  0x4a1b0f11, 0x3f001f19, 0x31001e07, 0x00001337,   // lv.tr.yo_653 cy.af.un_750  ms.az.un_420 bh.un.un_B00
  0x23072013, 0x0c3513a4, 0x2a230f04, 0x12061b04,   // sq.it.ca_665 et.zu.sv_433  lv.ca.mt_332 tr.de.hu_332
  0x0617130e, 0x20003b0d, 0x551c1ba4, 0x250413af,   // et.sr.de_555 so.sq.un_540  tr.id.rw_433 et.fi.eu_655
  0x553552a0, 0x31002a07, 0x683f06a4, 0x161335a4,   // ha.zu.rw_322 mt.az.un_420  de.af.ig_433 zu.et.hr_433
  // [52d0]
  0x01062705, 0x5300200c, 0x1c0e1204, 0x02355511,   // gd.de.en_333 sq.ht.un_530  hu.is.id_332 rw.zu.da_653
  0x020301a4, 0x0f005202, 0x06005218, 0x282a18a4,   // en.nl.da_433 ha.lv.un_220  ha.de.un_740 ga.mt.sw_433
  0x0d321708, 0x0d001e02, 0x25125555, 0x2100051a,   // sr.bs.cs_443 ms.cs.un_220  rw.hu.eu_442 fr.jw.un_760
  0x06200c04, 0x100a1705, 0x35555212, 0x250f13ee,   // sv.sq.de_332 sr.mk.be_333  ha.rw.zu_654 et.lv.eu_422
  // [52e0]
  0x2300290c, 0x250c13a4, 0x05002714, 0x0711050c,   // sl.ca.un_530 et.sv.eu_433  gd.fr.un_660 fr.ro.it_543
  0x04171005, 0x21550a04, 0x07050c05, 0x3b255208,   // be.sr.ru_333 pt.rw.jw_332  sv.fr.it_333 ha.eu.so_443
  0x033f1c04, 0x051a02ee, 0x23002107, 0x17100a13,   // id.af.nl_332 da.tl.fr_422  jw.ca.un_420 mk.be.sr_665
  0x0f00061a, 0x0a002305, 0x68281e12, 0x251a6b60,   // de.lv.un_760 ca.pt.un_330  ms.sw.ig_654 ceb.tl.eu_664
  // [52f0]
  0x06020fad, 0x16000507, 0x3f1306a4, 0x27013b04,   // lv.da.de_643 fr.hr.un_420  de.et.af_433 so.en.gd_332
  0x2a2864ad, 0x2a000c07, 0x03001c02, 0x0e002a07,   // lg.sw.mt_643 sv.mt.un_420  id.nl.un_220 mt.is.un_420
  0x25296808, 0x11002323, 0x2000090e, 0x1e1c0cee,   // ig.sl.eu_443 ca.ro.un_880  pl.sq.un_550 sv.id.ms_422
  0x68002a0c, 0x0e0208a4, 0x080e10a4, 0x230603a4,   // mt.ig.un_530 no.da.is_433  lt.is.no_433 nl.de.ca_433
  // [5300]
  0x321703a0, 0x13000621, 0x2d180ba9, 0x0c0308a9,   // nl.sr.bs_322 de.et.un_860  es.ga.sk_544 no.nl.sv_544
  0x06310f02, 0x032a20af, 0x6b000608, 0x0603010c,   // lv.az.de_222 sq.mt.nl_655  de.ceb.un_430 en.nl.de_543
  0x271101a9, 0x55352da4, 0x250803a0, 0x054a09a9,   // en.ro.gd_544 sk.zu.rw_433  nl.no.eu_322 pl.yo.fr_544
  0x05000213, 0x2b0121ee, 0x27181fad, 0x3b13040c,   // da.fr.un_650 jw.en.vi_422  cy.ga.gd_643 fi.et.so_543
  // [5310]
  0x19113b05, 0x02042ba0, 0x25054aa7, 0x1f00030d,   // so.ro.gl_333 vi.fi.da_322  yo.fr.eu_532 nl.cy.un_540
  0x2a08120e, 0x1b3b31ec, 0x050d01ec, 0x013f03af,   // hu.no.mt_555 az.so.tr_644  en.cs.fr_644 nl.af.en_655
  0x6b1f1a5a, 0x0e001119, 0x01033f08, 0x070a0413,   // tl.cy.ceb_553 ro.is.un_750  af.nl.en_443 ru.mk.bg_665
  0x080235a4, 0x033f21af, 0x04111ba4, 0x3f100a07,   // zu.da.no_433 jw.af.nl_655  tr.ro.fi_433 pt.lt.af_432
  // [5320]
  0x01556807, 0x522855ec, 0x031c1e0c, 0x0c031907,   // ig.rw.en_432 rw.sw.ha_644  ms.id.nl_543 gl.nl.sv_432
  0x133b6405, 0x27201f0c, 0x030c19ee, 0x0c045212,   // lg.so.et_333 cy.sq.gd_543  gl.sv.nl_422 ha.fi.sv_654
  0x64006821, 0x310453ec, 0x06210eee, 0x0464130c,   // ig.lg.un_860 ht.fi.az_644  is.jw.de_422 et.lg.fi_543
  0x1a00532a, 0x01030faf, 0x133b0414, 0x0e000a19,   // ht.tl.un_970 lv.nl.en_655  fi.so.et_666 pt.is.un_750
  // [5330]
  0x052923a0, 0x2d0d1ea4, 0x68536b0c, 0x03270613,   // ca.sl.fr_322 ms.cs.sk_433  ceb.ht.ig_543 de.gd.nl_665
  0x35251c12, 0x12000b14, 0x23013f0c, 0x043b2707,   // id.eu.zu_654 es.hu.un_660  af.en.ca_543 gd.so.fi_432
  0x18000a18, 0x0e181912, 0x55350612, 0x2000270e,   // pt.ga.un_740 gl.ga.is_654  de.zu.rw_654 gd.sq.un_550
  0x08021b05, 0x524a20a4, 0x29535513, 0x13251ea4,   // tr.da.no_333 sq.yo.ha_433  rw.ht.sl_665 ms.eu.et_433
  // [5340]
  0x112a07a4, 0x25681309, 0x29005212, 0x04251308,   // it.mt.ro_433 et.ig.eu_444  ha.sl.un_640 et.eu.fi_443
  0x68005312, 0x2d535505, 0x1312530b, 0x21250c08,   // ht.ig.un_640 rw.ht.sk_333  ht.hu.et_542 sv.eu.jw_443
  0x11000b08, 0x1b006b19, 0x03000714, 0x2d0f0d0c,   // es.ro.un_430 ceb.tr.un_750  it.nl.un_660 cs.lv.sk_543
  0x111707af, 0x0a5355a4, 0x092025a9, 0x211b020c,   // bg.sr.ro_655 rw.ht.pt_433  eu.sq.pl_544 da.tr.jw_543
  // [5350]
  0x07002a07, 0x286420af, 0x13324a02, 0x20000c1a,   // mt.it.un_420 sq.lg.sw_655  yo.bs.et_222 sv.sq.un_760
  0x0a16230c, 0x64682109, 0x182b28a0, 0x313f0fad,   // ca.hr.pt_543 jw.ig.lg_444  sw.vi.ga_322 lv.af.az_643
  0x2021130c, 0x32000f19, 0x4a00120d, 0x3f080f04,   // et.jw.sq_543 lv.bs.un_750  hu.yo.un_540 lv.no.af_332
  0x18003f04, 0x0a006b0b, 0x55001e08, 0x29001c02,   // af.ga.un_320 ceb.pt.un_520  ms.rw.un_430 id.sl.un_220
  // [5360]
  0x020608a9, 0x1c130d12, 0x080221ee, 0x27006b34,   // no.de.da_544 ne.bh.mr_654  jw.da.no_422 ceb.gd.un_A80
  0x123501a9, 0x0c270805, 0x283518a9, 0x2b35050c,   // en.zu.hu_544 no.gd.sv_333  ga.zu.sw_544 fr.zu.vi_543
  0x3f1f0e60, 0x1c131eac, 0x1f002714, 0x21041eee,   // is.cy.af_664 ms.et.id_632  gd.cy.un_660 ms.fi.jw_422
  0x6b030ca0, 0x05202b04, 0x13352aee, 0x2300040d,   // sv.nl.ceb_322 vi.sq.fr_332  mt.zu.et_422 fi.ca.un_540
  // [5370]
  0x0d180aaf, 0x20002122, 0x171b2304, 0x11001c09,   // pt.ga.cs_655 jw.sq.un_870  ca.tr.sr_332 id.ro.un_440
  0x0d3119ee, 0x11002a0c, 0x6b20230c, 0x080212ee,   // gl.az.cs_422 mt.ro.un_530  ca.sq.ceb_543 hu.da.no_422
  0x292a0dee, 0x1f0827ac, 0x1b003b0e, 0x050c5304,   // cs.mt.sl_422 gd.no.cy_632  so.tr.un_550 ht.sv.fr_332
  0x290c0e11, 0x1b2a04ad, 0x1b002a19, 0x13041ea4,   // is.sv.sl_653 fi.mt.tr_643  mt.tr.un_750 ms.fi.et_433
  // [5380]
  0x07005504, 0x041711a6, 0x04641804, 0x35002b07,   // rw.it.un_320 ro.sr.ru_521  ga.lg.fi_332 vi.zu.un_420
  0x550728af, 0x1135070c, 0x0d00550d, 0x20551702,   // sw.it.rw_655 it.zu.ro_543  rw.cs.un_540 sr.rw.sq_222
  0x350364ec, 0x09001a04, 0x2d0d0aee, 0x18003507,   // lg.nl.zu_644 tl.pl.un_320  pt.cs.sk_422 zu.ga.un_420
  0x55641a13, 0x35533105, 0x20006413, 0x350d64ad,   // tl.lg.rw_665 az.ht.zu_333  lg.sq.un_650 lg.cs.zu_643
  // [5390]
  0x091a6ba4, 0x09000513, 0x351a13af, 0x3b04200c,   // ceb.tl.pl_433 fr.pl.un_650  et.tl.zu_655 sq.fi.so_543
  0x352564ec, 0x180452a0, 0x130464af, 0x1e1064ad,   // lg.eu.zu_644 ha.fi.ga_322  lg.fi.et_655 lg.lt.ms_643
  0x041b35a9, 0x03110208, 0x2d060dad, 0x1100531b,   // zu.tr.fi_544 da.ro.nl_443  cs.de.sk_643 ht.ro.un_770
  0x1c121eaf, 0x0e2a23a7, 0x271813a4, 0x10040711,   // ms.hu.id_655 ca.mt.is_532  et.ga.gd_433 bg.ru.be_653
  // [53a0]
  0x310f2555, 0x296416ee, 0x5300190d, 0x2d2916a7,   // eu.lv.az_442 hr.lg.sl_422  gl.ht.un_540 hr.sl.sk_532
  0x352532ee, 0x11002908, 0x0a0813ee, 0x1e1a53a4,   // bs.eu.zu_422 sl.ro.un_430  et.no.pt_422 ht.tl.ms_433
  0x03120aad, 0x6404100c, 0x1a352811, 0x183527a7,   // pt.hu.nl_643 lt.fi.lg_543  sw.zu.tl_653 gd.zu.ga_532
  0x20001c08, 0x10003f13, 0x07170802, 0x0f286412,   // id.sq.un_430 af.lt.un_650  uk.sr.bg_222 lg.sw.lv_654
  // [53b0]
  0x04643512, 0x08111711, 0x190a2da4, 0x0a111304,   // zu.lg.fi_654 sr.ro.uk_653  sk.pt.gl_433 et.ro.pt_332
  0x05232b08, 0x292d08a0, 0x2d0d13a0, 0x6b3f0312,   // vi.ca.fr_443 no.sk.sl_322  et.cs.sk_322 nl.af.ceb_654
  0x3f1e1ca4, 0x05101fec, 0x08030611, 0x28041311,   // id.ms.af_433 cy.lt.fr_644  de.nl.no_653 et.fi.sw_653
  0x0e1c1aa4, 0x68350d07, 0x21521b09, 0x04111c04,   // tl.id.is_433 cs.zu.ig_432  tr.ha.jw_444 id.ro.fi_332
  // [53c0]
  0x0a0410af, 0x1f09350c, 0x02080e55, 0x0a2d0da4,   // be.ru.mk_655 zu.pl.cy_543  is.no.da_442 cs.sk.pt_433
  0x032d20a4, 0x173129a4, 0x211820af, 0x0e3553a9,   // sq.sk.nl_433 sl.az.sr_433  sq.ga.jw_655 ht.zu.is_544
  0x12552107, 0x033f0811, 0x32292da0, 0x53350a08,   // jw.rw.hu_432 no.af.nl_653  sk.sl.bs_322 pt.zu.ht_443
  0x28131a04, 0x072a3505, 0x06552805, 0x2a001304,   // tl.et.sw_332 zu.mt.it_333  sw.rw.de_333 et.mt.un_320
  // [53d0]
  0x1b060c12, 0x07003502, 0x2d0d21a4, 0x216b52a0,   // sv.de.tr_654 zu.it.un_220  jw.cs.sk_433 ha.ceb.jw_322
  0x2800210d, 0x0b1f23af, 0x291353a0, 0x25041308,   // jw.sw.un_540 ca.cy.es_655  ht.et.sl_322 et.fi.eu_443
  0x20001222, 0x64212305, 0x122a0408, 0x201f0107,   // hu.sq.un_870 ca.jw.lg_333  fi.mt.hu_443 en.cy.sq_432
  0x031e010c, 0x250b01ee, 0x20131e0c, 0x530913a9,   // en.ms.nl_543 en.es.eu_422  ms.et.sq_543 et.pl.ht_544
  // [53e0]
  0x0800210d, 0x2d003b22, 0x552d0314, 0x1b5253a4,   // jw.no.un_540 so.sk.un_870  nl.sk.rw_666 ht.ha.tr_433
  0x552112ad, 0x52000112, 0x174a52af, 0x20282104,   // hu.jw.rw_643 en.ha.un_640  ha.yo.sr_655 jw.sw.sq_332
  0x061f18a4, 0x2d0d35ee, 0x03552808, 0x201164a0,   // ga.cy.de_433 zu.cs.sk_422  sw.rw.nl_443 lg.ro.sq_322
  0x20005521, 0x08002022, 0x21014a07, 0x68355512,   // rw.sq.un_860 sq.no.un_870  yo.en.jw_432 rw.zu.ig_654
  // [53f0]
  0x165504ee, 0x55000b09, 0x20521ea4, 0x160e04a4,   // fi.rw.hr_422 es.rw.un_440  ms.ha.sq_433 fi.is.hr_433
  0x12002014, 0x160d2904, 0x522a10ad, 0x2b002511,   // sq.hu.un_660 sl.cs.hr_332  lt.mt.ha_643 eu.vi.un_630
  0x13000f02, 0x280b55a4, 0x0c0809af, 0x1c3f2807,   // lv.et.un_220 rw.es.sw_433  pl.no.sv_655 sw.af.id_432
  0x06081307, 0x5301280c, 0x321752a0, 0x072d2907,   // et.no.de_432 sw.en.ht_543  ha.sr.bs_322 sl.sk.it_432

  // [5400]
  0x20002107, 0x07001321, 0x3125280c, 0x165228a4,   // jw.sq.un_420 et.it.un_860  sw.eu.az_543 sw.ha.hr_433
  0x021b17a0, 0x1b532104, 0x071f2904, 0x1b1a6b0d,   // sr.tr.da_322 jw.ht.tr_332  sl.cy.it_332 ceb.tl.tr_554
  0x011311a0, 0x6e003f04, 0x050e1fee, 0x32031e07,   // ro.et.en_322 af.hmn.un_320  cy.is.fr_422 ms.nl.bs_432
  0x1c531f04, 0x21352812, 0x3b040c0c, 0x0b231fec,   // cy.ht.id_332 sw.zu.jw_654  sv.fi.so_543 cy.ca.es_644
  // [5410]
  0x131f31a9, 0x2b006b07, 0x04002507, 0x1a1b6bad,   // az.cy.et_544 ceb.vi.un_420  eu.fi.un_420 ceb.tr.tl_643
  0x1c3b27a4, 0x04251ca7, 0x19272d07, 0x35133113,   // gd.so.id_433 id.eu.fi_532  sk.gd.gl_432 az.et.zu_665
  0x31005321, 0x132506a4, 0x1a215312, 0x12251b08,   // ht.az.un_860 de.eu.et_433  ht.jw.tl_654 tr.eu.hu_443
  0x032a130c, 0x271e1c08, 0x033f0513, 0x18000804,   // et.mt.nl_543 id.ms.gd_443  fr.af.nl_665 no.ga.un_320
  // [5420]
  0x2100531a, 0x0828010c, 0x27050411, 0x12200607,   // ht.jw.un_760 en.sw.no_543  fi.fr.gd_653 de.sq.hu_432
  0x27130405, 0x1f1a1bee, 0x0c060ea0, 0x01004a02,   // fi.et.gd_333 tr.tl.cy_422  is.de.sv_322 yo.en.un_220
  0x16000607, 0x251064a4, 0x09000c04, 0x0a000d12,   // de.hr.un_420 lg.lt.eu_433  sv.pl.un_320 cs.pt.un_640
  0x080c020d, 0x182b01ad, 0x131c0da4, 0x20003504,   // da.sv.no_554 en.vi.ga_643  ne.mr.bh_433 zu.sq.un_320
  // [5430]
  0x27181ca0, 0x1c3b1eaf, 0x07042a60, 0x23000504,   // id.ga.gd_322 ms.so.id_655  mt.fi.it_664 fr.ca.un_320
  0x0b000e05, 0x12130908, 0x2012130c, 0x2d0d0aa4,   // is.es.un_330 pl.et.hu_443  et.hu.sq_543 pt.cs.sk_433
  0x53006b0b, 0x080e0413, 0x080253ec, 0x201325a4,   // ceb.ht.un_520 fi.is.no_665  ht.da.no_644 eu.et.sq_433
  0x0d000a0e, 0x104a2008, 0x25070ea0, 0x1b001a02,   // pt.cs.un_550 sq.yo.lt_443  is.it.eu_322 tl.tr.un_220
  // [5440]
  0x64553505, 0x081b040c, 0x020c52a7, 0x13201f12,   // zu.rw.lg_333 fi.tr.no_543  ha.sv.da_532 cy.sq.et_654
  0x13645508, 0x190a18a6, 0x1000270e, 0x2a3f0308,   // rw.lg.et_443 ga.pt.gl_521  gd.lt.un_550 nl.af.mt_443
  0x0d071304, 0x28321608, 0x0f030ea7, 0x02292d08,   // et.it.cs_332 hr.bs.sw_443  is.nl.lv_532 sk.sl.da_443
  0x293f0308, 0x280e13ad, 0x28355507, 0x3b00682a,   // nl.af.sl_443 et.is.sw_643  rw.zu.sw_432 ig.so.un_970
  // [5450]
  0x1f2701a4, 0x04311b07, 0x04050c11, 0x182327a4,   // en.gd.cy_433 tr.az.fi_432  sv.fr.fi_653 gd.ca.ga_433
  0x290d1f04, 0x120306ee, 0x21040204, 0x08060c02,   // cy.cs.sl_332 de.nl.hu_422  da.fi.jw_332 sv.de.no_222
  0x0c02035a, 0x29090f0e, 0x0c021f07, 0x04030611,   // nl.da.sv_553 lv.pl.sl_555  cy.da.sv_432 de.nl.fi_653
  0x02001f11, 0x522d04ac, 0x35000e09, 0x3f080f07,   // cy.da.un_630 fi.sk.ha_632  is.zu.un_440 lv.no.af_432
  // [5460]
  0x0a003508, 0x21531bad, 0x311b1904, 0x080e2a09,   // zu.pt.un_430 tr.ht.jw_643  gl.tr.az_332 mt.is.no_444
  0x0c231fa4, 0x1e0e1ca0, 0x32021fee, 0x080e64a0,   // cy.ca.sv_433 id.is.ms_322  cy.da.bs_422 lg.is.no_322
  0x1b531a0c, 0x17110aa7, 0x2d0d4aec, 0x07001714,   // tl.ht.tr_543 mk.ro.sr_532  yo.cs.sk_644 sr.bg.un_660
  0x12001a12, 0x110c23a4, 0x0e182dad, 0x0f002704,   // tl.hu.un_640 ca.sv.ro_433  sk.ga.is_643 gd.lv.un_320
  // [5470]
  0x1f001e04, 0x190a11ee, 0x0e003521, 0x190b4aa0,   // ms.cy.un_320 ro.pt.gl_422  zu.is.un_860 yo.es.gl_322
  0x01001e02, 0x0c0e0308, 0x190b4a09, 0x12005202,   // ms.en.un_220 nl.is.sv_443  yo.es.gl_444 ha.hu.un_220
  0x17001e04, 0x02031304, 0x200c11ee, 0x062718a9,   // ms.sr.un_320 et.nl.da_332  ro.sv.sq_422 ga.gd.de_544
  0x552028a4, 0x020f080c, 0x2902030c, 0x0a11040c,   // sw.sq.rw_433 no.lv.da_543  nl.da.sl_543 ru.ro.mk_543
  // [5480]
  0x314a1eee, 0x1e6b1ca4, 0x06030e11, 0x06106b08,   // ms.yo.az_422 id.ceb.ms_433  is.nl.de_653 ceb.lt.de_443
  0x05232011, 0x1b003508, 0x32131607, 0x074a19a0,   // sq.ca.fr_653 zu.tr.un_430  hr.et.bs_432 gl.yo.it_322
  0x20252a07, 0x31682105, 0x180501ec, 0x19005319,   // mt.eu.sq_432 jw.ig.az_333  en.fr.ga_644 ht.gl.un_750
  0x2d001f1a, 0x052718a4, 0x110a080c, 0x1f003f1a,   // cy.sk.un_760 ga.gd.fr_433  uk.mk.ro_543 af.cy.un_760
  // [5490]
  0x5300231d, 0x13080ea7, 0x0718275a, 0x0e03010c,   // ca.ht.un_820 is.no.et_532  gd.ga.it_553 en.nl.is_543
  0x0600251b, 0x112501ad, 0x05000a14, 0x0a2d0d08,   // eu.de.un_770 en.eu.ro_643  pt.fr.un_660 cs.sk.pt_443
  0x0f006e08, 0x52003b13, 0x021b6b12, 0x2b212512,   // hmn.lv.un_430 so.ha.un_650  ceb.tr.da_654 eu.jw.vi_654
  0x25006b1a, 0x04250513, 0x2500680d, 0x1805010c,   // ceb.eu.un_760 fr.eu.fi_665  ig.eu.un_540 en.fr.ga_543
  // [54a0]
  0x25002122, 0x2a002904, 0x6b000e13, 0x1f003f08,   // jw.eu.un_870 sl.mt.un_320  is.ceb.un_650 af.cy.un_430
  0x100c3f13, 0x53072305, 0x64315504, 0x3b045207,   // af.sv.lt_665 ca.it.ht_333  rw.az.lg_332 ha.fi.so_432
  0x28000713, 0x35521a07, 0x1c213108, 0x2b6b2512,   // it.sw.un_650 tl.ha.zu_432  az.jw.id_443 eu.ceb.vi_654
  0x0c106b0c, 0x03190b08, 0x05005312, 0x2d0d18ee,   // ceb.lt.sv_543 es.gl.nl_443  ht.fr.un_640 ga.cs.sk_422
  // [54b0]
  0x030511ee, 0x1e521f07, 0x0b110560, 0x255535a4,   // ro.fr.nl_422 cy.ha.ms_432  fr.ro.es_664 zu.rw.eu_433
  0x55351211, 0x2d001602, 0x10002104, 0x0c1a0604,   // hu.zu.rw_653 hr.sk.un_220  jw.lt.un_320 de.tl.sv_332
  0x5255535a, 0x1b0953ad, 0x29175307, 0x31193507,   // ht.rw.ha_553 ht.pl.tr_643  ht.sr.sl_432 zu.gl.az_432
  0x232719ee, 0x295255a4, 0x2a100f0c, 0x0a0417ec,   // gl.gd.ca_422 rw.ha.sl_433  lv.lt.mt_543 sr.ru.mk_644
  // [54c0]
  0x5511350c, 0x686b01a6, 0x0f100112, 0x27006807,   // zu.ro.rw_543 en.ceb.ig_521  en.lt.lv_654 ig.gd.un_420
  0x1b311aa9, 0x0a201b12, 0x050f100c, 0x063120ee,   // tl.az.tr_544 tr.sq.pt_654  lt.lv.fr_543 sq.az.de_422
  0x311b1a14, 0x2300181a, 0x32161309, 0x1c130d09,   // tl.tr.az_666 ga.ca.un_760  et.hr.bs_444 ne.bh.mr_444
  0x0f101aa7, 0x010f13ec, 0x53322912, 0x52201e04,   // tl.lt.lv_532 et.lv.en_644  sl.bs.ht_654 ms.sq.ha_332
  // [54d0]
  0x233f01a9, 0x010e050c, 0x063f01a4, 0x6e000104,   // en.af.ca_544 fr.is.en_543  en.af.de_433 en.hmn.un_320
  0x060f0107, 0x52001014, 0x180123a9, 0x04521313,   // en.lv.de_432 lt.ha.un_660  ca.en.ga_544 et.ha.fi_665
  0x13005307, 0x2b18270c, 0x05001e02, 0x3b01280c,   // ht.et.un_420 gd.ga.vi_543  ms.fr.un_220 sw.en.so_543
  0x23001f21, 0x35643112, 0x181027ec, 0x10281aad,   // cy.ca.un_860 az.lg.zu_654  gd.lt.ga_644 tl.sw.lt_643
  // [54e0]
  0x31525504, 0x6e00012b, 0x35110aa4, 0x1b1a3108,   // rw.ha.az_332 en.hmn.un_980  pt.ro.zu_433 az.tl.tr_443
  0x6e00100e, 0x2d0d03a9, 0x1a001e1a, 0x082a010d,   // lt.hmn.un_550 nl.cs.sk_544  ms.tl.un_760 en.mt.no_554
  0x172a070b, 0x25033fad, 0x091308ad, 0x131a1ca4,   // it.mt.sr_542 af.nl.eu_643  no.et.pl_643 id.tl.et_433
  0x01002a07, 0x1a216bee, 0x356b6409, 0x283520a0,   // mt.en.un_420 ceb.jw.tl_422  lg.ceb.zu_444 sq.zu.sw_322
  // [54f0]
  0x01203b07, 0x05002b0e, 0x1b106b60, 0x1f1235ad,   // so.sq.en_432 vi.fr.un_550  ceb.lt.tr_664 zu.hu.cy_643
  0x0f556460, 0x6b013b07, 0x32132d0b, 0x0c0110ee,   // lg.rw.lv_664 so.en.ceb_432  sk.et.bs_542 lt.en.sv_422
  0x1b253113, 0x28090407, 0x08002713, 0x641b31ec,   // az.eu.tr_665 fi.pl.sw_432  gd.no.un_650 az.tr.lg_644
  0x172d29a0, 0x0d004a12, 0x311b530c, 0x641a1e12,   // sl.sk.sr_322 yo.cs.un_640  ht.tr.az_543 ms.tl.lg_654
  // [5500]
  0x190a10a4, 0x181223a9, 0x3f002514, 0x045228ad,   // lt.pt.gl_433 ca.hu.ga_544  eu.af.un_660 sw.ha.fi_643
  0x1f00010c, 0x0f095304, 0x110b01a4, 0x08071b04,   // en.cy.un_530 ht.pl.lv_332  en.es.ro_433 tr.it.no_332
  0x6855200c, 0x1e31100c, 0x281b35ad, 0x55005208,   // sq.rw.ig_543 lt.az.ms_543  zu.tr.sw_643 ha.rw.un_430
  0x05033f05, 0x55000714, 0x020c01a4, 0x550525a4,   // af.nl.fr_333 it.rw.un_660  en.sv.da_433 eu.fr.rw_433
  // [5510]
  0x3f002b0d, 0x0f005219, 0x190b12a4, 0x17292da4,   // vi.af.un_540 ha.lv.un_750  hu.es.gl_433 sk.sl.sr_433
  0x061101a4, 0x110129a4, 0x12190ea9, 0x1e1a1ca4,   // en.ro.de_433 sl.en.ro_433  is.gl.hu_544 id.tl.ms_433
  0x355306ad, 0x0d071313, 0x206e1a0c, 0x1c002b21,   // de.ht.zu_643 et.it.cs_665  tl.hmn.sq_543 vi.id.un_860
  0x68004a0d, 0x1e3b1c0c, 0x1b4a5504, 0x521e280c,   // yo.ig.un_540 id.so.ms_543  rw.yo.tr_332 sw.ms.ha_543
  // [5520]
  0x1b5553ec, 0x3f0301ad, 0x1a1e1c0c, 0x01271812,   // ht.rw.tr_644 en.nl.af_643  id.ms.tl_543 ga.gd.en_654
  0x3b042007, 0x25000629, 0x53045211, 0x1e131c07,   // sq.fi.so_432 de.eu.un_960  ha.fi.ht_653 id.et.ms_432
  0x016b35a0, 0x0d004a14, 0x2b641c0c, 0x6b1a3b0d,   // zu.ceb.en_322 yo.cs.un_660  id.lg.vi_543 so.tl.ceb_554
  0x21205304, 0x131104ee, 0x1a2821a4, 0x1c1316a0,   // ht.sq.jw_332 fi.ro.et_422  jw.sw.tl_433 hr.et.id_322
  // [5530]
  0x641a350c, 0x1a2155a9, 0x08040aad, 0x6b1a1ca9,   // zu.tl.lg_543 rw.jw.tl_544  mk.ru.uk_643 id.tl.ceb_544
  0x02283502, 0x21005504, 0x1e1c04a4, 0x23006e07,   // zu.sw.da_222 rw.jw.un_320  fi.id.ms_433 hmn.ca.un_420
  0x01001b08, 0x1e1c5302, 0x0c532308, 0x200d3ba9,   // tr.en.un_430 ht.id.ms_222  ca.ht.sv_443 so.cs.sq_544
  0x0c1b5305, 0x1f005204, 0x0e00522a, 0x283f5308,   // ht.tr.sv_333 ha.cy.un_320  ha.is.un_970 ht.af.sw_443
  // [5540]
  0x6b6853a7, 0x0c5323a4, 0x6e003204, 0x6b003507,   // ht.ig.ceb_532 ca.ht.sv_433  bs.hmn.un_320 zu.ceb.un_420
  0x0c531f55, 0x2b3f16a7, 0x3f1e1c0c, 0x025208a4,   // cy.ht.sv_442 hr.af.vi_532  id.ms.af_543 no.ha.da_433
  0x18052307, 0x291b0fa4, 0x2a0d3b07, 0x01001604,   // ca.fr.ga_432 lv.tr.sl_433  so.cs.mt_432 hr.en.un_320
  0x213f060c, 0x1b6e1604, 0x311b53ad, 0x03001308,   // de.af.jw_543 hr.hmn.tr_332  ht.tr.az_643 et.nl.un_430
  // [5550]
  0x526b1b0c, 0x0e0c5308, 0x28001314, 0x1e1c0ca9,   // tr.ceb.ha_543 ht.sv.is_443  et.sw.un_660 sv.id.ms_544
  0x231b53ad, 0x0a003b09, 0x35002104, 0x68353b0c,   // ht.tr.ca_643 so.pt.un_440  jw.zu.un_320 so.zu.ig_543
  0x1f522aa4, 0x3b004a08, 0x29173507, 0x1b12350c,   // mt.ha.cy_433 yo.so.un_430  zu.sr.sl_432 zu.hu.tr_543
  0x110a1760, 0x172916ad, 0x0b0a19a7, 0x130110a4,   // sr.mk.ro_664 hr.sl.sr_643  gl.pt.es_532 lt.en.et_433
  // [5560]
  0x521f3b07, 0x19002308, 0x20102812, 0x3227180c,   // so.cy.ha_432 ca.gl.un_430  sw.lt.sq_654 ga.gd.bs_543
  0x3f641307, 0x01231a08, 0x27001008, 0x020408a4,   // et.lg.af_432 tl.ca.en_443  lt.gd.un_430 no.fi.da_433
  0x6b000d08, 0x643f3ba4, 0x4a313bad, 0x252053a4,   // cs.ceb.un_430 so.af.lg_433  so.az.yo_643 ht.sq.eu_433
  0x522b010c, 0x534a5209, 0x192b0ba9, 0x550603ad,   // en.vi.ha_543 ha.yo.ht_444  es.vi.gl_544 nl.de.rw_643
  // [5570]
  0x0f0b53a4, 0x0a0e52a7, 0x0f0d2dad, 0x321752a9,   // ht.es.lv_433 ha.is.pt_532  sk.cs.lv_643 ha.sr.bs_544
  0x35033fee, 0x0204080c, 0x3b001e1a, 0x170b295a,   // af.nl.zu_422 no.fi.da_543  ms.so.un_760 sl.es.sr_553
  0x4a003b23, 0x0e5227a9, 0x13116408, 0x4a001113,   // so.yo.un_880 gd.ha.is_544  lg.ro.et_443 ro.yo.un_650
  0x06031f09, 0x1f0603a4, 0x255511a6, 0x135527ac,   // cy.nl.de_444 nl.de.cy_433  ro.rw.eu_521 gd.rw.et_632
  // [5580]
  0x1a3b0bee, 0x25556408, 0x0a002704, 0x523b11a4,   // es.so.tl_422 lg.rw.eu_443  gd.pt.un_320 ro.so.ha_433
  0x4a191e07, 0x2b1c2707, 0x25186405, 0x092921a4,   // ms.gl.yo_432 gd.id.vi_432  lg.ga.eu_333 jw.sl.pl_433
  0x6b3b2709, 0x641155a4, 0x046b13a4, 0x2d296460,   // gd.so.ceb_444 rw.ro.lg_433  et.ceb.fi_433 lg.sl.sk_664
  0x0d1b3b07, 0x64281a05, 0x011f55a0, 0x19101105,   // so.tr.cs_432 tl.sw.lg_333  rw.cy.en_322 ro.lt.gl_333
  // [5590]
  0x524a1e12, 0x0a100712, 0x35001123, 0x684a3b08,   // ms.yo.ha_654 bg.be.mk_654  ro.zu.un_880 so.yo.ig_443
  0x28113512, 0x203553a4, 0x1a68350c, 0x033513a9,   // zu.ro.sw_654 ht.zu.sq_433  zu.ig.tl_543 et.zu.nl_544
  0x3f03350c, 0x32161109, 0x29020c60, 0x1b11130c,   // zu.nl.af_543 ro.hr.bs_444  sv.da.sl_664 et.ro.tr_543
  0x31001607, 0x351a0c07, 0x09006e34, 0x03113508,   // hr.az.un_420 sv.tl.zu_432  hmn.pl.un_A80 zu.ro.nl_443
  // [55a0]
  0x1b113512, 0x031c1102, 0x03006e0e, 0x1c1b1eee,   // zu.ro.tr_654 ro.id.nl_222  hmn.nl.un_550 ms.tr.id_422
  0x3b2d0d05, 0x190b5209, 0x2d0d6e11, 0x1100351b,   // cs.sk.so_333 ha.es.gl_444  hmn.cs.sk_653 zu.ro.un_770
  0x02250811, 0x35004a1b, 0x5311350c, 0x042752ad,   // no.eu.da_653 yo.zu.un_770  zu.ro.ht_543 ha.gd.fi_643
  0x0d131113, 0x0c0620a4, 0x07191f07, 0x1b01530c,   // ro.et.cs_665 sq.de.sv_433  cy.gl.it_432 ht.en.tr_543
  // [55b0]
  0x10003122, 0x3f13110c, 0x113513af, 0x100711ec,   // az.lt.un_870 ro.et.af_543  et.zu.ro_655 ro.bg.be_644
  0x1f0e06a7, 0x052321ad, 0x012135af, 0x3b276ba4,   // de.is.cy_532 jw.ca.fr_643  zu.jw.en_655 ceb.gd.so_433
  0x31252a0c, 0x0c033fad, 0x13310cac, 0x3f0305a6,   // mt.eu.az_543 af.nl.sv_643  sv.az.et_632 fr.nl.af_521
  0x1a3b040c, 0x1b3212a7, 0x6b041f04, 0x1e002104,   // fi.so.tl_543 hu.bs.tr_532  cy.fi.ceb_332 jw.ms.un_320
  // [55c0]
  0x6e000a1b, 0x030c3f60, 0x21003b08, 0x1e086e0c,   // pt.hmn.un_770 af.sv.nl_664  so.jw.un_430 hmn.no.ms_543
  0x1200021a, 0x043b4aa0, 0x250c0ea4, 0x02006b02,   // da.hu.un_760 yo.so.fi_322  is.sv.eu_433 ceb.da.un_220
  0x6b1a2107, 0x110305ee, 0x056e1f0c, 0x02273f07,   // jw.tl.ceb_432 fr.nl.ro_422  cy.hmn.fr_543 af.gd.da_432
  0x530a52a9, 0x3b001a13, 0x120e4a5a, 0x1e00211a,   // ha.pt.ht_544 tl.so.un_650  yo.is.hu_553 jw.ms.un_760
  // [55d0]
  0x030c3f0c, 0x1b006b0c, 0x11030512, 0x0e003113,   // af.sv.nl_543 ceb.tr.un_530  fr.nl.ro_654 az.is.un_650
  0x04000621, 0x0d1c13a7, 0x3b1a040c, 0x2b0a6eec,   // de.fi.un_860 bh.mr.ne_532  fi.tl.so_543 hmn.pt.vi_644
  0x03000c05, 0x0c0204ad, 0x01680ea4, 0x311b0707,   // sv.nl.un_330 fi.da.sv_643  is.ig.en_433 it.tr.az_432
  0x3500040c, 0x2a002504, 0x3f1a210c, 0x020305a9,   // fi.zu.un_530 eu.mt.un_320  jw.tl.af_543 fr.nl.da_544
  // [55e0]
  0x0e0c0613, 0x2b00160e, 0x250f100c, 0x0311050c,   // de.sv.is_665 hr.vi.un_550  lt.lv.eu_543 fr.ro.nl_543
  0x0501235a, 0x20521fad, 0x11000717, 0x01002802,   // ca.en.fr_553 cy.ha.sq_643  it.ro.un_730 sw.en.un_220
  0x08072a0d, 0x1207640c, 0x1b0c31a4, 0x00001737,   // mt.it.no_554 lg.it.hu_543  az.sv.tr_433 sr.un.un_B00
  0x0400172c, 0x210d32a0, 0x530308a9, 0x030604ad,   // sr.ru.un_990 bs.cs.jw_322  no.nl.ht_544 fi.de.nl_643
  // [55f0]
  0x25002a05, 0x311b4aa4, 0x25005314, 0x060b03a4,   // mt.eu.un_330 yo.tr.az_433  ht.eu.un_660 nl.es.de_433
  0x21006e04, 0x53190111, 0x555352a9, 0x4a213f11,   // hmn.jw.un_320 en.gl.ht_653  ha.ht.rw_544 af.jw.yo_653
  0x0f106e60, 0x204a2112, 0x131b680c, 0x02003f29,   // hmn.lt.lv_664 jw.yo.sq_654  ig.tr.et_543 af.da.un_960
  0x13004a19, 0x081b0255, 0x021c2ba7, 0x2820070c,   // yo.et.un_750 da.tr.no_442  vi.id.da_532 it.sq.sw_543
  // [5600]
  0x3f640755, 0x086e4aa0, 0x0705520c, 0x02321605,   // it.lg.af_442 yo.hmn.no_322  ha.fr.it_543 hr.bs.da_333
  0x29191c08, 0x52132512, 0x4a1b02ee, 0x1a6e2855,   // id.gl.sl_443 eu.et.ha_654  da.tr.yo_422 sw.hmn.tl_442
  0x250603a9, 0x550d0504, 0x134a02a4, 0x2b681808,   // nl.de.eu_544 fr.cs.rw_332  da.yo.et_433 ga.ig.vi_443
  0x04000922, 0x10006e2a, 0x3200520b, 0x3f1768a4,   // pl.fi.un_870 hmn.lt.un_970  ha.bs.un_520 ig.sr.af_433
  // [5610]
  0x160853a4, 0x1b190b08, 0x11253b0c, 0x3f00090c,   // ht.no.hr_433 es.gl.tr_443  so.eu.ro_543 pl.af.un_530
  0x1a005521, 0x07006e05, 0x2a030905, 0x19090b0c,   // rw.tl.un_860 hmn.it.un_330  pl.nl.mt_333 es.pl.gl_543
  0x06523fa4, 0x1b000c0e, 0x1100522a, 0x6b311ba4,   // af.ha.de_433 sv.tr.un_550  ha.ro.un_970 tr.az.ceb_433
  0x0f6e0714, 0x6413550c, 0x680208af, 0x3f10230c,   // it.hmn.lv_666 rw.et.lg_543  no.da.ig_655 ca.lt.af_543
  // [5620]
  0x02532908, 0x021b11a6, 0x31022507, 0x0d291ea0,   // sl.ht.da_443 ro.tr.da_521  eu.da.az_432 ms.sl.cs_322
  0x0a6e2b05, 0x080203a4, 0x11081ea0, 0x0c100fa4,   // vi.hmn.pt_333 nl.da.no_433  ms.no.ro_322 lv.lt.sv_433
  0x030f090c, 0x1f0309ad, 0x09201b0c, 0x0b000609,   // pl.lv.nl_543 pl.nl.cy_643  tr.sq.pl_543 de.es.un_440
  0x030f29a9, 0x68356ea4, 0x103f0405, 0x6b130f07,   // sl.lv.nl_544 hmn.zu.ig_433  fi.af.lt_333 lv.et.ceb_432
  // [5630]
  0x1f0364a9, 0x2a180a09, 0x10060e04, 0x0f103fa7,   // lg.nl.cy_544 pt.ga.mt_444  is.de.lt_332 af.lt.lv_532
  0x0e3b0408, 0x02081107, 0x0c041fa0, 0x06001f04,   // fi.so.is_443 ro.no.da_432  cy.fi.sv_322 cy.de.un_320
  0x1a211c08, 0x0200012a, 0x1e531ca4, 0x23003b04,   // id.jw.tl_443 en.da.un_970  id.ht.ms_433 so.ca.un_320
  0x28001813, 0x170708ad, 0x0553020c, 0x0e1b0f04,   // ga.sw.un_650 uk.bg.sr_643  da.ht.fr_543 lv.tr.is_332
  // [5640]
  0x25000908, 0x05006807, 0x190b0705, 0x011f28a6,   // pl.eu.un_430 ig.fr.un_420  it.es.gl_333 sw.cy.en_521
  0x0b004a04, 0x1153050c, 0x683f27a9, 0x321b5308,   // yo.es.un_320 fr.ht.ro_543  gd.af.ig_544 ht.tr.bs_443
  0x352718ec, 0x251c1e0c, 0x28071108, 0x170d2da4,   // ga.gd.zu_644 ms.id.eu_543  ro.it.sw_443 sk.cs.sr_433
  0x08020114, 0x25041ea7, 0x1e28110c, 0x10111ba7,   // en.da.no_666 ms.fi.eu_532  ro.sw.ms_543 tr.ro.lt_532
  // [5650]
  0x53112512, 0x190a05ec, 0x17291eec, 0x0d091c0d,   // eu.ro.ht_654 fr.pt.gl_644  ms.sl.sr_644 mr.hi.ne_554
  0x066403a4, 0x29101f0c, 0x642d0d13, 0x21002a07,   // nl.lg.de_433 cy.lt.sl_543  cs.sk.lg_665 mt.jw.un_420
  0x6b1001a7, 0x191f2108, 0x68000321, 0x21001f0c,   // en.lt.ceb_532 jw.cy.gl_443  nl.ig.un_860 cy.jw.un_530
  0x060801a0, 0x07012a02, 0x101253ee, 0x0c004a02,   // en.no.de_322 mt.en.it_222  ht.hu.lt_422 yo.sv.un_220
  // [5660]
  0x6b091aa9, 0x6b6818ee, 0x080602ee, 0x680906ad,   // tl.pl.ceb_544 ga.ig.ceb_422  da.de.no_422 de.pl.ig_643
  0x28111aa9, 0x3b002008, 0x1e1c6ba9, 0x231e05a4,   // tl.ro.sw_544 sq.so.un_430  ceb.id.ms_544 fr.ms.ca_433
  0x1329090d, 0x2d04050c, 0x53006b19, 0x13004a04,   // pl.sl.et_554 fr.fi.sk_543  ceb.ht.un_750 yo.et.un_320
  0x07230da4, 0x060e0860, 0x0e002d0c, 0x3b552807,   // cs.ca.it_433 no.is.de_664  sk.is.un_530 sw.rw.so_432
  // [5670]
  0x20011f11, 0x08020607, 0x131112a4, 0x3b311b08,   // cy.en.sq_653 de.da.no_432  hu.ro.et_433 tr.az.so_443
  0x1c131a60, 0x12001804, 0x100f20af, 0x350d2908,   // tl.et.id_664 ga.hu.un_320  sq.lv.lt_655 sl.cs.zu_443
  0x052a2708, 0x68131e07, 0x20313b12, 0x07212a0c,   // gd.mt.fr_443 ms.et.ig_432  so.az.sq_654 mt.jw.it_543
  0x0c2808ee, 0x13252a0c, 0x0d002704, 0x11051908,   // no.sw.sv_422 mt.eu.et_543  gd.cs.un_320 gl.fr.ro_443
  // [5680]
  0x135520a4, 0x03061fa9, 0x3b006e0e, 0x051b530d,   // sq.rw.et_433 cy.de.nl_544  hmn.so.un_550 ht.tr.fr_554
  0x28356ea4, 0x200d55a4, 0x0900310d, 0x2b06250c,   // hmn.zu.sw_433 rw.cs.sq_433  az.pl.un_540 eu.de.vi_543
  0x17080e0c, 0x2a042560, 0x08020fa4, 0x03001e04,   // is.no.sr_543 eu.fi.mt_664  lv.da.no_433 ms.nl.un_320
  0x041e1a08, 0x21281a0c, 0x130b3bad, 0x0b1e6ea0,   // tl.ms.fi_443 tl.sw.jw_543  so.es.et_643 hmn.ms.es_322
  // [5690]
  0x02052aee, 0x072b1faf, 0x3b534aad, 0x1b102a04,   // mt.fr.da_422 cy.vi.it_655  yo.ht.so_643 mt.lt.tr_332
  0x216e2707, 0x01002505, 0x1a3b6e0c, 0x18061f0c,   // gd.hmn.jw_432 eu.en.un_330  hmn.so.tl_543 cy.de.ga_543
  0x282a6408, 0x0f2304af, 0x07002d1a, 0x1a556b0e,   // lg.mt.sw_443 fi.ca.lv_655  sk.it.un_760 ceb.rw.tl_555
  0x23041112, 0x022508a4, 0x043f1ca4, 0x31001805,   // ro.fi.ca_654 no.eu.da_433  id.af.fi_433 ga.az.un_330
  // [56a0]
  0x25060407, 0x3b1f10ec, 0x0d092daf, 0x25002708,   // fi.de.eu_432 lt.cy.so_644  sk.pl.cs_655 gd.eu.un_430
  0x112825a9, 0x1a6b10ad, 0x1e1a1c0c, 0x060c1b0c,   // eu.sw.ro_544 lt.ceb.tl_643  id.tl.ms_543 tr.sv.de_543
  0x6b1e1a11, 0x0f0401a4, 0x046b1caf, 0x08315308,   // tl.ms.ceb_653 en.fi.lv_433  id.ceb.fi_655 ht.az.no_443
  0x1800252b, 0x1852100c, 0x190a05a7, 0x0b00030e,   // eu.ga.un_980 lt.ha.ga_543  fr.pt.gl_532 nl.es.un_550
  // [56b0]
  0x13092d04, 0x07001807, 0x0f5528ee, 0x25091ea4,   // sk.pl.et_332 ga.it.un_420  sw.rw.lv_422 ms.pl.eu_433
  0x0a07200c, 0x011f0fa7, 0x060a01a4, 0x0b0306a4,   // sq.it.pt_543 lv.cy.en_532  en.pt.de_433 de.nl.es_433
  0x033f1705, 0x12000614, 0x1f0a0205, 0x190a2304,   // sr.af.nl_333 de.hu.un_660  da.pt.cy_333 ca.pt.gl_332
  0x270b18a4, 0x20073ba4, 0x0a04010b, 0x05100fa4,   // ga.es.gd_433 so.it.sq_433  en.fi.pt_542 lv.lt.fr_433
  // [56c0]
  0x524a2804, 0x0e120cad, 0x111a27a4, 0x53133fa4,   // sw.yo.ha_332 sv.hu.is_643  gd.tl.ro_433 af.et.ht_433
  0x1a001812, 0x3b0a1aa7, 0x1f041aad, 0x291713a9,   // ga.tl.un_640 tl.pt.so_532  tl.fi.cy_643 et.sr.sl_544
  0x00000903, 0x2a110712, 0x0a002d11, 0x6b000a22,   // hi.un.un_300 it.ro.mt_654  sk.pt.un_630 pt.ceb.un_870
  0x05091f07, 0x3b00201a, 0x4a32160e, 0x19000a21,   // cy.pl.fr_432 sq.so.un_760  hr.bs.yo_555 pt.gl.un_860
  // [56d0]
  0x6b130507, 0x530d2705, 0x0306010c, 0x13001a02,   // fr.et.ceb_432 gd.cs.ht_333  en.de.nl_543 tl.et.un_220
  0x02130807, 0x0a230eaf, 0x3b52010c, 0x06000a12,   // no.et.da_432 is.ca.pt_655  en.ha.so_543 pt.de.un_640
  0x1820010c, 0x1f002302, 0x315206af, 0x2000522b,   // en.sq.ga_543 ca.cy.un_220  de.ha.az_655 ha.sq.un_980
  0x2d0d6b02, 0x641f5508, 0x64000614, 0x4a000704,   // ceb.cs.sk_222 rw.cy.lg_443  de.lg.un_660 it.yo.un_320
  // [56e0]
  0x060955ad, 0x311b12b4, 0x250b23a7, 0x0664550d,   // rw.pl.de_643 hu.tr.az_754  ca.es.eu_532 rw.lg.de_554
  0x08002507, 0x1e1c0b0c, 0x05001f19, 0x06552112,   // eu.no.un_420 es.id.ms_543  cy.fr.un_750 jw.rw.de_654
  0x1f002822, 0x230d0b04, 0x681b3112, 0x063f09ad,   // sw.cy.un_870 es.cs.ca_332  az.tr.ig_654 pl.af.de_643
  0x0a2d11af, 0x2a00310d, 0x08100ea9, 0x02000e09,   // ro.sk.pt_655 az.mt.un_540  is.lt.no_544 is.da.un_440
  // [56f0]
  0x1c28290c, 0x4a555202, 0x1f0c25a7, 0x0a2913a4,   // sl.sw.id_543 ha.rw.yo_222  eu.sv.cy_532 et.sl.pt_433
  0x1b4a6ba4, 0x1c2521ad, 0x1a041fa7, 0x115313a0,   // ceb.yo.tr_433 jw.eu.id_643  cy.fi.tl_532 et.ht.ro_322
  0x3f002813, 0x132d0da4, 0x1a1c1fa0, 0x06132807,   // sw.af.un_650 cs.sk.et_433  cy.id.tl_322 sw.et.de_432
  0x20113f07, 0x3b5568a9, 0x2b272860, 0x20002721,   // af.ro.sq_432 ig.rw.so_544  sw.gd.vi_664 gd.sq.un_860
  // [5700]
  0x0b0c250c, 0x2a0827a0, 0x1f006823, 0x1f281c07,   // eu.sv.es_543 gd.no.mt_322  ig.cy.un_880 id.sw.cy_432
  0x5368055a, 0x190b05af, 0x0a003505, 0x35000a21,   // fr.ig.ht_553 fr.es.gl_655  zu.pt.un_330 pt.zu.un_860
  0x1003520c, 0x11000714, 0x072a110c, 0x2d001107,   // ha.nl.lt_543 it.ro.un_660  ro.mt.it_543 ro.sk.un_420
  0x1000251a, 0x6e1f2bec, 0x28521c0c, 0x28002704,   // eu.lt.un_760 vi.cy.hmn_644  id.ha.sw_543 gd.sw.un_320
  // [5710]
  0x280c1a07, 0x0e091f0c, 0x01202811, 0x1a132105,   // tl.sv.sw_432 cy.pl.is_543  sw.sq.en_653 jw.et.tl_333
  0x3b18280c, 0x13283ba4, 0x6b00682a, 0x172855a9,   // sw.ga.so_543 so.sw.et_433  ig.ceb.un_970 rw.sw.sr_544
  0x0f071308, 0x0f321005, 0x033b6411, 0x011e2ba0,   // et.it.lv_443 lt.bs.lv_333  lg.so.nl_653 vi.ms.en_322
  0x033b1a0b, 0x3f002504, 0x052b01a6, 0x32003107,   // tl.so.nl_542 eu.af.un_320  en.vi.fr_521 az.bs.un_420
  // [5720]
  0x3f020fa0, 0x21002808, 0x11190baf, 0x041321af,   // lv.da.af_322 sw.jw.un_430  es.gl.ro_655 jw.et.fi_655
  0x043b13a4, 0x1a255555, 0x28523b07, 0x072a0405,   // et.so.fi_433 rw.eu.tl_442  so.ha.sw_432 fi.mt.it_333
  0x5300231a, 0x01002a02, 0x012805ee, 0x2b6b040c,   // ca.ht.un_760 mt.en.un_220  fr.sw.en_422 fi.ceb.vi_543
  0x212b1c09, 0x532b28ee, 0x0c000d04, 0x10171111,   // id.vi.jw_444 sw.vi.ht_422  cs.sv.un_320 ro.sr.be_653
  // [5730]
  0x1828680c, 0x0000072d, 0x1f5327a9, 0x324a17a0,   // ig.sw.ga_543 it.un.un_A00  gd.ht.cy_544 sr.yo.bs_322
  0x5200042c, 0x102b680d, 0x2b000712, 0x0e0425ad,   // fi.ha.un_990 ig.vi.lt_554  it.vi.un_640 eu.fi.is_643
  0x201923a9, 0x523b01af, 0x0e0452ad, 0x1b0e31af,   // ca.gl.sq_544 en.so.ha_655  ha.fi.is_643 az.is.tr_655
  0x13090d5a, 0x0418270c, 0x1e27180c, 0x11040da4,   // ne.hi.bh_553 gd.ga.fi_543  ga.gd.ms_543 cs.fi.ro_433
  // [5740]
  0x552528a4, 0x202723a4, 0x52183ba4, 0x1b310b04,   // sw.eu.rw_433 ca.gd.sq_433  so.ga.ha_433 es.az.tr_332
  0x2800291a, 0x00000142, 0x6b1a10a7, 0x061e1f07,   // sl.sw.un_760 en.un.un_C00  lt.tl.ceb_532 cy.ms.de_432
  0x55353b0c, 0x310b0eee, 0x1b0e3108, 0x1f00230c,   // so.zu.rw_543 is.es.az_422  az.is.tr_443 ca.cy.un_530
  0x0e04520c, 0x19040b0c, 0x16130404, 0x01271f05,   // ha.fi.is_543 es.fi.gl_543  fi.et.hr_332 cy.gd.en_333
  // [5750]
  0x08000702, 0x6b2d1a07, 0x251364a4, 0x0e231f12,   // it.no.un_220 tl.sk.ceb_432  lg.et.eu_433 cy.ca.is_654
  0x07001812, 0x282d0d5a, 0x08231fa4, 0x18551b07,   // ga.it.un_640 cs.sk.sw_553  cy.ca.no_433 tr.rw.ga_432
  0x352028af, 0x1b005304, 0x0913040c, 0x23002a22,   // sw.sq.zu_655 ht.tr.un_320  fi.et.pl_543 mt.ca.un_870
  0x0f100e12, 0x06082308, 0x6b1a1308, 0x060b1fa0,   // is.lt.lv_654 ca.no.de_443  et.tl.ceb_443 cy.es.de_322
  // [5760]
  0x1712080b, 0x20001c0c, 0x551021ec, 0x1228550c,   // no.hu.sr_542 id.sq.un_530  jw.lt.rw_644 rw.sw.hu_543
  0x4a0d52ee, 0x3b212012, 0x094a1307, 0x55006e04,   // ha.cs.yo_422 sq.jw.so_654  et.yo.pl_432 hmn.rw.un_320
  0x0a051960, 0x03124aa4, 0x191f0a04, 0x1c0429a0,   // gl.fr.pt_664 yo.hu.nl_433  pt.cy.gl_332 sl.fi.id_322
  0x2d0d35a9, 0x321b6407, 0x2d0d6b14, 0x1e1c10ee,   // zu.cs.sk_544 lg.tr.bs_432  ceb.cs.sk_666 lt.id.ms_422
  // [5770]
  0x190b3b05, 0x03011007, 0x531b0ba4, 0x10006b12,   // so.es.gl_333 lt.en.nl_432  es.tr.ht_433 ceb.lt.un_640
  0x060120a0, 0x1b1c6ba4, 0x01353fa0, 0x4a2368a4,   // sq.en.de_322 ceb.id.tr_433  af.zu.en_322 ig.ca.yo_433
  0x02001a0d, 0x3b1f6baf, 0x3b001a20, 0x3b2a29a9,   // tl.da.un_540 ceb.cy.so_655  tl.so.un_850 sl.mt.so_544
  0x1a0931a0, 0x193b0b55, 0x2302010c, 0x3f0f0112,   // az.pl.tl_322 es.so.gl_442  en.da.ca_543 en.lv.af_654
  // [5780]
  0x6400091b, 0x110d2911, 0x13010f11, 0x55071c04,   // pl.lg.un_770 sl.cs.ro_653  lv.en.et_653 id.it.rw_332
  0x08071160, 0x0f00011a, 0x1120210c, 0x1b030aee,   // ro.bg.uk_664 en.lv.un_760  jw.sq.ro_543 pt.nl.tr_422
  0x6b001212, 0x080229a4, 0x170d2dad, 0x0e002908,   // hu.ceb.un_640 sl.da.no_433  sk.cs.sr_643 sl.is.un_430
  0x55003112, 0x16001a07, 0x0d1e1c13, 0x68013ba7,   // az.rw.un_640 tl.hr.un_420  id.ms.cs_665 so.en.ig_532
  // [5790]
  0x2d29010c, 0x04132304, 0x2d0d35a4, 0x06000713,   // en.sl.sk_543 ca.et.fi_332  zu.cs.sk_433 it.de.un_650
  0x35006e07, 0x126468ad, 0x29000c14, 0x04002322,   // hmn.zu.un_420 ig.lg.hu_643  sv.sl.un_660 ca.fi.un_870
  0x0a2119a4, 0x0b121907, 0x201b3105, 0x1e001304,   // gl.jw.pt_433 gl.hu.es_432  az.tr.sq_333 et.ms.un_320
  0x06000e0c, 0x203564a9, 0x192d0b07, 0x08120eee,   // is.de.un_530 lg.zu.sq_544  es.sk.gl_432 is.hu.no_422
  // [57a0]
  0x285220ad, 0x09292008, 0x3b6855a7, 0x10000802,   // sq.ha.sw_643 sq.sl.pl_443  rw.ig.so_532 uk.be.un_220
  0x1b202908, 0x080c0e05, 0x1c521eec, 0x2d0d230c,   // sl.sq.tr_443 is.sv.no_333  ms.ha.id_644 ca.cs.sk_543
  0x1e1c3b14, 0x6b2d12a9, 0x4a1a5511, 0x1a2d1208,   // so.id.ms_666 hu.sk.ceb_544  rw.tl.yo_653 hu.sk.tl_443
  0x1b2920ad, 0x25122d0c, 0x201029a4, 0x1b072014,   // sq.sl.tr_643 sk.hu.eu_543  sl.lt.sq_433 sq.it.tr_666
  // [57b0]
  0x6b684aad, 0x10000704, 0x25040308, 0x551b200c,   // yo.ig.ceb_643 it.lt.un_320  nl.fi.eu_443 sq.tr.rw_543
  0x212d1209, 0x1b31200c, 0x4a005221, 0x2125120c,   // hu.sk.jw_444 sq.az.tr_543  ha.yo.un_860 hu.eu.jw_543
  0x1c0d090b, 0x0c081a08, 0x3b13030c, 0x12211cad,   // hi.ne.mr_542 tl.no.sv_443  nl.et.so_543 id.jw.hu_643
  0x4a00682c, 0x1000072b, 0x121f1104, 0x0a190513,   // ig.yo.un_990 bg.be.un_980  ro.cy.hu_332 fr.gl.pt_665
  // [57c0]
  0x3f2512a4, 0x28250da0, 0x1a122d11, 0x0b0a05a4,   // hu.eu.af_433 cs.eu.sw_322  sk.hu.tl_653 fr.pt.es_433
  0x2d29120d, 0x1c1a1212, 0x520e01af, 0x12001c1a,   // hu.sl.sk_554 hu.tl.id_654  en.is.ha_655 id.hu.un_760
  0x08001707, 0x640313ee, 0x1a001105, 0x19002304,   // sr.uk.un_420 et.nl.lg_422  ro.tl.un_330 ca.gl.un_320
  0x01023fa0, 0x23190704, 0x230b0a04, 0x0106280d,   // af.da.en_322 it.gl.ca_332  pt.es.ca_332 sw.de.en_554
  // [57d0]
  0x4a6b1a5a, 0x111b1605, 0x0d092d0c, 0x55006823,   // tl.ceb.yo_553 hr.tr.ro_333  sk.pl.cs_543 ig.rw.un_880
  0x13040ca0, 0x6b526813, 0x130c2aec, 0x04644a08,   // sv.fi.et_322 ig.ha.ceb_665  mt.sv.et_644 yo.lg.fi_443
  0x0c030609, 0x03005304, 0x53312009, 0x08000321,   // de.nl.sv_444 ht.nl.un_320  sq.az.ht_444 nl.no.un_860
  0x6800550e, 0x020308a9, 0x071210ad, 0x273b2011,   // rw.ig.un_550 no.nl.da_544  lt.hu.it_643 sq.so.gd_653
  // [57e0]
  0x09642504, 0x20122907, 0x20310107, 0x0a000735,   // eu.lg.pl_332 sl.hu.sq_432  en.az.sq_432 bg.mk.un_A90
  0x23200413, 0x271c010c, 0x3b1b1fec, 0x68003b1b,   // fi.sq.ca_665 en.id.gd_543  cy.tr.so_644 so.ig.un_770
  0x04002019, 0x0b251908, 0x684a0408, 0x211a3508,   // sq.fi.un_750 gl.eu.es_443  fi.yo.ig_443 zu.tl.jw_443
  0x310355a7, 0x061a3bad, 0x100e3f13, 0x0320060c,   // rw.nl.az_532 so.tl.de_643  af.is.lt_665 de.sq.nl_543
  // [57f0]
  0x6b683b05, 0x3f000414, 0x35551a09, 0x6e352108,   // so.ig.ceb_333 fi.af.un_660  tl.rw.zu_444 jw.zu.hmn_443
  0x182d0d5a, 0x04080a0c, 0x3b196ea9, 0x0d000504,   // cs.sk.ga_553 mk.uk.ru_543  hmn.gl.so_544 fr.cs.un_320
  0x2a2023a9, 0x55062508, 0x120a0dad, 0x3b3f1308,   // ca.sq.mt_544 eu.de.rw_443  cs.pt.hu_643 et.af.so_443
  0x3568060c, 0x35281205, 0x6b1b09a4, 0x06000204,   // de.ig.zu_543 hu.sw.zu_333  pl.tr.ceb_433 da.de.un_320

  // [5800]
  0x21521c11, 0x2700351a, 0x022a11a4, 0x35000108,   // id.ha.jw_653 zu.gd.un_760  ro.mt.da_433 en.zu.un_430
  0x112152a4, 0x68255508, 0x352804ad, 0x2523520b,   // ha.jw.ro_433 rw.eu.ig_443  fi.sw.zu_643 ha.ca.eu_542
  0x35000613, 0x320f6804, 0x1110040c, 0x64521a04,   // de.zu.un_650 ig.lv.bs_332  ru.be.ro_543 tl.ha.lg_332
  0x35006829, 0x350a07a9, 0x1268550d, 0x553529a4,   // ig.zu.un_960 it.pt.zu_544  rw.ig.hu_554 sl.zu.rw_433
  // [5810]
  0x1b000308, 0x68002818, 0x1c063502, 0x28533b14,   // nl.tr.un_430 sw.ig.un_740  zu.de.id_222 so.ht.sw_666
  0x1c4a68ad, 0x09213507, 0x3500522a, 0x350d0909,   // ig.yo.id_643 zu.jw.pl_432  ha.zu.un_970 pl.cs.zu_444
  0x100953ec, 0x52182ba7, 0x06021113, 0x21686404,   // ht.pl.lt_644 vi.ga.ha_532  ro.da.de_665 lg.ig.jw_332
  0x190a200c, 0x171013a4, 0x0f190d0b, 0x3525090c,   // sq.pt.gl_543 et.lt.sr_433  cs.gl.lv_542 pl.eu.zu_543
  // [5820]
  0x06003508, 0x55282108, 0x2b131ca9, 0x35551aa9,   // zu.de.un_430 jw.sw.rw_443  id.et.vi_544 tl.rw.zu_544
  0x200c0208, 0x3b2101a4, 0x1e100708, 0x552021a4,   // da.sv.sq_443 en.jw.so_433  it.lt.ms_443 jw.sq.rw_433
  0x3f3b6b08, 0x2b271e0c, 0x0f1953a4, 0x0c1b080c,   // ceb.so.af_443 ms.gd.vi_543  ht.gl.lv_433 no.tr.sv_543
  0x35002702, 0x251a350c, 0x090d13a4, 0x254a68ac,   // gd.zu.un_220 zu.tl.eu_543  bh.ne.hi_433 ig.yo.eu_632
  // [5830]
  0x1e001a04, 0x033f1b0c, 0x0f5510ec, 0x11551e08,   // tl.ms.un_320 tr.af.nl_543  lt.rw.lv_644 ms.rw.ro_443
  0x11000514, 0x0b000511, 0x6b1b53ec, 0x35526baf,   // fr.ro.un_660 fr.es.un_630  ht.tr.ceb_644 ceb.ha.zu_655
  0x051104a4, 0x102001ad, 0x20005509, 0x356b13ac,   // fi.ro.fr_433 en.sq.lt_643  rw.sq.un_440 et.ceb.zu_632
  0x03002021, 0x11003b04, 0x1f1118ac, 0x21523b0c,   // sq.nl.un_860 so.ro.un_320  ga.ro.cy_632 so.ha.jw_543
  // [5840]
  0x5528130e, 0x293b130c, 0x1e5225af, 0x311c55a0,   // et.sw.rw_555 et.so.sl_543  eu.ha.ms_655 rw.id.az_322
  0x3b2519a9, 0x09130d13, 0x1b101ea0, 0x121e1c0d,   // gl.eu.so_544 ne.bh.hi_665  ms.lt.tr_322 id.ms.hu_554
  0x1a001707, 0x04290304, 0x10006814, 0x68002012,   // sr.tl.un_420 nl.sl.fi_332  ig.lt.un_660 sq.ig.un_640
  0x521b4a0c, 0x5221530c, 0x3b556412, 0x1800280e,   // yo.tr.ha_543 ht.jw.ha_543  lg.rw.so_654 sw.ga.un_550
  // [5850]
  0x0c4a6e02, 0x1a004a1b, 0x0623010c, 0x060105ec,   // hmn.yo.sv_222 yo.tl.un_770  en.ca.de_543 fr.en.de_644
  0x64556814, 0x03002a12, 0x2a23110d, 0x68003b19,   // ig.rw.lg_666 mt.nl.un_640  ro.ca.mt_554 so.ig.un_750
  0x645335af, 0x551e1f04, 0x04200ca0, 0x64005302,   // zu.ht.lg_655 cy.ms.rw_332  sv.sq.fi_322 ht.lg.un_220
  0x110603ec, 0x311b4aac, 0x1f645511, 0x100a07a0,   // nl.de.ro_644 yo.tr.az_632  rw.lg.cy_653 bg.mk.be_322
  // [5860]
  0x17080405, 0x05000b0c, 0x322864ad, 0x0d00531a,   // ru.uk.sr_333 es.fr.un_530  lg.sw.bs_643 ht.cs.un_760
  0x6e1a6baf, 0x0c002a1b, 0x16286408, 0x033f0aaf,   // ceb.tl.hmn_655 mt.sv.un_770  lg.sw.hr_443 pt.af.nl_655
  0x2a112308, 0x1a5564a4, 0x23110d12, 0x35002a07,   // ca.ro.mt_443 lg.rw.tl_433  cs.ro.ca_654 mt.zu.un_420
  0x1f1a6bec, 0x523f230c, 0x1800191a, 0x1a003b14,   // ceb.tl.cy_644 ca.af.ha_543  gl.ga.un_760 so.tl.un_660
  // [5870]
  0x271f0208, 0x1355520e, 0x1f0727a9, 0x32003505,   // da.cy.gd_443 ha.rw.et_555  gd.it.cy_544 zu.bs.un_330
  0x13003519, 0x0f64550d, 0x3b211b0c, 0x351b13a4,   // zu.et.un_750 rw.lg.lv_554  tr.jw.so_543 et.tr.zu_433
  0x1a101e07, 0x1107130c, 0x28641e07, 0x64006819,   // ms.lt.tl_432 et.it.ro_543  ms.lg.sw_432 ig.lg.un_750
  0x292d1705, 0x284a645a, 0x2d29100c, 0x35280713,   // sr.sk.sl_333 lg.yo.sw_553  lt.sl.sk_543 it.sw.zu_665
  // [5880]
  0x13046408, 0x05110713, 0x1e101c0c, 0x2d170d07,   // lg.fi.et_443 it.ro.fr_665  id.lt.ms_543 cs.sr.sk_432
  0x12082907, 0x120721ad, 0x291625ee, 0x3b355304,   // sl.no.hu_432 jw.it.hu_643  eu.hr.sl_422 ht.zu.so_332
  0x21005202, 0x35646808, 0x3f3b1f12, 0x322a09a4,   // ha.jw.un_220 ig.lg.zu_443  cy.so.af_654 pl.mt.bs_433
  0x1e004a19, 0x0500101b, 0x29204a13, 0x0200201a,   // yo.ms.un_750 lt.fr.un_770  yo.sq.sl_665 sq.da.un_760
  // [5890]
  0x53001602, 0x202a2104, 0x022008ad, 0x172952a7,   // hr.ht.un_220 jw.mt.sq_332  no.sq.da_643 ha.sl.sr_532
  0x0a182708, 0x0c20080c, 0x180e2709, 0x05060fad,   // gd.ga.pt_443 no.sq.sv_543  gd.is.ga_444 lv.de.fr_643
  0x120e0cee, 0x0e0827a4, 0x2d1729af, 0x033f2311,   // sv.is.hu_422 gd.no.is_433  sl.sr.sk_655 ca.af.nl_653
  0x2d0807ac, 0x0e250504, 0x0206080c, 0x13052707,   // it.no.sk_632 fr.eu.is_332  no.de.da_543 gd.fr.et_432
  // [58a0]
  0x0d091c07, 0x11000522, 0x1f2327a9, 0x13091cac,   // mr.hi.ne_432 fr.ro.un_870  gd.ca.cy_544 mr.hi.bh_632
  0x1c6e1e07, 0x231918a4, 0x03002804, 0x0e020604,   // ms.hmn.id_432 ga.gl.ca_433  sw.nl.un_320 de.da.is_332
  0x206432a4, 0x13121ba4, 0x1a6407ad, 0x2032160d,   // bs.lg.sq_433 tr.hu.et_433  it.lg.tl_643 hr.bs.sq_554
  0x21002029, 0x0613250c, 0x032555a9, 0x1e2021af,   // sq.jw.un_960 eu.et.de_543  rw.eu.nl_544 jw.sq.ms_655
  // [58b0]
  0x09550e08, 0x082002af, 0x523b64ad, 0x11061fa4,   // is.rw.pl_443 da.sq.no_655  lg.so.ha_643 cy.de.ro_433
  0x4a0c6804, 0x1f002321, 0x3f55070c, 0x100907a4,   // ig.sv.yo_332 ca.cy.un_860  it.rw.af_543 it.pl.lt_433
  0x1f3b07ad, 0x3b0a0fa4, 0x16042904, 0x011803a0,   // it.so.cy_643 lv.pt.so_433  sl.fi.hr_332 nl.ga.en_322
  0x103b29a0, 0x190113a4, 0x6e2b4aa0, 0x0c002d0d,   // sl.so.lt_322 et.en.gl_433  yo.vi.hmn_322 sk.sv.un_540
  // [58c0]
  0x0f12250c, 0x35006b02, 0x133f0c08, 0x030764a7,   // eu.hu.lv_543 ceb.zu.un_220  sv.af.et_443 lg.it.nl_532
  0x100b2da0, 0x3b000729, 0x64002108, 0x350603a4,   // sk.es.lt_322 it.so.un_960  jw.lg.un_430 nl.de.zu_433
  0x3f0c350c, 0x6e0a1f0c, 0x13232508, 0x285521a9,   // zu.sv.af_543 cy.pt.hmn_543  eu.ca.et_443 jw.rw.sw_544
  0x1906050c, 0x2118280c, 0x10002d04, 0x101f3b13,   // fr.de.gl_543 sw.ga.jw_543  sk.lt.un_320 so.cy.lt_665
  // [58d0]
  0x3b00040c, 0x0a0b19ad, 0x190a0c0c, 0x550c2da0,   // fi.so.un_530 gl.es.pt_643  sv.pt.gl_543 sk.sv.rw_322
  0x130c2d07, 0x101f090c, 0x08171014, 0x4a352555,   // sk.sv.et_432 pl.cy.lt_543  be.sr.uk_666 eu.zu.yo_442
  0x200e020c, 0x52003504, 0x3f3b13ad, 0x68190b13,   // da.is.sq_543 zu.ha.un_320  et.so.af_643 es.gl.ig_665
  0x55282907, 0x3f036455, 0x32060fa0, 0x4a00212a,   // sl.sw.rw_432 lg.nl.af_442  lv.de.bs_322 jw.yo.un_970
  // [58e0]
  0x554a6812, 0x520b5504, 0x02005513, 0x1b646808,   // ig.yo.rw_654 rw.es.ha_332  rw.da.un_650 ig.lg.tr_443
  0x101b4aee, 0x551e4aa4, 0x11000307, 0x532105a6,   // yo.tr.lt_422 yo.ms.rw_433  nl.ro.un_420 fr.jw.ht_521
  0x32002018, 0x0b4a6808, 0x35684aec, 0x190b0207,   // sq.bs.un_740 ig.yo.es_443  yo.ig.zu_644 da.es.gl_432
  0x06110a08, 0x122911a0, 0x28092913, 0x0e180d12,   // pt.ro.de_443 ro.sl.hu_322  sl.pl.sw_665 cs.ga.is_654
  // [58f0]
  0x02003513, 0x18001f0e, 0x1e110411, 0x685552ad,   // zu.da.un_650 cy.ga.un_550  fi.ro.ms_653 ha.rw.ig_643
  0x3b00011b, 0x11000735, 0x3b180913, 0x190306a4,   // en.so.un_770 bg.ro.un_A90  pl.ga.so_665 de.nl.gl_433
  0x52646b04, 0x1e132107, 0x52001a1b, 0x211b1207,   // ceb.lg.ha_332 jw.et.ms_432  tl.ha.un_770 hu.tr.jw_432
  0x0700350d, 0x681b5308, 0x2500120d, 0x3500022b,   // zu.it.un_540 ht.tr.ig_443  hu.eu.un_540 da.zu.un_980
  // [5900]
  0x1e022505, 0x01062ba0, 0x1e3b1a12, 0x03080e08,   // eu.da.ms_333 vi.de.en_322  tl.so.ms_654 is.no.nl_443
  0x1b1e21a4, 0x093b6e0c, 0x52190bec, 0x0b0223ee,   // jw.ms.tr_433 hmn.so.pl_543  es.gl.ha_644 ca.da.es_422
  0x02001807, 0x53121e07, 0x09003b0e, 0x08060205,   // ga.da.un_420 ms.hu.ht_432  so.pl.un_550 da.de.no_333
  0x5331120c, 0x0709110c, 0x0a1925ad, 0x25190e0c,   // hu.az.ht_543 ro.pl.it_543  eu.gl.pt_643 is.gl.eu_543
  // [5910]
  0x066b1aad, 0x12211c0c, 0x12092512, 0x201f11ad,   // tl.ceb.de_643 id.jw.hu_543  eu.pl.hu_654 ro.cy.sq_643
  0x1c6b53a0, 0x06002307, 0x230621a4, 0x21000607,   // ht.ceb.id_322 ca.de.un_420  jw.de.ca_433 de.jw.un_420
  0x251710af, 0x3b131ca4, 0x110925a0, 0x552a25a4,   // lt.sr.eu_655 id.et.so_433  eu.pl.ro_322 eu.mt.rw_433
  0x3f081208, 0x4a0512a9, 0x040513a0, 0x02185504,   // hu.no.af_443 hu.fr.yo_544  et.fr.fi_322 rw.ga.da_332
  // [5920]
  0x68004a21, 0x230a0e05, 0x55640611, 0x0c030502,   // yo.ig.un_860 is.pt.ca_333  de.lg.rw_653 fr.nl.sv_222
  0x25551e0b, 0x4a07230c, 0x040a17a6, 0x1c1a2b11,   // ms.rw.eu_542 ca.it.yo_543  sr.mk.ru_521 vi.tl.id_653
  0x1b0d55a0, 0x10001313, 0x086b270d, 0x101b0f60,   // rw.cs.tr_322 et.lt.un_650  gd.ceb.no_554 lv.tr.lt_664
  0x6e033f0d, 0x1e1c35a0, 0x1b06210c, 0x1c1a1e07,   // af.nl.hmn_554 zu.id.ms_322  jw.de.tr_543 ms.tl.id_432
  // [5930]
  0x27081855, 0x29004a04, 0x683506af, 0x3f0864ad,   // ga.no.gd_442 yo.sl.un_320  de.zu.ig_655 lg.no.af_643
  0x6b2b010c, 0x0b1f100d, 0x0c121fad, 0x08023502,   // en.vi.ceb_543 lt.cy.es_554  cy.hu.sv_643 zu.da.no_222
  0x07001f23, 0x06202aa9, 0x03350612, 0x1c1225ee,   // cy.it.un_880 mt.sq.de_544  de.zu.nl_654 eu.hu.id_422
  0x10002823, 0x0c061fac, 0x0a001f20, 0x0c002018,   // sw.lt.un_880 cy.de.sv_632  cy.pt.un_850 sq.sv.un_740
  // [5940]
  0x062a010c, 0x11060111, 0x52071fa4, 0x08000402,   // en.mt.de_543 en.de.ro_653  cy.it.ha_433 ru.uk.un_220
  0x016b1007, 0x68642508, 0x10080405, 0x0700252c,   // lt.ceb.en_432 eu.lg.ig_443  ru.uk.be_333 eu.it.un_990
  0x29311ba9, 0x68185512, 0x20001e13, 0x190b01ee,   // tr.az.sl_544 rw.ga.ig_654  ms.sq.un_650 en.es.gl_422
  0x130601a6, 0x110704a9, 0x20000d20, 0x010f100c,   // en.de.et_521 ru.bg.ro_544  cs.sq.un_850 lt.lv.en_543
  // [5950]
  0x0e2a1609, 0x101f1ca0, 0x171606a4, 0x21066404,   // hr.mt.is_444 id.cy.lt_322  de.hr.sr_433 lg.de.jw_332
  0x1e12520b, 0x0a00081b, 0x0d002304, 0x04202308,   // ha.hu.ms_542 uk.mk.un_770  ca.cs.un_320 ca.sq.fi_443
  0x1c061e12, 0x23082007, 0x0e0c08a9, 0x2300530d,   // ms.de.id_654 sq.no.ca_432  no.sv.is_544 ht.ca.un_540
  0x311f0e0c, 0x0e0c1304, 0x1255680d, 0x551a3b08,   // is.cy.az_543 et.sv.is_332  ig.rw.hu_554 so.tl.rw_443
  // [5960]
  0x04202105, 0x31011802, 0x28042007, 0x1b250e08,   // jw.sq.fi_333 ga.en.az_222  sq.fi.sw_432 is.eu.tr_443
  0x20002109, 0x2325280c, 0x041052ad, 0x1a0e2009,   // jw.sq.un_440 sw.eu.ca_543  ha.lt.fi_643 sq.is.tl_444
  0x0f10530b, 0x355225a4, 0x051e5302, 0x3b2717ee,   // ht.lt.lv_542 eu.ha.zu_433  ht.ms.fr_222 sr.gd.so_422
  0x521e1fa4, 0x290917a0, 0x12135213, 0x231101af,   // cy.ms.ha_433 sr.pl.sl_322  ha.et.hu_665 en.ro.ca_655
  // [5970]
  0x012927a4, 0x1f002a04, 0x180327af, 0x012311a4,   // gd.sl.en_433 mt.cy.un_320  gd.nl.ga_655 ro.ca.en_433
  0x020b6b0c, 0x2100071a, 0x52002908, 0x094a5212,   // ceb.es.da_543 it.jw.un_760  sl.ha.un_430 ha.yo.pl_654
  0x05000c13, 0x28073508, 0x52051ea0, 0x1353250b,   // sv.fr.un_650 zu.it.sw_443  ms.fr.ha_322 eu.ht.et_542
  0x531725ee, 0x1b250408, 0x25073ba0, 0x070e0aec,   // eu.sr.ht_422 fi.eu.tr_443  so.it.eu_322 pt.is.it_644
  // [5980]
  0x1b4a6809, 0x6800022c, 0x04201b13, 0x2a000804,   // ig.yo.tr_444 da.ig.un_990  tr.sq.fi_665 no.mt.un_320
  0x1b00531a, 0x2b2301ad, 0x070c25af, 0x55521f07,   // ht.tr.un_760 en.ca.vi_643  eu.sv.it_655 cy.ha.rw_432
  0x2b1c01a4, 0x11005302, 0x4a2025ec, 0x280955a4,   // en.id.vi_433 ht.ro.un_220  eu.sq.yo_644 rw.pl.sw_433
  0x120d350c, 0x68000822, 0x280d03a4, 0x020a4aa7,   // zu.cs.hu_543 no.ig.un_870  nl.cs.sw_433 yo.pt.da_532
  // [5990]
  0x6e6b6807, 0x35164a0c, 0x07000622, 0x12003522,   // ig.ceb.hmn_432 yo.hr.zu_543  de.it.un_870 zu.hu.un_870
  0x552868ad, 0x681b3b0e, 0x0607050c, 0x18080c0d,   // ig.sw.rw_643 so.tr.ig_555  fr.it.de_543 sv.no.ga_554
  0x130852a9, 0x04171819, 0x324a13ad, 0x23684aec,   // ha.no.et_544 ar.sr.ru_765  et.yo.bs_643 yo.ig.ca_644
  0x52005512, 0x4a685355, 0x68132309, 0x0635290c,   // rw.ha.un_640 ht.ig.yo_442  ca.et.ig_444 sl.zu.de_543
  // [59a0]
  0x55004a07, 0x3f201112, 0x0c0504ee, 0x0100682b,   // yo.rw.un_420 ro.sq.af_654  fi.fr.sv_422 ig.en.un_980
  0x042011ee, 0x02170cec, 0x20681313, 0x190b010c,   // ro.sq.fi_422 sv.sr.da_644  et.ig.sq_665 en.es.gl_543
  0x0768010b, 0x2d004a13, 0x202552a0, 0x0e001704,   // en.ig.it_542 yo.sk.un_650  ha.eu.sq_322 sr.is.un_320
  0x19313b0d, 0x092564a4, 0x111301a4, 0x35000a35,   // so.az.gl_554 lg.eu.pl_433  en.et.ro_433 pt.zu.un_A90
  // [59b0]
  0x0d0655ad, 0x03010ca4, 0x0c000f18, 0x0e000c2b,   // rw.de.cs_643 sv.en.nl_433  lv.sv.un_740 sv.is.un_980
  0x05521ea4, 0x050e01af, 0x1029130c, 0x3b002a0e,   // ms.ha.fr_433 en.is.fr_655  et.sl.lt_543 mt.so.un_550
  0x522313a9, 0x231f1aa4, 0x02270812, 0x1255110b,   // et.ca.ha_544 tl.cy.ca_433  no.gd.da_654 ro.rw.hu_542
  0x32272d0c, 0x321601ee, 0x070111a9, 0x0c126b08,   // sk.gd.bs_543 en.hr.bs_422  ro.en.it_544 ceb.hu.sv_443
  // [59c0]
  0x20556860, 0x06321605, 0x2a110709, 0x0d1219a7,   // ig.rw.sq_664 hr.bs.de_333  it.ro.mt_444 gl.hu.cs_532
  0x123f1fa9, 0x0600181a, 0x290d2da4, 0x061203a9,   // cy.af.hu_544 ga.de.un_760  sk.cs.sl_433 nl.hu.de_544
  0x252d1112, 0x02061208, 0x2d0d0fa6, 0x0713010c,   // ro.sk.eu_654 hu.de.da_443  lv.cs.sk_521 en.et.it_543
  0x20190bec, 0x35011fa4, 0x250711a4, 0x023f0f07,   // es.gl.sq_644 cy.en.zu_433  ro.it.eu_433 lv.af.da_432
  // [59d0]
  0x0f2301a4, 0x29006807, 0x12006e0d, 0x05080304,   // en.ca.lv_433 ig.sl.un_420  hmn.hu.un_540 nl.no.fr_332
  0x6e000c0e, 0x11095505, 0x6828550c, 0x6e000c12,   // sv.hmn.un_550 rw.pl.ro_333  rw.sw.ig_543 sv.hmn.un_640
  0x1a003f1a, 0x0c001012, 0x0a00530c, 0x28682a0d,   // af.tl.un_760 lt.sv.un_640  ht.pt.un_530 mt.ig.sw_554
  0x1a6e3f5a, 0x200712a4, 0x08126b0c, 0x28682907,   // af.hmn.tl_553 hu.it.sq_433  ceb.hu.no_543 sl.ig.sw_432
  // [59e0]
  0x280152a0, 0x291668ac, 0x190a0ea0, 0x685521a9,   // ha.en.sw_322 ig.hr.sl_632  is.pt.gl_322 jw.rw.ig_544
  0x11050760, 0x53002504, 0x680555a4, 0x16001019,   // it.fr.ro_664 eu.ht.un_320  rw.fr.ig_433 lt.hr.un_750
  0x030f68ee, 0x25070607, 0x25000f13, 0x20003509,   // ig.lv.nl_422 de.it.eu_432  lv.eu.un_650 zu.sq.un_440
  0x283553ee, 0x12002805, 0x3500060c, 0x0a0523ec,   // ht.zu.sw_422 sw.hu.un_330  de.zu.un_530 ca.fr.pt_644
  // [59f0]
  0x0f006813, 0x0a08025a, 0x291603ee, 0x1a6b18ee,   // ig.lv.un_650 da.no.pt_553  nl.hr.sl_422 ga.ceb.tl_422
  0x08001c02, 0x0c353baf, 0x4a00210c, 0x08273fa0,   // id.no.un_220 so.zu.sv_655  jw.yo.un_530 af.gd.no_322
  0x531628ee, 0x04063512, 0x1b3552af, 0x4a002807,   // sw.hr.ht_422 zu.de.fi_654  ha.zu.tr_655 sw.yo.un_420
  0x52534aaf, 0x02060c08, 0x32550b0c, 0x1e251702,   // yo.ht.ha_655 sv.de.da_443  es.rw.bs_543 sr.eu.ms_222
  // [5a00]
  0x6b311b13, 0x172568ad, 0x2d320d07, 0x534a28a7,   // tr.az.ceb_665 ig.eu.sr_643  cs.bs.sk_432 sw.yo.ht_532
  0x1f003b08, 0x28001a0e, 0x12001602, 0x23000a0e,   // so.cy.un_430 tl.sw.un_550  hr.hu.un_220 pt.ca.un_550
  0x31000a04, 0x13090dac, 0x2506550c, 0x020608a4,   // pt.az.un_320 ne.hi.bh_632  rw.de.eu_543 no.de.da_433
  0x533504a0, 0x1200550d, 0x32160ba4, 0x311b1fa4,   // fi.zu.ht_322 rw.hu.un_540  es.hr.bs_433 cy.tr.az_433
  // [5a10]
  0x04351aa4, 0x11104a02, 0x042564a4, 0x28093505,   // tl.zu.fi_433 yo.lt.ro_222  lg.eu.fi_433 zu.pl.sw_333
  0x55640da4, 0x311b08a9, 0x2d1107ad, 0x2302110c,   // cs.lg.rw_433 no.tr.az_544  it.ro.sk_643 ro.da.ca_543
  0x31006b19, 0x184a0daf, 0x31001a04, 0x0811060d,   // ceb.az.un_750 cs.yo.ga_655  tl.az.un_320 de.ro.no_554
  0x09022305, 0x31001f13, 0x5500120d, 0x681b5508,   // ca.da.pl_333 cy.az.un_650  hu.rw.un_540 rw.tr.ig_443
  // [5a20]
  0x03000108, 0x190a05af, 0x2d0d0ea9, 0x13000212,   // en.nl.un_430 fr.pt.gl_655  is.cs.sk_544 da.et.un_640
  0x270e1812, 0x100f110c, 0x11232508, 0x29001c04,   // ga.is.gd_654 ro.lv.lt_543  eu.ca.ro_443 id.sl.un_320
  0x1c32210d, 0x23205508, 0x09002519, 0x18232aa4,   // jw.bs.id_554 rw.sq.ca_443  eu.pl.un_750 mt.ca.ga_433
  0x0601230c, 0x191b0aec, 0x135304ad, 0x10170713,   // ca.en.de_543 pt.tr.gl_644  fi.ht.et_643 bg.sr.be_665
  // [5a30]
  0x28001f19, 0x0c2a230c, 0x0c002313, 0x211205a6,   // cy.sw.un_750 ca.mt.sv_543  ca.sv.un_650 fr.hu.jw_521
  0x020508a4, 0x062308a7, 0x2d120cac, 0x021f0807,   // no.fr.da_433 no.ca.de_532  sv.hu.sk_632 no.cy.da_432
  0x17000c13, 0x18201313, 0x0600051a, 0x043f035a,   // sv.sr.un_650 et.sq.ga_665  fr.de.un_760 nl.af.fi_553
  0x061f04a4, 0x0e0f13ad, 0x1e1c06ac, 0x011f030c,   // fi.cy.de_433 et.lv.is_643  de.id.ms_632 nl.cy.en_543
  // [5a40]
  0x0f110e08, 0x0c000305, 0x270e010c, 0x3f00041a,   // is.ro.lv_443 nl.sv.un_330  en.is.gd_543 fi.af.un_760
  0x090c0812, 0x1f06230c, 0x53002514, 0x111310ec,   // no.sv.pl_654 ca.de.cy_543  eu.ht.un_660 lt.et.ro_644
  0x21003b1b, 0x1b000408, 0x21101c0c, 0x6b1a68ac,   // so.jw.un_770 fi.tr.un_430  id.lt.jw_543 ig.tl.ceb_632
  0x09113ba4, 0x116b6e08, 0x05181311, 0x28000b0e,   // so.ro.pl_433 hmn.ceb.ro_443  et.ga.fr_653 es.sw.un_550
  // [5a50]
  0x0f001e13, 0x1b06030d, 0x07190b0d, 0x050a12ad,   // ms.lv.un_650 nl.de.tr_554  es.gl.it_554 hu.pt.fr_643
  0x230a0e55, 0x12001302, 0x06031f13, 0x4a0e1805,   // is.pt.ca_442 et.hu.un_220  cy.nl.de_665 ga.is.yo_333
  0x322820a6, 0x1f2b35ac, 0x3513040c, 0x52046e12,   // sq.sw.bs_521 zu.vi.cy_632  fi.et.zu_543 hmn.fi.ha_654
  0x1a0405a0, 0x120f6808, 0x35001221, 0x1a1f2111,   // fr.fi.tl_322 ig.lv.hu_443  hu.zu.un_860 jw.cy.tl_653
  // [5a60]
  0x6e1001a9, 0x11101713, 0x21082011, 0x06000c02,   // en.lt.hmn_544 sr.be.ro_665  sq.no.jw_653 sv.de.un_220
  0x041b03a4, 0x09002d1b, 0x06041b07, 0x31041ba4,   // nl.tr.fi_433 sk.pl.un_770  tr.fi.de_432 tr.fi.az_433
  0x03041ba7, 0x1b02030c, 0x21002004, 0x16002702,   // tr.fi.nl_532 nl.da.tr_543  sq.jw.un_320 gd.hr.un_220
  0x056b0709, 0x05000607, 0x0e3217a6, 0x11006408,   // it.ceb.fr_444 de.fr.un_420  sr.bs.is_521 lg.ro.un_430
  // [5a70]
  0x2500640d, 0x0e0820ad, 0x070e0ca4, 0x08020eee,   // lg.eu.un_540 sq.no.is_643  sv.is.it_433 is.da.no_422
  0x103b35a4, 0x1a5505ad, 0x31031b07, 0x130425ec,   // zu.so.lt_433 fr.rw.tl_643  tr.nl.az_432 eu.fi.et_644
  0x020e0c09, 0x09013f12, 0x091f1a12, 0x3b250b0e,   // sv.is.da_444 af.en.pl_654  tl.cy.pl_654 es.eu.so_555
  0x0407110d, 0x03123bee, 0x103f0d11, 0x4a283505,   // ro.bg.ru_554 so.hu.nl_422  cs.af.lt_653 zu.sw.yo_333
  // [5a80]
  0x29003505, 0x2d1b25ec, 0x64063ba4, 0x551f13a7,   // zu.sl.un_330 eu.tr.sk_644  so.de.lg_433 et.cy.rw_532
  0x1e211c55, 0x1a073b0c, 0x641368a9, 0x0b0a07a4,   // id.jw.ms_442 so.it.tl_543  ig.et.lg_544 it.pt.es_433
  0x043f1305, 0x096b4a04, 0x283b10ec, 0x35526402,   // et.af.fi_333 yo.ceb.pl_332  lt.so.sw_644 lg.ha.zu_222
  0x0a23195a, 0x082a1205, 0x6b005212, 0x6b285209,   // gl.ca.pt_553 hu.mt.no_333  ha.ceb.un_640 ha.sw.ceb_444
  // [5a90]
  0x35000722, 0x061809ad, 0x0d1c1312, 0x2718310c,   // it.zu.un_870 pl.ga.de_643  bh.mr.ne_654 az.ga.gd_543
  0x04554aaf, 0x4a001b1b, 0x1200040e, 0x212568ad,   // yo.rw.fi_655 tr.yo.un_770  fi.hu.un_550 ig.eu.jw_643
  0x08022a0c, 0x20533f08, 0x211b640d, 0x191325ee,   // mt.da.no_543 af.ht.sq_443  lg.tr.jw_554 eu.et.gl_422
  0x1c090dac, 0x0e0c02a4, 0x3f002018, 0x08020c0d,   // ne.hi.mr_632 da.sv.is_433  sq.af.un_740 sv.da.no_554
  // [5aa0]
  0x533f230c, 0x0c003f02, 0x031a3faf, 0x1e1c10a4,   // ca.af.ht_543 af.sv.un_220  af.tl.nl_655 lt.id.ms_433
  0x020f11ad, 0x3200550c, 0x3f002021, 0x04252704,   // ro.lv.da_643 rw.bs.un_530  sq.af.un_860 gd.eu.fi_332
  0x2500272b, 0x0d00521a, 0x215255ad, 0x35256ba4,   // gd.eu.un_980 ha.cs.un_760  rw.ha.jw_643 ceb.eu.zu_433
  0x06032709, 0x04110a05, 0x08000e05, 0x126b1a0d,   // gd.nl.de_444 mk.ro.ru_333  is.no.un_330 tl.ceb.hu_554
  // [5ab0]
  0x2d0d07a6, 0x212518a4, 0x183f1105, 0x252307a0,   // it.cs.sk_521 ga.eu.jw_433  ro.af.ga_333 it.ca.eu_322
  0x0d006b04, 0x28000a05, 0x08020614, 0x116b27a0,   // ceb.cs.un_320 pt.sw.un_330  de.da.no_666 gd.ceb.ro_322
  0x0e6b5307, 0x070e06a4, 0x21283508, 0x0429090c,   // ht.ceb.is_432 de.is.it_433  zu.sw.jw_443 pl.sl.fi_543
  0x2018275a, 0x07051f11, 0x04642508, 0x350153a7,   // gd.ga.sq_553 cy.fr.it_653  eu.lg.fi_443 ht.en.zu_532
  // [5ac0]
  0x2d092908, 0x681a2507, 0x2d3b6405, 0x04642512,   // sl.pl.sk_443 eu.tl.ig_432  lg.so.sk_333 eu.lg.fi_654
  0x684a07a4, 0x0d356eac, 0x0c081b09, 0x0c310808,   // it.yo.ig_433 hmn.zu.cs_632  tr.no.sv_444 no.az.sv_443
  0x04191f11, 0x68130414, 0x08004a0d, 0x4a6468a0,   // cy.gl.fi_653 fi.et.ig_666  yo.no.un_540 ig.lg.yo_322
  0x04162da9, 0x080b310c, 0x0408115a, 0x100464a4,   // sk.hr.fi_544 az.es.no_543  ro.uk.ru_553 lg.fi.lt_433
  // [5ad0]
  0x68110a0c, 0x16002708, 0x3b1b045a, 0x0d092d07,   // pt.ro.ig_543 gd.hr.un_430  fi.tr.so_553 sk.pl.cs_432
  0x130c04a6, 0x31000c0d, 0x12532812, 0x1b310807,   // fi.sv.et_521 sv.az.un_540  sw.ht.hu_654 no.az.tr_432
  0x21283bad, 0x0a0f0d11, 0x23311b0d, 0x353b6807,   // so.sw.jw_643 cs.lv.pt_653  tr.az.ca_554 ig.so.zu_432
  0x31081b12, 0x530568ec, 0x18016ea0, 0x16002504,   // tr.no.az_654 ig.fr.ht_644  hmn.en.ga_322 eu.hr.un_320
  // [5ae0]
  0x2a006404, 0x68002108, 0x683521a4, 0x53006e12,   // lg.mt.un_320 jw.ig.un_430  jw.zu.ig_433 hmn.ht.un_640
  0x3b006821, 0x6e1e1c13, 0x043b03a9, 0x253b04ad,   // ig.so.un_860 id.ms.hmn_665  nl.so.fi_544 fi.so.eu_643
  0x040925ee, 0x281e1c0c, 0x03043b12, 0x043f2509,   // eu.pl.fi_422 id.ms.sw_543  so.fi.nl_654 eu.af.fi_444
  0x5220280c, 0x25003b22, 0x31003207, 0x55281a12,   // sw.sq.ha_543 so.eu.un_870  bs.az.un_420 tl.sw.rw_654
  // [5af0]
  0x5320280c, 0x1f180911, 0x090a2da4, 0x130f1ba4,   // sw.sq.ht_543 pl.ga.cy_653  sk.pt.pl_433 tr.lv.et_433
  0x080c1eec, 0x35315505, 0x3b004a13, 0x25003b18,   // ms.sv.no_644 rw.az.zu_333  yo.so.un_650 so.eu.un_740
  0x10526412, 0x033b040d, 0x645355ad, 0x08200ead,   // lg.ha.lt_654 fi.so.nl_554  rw.ht.lg_643 is.sq.no_643
  0x3b00042a, 0x2853100c, 0x0f022508, 0x2d0d0fa9,   // fi.so.un_970 lt.ht.sw_543  eu.da.lv_443 lv.cs.sk_544
  // [5b00]
  0x08021bec, 0x6b003204, 0x28032b12, 0x08021baf,   // tr.da.no_644 bs.ceb.un_320  vi.nl.sw_654 tr.da.no_655
  0x06102304, 0x2b190513, 0x2b00051a, 0x010306ac,   // ca.lt.de_332 fr.gl.vi_665  fr.vi.un_760 de.nl.en_632
  0x081b0208, 0x2b071112, 0x356e1e0c, 0x23072bad,   // da.tr.no_443 ro.it.vi_654  ms.hmn.zu_543 vi.it.ca_643
  0x19000e0c, 0x31211ca4, 0x2a130708, 0x08021b12,   // is.gl.un_530 id.jw.az_433  it.et.mt_443 tr.da.no_654
  // [5b10]
  0x1b00080d, 0x17000802, 0x3f000504, 0x2b051f0c,   // no.tr.un_540 uk.sr.un_220  fr.af.un_320 cy.fr.vi_543
  0x31051bec, 0x021b0808, 0x04052b08, 0x1c130da4,   // tr.fr.az_644 no.tr.da_443  vi.fr.fi_443 ne.bh.mr_433
  0x2b1104a9, 0x042b05af, 0x04005208, 0x291b2d07,   // fi.ro.vi_544 fr.vi.fi_655  ha.fi.un_430 sk.tr.sl_432
  0x23002b07, 0x3b000e12, 0x0c000802, 0x1c130dad,   // vi.ca.un_420 is.so.un_640  no.sv.un_220 ne.bh.mr_643
  // [5b20]
  0x531f05ad, 0x01005302, 0x23110404, 0x3b101aec,   // fr.cy.ht_643 ht.en.un_220  fi.ro.ca_332 tl.lt.so_644
  0x323b1aa4, 0x10531e07, 0x012321a4, 0x3f1f0308,   // tl.so.bs_433 ms.ht.lt_432  jw.ca.en_433 nl.cy.af_443
  0x3b551a0c, 0x256b550c, 0x6b255311, 0x55080cad,   // tl.rw.so_543 rw.ceb.eu_543  ht.eu.ceb_653 sv.no.rw_643
  0x531b0507, 0x531c05ee, 0x05000a1a, 0x3b1a5512,   // fr.tr.ht_432 fr.id.ht_422  pt.fr.un_760 rw.tl.so_654
  // [5b30]
  0x35006407, 0x0c002707, 0x6e003f2b, 0x3f6e0811,   // lg.zu.un_420 gd.sv.un_420  af.hmn.un_980 no.hmn.af_653
  0x0d03110c, 0x20001e11, 0x19182760, 0x04120faf,   // ro.nl.cs_543 ms.sq.un_630  gd.ga.gl_664 lv.hu.fi_655
  0x27086ead, 0x052718ec, 0x031c3fad, 0x6e052314,   // hmn.no.gd_643 ga.gd.fr_644  af.id.nl_643 ca.fr.hmn_666
  0x2a001a04, 0x040d6b0c, 0x6b3528a6, 0x161c290c,   // tl.mt.un_320 ceb.cs.fi_543  sw.zu.ceb_521 sl.id.hr_543
  // [5b40]
  0x213b20ad, 0x2b290a11, 0x2d090c09, 0x10556405,   // sq.so.jw_643 pt.sl.vi_653  sv.pl.sk_444 lg.rw.lt_333
  0x08051807, 0x2b086813, 0x27002809, 0x101f0411,   // ga.fr.no_432 ig.no.vi_665  sw.gd.un_440 fi.cy.lt_653
  0x2a070407, 0x11000622, 0x0f1210a9, 0x041a1ca7,   // fi.it.mt_432 de.ro.un_870  lt.hu.lv_544 id.tl.fi_532
  0x1c1a6b0c, 0x6b1e1cec, 0x2b006e22, 0x211e050c,   // ceb.tl.id_543 id.ms.ceb_644  hmn.vi.un_870 fr.ms.jw_543
  // [5b50]
  0x1a2052a0, 0x0e003504, 0x29005202, 0x1f2d2908,   // ha.sq.tl_322 zu.is.un_320  ha.sl.un_220 sl.sk.cy_443
  0x25521baf, 0x1c1e520b, 0x18283ba0, 0x070911ad,   // tr.ha.eu_655 ha.ms.id_542  so.sw.ga_322 ro.pl.it_643
  0x1c000f02, 0x6e002b2a, 0x4a5352a4, 0x190a0daf,   // lv.id.un_220 vi.hmn.un_970  ha.ht.yo_433 cs.pt.gl_655
  0x35006e1a, 0x1304525a, 0x35080e02, 0x290e090c,   // hmn.zu.un_760 ha.fi.et_553  is.no.zu_222 pl.is.sl_543
  // [5b60]
  0x3f25100c, 0x030507a4, 0x0d27180c, 0x351b5555,   // lt.eu.af_543 it.fr.nl_433  ga.gd.cs_543 rw.tr.zu_442
  0x1c0d09a9, 0x1b295504, 0x2a105505, 0x090d3b07,   // hi.ne.mr_544 rw.sl.tr_332  rw.lt.mt_333 so.cs.pl_432
  0x080c1c02, 0x19235302, 0x170c21a4, 0x2b1c3fa7,   // id.sv.no_222 ht.ca.gl_222  jw.sv.sr_433 af.id.vi_532
  0x06070e0c, 0x211c08a4, 0x061368a0, 0x523b20a4,   // is.it.de_543 no.id.jw_433  ig.et.de_322 sq.so.ha_433
  // [5b70]
  0x1e000c02, 0x13002b19, 0x531001a4, 0x25046812,   // sv.ms.un_220 vi.et.un_750  en.lt.ht_433 ig.fi.eu_654
  0x13046b14, 0x0a054aa7, 0x132d0408, 0x21000c09,   // ceb.fi.et_666 yo.fr.pt_532  fi.sk.et_443 sv.jw.un_440
  0x03085311, 0x2b000104, 0x1c004a04, 0x6e272355,   // ht.no.nl_653 en.vi.un_320  yo.id.un_320 ca.gd.hmn_442
  0x110a07a0, 0x120c1bec, 0x3b5553a4, 0x132b2807,   // it.pt.ro_322 tr.sv.hu_644  ht.rw.so_433 sw.vi.et_432
  // [5b80]
  0x2a3528ad, 0x2a211905, 0x27530ea4, 0x0b111908,   // sw.zu.mt_643 gl.jw.mt_333  is.ht.gd_433 gl.ro.es_443
  0x130c0413, 0x6e6b3502, 0x20000b09, 0x355521ee,   // fi.sv.et_665 zu.ceb.hmn_222  es.sq.un_440 jw.rw.zu_422
  0x02203f12, 0x0400642a, 0x292a0eee, 0x1c0d09ee,   // af.sq.da_654 lg.fi.un_970  is.mt.sl_422 hi.ne.mr_422
  0x181b0e04, 0x0802030c, 0x0e1e1c14, 0x1b000e08,   // is.tr.ga_332 nl.da.no_543  id.ms.is_666 is.tr.un_430
  // [5b90]
  0x31190b11, 0x25001705, 0x21132d08, 0x06003205,   // es.gl.az_653 sr.eu.un_330  sk.et.jw_443 bs.de.un_330
  0x1f35090c, 0x11550b05, 0x280518a4, 0x682a4aad,   // pl.zu.cy_543 es.rw.ro_333  ga.fr.sw_433 yo.mt.ig_643
  0x520306ad, 0x3f030faf, 0x0304210c, 0x092d3f04,   // de.nl.ha_643 lv.nl.af_655  jw.fi.nl_543 af.sk.pl_332
  0x066b010c, 0x133b030c, 0x081e0305, 0x1c1712ad,   // en.ceb.de_543 nl.so.et_543  nl.ms.no_333 hu.sr.id_643
  // [5ba0]
  0x080204a0, 0x0f4a68ec, 0x211268ec, 0x2a18010c,   // fi.da.no_322 ig.yo.lv_644  ig.hu.jw_644 en.ga.mt_543
  0x5200010d, 0x0f101b08, 0x05010705, 0x0a001012,   // en.ha.un_540 tr.lt.lv_443  it.en.fr_333 lt.pt.un_640
  0x1300682b, 0x120f10a4, 0x52006808, 0x041a6baf,   // ig.et.un_980 lt.lv.hu_433  ig.ha.un_430 ceb.tl.fi_655
  0x64001c1a, 0x25556b55, 0x1b033f0d, 0x2a02010d,   // id.lg.un_760 ceb.rw.eu_442  af.nl.tr_554 en.da.mt_554
  // [5bb0]
  0x28002a12, 0x0d112da0, 0x2a1a4aad, 0x08520207,   // mt.sw.un_640 sk.ro.cs_322  yo.tl.mt_643 da.ha.no_432
  0x07080208, 0x35292105, 0x6e0a13ee, 0x20112107,   // da.no.it_443 jw.sl.zu_333  et.pt.hmn_422 jw.ro.sq_432
  0x07100805, 0x09281ca4, 0x0c003107, 0x530e3507,   // uk.be.bg_333 id.sw.pl_433  az.sv.un_420 zu.is.ht_432
  0x21031fa4, 0x5200201b, 0x68283505, 0x17095208,   // cy.nl.jw_433 sq.ha.un_770  zu.sw.ig_333 ha.pl.sr_443
  // [5bc0]
  0x13556ba4, 0x0a11100c, 0x160752ee, 0x20001107,   // ceb.rw.et_433 be.ro.mk_543  ha.it.hr_422 ro.sq.un_420
  0x201152a0, 0x0f2a070c, 0x21045308, 0x120c2aa0,   // ha.ro.sq_322 it.mt.lv_543  ht.fi.jw_443 mt.sv.hu_322
  0x4a2a070c, 0x0c002904, 0x0a521107, 0x6e002b2c,   // it.mt.yo_543 sl.sv.un_320  ro.ha.pt_432 vi.hmn.un_990
  0x6b2a2dec, 0x0b00111a, 0x21003f07, 0x52001102,   // sk.mt.ceb_644 ro.es.un_760  af.jw.un_420 ro.ha.un_220
  // [5bd0]
  0x0a002302, 0x12131f08, 0x29001012, 0x13251260,   // ca.pt.un_220 cy.et.hu_443  lt.sl.un_640 hu.eu.et_664
  0x11120aa0, 0x0d1c09a7, 0x356812a4, 0x3f003b13,   // pt.hu.ro_322 hi.mr.ne_532  hu.ig.zu_433 so.af.un_650
  0x1a190bad, 0x0a100702, 0x1300680d, 0x2d110d0c,   // es.gl.tl_643 bg.be.mk_222  ig.et.un_540 cs.ro.sk_543
  0x0e001e02, 0x2a0628af, 0x2d290913, 0x3f2d0d08,   // ms.is.un_220 sw.de.mt_655  pl.sl.sk_665 cs.sk.af_443
  // [5be0]
  0x1f294aad, 0x12003105, 0x09530407, 0x521312a7,   // yo.sl.cy_643 az.hu.un_330  fi.ht.pl_432 hu.et.ha_532
  0x3f004a1a, 0x196b0bad, 0x2364250c, 0x23280714,   // yo.af.un_760 es.ceb.gl_643  eu.lg.ca_543 it.sw.ca_666
  0x0e1b2008, 0x0455530c, 0x31641b0d, 0x130e23ee,   // sq.tr.is_443 ht.rw.fi_543  tr.lg.az_554 ca.is.et_422
  0x211b3114, 0x080a05a9, 0x25100ead, 0x5500080d,   // az.tr.jw_666 fr.pt.no_544  is.lt.eu_643 no.rw.un_540
  // [5bf0]
  0x282555a9, 0x2b000722, 0x03681f0c, 0x0e0635ec,   // rw.eu.sw_544 it.vi.un_870  cy.ig.nl_543 zu.de.is_644
  0x0f000320, 0x10530408, 0x04001b08, 0x09001704,   // nl.lv.un_850 fi.ht.lt_443  tr.fi.un_430 sr.pl.un_320
  0x1e021ca4, 0x201b6411, 0x0e051ba4, 0x0c080da0,   // id.da.ms_433 lg.tr.sq_653  tr.fr.is_433 cs.no.sv_322
  0x063f1ca4, 0x311b1a08, 0x55131a0c, 0x0c352a04,   // id.af.de_433 tl.tr.az_443  tl.et.rw_543 mt.zu.sv_332

  // [5c00]
  0x1a64550c, 0x350264a4, 0x060b55a4, 0x063564a4,   // rw.lg.tl_543 lg.da.zu_433  rw.es.de_433 lg.zu.de_433
  0x0e003b07, 0x55061a05, 0x0e0435a4, 0x206e0112,   // so.is.un_420 tl.de.rw_333  zu.fi.is_433 en.hmn.sq_654
  0x16002307, 0x08040b02, 0x0c000502, 0x4a033f08,   // ca.hr.un_420 es.fi.no_222  fr.sv.un_220 af.nl.yo_443
  0x5531210c, 0x0e2909a4, 0x1b033205, 0x4a000d04,   // jw.az.rw_543 pl.sl.is_433  bs.nl.tr_333 cs.yo.un_320
  // [5c10]
  0x1e1c2102, 0x3f292da4, 0x1b35310c, 0x07112d0c,   // jw.id.ms_222 sk.sl.af_433  az.zu.tr_543 sk.ro.it_543
  0x120720af, 0x1907290c, 0x20280ead, 0x6b6423ad,   // sq.it.hu_655 sl.it.gl_543  is.sw.sq_643 ca.lg.ceb_643
  0x25000418, 0x3f0453a9, 0x531e3fad, 0x0f1b0512,   // fi.eu.un_740 ht.fi.af_544  af.ms.ht_643 fr.tr.lv_654
  0x08020c08, 0x35250608, 0x68553505, 0x2d000912,   // sv.da.no_443 de.eu.zu_443  zu.rw.ig_333 pl.sk.un_640
  // [5c20]
  0x6b002713, 0x0b5511a4, 0x080e0c12, 0x03002009,   // gd.ceb.un_650 ro.rw.es_433  sv.is.no_654 sq.nl.un_440
  0x25015505, 0x0a080e12, 0x2d080d07, 0x642835ee,   // rw.en.eu_333 is.no.pt_654  cs.no.sk_432 zu.sw.lg_422
  0x350a550c, 0x0a251b08, 0x1f0419ee, 0x0c083555,   // rw.pt.zu_543 tr.eu.pt_443  gl.fi.cy_422 zu.no.sv_442
  0x0e1f06a9, 0x271f060c, 0x2b5303a4, 0x0a230ea9,   // de.cy.is_544 de.cy.gd_543  nl.ht.vi_433 is.ca.pt_544
  // [5c30]
  0x081f0508, 0x1e1b28ad, 0x0c025509, 0x01000a04,   // fr.cy.no_443 sw.tr.ms_643  rw.da.sv_444 pt.en.un_320
  0x2a000f08, 0x1b00250c, 0x0329640c, 0x28646808,   // lv.mt.un_430 eu.tr.un_530  lg.sl.nl_543 ig.lg.sw_443
  0x0b1f070c, 0x080c05ec, 0x05002702, 0x0c000a05,   // it.cy.es_543 fr.sv.no_644  gd.fr.un_220 pt.sv.un_330
  0x2a000204, 0x2d0d13a4, 0x01091f04, 0x285218a9,   // da.mt.un_320 et.cs.sk_433  cy.pl.en_332 ga.ha.sw_544
  // [5c40]
  0x52006b02, 0x06090308, 0x2d001e0e, 0x0d282d07,   // ceb.ha.un_220 nl.pl.de_443  ms.sk.un_550 sk.sw.cs_432
  0x08040e12, 0x35550255, 0x0800060e, 0x10000f07,   // is.fi.no_654 da.rw.zu_442  de.no.un_550 lv.lt.un_420
  0x03001b02, 0x18271f0c, 0x09016ba4, 0x0c00291a,   // tr.nl.un_220 cy.gd.ga_543  ceb.en.pl_433 sl.sv.un_760
  0x3f1306a0, 0x1810270e, 0x080206af, 0x0b230608,   // de.et.af_322 gd.lt.ga_555  de.da.no_655 de.ca.es_443
  // [5c50]
  0x0c080708, 0x0a00072c, 0x6b020507, 0x130f2707,   // it.no.sv_443 bg.mk.un_990  fr.da.ceb_432 gd.lv.et_432
  0x0b0507a4, 0x320916ee, 0x06293f02, 0x061225a7,   // it.fr.es_433 hr.pl.bs_422  af.sl.de_222 eu.hu.de_532
  0x1f012a0c, 0x070b2314, 0x0d052113, 0x4a210d07,   // mt.en.cy_543 ca.es.it_666  jw.fr.cs_665 cs.jw.yo_432
  0x2d210d12, 0x35550aa4, 0x25190b60, 0x6b011fa9,   // cs.jw.sk_654 pt.rw.zu_433  es.gl.eu_664 cy.en.ceb_544
  // [5c60]
  0x1a023f04, 0x28001a22, 0x6b352112, 0x08110308,   // af.da.tl_332 tl.sw.un_870  jw.zu.ceb_654 nl.ro.no_443
  0x354a5514, 0x13110fa4, 0x55642805, 0x3b00290e,   // rw.yo.zu_666 lv.ro.et_433  sw.lg.rw_333 sl.so.un_550
  0x05002311, 0x25000a04, 0x21001012, 0x2d0d4a05,   // ca.fr.un_630 pt.eu.un_320  lt.jw.un_640 yo.cs.sk_333
  0x64351902, 0x25271204, 0x6800211a, 0x1008110c,   // gl.zu.lg_222 hu.gd.eu_332  jw.ig.un_760 ro.uk.be_543
  // [5c70]
  0x06001122, 0x12001704, 0x16001107, 0x4a21050e,   // ro.de.un_870 sr.hu.un_320  ro.hr.un_420 fr.jw.yo_555
  0x64014aa7, 0x0d131c0c, 0x2d0d05a9, 0x4a052107,   // yo.en.lg_532 mr.bh.ne_543  fr.cs.sk_544 jw.fr.yo_432
  0x25202112, 0x0d092908, 0x17072907, 0x0600550d,   // jw.sq.eu_654 sl.pl.cs_443  sl.it.sr_432 rw.de.un_540
  0x28006e13, 0x4a006b04, 0x1b002520, 0x272d5507,   // hmn.sw.un_650 ceb.yo.un_320  eu.tr.un_850 rw.sk.gd_432
  // [5c80]
  0x030b01a9, 0x211e1804, 0x53003f35, 0x1c041360,   // en.es.nl_544 ga.ms.jw_332  af.ht.un_A90 et.fi.id_664
  0x320901ac, 0x233f53ec, 0x0c53210c, 0x53001c2b,   // en.pl.bs_632 ht.af.ca_644  jw.ht.sv_543 id.ht.un_980
  0x53233fad, 0x19530a04, 0x05532308, 0x2d180d12,   // af.ca.ht_643 pt.ht.gl_332  ca.ht.fr_443 cs.ga.sk_654
  0x53003f1a, 0x1004520c, 0x27070b08, 0x550e53a9,   // af.ht.un_760 ha.fi.lt_543  es.it.gd_443 ht.is.rw_544
  // [5c90]
  0x29020ea4, 0x16044aa0, 0x0511010c, 0x2d0d1809,   // is.da.sl_433 yo.fi.hr_322  en.ro.fr_543 ga.cs.sk_444
  0x53113f55, 0x3f005334, 0x53006419, 0x1b00522b,   // af.ro.ht_442 ht.af.un_A80  lg.ht.un_750 ha.tr.un_980
  0x3f190aad, 0x03533f12, 0x18000d21, 0x20000534,   // pt.gl.af_643 af.ht.nl_654  cs.ga.un_860 fr.sq.un_A80
  0x171f4aa4, 0x10001f19, 0x6b0929a4, 0x644a35ad,   // yo.cy.sr_433 cy.lt.un_750  sl.pl.ceb_433 zu.yo.lg_643
  // [5ca0]
  0x190b35ee, 0x3b0f520c, 0x230f0608, 0x09523bad,   // zu.es.gl_422 ha.lv.so_543  de.lv.ca_443 so.ha.pl_643
  0x101304ad, 0x18000d13, 0x182d0dad, 0x521b4aad,   // fi.et.lt_643 cs.ga.un_650  cs.sk.ga_643 yo.tr.ha_643
  0x10011f12, 0x09001220, 0x131c095a, 0x251c21a9,   // cy.en.lt_654 hu.pl.un_850  hi.mr.bh_553 jw.id.eu_544
  0x2a000512, 0x19000609, 0x09215509, 0x03023fa9,   // fr.mt.un_640 de.gl.un_440  rw.jw.pl_444 af.da.nl_544
  // [5cb0]
  0x09000f08, 0x053f2312, 0x231925a4, 0x351b1208,   // lv.pl.un_430 ca.af.fr_654  eu.gl.ca_433 hu.tr.zu_443
  0x07192b13, 0x1000522c, 0x3f030e05, 0x05251012,   // vi.gl.it_665 ha.lt.un_990  is.nl.af_333 lt.eu.fr_654
  0x521108a4, 0x4a2b0fad, 0x031125ad, 0x2d0d68a0,   // no.ro.ha_433 lv.vi.yo_643  eu.ro.nl_643 ig.cs.sk_322
  0x0d001812, 0x551228af, 0x310c2aa4, 0x0c250808,   // ga.cs.un_640 sw.hu.rw_655  mt.sv.az_433 no.eu.sv_443
  // [5cc0]
  0x6e0752ad, 0x0a100f08, 0x0d0f2dec, 0x2b00251b,   // ha.it.hmn_643 lv.lt.pt_443  sk.lv.cs_644 eu.vi.un_770
  0x0a1b110c, 0x28526e0e, 0x2b236ea9, 0x0f11250d,   // ro.tr.pt_543 hmn.ha.sw_555  hmn.ca.vi_544 eu.ro.lv_554
  0x07521f08, 0x55001b20, 0x6e1352ec, 0x2d0d3fa4,   // cy.ha.it_443 tr.rw.un_850  ha.et.hmn_644 af.cs.sk_433
  0x03130111, 0x033f20ad, 0x061f0308, 0x040a0f12,   // en.et.nl_653 sq.af.nl_643  nl.cy.de_443 lv.pt.fi_654
  // [5cd0]
  0x520105a7, 0x130329ee, 0x2b041012, 0x521125af,   // fr.en.ha_532 sl.nl.et_422  lt.fi.vi_654 eu.ro.ha_655
  0x1e1c68a4, 0x0c3b0ea6, 0x012d05a0, 0x03001e02,   // ig.id.ms_433 is.so.sv_521  fr.sk.en_322 ms.nl.un_220
  0x6b01050c, 0x06192507, 0x010d050c, 0x010305ad,   // fr.en.ceb_543 eu.gl.de_432  fr.cs.en_543 fr.nl.en_643
  0x082d0d08, 0x2a001112, 0x23001008, 0x23053f09,   // cs.sk.no_443 ro.mt.un_640  lt.ca.un_430 af.fr.ca_444
  // [5ce0]
  0x060305a0, 0x35000304, 0x010607ec, 0x2d0d06ee,   // fr.nl.de_322 nl.zu.un_320  it.de.en_644 de.cs.sk_422
  0x1053020c, 0x1e271ca9, 0x274a2107, 0x532b52a4,   // da.ht.lt_543 id.gd.ms_544  jw.yo.gd_432 ha.vi.ht_433
  0x2b080208, 0x1a18270c, 0x0f6e20a9, 0x02253bad,   // da.no.vi_443 gd.ga.tl_543  sq.hmn.lv_544 so.eu.da_643
  0x0c251a0c, 0x10290dad, 0x643b1f0d, 0x1017110c,   // tl.eu.sv_543 cs.sl.lt_643  cy.so.lg_554 ro.sr.be_543
  // [5cf0]
  0x2b522dee, 0x1e2855a0, 0x3b1752a4, 0x1f00530e,   // sk.ha.vi_422 rw.sw.ms_322  ha.sr.so_433 ht.cy.un_550
  0x68100504, 0x2b1f27a4, 0x1900520b, 0x1e536e0c,   // fr.lt.ig_332 gd.cy.vi_433  ha.gl.un_520 hmn.ht.ms_543
  0x0a00021a, 0x1c521a0c, 0x1f001a1b, 0x251f2708,   // da.pt.un_760 tl.ha.id_543  tl.cy.un_770 gd.cy.eu_443
  0x2d0d3fee, 0x16000104, 0x21271c08, 0x536e1f0c,   // af.cs.sk_422 en.hr.un_320  id.gd.jw_443 cy.hmn.ht_543
  // [5d00]
  0x051c1a0c, 0x321a16ee, 0x07056407, 0x6e000d0d,   // tl.id.fr_543 hr.tl.bs_422  lg.fr.it_432 cs.hmn.un_540
  0x21006818, 0x10002009, 0x1c05210c, 0x3255210c,   // ig.jw.un_740 sq.lt.un_440  jw.fr.id_543 jw.rw.bs_543
  0x040912a4, 0x3f0305a0, 0x03023f14, 0x05001f0e,   // hu.pl.fi_433 fr.nl.af_322  af.da.nl_666 cy.fr.un_550
  0x320f0da0, 0x64002502, 0x171329ee, 0x0c2a290c,   // cs.lv.bs_322 eu.lg.un_220  sl.et.sr_422 sl.mt.sv_543
  // [5d10]
  0x23000614, 0x1a1b310c, 0x3f211ea4, 0x0e311b08,   // de.ca.un_660 az.tr.tl_543  ms.jw.af_433 tr.az.is_443
  0x1f1e270c, 0x64004a19, 0x28254a11, 0x08000704,   // gd.ms.cy_543 yo.lg.un_750  yo.eu.sw_653 bg.uk.un_320
  0x35211aad, 0x28291907, 0x283b5208, 0x1b0e310c,   // tl.jw.zu_643 gl.sl.sw_432  ha.so.sw_443 az.is.tr_543
  0x1b3113a0, 0x08171b07, 0x32001220, 0x190a01ee,   // et.az.tr_322 tr.sr.no_432  hu.bs.un_850 en.pt.gl_422
  // [5d20]
  0x182d120c, 0x1a04130c, 0x4a003b08, 0x680f3b0c,   // hu.sk.ga_543 et.fi.tl_543  so.yo.un_430 so.lv.ig_543
  0x04023107, 0x68134a0c, 0x3b1e68a4, 0x20131004,   // az.da.fi_432 yo.et.ig_543  ig.ms.so_433 lt.et.sq_332
  0x4a1b3108, 0x6b004a2b, 0x283b0fad, 0x1c1b210c,   // az.tr.yo_443 yo.ceb.un_980  lv.so.sw_643 jw.tr.id_543
  0x1c1f18a0, 0x0a0c070c, 0x6b13010c, 0x11090da4,   // ga.cy.id_322 it.sv.pt_543  en.et.ceb_543 cs.pl.ro_433
  // [5d30]
  0x684a3b0c, 0x122a130d, 0x20043b0c, 0x1c0312a7,   // so.yo.ig_543 et.mt.hu_554  so.fi.sq_543 hu.nl.id_532
  0x4a003b18, 0x0d1c09ee, 0x55003534, 0x52006813,   // so.yo.un_740 hi.mr.ne_422  zu.rw.un_A80 ig.ha.un_650
  0x1b1c3b0c, 0x03066402, 0x3b044a07, 0x081f0107,   // so.id.tr_543 lg.de.nl_222  yo.fi.so_432 en.cy.no_432
  0x2813040d, 0x08021aa4, 0x05006b04, 0x1e6b01ee,   // fi.et.sw_554 tl.da.no_433  ceb.fr.un_320 en.ceb.ms_422
  // [5d40]
  0x0f3b680c, 0x3204130c, 0x256835ad, 0x02062a11,   // ig.so.lv_543 et.fi.bs_543  zu.ig.eu_643 mt.de.da_653
  0x0b002314, 0x16000e05, 0x08002304, 0x13000113,   // ca.es.un_660 is.hr.un_330  ca.no.un_320 en.et.un_650
  0x100e16a0, 0x23001307, 0x0500130d, 0x0e211caf,   // hr.is.lt_322 et.ca.un_420  et.fr.un_540 id.jw.is_655
  0x024a1cad, 0x113528a4, 0x1a002807, 0x0b000a12,   // id.yo.da_643 sw.zu.ro_433  sw.tl.un_420 pt.es.un_640
  // [5d50]
  0x16000d19, 0x55000302, 0x0200290b, 0x1b003207,   // cs.hr.un_750 nl.rw.un_220  sl.da.un_520 bs.tr.un_420
  0x050c070c, 0x313f2008, 0x190b09a4, 0x3b211e0d,   // it.sv.fr_543 sq.af.az_443  pl.es.gl_433 ms.jw.so_554
  0x043b0305, 0x216b1c09, 0x1c041e11, 0x04683b0c,   // nl.so.fi_333 id.ceb.jw_444  ms.fi.id_653 so.ig.fi_543
  0x190b1a08, 0x21041e0c, 0x17322955, 0x133f1812,   // tl.es.gl_443 ms.fi.jw_543  sl.bs.sr_442 ga.af.et_654
  // [5d60]
  0x1b31680d, 0x033f3ba9, 0x4a683bad, 0x2a2103ac,   // ig.az.tr_554 so.af.nl_544  so.ig.yo_643 nl.jw.mt_632
  0x121b0d0b, 0x32681a08, 0x0d2512a9, 0x1c1e3b12,   // cs.tr.hu_542 tl.ig.bs_443  hu.eu.cs_544 so.ms.id_654
  0x190b1faf, 0x68354a12, 0x121b1c12, 0x32161ea9,   // cy.es.gl_655 yo.zu.ig_654  id.tr.hu_654 ms.hr.bs_544
  0x190b03a4, 0x06100c04, 0x1a003b12, 0x031a1309,   // nl.es.gl_433 sv.lt.de_332  so.tl.un_640 et.tl.nl_444
  // [5d70]
  0x4a3b285a, 0x0802180c, 0x19002119, 0x350206a4,   // sw.so.yo_553 ga.da.no_543  jw.gl.un_750 de.da.zu_433
  0x3f030907, 0x250d1208, 0x1a2b18a0, 0x042029ad,   // pl.nl.af_432 hu.cs.eu_443  ga.vi.tl_322 sl.sq.fi_643
  0x2a000a1b, 0x06120305, 0x3500252a, 0x0400281a,   // pt.mt.un_770 nl.hu.de_333  eu.zu.un_970 sw.fi.un_760
  0x211c0908, 0x29120d0c, 0x03000607, 0x1b121ca4,   // pl.id.jw_443 cs.hu.sl_543  de.nl.un_420 id.hu.tr_433
  // [5d80]
  0x033f1e0d, 0x0d21120c, 0x0c001f11, 0x29001208,   // ms.af.nl_554 hu.jw.cs_543  cy.sv.un_630 hu.sl.un_430
  0x3f0806a4, 0x640752a4, 0x182a270c, 0x0b2955ee,   // de.no.af_433 ha.it.lg_433  gd.mt.ga_543 rw.sl.es_422
  0x251118ec, 0x641235ec, 0x17200655, 0x05001811,   // ga.ro.eu_644 zu.hu.lg_644  de.sq.sr_442 ga.fr.un_630
  0x231907a4, 0x06001221, 0x190b2311, 0x2d002307,   // it.gl.ca_433 hu.de.un_860  ca.es.gl_653 ca.sk.un_420
  // [5d90]
  0x1000250e, 0x550d3555, 0x211c1f0c, 0x1c0d13a9,   // eu.lt.un_550 zu.cs.rw_442  cy.id.jw_543 bh.ne.mr_544
  0x3b0b2b12, 0x2a20520c, 0x08020daf, 0x1c6412ad,   // vi.es.so_654 ha.sq.mt_543  cs.da.no_655 hu.lg.id_643
  0x1700280d, 0x2d0d3202, 0x35001a02, 0x07280b08,   // sw.sr.un_540 bs.cs.sk_222  tl.zu.un_220 es.sw.it_443
  0x1200642a, 0x1b2753a0, 0x32002807, 0x2d0d0c05,   // lg.hu.un_970 ht.gd.tr_322  sw.bs.un_420 sv.cs.sk_333
  // [5da0]
  0x190b07a9, 0x6e002b12, 0x53120911, 0x072b19a0,   // it.es.gl_544 vi.hmn.un_640  pl.hu.ht_653 gl.vi.it_322
  0x1c1127a0, 0x2700210e, 0x08021f0e, 0x2b000119,   // gd.ro.id_322 jw.gd.un_550  cy.da.no_555 en.vi.un_750
  0x3b001602, 0x28315504, 0x55201105, 0x1b312bec,   // hr.so.un_220 rw.az.sw_332  ro.sq.rw_333 vi.az.tr_644
  0x050129ec, 0x29006821, 0x11071a13, 0x0e21160c,   // sl.en.fr_644 ig.sl.un_860  tl.it.ro_665 hr.jw.is_543
  // [5db0]
  0x253b5208, 0x190b18a9, 0x09000c09, 0x253b1ea4,   // ha.so.eu_443 ga.es.gl_544  sv.pl.un_440 ms.so.eu_433
  0x552d1f05, 0x354a6413, 0x28125507, 0x02121fa0,   // cy.sk.rw_333 lg.yo.zu_665  rw.hu.sw_432 cy.hu.da_322
  0x551220a0, 0x120c17ee, 0x130608ee, 0x55682d07,   // sq.hu.rw_322 sr.sv.hu_422  no.de.et_422 sk.ig.rw_432
  0x0c0e1fad, 0x120d2da4, 0x311b25ad, 0x2a006813,   // cy.is.sv_643 sk.cs.hu_433  eu.tr.az_643 ig.mt.un_650
  // [5dc0]
  0x1806010c, 0x16282909, 0x282a64af, 0x19180ba4,   // en.de.ga_543 sl.sw.hr_444  lg.mt.sw_655 es.ga.gl_433
  0x552d12a4, 0x68554a12, 0x2812290c, 0x55002021,   // hu.sk.rw_433 yo.rw.ig_654  sl.hu.sw_543 sq.rw.un_860
  0x0e004a04, 0x281809ad, 0x531b13a4, 0x16643204,   // yo.is.un_320 pl.ga.sw_643  et.tr.ht_433 bs.lg.hr_332
  0x19250ba4, 0x644a6812, 0x293b6ba4, 0x0c000e21,   // es.eu.gl_433 ig.yo.lg_654  ceb.so.sl_433 is.sv.un_860
  // [5dd0]
  0x0f0e0107, 0x3f095311, 0x2d290d12, 0x31003b04,   // en.is.lv_432 ht.pl.af_653  cs.sl.sk_654 so.az.un_320
  0x3f010f05, 0x29000508, 0x64002a14, 0x190b18a6,   // lv.en.af_333 fr.sl.un_430  mt.lg.un_660 ga.es.gl_521
  0x01003102, 0x0b190a60, 0x1328550c, 0x311a1bec,   // az.en.un_220 pt.gl.es_664  rw.sw.et_543 tr.tl.az_644
  0x1f3b030c, 0x19080307, 0x0f1064ad, 0x16000b04,   // nl.so.cy_543 nl.no.gl_432  lg.lt.lv_643 es.hr.un_320
  // [5de0]
  0x10640407, 0x29642109, 0x1c002807, 0x28003b07,   // fi.lg.lt_432 jw.lg.sl_444  sw.id.un_420 so.sw.un_420
  0x2d0d1fa4, 0x1a6e64a7, 0x27023fad, 0x0d093bad,   // cy.cs.sk_433 lg.hmn.tl_532  af.da.gd_643 so.pl.cs_643
  0x32162105, 0x190b03a0, 0x0f000412, 0x07005302,   // jw.hr.bs_333 nl.es.gl_322  fi.lv.un_640 ht.it.un_220
  0x050f010c, 0x3216070c, 0x02010807, 0x031b0e04,   // en.lv.fr_543 it.hr.bs_543  no.en.da_432 is.tr.nl_332
  // [5df0]
  0x282a18a0, 0x2904550c, 0x190b1a0c, 0x080212a4,   // ga.mt.sw_322 rw.fi.sl_543  tl.es.gl_543 hu.da.no_433
  0x25002305, 0x31000c04, 0x64350b09, 0x07230b08,   // ca.eu.un_330 sv.az.un_320  es.zu.lg_444 es.ca.it_443
  0x20556411, 0x29644a0c, 0x1a000707, 0x64001214,   // lg.rw.sq_653 yo.lg.sl_543  it.tl.un_420 hu.lg.un_660
  0x06250304, 0x4a005513, 0x182811ec, 0x1a004a07,   // nl.eu.de_332 rw.yo.un_650  ro.sw.ga_644 yo.tl.un_420
  // [5e00]
  0x0e520ca4, 0x3f001c12, 0x042910a9, 0x2152120c,   // sv.ha.is_433 id.af.un_640  lt.sl.fi_544 hu.ha.jw_543
  0x070123a4, 0x23201308, 0x6b121f55, 0x52252312,   // ca.en.it_433 et.sq.ca_443  cy.hu.ceb_442 ca.eu.ha_654
  0x252818a4, 0x04215208, 0x0f5204ac, 0x2a101708,   // ga.sw.eu_433 ha.jw.fi_443  fi.ha.lv_632 sr.lt.mt_443
  0x12005223, 0x23000f1a, 0x23005219, 0x1a162102,   // ha.hu.un_880 lv.ca.un_760  ha.ca.un_750 jw.hr.tl_222
  // [5e10]
  0x03001f12, 0x11001813, 0x23053fee, 0x0e11250c,   // cy.nl.un_640 ga.ro.un_650  af.fr.ca_422 eu.ro.is_543
  0x0821520c, 0x18102704, 0x52002514, 0x2a1710ad,   // ha.jw.no_543 gd.lt.ga_332  eu.ha.un_660 lt.sr.mt_643
  0x172a10ac, 0x3b056ba9, 0x3f080e0c, 0x3b4a6ba9,   // lt.mt.sr_632 ceb.fr.so_544  is.no.af_543 ceb.yo.so_544
  0x072a1fad, 0x12080205, 0x180d0ba0, 0x09062dad,   // cy.mt.it_643 da.no.hu_333  es.cs.ga_322 sk.de.pl_643
  // [5e20]
  0x1f296ea4, 0x521855a4, 0x210302ee, 0x060b110c,   // hmn.sl.cy_433 rw.ga.ha_433  da.nl.jw_422 ro.es.de_543
  0x55001e04, 0x523555ac, 0x554a0508, 0x190a35a4,   // ms.rw.un_320 rw.zu.ha_632  fr.yo.rw_443 zu.pt.gl_433
  0x116455ad, 0x6b2511af, 0x64553560, 0x130c0fec,   // rw.lg.ro_643 ro.eu.ceb_655  zu.rw.lg_664 lv.sv.et_644
  0x2a52130c, 0x0a1110a4, 0x1a00531a, 0x1b0802a0,   // et.ha.mt_543 lt.ro.pt_433  ht.tl.un_760 da.no.tr_322
  // [5e30]
  0x3f3b1aad, 0x283f5314, 0x0c030e04, 0x03002104,   // tl.so.af_643 ht.af.sw_666  is.nl.sv_332 jw.nl.un_320
  0x172555a4, 0x13000704, 0x272b3bad, 0x4a00642b,   // rw.eu.sr_433 it.et.un_320  so.vi.gd_643 lg.yo.un_980
  0x254a6808, 0x11001f1a, 0x526e2512, 0x0200082a,   // ig.yo.eu_443 cy.ro.un_760  eu.hmn.ha_654 no.da.un_970
  0x32011107, 0x282764ad, 0x2b211c11, 0x2029120c,   // ro.en.bs_432 lg.gd.sw_643  id.jw.vi_653 hu.sl.sq_543
  // [5e40]
  0x2b6e25a9, 0x11061213, 0x230668af, 0x232552a4,   // eu.hmn.vi_544 hu.de.ro_665  ig.de.ca_655 ha.eu.ca_433
  0x2500532b, 0x232b1f13, 0x1f001c04, 0x0b310ea4,   // ht.eu.un_980 cy.vi.ca_665  id.cy.un_320 is.az.es_433
  0x313f1f55, 0x25001f14, 0x23005202, 0x0e000b04,   // cy.af.az_442 cy.eu.un_660  ha.ca.un_220 es.is.un_320
  0x20292d11, 0x12030811, 0x6e005222, 0x0b0e3108,   // sk.sl.sq_653 no.nl.hu_653  ha.hmn.un_870 az.is.es_443
  // [5e50]
  0x310c13a4, 0x3b000913, 0x311a2d07, 0x181f01a4,   // et.sv.az_433 pl.so.un_650  sk.tl.az_432 en.cy.ga_433
  0x523555a4, 0x081110a4, 0x0b003105, 0x6e2b1114,   // rw.zu.ha_433 be.ro.uk_433  az.es.un_330 ro.vi.hmn_666
  0x3b1a060c, 0x04236e04, 0x1e002118, 0x101a6b13,   // de.tl.so_543 hmn.ca.fi_332  jw.ms.un_740 ceb.tl.lt_665
  0x0b002822, 0x0b311b12, 0x6b000612, 0x0212060c,   // sw.es.un_870 tr.az.es_654  de.ceb.un_640 de.hu.da_543
  // [5e60]
  0x1c255307, 0x52001f18, 0x0a006805, 0x5553290c,   // ht.eu.id_432 cy.ha.un_740  ig.pt.un_330 sl.ht.rw_543
  0x08020609, 0x1806030c, 0x0b311b0c, 0x3555680b,   // de.da.no_444 nl.de.ga_543  tr.az.es_543 ig.rw.zu_542
  0x18000702, 0x1e1c20ee, 0x09001a09, 0x356b1a08,   // it.ga.un_220 sq.id.ms_422  tl.pl.un_440 tl.ceb.zu_443
  0x2a100f09, 0x1a011b04, 0x023f0313, 0x04001133,   // lv.lt.mt_444 tr.en.tl_332  nl.af.da_665 ro.ru.un_A70
  // [5e70]
  0x04321608, 0x53003504, 0x196b1aad, 0x0b001a20,   // hr.bs.fi_443 zu.ht.un_320  tl.ceb.gl_643 tl.es.un_850
  0x3200031a, 0x21003f04, 0x1c1e1307, 0x6b1f3f11,   // nl.bs.un_760 af.jw.un_320  et.ms.id_432 af.cy.ceb_653
  0x03000113, 0x554a68ee, 0x03000c02, 0x171a250c,   // en.nl.un_650 ig.yo.rw_422  sv.nl.un_220 eu.tl.sr_543
  0x55684aa4, 0x5510290c, 0x111707a4, 0x17682da0,   // yo.ig.rw_433 sl.lt.rw_543  bg.sr.ro_433 sk.ig.sr_322
  // [5e80]
  0x1e521c12, 0x04522aad, 0x1a25350c, 0x55351a12,   // id.ha.ms_654 mt.ha.fi_643  zu.eu.tl_543 tl.zu.rw_654
  0x554a35a9, 0x16032a08, 0x531f520d, 0x3f1b1f07,   // zu.yo.rw_544 mt.nl.hr_443  ha.cy.ht_554 cy.tr.af_432
  0x25202a0c, 0x1e681ca9, 0x25205508, 0x2352090c,   // mt.sq.eu_543 id.ig.ms_544  rw.sq.eu_443 pl.ha.ca_543
  0x11005507, 0x52001a08, 0x6b686eee, 0x0e0d21a0,   // rw.ro.un_420 tl.ha.un_430  hmn.ig.ceb_422 jw.cs.is_322
  // [5e90]
  0x253b10a4, 0x1a5255ac, 0x32000605, 0x2d000704,   // lt.so.eu_433 rw.ha.tl_632  de.bs.un_330 it.sk.un_320
  0x061b2a05, 0x1f121809, 0x040b5502, 0x03200b14,   // mt.tr.de_333 ga.hu.cy_444  rw.es.fi_222 es.sq.nl_666
  0x4a6452ad, 0x2d0d12b3, 0x08005312, 0x13001c02,   // ha.lg.yo_643 hu.cs.sk_743  ht.no.un_640 id.et.un_220
  0x12001b12, 0x6b1e1c08, 0x2028550c, 0x16173207,   // tr.hu.un_640 id.ms.ceb_443  rw.sw.sq_543 bs.sr.hr_432
  // [5ea0]
  0x12004a2b, 0x060107a4, 0x18004a2c, 0x2d1a21ee,   // yo.hu.un_980 it.en.de_433  yo.ga.un_990 jw.tl.sk_422
  0x320a0f5a, 0x2b00182c, 0x530b120c, 0x171329a0,   // lv.pt.bs_553 ga.vi.un_990  hu.es.ht_543 sl.et.sr_322
  0x1c003b07, 0x00002b37, 0x18004a1b, 0x131c090d,   // so.id.un_420 vi.un.un_B00  yo.ga.un_770 hi.mr.bh_554
  0x1c253bec, 0x1b2129ee, 0x01115308, 0x080c13ec,   // so.eu.id_644 sl.jw.tr_422  ht.ro.en_443 et.sv.no_644
  // [5eb0]
  0x1a2855a4, 0x063555ad, 0x2a00130d, 0x351325af,   // rw.sw.tl_433 rw.zu.de_643  et.mt.un_540 eu.et.zu_655
  0x041029a4, 0x4a190a13, 0x05191bee, 0x0a004a14,   // sl.lt.fi_433 pt.gl.yo_665  tr.gl.fr_422 yo.pt.un_660
  0x3f00010c, 0x11551ba4, 0x17291bad, 0x3b1c2905,   // en.af.un_530 tr.rw.ro_433  tr.sl.sr_643 sl.id.so_333
  0x253521a6, 0x080525a4, 0x105223a7, 0x2a002309,   // jw.zu.eu_521 eu.fr.no_433  ca.ha.lt_532 ca.mt.un_440
  // [5ec0]
  0x03001218, 0x0801070d, 0x0c085512, 0x203528ec,   // hu.nl.un_740 it.en.no_554  rw.no.sv_654 sw.zu.sq_644
  0x18001e18, 0x04132dee, 0x2b003f08, 0x13003502,   // ms.ga.un_740 sk.et.fi_422  af.vi.un_430 zu.et.un_220
  0x551e1c14, 0x041117af, 0x0f291009, 0x28000d0d,   // id.ms.rw_666 sr.ro.ru_655  lt.sl.lv_444 cs.sw.un_540
  0x1a09100c, 0x05640ca0, 0x01000702, 0x1100020c,   // lt.pl.tl_543 sv.lg.fr_322  it.en.un_220 da.ro.un_530
  // [5ed0]
  0x1b2752a4, 0x08022502, 0x2d2904af, 0x04000d12,   // ha.gd.tr_433 eu.da.no_222  fi.sl.sk_655 cs.fi.un_640
  0x080e5207, 0x0f001308, 0x534a21ee, 0x20212a04,   // ha.is.no_432 et.lv.un_430  jw.yo.ht_422 mt.jw.sq_332
  0x531f2aad, 0x0f093107, 0x351a53ec, 0x016b52ee,   // mt.cy.ht_643 az.pl.lv_432  ht.tl.zu_644 ha.ceb.en_422
  0x070a3ba4, 0x100f1ba6, 0x2d0d09a4, 0x09001a0d,   // so.pt.it_433 tr.lv.lt_521  pl.cs.sk_433 tl.pl.un_540
  // [5ee0]
  0x190b2310, 0x2d0d17a9, 0x1e1c31a4, 0x08120c08,   // ca.es.gl_642 sr.cs.sk_544  az.id.ms_433 sv.hu.no_443
  0x532a09ec, 0x2d1b310d, 0x0e001604, 0x101b52a4,   // pl.mt.ht_644 az.tr.sk_554  hr.is.un_320 ha.tr.lt_433
  0x06190b05, 0x2a083b13, 0x100f285a, 0x0f042aa4,   // es.gl.de_333 so.no.mt_665  sw.lv.lt_553 mt.fi.lv_433
  0x110b0408, 0x04000e0e, 0x351a31ad, 0x28000412,   // fi.es.ro_443 is.fi.un_550  az.tl.zu_643 fi.sw.un_640
  // [5ef0]
  0x523b2a05, 0x52002a13, 0x250c19ad, 0x5500211a,   // mt.so.ha_333 mt.ha.un_650  gl.sv.eu_643 jw.rw.un_760
  0x016b04ee, 0x1a190b08, 0x351008a9, 0x04000a2a,   // fi.ceb.en_422 es.gl.tl_443  no.lt.zu_544 pt.fi.un_970
  0x642035ad, 0x083528a4, 0x1b001707, 0x07060360,   // zu.sq.lg_643 sw.zu.no_433  sr.tr.un_420 nl.de.it_664
  0x2b002a0d, 0x321710b3, 0x27230509, 0x2a0823af,   // mt.vi.un_540 lt.sr.bs_743  fr.ca.gd_444 ca.no.mt_655
  // [5f00]
  0x13093b02, 0x321735ee, 0x1a093b07, 0x160c320c,   // so.pl.et_222 zu.sr.bs_422  so.pl.tl_432 bs.sv.hr_543
  0x3217530c, 0x10041baf, 0x551b6ea0, 0x0e1a0b0c,   // ht.sr.bs_543 tr.fi.lt_655  hmn.tr.rw_322 es.tl.is_543
  0x11001c07, 0x10530dad, 0x051801a4, 0x033f3555,   // id.ro.un_420 cs.ht.lt_643  en.ga.fr_433 zu.af.nl_442
  0x02522109, 0x1b313ba6, 0x13091c07, 0x1f2a2360,   // jw.ha.da_444 so.az.tr_521  mr.hi.bh_432 ca.mt.cy_664
  // [5f10]
  0x1e1c2108, 0x1a00121a, 0x1e003202, 0x16002a12,   // jw.id.ms_443 hu.tl.un_760  bs.ms.un_220 mt.hr.un_640
  0x32000607, 0x31103f04, 0x12001307, 0x190b0aaf,   // de.bs.un_420 af.lt.az_332  et.hu.un_420 pt.es.gl_655
  0x055568a0, 0x10252908, 0x02103fec, 0x3f00101a,   // ig.rw.fr_322 sl.eu.lt_443  af.lt.da_644 lt.af.un_760
  0x0f00292b, 0x130111a4, 0x2900090c, 0x0b006b18,   // sl.lv.un_980 ro.en.et_433  pl.sl.un_530 ceb.es.un_740
  // [5f20]
  0x640955a4, 0x230b0705, 0x53110c0c, 0x1a3b090c,   // rw.pl.lg_433 it.es.ca_333  sv.ro.ht_543 pl.so.tl_543
  0x09270607, 0x04112a0c, 0x0a6b2a07, 0x072164a4,   // de.gd.pl_432 mt.ro.fi_543  mt.ceb.pt_432 lg.jw.it_433
  0x0b25190d, 0x09002a22, 0x1004120e, 0x11000a17,   // gl.eu.es_554 mt.pl.un_870  hu.fi.lt_555 pt.ro.un_730
  0x2d0d29a7, 0x29000813, 0x110464a0, 0x6b006405,   // sl.cs.sk_532 no.sl.un_650  lg.fi.ro_322 lg.ceb.un_330
  // [5f30]
  0x0b001f09, 0x311f1907, 0x0c3f64ec, 0x64252305,   // cy.es.un_440 gl.cy.az_432  lg.af.sv_644 ca.eu.lg_333
  0x52643b12, 0x0a315555, 0x3b011f0c, 0x29000e08,   // so.lg.ha_654 rw.az.pt_442  cy.en.so_543 is.sl.un_430
  0x0a3b1907, 0x5301055a, 0x011325ee, 0x0900550c,   // gl.so.pt_432 fr.en.ht_553  eu.et.en_422 rw.pl.un_530
  0x100453ad, 0x25191f04, 0x55202112, 0x096468ac,   // ht.fi.lt_643 cy.gl.eu_332  jw.sq.rw_654 ig.lg.pl_632
  // [5f40]
  0x52001904, 0x352813a7, 0x04003511, 0x1c090d04,   // gl.ha.un_320 et.sw.zu_532  zu.fi.un_630 ne.hi.mr_332
  0x320c25a4, 0x2a1320a9, 0x1b1a6bad, 0x102a3b11,   // eu.sv.bs_433 sq.et.mt_544  ceb.tl.tr_643 so.mt.lt_653
  0x09000e0d, 0x0e0c2511, 0x2a272504, 0x1a086ba7,   // is.pl.un_540 eu.sv.is_653  eu.gd.mt_332 ceb.no.tl_532
  0x25003f02, 0x070a25ad, 0x53093508, 0x681c27ac,   // af.eu.un_220 eu.pt.it_643  zu.pl.ht_443 gd.id.ig_632
  // [5f50]
  0x0d090aa0, 0x0d091f07, 0x32175305, 0x1e1c2a0c,   // pt.pl.cs_322 cy.pl.cs_432  ht.sr.bs_333 mt.id.ms_543
  0x0453350c, 0x52310507, 0x28171112, 0x11002a1b,   // zu.ht.fi_543 fr.az.ha_432  ro.sr.sw_654 mt.ro.un_770
  0x073b0b09, 0x0c000421, 0x18006b07, 0x09006e11,   // es.so.it_444 fi.sv.un_860  ceb.ga.un_420 hmn.pl.un_630
  0x1b1a53a4, 0x02091f13, 0x1e1c2805, 0x230501a4,   // ht.tl.tr_433 cy.pl.da_665  sw.id.ms_333 en.fr.ca_433
  // [5f60]
  0x17070460, 0x11055208, 0x09130da6, 0x1e1c68a9,   // ru.bg.sr_664 ha.fr.ro_443  cs.et.pl_521 ig.id.ms_544
  0x080c3fee, 0x640968ec, 0x2827180e, 0x1e1c52a9,   // af.sv.no_422 ig.pl.lg_644  ga.gd.sw_555 ha.id.ms_544
  0x060c04a9, 0x29002304, 0x20326812, 0x0464685a,   // fi.sv.de_544 ca.sl.un_320  ig.bs.sq_654 ig.lg.fi_553
  0x170f03ac, 0x3f032da4, 0x070523a4, 0x05642308,   // nl.lv.sr_632 sk.nl.af_433  ca.fr.it_433 ca.lg.fr_443
  // [5f70]
  0x03001109, 0x1b3555ec, 0x0c003504, 0x060e27a9,   // ro.nl.un_440 rw.zu.tr_644  zu.sv.un_320 gd.is.de_544
  0x64355212, 0x4a122d5a, 0x64552014, 0x10110855,   // ha.zu.lg_654 sk.hu.yo_553  sq.rw.lg_666 no.ro.lt_442
  0x2a00121b, 0x640e13ec, 0x232b0555, 0x52533bad,   // hu.mt.un_770 et.is.lg_644  fr.vi.ca_442 so.ht.ha_643
  0x0b1125a4, 0x060103ad, 0x551f0708, 0x0b0a230c,   // eu.ro.es_433 nl.en.de_643  it.cy.rw_443 ca.pt.es_543
  // [5f80]
  0x02120508, 0x1b5264a4, 0x08001b18, 0x2d291605,   // fr.hu.da_443 lg.ha.tr_433  tr.no.un_740 hr.sl.sk_333
  0x20000e14, 0x03002a14, 0x112123af, 0x556452a4,   // is.sq.un_660 mt.nl.un_660  ca.jw.ro_655 ha.lg.rw_433
  0x133f1b0c, 0x0c311307, 0x321603a4, 0x2500210e,   // tr.af.et_543 et.az.sv_432  nl.hr.bs_433 jw.eu.un_550
  0x29173fa4, 0x2b000a09, 0x2a2d09a6, 0x0a002b0d,   // af.sr.sl_433 pt.vi.un_440  pl.sk.mt_521 vi.pt.un_540
  // [5f90]
  0x11055308, 0x64000512, 0x12000c18, 0x09011fac,   // ht.fr.ro_443 fr.lg.un_640  sv.hu.un_740 cy.en.pl_632
  0x3f0c12a6, 0x040506a7, 0x0810020c, 0x08021702,   // hu.sv.af_521 de.fr.fi_532  da.lt.no_543 sr.da.no_222
  0x230b25a9, 0x03070ca0, 0x28002d12, 0x1f0c06a4,   // eu.es.ca_544 sv.it.nl_322  sk.sw.un_640 de.sv.cy_433
  0x2b000a07, 0x1b005502, 0x21005321, 0x684a315a,   // pt.vi.un_420 rw.tr.un_220  ht.jw.un_860 az.yo.ig_553
  // [5fa0]
  0x0d2d09a4, 0x011f0c08, 0x53002114, 0x35000204,   // pl.sk.cs_433 sv.cy.en_443  jw.ht.un_660 da.zu.un_320
  0x0700231d, 0x04123fa0, 0x3b2b01ee, 0x556468ec,   // ca.it.un_820 af.hu.fi_322  en.vi.so_422 ig.lg.rw_644
  0x08023faf, 0x08020705, 0x210568a7, 0x681a20ee,   // af.da.no_655 it.da.no_333  ig.fr.jw_532 sq.tl.ig_422
  0x3f130e0c, 0x35311b12, 0x31211b07, 0x0b000509,   // is.et.af_543 tr.az.zu_654  tr.jw.az_432 fr.es.un_440
  // [5fb0]
  0x5321230e, 0x23001c04, 0x352d530e, 0x08001311,   // ca.jw.ht_555 id.ca.un_320  ht.sk.zu_555 et.no.un_630
  0x100923a7, 0x2d002a05, 0x230b3107, 0x0c3201a4,   // ca.pl.lt_532 mt.sk.un_330  az.es.ca_432 en.bs.sv_433
  0x6e6b01ad, 0x10041702, 0x1c2155a4, 0x52002109,   // en.ceb.hmn_643 sr.ru.be_222  rw.jw.id_433 jw.ha.un_440
  0x20001104, 0x290a1b07, 0x27000807, 0x1300060b,   // ro.sq.un_320 tr.pt.sl_432  no.gd.un_420 de.et.un_520
  // [5fc0]
  0x095510ad, 0x0a192107, 0x17100a05, 0x13311b0c,   // lt.rw.pl_643 jw.gl.pt_432  mk.be.sr_333 tr.az.et_543
  0x321609af, 0x190b1f0c, 0x0d002521, 0x04122907,   // pl.hr.bs_655 cy.es.gl_543  eu.cs.un_860 sl.hu.fi_432
  0x55003b13, 0x2d291104, 0x0100280d, 0x166b0909,   // so.rw.un_650 ro.sl.sk_332  sw.en.un_540 pl.ceb.hr_444
  0x072d010c, 0x0700190e, 0x2a001b09, 0x2d0d12a4,   // en.sk.it_543 gl.it.un_550  tr.mt.un_440 hu.cs.sk_433
  // [5fd0]
  0x01276ba0, 0x211c2812, 0x093f10a4, 0x291805ec,   // ceb.gd.en_322 sw.id.jw_654  lt.af.pl_433 fr.ga.sl_644
  0x310e1b13, 0x12002909, 0x050c010c, 0x4a556408,   // tr.is.az_665 sl.hu.un_440  en.sv.fr_543 lg.rw.yo_443
  0x07004a02, 0x52684a13, 0x310e1f12, 0x253568a0,   // yo.it.un_220 yo.ig.ha_665  cy.is.az_654 ig.zu.eu_322
  0x1e1c2909, 0x0900120c, 0x041e12ad, 0x2100080e,   // sl.id.ms_444 hu.pl.un_530  hu.ms.fi_643 no.jw.un_550
  // [5fe0]
  0x1609295a, 0x1e003104, 0x1e1c2509, 0x19350711,   // sl.pl.hr_553 az.ms.un_320  eu.id.ms_444 it.zu.gl_653
  0x1e044aa0, 0x03002d14, 0x29210705, 0x1f1b315a,   // yo.fi.ms_322 sk.nl.un_660  it.jw.sl_333 az.tr.cy_553
  0x03013fa9, 0x1f311b13, 0x0528190d, 0x010a6ba4,   // af.en.nl_544 tr.az.cy_665  gl.sw.fr_554 ceb.pt.en_433
  0x0c0831ec, 0x05002007, 0x062a07a4, 0x04001209,   // az.no.sv_644 sq.fr.un_420  it.mt.de_433 hu.fi.un_440
  // [5ff0]
  0x1e001208, 0x08000218, 0x12000d08, 0x00002042,   // hu.ms.un_430 da.no.un_740  cs.hu.un_430 sq.un.un_C00
  0x063f0111, 0x122d210e, 0x200d04af, 0x04001e13,   // en.af.de_653 jw.sk.hu_555  fi.cs.sq_655 ms.fi.un_650
  0x1e1c0d09, 0x32001e02, 0x175307a7, 0x311b1e09,   // cs.id.ms_444 ms.bs.un_220  it.ht.sr_532 ms.tr.az_444
  0x536e070b, 0x18311b09, 0x08311309, 0x08020305,   // it.hmn.ht_542 tr.az.ga_444  et.az.no_444 nl.da.no_333

  // [6000]
  0x022d1e07, 0x23310511, 0x0f1025ad, 0x29322da4,   // ms.sk.da_432 fr.az.ca_653  eu.lt.lv_643 sk.bs.sl_433
  0x201b1ea4, 0x23041302, 0x64005202, 0x19182b0c,   // ms.tr.sq_433 et.fi.ca_222  ha.lg.un_220 vi.ga.gl_543
  0x10121b08, 0x060727a0, 0x1e001c34, 0x18270aa9,   // tr.hu.lt_443 gd.it.de_322  id.ms.un_A80 pt.gd.ga_544
  0x2b210605, 0x250703a0, 0x64001f22, 0x201b4a07,   // de.jw.vi_333 nl.it.eu_322  cy.lg.un_870 yo.tr.sq_432
  // [6010]
  0x215520ad, 0x53002523, 0x0a075505, 0x08001104,   // sq.rw.jw_643 eu.ht.un_880  rw.it.pt_333 ro.uk.un_320
  0x0f00290e, 0x251b68af, 0x18006e0e, 0x272b180c,   // sl.lv.un_550 ig.tr.eu_655  hmn.ga.un_550 ga.vi.gd_543
  0x07003504, 0x522807a4, 0x0b005505, 0x09251c05,   // zu.it.un_320 it.sw.ha_433  rw.es.un_330 id.eu.pl_333
  0x27091808, 0x2900202a, 0x1b001004, 0x53256bad,   // ga.pl.gd_443 sq.sl.un_970  lt.tr.un_320 ceb.eu.ht_643
  // [6020]
  0x0c684aa0, 0x3f1f0913, 0x03083fad, 0x0c001b0b,   // yo.ig.sv_322 pl.cy.af_665  af.no.nl_643 tr.sv.un_520
  0x31251e0c, 0x04132a0c, 0x28001902, 0x1e122512,   // ms.eu.az_543 mt.et.fi_543  gl.sw.un_220 eu.hu.ms_654
  0x643f29a4, 0x2503090b, 0x20212509, 0x1e1003a7,   // sl.af.lg_433 pl.nl.eu_542  eu.jw.sq_444 nl.lt.ms_532
  0x1e251c0c, 0x28001702, 0x25001812, 0x28000e04,   // id.eu.ms_543 sr.sw.un_220  ga.eu.un_640 is.sw.un_320
  // [6030]
  0x21001b2b, 0x2d1f0d07, 0x284a31a9, 0x0400090e,   // tr.jw.un_980 cs.cy.sk_432  az.yo.sw_544 pl.fi.un_550
  0x0c3f0fee, 0x160c06ee, 0x0d000807, 0x08520e08,   // lv.af.sv_422 de.sv.hr_422  no.cs.un_420 is.ha.no_443
  0x100c1bee, 0x1e291ca4, 0x55212012, 0x211e1aa9,   // tr.sv.lt_422 id.sl.ms_433  sq.jw.rw_654 tl.ms.jw_544
  0x17251c0c, 0x1e2d0d11, 0x00000201, 0x0e0c1f0c,   // id.eu.sr_543 cs.sk.ms_653  da.un.un_200 cy.sv.is_543
  // [6040]
  0x1b000c1b, 0x1e1c25a9, 0x68004a09, 0x18001913,   // sv.tr.un_770 eu.id.ms_544  yo.ig.un_440 gl.ga.un_650
  0x551b68af, 0x19310b55, 0x6804080c, 0x1c4a1ea4,   // ig.tr.rw_655 es.az.gl_442  no.fi.ig_543 ms.yo.id_433
  0x64001f12, 0x190a11a9, 0x68534a60, 0x270631a7,   // cy.lg.un_640 ro.pt.gl_544  yo.ht.ig_664 az.de.gd_532
  0x28100612, 0x071017a7, 0x1b0b08a0, 0x08101b08,   // de.lt.sw_654 sr.be.bg_532  no.es.tr_322 tr.lt.no_443
  // [6050]
  0x35211ca9, 0x0c523b08, 0x13211ba4, 0x68000219,   // id.jw.zu_544 so.ha.sv_443  tr.jw.et_433 da.ig.un_750
  0x32162005, 0x0a231913, 0x3b190a0d, 0x3b1b1012,   // sq.hr.bs_333 gl.ca.pt_665  pt.gl.so_554 lt.tr.so_654
  0x08000734, 0x04081113, 0x23002a1a, 0x232013a7,   // bg.uk.un_A80 ro.no.fi_665  mt.ca.un_760 et.sq.ca_532
  0x181011a0, 0x11190b5a, 0x1e171c04, 0x1b2509a4,   // ro.lt.ga_322 es.gl.ro_553  id.sr.ms_332 pl.eu.tr_433
  // [6060]
  0x35201b08, 0x166b0eee, 0x04201b0b, 0x0406130d,   // tr.sq.zu_443 is.ceb.hr_422  tr.sq.fi_542 et.de.fi_554
  0x21311b55, 0x0852010c, 0x070b01a4, 0x3f1b06ad,   // tr.az.jw_442 en.ha.no_543  en.es.it_433 de.tr.af_643
  0x014a0c04, 0x32000a08, 0x0b0a0eec, 0x2d290da4,   // sv.yo.en_332 pt.bs.un_430  is.pt.es_644 cs.sl.sk_433
  0x3b281a02, 0x081f02ee, 0x080c0412, 0x1703020c,   // tl.sw.so_222 da.cy.no_422  fi.sv.no_654 da.nl.sr_543
  // [6070]
  0x0c2a0708, 0x32000704, 0x2a0c0812, 0x1a27180e,   // it.mt.sv_443 it.bs.un_320  no.sv.mt_654 ga.gd.tl_555
  0x18191f08, 0x6e532ba4, 0x53206e05, 0x180a0807,   // cy.gl.ga_443 vi.ht.hmn_433  hmn.sq.ht_333 no.pt.ga_432
  0x3b1c1e0c, 0x1f3f0213, 0x2a3b0a08, 0x0a1b6e12,   // ms.id.so_543 da.af.cy_665  pt.so.mt_443 hmn.tr.pt_654
  0x09002804, 0x10005313, 0x6e0d2dee, 0x190b08a0,   // sw.pl.un_320 ht.lt.un_650  sk.cs.hmn_422 no.es.gl_322
  // [6080]
  0x311b6e04, 0x19181f0c, 0x29272b13, 0x1a00521a,   // hmn.tr.az_332 cy.ga.gl_543  vi.gd.sl_665 ha.tl.un_760
  0x08321708, 0x211a1e12, 0x6b1a1baf, 0x0c0a2913,   // sr.bs.no_443 ms.tl.jw_654  tr.tl.ceb_655 sl.pt.sv_665
  0x351a64a9, 0x1a0a68ee, 0x29000a2c, 0x53183ba4,   // lg.tl.zu_544 ig.pt.tl_422  pt.sl.un_990 so.ga.ht_433
  0x08001e08, 0x52000c04, 0x3b1135ee, 0x1b0901a4,   // ms.no.un_430 sv.ha.un_320  zu.ro.so_422 en.pl.tr_433
  // [6090]
  0x080232a4, 0x16293bad, 0x29001313, 0x101709a4,   // bs.da.no_433 so.sl.hr_643  et.sl.un_650 pl.sr.lt_433
  0x12000618, 0x6b183bee, 0x0f105313, 0x3b000c19,   // de.hu.un_740 so.ga.ceb_422  ht.lt.lv_665 sv.so.un_750
  0x3b002913, 0x250631a4, 0x0f0818a7, 0x3b09120c,   // sl.so.un_650 az.de.eu_433  ga.no.lv_532 hu.pl.so_543
  0x04280f04, 0x29063ba4, 0x01006b14, 0x17003107,   // lv.sw.fi_332 so.de.sl_433  ceb.en.un_660 az.sr.un_420
  // [60a0]
  0x28311baf, 0x16005307, 0x35002804, 0x1f2a210c,   // tr.az.sw_655 ht.hr.un_420  sw.zu.un_320 jw.mt.cy_543
  0x281a555a, 0x181b27ac, 0x3f0313ad, 0x1911180c,   // rw.tl.sw_553 gd.tr.ga_632  et.nl.af_643 ga.ro.gl_543
  0x683f03a4, 0x04080c14, 0x0a1a6bad, 0x556b210c,   // nl.af.ig_433 sv.no.fi_666  ceb.tl.pt_643 jw.ceb.rw_543
  0x100a110c, 0x4a001902, 0x21551aa4, 0x0e256ba9,   // ro.mk.be_543 gl.yo.un_220  tl.rw.jw_433 ceb.eu.is_544
  // [60b0]
  0x0c1117a4, 0x350452a4, 0x27003202, 0x19130ba4,   // sr.ro.sv_433 ha.fi.zu_433  bs.gd.un_220 es.et.gl_433
  0x52000422, 0x55211aa4, 0x27000b02, 0x06082a55,   // fi.ha.un_870 tl.jw.rw_433  es.gd.un_220 mt.no.de_442
  0x133f6405, 0x0a280c55, 0x55006b0e, 0x0c130a08,   // lg.af.et_333 sv.sw.pt_442  ceb.rw.un_550 pt.et.sv_443
  0x04201f0d, 0x13643f05, 0x3f1a1208, 0x0e041fee,   // cy.sq.fi_554 af.lg.et_333  hu.tl.af_443 cy.fi.is_422
  // [60c0]
  0x276b1a12, 0x5300212a, 0x0a170460, 0x210c52a7,   // tl.ceb.gd_654 jw.ht.un_970  ru.sr.mk_664 ha.sv.jw_532
  0x160435ad, 0x29132008, 0x0305020c, 0x531f0bee,   // zu.fi.hr_643 sq.et.sl_443  da.fr.nl_543 es.cy.ht_422
  0x0c0e0407, 0x683b13a4, 0x172905ee, 0x1e005221,   // fi.is.sv_432 et.so.ig_433  fr.sl.sr_422 ha.ms.un_860
  0x25080208, 0x1b3111a4, 0x310827a0, 0x68002b0d,   // da.no.eu_443 ro.az.tr_433  gd.no.az_322 vi.ig.un_540
  // [60d0]
  0x103f68a6, 0x230b64a4, 0x060c6bec, 0x1f1b0e0c,   // ig.af.lt_521 lg.es.ca_433  ceb.sv.de_644 is.tr.cy_543
  0x52350e5a, 0x3f1a0213, 0x210b1805, 0x0b0127a7,   // is.zu.ha_553 da.tl.af_665  ga.es.jw_333 gd.en.es_532
  0x053f0309, 0x043b13af, 0x3f082905, 0x2a00681b,   // nl.af.fr_444 et.so.fi_655  sl.no.af_333 ig.mt.un_770
  0x061801a4, 0x08180cac, 0x0300682b, 0x020f0c0c,   // en.ga.de_433 sv.ga.no_632  ig.nl.un_980 sv.lv.da_543
  // [60e0]
  0x0c1304a4, 0x07181907, 0x0b002707, 0x0e000308,   // fi.et.sv_433 gl.ga.it_432  gd.es.un_420 nl.is.un_430
  0x1e1c64af, 0x29256804, 0x0c04060e, 0x68003f21,   // lg.id.ms_655 ig.eu.sl_332  de.fi.sv_555 af.ig.un_860
  0x0c0504ac, 0x112701ad, 0x190a0e09, 0x1b311a08,   // fi.fr.sv_632 en.gd.ro_643  is.pt.gl_444 tl.az.tr_443
  0x6e006404, 0x1c2101a4, 0x09006e07, 0x230e2da0,   // lg.hmn.un_320 en.jw.id_433  hmn.pl.un_420 sk.is.ca_322
  // [60f0]
  0x05313f04, 0x21002804, 0x07352808, 0x01002714,   // af.az.fr_332 sw.jw.un_320  sw.zu.it_443 gd.en.un_660
  0x6e5305a4, 0x53232508, 0x233b05ec, 0x2d520dec,   // fr.ht.hmn_433 eu.ca.ht_443  fr.so.ca_644 cs.ha.sk_644
  0x644a52ad, 0x6804130c, 0x0f1725a0, 0x07190bec,   // ha.yo.lg_643 et.fi.ig_543  eu.sr.lv_322 es.gl.it_644
  0x68005508, 0x040c0660, 0x281f0aee, 0x68002a05,   // rw.ig.un_430 de.sv.fi_664  pt.cy.sw_422 mt.ig.un_330
  // [6100]
  0x6b1a2907, 0x55005302, 0x1e1c13ec, 0x17080a0d,   // sl.tl.ceb_432 ht.rw.un_220  et.id.ms_644 mk.uk.sr_554
  0x03023fee, 0x1a1b53a9, 0x193b25a4, 0x02201f12,   // af.da.nl_422 ht.tr.tl_544  eu.so.gl_433 cy.sq.da_654
  0x0f100a07, 0x04283bad, 0x101b09a0, 0x2110290c,   // pt.lt.lv_432 so.sw.fi_643  pl.tr.lt_322 sl.lt.jw_543
  0x0e312b55, 0x193f0b07, 0x3b002919, 0x08131807,   // vi.az.is_442 es.af.gl_432  sl.so.un_750 ga.et.no_432
  // [6110]
  0x1f001b19, 0x68004a35, 0x1b3f13af, 0x1200020d,   // tr.cy.un_750 yo.ig.un_A90  et.af.tr_655 da.hu.un_540
  0x0406250b, 0x10092daf, 0x1000641a, 0x3f000634,   // eu.de.fi_542 sk.pl.lt_655  lg.lt.un_760 de.af.un_A80
  0x3b003f0c, 0x043b29ee, 0x6b0610a0, 0x0f001c02,   // af.so.un_530 sl.so.fi_422  lt.de.ceb_322 id.lv.un_220
  0x133b5504, 0x1b0c04a4, 0x4a005207, 0x21001a02,   // rw.so.et_332 fi.sv.tr_433  ha.yo.un_420 tl.jw.un_220
  // [6120]
  0x1c110a04, 0x2d290dad, 0x0b2364ee, 0x060b0708,   // pt.ro.id_332 cs.sl.sk_643  lg.ca.es_422 it.es.de_443
  0x110f2daf, 0x0f042d0c, 0x1b0c2905, 0x062a0914,   // sk.lv.ro_655 sk.fi.lv_543  sl.sv.tr_333 pl.mt.de_666
  0x3b271812, 0x21136807, 0x2b005502, 0x07112312,   // ga.gd.so_654 ig.et.jw_432  rw.vi.un_220 ca.ro.it_654
  0x02031fec, 0x09190b08, 0x0a0318a4, 0x1711100c,   // cy.nl.da_644 es.gl.pl_443  ga.nl.pt_433 be.ro.sr_543
  // [6130]
  0x02093ba7, 0x6b2035a9, 0x111220a4, 0x0d0f2da4,   // so.pl.da_532 zu.sq.ceb_544  sq.hu.ro_433 sk.lv.cs_433
  0x16070aad, 0x233b27a9, 0x2d000a19, 0x042029a4,   // pt.it.hr_643 gd.so.ca_544  pt.sk.un_750 sl.sq.fi_433
  0x03321605, 0x35003f0c, 0x29041809, 0x0a212960,   // hr.bs.nl_333 af.zu.un_530  ga.fi.sl_444 sl.jw.pt_664
  0x010e25ad, 0x190b04ee, 0x4a041311, 0x25000407,   // eu.is.en_643 fi.es.gl_422  et.fi.yo_653 fi.eu.un_420
  // [6140]
  0x646b13ee, 0x0b001012, 0x1b0231a4, 0x1b23020c,   // et.ceb.lg_422 lt.es.un_640  az.da.tr_433 da.ca.tr_543
  0x190a1a14, 0x2021350c, 0x282552a0, 0x19001208,   // tl.pt.gl_666 zu.jw.sq_543  ha.eu.sw_322 hu.gl.un_430
  0x100f1c0c, 0x6e070912, 0x11292da0, 0x1a0f1e12,   // id.lv.lt_543 pl.it.hmn_654  sk.sl.ro_322 ms.lv.tl_654
  0x21200e12, 0x321703ee, 0x08020e0e, 0x2d0712a4,   // is.sq.jw_654 nl.sr.bs_422  is.da.no_555 hu.it.sk_433
  // [6150]
  0x21066b12, 0x190f0b0c, 0x53053faf, 0x25000212,   // ceb.de.jw_654 es.lv.gl_543  af.fr.ht_655 da.eu.un_640
  0x5301130c, 0x2d180d0d, 0x192d0d17, 0x0f001219,   // et.en.ht_543 cs.ga.sk_554  cs.sk.gl_753 hu.lv.un_750
  0x290f0da0, 0x052852ad, 0x032d1007, 0x3f071060,   // cs.lv.sl_322 ha.sw.fr_643  lt.sk.nl_432 lt.it.af_664
  0x093f0fee, 0x1a6b55ad, 0x1f0e20a4, 0x1f23190d,   // lv.af.pl_422 rw.ceb.tl_643  sq.is.cy_433 gl.ca.cy_554
  // [6160]
  0x1b2555ac, 0x2a0b0aa4, 0x0b251955, 0x3b55640d,   // rw.eu.tr_632 pt.es.mt_433  gl.eu.es_442 lg.rw.so_554
  0x110b010c, 0x04272107, 0x2d1219a9, 0x070f52ad,   // en.es.ro_543 jw.gd.fi_432  gl.hu.sk_544 ha.lv.it_643
  0x0728100c, 0x0709100c, 0x09085507, 0x6b1a2a12,   // lt.sw.it_543 lt.pl.it_543  rw.no.pl_432 mt.tl.ceb_654
  0x352a53a4, 0x122d190c, 0x13006e0d, 0x3b6e6b08,   // ht.mt.zu_433 gl.sk.hu_543  hmn.et.un_540 ceb.hmn.so_443
  // [6170]
  0x2d2307a9, 0x18001307, 0x35001a19, 0x55014aee,   // it.ca.sk_544 et.ga.un_420  tl.zu.un_750 yo.en.rw_422
  0x1b1a010c, 0x133b1aad, 0x130f1008, 0x123b1a05,   // en.tl.tr_543 tl.so.et_643  lt.lv.et_443 tl.so.hu_333
  0x1f3f030e, 0x192d0aa4, 0x29090d0c, 0x0e033f0c,   // nl.af.cy_555 pt.sk.gl_433  cs.pl.sl_543 af.nl.is_543
  0x102307a4, 0x25002302, 0x2d280707, 0x641e28a0,   // it.ca.lt_433 ca.eu.un_220  it.sw.sk_432 sw.ms.lg_322
  // [6180]
  0x186810a4, 0x6b1a2a09, 0x17003f1a, 0x120b04a4,   // lt.ig.ga_433 mt.tl.ceb_444  af.sr.un_760 fi.es.hu_433
  0x0e23180d, 0x19072305, 0x1a6b2a12, 0x27050712,   // ga.ca.is_554 ca.it.gl_333  mt.ceb.tl_654 it.fr.gd_654
  0x120a2508, 0x2d0d05af, 0x23553b0c, 0x043f0312,   // eu.pt.hu_443 fr.cs.sk_655  so.rw.ca_543 nl.af.fi_654
  0x03052102, 0x030c08ad, 0x08520c07, 0x101707a4,   // jw.fr.nl_222 no.sv.nl_643  sv.ha.no_432 bg.sr.be_433
  // [6190]
  0x0100250d, 0x3f03270c, 0x016e6ba0, 0x2a001912,   // eu.en.un_540 gd.nl.af_543  ceb.hmn.en_322 gl.mt.un_640
  0x11002702, 0x082a06ee, 0x0700191b, 0x19000707,   // gd.ro.un_220 de.mt.no_422  gl.it.un_770 it.gl.un_420
  0x01051fac, 0x12050e55, 0x060e1e07, 0x1c211e0b,   // cy.fr.en_632 is.fr.hu_442  ms.is.de_432 ms.jw.id_542
  0x6b2521a4, 0x3f0c0813, 0x0c180e05, 0x2b005319,   // jw.eu.ceb_433 no.sv.af_665  is.ga.sv_333 ht.vi.un_750
  // [61a0]
  0x05270408, 0x061b2107, 0x52283b13, 0x1c1f1008,   // fi.gd.fr_443 jw.tr.de_432  so.sw.ha_665 lt.cy.id_443
  0x052312a4, 0x090b6b02, 0x122d0aac, 0x523b5508,   // hu.ca.fr_433 ceb.es.pl_222  pt.sk.hu_632 rw.so.ha_443
  0x0e000513, 0x353b5507, 0x050e0fa4, 0x64531aa0,   // fr.is.un_650 rw.so.zu_432  lv.is.fr_433 tl.ht.lg_322
  0x1a206b0d, 0x0500211a, 0x053111ad, 0x2d120aa0,   // ceb.sq.tl_554 jw.fr.un_760  ro.az.fr_643 pt.hu.sk_322
  // [61b0]
  0x19070aee, 0x092d3fee, 0x033b0d07, 0x07111805,   // pt.it.gl_422 af.sk.pl_422  cs.so.nl_432 ga.ro.it_333
  0x041828a6, 0x230731a0, 0x07116807, 0x31354aaf,   // sw.ga.fi_521 az.it.ca_322  ig.ro.it_432 yo.zu.az_655
  0x190c0aee, 0x06080ca6, 0x2104130c, 0x0b3b07a0,   // pt.sv.gl_422 sv.no.de_521  et.fi.jw_543 it.so.es_322
  0x12531013, 0x190e0aad, 0x013f070c, 0x55001309,   // lt.ht.hu_665 pt.is.gl_643  it.af.en_543 et.rw.un_440
  // [61c0]
  0x1e201a05, 0x0e6864a4, 0x52203b0c, 0x181f2807,   // tl.sq.ms_333 lg.ig.is_433  so.sq.ha_543 sw.cy.ga_432
  0x23110aa9, 0x64350e05, 0x6b1f1804, 0x2b1e3f02,   // pt.ro.ca_544 is.zu.lg_333  ga.cy.ceb_332 af.ms.vi_222
  0x31321705, 0x350711a4, 0x6455110c, 0x04002121,   // sr.bs.az_333 ro.it.zu_433  ro.rw.lg_543 jw.fi.un_860
  0x10352a13, 0x09052a0c, 0x680735af, 0x0200350c,   // mt.zu.lt_665 mt.fr.pl_543  zu.it.ig_655 zu.da.un_530
  // [61d0]
  0x03001707, 0x10080212, 0x23000521, 0x2353250c,   // sr.nl.un_420 da.no.lt_654  fr.ca.un_860 eu.ht.ca_543
  0x0a1b1904, 0x3b00111b, 0x0a002123, 0x23001923,   // gl.tr.pt_332 ro.so.un_770  jw.pt.un_880 gl.ca.un_880
  0x5264530c, 0x10000b08, 0x20061f0c, 0x1b2d35af,   // ht.lg.ha_543 es.lt.un_430  cy.de.sq_543 zu.sk.tr_655
  0x0c061904, 0x311b3511, 0x4a000b02, 0x20522a0b,   // gl.de.sv_332 zu.tr.az_653  es.yo.un_220 mt.ha.sq_542
  // [61e0]
  0x31001902, 0x52211c12, 0x05230ead, 0x17100408,   // gl.az.un_220 id.jw.ha_654  is.ca.fr_643 ru.be.sr_443
  0x281a0408, 0x55002519, 0x530f215a, 0x1000090c,   // fi.tl.sw_443 eu.rw.un_750  jw.lv.ht_553 pl.lt.un_530
  0x55285213, 0x6b521a09, 0x10311bec, 0x080613ee,   // ha.sw.rw_665 tl.ha.ceb_444  tr.az.lt_644 et.de.no_422
  0x0400230c, 0x1b1a25a4, 0x1c000d02, 0x28552508,   // ca.fi.un_530 eu.tl.tr_433  ne.mr.un_220 eu.rw.sw_443
  // [61f0]
  0x0f100cad, 0x292d0f07, 0x0b121902, 0x0c001c02,   // sv.lt.lv_643 lv.sk.sl_432  gl.hu.es_222 id.sv.un_220
  0x6b002813, 0x203132a0, 0x55253112, 0x052519a6,   // sw.ceb.un_650 bs.az.sq_322  az.eu.rw_654 gl.eu.fr_521
  0x28042da4, 0x253b1108, 0x4a5528a4, 0x080e0fad,   // sk.fi.sw_433 ro.so.eu_443  sw.rw.yo_433 lv.is.no_643
  0x045228a9, 0x533f05a7, 0x101a1ea4, 0x094a6860,   // sw.ha.fi_544 fr.af.ht_532  ms.tl.lt_433 ig.yo.pl_664
  // [6200]
  0x256b1a60, 0x20183508, 0x016b0507, 0x3b2808a0,   // tl.ceb.eu_664 zu.ga.sq_443  fr.ceb.en_432 no.sw.so_322
  0x282055af, 0x4a355304, 0x2a5325a6, 0x1e1228a4,   // rw.sq.sw_655 ht.zu.yo_332  eu.ht.mt_521 sw.hu.ms_433
  0x351f680c, 0x53023f08, 0x1100180e, 0x0a101705,   // ig.cy.zu_543 af.da.ht_443  ga.ro.un_550 sr.be.mk_333
  0x6402080c, 0x0b000613, 0x190b050c, 0x2d001112,   // no.da.lg_543 de.es.un_650  fr.es.gl_543 ro.sk.un_640
  // [6210]
  0x53006808, 0x10010fad, 0x081f0cec, 0x0605190c,   // ig.ht.un_430 lv.en.lt_643  sv.cy.no_644 gl.fr.de_543
  0x6b3b19ad, 0x4a000d13, 0x0a0702a4, 0x2d000508,   // gl.so.ceb_643 cs.yo.un_650  da.it.pt_433 fr.sk.un_430
  0x124a0509, 0x3b060b05, 0x3f000519, 0x4a2a13ad,   // fr.yo.hu_444 es.de.so_333  fr.af.un_750 et.mt.yo_643
  0x070a100e, 0x4a002b0d, 0x2b001809, 0x0a2d05a9,   // be.mk.bg_555 vi.yo.un_540  ga.vi.un_440 fr.sk.pt_544
  // [6220]
  0x3f3507a7, 0x6b681aec, 0x551304ee, 0x20002502,   // it.zu.af_532 tl.ig.ceb_644  fi.et.rw_422 eu.sq.un_220
  0x3b13640e, 0x0a1a28a4, 0x64002a0d, 0x110b23ad,   // lg.et.so_555 sw.tl.pt_433  mt.lg.un_540 ca.es.ro_643
  0x0e184a14, 0x52006e09, 0x07001a2b, 0x1a0e64af,   // yo.ga.is_666 hmn.ha.un_440  tl.it.un_980 lg.is.tl_655
  0x182a27ee, 0x0c000a08, 0x06002d04, 0x17001104,   // gd.mt.ga_422 pt.sv.un_430  sk.de.un_320 ro.sr.un_320
  // [6230]
  0x6b1a55a4, 0x0d1c1fa0, 0x07000e0c, 0x0f4a64a7,   // rw.tl.ceb_433 cy.id.cs_322  is.it.un_530 lg.yo.lv_532
  0x01063ba7, 0x0b4a280c, 0x0c20210c, 0x1200060d,   // so.de.en_532 sw.yo.es_543  jw.sq.sv_543 de.hu.un_540
  0x2855215a, 0x2d350da4, 0x21001202, 0x2100030e,   // jw.rw.sw_553 cs.zu.sk_433  ur.fa.un_220 nl.jw.un_550
  0x3b645505, 0x27002013, 0x0d2910a4, 0x036b68a0,   // rw.lg.so_333 sq.gd.un_650  lt.sl.cs_433 ig.ceb.nl_322
  // [6240]
  0x552d2855, 0x04132912, 0x0300350e, 0x681a64a4,   // sw.sk.rw_442 sl.et.fi_654  zu.nl.un_550 lg.tl.ig_433
  0x2d004a11, 0x100b0fa7, 0x101a1305, 0x0a2728a0,   // yo.sk.un_630 lv.es.lt_532  et.tl.lt_333 sw.gd.pt_322
  0x321a0307, 0x2d1f0ca4, 0x12101313, 0x06001304,   // nl.tl.bs_432 sv.cy.sk_433  et.lt.hu_665 et.de.un_320
  0x1b553bec, 0x4a6b350c, 0x253507ee, 0x13554a02,   // so.rw.tr_644 zu.ceb.yo_543  it.zu.eu_422 yo.rw.et_222
  // [6250]
  0x060c3fa4, 0x32000104, 0x062d0d08, 0x28181ba4,   // af.sv.de_433 en.bs.un_320  cs.sk.de_443 tr.ga.sw_433
  0x070e1f02, 0x120a2105, 0x0f000b04, 0x0c351807,   // cy.is.it_222 jw.pt.hu_333  es.lv.un_320 ga.zu.sv_432
  0x0a000b04, 0x1b000a07, 0x10076b08, 0x040c0a08,   // es.pt.un_320 pt.tr.un_420  ceb.it.lt_443 pt.sv.fi_443
  0x3b553205, 0x551764ee, 0x0968285a, 0x35311fa7,   // bs.rw.so_333 lg.sr.rw_422  sw.ig.pl_553 cy.az.zu_532
  // [6260]
  0x09130404, 0x13006407, 0x1b3152ee, 0x1335100c,   // fi.et.pl_332 lg.et.un_420  ha.az.tr_422 lt.zu.et_543
  0x2a20550d, 0x0b0407a4, 0x25001b14, 0x2728350c,   // rw.sq.mt_554 it.fi.es_433  tr.eu.un_660 zu.sw.gd_543
  0x200709ad, 0x683b130c, 0x12251fad, 0x0c55280c,   // pl.it.sq_643 et.so.ig_543  cy.eu.hu_643 sw.rw.sv_543
  0x11002309, 0x110a170c, 0x21283b04, 0x52002014,   // ca.ro.un_440 sr.mk.ro_543  so.sw.jw_332 sq.ha.un_660
  // [6270]
  0x20646bec, 0x16202a0c, 0x201c1e11, 0x6800132c,   // ceb.lg.sq_644 mt.sq.hr_543  ms.id.sq_653 et.ig.un_990
  0x3f0106ac, 0x181f55ee, 0x53250f08, 0x1c64210d,   // de.en.af_632 rw.cy.ga_422  lv.eu.ht_443 jw.lg.id_554
  0x13201014, 0x0c55250c, 0x29000304, 0x0e002705,   // lt.sq.et_666 eu.rw.sv_543  nl.sl.un_320 gd.is.un_330
  0x31201baf, 0x0d091c13, 0x01001807, 0x3f0203a0,   // tr.sq.az_655 mr.hi.ne_665  ga.en.un_420 nl.da.af_322
  // [6280]
  0x3b212007, 0x0f046408, 0x3b00212c, 0x1f002b13,   // sq.jw.so_432 lg.fi.lv_443  jw.so.un_990 vi.cy.un_650
  0x13183b0c, 0x0c072aad, 0x1f002b19, 0x3b1f6b0b,   // so.ga.et_543 mt.it.sv_643  vi.cy.un_750 ceb.cy.so_542
  0x04103ba9, 0x53004a0d, 0x182120a9, 0x35041a09,   // so.lt.fi_544 yo.ht.un_540  sq.jw.ga_544 tl.fi.zu_444
  0x0c032aee, 0x3110120c, 0x0d292da0, 0x523b10af,   // mt.nl.sv_422 hu.lt.az_543  sk.sl.cs_322 lt.so.ha_655
  // [6290]
  0x183b27ec, 0x3b11100d, 0x0653030c, 0x03100911,   // gd.so.ga_644 lt.ro.so_554  nl.ht.de_543 pl.lt.nl_653
  0x3b0c52af, 0x11251011, 0x0f3b13ec, 0x031a6bee,   // ha.sv.so_655 lt.eu.ro_653  et.so.lv_644 ceb.tl.nl_422
  0x2d0d1f14, 0x311b0c0c, 0x12113512, 0x5212350c,   // cy.cs.sk_666 sv.tr.az_543  zu.ro.hu_654 zu.hu.ha_543
  0x16552508, 0x0d3b27ee, 0x10110413, 0x23120107,   // eu.rw.hr_443 gd.so.cs_422  fi.ro.lt_665 en.hu.ca_432
  // [62a0]
  0x0431100c, 0x0f002304, 0x20003f04, 0x1b043505,   // lt.az.fi_543 ca.lv.un_320  af.sq.un_320 zu.fi.tr_333
  0x205521a9, 0x0804020e, 0x68195508, 0x0b0a0702,   // jw.rw.sq_544 da.fi.no_555  rw.gl.ig_443 it.pt.es_222
  0x2d1128ad, 0x04082a0c, 0x3f080ca6, 0x016b0eee,   // sw.ro.sk_643 mt.no.fi_543  sv.no.af_521 is.ceb.en_422
  0x23532505, 0x681c3507, 0x64213507, 0x52554a0c,   // eu.ht.ca_333 zu.id.ig_432  zu.jw.lg_432 yo.rw.ha_543
  // [62b0]
  0x0e52550c, 0x08026405, 0x03532107, 0x03250f60,   // rw.ha.is_543 lg.da.no_333  jw.ht.nl_432 lv.eu.nl_664
  0x1610200c, 0x1b4a68af, 0x0a531cee, 0x190b55ee,   // sq.lt.hr_543 ig.yo.tr_655  id.ht.pt_422 rw.es.gl_422
  0x29136402, 0x133b3f05, 0x071f27ec, 0x55253b0c,   // lg.et.sl_222 af.so.et_333  gd.cy.it_644 so.eu.rw_543
  0x281a1204, 0x211a64ad, 0x0613645a, 0x105528a9,   // hu.tl.sw_332 lg.tl.jw_643  lg.et.de_553 sw.rw.lt_544
  // [62c0]
  0x0f4a53a4, 0x325525a7, 0x180e10a4, 0x09006b0d,   // ht.yo.lv_433 eu.rw.bs_532  lt.is.ga_433 ceb.pl.un_540
  0x250f0baf, 0x0c034a0c, 0x2d000308, 0x0e001b07,   // es.lv.eu_655 yo.nl.sv_543  nl.sk.un_430 tr.is.un_420
  0x2d033bee, 0x0b002102, 0x3f100b0c, 0x280e52a4,   // so.nl.sk_422 jw.es.un_220  es.lt.af_543 ha.is.sw_433
  0x53033faf, 0x2d0d0909, 0x132718ec, 0x18120307,   // af.nl.ht_655 pl.cs.sk_444  ga.gd.et_644 nl.hu.ga_432
  // [62d0]
  0x2b000621, 0x11002519, 0x071a10a4, 0x1f3b090d,   // de.vi.un_860 eu.ro.un_750  lt.tl.it_433 pl.so.cy_554
  0x033f53af, 0x06001704, 0x04131005, 0x1200040c,   // ht.af.nl_655 sr.de.un_320  lt.et.fi_333 fi.hu.un_530
  0x06530112, 0x0c083f0b, 0x55106408, 0x070e0c05,   // en.ht.de_654 af.no.sv_542  lg.lt.rw_443 sv.is.it_333
  0x2d0d1fad, 0x102928a4, 0x0a2a05ee, 0x0335100c,   // cy.cs.sk_643 sw.sl.lt_433  fr.mt.pt_422 lt.zu.nl_543
  // [62e0]
  0x20006807, 0x13031ea7, 0x6b1a1f0c, 0x6404130c,   // ig.sq.un_420 ms.nl.et_532  cy.tl.ceb_543 et.fi.lg_543
  0x2d3f03a4, 0x072a64a4, 0x0f1f060c, 0x1a09210c,   // nl.af.sk_433 lg.mt.it_433  de.cy.lv_543 jw.pl.tl_543
  0x53001b12, 0x09182760, 0x28001a19, 0x16291007,   // tr.ht.un_640 gd.ga.pl_664  tl.sw.un_750 lt.sl.hr_432
  0x531c1ea4, 0x093b2108, 0x5535290c, 0x0d092d04,   // ms.id.ht_433 jw.so.pl_443  sl.zu.rw_543 sk.pl.cs_332
  // [62f0]
  0x033f0fec, 0x046e1304, 0x3b1b31ec, 0x53091b07,   // lv.af.nl_644 et.hmn.fi_332  az.tr.so_644 tr.pl.ht_432
  0x4a6b1aad, 0x2100092a, 0x0f2d1f08, 0x6e683b04,   // tl.ceb.yo_643 pl.jw.un_970  cy.sk.lv_443 so.ig.hmn_332
  0x6e1e1ca4, 0x4a3b6ea4, 0x212007ee, 0x120964a7,   // id.ms.hmn_433 hmn.so.yo_433  it.sq.jw_422 lg.pl.hu_532
  0x20282107, 0x311b6408, 0x20000a07, 0x0a2921a4,   // jw.sw.sq_432 lg.tr.az_443  pt.sq.un_420 jw.sl.pt_433
  // [6300]
  0x1055130c, 0x1b006e08, 0x13003b34, 0x030e0208,   // et.rw.lt_543 hmn.tr.un_430  so.et.un_A80 da.is.nl_443
  0x0b0a01a4, 0x096410ad, 0x530910ad, 0x6b1b1007,   // en.pt.es_433 lt.lg.pl_643  lt.pl.ht_643 lt.tr.ceb_432
  0x01000e04, 0x0503190c, 0x282519ec, 0x3f28310c,   // is.en.un_320 gl.nl.fr_543  gl.eu.sw_644 az.sw.af_543
  0x35002904, 0x2a1c28a7, 0x27001f23, 0x29530b07,   // sl.zu.un_320 sw.id.mt_532  cy.gd.un_880 es.ht.sl_432
  // [6310]
  0x3f1c1ea4, 0x1f006b23, 0x20281007, 0x2b13010c,   // ms.id.af_433 ceb.cy.un_880  lt.sw.sq_432 en.et.vi_543
  0x64554a08, 0x010753ee, 0x06033555, 0x23120e0c,   // yo.rw.lg_443 ht.it.en_422  zu.nl.de_442 is.hu.ca_543
  0x2d0a0dec, 0x10001212, 0x5500310c, 0x64353114,   // cs.pt.sk_644 hu.lt.un_640  az.rw.un_530 az.zu.lg_666
  0x1e312aa4, 0x0a2d2504, 0x203f130c, 0x35182813,   // mt.az.ms_433 eu.sk.pt_332  et.af.sq_543 sw.ga.zu_665
  // [6320]
  0x0a1f2d11, 0x09001907, 0x55314a5a, 0x06000f04,   // sk.cy.pt_653 gl.pl.un_420  yo.az.rw_553 lv.de.un_320
  0x03290608, 0x1b042aa0, 0x4a0725ad, 0x235305a9,   // de.sl.nl_443 mt.fi.tr_322  eu.it.yo_643 fr.ht.ca_544
  0x04252309, 0x20000302, 0x1c04100c, 0x04001f04,   // ca.eu.fi_444 nl.sq.un_220  lt.fi.id_543 cy.fi.un_320
  0x180327a4, 0x0e00021b, 0x2d0d0609, 0x190b0702,   // gd.nl.ga_433 da.is.un_770  de.cs.sk_444 it.es.gl_222
  // [6330]
  0x09276b08, 0x12001f12, 0x53012bec, 0x320c1708,   // ceb.gd.pl_443 cy.hu.un_640  vi.en.ht_644 sr.sv.bs_443
  0x3b001f14, 0x1b00100e, 0x08000a04, 0x03001311,   // cy.so.un_660 lt.tr.un_550  mk.uk.un_320 et.nl.un_630
  0x07000519, 0x6b531a14, 0x0a2327a4, 0x53001f1b,   // fr.it.un_750 tl.ht.ceb_666  gd.ca.pt_433 cy.ht.un_770
  0x4a001909, 0x061e0804, 0x2d2a07a4, 0x3f2a0714,   // gl.yo.un_440 no.ms.de_332  it.mt.sk_433 it.mt.af_666
  // [6340]
  0x55006814, 0x35551108, 0x01532702, 0x10321608,   // ig.rw.un_660 ro.rw.zu_443  gd.ht.en_222 hr.bs.lt_443
  0x64006829, 0x27001c02, 0x2500101a, 0x18190b13,   // ig.lg.un_960 id.gd.un_220  lt.eu.un_760 es.gl.ga_665
  0x2d280b04, 0x11000e2a, 0x21351a08, 0x0c0203a0,   // es.sw.sk_332 is.ro.un_970  tl.zu.jw_443 nl.da.sv_322
  0x321602ee, 0x643553a4, 0x21000e0c, 0x09201f08,   // da.hr.bs_422 ht.zu.lg_433  is.jw.un_530 cy.sq.pl_443
  // [6350]
  0x05001f05, 0x64133511, 0x133b0308, 0x1f53230c,   // cy.fr.un_330 zu.et.lg_653  nl.so.et_443 ca.ht.cy_543
  0x68181fa9, 0x3f640955, 0x2a0523a9, 0x252009a4,   // cy.ga.ig_544 pl.lg.af_442  ca.fr.mt_544 pl.sq.eu_433
  0x521a6ba4, 0x32160f0e, 0x6b01200d, 0x3f280a12,   // ceb.tl.ha_433 lv.hr.bs_555  sq.en.ceb_554 pt.sw.af_654
  0x53006813, 0x6b3f130c, 0x282153ec, 0x3b001e02,   // ig.ht.un_650 et.af.ceb_543  ht.jw.sw_644 ms.so.un_220
  // [6360]
  0x0103060d, 0x20005302, 0x532103a4, 0x18352712,   // de.nl.en_554 ht.sq.un_220  nl.jw.ht_433 gd.zu.ga_654
  0x29000d17, 0x271101a4, 0x10130e5a, 0x1b3132a0,   // cs.sl.un_730 en.ro.gd_433  is.et.lt_553 bs.az.tr_322
  0x11170aec, 0x0f68640e, 0x642b35af, 0x641052a4,   // mk.sr.ro_644 lg.ig.lv_555  zu.vi.lg_655 ha.lt.lg_433
  0x281335a9, 0x28553b55, 0x03645307, 0x3f030912,   // zu.et.sw_544 so.rw.sw_442  ht.lg.nl_432 pl.nl.af_654
  // [6370]
  0x21000302, 0x0b135204, 0x091c13a6, 0x6427180c,   // nl.jw.un_220 ha.et.es_332  bh.mr.hi_521 ga.gd.lg_543
  0x10203b07, 0x2d0d0414, 0x18002302, 0x08200207,   // so.sq.lt_432 fi.cs.sk_666  ca.ga.un_220 da.sq.no_432
  0x20081f04, 0x071310ad, 0x1b312109, 0x1e1c0faf,   // cy.no.sq_332 lt.et.it_643  jw.az.tr_444 lv.id.ms_655
  0x0a231908, 0x6b001818, 0x521a28a9, 0x3b001a0d,   // gl.ca.pt_443 ga.ceb.un_740  sw.tl.ha_544 tl.so.un_540
  // [6380]
  0x32132a5a, 0x35130408, 0x116435a4, 0x07001f13,   // mt.et.bs_553 fi.et.zu_443  zu.lg.ro_433 cy.it.un_650
  0x3b133fa0, 0x55062108, 0x10001723, 0x68003508,   // af.et.so_322 jw.de.rw_443  sr.be.un_880 zu.ig.un_430
  0x35092812, 0x5525680d, 0x685553af, 0x133b520d,   // sw.pl.zu_654 ig.eu.rw_554  ht.rw.ig_655 ha.so.et_554
  0x280535ee, 0x0300021a, 0x02033f05, 0x293564ad,   // zu.fr.sw_422 da.nl.un_760  af.nl.da_333 lg.zu.sl_643
  // [6390]
  0x68551b12, 0x6425350c, 0x130410ec, 0x12000608,   // tr.rw.ig_654 zu.eu.lg_543  lt.fi.et_644 de.hu.un_430
  0x25120fa4, 0x1f000c0e, 0x192003a0, 0x643552a7,   // lv.hu.eu_433 sv.cy.un_550  nl.sq.gl_322 ha.zu.lg_532
  0x2a001f07, 0x680c3508, 0x1b640f11, 0x0f1b28a4,   // cy.mt.un_420 zu.sv.ig_443  lv.lg.tr_653 sw.tr.lv_433
  0x3b00291b, 0x1c211607, 0x132a2908, 0x321620af,   // sl.so.un_770 hr.jw.id_432  sl.mt.et_443 sq.hr.bs_655
  // [63a0]
  0x1a212308, 0x640f280c, 0x06002534, 0x64280f13,   // ca.jw.tl_443 sw.lv.lg_543  eu.de.un_A80 lv.sw.lg_665
  0x28535508, 0x092d0f04, 0x35102513, 0x102d070c,   // rw.ht.sw_443 lv.sk.pl_332  eu.lt.zu_665 it.sk.lt_543
  0x0f2a2011, 0x64533b05, 0x08111005, 0x121b53ee,   // sq.mt.lv_653 so.ht.lg_333  be.ro.uk_333 ht.tr.hu_422
  0x13350612, 0x6408130c, 0x194a64a0, 0x282d0f08,   // de.zu.et_654 et.no.lg_543  lg.yo.gl_322 lv.sk.sw_443
  // [63b0]
  0x2a001114, 0x05230a0d, 0x060208a4, 0x291b17a9,   // ro.mt.un_660 pt.ca.fr_554  no.da.de_433 sr.tr.sl_544
  0x03061312, 0x191323a7, 0x0111050c, 0x210452ad,   // et.de.nl_654 ca.et.gl_532  fr.ro.en_543 ha.fi.jw_643
  0x555325af, 0x03000907, 0x192a0aad, 0x1f000a1a,   // eu.ht.rw_655 pl.nl.un_420  pt.mt.gl_643 pt.cy.un_760
  0x270a4a13, 0x0313120c, 0x211b55a6, 0x171364a4,   // yo.pt.gd_665 hu.et.nl_543  rw.tr.jw_521 lg.et.sr_433
  // [63c0]
  0x5531250c, 0x3b2d5512, 0x2d0953a0, 0x2d00060c,   // eu.az.rw_543 rw.sk.so_654  ht.pl.sk_322 de.sk.un_530
  0x1c0d13ee, 0x553135a4, 0x682752a4, 0x52534a07,   // bh.ne.mr_422 zu.az.rw_433  ha.gd.ig_433 yo.ht.ha_432
  0x2128550c, 0x040a10af, 0x0523070c, 0x21000723,   // rw.sw.jw_543 be.mk.ru_655  it.ca.fr_543 it.jw.un_880
  0x1029680d, 0x35003b2b, 0x190721a0, 0x01003502,   // ig.sl.lt_554 so.zu.un_980  jw.it.gl_322 zu.en.un_220
  // [63d0]
  0x29522105, 0x35002014, 0x29065202, 0x0a122d0d,   // jw.ha.sl_333 sq.zu.un_660  ha.de.sl_222 sk.hu.pt_554
  0x044a21ee, 0x31251311, 0x254a1a12, 0x08002b04,   // jw.yo.fi_422 et.eu.az_653  tl.yo.eu_654 vi.no.un_320
  0x6b1a3ba4, 0x0b102807, 0x13120408, 0x0d292d11,   // so.tl.ceb_433 sw.lt.es_432  fi.hu.et_443 sk.sl.cs_653
  0x04000905, 0x6400130d, 0x3f0c1f14, 0x07003108,   // pl.fi.un_330 et.lg.un_540  cy.sv.af_666 az.it.un_430
  // [63e0]
  0x55002d04, 0x1b0513ee, 0x051b5311, 0x291b0f55,   // sk.rw.un_320 et.fr.tr_422  ht.tr.fr_653 lv.tr.sl_442
  0x0d1652ee, 0x29006e08, 0x07000418, 0x0b0929ee,   // ha.hr.cs_422 hmn.sl.un_430  ru.bg.un_740 sl.pl.es_422
  0x251b07ad, 0x050755a7, 0x6e036b04, 0x022d290e,   // it.tr.eu_643 rw.it.fr_532  ceb.nl.hmn_332 sl.sk.da_555
  0x016b64a0, 0x283210a9, 0x08000304, 0x014a1307,   // lg.ceb.en_322 lt.bs.sw_544  nl.no.un_320 et.yo.en_432
  // [63f0]
  0x6b521c0b, 0x133255ee, 0x063552a0, 0x29190a0d,   // id.ha.ceb_542 rw.bs.et_422  ha.zu.de_322 pt.gl.sl_554
  0x01281307, 0x1a1c0c0d, 0x02200602, 0x52554a08,   // et.sw.en_432 sv.id.tl_554  de.sq.da_222 yo.rw.ha_443
  0x080212ec, 0x03001e0d, 0x211268a9, 0x043f1a08,   // hu.da.no_644 ms.nl.un_540  ig.hu.jw_544 tl.af.fi_443
  0x320816a4, 0x55534a07, 0x640802ad, 0x0b0a11ac,   // hr.no.bs_433 yo.ht.rw_432  da.no.lg_643 ro.pt.es_632

  // [6400]
  0x0c1c53ad, 0x1e1c1aec, 0x1a206ea0, 0x13002017,   // ht.id.sv_643 tl.id.ms_644  hmn.sq.tl_322 sq.et.un_730
  0x68130204, 0x3f00550c, 0x1b002013, 0x0c270607,   // da.et.ig_332 rw.af.un_530  sq.tr.un_650 de.gd.sv_432
  0x32162909, 0x0c02120c, 0x27061ead, 0x0c100f0c,   // sl.hr.bs_444 hu.da.sv_543  ms.de.gd_643 lv.lt.sv_543
  0x23061f12, 0x082a02a0, 0x0c051304, 0x5304130c,   // cy.de.ca_654 da.mt.no_322  et.fr.sv_332 et.fi.ht_543
  // [6410]
  0x03020c0d, 0x35002302, 0x641e1c12, 0x230b3ba4,   // sv.da.nl_554 ca.zu.un_220  id.ms.lg_654 so.es.ca_433
  0x0c6b08a0, 0x01030602, 0x2a001804, 0x0c3f2907,   // no.ceb.sv_322 de.nl.en_222  ga.mt.un_320 sl.af.sv_432
  0x0c520608, 0x18002d18, 0x251b0ba0, 0x531a520c,   // de.ha.sv_443 sk.ga.un_740  es.tr.eu_322 ha.tl.ht_543
  0x0a1708ec, 0x55521bad, 0x5264550c, 0x5300211a,   // uk.sr.mk_644 tr.ha.rw_643  rw.lg.ha_543 jw.ht.un_760
  // [6420]
  0x18230713, 0x53006422, 0x0b354aad, 0x6b1a1213,   // it.ca.ga_665 lg.ht.un_870  yo.zu.es_643 hu.tl.ceb_665
  0x2505190c, 0x6b0e125a, 0x09102504, 0x1b2864a0,   // gl.fr.eu_543 hu.is.ceb_553  eu.lt.pl_332 lg.sw.tr_322
  0x161304a4, 0x0f0310ec, 0x31002102, 0x256b3b09,   // fi.et.hr_433 lt.nl.lv_644  jw.az.un_220 so.ceb.eu_444
  0x253b1308, 0x3f0c25a4, 0x6b3153af, 0x3f531e08,   // et.so.eu_443 eu.sv.af_433  ht.az.ceb_655 ms.ht.af_443
  // [6430]
  0x053b11a4, 0x072504a4, 0x120a07a9, 0x033b3fac,   // ro.so.fr_433 fi.eu.it_433  it.pt.hu_544 af.so.nl_632
  0x033f3b60, 0x3b1e1308, 0x1a080208, 0x35254aa4,   // so.af.nl_664 et.ms.so_443  da.no.tl_443 yo.eu.zu_433
  0x03013b07, 0x280a2104, 0x20000609, 0x216b06ad,   // so.en.nl_432 jw.pt.sw_332  de.sq.un_440 de.ceb.jw_643
  0x3b520107, 0x0a033f14, 0x35002102, 0x080a10ec,   // en.ha.so_432 af.nl.pt_666  jw.zu.un_220 be.mk.uk_644
  // [6440]
  0x1c002a13, 0x190b04a9, 0x052723a4, 0x031f27ad,   // mt.id.un_650 fi.es.gl_544  ca.gd.fr_433 gd.cy.nl_643
  0x27000621, 0x272311af, 0x07081011, 0x1a321c07,   // de.gd.un_860 ro.ca.gd_655  be.uk.bg_653 id.bs.tl_432
  0x6b201a0b, 0x282555ad, 0x5517040c, 0x02001a07,   // tl.sq.ceb_542 rw.eu.sw_643  fi.sr.rw_543 tl.da.un_420
  0x641b55ee, 0x05072004, 0x03113f60, 0x53091113,   // rw.tr.lg_422 sq.it.fr_332  af.ro.nl_664 ro.pl.ht_665
  // [6450]
  0x280c1060, 0x271f2308, 0x0600230d, 0x6813280c,   // lt.sv.sw_664 ca.cy.gd_443  ca.de.un_540 sw.et.ig_543
  0x10006414, 0x17531baf, 0x16000c0b, 0x53001222,   // lg.lt.un_660 tr.ht.sr_655  sv.hr.un_520 hu.ht.un_870
  0x25005204, 0x040107a4, 0x19050a07, 0x3b002107,   // ha.eu.un_320 it.en.fi_433  pt.fr.gl_432 jw.so.un_420
  0x2307680c, 0x1b0e1307, 0x100a20a9, 0x051a20ee,   // ig.it.ca_543 et.is.tr_432  sq.pt.lt_544 sq.tl.fr_422
  // [6460]
  0x2a100504, 0x641b1307, 0x1e4a1ca4, 0x3b005221,   // fr.lt.mt_332 et.tr.lg_432  id.yo.ms_433 ha.so.un_860
  0x03000702, 0x3528170c, 0x08525312, 0x53001e1a,   // it.nl.un_220 sr.sw.zu_543  ht.ha.no_654 ms.ht.un_760
  0x252d29a0, 0x06100f0d, 0x09002302, 0x53001113,   // sl.sk.eu_322 lv.lt.de_554  ca.pl.un_220 ro.ht.un_650
  0x3f030fa4, 0x1c002709, 0x521e050c, 0x0727110c,   // lv.nl.af_433 gd.id.un_440  fr.ms.ha_543 ro.gd.it_543
  // [6470]
  0x250210ac, 0x0c130fa4, 0x27002b04, 0x27283b08,   // lt.da.eu_632 lv.et.sv_433  vi.gd.un_320 so.sw.gd_443
  0x523b2508, 0x1c005302, 0x68001e0d, 0x016b21a0,   // eu.so.ha_443 ht.id.un_220  ms.ig.un_540 jw.ceb.en_322
  0x23000b09, 0x31006812, 0x11040aa4, 0x3b311ea9,   // es.ca.un_440 ig.az.un_640  mk.ru.ro_433 ms.az.so_544
  0x20001902, 0x53523b0c, 0x55523bec, 0x552752a9,   // gl.sq.un_220 so.ha.ht_543  so.ha.rw_644 ha.gd.rw_544
  // [6480]
  0x311a52ec, 0x353b1a0c, 0x3b004a02, 0x32001b08,   // ha.tl.az_644 tl.so.zu_543  yo.so.un_220 tr.bs.un_430
  0x213b520c, 0x35645212, 0x07001e04, 0x1b1a3ba9,   // ha.so.jw_543 ha.lg.zu_654  ms.it.un_320 so.tl.tr_544
  0x3531520c, 0x28002114, 0x272118af, 0x356431a7,   // ha.az.zu_543 jw.sw.un_660  ga.jw.gd_655 az.lg.zu_532
  0x0f10270e, 0x351a28af, 0x0b0f1008, 0x060c020e,   // gd.lt.lv_555 sw.tl.zu_655  lt.lv.es_443 da.sv.de_555
  // [6490]
  0x112b28a4, 0x0c1601a4, 0x21313ba4, 0x523b31a9,   // sw.vi.ro_433 en.hr.sv_433  so.az.jw_433 az.so.ha_544
  0x182927ee, 0x31645509, 0x2d0d1aa4, 0x55002113,   // gd.sl.ga_422 rw.lg.az_444  tl.cs.sk_433 jw.rw.un_650
  0x1b1a210c, 0x010504ad, 0x6b5552ec, 0x1a3531ec,   // jw.tl.tr_543 fi.fr.en_643  ha.rw.ceb_644 az.zu.tl_644
  0x64682812, 0x0d020c12, 0x0b0710af, 0x0b1f6b11,   // sw.ig.lg_654 sv.da.cs_654  lt.it.es_655 ceb.cy.es_653
  // [64a0]
  0x32172da4, 0x08060207, 0x1208025a, 0x211b6ea0,   // sk.sr.bs_433 da.de.no_432  da.no.hu_553 hmn.tr.jw_322
  0x063f0aee, 0x19000704, 0x2d0d3205, 0x25193107,   // pt.af.de_422 it.gl.un_320  bs.cs.sk_333 az.gl.eu_432
  0x0d1710a4, 0x0c001a07, 0x55043b0c, 0x0a3204a4,   // lt.sr.cs_433 tl.sv.un_420  so.fi.rw_543 fi.bs.pt_433
  0x1b0a1a07, 0x0c000a02, 0x2700050d, 0x1c002d04,   // tl.pt.tr_432 pt.sv.un_220  fr.gd.un_540 sk.id.un_320
  // [64b0]
  0x0f120a08, 0x13090d55, 0x12553504, 0x1f55520c,   // pt.hu.lv_443 ne.hi.bh_442  zu.rw.hu_332 ha.rw.cy_543
  0x18003518, 0x173f010c, 0x11172911, 0x35001822,   // zu.ga.un_740 en.af.sr_543  sl.sr.ro_653 ga.zu.un_870
  0x013527a0, 0x103b5507, 0x0f3b3511, 0x130f6b0c,   // gd.zu.en_322 rw.so.lt_432  zu.so.lv_653 ceb.lv.et_543
  0x1c130d04, 0x080612a4, 0x3b004a19, 0x101113a0,   // ne.bh.mr_332 hu.de.no_433  yo.so.un_750 et.ro.lt_322
  // [64c0]
  0x1101070c, 0x2806520c, 0x3553050c, 0x04120f55,   // it.en.ro_543 ha.de.sw_543  fr.ht.zu_543 lv.hu.fi_442
  0x120c1304, 0x0e0713a7, 0x20231304, 0x10072512,   // et.sv.hu_332 et.it.is_532  et.ca.sq_332 eu.it.lt_654
  0x200523a9, 0x0c082aad, 0x0f0523a4, 0x041b270b,   // ca.fr.sq_544 mt.no.sv_643  ca.fr.lv_433 gd.tr.fi_542
  0x0e0429ac, 0x20002807, 0x1a001c02, 0x3b526460,   // sl.fi.is_632 sw.sq.un_420  id.tl.un_220 lg.ha.so_664
  // [64d0]
  0x29355212, 0x1c036b02, 0x3f6b1a12, 0x1f016804,   // ha.zu.sl_654 ceb.nl.id_222  tl.ceb.af_654 ig.en.cy_332
  0x21002a02, 0x25130108, 0x2d0f29a4, 0x0a001920,   // mt.jw.un_220 en.et.eu_443  sl.lv.sk_433 gl.pt.un_850
  0x0b000a1e, 0x0e12080c, 0x29200fee, 0x11006818,   // pt.es.un_830 no.hu.is_543  lv.sq.sl_422 ig.ro.un_740
  0x13090d0d, 0x10042307, 0x25006e04, 0x0c080412,   // ne.hi.bh_554 ca.fi.lt_432  hmn.eu.un_320 fi.no.sv_654
  // [64e0]
  0x0e041bad, 0x08040212, 0x68000d13, 0x2d002514,   // tr.fi.is_643 da.fi.no_654  cs.ig.un_650 eu.sk.un_660
  0x6b2d550c, 0x033f080c, 0x0502010c, 0x16001104,   // rw.sk.ceb_543 no.af.nl_543  en.da.fr_543 ro.hr.un_320
  0x536b2807, 0x111923ee, 0x016e02ee, 0x0e124aa9,   // sw.ceb.ht_432 ca.gl.ro_422  da.hmn.en_422 yo.hu.is_544
  0x2a00041b, 0x522d3fa0, 0x1208350c, 0x080220af,   // fi.mt.un_770 af.sk.ha_322  zu.no.hu_543 sq.da.no_655
  // [64f0]
  0x552d0d0d, 0x2a686b07, 0x102528a4, 0x2d00041a,   // cs.sk.rw_554 ceb.ig.mt_432  sw.eu.lt_433 fi.sk.un_760
  0x042d5504, 0x32006e07, 0x2b00250e, 0x1a6b55a9,   // rw.sk.fi_332 hmn.bs.un_420  eu.vi.un_550 rw.ceb.tl_544
  0x1000070e, 0x13321708, 0x3b353112, 0x20071aa0,   // it.lt.un_550 sr.bs.et_443  az.zu.so_654 tl.it.sq_322
  0x0b0523a4, 0x013b2707, 0x5500680e, 0x25531f05,   // ca.fr.es_433 gd.so.en_432  ig.rw.un_550 cy.ht.eu_333
  // [6500]
  0x3b001902, 0x052868ee, 0x0f181ea9, 0x356820a4,   // gl.so.un_220 ig.sw.fr_422  ms.ga.lv_544 sq.ig.zu_433
  0x32003f08, 0x190a050c, 0x130553ad, 0x10282507,   // af.bs.un_430 fr.pt.gl_543  ht.fr.et_643 eu.sw.lt_432
  0x0b0a25a4, 0x28102508, 0x01646b02, 0x16120dee,   // eu.pt.es_433 eu.lt.sw_443  ceb.lg.en_222 cs.hu.hr_422
  0x1e0c1c0c, 0x052a0408, 0x322a160c, 0x3f0704a4,   // id.sv.ms_543 fi.mt.fr_443  hr.mt.bs_543 fi.it.af_433
  // [6510]
  0x04070505, 0x04003112, 0x080b060c, 0x12061b07,   // fr.it.fi_333 az.fi.un_640  de.es.no_543 tr.de.hu_432
  0x072a0a0c, 0x3f250b0d, 0x285535a4, 0x1008250c,   // pt.mt.it_543 es.eu.af_554  zu.rw.sw_433 eu.no.lt_543
  0x132704a7, 0x1a3525a4, 0x64551fa4, 0x0c0e20a7,   // fi.gd.et_532 eu.zu.tl_433  cy.rw.lg_433 sq.is.sv_532
  0x6b551a0e, 0x083f0305, 0x5355640c, 0x08280207,   // tl.rw.ceb_555 nl.af.no_333  lg.rw.ht_543 da.sw.no_432
  // [6520]
  0x03062a08, 0x1017290c, 0x050704a4, 0x0410350c,   // mt.de.nl_443 sl.sr.lt_543  fi.it.fr_433 zu.lt.fi_543
  0x290a350c, 0x0305040c, 0x2d19350b, 0x012027ee,   // zu.pt.sl_543 fi.fr.nl_543  zu.gl.sk_542 gd.sq.en_422
  0x082a0455, 0x52006e2a, 0x0c002102, 0x04554a0d,   // fi.mt.no_442 hmn.ha.un_970  jw.sv.un_220 yo.rw.fi_554
  0x1c291e04, 0x1c001a07, 0x20231f0d, 0x55121ea4,   // ms.sl.id_332 tl.id.un_420  cy.ca.sq_554 ms.hu.rw_433
  // [6530]
  0x21070da4, 0x081220a6, 0x19230b13, 0x043b1e08,   // cs.it.jw_433 sq.hu.no_521  es.ca.gl_665 ms.so.fi_443
  0x35124aee, 0x1e001704, 0x271128af, 0x12000c0b,   // yo.hu.zu_422 sr.ms.un_320  sw.ro.gd_655 sv.hu.un_520
  0x1c1e3b04, 0x011f09a7, 0x093528a4, 0x1f00060e,   // so.ms.id_332 pl.cy.en_532  sw.zu.pl_433 de.cy.un_550
  0x29000108, 0x3f002102, 0x6b000709, 0x313519ad,   // en.sl.un_430 jw.af.un_220  it.ceb.un_440 gl.zu.az_643
  // [6540]
  0x280e35a4, 0x04133ba7, 0x0c2a200d, 0x10001f0e,   // zu.is.sw_433 so.et.fi_532  sq.mt.sv_554 cy.lt.un_550
  0x01130a05, 0x25102805, 0x09001213, 0x060c08ad,   // pt.et.en_333 sw.lt.eu_333  hu.pl.un_650 no.sv.de_643
  0x073f01a4, 0x190b01a0, 0x10002704, 0x033f3512,   // en.af.it_433 en.es.gl_322  gd.lt.un_320 zu.af.nl_654
  0x1e1c0dee, 0x1a0f10a4, 0x190a0faf, 0x02006b07,   // cs.id.ms_422 lt.lv.tl_433  lv.pt.gl_655 ceb.da.un_420
  // [6550]
  0x130f0ba4, 0x6b68350c, 0x2a0703a4, 0x0f210bee,   // es.lv.et_433 zu.ig.ceb_543  nl.it.mt_433 es.jw.lv_422
  0x2a000504, 0x28002505, 0x01000513, 0x523b21ec,   // fr.mt.un_320 eu.sw.un_330  fr.en.un_650 jw.so.ha_644
  0x2d3b0d07, 0x2d0d080c, 0x2d4a120c, 0x10113ba4,   // cs.so.sk_432 no.cs.sk_543  hu.yo.sk_543 so.ro.lt_433
  0x191c0ba0, 0x1f103b08, 0x0e006b12, 0x356864a4,   // es.id.gl_322 so.lt.cy_443  ceb.is.un_640 lg.ig.zu_433
  // [6560]
  0x07193b05, 0x0b076b07, 0x0727180c, 0x282d2905,   // so.gl.it_333 ceb.it.es_432  ga.gd.it_543 sl.sk.sw_333
  0x4a3b52ec, 0x1f2012af, 0x1e000808, 0x10135208,   // ha.so.yo_644 hu.sq.cy_655  no.ms.un_430 ha.et.lt_443
  0x071a4aa0, 0x0b003204, 0x0a063fad, 0x1f00521a,   // yo.tl.it_322 bs.es.un_320  af.de.pt_643 ha.cy.un_760
  0x35010407, 0x20182905, 0x202d55a0, 0x080d02ee,   // fi.en.zu_432 sl.ga.sq_333  rw.sk.sq_322 da.cs.no_422
  // [6570]
  0x0d00350e, 0x06002702, 0x1b0f1304, 0x11000c04,   // zu.cs.un_550 gd.de.un_220  et.lv.tr_332 sv.ro.un_320
  0x1f000d18, 0x2305080c, 0x1b131007, 0x081710ec,   // cs.cy.un_740 no.fr.ca_543  lt.et.tr_432 be.sr.uk_644
  0x19050b12, 0x19530a08, 0x13003f13, 0x352d0d08,   // es.fr.gl_654 pt.ht.gl_443  af.et.un_650 cs.sk.zu_443
  0x3f031055, 0x210c2aa7, 0x23001013, 0x3f032760,   // lt.nl.af_442 mt.sv.jw_532  lt.ca.un_650 gd.nl.af_664
  // [6580]
  0x10003f19, 0x10000312, 0x1b6e10a4, 0x1c4a1ea0,   // af.lt.un_750 nl.lt.un_640  lt.hmn.tr_433 ms.yo.id_322
  0x1a2d21a0, 0x290f18ad, 0x32311705, 0x11531ba0,   // jw.sk.tl_322 ga.lv.sl_643  sr.az.bs_333 tr.ht.ro_322
  0x55211009, 0x122a3505, 0x27000a04, 0x2d0d0f0c,   // lt.jw.rw_444 zu.mt.hu_333  pt.gd.un_320 lv.cs.sk_543
  0x55046bad, 0x170f10a4, 0x52200fa4, 0x12210408,   // ceb.fi.rw_643 lt.lv.sr_433  lv.sq.ha_433 fi.jw.hu_443
  // [6590]
  0x1a3f0305, 0x10030ead, 0x29040ea4, 0x18001b0e,   // nl.af.tl_333 is.nl.lt_643  is.fi.sl_433 tr.ga.un_550
  0x0c2b27ad, 0x6b0f21a9, 0x3f000223, 0x52202707,   // gd.vi.sv_643 jw.lv.ceb_544  da.af.un_880 gd.sq.ha_432
  0x033f1812, 0x1c1f1e12, 0x6e271809, 0x1106070c,   // ga.af.nl_654 ms.cy.id_654  ga.gd.hmn_444 it.de.ro_543
  0x0412280c, 0x3f110304, 0x162528a6, 0x122821a4,   // sw.hu.fi_543 nl.ro.af_332  sw.eu.hr_521 jw.sw.hu_433
  // [65a0]
  0x4a0e6805, 0x3f020608, 0x4a20280c, 0x1c201e12,   // ig.is.yo_333 de.da.af_443  sw.sq.yo_543 ms.sq.id_654
  0x27040512, 0x0d001321, 0x05010408, 0x0a003502,   // fr.fi.gd_654 bh.ne.un_860  fi.en.fr_443 zu.pt.un_220
  0x170f1a08, 0x18090555, 0x0c0806af, 0x19040508,   // tl.lv.sr_443 fr.pl.ga_442  de.no.sv_655 fr.fi.gl_443
  0x1f190b05, 0x080711af, 0x0b0a19a6, 0x10090ead,   // es.gl.cy_333 ro.bg.uk_655  gl.pt.es_521 is.pl.lt_643
  // [65b0]
  0x2d12290c, 0x0c0406a7, 0x0d093f0e, 0x06180308,   // sl.hu.sk_543 de.fi.sv_532  af.pl.cs_555 nl.ga.de_443
  0x25285512, 0x28190a08, 0x16072aa7, 0x0f1001a4,   // rw.sw.eu_654 pt.gl.sw_443  mt.it.hr_532 en.lt.lv_433
  0x0a1129a0, 0x25000714, 0x081023af, 0x08230f08,   // sl.ro.pt_322 it.eu.un_660  ca.lt.no_655 lv.ca.no_443
  0x290821a6, 0x1f2a3ba4, 0x21002802, 0x1610020c,   // jw.no.sl_521 so.mt.cy_433  sw.jw.un_220 da.lt.hr_543
  // [65c0]
  0x29002d02, 0x11103107, 0x190a52ee, 0x100f040c,   // sk.sl.un_220 az.lt.ro_432  ha.pt.gl_422 fi.lv.lt_543
  0x20273fa0, 0x0f292da4, 0x286b5304, 0x2d0d2505,   // af.gd.sq_322 sk.sl.lv_433  ht.ceb.sw_332 eu.cs.sk_333
  0x1a0b6b13, 0x180b1fa0, 0x23256407, 0x52201fa4,   // ceb.es.tl_665 cy.es.ga_322  lg.eu.ca_432 cy.sq.ha_433
  0x29001723, 0x1c13090b, 0x1712200c, 0x535204ad,   // sr.sl.un_880 hi.bh.mr_542  sq.hu.sr_543 fi.ha.ht_643
  // [65d0]
  0x12190aad, 0x31033f0c, 0x2d0d1209, 0x110755a4,   // pt.gl.hu_643 af.nl.az_543  hu.cs.sk_444 rw.it.ro_433
  0x12000307, 0x556401a4, 0x25030f55, 0x131f03ad,   // nl.hu.un_420 en.lg.rw_433  lv.nl.eu_442 nl.cy.et_643
  0x0a003f04, 0x4a3564af, 0x080c13a4, 0x35030a02,   // af.pt.un_320 lg.zu.yo_655  et.sv.no_433 pt.nl.zu_222
  0x02003f07, 0x1f011ca4, 0x3f000c0b, 0x202503ad,   // af.da.un_420 id.en.cy_433  sv.af.un_520 nl.eu.sq_643
  // [65e0]
  0x2517290c, 0x2d1e2304, 0x551a68ec, 0x2b322dad,   // sl.sr.eu_543 ca.ms.sk_332  ig.tl.rw_644 sk.bs.vi_643
  0x05351102, 0x21000204, 0x35295512, 0x1b04130c,   // ro.zu.fr_222 da.jw.un_320  rw.sl.zu_654 et.fi.tr_543
  0x27060211, 0x682855ad, 0x0b2318a4, 0x1e071c07,   // da.de.gd_653 rw.sw.ig_643  ga.ca.es_433 id.it.ms_432
  0x07000502, 0x2a005302, 0x1e1b1aaf, 0x2d1c0804,   // fr.it.un_220 ht.mt.un_220  tl.tr.ms_655 no.id.sk_332
  // [65f0]
  0x3220170c, 0x021b1fa7, 0x2a004a0d, 0x32172905,   // sr.sq.bs_543 cy.tr.da_532  yo.mt.un_540 sl.sr.bs_333
  0x0728350d, 0x070b23a4, 0x0f090304, 0x321631a0,   // zu.sw.it_554 ca.es.it_433  nl.pl.lv_332 az.hr.bs_322
  0x09681107, 0x210c1a04, 0x276b06ee, 0x0c006805,   // ro.ig.pl_432 tl.sv.jw_332  de.ceb.gd_422 ig.sv.un_330
  0x31121bec, 0x12111304, 0x01523f04, 0x320512ee,   // tr.hu.az_644 et.ro.hu_332  af.ha.en_332 hu.fr.bs_422
  // [6600]
  0x091a64ec, 0x1b00640e, 0x3f180107, 0x210e1ca4,   // lg.tl.pl_644 lg.tr.un_550  en.ga.af_432 id.is.jw_433
  0x0f103fac, 0x08270cad, 0x0e003f21, 0x102d29a9,   // af.lt.lv_632 sv.gd.no_643  af.is.un_860 sl.sk.lt_544
  0x0b000a1b, 0x03272a04, 0x172d53a4, 0x1c006e04,   // pt.es.un_770 mt.gd.nl_332  ht.sk.sr_433 hmn.id.un_320
  0x0c002a05, 0x3b000a14, 0x0b070a07, 0x0a3f2a05,   // mt.sv.un_330 pt.so.un_660  pt.it.es_432 mt.af.pt_333
  // [6610]
  0x3500210c, 0x091a6b5a, 0x16000c07, 0x0f000604,   // jw.zu.un_530 ceb.tl.pl_553  sv.hr.un_420 de.lv.un_320
  0x0a1a6eee, 0x29071308, 0x2810130c, 0x52353fa0,   // hmn.tl.pt_422 et.it.sl_443  et.lt.sw_543 af.zu.ha_322
  0x0a291008, 0x1b211ca4, 0x071a6b05, 0x12201ba7,   // lt.sl.pt_443 id.jw.tr_433  ceb.tl.it_333 tr.sq.hu_532
  0x08076b04, 0x28205208, 0x03273f12, 0x273f230c,   // ceb.it.no_332 ha.sq.sw_443  af.gd.nl_654 ca.af.gd_543
  // [6620]
  0x02126bee, 0x190b23a6, 0x6b182711, 0x036b3faf,   // ceb.hu.da_422 ca.es.gl_521  gd.ga.ceb_653 af.ceb.nl_655
  0x100220a4, 0x030c06ee, 0x2d0d25ee, 0x6b003f07,   // sq.da.lt_433 de.sv.nl_422  eu.cs.sk_422 af.ceb.un_420
  0x01006402, 0x1f110508, 0x53352508, 0x07171005,   // lg.en.un_220 fr.ro.cy_443  eu.zu.ht_443 be.sr.bg_333
  0x05011fee, 0x190b2509, 0x070a12a9, 0x020e0c05,   // cy.en.fr_422 eu.es.gl_444  hu.pt.it_544 sv.is.da_333
  // [6630]
  0x132935a0, 0x093516ee, 0x091f25a6, 0x040a1f05,   // zu.sl.et_322 hr.zu.pl_422  eu.cy.pl_521 cy.pt.fi_333
  0x132325af, 0x3f031f09, 0x52281eaf, 0x05092309,   // eu.ca.et_655 cy.nl.af_444  ms.sw.ha_655 ca.pl.fr_444
  0x04003f13, 0x08352312, 0x03002321, 0x311a6b08,   // af.fi.un_650 ca.zu.no_654  ca.nl.un_860 ceb.tl.az_443
  0x25001919, 0x0a0b1960, 0x100701a9, 0x1121010c,   // gl.eu.un_750 gl.es.pt_664  en.it.lt_544 en.jw.ro_543
  // [6640]
  0x0e0925a4, 0x05010807, 0x0d09250c, 0x643509ad,   // eu.pl.is_433 no.en.fr_432  eu.pl.cs_543 pl.zu.lg_643
  0x1100201b, 0x1a042511, 0x080717ec, 0x3f13060b,   // sq.ro.un_770 eu.fi.tl_653  sr.bg.uk_644 de.et.af_542
  0x1c005304, 0x1f040f55, 0x09003509, 0x04641a09,   // ht.id.un_320 lv.fi.cy_442  zu.pl.un_440 tl.lg.fi_444
  0x355209ad, 0x35092802, 0x28641a08, 0x5318010c,   // pl.ha.zu_643 sw.pl.zu_222  tl.lg.sw_443 en.ga.ht_543
  // [6650]
  0x033f06a6, 0x4a0f28ee, 0x21533b04, 0x02000c22,   // de.af.nl_521 sw.lv.yo_422  so.ht.jw_332 sv.da.un_870
  0x28000920, 0x32203509, 0x290d12af, 0x1c000c05,   // pl.sw.un_850 zu.sq.bs_444  hu.cs.sl_655 sv.id.un_330
  0x0f0c130c, 0x03130508, 0x020e08ec, 0x042d0d05,   // et.sv.lv_543 fr.et.nl_443  no.is.da_644 cs.sk.fi_333
  0x1e211c60, 0x1c000c18, 0x6b2864ac, 0x0b1912a9,   // id.jw.ms_664 sv.id.un_740  lg.sw.ceb_632 hu.gl.es_544
  // [6660]
  0x3f06035a, 0x1c0f6eee, 0x07282a13, 0x11000f12,   // nl.de.af_553 hmn.lv.id_422  mt.sw.it_665 lv.ro.un_640
  0x32000f04, 0x0c0603a0, 0x120d2012, 0x1b001604,   // lv.bs.un_320 nl.de.sv_322  sq.cs.hu_654 hr.tr.un_320
  0x3f230512, 0x126425af, 0x290353af, 0x3b000c05,   // fr.ca.af_654 eu.lg.hu_655  ht.nl.sl_655 sv.so.un_330
  0x0a3b13af, 0x171c21a6, 0x556b680d, 0x2d120daf,   // et.so.pt_655 jw.id.sr_521  ig.ceb.rw_554 cs.hu.sk_655
  // [6670]
  0x536428ad, 0x18120bec, 0x68133b12, 0x253f03ad,   // sw.lg.ht_643 es.hu.ga_644  so.et.ig_654 nl.af.eu_643
  0x032d0513, 0x03000502, 0x35092a05, 0x55005204,   // fr.sk.nl_665 fr.nl.un_220  mt.pl.zu_333 ha.rw.un_320
  0x68003f1a, 0x25002002, 0x533f6b02, 0x03270c07,   // af.ig.un_760 sq.eu.un_220  ceb.af.ht_222 sv.gd.nl_432
  0x08171208, 0x23000a2b, 0x212864a0, 0x033f0dee,   // hu.sr.no_443 pt.ca.un_980  lg.sw.jw_322 cs.af.nl_422
  // [6680]
  0x10000907, 0x130823ad, 0x010a19ee, 0x10023f0c,   // pl.lt.un_420 ca.no.et_643  gl.pt.en_422 af.da.lt_543
  0x090316a7, 0x0c05080c, 0x0f060512, 0x1b525508,   // hr.nl.pl_532 no.fr.sv_543  fr.de.lv_654 rw.ha.tr_443
  0x010519ad, 0x091953ec, 0x281125ad, 0x1f0c020c,   // gl.fr.en_643 ht.gl.pl_644  eu.ro.sw_643 da.sv.cy_543
  0x1c006402, 0x21013bee, 0x19110a0c, 0x1800190d,   // lg.id.un_220 so.en.jw_422  pt.ro.gl_543 gl.ga.un_540
  // [6690]
  0x073b040c, 0x0d055311, 0x17290fad, 0x290f2d07,   // fi.so.it_543 ht.fr.cs_653  lv.sl.sr_643 sk.lv.sl_432
  0x291e1c13, 0x3f055312, 0x081f1e07, 0x09641e07,   // id.ms.sl_665 ht.fr.af_654  ms.cy.no_432 ms.lg.pl_432
  0x04005302, 0x32002104, 0x190a0b07, 0x21096407,   // ht.fi.un_220 jw.bs.un_320  es.pt.gl_432 lg.pl.jw_432
  0x1f52640c, 0x5520110c, 0x07160a07, 0x05000d04,   // lg.ha.cy_543 ro.sq.rw_543  pt.hr.it_432 cs.fr.un_320
  // [66a0]
  0x3b521e12, 0x08010bee, 0x033f10ad, 0x06000d04,   // ms.ha.so_654 es.en.no_422  lt.af.nl_643 cs.de.un_320
  0x643b685a, 0x27001308, 0x6b531a09, 0x6b641a05,   // ig.so.lg_553 et.gd.un_430  tl.ht.ceb_444 tl.lg.ceb_333
  0x25066b02, 0x1f3b2aee, 0x025208af, 0x0c2a07a9,   // ceb.de.eu_222 mt.so.cy_422  no.ha.da_655 it.mt.sv_544
  0x0664070c, 0x083f0508, 0x321e1c14, 0x6b1a55af,   // it.lg.de_543 fr.af.no_443  id.ms.bs_666 rw.tl.ceb_655
  // [66b0]
  0x64183fa7, 0x35006e0e, 0x316e1307, 0x321606ec,   // af.ga.lg_532 hmn.zu.un_550  et.hmn.az_432 de.hr.bs_644
  0x31001111, 0x06001805, 0x2d004a05, 0x11000408,   // ro.az.un_630 ga.de.un_330  yo.sk.un_330 ru.ro.un_430
  0x051a6860, 0x06000b05, 0x25036ba0, 0x20042aad,   // ig.tl.fr_664 es.de.un_330  ceb.nl.eu_322 mt.fi.sq_643
  0x21111a0c, 0x190a6eec, 0x0e2d0d1b, 0x52113107,   // tl.ro.jw_543 hmn.pt.gl_644  cs.sk.is_777 az.ro.ha_432
  // [66c0]
  0x0b0a10a6, 0x1b002709, 0x6b101a0b, 0x0e280caf,   // lt.pt.es_521 gd.tr.un_440  tl.lt.ceb_542 sv.sw.is_655
  0x08006e0d, 0x55253b08, 0x1632170c, 0x01282bad,   // hmn.no.un_540 so.eu.rw_443  sr.bs.hr_543 vi.sw.en_643
  0x6b1f0c09, 0x32000804, 0x25042008, 0x53000521,   // sv.cy.ceb_444 no.bs.un_320  sq.fi.eu_443 fr.ht.un_860
  0x0b0a2309, 0x11051fa0, 0x203f1304, 0x2d0d0b02,   // ca.pt.es_444 cy.fr.ro_322  et.af.sq_332 es.cs.sk_222
  // [66d0]
  0x0f082804, 0x08005219, 0x190b0ea4, 0x3f00280c,   // sw.no.lv_332 ha.no.un_750  is.es.gl_433 sw.af.un_530
  0x1f6b2707, 0x11050304, 0x1b001702, 0x3f000e21,   // gd.ceb.cy_432 nl.fr.ro_332  sr.tr.un_220 is.af.un_860
  0x556b2812, 0x10005220, 0x3f001f14, 0x1200290d,   // sw.ceb.rw_654 ha.lt.un_850  cy.af.un_660 sl.hu.un_540
  0x05040f0c, 0x25001212, 0x05001b14, 0x0d1c13a0,   // lv.fi.fr_543 hu.eu.un_640  tr.fr.un_660 bh.mr.ne_322
  // [66e0]
  0x05000829, 0x3f000f23, 0x10006e1a, 0x013f23af,   // no.fr.un_960 lv.af.un_880  hmn.lt.un_760 ca.af.en_655
  0x68001c22, 0x3f012a05, 0x526b1a0c, 0x120b0a04,   // id.ig.un_870 mt.en.af_333  tl.ceb.ha_543 pt.es.hu_332
  0x520e1a5a, 0x23075308, 0x0164180c, 0x0f030108,   // tl.is.ha_553 ht.it.ca_443  ga.lg.en_543 en.nl.lv_443
  0x532852ad, 0x030f0111, 0x282568af, 0x0f003f23,   // ha.sw.ht_643 en.lv.nl_653  ig.eu.sw_655 af.lv.un_880
  // [66f0]
  0x28133bec, 0x060c0860, 0x103528a9, 0x1e1c52af,   // so.et.sw_644 no.sv.de_664  sw.zu.lt_544 ha.id.ms_655
  0x2d210da4, 0x1b000e04, 0x08020f07, 0x09520ea9,   // cs.jw.sk_433 is.tr.un_320  lv.da.no_432 is.ha.pl_544
  0x1005280d, 0x13042508, 0x1f0802ee, 0x180413a9,   // sw.fr.lt_554 eu.fi.et_443  da.no.cy_422 et.fi.ga_544
  0x092155af, 0x28100508, 0x080c2aec, 0x0c000820,   // rw.jw.pl_655 fr.lt.sw_443  mt.sv.no_644 no.sv.un_850
  // [6700]
  0x0b070112, 0x08520e05, 0x52100fa4, 0x64683bec,   // en.it.es_654 is.ha.no_333  lv.lt.ha_433 so.ig.lg_644
  0x0b0a0eee, 0x17072055, 0x180727a0, 0x110e0f04,   // is.pt.es_422 sq.it.sr_442  gd.it.ga_322 lv.is.ro_332
  0x1e001a0c, 0x2a0807a9, 0x04050fa9, 0x683b6412,   // tl.ms.un_530 it.no.mt_544  lv.fr.fi_544 lg.so.ig_654
  0x35215212, 0x3b071e02, 0x2d0d23ec, 0x190510ad,   // ha.jw.zu_654 ms.it.so_222  ca.cs.sk_644 lt.fr.gl_643
  // [6710]
  0x3b006402, 0x271018a9, 0x0b000208, 0x0f080e08,   // lg.so.un_220 ga.lt.gd_544  da.es.un_430 is.no.lv_443
  0x0a6b010c, 0x6404050c, 0x0c065213, 0x55640b07,   // en.ceb.pt_543 fr.fi.lg_543  ha.de.sv_665 es.lg.rw_432
  0x6b4a550c, 0x11200d07, 0x02183b55, 0x350b0304,   // rw.yo.ceb_543 cs.sq.ro_432  so.ga.da_442 nl.es.zu_332
  0x280903a4, 0x3b090407, 0x6453550d, 0x521a1b0c,   // nl.pl.sw_433 fi.pl.so_432  rw.ht.lg_554 tr.tl.ha_543
  // [6720]
  0x321608af, 0x19003102, 0x17100aa4, 0x186e27a7,   // no.hr.bs_655 az.gl.un_220  mk.be.sr_433 gd.hmn.ga_532
  0x083b1b0d, 0x190b27a4, 0x13005204, 0x216468a0,   // tr.so.no_554 gd.es.gl_433  ha.et.un_320 ig.lg.jw_322
  0x18001e04, 0x0f041aa0, 0x062a070c, 0x27180605,   // ms.ga.un_320 tl.fi.lv_322  it.mt.de_543 de.ga.gd_333
  0x2d0d68a4, 0x0f000a08, 0x183b5213, 0x3b27250c,   // ig.cs.sk_433 pt.lv.un_430  ha.so.ga_665 eu.gd.so_543
  // [6730]
  0x21111aa4, 0x2a1b6ba4, 0x281a1b0c, 0x1b352808,   // tl.ro.jw_433 ceb.tr.mt_433  tr.tl.sw_543 sw.zu.tr_443
  0x100b2804, 0x18000313, 0x08231c0b, 0x1331110c,   // sw.es.lt_332 nl.ga.un_650  id.ca.no_542 ro.az.et_543
  0x1c641ea0, 0x082501a4, 0x1213520c, 0x05005504,   // ms.lg.id_322 en.eu.no_433  ha.et.hu_543 rw.fr.un_320
  0x1f05040c, 0x641135a4, 0x18210fa4, 0x0d1613ad,   // fi.fr.cy_543 zu.ro.lg_433  lv.jw.ga_433 et.hr.cs_643
  // [6740]
  0x1029350c, 0x322935a4, 0x17286b08, 0x11311ba4,   // zu.sl.lt_543 zu.sl.bs_433  ceb.sw.sr_443 tr.az.ro_433
  0x04111a02, 0x1b311208, 0x096435a6, 0x212a290c,   // tl.ro.fi_222 hu.az.tr_443  zu.lg.pl_521 sl.mt.jw_543
  0x16002107, 0x10130f08, 0x16006408, 0x1c2a1ea0,   // jw.hr.un_420 lv.et.lt_443  lg.hr.un_430 ms.mt.id_322
  0x1017040c, 0x190f0bad, 0x270a110c, 0x201b060c,   // ru.sr.be_543 es.lv.gl_643  ro.pt.gd_543 de.tr.sq_543
  // [6750]
  0x2800041b, 0x190b23ac, 0x030c2013, 0x131827a9,   // fi.sw.un_770 ca.es.gl_632  sq.sv.nl_665 gd.ga.et_544
  0x20000e12, 0x04032704, 0x030806ee, 0x041c25a9,   // is.sq.un_640 gd.nl.fi_332  de.no.nl_422 eu.id.fi_544
  0x103f04a7, 0x3f1f1008, 0x0a002104, 0x133b3f11,   // fi.af.lt_532 lt.cy.af_443  jw.pt.un_320 af.so.et_653
  0x0e001812, 0x23072007, 0x2503060e, 0x3f5310a4,   // ga.is.un_640 sq.it.ca_432  de.nl.eu_555 lt.ht.af_433
  // [6760]
  0x0d000f12, 0x180427a7, 0x273f03af, 0x0a2311af,   // lv.cs.un_640 gd.fi.ga_532  nl.af.gd_655 ro.ca.pt_655
  0x1e003b12, 0x35096407, 0x233b195a, 0x64001602,   // so.ms.un_640 lg.pl.zu_432  gl.so.ca_553 hr.lg.un_220
  0x3f032704, 0x2900160d, 0x0a1c28a4, 0x3f001f2a,   // gd.nl.af_332 hr.sl.un_540  sw.id.pt_433 cy.af.un_970
  0x1f3f100c, 0x011f10ee, 0x072320a4, 0x211e1a08,   // lt.af.cy_543 lt.cy.en_422  sq.ca.it_433 tl.ms.jw_443
  // [6770]
  0x1a4a2813, 0x32006b04, 0x3f002307, 0x2d18270d,   // sw.yo.tl_665 ceb.bs.un_320  ca.af.un_420 gd.ga.sk_554
  0x10116ea6, 0x0e2a0b08, 0x0e00120b, 0x4a003113,   // hmn.ro.lt_521 es.mt.is_443  hu.is.un_520 az.yo.un_650
  0x10072d12, 0x270b18af, 0x18136b05, 0x1900281a,   // sk.it.lt_654 ga.es.gd_655  ceb.et.ga_333 sw.gl.un_760
  0x6b111a05, 0x0f1310ec, 0x08001913, 0x05002a02,   // tl.ro.ceb_333 lt.et.lv_644  gl.no.un_650 mt.fr.un_220
  // [6780]
  0x27003b0c, 0x64133508, 0x0b0a5202, 0x21001604,   // so.gd.un_530 zu.et.lg_443  ha.pt.es_222 hr.jw.un_320
  0x1a006e0d, 0x120a050c, 0x5200050d, 0x0b3b35a7,   // hmn.tl.un_540 fr.pt.hu_543  fr.ha.un_540 zu.so.es_532
  0x3229080b, 0x100f0c09, 0x3b521c07, 0x4a0b0a14,   // no.sl.bs_542 sv.lv.lt_444  id.ha.so_432 pt.es.yo_666
  0x17523b08, 0x3b0403a9, 0x3b215505, 0x2b006b02,   // so.ha.sr_443 nl.fi.so_544  rw.jw.so_333 ceb.vi.un_220
  // [6790]
  0x0e101307, 0x043f1f55, 0x6b1c0408, 0x2a5564a4,   // et.lt.is_432 cy.af.fi_442  fi.id.ceb_443 lg.rw.mt_433
  0x0405310c, 0x312a6b04, 0x31201f07, 0x2909320d,   // az.fr.fi_543 ceb.mt.az_332  cy.sq.az_432 bs.pl.sl_554
  0x3b6413a4, 0x04136413, 0x315220a7, 0x033f1fa4,   // et.lg.so_433 lg.et.fi_665  sq.ha.az_532 cy.af.nl_433
  0x3f061fa4, 0x07021007, 0x3f12105a, 0x2021040c,   // cy.de.af_433 lt.da.it_432  lt.hu.af_553 fi.jw.sq_543
  // [67a0]
  0x640a4aa0, 0x091f2108, 0x5200200c, 0x251120a4,   // yo.pt.lg_322 jw.cy.pl_443  sq.ha.un_530 sq.ro.eu_433
  0x04001218, 0x64011fee, 0x0a5210a4, 0x28203bad,   // hu.fi.un_740 cy.en.lg_422  lt.ha.pt_433 so.sq.sw_643
  0x18000121, 0x25201aa4, 0x28002007, 0x11163211,   // en.ga.un_860 tl.sq.eu_433  sq.sw.un_420 bs.hr.ro_653
  0x1a002722, 0x1c2b2707, 0x1e251c07, 0x182b2709,   // gd.tl.un_870 gd.vi.id_432  id.eu.ms_432 gd.vi.ga_444
  // [67b0]
  0x1c271e07, 0x0f0c21a4, 0x52005304, 0x52556812,   // ms.gd.id_432 jw.sv.lv_433  ht.ha.un_320 ig.rw.ha_654
  0x644a115a, 0x2d000f11, 0x11004a23, 0x1a255512,   // ro.yo.lg_553 lv.sk.un_630  yo.ro.un_880 rw.eu.tl_654
  0x686b280c, 0x1b1821ee, 0x6b1e1aa4, 0x282055a7,   // sw.ceb.ig_543 jw.ga.tr_422  tl.ms.ceb_433 rw.sq.sw_532
  0x1e1c1fee, 0x1e251ca4, 0x0f091212, 0x201b1104,   // cy.id.ms_422 id.eu.ms_433  hu.pl.lv_654 ro.tr.sq_332
  // [67c0]
  0x1a00250d, 0x0f02270c, 0x31001709, 0x1a3b4a14,   // eu.tl.un_540 gd.da.lv_543  sr.az.un_440 yo.so.tl_666
  0x522a1fa7, 0x55111a09, 0x10132014, 0x03000e08,   // cy.mt.ha_532 tl.ro.rw_444  sq.et.lt_666 is.nl.un_430
  0x53003202, 0x17005302, 0x16001704, 0x0d530aee,   // bs.ht.un_220 ht.sr.un_220  sr.hr.un_320 pt.ht.cs_422
  0x53001e02, 0x270618ac, 0x1e1c520e, 0x09005304,   // ms.ht.un_220 ga.de.gd_632  ha.id.ms_555 ht.pl.un_320
  // [67d0]
  0x681a11a4, 0x230225ec, 0x351a3f0c, 0x0e103f07,   // ro.tl.ig_433 eu.da.ca_644  af.tl.zu_543 af.lt.is_432
  0x10000c1a, 0x321752a4, 0x68205505, 0x4a00180d,   // sv.lt.un_760 ha.sr.bs_433  rw.sq.ig_333 ga.yo.un_540
  0x11002921, 0x2d022955, 0x132555a4, 0x1716550c,   // sl.ro.un_860 sl.da.sk_442  rw.eu.et_433 rw.hr.sr_543
  0x6e0f1014, 0x04255205, 0x271f4a60, 0x041a0fa4,   // lt.lv.hmn_666 ha.eu.fi_333  yo.cy.gd_664 lv.tl.fi_433
  // [67e0]
  0x0f2510ad, 0x013f290c, 0x190b23ec, 0x6b0604a4,   // lt.eu.lv_643 sl.af.en_543  ca.es.gl_644 fi.de.ceb_433
  0x29164a0c, 0x04130e08, 0x351a6405, 0x16231f08,   // yo.hr.sl_543 is.et.fi_443  lg.tl.zu_333 cy.ca.hr_443
  0x1c351f04, 0x05321fee, 0x28551e0b, 0x2b352105,   // cy.zu.id_332 cy.bs.fr_422  ms.rw.sw_542 jw.zu.vi_333
  0x3b002721, 0x1f1b1213, 0x1a126b11, 0x1e355505,   // gd.so.un_860 hu.tr.cy_665  ceb.hu.tl_653 rw.zu.ms_333
  // [67f0]
  0x311b6b05, 0x3200530c, 0x270f04a6, 0x52350f08,   // ceb.tr.az_333 ht.bs.un_530  fi.lv.gd_521 lv.zu.ha_443
  0x00000406, 0x2327040c, 0x52213f05, 0x112327a9,   // ru.un.un_400 fi.gd.ca_543  af.jw.ha_333 gd.ca.ro_544
  0x35002021, 0x681c6408, 0x03002a0e, 0x23071fa4,   // sq.zu.un_860 lg.id.ig_443  mt.nl.un_550 cy.it.ca_433
  0x4a006809, 0x0600040e, 0x0c64080b, 0x0b0952ac,   // ig.yo.un_440 fi.de.un_550  no.lg.sv_542 ha.pl.es_632

  // [6800]
  0x070b2808, 0x0955520c, 0x12000521, 0x21524aa9,   // sw.es.it_443 ha.rw.pl_543  fr.hu.un_860 yo.ha.jw_544
  0x28523bad, 0x16002d0c, 0x20002d12, 0x356b01ee,   // so.ha.sw_643 sk.hr.un_530  sk.sq.un_640 en.ceb.zu_422
  0x0f311bec, 0x13113b11, 0x6b0a28a0, 0x160d2955,   // tr.az.lv_644 so.ro.et_653  sw.pt.ceb_322 sl.cs.hr_442
  0x21681aad, 0x32162a14, 0x2d043fad, 0x193f0b11,   // tl.ig.jw_643 mt.hr.bs_666  af.fi.sk_643 es.af.gl_653
  // [6810]
  0x182735ec, 0x21000a04, 0x556b2802, 0x07112112,   // zu.gd.ga_644 pt.jw.un_320  sw.ceb.rw_222 jw.ro.it_654
  0x1b0e520c, 0x021a5507, 0x21205512, 0x080c3faf,   // ha.is.tr_543 rw.tl.da_432  rw.sq.jw_654 af.sv.no_655
  0x6b682707, 0x53200908, 0x09113b0c, 0x05232aad,   // gd.ig.ceb_432 pl.sq.ht_443  so.ro.pl_543 mt.ca.fr_643
  0x093b1112, 0x1b2a5212, 0x083f02a0, 0x0b03060c,   // ro.so.pl_654 ha.mt.tr_654  da.af.no_322 de.nl.es_543
  // [6820]
  0x1f060905, 0x1c0c1a0c, 0x23530cee, 0x11081013,   // pl.de.cy_333 tl.sv.id_543  sv.ht.ca_422 be.uk.ro_665
  0x20000a2b, 0x0300681a, 0x1f2b07af, 0x0a00250e,   // pt.sq.un_980 ig.nl.un_760  it.vi.cy_655 eu.pt.un_550
  0x2d1310ee, 0x1f0135ad, 0x200835ad, 0x25081f04,   // lt.et.sk_422 zu.en.cy_643  zu.no.sq_643 cy.no.eu_332
  0x04002a04, 0x2d006808, 0x232025a4, 0x08023505,   // mt.fi.un_320 ig.sk.un_430  eu.sq.ca_433 zu.da.no_333
  // [6830]
  0x1a526ba0, 0x23202904, 0x06312a0b, 0x2b005314,   // ceb.ha.tl_322 sl.sq.ca_332  mt.az.de_542 ht.vi.un_660
  0x041352a9, 0x1f6b2102, 0x190b1a14, 0x290407ad,   // ha.et.fi_544 jw.ceb.cy_222  tl.es.gl_666 it.fi.sl_643
  0x1c521ea0, 0x0a0905a0, 0x18001a07, 0x3f6e1312,   // ms.ha.id_322 fr.pl.pt_322  tl.ga.un_420 et.hmn.af_654
  0x3b19070c, 0x35280755, 0x280306ec, 0x23001604,   // it.gl.so_543 it.sw.zu_442  de.nl.sw_644 hr.ca.un_320
  // [6840]
  0x19100b02, 0x1107270c, 0x031853a0, 0x645520a4,   // es.lt.gl_222 gd.it.ro_543  ht.ga.nl_322 sq.rw.lg_433
  0x120b0aa9, 0x27066811, 0x64524a0c, 0x68092812,   // pt.es.hu_544 ig.de.gd_653  yo.ha.lg_543 sw.pl.ig_654
  0x112007ad, 0x53006e04, 0x28000d12, 0x3f6e0307,   // it.sq.ro_643 hmn.ht.un_320  cs.sw.un_640 nl.hmn.af_432
  0x3b2907a7, 0x280705af, 0x276b07ee, 0x553b07a4,   // it.sl.so_532 fr.it.sw_655  it.ceb.gd_422 it.so.rw_433
  // [6850]
  0x64132308, 0x4a006e04, 0x115568ec, 0x2b0f25a7,   // ca.et.lg_443 hmn.yo.un_320  ig.rw.ro_644 eu.lv.vi_532
  0x3f036e05, 0x3512030c, 0x684a25ec, 0x321721a9,   // hmn.nl.af_333 nl.hu.zu_543  eu.yo.ig_644 jw.sr.bs_544
  0x0a6b070c, 0x052707ad, 0x2a3b0712, 0x232511ee,   // it.ceb.pt_543 it.gd.fr_643  it.so.mt_654 ro.eu.ca_422
  0x27060312, 0x0a07280c, 0x272806a9, 0x311b6b13,   // nl.de.gd_654 sw.it.pt_543  de.sw.gd_544 ceb.tr.az_665
  // [6860]
  0x4a0f68ad, 0x4a2568a9, 0x644a5512, 0x20024a02,   // ig.lv.yo_643 ig.eu.yo_544  rw.yo.lg_654 yo.da.sq_222
  0x17002d35, 0x68293f5a, 0x32163f14, 0x1c2764a4,   // sk.sr.un_A90 af.sl.ig_553  af.hr.bs_666 lg.gd.id_433
  0x0a014aa0, 0x1c00170c, 0x080221a4, 0x2a000d08,   // yo.en.pt_322 sr.id.un_530  jw.da.no_433 cs.mt.un_430
  0x6e6b1fa0, 0x211b1caf, 0x642a520c, 0x21003504,   // cy.ceb.hmn_322 id.tr.jw_655  ha.mt.lg_543 zu.jw.un_320
  // [6870]
  0x64132a07, 0x1e1c52a0, 0x043b1ea7, 0x19050ba0,   // mt.et.lg_432 ha.id.ms_322  ms.so.fi_532 es.fr.gl_322
  0x2a006421, 0x682a640c, 0x4a1c1e0c, 0x0f27100d,   // lg.mt.un_860 lg.mt.ig_543  ms.id.yo_543 lt.gd.lv_554
  0x061b31a0, 0x646b35ad, 0x0e002507, 0x1a52530c,   // az.tr.de_322 zu.ceb.lg_643  eu.is.un_420 ht.ha.tl_543
  0x07310e04, 0x2728180c, 0x1120530c, 0x1f270f09,   // is.az.it_332 ga.sw.gd_543  ht.sq.ro_543 lv.gd.cy_444
  // [6880]
  0x060704a9, 0x5355210c, 0x1c101ea9, 0x281f27a6,   // fi.it.de_544 jw.rw.ht_543  ms.lt.id_544 gd.cy.sw_521
  0x64551aad, 0x64002a19, 0x072b110c, 0x0c313b07,   // tl.rw.lg_643 mt.lg.un_750  ro.vi.it_543 so.az.sv_432
  0x040812a4, 0x043b2705, 0x030152a0, 0x21041a0c,   // hu.no.fi_433 gd.so.fi_333  ha.en.nl_322 tl.fi.jw_543
  0x2a005213, 0x070a010c, 0x23200c08, 0x27002823,   // ha.mt.un_650 en.pt.it_543  sv.sq.ca_443 sw.gd.un_880
  // [6890]
  0x03683f0d, 0x1e6425a4, 0x0a120612, 0x3b001105,   // af.ig.nl_554 eu.lg.ms_433  de.hu.pt_654 ro.so.un_330
  0x64211aa9, 0x0d173bad, 0x2b0155a0, 0x102506a4,   // tl.jw.lg_544 so.sr.cs_643  rw.en.vi_322 de.eu.lt_433
  0x2a643f04, 0x35041f0c, 0x0e1809ec, 0x0e06130c,   // af.lg.mt_332 cy.fi.zu_543  pl.ga.is_644 et.de.is_543
  0x68000608, 0x2d2917ee, 0x073164a7, 0x6b6806ec,   // de.ig.un_430 sr.sl.sk_422  lg.az.it_532 de.ig.ceb_644
  // [68a0]
  0x06002721, 0x52190b13, 0x0b2753a0, 0x0a002307,   // gd.de.un_860 es.gl.ha_665  ht.gd.es_322 ca.pt.un_420
  0x27002b19, 0x27000121, 0x290e0c08, 0x11002704,   // vi.gd.un_750 en.gd.un_860  sv.is.sl_443 gd.ro.un_320
  0x2b53270c, 0x1f062bee, 0x25002321, 0x21521aec,   // gd.ht.vi_543 vi.de.cy_422  ca.eu.un_860 tl.ha.jw_644
  0x06531f11, 0x0c530604, 0x23552aa0, 0x11130605,   // cy.ht.de_653 de.ht.sv_332  mt.rw.ca_322 de.et.ro_333
  // [68b0]
  0x4a1a11a9, 0x0f00110c, 0x28133504, 0x08002d08,   // ro.tl.yo_544 ro.lv.un_530  zu.et.sw_332 sk.no.un_430
  0x122855ee, 0x0a001134, 0x64001c04, 0x20291711,   // rw.sw.hu_422 ro.pt.un_A80  id.lg.un_320 sr.sl.sq_653
  0x1b0768a9, 0x19001f02, 0x0d1016a4, 0x130c0614,   // ig.it.tr_544 cy.gl.un_220  hr.lt.cs_433 de.sv.et_666
  0x062055a4, 0x3f00291a, 0x020553af, 0x6b010713,   // rw.sq.de_433 sl.af.un_760  ht.fr.da_655 it.en.ceb_665
  // [68c0]
  0x29130460, 0x1c1e2104, 0x3f001f22, 0x25000302,   // fi.et.sl_664 jw.ms.id_332  cy.af.un_870 nl.eu.un_220
  0x1e2d0d14, 0x1e101c04, 0x213b5512, 0x063b1b08,   // cs.sk.ms_666 id.lt.ms_332  rw.so.jw_654 tr.so.de_443
  0x27001105, 0x0c0229ad, 0x55132a0c, 0x205528ec,   // ro.gd.un_330 sl.da.sv_643  mt.et.rw_543 sw.rw.sq_644
  0x071035a4, 0x10130fad, 0x063f3508, 0x521a5504,   // zu.lt.it_433 lv.et.lt_643  zu.af.de_443 rw.tl.ha_332
  // [68d0]
  0x0f006423, 0x100f1a12, 0x683f06ad, 0x216b28ad,   // lg.lv.un_880 tl.lv.lt_654  de.af.ig_643 sw.ceb.jw_643
  0x1c1304a9, 0x2735110c, 0x4a0f52a4, 0x133b6b14,   // fi.et.id_544 ro.zu.gd_543  ha.lv.yo_433 ceb.so.et_666
  0x080253ee, 0x2000211b, 0x64683ba7, 0x354a530c,   // ht.da.no_422 jw.sq.un_770  so.ig.lg_532 ht.yo.zu_543
  0x27100f09, 0x19050ba7, 0x68003505, 0x055331ec,   // lv.lt.gd_444 es.fr.gl_532  zu.ig.un_330 az.ht.fr_644
  // [68e0]
  0x35282005, 0x0f1320a9, 0x10006b0d, 0x292d3f05,   // sq.sw.zu_333 sq.et.lv_544  ceb.lt.un_540 af.sk.sl_333
  0x552820af, 0x01002905, 0x352820af, 0x28003b18,   // sq.sw.rw_655 sl.en.un_330  sq.sw.zu_655 so.sw.un_740
  0x010910a0, 0x0e00060c, 0x0b3507a4, 0x32191704,   // lt.pl.en_322 de.is.un_530  it.zu.es_433 sr.gl.bs_332
  0x3b281308, 0x643b13a0, 0x55003b21, 0x311b520c,   // et.sw.so_443 et.so.lg_322  so.rw.un_860 ha.tr.az_543
  // [68f0]
  0x01002b07, 0x2100640d, 0x53003f09, 0x3b281f02,   // vi.en.un_420 lg.jw.un_540  af.ht.un_440 cy.sw.so_222
  0x08120cee, 0x23001f12, 0x12042a12, 0x680112a0,   // sv.hu.no_422 cy.ca.un_640  mt.fi.hu_654 hu.en.ig_322
  0x01070509, 0x6b2052a9, 0x23001235, 0x283b1fee,   // fr.it.en_444 ha.sq.ceb_544  hu.ca.un_A90 cy.so.sw_422
  0x0c081905, 0x0c001321, 0x644a0911, 0x20006822,   // gl.no.sv_333 et.sv.un_860  pl.yo.lg_653 ig.sq.un_870
  // [6900]
  0x53163fa9, 0x6b005523, 0x100a350b, 0x52136860,   // af.hr.ht_544 rw.ceb.un_880  zu.pt.lt_542 ig.et.ha_664
  0x3f68640c, 0x3f2a2512, 0x2a2025a4, 0x25180aaf,   // lg.ig.af_543 eu.mt.af_654  eu.sq.mt_433 pt.ga.eu_655
  0x0201080c, 0x0104520b, 0x320f20a4, 0x3b2820ad,   // no.en.da_543 ha.fi.en_542  sq.lv.bs_433 sq.sw.so_643
  0x202b08ee, 0x64521fa9, 0x1b001220, 0x1e551ca9,   // no.vi.sq_422 cy.ha.lg_544  hu.tr.un_850 id.rw.ms_544
  // [6910]
  0x642810a4, 0x35001c04, 0x06350ea0, 0x3f035509,   // lt.sw.lg_433 id.zu.un_320  is.zu.de_322 rw.nl.af_444
  0x21131e07, 0x21103507, 0x28002120, 0x283b55ee,   // ms.et.jw_432 zu.lt.jw_432  jw.sw.un_850 rw.so.sw_422
  0x230308a4, 0x64013f0c, 0x2a1955ee, 0x214a1ca4,   // no.nl.ca_433 af.en.lg_543  rw.gl.mt_422 id.yo.jw_433
  0x311b13ec, 0x6b080213, 0x1121520c, 0x353b1308,   // et.tr.az_644 da.no.ceb_665  ha.jw.ro_543 et.so.zu_443
  // [6920]
  0x061b3b07, 0x0a080405, 0x3b002805, 0x2d520d08,   // so.tr.de_432 ru.uk.mk_333  sw.so.un_330 cs.ha.sk_443
  0x3b536b08, 0x281a3b11, 0x1c0e4aac, 0x28000707,   // ceb.ht.so_443 so.tl.sw_653  yo.is.id_632 it.sw.un_420
  0x0f001e07, 0x0a00250c, 0x3f2864ac, 0x291310af,   // ms.lv.un_420 eu.pt.un_530  lg.sw.af_632 lt.et.sl_655
  0x1e1c6414, 0x19230a11, 0x64041eee, 0x050806ee,   // lg.id.ms_666 pt.ca.gl_653  ms.fi.lg_422 de.no.fr_422
  // [6930]
  0x0b18020c, 0x4a0453a0, 0x530504a4, 0x284a5208,   // da.ga.es_543 ht.fi.yo_322  fi.fr.ht_433 ha.yo.sw_443
  0x3f3b02a0, 0x12002d12, 0x060308a4, 0x2709550c,   // da.so.af_322 sk.hu.un_640  no.nl.de_433 rw.pl.gd_543
  0x052d27a0, 0x116b6408, 0x32162911, 0x0f100713,   // gd.sk.fr_322 lg.ceb.ro_443  sl.hr.bs_653 it.lt.lv_665
  0x5305640c, 0x0a1205af, 0x04056407, 0x070255af,   // lg.fr.ht_543 fr.hu.pt_655  lg.fr.fi_432 rw.da.it_655
  // [6940]
  0x1b1304ec, 0x1809050c, 0x316b1ca0, 0x640705ee,   // fi.et.tr_644 fr.pl.ga_543  id.ceb.az_322 fr.it.lg_422
  0x08021caf, 0x23011e0c, 0x072823a4, 0x23005222,   // id.da.no_655 ms.en.ca_543  ca.sw.it_433 ha.ca.un_870
  0x132a0ca9, 0x010c0404, 0x08002104, 0x5300230e,   // sv.mt.et_544 fi.sv.en_332  jw.no.un_320 ca.ht.un_550
  0x3b0b0411, 0x0b0a235a, 0x01050407, 0x551b640c,   // fi.es.so_653 ca.pt.es_553  fi.fr.en_432 lg.tr.rw_543
  // [6950]
  0x0f0e13af, 0x0d271860, 0x4a255355, 0x0d122d0d,   // et.is.lv_655 ga.gd.cs_664  ht.eu.yo_442 sk.hu.cs_554
  0x2b03010c, 0x3b3f1313, 0x12254a13, 0x3b005213,   // en.nl.vi_543 et.af.so_665  yo.eu.hu_665 ha.so.un_650
  0x29165207, 0x27092513, 0x11050a05, 0x292d2008,   // ha.hr.sl_432 eu.pl.gd_665  pt.fr.ro_333 sq.sk.sl_443
  0x11000821, 0x282a68ad, 0x322920af, 0x0b1923a6,   // uk.ro.un_860 ig.mt.sw_643  sq.sl.bs_655 ca.gl.es_521
  // [6960]
  0x27643b13, 0x531e4aa4, 0x521b2308, 0x080e180c,   // so.lg.gd_665 yo.ms.ht_433  ca.tr.ha_443 ga.is.no_543
  0x231827a9, 0x3f2a0605, 0x033f130c, 0x11000e21,   // gd.ga.ca_544 de.mt.af_333  et.af.nl_543 is.ro.un_860
  0x2a040f0c, 0x29110da7, 0x035325ee, 0x4a250655,   // lv.fi.mt_543 cs.ro.sl_532  eu.ht.nl_422 de.eu.yo_442
  0x25271c07, 0x21251c12, 0x125225a9, 0x18000919,   // id.gd.eu_432 id.eu.jw_654  eu.ha.hu_544 pl.ga.un_750
  // [6970]
  0x1a1c52af, 0x190b25ee, 0x6b002504, 0x521a1e11,   // ha.id.tl_655 eu.es.gl_422  eu.ceb.un_320 ms.tl.ha_653
  0x1f0618a4, 0x6b351a12, 0x3b06270e, 0x291f06af,   // ga.de.cy_433 tl.zu.ceb_654  gd.de.so_555 de.cy.sl_655
  0x13002817, 0x231f6ea9, 0x52682504, 0x080e6b5a,   // sw.et.un_730 hmn.cy.ca_544  eu.ig.ha_332 ceb.is.no_553
  0x521b25ec, 0x130452a0, 0x2500071a, 0x1a643508,   // eu.tr.ha_644 ha.fi.et_322  it.eu.un_760 zu.lg.tl_443
  // [6980]
  0x0452070c, 0x21073fad, 0x10251213, 0x09002a02,   // it.ha.fi_543 af.it.jw_643  hu.eu.lt_665 mt.pl.un_220
  0x0c1e2305, 0x0f2d04a4, 0x0f6b1a0d, 0x0b0a1b09,   // ca.ms.sv_333 fi.sk.lv_433  tl.ceb.lv_554 tr.pt.es_444
  0x16000c04, 0x3b2a5208, 0x052a5202, 0x19004a0d,   // sv.hr.un_320 ha.mt.so_443  ha.mt.fr_222 yo.gl.un_540
  0x640428af, 0x0700050e, 0x160710ee, 0x1009680e,   // sw.fi.lg_655 fr.it.un_550  lt.it.hr_422 ig.pl.lt_555
  // [6990]
  0x17291607, 0x271825ad, 0x1b006409, 0x25001f2b,   // hr.sl.sr_432 eu.ga.gd_643  lg.tr.un_440 cy.eu.un_980
  0x282120ec, 0x68042107, 0x351e5209, 0x642510a7,   // sq.jw.sw_644 jw.fi.ig_432  ha.ms.zu_444 lt.eu.lg_532
  0x08130405, 0x32111e0b, 0x2a000313, 0x4a001018,   // fi.et.no_333 ms.ro.bs_542  nl.mt.un_650 lt.yo.un_740
  0x110725af, 0x0b350507, 0x07081213, 0x68122114,   // eu.it.ro_655 fr.zu.es_432  hu.no.it_665 jw.hu.ig_666
  // [69a0]
  0x040b070c, 0x102718ec, 0x231f0a02, 0x0a072da9,   // it.es.fi_543 ga.gd.lt_644  pt.cy.ca_222 sk.it.pt_544
  0x1a6b2d0c, 0x2d1925a4, 0x06026405, 0x643b07ad,   // sk.ceb.tl_543 eu.gl.sk_433  lg.da.de_333 it.so.lg_643
  0x31001007, 0x02001705, 0x1a04680c, 0x133b6e05,   // lt.az.un_420 sr.da.un_330  ig.fi.tl_543 hmn.so.et_333
  0x23160a07, 0x0a003114, 0x11006b02, 0x2d2928a7,   // pt.hr.ca_432 az.pt.un_660  ceb.ro.un_220 sw.sl.sk_532
  // [69b0]
  0x1e000505, 0x23071fa0, 0x120421a0, 0x081025a0,   // fr.ms.un_330 cy.it.ca_322  jw.fi.hu_322 eu.lt.no_322
  0x041328ee, 0x0a111712, 0x10271f12, 0x21122307,   // sw.et.fi_422 sr.ro.mk_654  cy.gd.lt_654 ca.hu.jw_432
  0x10000b19, 0x23281909, 0x01003b02, 0x643b6804,   // es.lt.un_750 gl.sw.ca_444  so.en.un_220 ig.so.lg_332
  0x11002d0d, 0x1a001902, 0x21291e08, 0x212d1c04,   // sk.ro.un_540 gl.tl.un_220  ms.sl.jw_443 id.sk.jw_332
  // [69c0]
  0x0e23080c, 0x1a00020c, 0x281b1c0c, 0x556e2804,   // no.ca.is_543 da.tl.un_530  id.tr.sw_543 sw.hmn.rw_332
  0x16286411, 0x10000e13, 0x2a521bad, 0x19041309,   // lg.sw.hr_653 is.lt.un_650  tr.ha.mt_643 et.fi.gl_444
  0x16283508, 0x55281f0c, 0x07000b02, 0x2b004a0c,   // zu.sw.hr_443 cy.sw.rw_543  es.it.un_220 yo.vi.un_530
  0x3b281fa4, 0x21001f22, 0x202821ad, 0x21001b1a,   // cy.sw.so_433 cy.jw.un_870  jw.sw.sq_643 tr.jw.un_760
  // [69d0]
  0x2800091a, 0x3f032012, 0x211c2008, 0x0e551e0c,   // pl.sw.un_760 sq.nl.af_654  sq.id.jw_443 ms.rw.is_543
  0x0f3f0ca9, 0x020f0807, 0x101721a7, 0x08050f07,   // sv.af.lv_544 no.lv.da_432  jw.sr.lt_532 lv.fr.no_432
  0x0a1e1c13, 0x291a21a4, 0x2d0220ec, 0x0400211a,   // id.ms.pt_665 jw.tl.sl_433  sq.da.sk_644 jw.fi.un_760
  0x040e28af, 0x0c003f0e, 0x16321712, 0x02002304,   // sw.is.fi_655 af.sv.un_550  sr.bs.hr_654 ca.da.un_320
  // [69e0]
  0x31231ba4, 0x05120b05, 0x35001b12, 0x35002a1a,   // tr.ca.az_433 es.hu.fr_333  tr.zu.un_640 mt.zu.un_760
  0x010603ee, 0x18055502, 0x2018350c, 0x131155a7,   // nl.de.en_422 rw.fr.ga_222  zu.ga.sq_543 rw.ro.et_532
  0x1b2023a6, 0x1c051e07, 0x35230ba4, 0x0a050fa7,   // ca.sq.tr_521 ms.fr.id_432  es.ca.zu_433 lv.fr.pt_532
  0x0613080c, 0x011b13ee, 0x3f27130c, 0x2008110c,   // no.et.de_543 et.tr.en_422  et.gd.af_543 ro.no.sq_543
  // [69f0]
  0x04100e08, 0x1300102c, 0x64201109, 0x35551b07,   // is.lt.fi_443 lt.et.un_990  ro.sq.lg_444 tr.rw.zu_432
  0x01072005, 0x05271805, 0x52001e0e, 0x183f0608,   // sq.it.en_333 ga.gd.fr_333  ms.ha.un_550 de.af.ga_443
  0x18273bec, 0x642035a6, 0x2300270b, 0x21121ea9,   // so.gd.ga_644 zu.sq.lg_521  gd.ca.un_520 ms.hu.jw_544
  0x01002119, 0x28042107, 0x2d006b04, 0x200513ee,   // jw.en.un_750 jw.fi.sw_432  ceb.sk.un_320 et.fr.sq_422
  // [6a00]
  0x17290d05, 0x010520a4, 0x1c2a070c, 0x35001322,   // cs.sl.sr_333 sq.fr.en_433  it.mt.id_543 et.zu.un_870
  0x12020812, 0x1e211baf, 0x082d250c, 0x6b002522,   // no.da.hu_654 tr.jw.ms_655  eu.sk.no_543 eu.ceb.un_870
  0x03001a08, 0x06212a04, 0x6b080eaf, 0x29000923,   // tl.nl.un_430 mt.jw.de_332  is.no.ceb_655 pl.sl.un_880
  0x1100230d, 0x21001602, 0x0600100e, 0x321729a9,   // ca.ro.un_540 hr.jw.un_220  lt.de.un_550 sl.sr.bs_544
  // [6a10]
  0x6b4a1a07, 0x536b05ee, 0x64283505, 0x2d0d17a4,   // tl.yo.ceb_432 fr.ceb.ht_422  zu.sw.lg_333 sr.cs.sk_433
  0x090d2dec, 0x531c210c, 0x11202508, 0x35131ea0,   // sk.cs.pl_644 jw.id.ht_543  eu.sq.ro_443 ms.et.zu_322
  0x643f3b0c, 0x070b280c, 0x13356808, 0x4a3f3b08,   // so.af.lg_543 sw.es.it_543  ig.zu.et_443 so.af.yo_443
  0x27112304, 0x272d2a07, 0x09003520, 0x064a35a4,   // ca.ro.gd_332 mt.sk.gd_432  zu.pl.un_850 zu.yo.de_433
  // [6a20]
  0x25092aee, 0x6e185212, 0x20252855, 0x12003b0d,   // mt.pl.eu_422 ha.ga.hmn_654  sw.eu.sq_442 so.hu.un_540
  0x3f4a13a4, 0x07280b13, 0x68001a19, 0x25211fa4,   // et.yo.af_433 es.sw.it_665  tl.ig.un_750 cy.jw.eu_433
  0x122b3b0d, 0x6b6817a6, 0x062d0f07, 0x0768280c,   // so.vi.hu_554 sr.ig.ceb_521  lv.sk.de_432 sw.ig.it_543
  0x2d0d0ca4, 0x106825ad, 0x281c010b, 0x0b251a08,   // sv.cs.sk_433 eu.ig.lt_643  en.id.sw_542 tl.eu.es_443
  // [6a30]
  0x0700210c, 0x01271112, 0x27191812, 0x1c6b0cad,   // jw.it.un_530 ro.gd.en_654  ga.gl.gd_654 sv.ceb.id_643
  0x2d5511ad, 0x68016b0d, 0x1a00520d, 0x3b681b0c,   // ro.rw.sk_643 ceb.en.ig_554  ha.tl.un_540 tr.ig.so_543
  0x3b1a28a9, 0x5300230c, 0x320216a4, 0x3b1a5209,   // sw.tl.so_544 ca.ht.un_530  hr.da.bs_433 ha.tl.so_444
  0x180b2708, 0x17211c0e, 0x270b1855, 0x64005204,   // gd.es.ga_443 id.jw.sr_555  ga.es.gd_442 ha.lg.un_320
  // [6a40]
  0x52642108, 0x121b55a4, 0x01000614, 0x1b3168af,   // jw.lg.ha_443 rw.tr.hu_433  de.en.un_660 ig.az.tr_655
  0x05551104, 0x1a52310c, 0x04641309, 0x1e1f1ca4,   // ro.rw.fr_332 az.ha.tl_543  et.lg.fi_444 id.cy.ms_433
  0x0c6b2aec, 0x0a2119ad, 0x04134a13, 0x08212a0c,   // mt.ceb.sv_644 gl.jw.pt_643  yo.et.fi_665 mt.jw.no_543
  0x3f3b2504, 0x640e5508, 0x1b681a0c, 0x2d0d4aa0,   // eu.so.af_332 rw.is.lg_443  tl.ig.tr_543 yo.cs.sk_322
  // [6a50]
  0x0e002a33, 0x2d0d08a4, 0x13271860, 0x231729ec,   // mt.is.un_A70 no.cs.sk_433  ga.gd.et_664 sl.sr.ca_644
  0x03233fa0, 0x21641705, 0x203b5307, 0x04684aa4,   // af.ca.nl_322 sr.lg.jw_333  ht.so.sq_432 yo.ig.fi_433
  0x180f01ad, 0x126403a9, 0x19014aa0, 0x29071f0d,   // en.lv.ga_643 nl.lg.hu_544  yo.en.gl_322 cy.it.sl_554
  0x080f2908, 0x0f132107, 0x3f060e0c, 0x103b070b,   // sl.lv.no_443 jw.et.lv_432  is.de.af_543 it.so.lt_542
  // [6a60]
  0x0e00272a, 0x0818270d, 0x3b001007, 0x0b2d1904,   // gd.is.un_970 gd.ga.no_554  lt.so.un_420 gl.sk.es_332
  0x551b35ee, 0x08002a13, 0x0a073b05, 0x2d295504,   // zu.tr.rw_422 mt.no.un_650  so.it.pt_333 rw.sl.sk_332
  0x05006e07, 0x53130eee, 0x28006b14, 0x0d0e1908,   // hmn.fr.un_420 is.et.ht_422  ceb.sw.un_660 gl.is.cs_443
  0x35110a0e, 0x00001203, 0x09001f02, 0x04281b55,   // pt.ro.zu_555 ur.un.un_300  cy.pl.un_220 tr.sw.fi_442
  // [6a70]
  0x211304ec, 0x1b1110a4, 0x25130460, 0x113104ee,   // fi.et.jw_644 lt.ro.tr_433  fi.et.eu_664 fi.az.ro_422
  0x08006b20, 0x2d120dad, 0x0f000720, 0x311b1108,   // ceb.no.un_850 cs.hu.sk_643  it.lv.un_850 ro.tr.az_443
  0x5200250b, 0x07001a1a, 0x0a1219a9, 0x64005308,   // eu.ha.un_520 tl.it.un_760  gl.hu.pt_544 ht.lg.un_430
  0x0b001708, 0x08090304, 0x3f2103ac, 0x1b1011af,   // sr.es.un_430 nl.pl.no_332  nl.jw.af_632 ro.lt.tr_655
  // [6a80]
  0x1a6b2814, 0x23053ba0, 0x06180812, 0x216e0e04,   // sw.ceb.tl_666 so.fr.ca_322  no.ga.de_654 is.hmn.jw_332
  0x234a1812, 0x0e0b1a08, 0x3f6e6b55, 0x0f200907,   // ga.yo.ca_654 tl.es.is_443  ceb.hmn.af_442 pl.sq.lv_432
  0x076b11a0, 0x0f00131b, 0x3b001f12, 0x29001222,   // ro.ceb.it_322 et.lv.un_770  cy.so.un_640 hu.sl.un_870
  0x0a255307, 0x3b1f6e0d, 0x19000621, 0x2a072513,   // ht.eu.pt_432 hmn.cy.so_554  de.gl.un_860 eu.it.mt_665
  // [6a90]
  0x23180d0c, 0x27010cee, 0x12005302, 0x5200210c,   // cs.ga.ca_543 sv.en.gd_422  ht.hu.un_220 jw.ha.un_530
  0x280f2504, 0x13100fa4, 0x0a251ca7, 0x1e3b3508,   // eu.lv.sw_332 lv.lt.et_433  id.eu.pt_532 zu.so.ms_443
  0x104a0f11, 0x070817ad, 0x08023f02, 0x123104af,   // lv.yo.lt_653 sr.uk.bg_643  af.da.no_222 fi.az.hu_655
  0x1e531c04, 0x536b4a04, 0x0703010c, 0x3b352a12,   // id.ht.ms_332 yo.ceb.ht_332  en.nl.it_543 mt.zu.so_654
  // [6aa0]
  0x1e0d3155, 0x07190a14, 0x280f0d04, 0x16003f12,   // az.cs.ms_442 pt.gl.it_666  cs.lv.sw_332 af.hr.un_640
  0x0700011a, 0x12520407, 0x55000513, 0x2a000618,   // en.it.un_760 fi.ha.hu_432  fr.rw.un_650 de.mt.un_740
  0x1f195214, 0x64001209, 0x16131e08, 0x0b1720ee,   // ha.gl.cy_666 hu.lg.un_440  ms.et.hr_443 sq.sr.es_422
  0x0800070c, 0x0c271809, 0x12101f09, 0x13050455,   // bg.uk.un_530 ga.gd.sv_444  cy.lt.hu_444 fi.fr.et_442
  // [6ab0]
  0x535228a9, 0x2b006808, 0x552811af, 0x0a1229ee,   // sw.ha.ht_544 ig.vi.un_430  ro.sw.rw_655 sl.hu.pt_422
  0x02001012, 0x07000c13, 0x1e1c1bac, 0x111017a4,   // lt.da.un_640 sv.it.un_650  tr.id.ms_632 sr.be.ro_433
  0x31000904, 0x12000702, 0x1200680c, 0x11001212,   // pl.az.un_320 it.hu.un_220  ig.hu.un_530 hu.ro.un_640
  0x3b00642a, 0x0a000d08, 0x100f090c, 0x09001a07,   // lg.so.un_970 cs.pt.un_430  pl.lv.lt_543 tl.pl.un_420
  // [6ac0]
  0x21124aee, 0x071117ad, 0x042852ad, 0x190a25ec,   // yo.hu.jw_422 sr.ro.bg_643  ha.sw.fi_643 eu.pt.gl_644
  0x0400350e, 0x211c35a0, 0x05001912, 0x10131ea4,   // zu.fi.un_550 zu.id.jw_322  gl.fr.un_640 ms.et.lt_433
  0x03120660, 0x043525ad, 0x535229af, 0x0f11130d,   // de.hu.nl_664 eu.zu.fi_643  sl.ha.ht_655 et.ro.lv_554
  0x0900350d, 0x21273fa0, 0x01005505, 0x2a003f0d,   // zu.pl.un_540 af.gd.jw_322  rw.en.un_330 af.mt.un_540
  // [6ad0]
  0x081b02ad, 0x1b1f0911, 0x06523507, 0x081b1305,   // da.tr.no_643 pl.cy.tr_653  zu.ha.de_432 et.tr.no_333
  0x3b2d35a9, 0x321709a4, 0x1e1c18a4, 0x271f18ad,   // zu.sk.so_544 pl.sr.bs_433  ga.id.ms_433 ga.cy.gd_643
  0x3f3552a0, 0x21523fad, 0x211f3507, 0x3f000e0b,   // ha.zu.af_322 af.ha.jw_643  zu.cy.jw_432 is.af.un_520
  0x2d0a23af, 0x210f1c0c, 0x1a001008, 0x0b2a0708,   // ca.pt.sk_655 id.lv.jw_543  lt.tl.un_430 it.mt.es_443
  // [6ae0]
  0x52004a02, 0x1c031eee, 0x03131ba7, 0x1f122b07,   // yo.ha.un_220 ms.nl.id_422  tr.et.nl_532 vi.hu.cy_432
  0x3f130805, 0x021008a0, 0x020e0812, 0x08020314,   // no.et.af_333 no.lt.da_322  no.is.da_654 nl.da.no_666
  0x6b55045a, 0x2035530c, 0x35201708, 0x642804ee,   // fi.rw.ceb_553 ht.zu.sq_543  sr.sq.zu_443 fi.sw.lg_422
  0x06311b08, 0x2d001714, 0x09071813, 0x2b002a02,   // tr.az.de_443 sr.sk.un_660  ga.it.pl_665 mt.vi.un_220
  // [6af0]
  0x3f000f13, 0x23534a08, 0x190b1114, 0x181013a4,   // lv.af.un_650 yo.ht.ca_443  ro.es.gl_666 et.lt.ga_433
  0x09172dee, 0x1c2b01a6, 0x2400010c, 0x4a1e550c,   // sk.sr.pl_422 en.vi.id_521  iw.yi.un_530 rw.ms.yo_543
  0x190b0da4, 0x0a2d23ec, 0x311b09a7, 0x19050a0b,   // cs.es.gl_433 ca.sk.pt_644  pl.tr.az_532 pt.fr.gl_542
  0x520e0412, 0x170e16a4, 0x181123a4, 0x080c02a0,   // fi.is.ha_654 hr.is.sr_433  ca.ro.ga_433 da.sv.no_322
  // [6b00]
  0x0d00160c, 0x01000205, 0x190a55af, 0x0b2312ec,   // hr.cs.un_530 da.en.un_330  rw.pt.gl_655 hu.ca.es_644
  0x1f0e5355, 0x6e005522, 0x1e00030d, 0x17531107,   // ht.is.cy_442 rw.hmn.un_870  nl.ms.un_540 ro.ht.sr_432
  0x190a3205, 0x190b2312, 0x0f32250d, 0x0b005207,   // bs.pt.gl_333 ca.es.gl_654  eu.bs.lv_554 ha.es.un_420
  0x6e006409, 0x230a0bec, 0x53004a09, 0x52002d0d,   // lg.hmn.un_440 es.pt.ca_644  yo.ht.un_440 sk.ha.un_540
  // [6b10]
  0x100c0ea9, 0x03054a02, 0x05520655, 0x19120a0d,   // is.sv.lt_544 yo.fr.nl_222  de.ha.fr_442 pt.hu.gl_554
  0x0d102d12, 0x2d0d23a4, 0x01251fa0, 0x230a19a9,   // sk.lt.cs_654 ca.cs.sk_433  cy.eu.en_322 gl.pt.ca_544
  0x12003202, 0x1e043b12, 0x29126ea4, 0x2d0d1fec,   // bs.hu.un_220 so.fi.ms_654  hmn.hu.sl_433 cy.cs.sk_644
  0x06030fad, 0x524a10ad, 0x130f08a4, 0x3b006e02,   // lv.nl.de_643 lt.yo.ha_643  no.lv.et_433 hmn.so.un_220
  // [6b20]
  0x04002308, 0x23000e19, 0x68356411, 0x09100faf,   // ca.fi.un_430 is.ca.un_750  lg.zu.ig_653 lv.lt.pl_655
  0x310264ec, 0x6b000307, 0x27071fad, 0x04283b09,   // lg.da.az_644 nl.ceb.un_420  cy.it.gd_643 so.sw.fi_444
  0x21001210, 0x092a0f13, 0x06006804, 0x0900020e,   // hu.jw.un_620 lv.mt.pl_665  ig.de.un_320 da.pl.un_550
  0x1b316b0c, 0x05093f08, 0x0d062da9, 0x07002b07,   // ceb.az.tr_543 af.pl.fr_443  sk.de.cs_544 vi.it.un_420
  // [6b30]
  0x05186ba4, 0x10006405, 0x033f0da9, 0x090f05a9,   // ceb.ga.fr_433 lg.lt.un_330  cs.af.nl_544 fr.lv.pl_544
  0x07000e07, 0x04001702, 0x291c0e04, 0x645505a0,   // is.it.un_420 sr.ru.un_220  is.id.sl_332 fr.rw.lg_322
  0x073555a4, 0x2b00071a, 0x082d0d13, 0x1c001f12,   // rw.zu.it_433 it.vi.un_760  cs.sk.no_665 cy.id.un_640
  0x0f1813a4, 0x1300100c, 0x3b290eee, 0x3f270c07,   // et.ga.lv_433 lt.et.un_530  is.sl.so_422 sv.gd.af_432
  // [6b40]
  0x07001111, 0x286b550c, 0x1b1304a4, 0x042031ad,   // ro.bg.un_630 rw.ceb.sw_543  fi.et.tr_433 az.sq.fi_643
  0x35135508, 0x1b313505, 0x1a553508, 0x13001702,   // rw.et.zu_443 zu.az.tr_333  zu.rw.tl_443 sr.et.un_220
  0x09642507, 0x12003512, 0x13005213, 0x0464280c,   // eu.lg.pl_432 zu.hu.un_640  ha.et.un_650 sw.lg.fi_543
  0x03130407, 0x312d1b07, 0x3f1210af, 0x033f0404,   // fi.et.nl_432 tr.sk.az_432  lt.hu.af_655 fi.af.nl_332
  // [6b50]
  0x4a002b19, 0x1819110c, 0x250120a4, 0x00002837,   // vi.yo.un_750 ro.gl.ga_543  sq.en.eu_433 sw.un.un_B00
  0x0d282005, 0x2d0d11af, 0x03006e04, 0x68001f1a,   // sq.sw.cs_333 ro.cs.sk_655  hmn.nl.un_320 cy.ig.un_760
  0x0a552008, 0x53645513, 0x4a096411, 0x1f5564af,   // sq.rw.pt_443 rw.lg.ht_665  lg.pl.yo_653 lg.rw.cy_655
  0x23112004, 0x1f180107, 0x0a000e02, 0x190a4a09,   // sq.ro.ca_332 en.ga.cy_432  is.pt.un_220 yo.pt.gl_444
  // [6b60]
  0x556852af, 0x200102a0, 0x3f6b1a0e, 0x356e2b05,   // ha.ig.rw_655 da.en.sq_322  tl.ceb.af_555 vi.hmn.zu_333
  0x3f001805, 0x130e1f08, 0x1000230d, 0x01050808,   // ga.af.un_330 cy.is.et_443  ca.lt.un_540 no.fr.en_443
  0x556b1ca0, 0x0e6b1aa0, 0x3f030605, 0x0e6b1305,   // id.ceb.rw_322 tl.ceb.is_322  de.nl.af_333 et.ceb.is_333
  0x6b001e22, 0x286852a7, 0x64001a04, 0x0b0764a4,   // ms.ceb.un_870 ha.ig.sw_532  tl.lg.un_320 lg.it.es_433
  // [6b70]
  0x2a1f25af, 0x1e104aee, 0x2b005202, 0x31281ca4,   // eu.cy.mt_655 yo.lt.ms_422  ha.vi.un_220 id.sw.az_433
  0x3f0a1804, 0x32002a0d, 0x10000e0d, 0x050753ec,   // ga.pt.af_332 mt.bs.un_540  is.lt.un_540 ht.it.fr_644
  0x1a5325a4, 0x521c6808, 0x2b530f05, 0x55001319,   // eu.ht.tl_433 ig.id.ha_443  lv.ht.vi_333 et.rw.un_750
  0x64006b05, 0x350e0c0e, 0x3f00520c, 0x530f1305,   // ceb.lg.un_330 sv.is.zu_555  ha.af.un_530 et.lv.ht_333
  // [6b80]
  0x11002102, 0x072053a7, 0x1964550c, 0x070e53ad,   // jw.ro.un_220 ht.sq.it_532  rw.lg.gl_543 ht.is.it_643
  0x042a10ec, 0x355364ec, 0x09102d12, 0x09644aa7,   // lt.mt.fi_644 lg.ht.zu_644  sk.lt.pl_654 yo.lg.pl_532
  0x091f6809, 0x6855110c, 0x2564230b, 0x18684a04,   // ig.cy.pl_444 ro.rw.ig_543  ca.lg.eu_542 yo.ig.ga_332
  0x55004a34, 0x21003f22, 0x13000f1a, 0x1b4a2808,   // yo.rw.un_A80 af.jw.un_870  lv.et.un_760 sw.yo.tr_443
  // [6b90]
  0x010628ee, 0x09525512, 0x042513ad, 0x1028160c,   // sw.de.en_422 rw.ha.pl_654  et.eu.fi_643 hr.sw.lt_543
  0x0e02200c, 0x6e25130d, 0x281b35ee, 0x32101707,   // sq.da.is_543 et.eu.hmn_554  zu.tr.sw_422 sr.lt.bs_432
  0x2a0f10af, 0x0628680c, 0x280a5207, 0x1f066809,   // lt.lv.mt_655 ig.sw.de_543  ha.pt.sw_432 ig.de.cy_444
  0x1e1c04af, 0x04002511, 0x0b1223a4, 0x12001a23,   // fi.id.ms_655 eu.fi.un_630  ca.hu.es_433 tl.hu.un_880
  // [6ba0]
  0x354a53ec, 0x19030ba4, 0x31002702, 0x681f06af,   // ht.yo.zu_644 es.nl.gl_433  gd.az.un_220 de.cy.ig_655
  0x193b235a, 0x030b060e, 0x4a2125a7, 0x130c25a9,   // ca.so.gl_553 de.es.nl_555  eu.jw.yo_532 eu.sv.et_544
  0x19350b07, 0x052d530b, 0x28124aec, 0x6b1e1a05,   // es.zu.gl_432 ht.sk.fr_542  yo.hu.sw_644 tl.ms.ceb_333
  0x03042802, 0x03353fa4, 0x110405af, 0x1b0a25ac,   // sw.fi.nl_222 af.zu.nl_433  fr.fi.ro_655 eu.pt.tr_632
  // [6bb0]
  0x3b2a19ec, 0x06032a0c, 0x550a5355, 0x05001e04,   // gl.mt.so_644 mt.nl.de_543  ht.pt.rw_442 ms.fr.un_320
  0x032012ec, 0x05182507, 0x52201ba7, 0x09000305,   // hu.sq.nl_644 eu.ga.fr_432  tr.sq.ha_532 nl.pl.un_330
  0x1b533104, 0x352d0ca4, 0x1e1c0b05, 0x0a230ea4,   // az.ht.tr_332 sv.sk.zu_433  es.id.ms_333 is.ca.pt_433
  0x321b0e13, 0x28126eee, 0x11550e07, 0x121023a0,   // is.tr.bs_665 hmn.hu.sw_422  is.rw.ro_432 ca.lt.hu_322
  // [6bc0]
  0x05002513, 0x2d0d2108, 0x55000908, 0x05235309,   // eu.fr.un_650 jw.cs.sk_443  pl.rw.un_430 ht.ca.fr_444
  0x53050aa7, 0x1200080d, 0x21000704, 0x0800042c,   // pt.fr.ht_532 no.hu.un_540  it.jw.un_320 ru.uk.un_990
  0x31283b02, 0x0213080c, 0x644a0411, 0x6e6855ad,   // so.sw.az_222 no.et.da_543  fi.yo.lg_653 rw.ig.hmn_643
  0x6819200d, 0x25286bee, 0x00002537, 0x6b2a5507,   // sq.gl.ig_554 ceb.sw.eu_422  eu.un.un_B00 rw.mt.ceb_432
  // [6bd0]
  0x0455250c, 0x13520455, 0x20045502, 0x201a5207,   // eu.rw.fi_543 fi.ha.et_442  rw.fi.sq_222 ha.tl.sq_432
  0x200429ee, 0x0621010c, 0x2d290d0d, 0x28116802,   // sl.fi.sq_422 en.jw.de_543  cs.sl.sk_554 ig.ro.sw_222
  0x53003b12, 0x29210aee, 0x52002913, 0x3b1a2aa0,   // so.ht.un_640 pt.jw.sl_422  sl.ha.un_650 mt.tl.so_322
  0x0f1005a4, 0x0f1810a9, 0x2a1e1c09, 0x01000808,   // fr.lt.lv_433 lt.ga.lv_544  id.ms.mt_444 no.en.un_430
  // [6be0]
  0x11040805, 0x0e2909ac, 0x033f290c, 0x04103b11,   // uk.ru.ro_333 pl.sl.is_632  sl.af.nl_543 so.lt.fi_653
  0x3120350c, 0x28685208, 0x13006804, 0x02536804,   // zu.sq.az_543 ha.ig.sw_443  ig.et.un_320 ig.ht.da_332
  0x0e003f05, 0x0d090f14, 0x0d2d0208, 0x52553509,   // af.is.un_330 lv.pl.cs_666  da.sk.cs_443 zu.rw.ha_444
  0x681c1eac, 0x110a2508, 0x2d0d2355, 0x0c205260,   // ms.id.ig_632 eu.pt.ro_443  ca.cs.sk_442 ha.sq.sv_664
  // [6bf0]
  0x64355508, 0x043b0912, 0x0500250b, 0x55002104,   // rw.zu.lg_443 pl.so.fi_654  eu.fr.un_520 jw.rw.un_320
  0x270468a4, 0x35002114, 0x0c1808ac, 0x2d002512,   // ig.fi.gd_433 jw.zu.un_660  no.ga.sv_632 eu.sk.un_640
  0x1300101b, 0x552120a4, 0x25000f08, 0x235205ad,   // lt.et.un_770 sq.jw.rw_433  lv.eu.un_430 fr.ha.ca_643
  0x1e28520c, 0x1f006419, 0x35005305, 0x0c002302,   // ha.sw.ms_543 lg.cy.un_750  ht.zu.un_330 ca.sv.un_220

  // [6c00]
  0x53084a05, 0x0f033f13, 0x6b681c05, 0x31012055,   // yo.no.ht_333 af.nl.lv_665  id.ig.ceb_333 sq.en.az_442
  0x20682a08, 0x291e060c, 0x1e1c2aa4, 0x68642008,   // mt.ig.sq_443 de.ms.sl_543  mt.id.ms_433 sq.lg.ig_443
  0x0b100a13, 0x641b3109, 0x08006409, 0x0b000804,   // pt.lt.es_665 az.tr.lg_444  lg.no.un_440 no.es.un_320
  0x080e100d, 0x681c1e11, 0x0c0a550c, 0x2321200c,   // lt.is.no_554 ms.id.ig_653  rw.pt.sv_543 sq.jw.ca_543
  // [6c10]
  0x2b001905, 0x230705ec, 0x101325ad, 0x19002b19,   // gl.vi.un_330 fr.it.ca_644  eu.et.lt_643 vi.gl.un_750
  0x07683ba7, 0x1c091ea4, 0x2b002013, 0x55203513,   // so.ig.it_532 ms.pl.id_433  sq.vi.un_650 zu.sq.rw_665
  0x28203512, 0x1a103108, 0x4a553ba4, 0x121e3513,   // zu.sq.sw_654 az.lt.tl_443  so.rw.yo_433 zu.ms.hu_665
  0x20111bad, 0x1f64350c, 0x3b1b1ea7, 0x281c1e0c,   // tr.ro.sq_643 zu.lg.cy_543  ms.tr.so_532 ms.id.sw_543
  // [6c20]
  0x060c08a9, 0x1e1c2aee, 0x553b1b09, 0x0508060c,   // no.sv.de_544 mt.id.ms_422  tr.so.rw_444 de.no.fr_543
  0x3b1b5507, 0x0b1221ee, 0x08021ca4, 0x20282907,   // rw.tr.so_432 jw.hu.es_422  id.da.no_433 sl.sw.sq_432
  0x0a006e1b, 0x321710ec, 0x64000708, 0x06010cee,   // hmn.pt.un_770 lt.sr.bs_644  it.lg.un_430 sv.en.de_422
  0x352520ad, 0x31082702, 0x2b316e07, 0x11000a2a,   // sq.eu.zu_643 gd.no.az_222  hmn.az.vi_432 mk.ro.un_970
  // [6c30]
  0x12050a0e, 0x2900350c, 0x190b0dec, 0x3b3f1305,   // pt.fr.hu_555 zu.sl.un_530  cs.es.gl_644 et.af.so_333
  0x1335530c, 0x554a35a0, 0x13041608, 0x1f040ea4,   // ht.zu.et_543 zu.yo.rw_322  hr.fi.et_443 is.fi.cy_433
  0x312913ad, 0x020a07a0, 0x2d212b12, 0x1a002912,   // et.sl.az_643 it.pt.da_322  vi.jw.sk_654 sl.tl.un_640
  0x08003b12, 0x3f2821ad, 0x1e2855ee, 0x322925ad,   // so.no.un_640 jw.sw.af_643  rw.sw.ms_422 eu.sl.bs_643
  // [6c40]
  0x0e001a12, 0x64251a0c, 0x21003b18, 0x352521ad,   // tl.is.un_640 tl.eu.lg_543  so.jw.un_740 jw.eu.zu_643
  0x6b251aa4, 0x2128080d, 0x0e080b04, 0x04001b13,   // tl.eu.ceb_433 no.sw.jw_554  es.no.is_332 tr.fi.un_650
  0x640e550c, 0x284a10a6, 0x55273bec, 0x216435a9,   // rw.is.lg_543 lt.yo.sw_521  so.gd.rw_644 zu.lg.jw_544
  0x32002507, 0x1c2a28ad, 0x211e2807, 0x01280802,   // eu.bs.un_420 sw.mt.id_643  sw.ms.jw_432 no.sw.en_222
  // [6c50]
  0x64255508, 0x2d0d17ee, 0x0e0806a7, 0x20643512,   // rw.eu.lg_443 sr.cs.sk_422  de.no.is_532 zu.lg.sq_654
  0x1b0903ec, 0x1a526412, 0x1c071e0c, 0x28006e19,   // nl.pl.tr_644 lg.ha.tl_654  ms.it.id_543 hmn.sw.un_750
  0x552164a4, 0x25551c11, 0x20281e12, 0x20002b2a,   // lg.jw.rw_433 id.rw.eu_653  ms.sw.sq_654 vi.sq.un_970
  0x21526ba0, 0x082821a4, 0x3f6b3b0c, 0x06002808,   // ceb.ha.jw_322 jw.sw.no_433  so.ceb.af_543 sw.de.un_430
  // [6c60]
  0x082b18ad, 0x0a001602, 0x1c6e1e11, 0x2900270d,   // ga.vi.no_643 hr.pt.un_220  ms.hmn.id_653 gd.sl.un_540
  0x1a535207, 0x19250ba0, 0x17092905, 0x186e0a0c,   // ha.ht.tl_432 es.eu.gl_322  sl.pl.sr_333 pt.hmn.ga_543
  0x320d1f04, 0x190b53ee, 0x1f076e0d, 0x19250b12,   // cy.cs.bs_332 ht.es.gl_422  hmn.it.cy_554 es.eu.gl_654
  0x6b680b0c, 0x030e2513, 0x13003f0e, 0x180a3107,   // es.ig.ceb_543 eu.is.nl_665  af.et.un_550 az.pt.ga_432
  // [6c70]
  0x020e0860, 0x1e005212, 0x35003b20, 0x0d001220,   // no.is.da_664 ha.ms.un_640  so.zu.un_850 hu.cs.un_850
  0x52004a19, 0x3f020605, 0x0d5304ad, 0x102509ee,   // yo.ha.un_750 de.da.af_333  fi.ht.cs_643 pl.eu.lt_422
  0x3f090409, 0x3500532a, 0x25062b04, 0x19000505,   // fi.pl.af_444 ht.zu.un_970  vi.de.eu_332 fr.gl.un_330
  0x21003f02, 0x03001f0b, 0x1a003107, 0x1006090b,   // af.jw.un_220 cy.nl.un_520  az.tl.un_420 pl.de.lt_542
  // [6c80]
  0x1e1c2bee, 0x1c201eaf, 0x1c111e04, 0x3f1105a7,   // vi.id.ms_422 ms.sq.id_655  ms.ro.id_332 fr.ro.af_532
  0x1a55250c, 0x281a01a7, 0x53280504, 0x280a20a6,   // eu.rw.tl_543 en.tl.sw_532  fr.sw.ht_332 sq.pt.sw_521
  0x6b6e68a0, 0x29002a0d, 0x0100071b, 0x2932170c,   // ig.hmn.ceb_322 mt.sl.un_540  it.en.un_770 sr.bs.sl_543
  0x191b0a07, 0x0500681b, 0x06003520, 0x130504a9,   // pt.tr.gl_432 ig.fr.un_770  zu.de.un_850 fi.fr.et_544
  // [6c90]
  0x030727a0, 0x6b003b1a, 0x2d00350d, 0x130411ee,   // gd.it.nl_322 so.ceb.un_760  zu.sk.un_540 ro.fi.et_422
  0x3b001114, 0x53002313, 0x64281208, 0x1c0405a0,   // ro.so.un_660 ca.ht.un_650  hu.sw.lg_443 fr.fi.id_322
  0x091f31ad, 0x03000412, 0x11130460, 0x05003b07,   // az.cy.pl_643 fi.nl.un_640  fi.et.ro_664 so.fr.un_420
  0x35005212, 0x180b6ba0, 0x21002a19, 0x130452ad,   // ha.zu.un_640 ceb.es.ga_322  mt.jw.un_750 ha.fi.et_643
  // [6ca0]
  0x53001a04, 0x0500020b, 0x292d1f08, 0x01536402,   // tl.ht.un_320 da.fr.un_520  cy.sk.sl_443 lg.ht.en_222
  0x2a005202, 0x1c000729, 0x210e12a4, 0x17291008,   // ha.mt.un_220 it.id.un_960  hu.is.jw_433 lt.sl.sr_443
  0x0f3f10ec, 0x530609af, 0x11074a12, 0x2d091605,   // lt.af.lv_644 pl.de.ht_655  yo.it.ro_654 hr.pl.sk_333
  0x1a1053a0, 0x55002807, 0x0600080c, 0x05006b19,   // ht.lt.tl_322 sw.rw.un_420  no.de.un_530 ceb.fr.un_750
  // [6cb0]
  0x29020dee, 0x28010404, 0x041f09ec, 0x181f3b02,   // cs.da.sl_422 fi.en.sw_332  pl.cy.fi_644 so.cy.ga_222
  0x2a003b2a, 0x2a3f03ec, 0x072b01ee, 0x2800160e,   // so.mt.un_970 nl.af.mt_644  en.vi.it_422 hr.sw.un_550
  0x1900100c, 0x0c0e0b0c, 0x02005319, 0x0b0a55a4,   // lt.gl.un_530 es.is.sv_543  ht.da.un_750 rw.pt.es_433
  0x0e0a23a0, 0x525525a7, 0x132864a0, 0x08002807,   // ca.pt.is_322 eu.rw.ha_532  lg.sw.et_322 sw.no.un_420
  // [6cc0]
  0x28000807, 0x6b00280d, 0x52641a05, 0x1a2a53a7,   // no.sw.un_420 sw.ceb.un_540  tl.lg.ha_333 ht.mt.tl_532
  0x3f280f0c, 0x1a215208, 0x16006405, 0x1c281e0c,   // lv.sw.af_543 ha.jw.tl_443  lg.hr.un_330 ms.sw.id_543
  0x0a072da4, 0x09006b23, 0x3f040e07, 0x29071fee,   // sk.it.pt_433 ceb.pl.un_880  is.fi.af_432 cy.it.sl_422
  0x6b2a0607, 0x092804a4, 0x6e2a53af, 0x1e6b1c07,   // de.mt.ceb_432 fi.sw.pl_433  ht.mt.hmn_655 id.ceb.ms_432
  // [6cd0]
  0x0413350c, 0x530f0cad, 0x2a072704, 0x2d000a05,   // zu.et.fi_543 sv.lv.ht_643  gd.it.mt_332 pt.sk.un_330
  0x3f6803a4, 0x06002a02, 0x050c0909, 0x641b3113,   // nl.ig.af_433 mt.de.un_220  pl.sv.fr_444 az.tr.lg_665
  0x121604ad, 0x0a311112, 0x032a09ec, 0x292a0713,   // fi.hr.hu_643 ro.az.pt_654  pl.mt.nl_644 it.mt.sl_665
  0x35002111, 0x01640ba0, 0x2d00081a, 0x09550fa4,   // jw.zu.un_630 es.lg.en_322  no.sk.un_760 lv.rw.pl_433
  // [6ce0]
  0x090f06af, 0x3f1203a4, 0x13002807, 0x1e1c6bee,   // de.lv.pl_655 nl.hu.af_433  sw.et.un_420 ceb.id.ms_422
  0x1c1921ee, 0x181f1ca9, 0x1e1f2711, 0x2d002907,   // jw.gl.id_422 id.cy.ga_544  gd.cy.ms_653 sl.sk.un_420
  0x21275505, 0x6e0407a0, 0x251b2da4, 0x230f1807,   // rw.gd.jw_333 it.fi.hmn_322  sk.tr.eu_433 ga.lv.ca_432
  0x2a050eaf, 0x1b522113, 0x5300040c, 0x07062512,   // is.fr.mt_655 jw.ha.tr_665  fi.ht.un_530 eu.de.it_654
  // [6cf0]
  0x27000b13, 0x52641a0c, 0x2a0a23a9, 0x4a131b12,   // es.gd.un_650 tl.lg.ha_543  ca.pt.mt_544 tr.et.yo_654
  0x183f08a9, 0x2a002b0d, 0x0e002913, 0x043b1305,   // no.af.ga_544 vi.mt.un_540  sl.is.un_650 et.so.fi_333
  0x040610ec, 0x100604a4, 0x2b001a22, 0x322010a7,   // lt.de.fi_644 fi.de.lt_433  tl.vi.un_870 lt.sq.bs_532
  0x232519a4, 0x291f1e0b, 0x0c002107, 0x09002902,   // gl.eu.ca_433 ms.cy.sl_542  jw.sv.un_420 sl.pl.un_220
  // [6d00]
  0x1e002302, 0x0f103ba7, 0x3f3b3508, 0x132b210b,   // ca.ms.un_220 so.lt.lv_532  zu.so.af_443 jw.vi.et_542
  0x1b185212, 0x062031ad, 0x073f19a7, 0x071e1aee,   // ha.ga.tr_654 az.sq.de_643  gl.af.it_532 tl.ms.it_422
  0x02000607, 0x322d1609, 0x32100107, 0x0f072aa4,   // de.da.un_420 hr.sk.bs_444  en.lt.bs_432 mt.it.lv_433
  0x64553f07, 0x190a2005, 0x19680d07, 0x2a003f12,   // af.rw.lg_432 sq.pt.gl_333  cs.ig.gl_432 af.mt.un_640
  // [6d10]
  0x131135a4, 0x323504ee, 0x3f4a0313, 0x043b1e11,   // zu.ro.et_433 fi.zu.bs_422  nl.yo.af_665 ms.so.fi_653
  0x21204aa6, 0x1f2d0d0d, 0x183b6804, 0x4a553b12,   // yo.sq.jw_521 cs.sk.cy_554  ig.so.ga_332 so.rw.yo_654
  0x133b2813, 0x6800282a, 0x042d0fa4, 0x040c065a,   // sw.so.et_665 sw.ig.un_970  lv.sk.fi_433 de.sv.fi_553
  0x030213ad, 0x2a003f21, 0x68552804, 0x02080c0d,   // et.da.nl_643 af.mt.un_860  sw.rw.ig_332 sv.no.da_554
  // [6d20]
  0x0b3f10a4, 0x3f02180c, 0x55110ba0, 0x061225ee,   // lt.af.es_433 ga.da.af_543  es.ro.rw_322 eu.hu.de_422
  0x23051aa4, 0x6b1a2a0c, 0x06000312, 0x09100ca0,   // tl.fr.ca_433 mt.tl.ceb_543  nl.de.un_640 sv.lt.pl_322
  0x275564ac, 0x021f080c, 0x3b0413a0, 0x12111905,   // lg.rw.gd_632 no.cy.da_543  et.fi.so_322 gl.ro.hu_333
  0x3f133b05, 0x08063f13, 0x0b0519ee, 0x06032013,   // so.et.af_333 af.de.no_665  gl.fr.es_422 sq.nl.de_665
  // [6d30]
  0x353f2813, 0x1a3b5305, 0x03533bee, 0x10000605,   // sw.af.zu_665 ht.so.tl_333  so.ht.nl_422 de.lt.un_330
  0x16320304, 0x0c060813, 0x03533fa0, 0x04001b19,   // nl.bs.hr_332 no.de.sv_665  af.ht.nl_322 tr.fi.un_750
  0x06133fa9, 0x11000b1b, 0x1a276b09, 0x1a076b07,   // af.et.de_544 es.ro.un_770  ceb.gd.tl_444 ceb.it.tl_432
  0x52080c13, 0x080e520b, 0x01212d0c, 0x1b230cee,   // sv.no.ha_665 ha.is.no_542  sk.jw.en_543 sv.ca.tr_422
  // [6d40]
  0x0d000607, 0x211a2b07, 0x6b003b04, 0x19000d08,   // de.cs.un_420 vi.tl.jw_432  so.ceb.un_320 cs.gl.un_430
  0x3b35200c, 0x08000a21, 0x120b05af, 0x271c1e0c,   // sq.zu.so_543 mk.uk.un_860  fr.es.hu_655 ms.id.gd_543
  0x06251f60, 0x07006b0e, 0x011b0507, 0x03201707,   // cy.eu.de_664 ceb.it.un_550  fr.tr.en_432 sr.sq.nl_432
  0x13001609, 0x2d0d050e, 0x356468a9, 0x53162913,   // hr.et.un_440 fr.cs.sk_555  ig.lg.zu_544 sl.hr.ht_665
  // [6d50]
  0x126b52a0, 0x0d2d120b, 0x00001615, 0x0b001804,   // ha.ceb.hu_322 hu.sk.cs_542  hr.un.un_700 ga.es.un_320
  0x0b0a13ee, 0x230f0b07, 0x081f0208, 0x310f1207,   // et.pt.es_422 es.lv.ca_432  da.cy.no_443 hu.lv.az_432
  0x120a0d14, 0x010b0f0c, 0x02003f02, 0x021206ad,   // cs.pt.hu_666 lv.es.en_543  af.da.un_220 de.hu.da_643
  0x3216230c, 0x283b1ead, 0x27051b0c, 0x2a2007ec,   // ca.hr.bs_543 ms.so.sw_643  tr.fr.gd_543 it.sq.mt_644
  // [6d60]
  0x64011aa4, 0x2a121f0c, 0x53271808, 0x0a00120c,   // tl.en.lg_433 cy.hu.mt_543  ga.gd.ht_443 hu.pt.un_530
  0x1b041f08, 0x06121fa7, 0x3f06040c, 0x20006b12,   // cy.fi.tr_443 cy.hu.de_532  fi.de.af_543 ceb.sq.un_640
  0x040908af, 0x1e1c68a0, 0x0c532008, 0x19250bec,   // no.pl.fi_655 ig.id.ms_322  sq.ht.sv_443 es.eu.gl_644
  0x4a0253a4, 0x52283b0c, 0x07052aa9, 0x2500231a,   // ht.da.yo_433 so.sw.ha_543  mt.fr.it_544 ca.eu.un_760
  // [6d70]
  0x2b64050b, 0x0c000702, 0x190b31a0, 0x3f641f07,   // fr.lg.vi_542 it.sv.un_220  az.es.gl_322 cy.lg.af_432
  0x681828af, 0x04060805, 0x2d041f0c, 0x0d6b1aec,   // sw.ga.ig_655 no.de.fi_333  cy.fi.sk_543 tl.ceb.cs_644
  0x03061207, 0x551b280c, 0x211a28ad, 0x06283fa4,   // hu.de.nl_432 sw.tr.rw_543  sw.tl.jw_643 af.sw.de_433
  0x1b006407, 0x2a002913, 0x186b27ec, 0x0720215a,   // lg.tr.un_420 sl.mt.un_650  gd.ceb.ga_644 jw.sq.it_553
  // [6d80]
  0x10181f05, 0x535201a4, 0x6b683b0c, 0x68270608,   // cy.ga.lt_333 en.ha.ht_433  so.ig.ceb_543 de.gd.ig_443
  0x05032aee, 0x290209ad, 0x31002004, 0x08125205,   // mt.nl.fr_422 pl.da.sl_643  sq.az.un_320 ha.hu.no_333
  0x68271808, 0x0d201212, 0x6b533bee, 0x060327ad,   // ga.gd.ig_443 hu.sq.cs_654  so.ht.ceb_422 gd.nl.de_643
  0x212a53af, 0x68062809, 0x1a1227a9, 0x4a3b1109,   // ht.mt.jw_655 sw.de.ig_444  gd.hu.tl_544 ro.so.yo_444
  // [6d90]
  0x2a1f23af, 0x31295312, 0x105268a9, 0x53352808,   // ca.cy.mt_655 ht.sl.az_654  ig.ha.lt_544 sw.zu.ht_443
  0x536e2a14, 0x55284a12, 0x03280608, 0x2900210c,   // mt.hmn.ht_666 yo.sw.rw_654  de.sw.nl_443 jw.sl.un_530
  0x1e1c07af, 0x180968a4, 0x061a35a9, 0x041f130e,   // it.id.ms_655 ig.pl.ga_433  zu.tl.de_544 et.cy.fi_555
  0x2a114a12, 0x3f2a0e05, 0x05003b12, 0x086b68af,   // yo.ro.mt_654 is.mt.af_333  so.fr.un_640 ig.ceb.no_655
  // [6da0]
  0x3508060c, 0x01083555, 0x6420110c, 0x0b004a0d,   // de.no.zu_543 zu.no.en_442  ro.sq.lg_543 yo.es.un_540
  0x255504a7, 0x6b641ca4, 0x211a28a6, 0x32534aad,   // fi.rw.eu_532 id.lg.ceb_433  sw.tl.jw_521 yo.ht.bs_643
  0x040e1e0c, 0x3f212b0e, 0x0a182b1f, 0x3500091a,   // ms.is.fi_543 vi.jw.af_555  vi.ga.pt_864 pl.zu.un_760
  0x3f011f0d, 0x0b20050d, 0x01001802, 0x20000527,   // cy.en.af_554 fr.sq.es_554  ga.en.un_220 fr.sq.un_940
  // [6db0]
  0x042528ec, 0x104a6b07, 0x10006805, 0x32003b13,   // sw.eu.fi_644 ceb.yo.lt_432  ig.lt.un_330 so.bs.un_650
  0x0a0f0e08, 0x52001b22, 0x35132107, 0x3f000919,   // is.lv.pt_443 tr.ha.un_870  jw.et.zu_432 pl.af.un_750
  0x04000520, 0x16101704, 0x286b100c, 0x3f6b1aa0,   // fr.fi.un_850 sr.lt.hr_332  lt.ceb.sw_543 tl.ceb.af_322
  0x3f2301ee, 0x081f3f08, 0x02080c12, 0x211c6411,   // en.ca.af_422 af.cy.no_443  sv.no.da_654 lg.id.jw_653
  // [6dc0]
  0x0e352105, 0x080e020b, 0x3b682008, 0x3f121a55,   // jw.zu.is_333 da.is.no_542  sq.ig.so_443 tl.hu.af_442
  0x020c085a, 0x27311ea4, 0x68003b0e, 0x28350605,   // no.sv.da_553 ms.az.gd_433  so.ig.un_550 de.zu.sw_333
  0x643208ee, 0x282523a4, 0x21646b08, 0x283b4a08,   // no.bs.lg_422 ca.eu.sw_433  ceb.lg.jw_443 yo.so.sw_443
  0x64003f13, 0x03183fa4, 0x4a6b1ba4, 0x090802ee,   // af.lg.un_650 af.ga.nl_433  tr.ceb.yo_433 da.no.pl_422
  // [6dd0]
  0x352d290c, 0x281a07a9, 0x53081907, 0x2d060daf,   // sl.sk.zu_543 it.tl.sw_544  gl.no.ht_432 cs.de.sk_655
  0x35171aa4, 0x0f00251b, 0x040b1313, 0x172910a6,   // tl.sr.zu_433 eu.lv.un_770  et.es.fi_665 lt.sl.sr_521
  0x043f64ee, 0x03006b04, 0x190b4aa4, 0x6400080d,   // lg.af.fi_422 ceb.nl.un_320  yo.es.gl_433 no.lg.un_540
  0x080227ee, 0x04130cec, 0x04002a1b, 0x1a092811,   // gd.da.no_422 sv.et.fi_644  mt.fi.un_770 sw.pl.tl_653
  // [6de0]
  0x200c6eec, 0x32281a0c, 0x02080460, 0x04001808,   // hmn.sv.sq_644 tl.sw.bs_543  fi.no.da_664 ga.fi.un_430
  0x180631a0, 0x0d1a5305, 0x120913a9, 0x16002007,   // az.de.ga_322 ht.tl.cs_333  et.pl.hu_544 sq.hr.un_420
  0x2a004a08, 0x6e00200e, 0x10002d11, 0x0d202da9,   // yo.mt.un_430 sq.hmn.un_550  sk.lt.un_630 sk.sq.cs_544
  0x1b04520c, 0x53212312, 0x0e0f045a, 0x0d006807,   // ha.fi.tr_543 ca.jw.ht_654  fi.lv.is_553 ig.cs.un_420
  // [6df0]
  0x641b0409, 0x0d082da0, 0x13006402, 0x13001b02,   // fi.tr.lg_444 sk.no.cs_322  lg.et.un_220 tr.et.un_220
  0x645535af, 0x3b1827ad, 0x2a040a0c, 0x0a2105af,   // zu.rw.lg_655 gd.ga.so_643  pt.fi.mt_543 fr.jw.pt_655
  0x03131fa6, 0x35016412, 0x00001242, 0x231b0aad,   // cy.et.nl_521 lg.en.zu_654  ur.un.un_C00 pt.tr.ca_643
  0x2331250c, 0x29250d12, 0x4a643bad, 0x1e002a0b,   // eu.az.ca_543 cs.eu.sl_654  so.lg.yo_643 mt.ms.un_520
  // [6e00]
  0x3f643ba6, 0x06001a07, 0x13013b07, 0x684a3baf,   // so.lg.af_521 tl.de.un_420  so.en.et_432 so.yo.ig_655
  0x20536ba9, 0x066b1ca4, 0x04201307, 0x0b001a08,   // ceb.ht.sq_544 id.ceb.de_433  et.sq.fi_432 tl.es.un_430
  0x06001a0d, 0x4a53520c, 0x53003514, 0x555235a4,   // tl.de.un_540 ha.ht.yo_543  zu.ht.un_660 zu.ha.rw_433
  0x0e53010c, 0x0b0a19ec, 0x1b233109, 0x55003b1b,   // en.ht.is_543 gl.pt.es_644  az.ca.tr_444 so.rw.un_770
  // [6e10]
  0x136828ad, 0x020e2aa4, 0x27000704, 0x28080c12,   // sw.ig.et_643 mt.is.da_433  it.gd.un_320 sv.no.sw_654
  0x4a6828ec, 0x13211c09, 0x3b5255a9, 0x0a006e14,   // sw.ig.yo_644 id.jw.et_444  rw.ha.so_544 hmn.pt.un_660
  0x1a2952ee, 0x1b00681a, 0x6b002822, 0x2d280713,   // ha.sl.tl_422 ig.tr.un_760  sw.ceb.un_870 it.sw.sk_665
  0x2a1628ee, 0x20553ba9, 0x3f0327a4, 0x12001608,   // sw.hr.mt_422 so.rw.sq_544  gd.nl.af_433 hr.hu.un_430
  // [6e20]
  0x07006809, 0x520b1e07, 0x190b0109, 0x320f2907,   // ig.it.un_440 ms.es.ha_432  en.es.gl_444 sl.lv.bs_432
  0x35096405, 0x641a1313, 0x11000d16, 0x2a1a53a4,   // lg.pl.zu_333 et.tl.lg_665  cs.ro.un_720 ht.tl.mt_433
  0x21080209, 0x130419a7, 0x04072a12, 0x030f08a4,   // da.no.jw_444 gl.fi.et_532  mt.it.fi_654 no.lv.nl_433
  0x3f001a04, 0x190b2302, 0x211219a0, 0x0a0b19ee,   // tl.af.un_320 ca.es.gl_222  gl.hu.jw_322 gl.es.pt_422
  // [6e30]
  0x2d271808, 0x5200551a, 0x0d2908a7, 0x3229160e,   // ga.gd.sk_443 rw.ha.un_760  no.sl.cs_532 hr.sl.bs_555
  0x2a35190b, 0x25121b12, 0x29130405, 0x5232200c,   // gl.zu.mt_542 tr.hu.eu_654  fi.et.sl_333 sq.bs.ha_543
  0x04110808, 0x13352512, 0x4a1c1eec, 0x52215305,   // uk.ro.ru_443 eu.zu.et_654  ms.id.yo_644 ht.jw.ha_333
  0x0b181907, 0x2d0d55a0, 0x551b040c, 0x28002722,   // gl.ga.es_432 rw.cs.sk_322  fi.tr.rw_543 gd.sw.un_870
  // [6e40]
  0x041c4aa4, 0x09080c09, 0x00003b37, 0x2b322711,   // yo.id.fi_433 sv.no.pl_444  so.un.un_B00 gd.bs.vi_653
  0x4a550408, 0x082555a4, 0x1c0a1a0c, 0x270e280c,   // fi.rw.yo_443 rw.eu.no_433  tl.pt.id_543 sw.is.gd_543
  0x013552a0, 0x2b206eec, 0x200325ec, 0x13060da9,   // ha.zu.en_322 hmn.sq.vi_644  eu.nl.sq_644 cs.de.et_544
  0x3f0703a4, 0x280121a7, 0x09006822, 0x050f0714,   // nl.it.af_433 jw.en.sw_532  ig.pl.un_870 it.lv.fr_666
  // [6e50]
  0x133f21a4, 0x10001e04, 0x1c2921af, 0x3f642509,   // jw.af.et_433 ms.lt.un_320  jw.sl.id_655 eu.lg.af_444
  0x033f6812, 0x04172911, 0x2b211aec, 0x1c0c0208,   // ig.af.nl_654 sl.sr.fi_653  tl.jw.vi_644 da.sv.id_443
  0x1e000308, 0x35641c0c, 0x1b000f1b, 0x10312008,   // nl.ms.un_430 id.lg.zu_543  lv.tr.un_770 sq.az.lt_443
  0x55211f07, 0x3b005508, 0x0700121a, 0x52136b09,   // cy.jw.rw_432 rw.so.un_430  hu.it.un_760 ceb.et.ha_444
  // [6e60]
  0x1c00190e, 0x25191caf, 0x2700070e, 0x292025a6,   // gl.id.un_550 id.gl.eu_655  it.gd.un_550 eu.sq.sl_521
  0x215213a4, 0x532a2007, 0x1c212b0d, 0x281a6ba9,   // et.ha.jw_433 sq.mt.ht_432  vi.jw.id_554 ceb.tl.sw_544
  0x13072004, 0x27000713, 0x1a522ba7, 0x200f1108,   // sq.it.et_332 it.gd.un_650  vi.ha.tl_532 ro.lv.sq_443
  0x4a1819ee, 0x080c0213, 0x20071205, 0x05201f07,   // gl.ga.yo_422 da.sv.no_665  hu.it.sq_333 cy.sq.fr_432
  // [6e70]
  0x520f210c, 0x051b0313, 0x280f64a4, 0x101764ee,   // jw.lv.ha_543 nl.tr.fr_665  lg.lv.sw_433 lg.sr.lt_422
  0x251b2a09, 0x05003f0b, 0x52284aee, 0x07002812,   // mt.tr.eu_444 af.fr.un_520  yo.sw.ha_422 sw.it.un_640
  0x28106408, 0x1b2025ac, 0x120a180b, 0x642831af,   // lg.lt.sw_443 eu.sq.tr_632  ga.pt.hu_542 az.sw.lg_655
  0x190b28af, 0x0a042704, 0x21002320, 0x102304a7,   // sw.es.gl_655 gd.fi.pt_332  ca.jw.un_850 fi.ca.lt_532
  // [6e80]
  0x52091f04, 0x1b132a04, 0x28522055, 0x1b013fad,   // cy.pl.ha_332 mt.et.tr_332  sq.ha.sw_442 af.en.tr_643
  0x55000612, 0x32160405, 0x20080408, 0x0e136408,   // de.rw.un_640 fi.hr.bs_333  fi.no.sq_443 lg.et.is_443
  0x53190b09, 0x170811ad, 0x0e2820ac, 0x251e64a0,   // es.gl.ht_444 ro.uk.sr_643  sq.sw.is_632 lg.ms.eu_322
  0x06001c07, 0x190564a0, 0x531b0512, 0x641b050d,   // id.de.un_420 lg.fr.gl_322  fr.tr.ht_654 fr.tr.lg_554
  // [6e90]
  0x5500030e, 0x313b280d, 0x68191208, 0x020621ec,   // nl.rw.un_550 sw.so.az_554  hu.gl.ig_443 jw.de.da_644
  0x0500190b, 0x321620a4, 0x3216130c, 0x10002304,   // gl.fr.un_520 sq.hr.bs_433  et.hr.bs_543 ca.lt.un_320
  0x043f0809, 0x3b0602a9, 0x321731a0, 0x112005af,   // no.af.fi_444 da.de.so_544  az.sr.bs_322 fr.sq.ro_655
  0x120d0f05, 0x02001e04, 0x121b3f55, 0x0f0e55ec,   // lv.cs.hu_333 ms.da.un_320  af.tr.hu_442 rw.is.lv_644
  // [6ea0]
  0x311b3f08, 0x1c1a21a4, 0x3100130e, 0x04253512,   // af.tr.az_443 jw.tl.id_433  et.az.un_550 zu.eu.fi_654
  0x1b313faf, 0x190b2d0c, 0x1b003f12, 0x551f6bac,   // af.az.tr_655 sk.es.gl_543  af.tr.un_640 ceb.cy.rw_632
  0x0b0d01a4, 0x20531c0c, 0x1e1c3bee, 0x52000d21,   // en.cs.es_433 id.ht.sq_543  so.id.ms_422 cs.ha.un_860
  0x1e00350d, 0x1e041cee, 0x06111307, 0x55290dad,   // zu.ms.un_540 id.fi.ms_422  et.ro.de_432 cs.sl.rw_643
  // [6eb0]
  0x092a3507, 0x0b0a1f05, 0x1819010c, 0x1100011a,   // zu.mt.pl_432 cy.pt.es_333  en.gl.ga_543 en.ro.un_760
  0x06083f08, 0x06551307, 0x27201e0c, 0x0c2912ec,   // af.no.de_443 et.rw.de_432  ms.sq.gd_543 hu.sl.sv_644
  0x1c1a1e04, 0x6b2104ee, 0x21000f0c, 0x172007ee,   // ms.tl.id_332 fi.jw.ceb_422  lv.jw.un_530 it.sq.sr_422
  0x210f6807, 0x13000f09, 0x3f321609, 0x3f02100c,   // ig.lv.jw_432 lv.et.un_440  hr.bs.af_444 lt.da.af_543
  // [6ec0]
  0x0c000f0c, 0x100817ec, 0x01310cee, 0x1a00640e,   // lv.sv.un_530 sr.uk.be_644  sv.az.en_422 lg.tl.un_550
  0x20000c18, 0x0900210d, 0x0b190aee, 0x0a1b1c0b,   // sv.sq.un_740 jw.pl.un_540  pt.gl.es_422 id.tr.pt_542
  0x3f00080e, 0x250f2908, 0x2a18115a, 0x2d000808,   // no.af.un_550 sl.lv.eu_443  ro.ga.mt_553 no.sk.un_430
  0x250f08a4, 0x640452a7, 0x162a1ea4, 0x0f3202a9,   // no.lv.eu_433 ha.fi.lg_532  ms.mt.hr_433 da.bs.lv_544
  // [6ed0]
  0x686428af, 0x55044a09, 0x121906ad, 0x09291713,   // sw.lg.ig_655 yo.fi.rw_444  de.gl.hu_643 sr.sl.pl_665
  0x050255af, 0x2a13255a, 0x13060cec, 0x122523a4,   // rw.da.fr_655 eu.et.mt_553  sv.de.et_644 ca.eu.hu_433
  0x0b190a5a, 0x31292d09, 0x1e003102, 0x080212a0,   // pt.gl.es_553 sk.sl.az_444  az.ms.un_220 hu.da.no_322
  0x312d2913, 0x2d0d1902, 0x200511a0, 0x13003504,   // sl.sk.az_665 gl.cs.sk_222  ro.fr.sq_322 zu.et.un_320
  // [6ee0]
  0x29002d2a, 0x100f020b, 0x02051305, 0x31292d12,   // sk.sl.un_970 da.lv.lt_542  et.fr.da_333 sk.sl.az_654
  0x5500011a, 0x0e2a23ec, 0x28182a13, 0x01130507,   // en.rw.un_760 ca.mt.is_644  mt.ga.sw_665 fr.et.en_432
  0x29312d13, 0x316e2da6, 0x1306250c, 0x31292dac,   // sk.az.sl_665 sk.hmn.az_521  eu.de.et_543 sk.sl.az_632
  0x190a07ee, 0x13000d22, 0x355528a4, 0x012a1fa0,   // it.pt.gl_422 ne.bh.un_870  sw.rw.zu_433 cy.mt.en_322
  // [6ef0]
  0x09645502, 0x0f6e290b, 0x1600210b, 0x124a5209,   // rw.lg.pl_222 sl.hmn.lv_542  jw.hr.un_520 ha.yo.hu_444
  0x64070ead, 0x205329ec, 0x292a11a7, 0x061b3fa0,   // is.it.lg_643 sl.ht.sq_644  ro.mt.sl_532 af.tr.de_322
  0x0d0804a9, 0x130c28a4, 0x0a192bb2, 0x2103280c,   // fi.no.cs_544 sw.sv.et_433  vi.gl.pt_732 sw.nl.jw_543
  0x1e005512, 0x09003207, 0x1c0d0904, 0x2d005334,   // rw.ms.un_640 bs.pl.un_420  hi.ne.mr_332 ht.sk.un_A80
  // [6f00]
  0x0f2920ec, 0x2800022a, 0x02121bee, 0x1f00210b,   // sq.sl.lv_644 da.sw.un_970  tr.hu.da_422 jw.cy.un_520
  0x3100292b, 0x072b2aa0, 0x6b355512, 0x2d3f0305,   // sl.az.un_980 mt.vi.it_322  rw.zu.ceb_654 nl.af.sk_333
  0x0a072308, 0x0f0c0904, 0x3f283b12, 0x2100641a,   // ca.it.pt_443 pl.sv.lv_332  so.sw.af_654 lg.jw.un_760
  0x0b041012, 0x283f0912, 0x0e201008, 0x06100305,   // lt.fi.es_654 pl.af.sw_654  lt.sq.is_443 nl.lt.de_333
  // [6f10]
  0x350655ad, 0x55131ea0, 0x551b28ad, 0x643f2112,   // rw.de.zu_643 ms.et.rw_322  sw.tr.rw_643 jw.af.lg_654
  0x090c1e0c, 0x234a1907, 0x210806ad, 0x35286402,   // ms.sv.pl_543 gl.yo.ca_432  de.no.jw_643 lg.sw.zu_222
  0x2a1a28a9, 0x11040faf, 0x55070fad, 0x09110f0c,   // sw.tl.mt_544 lv.fi.ro_655  lv.it.rw_643 lv.ro.pl_543
  0x2a001302, 0x2917100c, 0x200a1ba4, 0x550c6ba4,   // et.mt.un_220 lt.sr.sl_543  tr.pt.sq_433 ceb.sv.rw_433
  // [6f20]
  0x1a20520d, 0x23060e11, 0x1b523113, 0x2520520c,   // ha.sq.tl_554 is.de.ca_653  az.ha.tr_665 ha.sq.eu_543
  0x194a2d04, 0x211f35a0, 0x042552af, 0x52000d04,   // sk.yo.gl_332 zu.cy.jw_322  ha.eu.fi_655 cs.ha.un_320
  0x1f4a52ec, 0x4a3b520c, 0x531f35ad, 0x0925210c,   // ha.yo.cy_644 ha.so.yo_543  zu.cy.ht_643 jw.eu.pl_543
  0x182d0a07, 0x4a3152ec, 0x19111308, 0x31233b0c,   // pt.sk.ga_432 ha.az.yo_644  et.ro.gl_443 so.ca.az_543
  // [6f30]
  0x1c3b4aad, 0x0d31045a, 0x03095305, 0x0613010c,   // yo.so.id_643 fi.az.cs_553  ht.pl.nl_333 en.et.de_543
  0x27000505, 0x286421ad, 0x04003121, 0x21045508,   // fr.gd.un_330 jw.lg.sw_643  az.fi.un_860 rw.fi.jw_443
  0x2913350c, 0x29251bec, 0x12002d23, 0x350e645a,   // zu.et.sl_543 tr.eu.sl_644  sk.hu.un_880 lg.is.zu_553
  0x08021305, 0x3b2a31ac, 0x0c5511a7, 0x131f200c,   // et.da.no_333 az.mt.so_632  ro.rw.sv_532 sq.cy.et_543
  // [6f40]
  0x53311a14, 0x0d35295a, 0x6e133113, 0x31131e07,   // tl.az.ht_666 sl.zu.cs_553  az.et.hmn_665 ms.et.az_432
  0x5301190c, 0x05001107, 0x1e132aaf, 0x250413a6,   // gl.en.ht_543 ro.fr.un_420  mt.et.ms_655 et.fi.eu_521
  0x31521e0c, 0x53281b13, 0x0f001005, 0x3b316e08,   // ms.ha.az_543 tr.sw.ht_665  lt.lv.un_330 hmn.az.so_443
  0x181135ad, 0x13213112, 0x1f136ea9, 0x0f1132a0,   // zu.ro.ga_643 az.jw.et_654  hmn.et.cy_544 bs.ro.lv_322
  // [6f50]
  0x1c041e07, 0x28160f04, 0x05000807, 0x09002309,   // ms.fi.id_432 lv.hr.sw_332  no.fr.un_420 ca.pl.un_440
  0x2d0d0709, 0x282d0d12, 0x08003519, 0x0a00190b,   // it.cs.sk_444 cs.sk.sw_654  zu.no.un_750 gl.pt.un_520
  0x0e003107, 0x080213a9, 0x320728a0, 0x2d0e2aa4,   // az.is.un_420 et.da.no_544  sw.it.bs_322 mt.is.sk_433
  0x07110b0c, 0x1b133113, 0x131b3508, 0x531b5555,   // es.ro.it_543 az.et.tr_665  zu.tr.et_443 rw.tr.ht_442
  // [6f60]
  0x321708a0, 0x5200030c, 0x312a1fad, 0x20551104,   // no.sr.bs_322 nl.ha.un_530  cy.mt.az_643 ro.rw.sq_332
  0x0d1c13ec, 0x3f002312, 0x1f002807, 0x021a6bee,   // bh.mr.ne_644 ca.af.un_640  sw.cy.un_420 ceb.tl.da_422
  0x091725a6, 0x4a1153a0, 0x2b184a02, 0x09002812,   // eu.sr.pl_521 ht.ro.yo_322  yo.ga.vi_222 sw.pl.un_640
  0x11004a04, 0x16002507, 0x0d000813, 0x526425a4,   // yo.ro.un_320 eu.hr.un_420  no.cs.un_650 eu.lg.ha_433
  // [6f70]
  0x1c110a02, 0x2a040712, 0x3b535512, 0x0b0220a7,   // pt.ro.id_222 it.fi.mt_654  rw.ht.so_654 sq.da.es_532
  0x061f23a4, 0x1a6807a7, 0x64286802, 0x55282514,   // ca.cy.de_433 it.ig.tl_532  ig.sw.lg_222 eu.sw.rw_666
  0x5200252a, 0x3f256412, 0x03001320, 0x531b250e,   // eu.ha.un_970 lg.eu.af_654  et.nl.un_850 eu.tr.ht_555
  0x190b25ec, 0x32311e05, 0x134a6409, 0x10130407,   // eu.es.gl_644 ms.az.bs_333  lg.yo.et_444 fi.et.lt_432
  // [6f80]
  0x18232dac, 0x04200fad, 0x521b25ee, 0x3f001e21,   // sk.ca.ga_632 lv.sq.fi_643  eu.tr.ha_422 ms.af.un_860
  0x1b0b53ee, 0x3b351aad, 0x171f32ee, 0x211c3f12,   // ht.es.tr_422 tl.zu.so_643  bs.cy.sr_422 af.id.jw_654
  0x35004a02, 0x3f25030d, 0x05000c04, 0x25003f1a,   // yo.zu.un_220 nl.eu.af_554  sv.fr.un_320 af.eu.un_760
  0x350208ac, 0x08211b08, 0x2d0d13af, 0x040e52a4,   // no.da.zu_632 tr.jw.no_443  et.cs.sk_655 ha.is.fi_433
  // [6f90]
  0x080252a9, 0x1b020307, 0x1c064aa6, 0x0e181fad,   // ha.da.no_544 nl.da.tr_432  yo.de.id_521 cy.ga.is_643
  0x111c1e0c, 0x040655ec, 0x182752a9, 0x270e53ad,   // ms.id.ro_543 rw.de.fi_644  ha.gd.ga_544 ht.is.gd_643
  0x200f0608, 0x013f64a6, 0x1002040c, 0x18005209,   // de.lv.sq_443 lg.af.en_521  fi.da.lt_543 ha.ga.un_440
  0x0e275307, 0x3f030a11, 0x28686e0b, 0x0c5308a4,   // ht.gd.is_432 pt.nl.af_653  hmn.ig.sw_542 no.ht.sv_433
  // [6fa0]
  0x55061e0c, 0x18130612, 0x080255a0, 0x0a0811a6,   // ms.de.rw_543 de.et.ga_654  rw.da.no_322 ro.uk.mk_521
  0x5500040d, 0x010f0302, 0x16092912, 0x0c10290c,   // fi.rw.un_540 nl.lv.en_222  sl.pl.hr_654 sl.lt.sv_543
  0x2d030611, 0x25006e0b, 0x131011a0, 0x180c3fa4,   // de.nl.sk_653 hmn.eu.un_520  ro.lt.et_322 af.sv.ga_433
  0x1a000423, 0x1e091005, 0x092912ec, 0x23002104,   // fi.tl.un_880 lt.pl.ms_333  hu.sl.pl_644 jw.ca.un_320
  // [6fb0]
  0x3b1f640c, 0x076b1aa9, 0x17162da0, 0x23050e0e,   // lg.cy.so_543 tl.ceb.it_544  sk.hr.sr_322 is.fr.ca_555
  0x063f0205, 0x1f1b0205, 0x1e0e1ca4, 0x08070209,   // da.af.de_333 da.tr.cy_333  id.is.ms_433 da.it.no_444
  0x1e002907, 0x311b18af, 0x0f2a3fa4, 0x190b1eaf,   // sl.ms.un_420 ga.tr.az_655  af.mt.lv_433 ms.es.gl_655
  0x310e080c, 0x251607a4, 0x32041cee, 0x04005212,   // no.is.az_543 it.hr.eu_433  id.fi.bs_422 ha.fi.un_640
  // [6fc0]
  0x320a3108, 0x2804550c, 0x3b3119ee, 0x6b1a0712,   // az.pt.bs_443 rw.fi.sw_543  gl.az.so_422 it.tl.ceb_654
  0x213b1fec, 0x06120207, 0x352507af, 0x23310ead,   // cy.so.jw_644 da.hu.de_432  it.eu.zu_655 is.az.ca_643
  0x0e311ea4, 0x4a002317, 0x211b1eaf, 0x3f286804,   // ms.az.is_433 ca.yo.un_730  ms.tr.jw_655 ig.sw.af_332
  0x1b002007, 0x1f52130c, 0x0f002d0d, 0x0d2d290b,   // sq.tr.un_420 et.ha.cy_543  sk.lv.un_540 sl.sk.cs_542
  // [6fd0]
  0x1a536404, 0x012864a4, 0x0e001804, 0x1e001b13,   // lg.ht.tl_332 lg.sw.en_433  ga.is.un_320 tr.ms.un_650
  0x040c13a0, 0x35250604, 0x1f0e0408, 0x172868a0,   // et.sv.fi_322 de.eu.zu_332  fi.is.cy_443 ig.sw.sr_322
  0x6b1a04a4, 0x17001b07, 0x3b00271a, 0x04002304,   // fi.tl.ceb_433 tr.sr.un_420  gd.so.un_760 ca.fi.un_320
  0x04271160, 0x04000829, 0x3f0e040c, 0x041f0e11,   // ro.gd.fi_664 uk.ru.un_960  fi.is.af_543 is.cy.fi_653
  // [6fe0]
  0x6e53290c, 0x190a3b05, 0x120c0e05, 0x2d290da0,   // sl.ht.hmn_543 so.pt.gl_333  is.sv.hu_333 cs.sl.sk_322
  0x2d090d13, 0x040503a4, 0x05040612, 0x3b4a355a,   // cs.pl.sk_665 nl.fr.fi_433  de.fi.fr_654 zu.yo.so_553
  0x2505040b, 0x1113530c, 0x090d17ad, 0x11001221,   // fi.fr.eu_542 ht.et.ro_543  sr.cs.pl_643 hu.ro.un_860
  0x1c531eee, 0x1b023104, 0x12354a12, 0x641035ad,   // ms.ht.id_422 az.da.tr_332  yo.zu.hu_654 zu.lt.lg_643
  // [6ff0]
  0x0d131c13, 0x28004a0c, 0x1006210c, 0x0b5255ee,   // mr.bh.ne_665 yo.sw.un_530  jw.de.lt_543 rw.ha.es_422
  0x2d120d0c, 0x641a6bec, 0x1e1c05ee, 0x0b0a12ee,   // cs.hu.sk_543 ceb.tl.lg_644  fr.id.ms_422 hu.pt.es_422
  0x201f2d0c, 0x20002d0d, 0x2a002502, 0x1125100c,   // sk.cy.sq_543 sk.sq.un_540  eu.mt.un_220 lt.eu.ro_543
  0x17004a05, 0x4a2011ad, 0x0400530e, 0x0e006404,   // yo.sr.un_330 ro.sq.yo_643  ht.fi.un_550 lg.is.un_320

  // [7000]
  0x1c0b5305, 0x2b004a07, 0x3b002504, 0x6b352aa9,   // ht.es.id_333 yo.vi.un_420  eu.so.un_320 mt.zu.ceb_544
  0x1f090ea4, 0x0b091109, 0x041f4aa7, 0x3b00130c,   // is.pl.cy_433 ro.pl.es_444  yo.cy.fi_532 et.so.un_530
  0x09000408, 0x1a4a6bee, 0x4a286460, 0x033b3f13,   // fi.pl.un_430 ceb.yo.tl_422  lg.sw.yo_664 af.so.nl_665
  0x6412280c, 0x213120ec, 0x23000a21, 0x1c0f52ee,   // sw.hu.lg_543 sq.az.jw_644  pt.ca.un_860 ha.lv.id_422
  // [7010]
  0x0f082007, 0x213b640e, 0x0c2a4a08, 0x6b005521,   // sq.no.lv_432 lg.so.jw_555  yo.mt.sv_443 rw.ceb.un_860
  0x3f3b6807, 0x4a641b5a, 0x133b0407, 0x3b3f13ad,   // ig.so.af_432 tr.lg.yo_553  fi.so.et_432 et.af.so_643
  0x13043f12, 0x0e2105a6, 0x0f021a08, 0x53040d14,   // af.fi.et_654 fr.jw.is_521  tl.da.lv_443 cs.fi.ht_666
  0x1a3110a9, 0x55042a08, 0x351a100d, 0x356b53a4,   // lt.az.tl_544 mt.fi.rw_443  lt.tl.zu_554 ht.ceb.zu_433
  // [7020]
  0x20212dee, 0x1a5510a9, 0x182a2007, 0x3252100c,   // sk.jw.sq_422 lt.rw.tl_544  sq.mt.ga_432 lt.ha.bs_543
  0x1a006e09, 0x531a2a05, 0x2b003202, 0x07000b0e,   // hmn.tl.un_440 mt.tl.ht_333  bs.vi.un_220 es.it.un_550
  0x2d530d12, 0x181f23ad, 0x311b100c, 0x2d0d53a9,   // cs.ht.sk_654 ca.cy.ga_643  lt.tr.az_543 ht.cs.sk_544
  0x1f2109ad, 0x1b3110ec, 0x101b310d, 0x531b10a4,   // pl.jw.cy_643 lt.az.tr_644  az.tr.lt_554 lt.tr.ht_433
  // [7030]
  0x130f1112, 0x64000804, 0x0800050b, 0x2a641f55,   // ro.lv.et_654 no.lg.un_320  fr.no.un_520 cy.lg.mt_442
  0x1c004a19, 0x10006b07, 0x2a003b19, 0x19002807,   // yo.id.un_750 ceb.lt.un_420  so.mt.un_750 sw.gl.un_420
  0x1a0228a4, 0x0c3f080c, 0x28252aaf, 0x10011102,   // sw.da.tl_433 no.af.sv_543  mt.eu.sw_655 ro.en.lt_222
  0x1e101ca4, 0x0c060a0c, 0x2d000e07, 0x3500290b,   // id.lt.ms_433 pt.de.sv_543  is.sk.un_420 sl.zu.un_520
  // [7040]
  0x5510350c, 0x04280fa4, 0x211b52ee, 0x1a2b55a7,   // zu.lt.rw_543 lv.sw.fi_433  ha.tr.jw_422 rw.vi.tl_532
  0x21001f09, 0x64285305, 0x351b640c, 0x16112a0c,   // cy.jw.un_440 ht.sw.lg_333  lg.tr.zu_543 mt.ro.hr_543
  0x232b0a11, 0x050b1ea4, 0x350f0e05, 0x131c09a9,   // pt.vi.ca_653 ms.es.fr_433  is.lv.zu_333 hi.mr.bh_544
  0x04001f29, 0x1c120fa4, 0x162917a4, 0x53291ea0,   // cy.fi.un_960 lv.hu.id_433  sr.sl.hr_433 ms.sl.ht_322
  // [7050]
  0x27001c07, 0x060a0e13, 0x21031e08, 0x190a28ec,   // id.gd.un_420 is.pt.de_665  ms.nl.jw_443 sw.pt.gl_644
  0x280b0aa4, 0x55282102, 0x27002102, 0x2b641207,   // pt.es.sw_433 jw.sw.rw_222  jw.gd.un_220 hu.lg.vi_432
  0x283208ee, 0x0b002323, 0x212d1c12, 0x2a005508,   // no.bs.sw_422 ca.es.un_880  id.sk.jw_654 rw.mt.un_430
  0x0a0d010c, 0x16001b08, 0x212820ec, 0x0c080ead,   // en.cs.pt_543 tr.hr.un_430  sq.sw.jw_644 is.no.sv_643
  // [7060]
  0x25063508, 0x1c210714, 0x192d0aad, 0x1e281ca0,   // zu.de.eu_443 it.jw.id_666  pt.sk.gl_643 id.sw.ms_322
  0x122528a4, 0x2d0d1ca4, 0x53074a08, 0x55002912,   // sw.eu.hu_433 id.cs.sk_433  yo.it.ht_443 sl.rw.un_640
  0x682864a4, 0x1b0d100c, 0x3f2d0fa7, 0x3217350c,   // lg.sw.ig_433 lt.cs.tr_543  lv.sk.af_532 zu.sr.bs_543
  0x290e0caf, 0x3f2d0308, 0x1a353f0c, 0x131c0908,   // sv.is.sl_655 nl.sk.af_443  af.zu.tl_543 hi.mr.bh_443
  // [7070]
  0x1b032dad, 0x3b07230c, 0x29002721, 0x55641aa7,   // sk.nl.tr_643 ca.it.so_543  gd.sl.un_860 tl.lg.rw_532
  0x3f041909, 0x251055ec, 0x1f643baf, 0x2d291708,   // gl.fi.af_444 rw.lt.eu_644  so.lg.cy_655 sr.sl.sk_443
  0x07002319, 0x1b641108, 0x060c20b4, 0x6b00111b,   // ca.it.un_750 ro.lg.tr_443  sq.sv.de_754 ro.ceb.un_770
  0x64551105, 0x521e21af, 0x1a00551a, 0x0b28535a,   // ro.rw.lg_333 jw.ms.ha_655  rw.tl.un_760 ht.sw.es_553
  // [7080]
  0x640c1314, 0x2a313502, 0x6b681aa4, 0x21060e05,   // et.sv.lg_666 zu.az.mt_222  tl.ig.ceb_433 is.de.jw_333
  0x02002a07, 0x21100f09, 0x2d324aee, 0x28203ba4,   // mt.da.un_420 lv.lt.jw_444  yo.bs.sk_422 so.sq.sw_433
  0x1c216e08, 0x2300072c, 0x350a5513, 0x0b1219a0,   // hmn.jw.id_443 it.ca.un_990  rw.pt.zu_665 gl.hu.es_322
  0x12103f08, 0x28001212, 0x074a1608, 0x03001702,   // af.lt.hu_443 hu.sw.un_640  hr.yo.it_443 sr.nl.un_220
  // [7090]
  0x25112313, 0x64192a04, 0x18004a04, 0x351a5204,   // ca.ro.eu_665 mt.gl.lg_332  yo.ga.un_320 ha.tl.zu_332
  0x1c2106a0, 0x23191113, 0x3b0e06a0, 0x2500180e,   // de.jw.id_322 ro.gl.ca_665  de.is.so_322 ga.eu.un_550
  0x530e55a4, 0x0e000d04, 0x08021f02, 0x070a0805,   // rw.is.ht_433 cs.is.un_320  cy.da.no_222 uk.mk.bg_333
  0x136b55ec, 0x52201ba4, 0x6b3b1aa4, 0x21190205,   // rw.ceb.et_644 tr.sq.ha_433  tl.so.ceb_433 da.gl.jw_333
  // [70a0]
  0x52070f0c, 0x02001708, 0x13001821, 0x13110e05,   // lv.it.ha_543 sr.da.un_430  ga.et.un_860 is.ro.et_333
  0x1b120cec, 0x3b1e110c, 0x11200707, 0x686b3ba4,   // sv.hu.tr_644 ro.ms.so_543  it.sq.ro_432 so.ceb.ig_433
  0x11022a0d, 0x0700351b, 0x53026eaf, 0x00000c37,   // mt.da.ro_554 zu.it.un_770  hmn.da.ht_655 sv.un.un_B00
  0x10070aad, 0x110e55a4, 0x081353a0, 0x03020755,   // mk.bg.be_643 rw.is.ro_433  ht.et.no_322 it.da.nl_442
  // [70b0]
  0x062507af, 0x3b4a200c, 0x2025060c, 0x31006e07,   // it.eu.de_655 sq.yo.so_543  de.eu.sq_543 hmn.az.un_420
  0x4a002d21, 0x6455250c, 0x35006804, 0x20002713,   // sk.yo.un_860 eu.rw.lg_543  ig.zu.un_320 gd.sq.un_650
  0x2d055312, 0x20292aee, 0x03000d08, 0x120e1112,   // ht.fr.sk_654 mt.sl.sq_422  cs.nl.un_430 ro.is.hu_654
  0x0f006b33, 0x323525ee, 0x2064070c, 0x1c551ea9,   // ceb.lv.un_A70 eu.zu.bs_422  it.lg.sq_543 ms.rw.id_544
  // [70c0]
  0x6b1a0708, 0x1a6b070c, 0x1e1c3514, 0x2b4a1cad,   // it.tl.ceb_443 it.ceb.tl_543  zu.id.ms_666 id.yo.vi_643
  0x10284a12, 0x55041313, 0x043b2010, 0x2a00050c,   // yo.sw.lt_654 et.fi.rw_665  sq.so.fi_642 fr.mt.un_530
  0x18001313, 0x1a0c1b0c, 0x190e0ba4, 0x0e001807,   // et.ga.un_650 tr.sv.tl_543  es.is.gl_433 ga.is.un_420
  0x11130404, 0x55526413, 0x0e1b1f55, 0x0c003b12,   // fi.et.ro_332 lg.ha.rw_665  cy.tr.is_442 so.sv.un_640
  // [70d0]
  0x53001f02, 0x1a1b4aad, 0x04003202, 0x191a0708,   // cy.ht.un_220 yo.tr.tl_643  bs.fi.un_220 it.tl.gl_443
  0x0d1c1313, 0x2913170c, 0x190b18af, 0x070c2a13,   // bh.mr.ne_665 sr.et.sl_543  ga.es.gl_655 mt.sv.it_665
  0x1a4a640c, 0x04130312, 0x29000405, 0x21001e18,   // lg.yo.tl_543 nl.et.fi_654  fi.sl.un_330 ms.jw.un_740
  0x16003504, 0x091f3faf, 0x27044a02, 0x020c1c05,   // zu.hr.un_320 af.cy.pl_655  yo.fi.gd_222 id.sv.da_333
  // [70e0]
  0x03096412, 0x05072a13, 0x190b1f09, 0x190b35ec,   // lg.pl.nl_654 mt.it.fr_665  cy.es.gl_444 zu.es.gl_644
  0x0f001c0b, 0x29033f09, 0x1e1c4aa9, 0x105535a4,   // id.lv.un_520 af.nl.sl_444  yo.id.ms_544 zu.rw.lt_433
  0x281f010c, 0x1f311b09, 0x2a00032a, 0x52002829,   // en.cy.sw_543 tr.az.cy_444  nl.mt.un_970 sw.ha.un_960
  0x2910120c, 0x2a5507ad, 0x533135a7, 0x19230b60,   // hu.lt.sl_543 it.rw.mt_643  zu.az.ht_532 es.ca.gl_664
  // [70f0]
  0x55000e23, 0x031c3b12, 0x1c0219a7, 0x0c0e1bec,   // is.rw.un_880 so.id.nl_654  gl.da.id_532 tr.is.sv_644
  0x0e00520c, 0x121809ec, 0x1e3f1c0c, 0x1e1c11a4,   // ha.is.un_530 pl.ga.hu_644  id.af.ms_543 ro.id.ms_433
  0x041a1b0c, 0x21202ba0, 0x165564ad, 0x2364280c,   // tr.tl.fi_543 vi.sq.jw_322  lg.rw.hr_643 sw.lg.ca_543
  0x2a0e28a6, 0x535564ec, 0x28684aac, 0x351a52af,   // sw.is.mt_521 lg.rw.ht_644  yo.ig.sw_632 ha.tl.zu_655
  // [7100]
  0x2a0731a9, 0x1c521fa0, 0x20286408, 0x1c0e1eee,   // az.it.mt_544 cy.ha.id_322  lg.sw.sq_443 ms.is.id_422
  0x1a0453ec, 0x10353fa0, 0x525504a4, 0x25063ba4,   // ht.fi.tl_644 af.zu.lt_322  fi.rw.ha_433 so.de.eu_433
  0x3200350d, 0x3f2a230c, 0x033f1c12, 0x20022a5a,   // zu.bs.un_540 ca.mt.af_543  id.af.nl_654 mt.da.sq_553
  0x530f5507, 0x1a002107, 0x6455100d, 0x172935ac,   // rw.lv.ht_432 jw.tl.un_420  lt.rw.lg_554 zu.sl.sr_632
  // [7110]
  0x68001a0c, 0x070a1aec, 0x0b00270b, 0x13552813,   // tl.ig.un_530 tl.pt.it_644  gd.es.un_520 sw.rw.et_665
  0x2a0721a4, 0x646b1e0c, 0x05001217, 0x1f0a4aad,   // jw.it.mt_433 ms.ceb.lg_543  hu.fr.un_730 yo.pt.cy_643
  0x3f000612, 0x53001e12, 0x20000605, 0x23000d19,   // de.af.un_640 ms.ht.un_640  de.sq.un_330 cs.ca.un_750
  0x321b2dee, 0x6b091a14, 0x09190b13, 0x1f031ea4,   // sk.tr.bs_422 tl.pl.ceb_666  es.gl.pl_665 ms.nl.cy_433
  // [7120]
  0x20001707, 0x25063f08, 0x4a016ba4, 0x2052550c,   // sr.sq.un_420 af.de.eu_443  ceb.en.yo_433 rw.ha.sq_543
  0x182a10a0, 0x1c1f1e0c, 0x52310ea7, 0x113b0309,   // lt.mt.ga_322 ms.cy.id_543  is.az.ha_532 nl.so.ro_444
  0x1655030c, 0x315368a9, 0x0c1e1c09, 0x1b3b1305,   // nl.rw.hr_543 ig.ht.az_544  id.ms.sv_444 et.so.tr_333
  0x08022dee, 0x06002113, 0x21031313, 0x02003b13,   // sk.da.no_422 jw.de.un_650  et.nl.jw_665 so.da.un_650
  // [7130]
  0x11530612, 0x6b1a6408, 0x05000b09, 0x10062aec,   // de.ht.ro_654 lg.tl.ceb_443  es.fr.un_440 mt.de.lt_644
  0x6b092da0, 0x3b001808, 0x1c641e07, 0x092d0fee,   // sk.pl.ceb_322 ga.so.un_430  ms.lg.id_432 lv.sk.pl_422
  0x55283bad, 0x11005304, 0x1f276ba7, 0x3b12100d,   // so.sw.rw_643 ht.ro.un_320  ceb.gd.cy_532 lt.hu.so_554
  0x0a1027a7, 0x29000522, 0x64004a13, 0x64284aad,   // gd.lt.pt_532 fr.sl.un_870  yo.lg.un_650 yo.sw.lg_643
  // [7140]
  0x082927a0, 0x29053fa0, 0x13001804, 0x525531ee,   // gd.sl.no_322 af.fr.sl_322  ga.et.un_320 az.rw.ha_422
  0x072b010c, 0x2a050fa4, 0x2a252104, 0x03001b19,   // en.vi.it_543 lv.fr.mt_433  jw.eu.mt_332 tr.nl.un_750
  0x6b000111, 0x1e1c53af, 0x07520e08, 0x29086ea0,   // en.ceb.un_630 ht.id.ms_655  is.ha.it_443 hmn.no.sl_322
  0x18000510, 0x19160bac, 0x2d0d2907, 0x35002507,   // fr.ga.un_620 es.hr.gl_632  sl.cs.sk_432 eu.zu.un_420
  // [7150]
  0x291f07ad, 0x3b1e2aad, 0x2d0d160e, 0x2d0d0ab6,   // it.cy.sl_643 mt.ms.so_643  hr.cs.sk_555 pt.cs.sk_766
  0x2d001e02, 0x3b281bad, 0x6800290c, 0x2a031211,   // ms.sk.un_220 tr.sw.so_643  sl.ig.un_530 hu.nl.mt_653
  0x05080c0d, 0x0c020e04, 0x3b3155a4, 0x00000137,   // sv.no.fr_554 is.da.sv_332  rw.az.so_433 en.un.un_B00
  0x08000e18, 0x070a2360, 0x13090dee, 0x11005504,   // is.no.un_740 ca.pt.it_664  ne.hi.bh_422 rw.ro.un_320
  // [7160]
  0x25000107, 0x08095305, 0x4a681f0c, 0x28040e08,   // en.eu.un_420 ht.pl.no_333  cy.ig.yo_543 is.fi.sw_443
  0x19001e05, 0x20004a12, 0x2a1207ad, 0x3229170c,   // ms.gl.un_330 yo.sq.un_640  it.hu.mt_643 sr.sl.bs_543
  0x04100f0d, 0x321709af, 0x23181aac, 0x52350555,   // lv.lt.fi_554 pl.sr.bs_655  tl.ga.ca_632 fr.zu.ha_442
  0x036806ee, 0x31532011, 0x02080e07, 0x2500522b,   // de.ig.nl_422 sq.ht.az_653  is.no.da_432 ha.eu.un_980
  // [7170]
  0x20000208, 0x080264ee, 0x2d0d0cec, 0x00000637,   // da.sq.un_430 lg.da.no_422  sv.cs.sk_644 de.un.un_B00
  0x350455a0, 0x04005508, 0x073f08a9, 0x211b1c0c,   // rw.fi.zu_322 rw.fi.un_430  no.af.it_544 id.tr.jw_543
  0x20005507, 0x53201f0c, 0x10351360, 0x08021005,   // rw.sq.un_420 cy.sq.ht_543  et.zu.lt_664 lt.da.no_333
  0x31355508, 0x20350fad, 0x190b23ee, 0x0c030802,   // rw.zu.az_443 lv.zu.sq_643  ca.es.gl_422 no.nl.sv_222
  // [7180]
  0x10005508, 0x07110a05, 0x35210cad, 0x12110fa0,   // rw.lt.un_430 mk.ro.bg_333  sv.jw.zu_643 lv.ro.hu_322
  0x08022b0c, 0x08002d02, 0x0f122d05, 0x280813ee,   // vi.da.no_543 sk.no.un_220  sk.hu.lv_333 et.no.sw_422
  0x06271fa0, 0x311f18a4, 0x16100d07, 0x1a001608,   // cy.gd.de_322 ga.cy.az_433  cs.lt.hr_432 hr.tl.un_430
  0x0c003512, 0x530b0aa6, 0x190b1fee, 0x20082da0,   // zu.sv.un_640 pt.es.ht_521  cy.es.gl_422 sk.no.sq_322
  // [7190]
  0x55000707, 0x181a4a12, 0x2a0753a0, 0x070b4a13,   // it.rw.un_420 yo.tl.ga_654  ht.it.mt_322 yo.es.it_665
  0x6b55520c, 0x0f002505, 0x4a5529a9, 0x1a5228ec,   // ha.rw.ceb_543 eu.lv.un_330  sl.rw.yo_544 sw.ha.tl_644
  0x2100520c, 0x52005521, 0x1f4a270c, 0x022808ad,   // ha.jw.un_530 rw.ha.un_860  gd.yo.cy_543 no.sw.da_643
  0x52071c07, 0x522d03a9, 0x55005333, 0x0f523bad,   // id.it.ha_432 nl.sk.ha_544  ht.rw.un_A70 so.ha.lv_643
  // [71a0]
  0x2b006e13, 0x096b2007, 0x35286812, 0x06082505,   // hmn.vi.un_650 sq.ceb.pl_432  ig.sw.zu_654 eu.no.de_333
  0x18000504, 0x274a110d, 0x1300050c, 0x1e051ca0,   // fr.ga.un_320 ro.yo.gd_554  fr.et.un_530 id.fr.ms_322
  0x1623290c, 0x532b2dec, 0x64554aec, 0x4a1601ec,   // sl.ca.hr_543 sk.vi.ht_644  yo.rw.lg_644 en.hr.yo_644
  0x6b211a08, 0x042a070c, 0x19020ba4, 0x092321a4,   // tl.jw.ceb_443 it.mt.fi_543  es.da.gl_433 jw.ca.pl_433
  // [71b0]
  0x1b001a07, 0x06211ea4, 0x1c101e0c, 0x2000230e,   // tl.tr.un_420 ms.jw.de_433  ms.lt.id_543 ca.sq.un_550
  0x2968100c, 0x1e1c2160, 0x17000e05, 0x0a2a2104,   // lt.ig.sl_543 jw.id.ms_664  is.sr.un_330 jw.mt.pt_332
  0x1e001312, 0x6400100c, 0x1c0e1e13, 0x110b68ad,   // et.ms.un_640 lt.lg.un_530  ms.is.id_665 ig.es.ro_643
  0x2d2b0d13, 0x532052a6, 0x06002d0e, 0x033f0e11,   // cs.vi.sk_665 ha.sq.ht_521  sk.de.un_550 is.af.nl_653
  // [71c0]
  0x551b25ec, 0x131b520d, 0x29312504, 0x192a070c,   // eu.tr.rw_644 ha.tr.et_554  eu.az.sl_332 it.mt.gl_543
  0x6b3518a6, 0x04200e12, 0x01532a09, 0x131b2907,   // ga.zu.ceb_521 is.sq.fi_654  mt.ht.en_444 sl.tr.et_432
  0x0f006419, 0x190a0da4, 0x0a0b1907, 0x081a02ee,   // lg.lv.un_750 cs.pt.gl_433  gl.es.pt_432 da.tl.no_422
  0x07130404, 0x351f5308, 0x27180a08, 0x3b1e1cec,   // fi.et.it_332 ht.cy.zu_443  pt.ga.gd_443 id.ms.so_644
  // [71d0]
  0x0f1053a4, 0x12533ba4, 0x19180b12, 0x532a060d,   // ht.lt.lv_433 so.ht.hu_433  es.ga.gl_654 de.mt.ht_554
  0x4a641b08, 0x1b00070e, 0x0f050208, 0x2a130a08,   // tr.lg.yo_443 it.tr.un_550  da.fr.lv_443 pt.et.mt_443
  0x1c004a02, 0x2a00290c, 0x1e002112, 0x19002322,   // yo.id.un_220 sl.mt.un_530  jw.ms.un_640 ca.gl.un_870
  0x551c20ad, 0x3b1f0712, 0x2a1220ee, 0x353b100c,   // sq.id.rw_643 it.cy.so_654  sq.hu.mt_422 lt.so.zu_543
  // [71e0]
  0x06002804, 0x0a53010c, 0x201105a9, 0x16290f0c,   // sw.de.un_320 en.ht.pt_543  fr.ro.sq_544 lv.sl.hr_543
  0x270608af, 0x321711a0, 0x551701a4, 0x20001b0e,   // no.de.gd_655 ro.sr.bs_322  en.sr.rw_433 tr.sq.un_550
  0x3b136b08, 0x04006b02, 0x202129a9, 0x53206404,   // ceb.et.so_443 ceb.fi.un_220  sl.jw.sq_544 lg.sq.ht_332
  0x051c04a4, 0x20102514, 0x25041a0c, 0x0c11010c,   // fi.id.fr_433 eu.lt.sq_666  tl.fi.eu_543 en.ro.sv_543
  // [71f0]
  0x0e000604, 0x4a281fa4, 0x03213faf, 0x1110530d,   // de.is.un_320 cy.sw.yo_433  af.jw.nl_655 ht.lt.ro_554
  0x09021f12, 0x19051113, 0x18000b08, 0x27002d05,   // cy.da.pl_654 ro.fr.gl_665  es.ga.un_430 sk.gd.un_330
  0x01040512, 0x08100fec, 0x201f3fec, 0x253104ac,   // fr.fi.en_654 lv.lt.no_644  af.cy.sq_644 fi.az.eu_632
  0x10252a07, 0x0e001f02, 0x080225af, 0x0c17120c,   // mt.eu.lt_432 cy.is.un_220  eu.da.no_655 hu.sr.sv_543
  // [7200]
  0x0729120c, 0x1000280c, 0x171168a4, 0x0d000c04,   // hu.sl.it_543 sw.lt.un_530  ig.ro.sr_433 sv.cs.un_320
  0x133512ad, 0x11001b11, 0x020c13ac, 0x2a1b20a4,   // hu.zu.et_643 tr.ro.un_630  et.sv.da_632 sq.tr.mt_433
  0x13204a04, 0x320d1107, 0x080235ee, 0x12312813,   // yo.sq.et_332 ro.cs.bs_432  zu.da.no_422 sw.az.hu_665
  0x1e1c18a9, 0x11291708, 0x3211200c, 0x111b17a0,   // ga.id.ms_544 sr.sl.ro_443  sq.ro.bs_543 sr.tr.ro_322
  // [7210]
  0x172a2bee, 0x0c000521, 0x25002912, 0x0b003b08,   // vi.mt.sr_422 fr.sv.un_860  sl.eu.un_640 so.es.un_430
  0x1f275307, 0x28200b02, 0x286409a4, 0x020c0811,   // ht.gd.cy_432 es.sq.sw_222  pl.lg.sw_433 no.sv.da_653
  0x291611ad, 0x16003f0c, 0x16023207, 0x11000c29,   // ro.hr.sl_643 af.hr.un_530  bs.da.hr_432 sv.ro.un_960
  0x1f002712, 0x100f2a60, 0x641a28ad, 0x0209080c,   // gd.cy.un_640 mt.lv.lt_664  sw.tl.lg_643 no.pl.da_543
  // [7220]
  0x0c251305, 0x29205309, 0x0c230aa9, 0x09002d22,   // et.eu.sv_333 ht.sq.sl_444  pt.ca.sv_544 sk.pl.un_870
  0x291609a4, 0x2d001e13, 0x25202814, 0x0a2319ad,   // pl.hr.sl_433 ms.sk.un_650  sw.sq.eu_666 gl.ca.pt_643
  0x202d0d0c, 0x09101fad, 0x1b102aad, 0x0b001c04,   // cs.sk.sq_543 cy.lt.pl_643  mt.lt.tr_643 id.es.un_320
  0x211c640c, 0x292d0914, 0x29251b07, 0x06001f18,   // lg.id.jw_543 pl.sk.sl_666  tr.eu.sl_432 cy.de.un_740
  // [7230]
  0x13001014, 0x190a5202, 0x1629090c, 0x02002d21,   // lt.et.un_660 ha.pt.gl_222  pl.sl.hr_543 sk.da.un_860
  0x35520f0c, 0x130f280c, 0x270b2807, 0x230619a0,   // lv.ha.zu_543 sw.lv.et_543  sw.es.gd_432 gl.de.ca_322
  0x100f0a08, 0x2d0d18ba, 0x0468030c, 0x323564ac,   // pt.lv.lt_443 ga.cs.sk_843  nl.ig.fi_543 lg.zu.bs_632
  0x684a3505, 0x060701ad, 0x133b6411, 0x6e2d2b0c,   // zu.yo.ig_333 en.it.de_643  lg.so.et_653 vi.sk.hmn_543
  // [7240]
  0x6800350e, 0x64000705, 0x19130aec, 0x3f081c0c,   // zu.ig.un_550 it.lg.un_330  pt.et.gl_644 id.no.af_543
  0x0100062c, 0x08021a0e, 0x026e27a0, 0x00001f42,   // de.en.un_990 tl.da.no_555  gd.hmn.da_322 cy.un.un_C00
  0x044a350c, 0x09001702, 0x080d2905, 0x06000908,   // zu.yo.fi_543 sr.pl.un_220  sl.cs.no_333 pl.de.un_430
  0x1c040805, 0x25200612, 0x070c2d07, 0x080418ad,   // no.fi.id_333 de.sq.eu_654  sk.sv.it_432 ga.fi.no_643
  // [7250]
  0x1200071b, 0x1600530b, 0x18000607, 0x17161ba0,   // it.hu.un_770 ht.hr.un_520  de.ga.un_420 tr.hr.sr_322
  0x52190b09, 0x070c3bee, 0x1a1935ee, 0x4a002305,   // es.gl.ha_444 so.sv.it_422  zu.gl.tl_422 ca.yo.un_330
  0x0f203209, 0x29032512, 0x190c230c, 0x31006b29,   // bs.sq.lv_444 eu.nl.sl_654  ca.sv.gl_543 ceb.az.un_960
  0x1f530308, 0x25230611, 0x0c0823ec, 0x4a000702,   // nl.ht.cy_443 de.ca.eu_653  ca.no.sv_644 it.yo.un_220
  // [7260]
  0x3b1b4aa7, 0x122503a9, 0x081e0c11, 0x070435ee,   // yo.tr.so_532 nl.eu.hu_544  sv.ms.no_653 zu.fi.it_422
  0x1a003f08, 0x28351e11, 0x0d311fa4, 0x0d001a09,   // af.tl.un_430 ms.zu.sw_653  cy.az.cs_433 tl.cs.un_440
  0x3b2004a0, 0x2a136e12, 0x21002a04, 0x1b071ca0,   // fi.sq.so_322 hmn.et.mt_654  mt.jw.un_320 id.it.tr_322
  0x110529ee, 0x070f01a4, 0x0a122dee, 0x551353a4,   // sl.fr.ro_422 en.lv.it_433  sk.hu.pt_422 ht.et.rw_433
  // [7270]
  0x204a2308, 0x0806020d, 0x6e2a1faf, 0x1f132a0c,   // ca.yo.sq_443 da.de.no_554  cy.mt.hmn_655 mt.et.cy_543
  0x0c0625a4, 0x3f00071a, 0x07000208, 0x13001121,   // eu.de.sv_433 it.af.un_760  da.it.un_430 ro.et.un_860
  0x0e001e0d, 0x05005202, 0x07004a04, 0x1a6e5204,   // ms.is.un_540 ha.fr.un_220  yo.it.un_320 ha.hmn.tl_332
  0x3b3f02a4, 0x050607ec, 0x0a252102, 0x2b1f200b,   // da.af.so_433 it.de.fr_644  jw.eu.pt_222 sq.cy.vi_542
  // [7280]
  0x08000429, 0x2a12530c, 0x6b1e20ee, 0x3b001b13,   // ru.uk.un_960 ht.hu.mt_543  sq.ms.ceb_422 tr.so.un_650
  0x033f29a4, 0x31531208, 0x3f4a530c, 0x25001f18,   // sl.af.nl_433 hu.ht.az_443  ht.yo.af_543 cy.eu.un_740
  0x08002313, 0x08024aa0, 0x1b3b6ba0, 0x3f001702,   // ca.no.un_650 yo.da.no_322  ceb.so.tr_322 sr.af.un_220
  0x53210f0c, 0x2b1123ec, 0x11000113, 0x11685307,   // lv.jw.ht_543 ca.ro.vi_644  en.ro.un_650 ht.ig.ro_432
  // [7290]
  0x08050cee, 0x3f0c0205, 0x13000218, 0x3b1b6bad,   // sv.fr.no_422 da.sv.af_333  da.et.un_740 ceb.tr.so_643
  0x641f1baf, 0x1f19115a, 0x0c1f520c, 0x1f2d53a7,   // tr.cy.lg_655 ro.gl.cy_553  ha.cy.sv_543 ht.sk.cy_532
  0x13006b22, 0x1e351c0c, 0x0d532d0c, 0x1e000205,   // ceb.et.un_870 id.zu.ms_543  sk.ht.cs_543 da.ms.un_330
  0x10180c07, 0x2b31530c, 0x1c00010d, 0x0d1b3f0c,   // sv.ga.lt_432 ht.az.vi_543  en.id.un_540 af.tr.cs_543
  // [72a0]
  0x6e2135ec, 0x12051ba4, 0x2a070612, 0x0b2d1955,   // zu.jw.hmn_644 tr.fr.hu_433  de.it.mt_654 gl.sk.es_442
  0x190b3502, 0x290525ad, 0x1c061eee, 0x1220250c,   // zu.es.gl_222 eu.fr.sl_643  ms.de.id_422 eu.sq.hu_543
  0x1900250d, 0x231105a7, 0x12250560, 0x0b191811,   // eu.gl.un_540 fr.ro.ca_532  fr.eu.hu_664 ga.gl.es_653
  0x210535ee, 0x20051b55, 0x1e1b250c, 0x6400200d,   // zu.fr.jw_422 tr.fr.sq_442  eu.tr.ms_543 sq.lg.un_540
  // [72b0]
  0x0f3f02ec, 0x25002704, 0x231f1e05, 0x1105255a,   // da.af.lv_644 gd.eu.un_320  ms.cy.ca_333 eu.fr.ro_553
  0x1b531e5a, 0x25001707, 0x6b000304, 0x3f030daf,   // ms.ht.tr_553 sr.eu.un_420  nl.ceb.un_320 cs.nl.af_655
  0x16002704, 0x21070fec, 0x1620100c, 0x523b0bee,   // gd.hr.un_320 lv.it.jw_644  lt.sq.hr_543 es.so.ha_422
  0x1a4a6bec, 0x0d091c09, 0x0e3b64ec, 0x0f531014,   // ceb.yo.tl_644 mr.hi.ne_444  lg.so.is_644 lt.ht.lv_666
  // [72c0]
  0x102b3f08, 0x3f031a0c, 0x1a104aad, 0x641b1905,   // af.vi.lt_443 tl.nl.af_543  yo.lt.tl_643 gl.tr.lg_333
  0x3229160c, 0x08000404, 0x08000604, 0x07181108,   // hr.sl.bs_543 ru.uk.un_320  de.no.un_320 ro.ga.it_443
  0x072d1fa0, 0x126403a0, 0x3b1f1aa7, 0x2718010c,   // cy.sk.it_322 nl.lg.hu_322  tl.cy.so_532 en.ga.gd_543
  0x1a0a6b09, 0x081302ec, 0x1e1c0ba0, 0x27000408,   // ceb.pt.tl_444 da.et.no_644  es.id.ms_322 fi.gd.un_430
  // [72d0]
  0x1a533512, 0x13001019, 0x09030fa0, 0x10521a0d,   // zu.ht.tl_654 lt.et.un_750  lv.nl.pl_322 tl.ha.lt_554
  0x1f52100d, 0x08001c07, 0x06056e02, 0x136e1aad,   // lt.ha.cy_554 id.no.un_420  hmn.fr.de_222 tl.hmn.et_643
  0x0c1e0211, 0x12111007, 0x21351fa0, 0x190a1eee,   // da.ms.sv_653 lt.ro.hu_432  cy.zu.jw_322 ms.pt.gl_422
  0x13013ba7, 0x0a000409, 0x3b3f6405, 0x070d0e07,   // so.en.et_532 ru.mk.un_440  lg.af.so_333 is.cs.it_432
  // [72e0]
  0x29170f0c, 0x0a001809, 0x0e00081b, 0x3b006e20,   // lv.sr.sl_543 ga.pt.un_440  no.is.un_770 hmn.so.un_850
  0x2b1a52a0, 0x0802060e, 0x522a68af, 0x3f080b0c,   // ha.tl.vi_322 de.da.no_555  ig.mt.ha_655 es.no.af_543
  0x110b1b08, 0x1a0328a9, 0x203b31ad, 0x0b0208ac,   // tr.es.ro_443 sw.nl.tl_544  az.so.sq_643 no.da.es_632
  0x062b11ec, 0x090d1fad, 0x251811af, 0x32201b08,   // ro.vi.de_644 cy.cs.pl_643  ro.ga.eu_655 tr.sq.bs_443
  // [72f0]
  0x4a072313, 0x29526812, 0x071011ee, 0x6e00190d,   // ca.it.yo_665 ig.ha.sl_654  ro.be.bg_422 gl.hmn.un_540
  0x010c230c, 0x52256b12, 0x4a6b2b0d, 0x0a556bad,   // ca.sv.en_543 ceb.eu.ha_654  vi.ceb.yo_554 ceb.rw.pt_643
  0x023f060c, 0x311b0505, 0x53112360, 0x0c033fa9,   // de.af.da_543 fr.tr.az_333  ca.ro.ht_664 af.nl.sv_544
  0x554a2812, 0x52002a36, 0x354a6408, 0x012706a0,   // sw.yo.rw_654 mt.ha.un_AA0  lg.yo.zu_443 de.gd.en_322
  // [7300]
  0x0c1f1c02, 0x6b312155, 0x1304310c, 0x2800212a,   // id.cy.sv_222 jw.az.ceb_442  az.fi.et_543 jw.sw.un_970
  0x00000e37, 0x03251bee, 0x0a23210d, 0x211b5507,   // is.un.un_B00 tr.eu.nl_422  jw.ca.pt_554 rw.tr.jw_432
  0x1a3521ee, 0x0d002107, 0x04000113, 0x02061fee,   // jw.zu.tl_422 jw.cs.un_420  en.fi.un_650 cy.de.da_422
  0x072501ad, 0x552125a4, 0x6806250c, 0x290d6e0c,   // en.eu.it_643 eu.jw.rw_433  eu.de.ig_543 hmn.cs.sl_543
  // [7310]
  0x1c295355, 0x3b00250d, 0x21255213, 0x1e1c0f14,   // ht.sl.id_442 eu.so.un_540  ha.eu.jw_665 lv.id.ms_666
  0x10003f0c, 0x18000c07, 0x126413ee, 0x083b0204,   // af.lt.un_530 sv.ga.un_420  et.lg.hu_422 da.so.no_332
  0x353b2d07, 0x1b00190d, 0x52040360, 0x072a1e11,   // sk.so.zu_432 gl.tr.un_540  nl.fi.ha_664 ms.mt.it_653
  0x523118a4, 0x20551008, 0x55281b13, 0x256b2da4,   // ga.az.ha_433 lt.rw.sq_443  tr.sw.rw_665 sk.ceb.eu_433
  // [7320]
  0x1b0a10a4, 0x52001b1a, 0x1c171ea0, 0x102a550d,   // lt.pt.tr_433 tr.ha.un_760  ms.sr.id_322 rw.mt.lt_554
  0x321628a4, 0x01000b02, 0x04526405, 0x53212bad,   // sw.hr.bs_433 es.en.un_220  lg.ha.fi_333 vi.jw.ht_643
  0x27071fa6, 0x0a2b1c0c, 0x2a0964af, 0x6e2b2807,   // cy.it.gd_521 id.vi.pt_543  lg.pl.mt_655 sw.vi.hmn_432
  0x0b2307a0, 0x1e1c2aec, 0x213b1b0c, 0x35281ba4,   // it.ca.es_322 mt.id.ms_644  tr.so.jw_543 tr.sw.zu_433
  // [7330]
  0x130604ec, 0x6b01180e, 0x01000e07, 0x130e0407,   // fi.de.et_644 ga.en.ceb_555  is.en.un_420 fi.is.et_432
  0x1b1025a0, 0x31111b07, 0x6b0a55a0, 0x0e00102a,   // eu.lt.tr_322 tr.ro.az_432  rw.pt.ceb_322 lt.is.un_970
  0x3b006418, 0x023f20ac, 0x1213170c, 0x522b11a0,   // lg.so.un_740 sq.af.da_632  sr.et.hu_543 ro.vi.ha_322
  0x070527a4, 0x3f3b64a4, 0x204a64a4, 0x2a092da9,   // gd.fr.it_433 lg.so.af_433  lg.yo.sq_433 sk.pl.mt_544
  // [7340]
  0x201216ee, 0x1b002d19, 0x35552a60, 0x2d200d12,   // hr.hu.sq_422 sk.tr.un_750  mt.rw.zu_664 cs.sq.sk_654
  0x0a0807ee, 0x1100102b, 0x2d291fa4, 0x53201b0c,   // bg.uk.mk_422 be.ro.un_980  cy.sl.sk_433 tr.sq.ht_543
  0x2900171a, 0x0400011b, 0x1b003f04, 0x3100210c,   // sr.sl.un_760 en.fi.un_770  af.tr.un_320 jw.az.un_530
  0x162953a7, 0x1a3b6413, 0x190b05ec, 0x102901a0,   // ht.sl.hr_532 lg.so.tl_665  fr.es.gl_644 en.sl.lt_322
  // [7350]
  0x283552a7, 0x17212808, 0x180a32a0, 0x08022d0c,   // ha.zu.sw_532 sw.jw.sr_443  bs.pt.ga_322 sk.da.no_543
  0x0c290d08, 0x28001019, 0x4a3b6412, 0x03006818,   // cs.sl.sv_443 lt.sw.un_750  lg.so.yo_654 ig.nl.un_740
  0x13684a04, 0x181912a9, 0x1e1a1c07, 0x100364ad,   // yo.ig.et_332 hu.gl.ga_544  id.tl.ms_432 lg.nl.lt_643
  0x4a121805, 0x4a28350c, 0x0d1918a4, 0x2823530d,   // ga.hu.yo_333 zu.sw.yo_543  ga.gl.cs_433 ht.ca.sw_554
  // [7360]
  0x271820af, 0x206e6ba0, 0x0d122d04, 0x10093205,   // sq.ga.gd_655 ceb.hmn.sq_322  sk.hu.cs_332 bs.pl.lt_333
  0x0d1912ec, 0x0b124a5a, 0x3f02010c, 0x12000d21,   // hu.gl.cs_644 yo.hu.es_553  en.da.af_543 cs.hu.un_860
  0x190b1209, 0x190b2da4, 0x194a0b07, 0x12184a13,   // hu.es.gl_444 sk.es.gl_433  es.yo.gl_432 yo.ga.hu_665
  0x13001a34, 0x4a2a0d12, 0x130a3ba4, 0x1f006e07,   // tl.et.un_A80 cs.mt.yo_654  so.pt.et_433 hmn.cy.un_420
  // [7370]
  0x255521af, 0x19270aad, 0x31111b14, 0x0a0c27ad,   // jw.rw.eu_655 pt.gd.gl_643  tr.ro.az_666 gd.sv.pt_643
  0x020601af, 0x234a2bad, 0x6b1152a4, 0x31553555,   // en.de.da_655 vi.yo.ca_643  ha.ro.ceb_433 zu.rw.az_442
  0x2d002a02, 0x20001c02, 0x04001f18, 0x6b2818ad,   // mt.sk.un_220 id.sq.un_220  cy.fi.un_740 ga.sw.ceb_643
  0x074a2712, 0x0500520c, 0x03000104, 0x02086ea7,   // gd.yo.it_654 ha.fr.un_530  en.nl.un_320 hmn.no.da_532
  // [7380]
  0x1b005211, 0x0c00270e, 0x2b274aec, 0x2a002d12,   // ha.tr.un_630 gd.sv.un_550  yo.gd.vi_644 sk.mt.un_640
  0x130e0f04, 0x10005202, 0x6b251a13, 0x3b250ca4,   // lv.is.et_332 ha.lt.un_220  tl.eu.ceb_665 sv.eu.so_433
  0x06020eee, 0x64000e14, 0x1b000302, 0x53000d22,   // is.da.de_422 is.lg.un_660  nl.tr.un_220 cs.ht.un_870
  0x20080caf, 0x1b0c08af, 0x080a04ec, 0x535520a0,   // sv.no.sq_655 no.sv.tr_655  ru.mk.uk_644 sq.rw.ht_322
  // [7390]
  0x102a0f13, 0x64066ba7, 0x0608250b, 0x322d6ea0,   // lv.mt.lt_665 ceb.de.lg_532  eu.no.de_542 hmn.sk.bs_322
  0x53050a0e, 0x53000d20, 0x2d09290c, 0x061304a7,   // pt.fr.ht_555 cs.ht.un_850  sl.pl.sk_543 fi.et.de_532
  0x351b04af, 0x550635a0, 0x25554a09, 0x201f6807,   // fi.tr.zu_655 zu.de.rw_322  yo.rw.eu_444 ig.cy.sq_432
  0x25104aee, 0x06296e13, 0x28001b1b, 0x5306640d,   // yo.lt.eu_422 hmn.sl.de_665  tr.sw.un_770 lg.de.ht_554
  // [73a0]
  0x1e1c28a9, 0x12184aec, 0x642a5508, 0x231128a4,   // sw.id.ms_544 yo.ga.hu_644  rw.mt.lg_443 sw.ro.ca_433
  0x531a0111, 0x19350a60, 0x3200110c, 0x0700232a,   // en.tl.ht_653 pt.zu.gl_664  ro.bs.un_530 ca.it.un_970
  0x0a191155, 0x1c1e21a7, 0x3f2a070d, 0x13253fa4,   // ro.gl.pt_442 jw.ms.id_532  it.mt.af_554 af.eu.et_433
  0x1b000913, 0x106828ad, 0x32292dad, 0x32252da4,   // pl.tr.un_650 sw.ig.lt_643  sk.sl.bs_643 sk.eu.bs_433
  // [73b0]
  0x0e0302a4, 0x3216110c, 0x23006e21, 0x1a003f14,   // da.nl.is_433 ro.hr.bs_543  hmn.ca.un_860 af.tl.un_660
  0x050420ee, 0x28552a05, 0x3b023faf, 0x1e0d1cad,   // sq.fi.fr_422 mt.rw.sw_333  af.da.so_655 id.cs.ms_643
  0x2b001219, 0x08113f60, 0x3f000221, 0x3f021107,   // hu.vi.un_750 af.ro.no_664  da.af.un_860 ro.da.af_432
  0x201b6b0c, 0x17001612, 0x096b28a4, 0x0f271005,   // ceb.tr.sq_543 hr.sr.un_640  sw.ceb.pl_433 lt.gd.lv_333
  // [73c0]
  0x1a001011, 0x55525305, 0x53004a2a, 0x1c1309ac,   // lt.tl.un_630 ht.ha.rw_333  yo.ht.un_970 hi.bh.mr_632
  0x160d29a4, 0x4a001c0e, 0x1a6b2113, 0x35005312,   // sl.cs.hr_433 id.yo.un_550  jw.ceb.tl_665 ht.zu.un_640
  0x0e0c130c, 0x0f05100c, 0x105313af, 0x06530e0c,   // et.sv.is_543 lt.fr.lv_543  et.ht.lt_655 is.ht.de_543
  0x130406a0, 0x1c1e2108, 0x08021e09, 0x09640708,   // de.fi.et_322 jw.ms.id_443  ms.da.no_444 it.lg.pl_443
  // [73d0]
  0x08021cee, 0x2b004a11, 0x2b074a12, 0x2a350707,   // id.da.no_422 yo.vi.un_630  yo.it.vi_654 it.zu.mt_432
  0x072b4a12, 0x033564af, 0x04000604, 0x1b003135,   // yo.vi.it_654 lg.zu.nl_655  de.fi.un_320 az.tr.un_A90
  0x071b20a4, 0x04112505, 0x6b09350d, 0x4a1c2512,   // sq.tr.it_433 eu.ro.fi_333  zu.pl.ceb_554 eu.id.yo_654
  0x28354aec, 0x13020ea4, 0x17002104, 0x28136b09,   // yo.zu.sw_644 is.da.et_433  jw.sr.un_320 ceb.et.sw_444
  // [73e0]
  0x2025555a, 0x162d21a9, 0x07640507, 0x050b01af,   // rw.eu.sq_553 jw.sk.hr_544  fr.lg.it_432 en.es.fr_655
  0x0b0a2109, 0x110607ec, 0x2a642812, 0x0e3f2aee,   // jw.pt.es_444 it.de.ro_644  sw.lg.mt_654 mt.af.is_422
  0x202a32a4, 0x072155a9, 0x1c1e5508, 0x292a07ad,   // bs.mt.sq_433 rw.jw.it_544  rw.ms.id_443 it.mt.sl_643
  0x2d0d1805, 0x062503a4, 0x52004a07, 0x2b68280d,   // ga.cs.sk_333 nl.eu.de_433  yo.ha.un_420 sw.ig.vi_554
  // [73f0]
  0x32171ca4, 0x0c031304, 0x25000304, 0x0f4a1013,   // id.sr.bs_433 et.nl.sv_332  nl.eu.un_320 lt.yo.lv_665
  0x10001e09, 0x0d131c11, 0x1b001308, 0x35552804,   // ms.lt.un_440 mr.bh.ne_653  et.tr.un_430 sw.rw.zu_332
  0x2a071e12, 0x020c0660, 0x68002512, 0x1b1c07ad,   // ms.it.mt_654 de.sv.da_664  eu.ig.un_640 it.id.tr_643
  0x0f4a2707, 0x1c001804, 0x1e2104a0, 0x1f001307,   // gd.yo.lv_432 ga.id.un_320  fi.jw.ms_322 et.cy.un_420

  // [7400]
  0x03002907, 0x18090eec, 0x35010fa4, 0x53000f19,   // sl.nl.un_420 is.pl.ga_644  lv.en.zu_433 lv.ht.un_750
  0x32173fa0, 0x31001302, 0x101827a9, 0x20092911,   // af.sr.bs_322 et.az.un_220  gd.ga.lt_544 sl.pl.sq_653
  0x100b1ca4, 0x2a000509, 0x0a07680c, 0x285268ad,   // id.es.lt_433 fr.mt.un_440  ig.it.pt_543 ig.ha.sw_643
  0x23090ba0, 0x29100f04, 0x1b000d0d, 0x3f111307,   // es.pl.ca_322 lv.lt.sl_332  cs.tr.un_540 et.ro.af_432
  // [7410]
  0x6e3153a7, 0x0b000c05, 0x531629a9, 0x01232b08,   // ht.az.hmn_532 sv.es.un_330  sl.hr.ht_544 vi.ca.en_443
  0x20012a05, 0x08040ca6, 0x4a001205, 0x020c11a4,   // mt.en.sq_333 sv.fi.no_521  hu.yo.un_330 ro.sv.da_433
  0x20523b07, 0x1f00211a, 0x08021ea0, 0x211a68a4,   // so.ha.sq_432 jw.cy.un_760  ms.da.no_322 ig.tl.jw_433
  0x25190c07, 0x53011109, 0x01643f0c, 0x3f131e0c,   // sv.gl.eu_432 ro.en.ht_444  af.lg.en_543 ms.et.af_543
  // [7420]
  0x28006805, 0x01060509, 0x23071ea4, 0x041307af,   // ig.sw.un_330 fr.de.en_444  ms.it.ca_433 it.et.fi_655
  0x643f2812, 0x12190508, 0x1e1c21ac, 0x04523514,   // sw.af.lg_654 fr.gl.hu_443  jw.id.ms_632 zu.ha.fi_666
  0x0c280f07, 0x1c1e525a, 0x0e2d1260, 0x030611a9,   // lv.sw.sv_432 ha.ms.id_553  hu.sk.is_664 ro.de.nl_544
  0x096b53a7, 0x1e1c29a4, 0x11061fa7, 0x11000304,   // ht.ceb.pl_532 sl.id.ms_433  cy.de.ro_532 nl.ro.un_320
  // [7430]
  0x4a00350c, 0x033f2004, 0x3b2028a0, 0x200613ad,   // zu.yo.un_530 sq.af.nl_332  sw.sq.so_322 et.de.sq_643
  0x1e1c11a9, 0x1f002d08, 0x3f00040c, 0x06023fec,   // ro.id.ms_544 sk.cy.un_430  fi.af.un_530 af.da.de_644
  0x01003b0d, 0x19210ba4, 0x2a002702, 0x1c1b27ee,   // so.en.un_540 es.jw.gl_433  gd.mt.un_220 gd.tr.id_422
  0x0b272307, 0x25313b08, 0x1704530d, 0x0e0c4a5a,   // ca.gd.es_432 so.az.eu_443  ht.fi.sr_554 yo.sv.is_553
  // [7440]
  0x1c251e12, 0x4a130e11, 0x0205080c, 0x032305ad,   // ms.eu.id_654 is.et.yo_653  no.fr.da_543 fr.ca.nl_643
  0x29111e0b, 0x0d292da4, 0x130523a9, 0x6b130e08,   // ms.ro.sl_542 sk.sl.cs_433  ca.fr.et_544 is.et.ceb_443
  0x0c0f230c, 0x12135304, 0x27183f14, 0x103b0f12,   // ca.lv.sv_543 ht.et.hu_332  af.ga.gd_666 lv.so.lt_654
  0x12532304, 0x0719010c, 0x0807175a, 0x0e033f13,   // ca.ht.hu_332 en.gl.it_543  sr.bg.uk_553 af.nl.is_665
  // [7450]
  0x2a2305a4, 0x2b0125ee, 0x292311ac, 0x5331130c,   // fr.ca.mt_433 eu.en.vi_422  ro.ca.sl_632 et.az.ht_543
  0x2d0d0a14, 0x5313020c, 0x533b130c, 0x2a0e2355,   // pt.cs.sk_666 da.et.ht_543  et.so.ht_543 ca.is.mt_442
  0x080209ad, 0x3f0613ad, 0x05533fee, 0x07000e04,   // pl.da.no_643 et.de.af_643  af.ht.fr_422 is.it.un_320
  0x016b1305, 0x29002a2b, 0x0a2027a0, 0x2100130d,   // et.ceb.en_333 mt.sl.un_980  gd.sq.pt_322 et.jw.un_540
  // [7460]
  0x4a006b0c, 0x3b133108, 0x0e0c4aa0, 0x1e6e3ba0,   // ceb.yo.un_530 az.et.so_443  yo.sv.is_322 so.hmn.ms_322
  0x53355512, 0x02002907, 0x13043b02, 0x12002907,   // rw.zu.ht_654 sl.da.un_420  so.fi.et_222 sl.hu.un_420
  0x32191f08, 0x102d1605, 0x19231108, 0x6b113bec,   // cy.gl.bs_443 hr.sk.lt_333  ro.ca.gl_443 so.ro.ceb_644
  0x0f161713, 0x68081fec, 0x29006404, 0x55001a04,   // sr.hr.lv_665 cy.no.ig_644  lg.sl.un_320 tl.rw.un_320
  // [7470]
  0x55286402, 0x0a00180d, 0x0b001a04, 0x681e3555,   // lg.sw.rw_222 ga.pt.un_540  tl.es.un_320 zu.ms.ig_442
  0x4a136408, 0x1c2d1ea0, 0x1a1e10a4, 0x0e1c06a9,   // lg.et.yo_443 ms.sk.id_322  lt.ms.tl_433 de.id.is_544
  0x103f0fac, 0x1e1c1fa4, 0x6e003b19, 0x13551205,   // lv.af.lt_632 cy.id.ms_433  so.hmn.un_750 hu.rw.et_333
  0x0f003114, 0x0b003b05, 0x0e643ba6, 0x061353a6,   // az.lv.un_660 so.es.un_330  so.lg.is_521 ht.et.de_521
  // [7480]
  0x2a0619a0, 0x13002319, 0x1c3564a9, 0x11232a05,   // gl.de.mt_322 ca.et.un_750  lg.zu.id_544 mt.ca.ro_333
  0x21291855, 0x13215308, 0x6b0110a0, 0x032806ad,   // ga.sl.jw_442 ht.jw.et_443  lt.en.ceb_322 de.sw.nl_643
  0x192a0b07, 0x0b0a32a0, 0x321e17ee, 0x16001b04,   // es.mt.gl_432 bs.pt.es_322  sr.ms.bs_422 tr.hr.un_320
  0x02530807, 0x310f10a0, 0x53356411, 0x28680e05,   // no.ht.da_432 lt.lv.az_322  lg.zu.ht_653 is.ig.sw_333
  // [7490]
  0x531225a7, 0x523f3b07, 0x21003520, 0x6400210e,   // eu.hu.ht_532 so.af.ha_432  zu.jw.un_850 jw.lg.un_550
  0x133b0b02, 0x35000920, 0x216b2508, 0x4a2825ad,   // es.so.et_222 pl.zu.un_850  eu.ceb.jw_443 eu.sw.yo_643
  0x07001b21, 0x05072a05, 0x09252da9, 0x09004a0e,   // tr.it.un_860 mt.it.fr_333  sk.eu.pl_544 yo.pl.un_550
  0x216b1c5a, 0x28005312, 0x31531b0c, 0x183b095a,   // id.ceb.jw_553 ht.sw.un_640  tr.ht.az_543 pl.so.ga_553
  // [74a0]
  0x2d0d250c, 0x163b35a0, 0x06011f0c, 0x1a6e28ec,   // eu.cs.sk_543 zu.so.hr_322  cy.en.de_543 sw.hmn.tl_644
  0x311b0405, 0x552a3512, 0x1e160ea4, 0x02280807,   // fi.tr.az_333 zu.mt.rw_654  is.hr.ms_433 no.sw.da_432
  0x32006b20, 0x35130ca9, 0x12040f0d, 0x0e10190c,   // ceb.bs.un_850 sv.et.zu_544  lv.fi.hu_554 gl.lt.is_543
  0x0a001817, 0x21000c23, 0x10230eaf, 0x2d0d5502,   // ga.pt.un_730 sv.jw.un_880  is.ca.lt_655 rw.cs.sk_222
  // [74b0]
  0x23520ca4, 0x1b121f0c, 0x03291313, 0x071306ee,   // sv.ha.ca_433 cy.hu.tr_543  et.sl.nl_665 de.et.it_422
  0x646855a9, 0x020d08ee, 0x35556bec, 0x100f1fac,   // rw.ig.lg_544 no.cs.da_422  ceb.rw.zu_644 cy.lv.lt_632
  0x20006818, 0x07002d04, 0x35071208, 0x0a64350c,   // ig.sq.un_740 sk.it.un_320  hu.it.zu_443 zu.lg.pt_543
  0x311202ee, 0x645553ec, 0x050207a0, 0x550928a4,   // da.hu.az_422 ht.rw.lg_644  it.da.fr_322 sw.pl.rw_433
  // [74c0]
  0x090f01a4, 0x1352250c, 0x0720080c, 0x31182aa7,   // en.lv.pl_433 eu.ha.et_543  no.sq.it_543 mt.ga.az_532
  0x18121baf, 0x28000619, 0x192311a7, 0x04003519,   // tr.hu.ga_655 de.sw.un_750  ro.ca.gl_532 zu.fi.un_750
  0x12002307, 0x53001012, 0x521a3511, 0x230f0b13,   // ca.hu.un_420 lt.ht.un_640  zu.tl.ha_653 es.lv.ca_665
  0x0a002102, 0x3b1c5212, 0x110723ad, 0x19000412,   // jw.pt.un_220 ha.id.so_654  ca.it.ro_643 fi.gl.un_640
  // [74d0]
  0x060305ee, 0x522a1ea9, 0x120e520e, 0x52001e22,   // fr.nl.de_422 ms.mt.ha_544  ha.is.hu_555 ms.ha.un_870
  0x051104ad, 0x191c11ee, 0x0d212aec, 0x120f105a,   // fi.ro.fr_643 ro.id.gl_422  mt.jw.cs_644 lt.lv.hu_553
  0x6b12070d, 0x25003b12, 0x013b07ac, 0x0a29070c,   // it.hu.ceb_554 so.eu.un_640  it.so.en_632 it.sl.pt_543
  0x3b27280c, 0x3f086eee, 0x3b282105, 0x32170f05,   // sw.gd.so_543 hmn.no.af_422  jw.sw.so_333 lv.sr.bs_333
  // [74e0]
  0x032b0c08, 0x03000529, 0x2700022a, 0x05202509,   // sv.vi.nl_443 fr.nl.un_960  da.gd.un_970 eu.sq.fr_444
  0x08001722, 0x0b002302, 0x13014aee, 0x10000d04,   // sr.uk.un_870 ca.es.un_220  yo.en.et_422 cs.lt.un_320
  0x25040ea4, 0x1929070c, 0x17131ba4, 0x13005314,   // is.fi.eu_433 it.sl.gl_543  tr.et.sr_433 ht.et.un_660
  0x0e4a0b08, 0x172855ee, 0x20052308, 0x2852640c,   // es.yo.is_443 rw.sw.sr_422  ca.fr.sq_443 lg.ha.sw_543
  // [74f0]
  0x531129a0, 0x1e1c0a02, 0x12000314, 0x6e002d08,   // sl.ro.ht_322 pt.id.ms_222  nl.hu.un_660 sk.hmn.un_430
  0x16641bec, 0x3200130c, 0x04002012, 0x6b042007,   // tr.lg.hr_644 et.bs.un_530  sq.fi.un_640 sq.fi.ceb_432
  0x2a1b3113, 0x0a001b1a, 0x08002b19, 0x291f2da0,   // az.tr.mt_665 tr.pt.un_760  vi.no.un_750 sk.cy.sl_322
  0x253f1307, 0x4a12195a, 0x0b0a1ca0, 0x13043fac,   // et.af.eu_432 gl.hu.yo_553  id.pt.es_322 af.fi.et_632
  // [7500]
  0x25353fa4, 0x64043b04, 0x190a2312, 0x290e07a4,   // af.zu.eu_433 so.fi.lg_332  ca.pt.gl_654 it.is.sl_433
  0x1b170907, 0x05000d0d, 0x32091004, 0x533f2a05,   // pl.sr.tr_432 cs.fr.un_540  lt.pl.bs_332 mt.af.ht_333
  0x030e0f07, 0x190b05a0, 0x2b002323, 0x1e1c2111,   // lv.is.nl_432 fr.es.gl_322  ca.vi.un_880 jw.id.ms_653
  0x1752550c, 0x04293b08, 0x2564290c, 0x28002a07,   // rw.ha.sr_543 so.sl.fi_443  sl.lg.eu_543 mt.sw.un_420
  // [7510]
  0x07030611, 0x322916ee, 0x08023fec, 0x290d01a9,   // de.nl.it_653 hr.sl.bs_422  af.da.no_644 en.cs.sl_544
  0x124a2aa0, 0x641a525a, 0x18272a04, 0x2155520c,   // mt.yo.hu_322 ha.tl.lg_553  mt.gd.ga_332 ha.rw.jw_543
  0x085323ad, 0x092d25a0, 0x310e0111, 0x4a3b1ba7,   // ca.ht.no_643 eu.sk.pl_322  en.is.az_653 tr.so.yo_532
  0x252d0909, 0x0f0c3fa9, 0x09522da4, 0x0f255208,   // pl.sk.eu_444 af.sv.lv_544  sk.ha.pl_433 ha.eu.lv_443
  // [7520]
  0x080227a4, 0x093552a9, 0x275302ad, 0x20080ca9,   // gd.da.no_433 ha.zu.pl_544  da.ht.gd_643 sv.no.sq_544
  0x042053a7, 0x21201cee, 0x6b013f05, 0x28551211,   // ht.sq.fi_532 id.sq.jw_422  af.en.ceb_333 hu.rw.sw_653
  0x3b2531ad, 0x10003102, 0x0c136b0c, 0x520c23ec,   // az.eu.so_643 az.lt.un_220  ceb.et.sv_543 ca.sv.ha_644
  0x0b236b05, 0x130f0c02, 0x0f100a11, 0x0700180d,   // ceb.ca.es_333 sv.lv.et_222  pt.lt.lv_653 ga.it.un_540
  // [7530]
  0x3b1b10a9, 0x1a5513a4, 0x07002702, 0x0f276bee,   // lt.tr.so_544 et.rw.tl_433  gd.it.un_220 ceb.gd.lv_422
  0x35040fa4, 0x35000e19, 0x086b2aee, 0x1c1b1e0d,   // lv.fi.zu_433 is.zu.un_750  mt.ceb.no_422 ms.tr.id_554
  0x17293b0c, 0x25000718, 0x033b1ba9, 0x02000702,   // so.sl.sr_543 it.eu.un_740  tr.so.nl_544 it.da.un_220
  0x3f5213af, 0x090d3105, 0x012806a0, 0x316b13ee,   // et.ha.af_655 az.cs.pl_333  de.sw.en_322 et.ceb.az_422
  // [7540]
  0x040c1312, 0x1a005204, 0x1b0c0a0c, 0x29520f55,   // et.sv.fi_654 ha.tl.un_320  pt.sv.tr_543 lv.ha.sl_442
  0x3b040f55, 0x011b55a0, 0x1f683ba7, 0x0a002a02,   // lv.fi.so_442 rw.tr.en_322  so.ig.cy_532 mt.pt.un_220
  0x11002811, 0x041b640b, 0x1a00102a, 0x641f0607,   // sw.ro.un_630 lg.tr.fi_542  lt.tl.un_970 de.cy.lg_432
  0x6b1f55ee, 0x681e550c, 0x35001c13, 0x03520ead,   // rw.cy.ceb_422 rw.ms.ig_543  id.zu.un_650 is.ha.nl_643
  // [7550]
  0x0353010c, 0x04136b12, 0x08020c07, 0x0b6e2012,   // en.ht.nl_543 ceb.et.fi_654  sv.da.no_432 sq.hmn.es_654
  0x4a1805af, 0x0b530fee, 0x21182b13, 0x280f2aa9,   // fr.ga.yo_655 lv.ht.es_422  vi.ga.jw_665 mt.lv.sw_544
  0x53000a08, 0x11055214, 0x1e1c28a6, 0x4a531f14,   // pt.ht.un_430 ha.fr.ro_666  sw.id.ms_521 cy.ht.yo_666
  0x31005207, 0x4a0c64a9, 0x080264a0, 0x534a640e,   // ha.az.un_420 lg.sv.yo_544  lg.da.no_322 lg.yo.ht_555
  // [7560]
  0x6b681f07, 0x05002519, 0x12171609, 0x09002704,   // cy.ig.ceb_432 eu.fr.un_750  hr.sr.hu_444 gd.pl.un_320
  0x4a001135, 0x1c171eec, 0x0d1b0111, 0x231302a4,   // ro.yo.un_A90 ms.sr.id_644  en.tr.cs_653 da.et.ca_433
  0x3f532013, 0x324a2aa0, 0x23112aac, 0x06291105,   // sq.ht.af_665 mt.yo.bs_322  mt.ro.ca_632 ro.sl.de_333
  0x53112911, 0x2d1806a4, 0x1a6b20ee, 0x04553ba0,   // sl.ro.ht_653 de.ga.sk_433  sq.ceb.tl_422 so.rw.fi_322
  // [7570]
  0x0d162dac, 0x04521e08, 0x6b180ca0, 0x016813a0,   // sk.hr.cs_632 ms.ha.fi_443  sv.ga.ceb_322 et.ig.en_322
  0x5500311a, 0x0a000518, 0x3b3f27a4, 0x550e3508,   // az.rw.un_760 fr.pt.un_740  gd.af.so_433 zu.is.rw_443
  0x1f002b11, 0x010605ee, 0x123b1aac, 0x052853a9,   // vi.cy.un_630 fr.de.en_422  tl.so.hu_632 ht.sw.fr_544
  0x131a1f02, 0x27003b2b, 0x1c0b180c, 0x1800680c,   // cy.tl.et_222 so.gd.un_980  ga.es.id_543 ig.ga.un_530
  // [7580]
  0x12050aaf, 0x020507ec, 0x522328a4, 0x08000a07,   // pt.fr.hu_655 it.fr.da_644  sw.ca.ha_433 mk.uk.un_420
  0x645312ec, 0x1f2b18ee, 0x31521bec, 0x20210a0c,   // hu.ht.lg_644 ga.vi.cy_422  tr.ha.az_644 pt.jw.sq_543
  0x030d3f0e, 0x10001b1b, 0x12000e07, 0x00001837,   // af.cs.nl_555 tr.lt.un_770  is.hu.un_420 ar.un.un_B00
  0x2b002707, 0x10313f5a, 0x1a00280d, 0x021708a9,   // gd.vi.un_420 af.az.lt_553  sw.tl.un_540 no.sr.da_544
  // [7590]
  0x1a350ea4, 0x111b640d, 0x1e1221a0, 0x551a1b0c,   // is.zu.tl_433 lg.tr.ro_554  jw.hu.ms_322 tr.tl.rw_543
  0x02005302, 0x255528a9, 0x55093bec, 0x0d002907,   // ht.da.un_220 sw.rw.eu_544  so.pl.rw_644 sl.cs.un_420
  0x3f00060e, 0x1b552908, 0x09553bec, 0x13001004,   // de.af.un_550 sl.rw.tr_443  so.rw.pl_644 lt.et.un_320
  0x0700550c, 0x06082aa0, 0x01111b0c, 0x351b4aa0,   // rw.it.un_530 mt.no.de_322  tr.ro.en_543 yo.tr.zu_322
  // [75a0]
  0x04030d05, 0x0b000420, 0x2d0d53a0, 0x531905ee,   // cs.nl.fi_333 fi.es.un_850  ht.cs.sk_322 fr.gl.ht_422
  0x55000913, 0x3f0503a0, 0x0c230409, 0x2105530c,   // pl.rw.un_650 nl.fr.af_322  fi.ca.sv_444 ht.fr.jw_543
  0x21003104, 0x28206bec, 0x28530111, 0x01535502,   // az.jw.un_320 ceb.sq.sw_644  en.ht.sw_653 rw.ht.en_222
  0x55351baf, 0x0e1f0c05, 0x20002312, 0x060e29a6,   // tr.zu.rw_655 sv.cy.is_333  ca.sq.un_640 sl.is.de_521
  // [75b0]
  0x0b000e07, 0x211c3513, 0x100d2dee, 0x64001a13,   // is.es.un_420 zu.id.jw_665  sk.cs.lt_422 tl.lg.un_650
  0x55001e02, 0x1c062007, 0x190d20a0, 0x200805a0,   // ms.rw.un_220 sq.de.id_432  sq.cs.gl_322 fr.no.sq_322
  0x07053ba0, 0x2d0d07ee, 0x090f2955, 0x06281a05,   // so.fr.it_322 it.cs.sk_422  sl.lv.pl_442 tl.sw.de_333
  0x311b0fa0, 0x01000404, 0x0d2d2107, 0x1b2a35a7,   // lv.tr.az_322 fi.en.un_320  jw.sk.cs_432 zu.mt.tr_532
  // [75c0]
  0x18192705, 0x130464a0, 0x06006402, 0x31091b04,   // gd.gl.ga_333 lg.fi.et_322  lg.de.un_220 tr.pl.az_332
  0x2b000307, 0x07000811, 0x07012a14, 0x25350fa4,   // nl.vi.un_420 uk.bg.un_630  mt.en.it_666 lv.zu.eu_433
  0x1c001704, 0x28250708, 0x3235250c, 0x20000e08,   // sr.id.un_320 it.eu.sw_443  eu.zu.bs_543 is.sq.un_430
  0x525321a4, 0x0a072aa4, 0x2b001019, 0x35096ba4,   // jw.ht.ha_433 mt.it.pt_433  lt.vi.un_750 ceb.pl.zu_433
  // [75d0]
  0x21536405, 0x553525ad, 0x3b5352a4, 0x643135af,   // lg.ht.jw_333 eu.zu.rw_643  ha.ht.so_433 zu.az.lg_655
  0x03532702, 0x532507a9, 0x07352508, 0x0e270c55,   // gd.ht.nl_222 it.eu.ht_544  eu.zu.it_443 sv.gd.is_442
  0x0f250708, 0x2d005504, 0x6e003512, 0x35283f09,   // it.eu.lv_443 rw.sk.un_320  zu.hmn.un_640 af.sw.zu_444
  0x2a006414, 0x31000302, 0x06283512, 0x13002a09,   // lg.mt.un_660 nl.az.un_220  zu.sw.de_654 mt.et.un_440
  // [75e0]
  0x1c162bee, 0x0b2868ee, 0x1c003f02, 0x2d0d2502,   // vi.hr.id_422 ig.sw.es_422  af.id.un_220 eu.cs.sk_222
  0x53000912, 0x21000504, 0x16291208, 0x1320100c,   // pl.ht.un_640 fr.jw.un_320  hu.sl.hr_443 lt.sq.et_543
  0x060b2804, 0x080602a0, 0x1e1c0308, 0x0d6e1ca0,   // sw.es.de_332 da.de.no_322  nl.id.ms_443 id.hmn.cs_322
  0x20001608, 0x111f6ba4, 0x0f000407, 0x04000519,   // hr.sq.un_430 ceb.cy.ro_433  fi.lv.un_420 fr.fi.un_750
  // [75f0]
  0x0f102907, 0x05005335, 0x2d0d050c, 0x100f0313,   // sl.lt.lv_432 ht.fr.un_A90  fr.cs.sk_543 nl.lv.lt_665
  0x64001220, 0x35316402, 0x0700030e, 0x25091013,   // hu.lg.un_850 lg.az.zu_222  nl.it.un_550 lt.pl.eu_665
  0x091153ad, 0x0a0512bb, 0x290f350c, 0x2a2564ec,   // ht.ro.pl_643 hu.fr.pt_854  zu.lv.sl_543 lg.eu.mt_644
  0x3f0725a4, 0x25090660, 0x070264a4, 0x64002d13,   // eu.it.af_433 de.pl.eu_664  lg.da.it_433 sk.lg.un_650
  // [7600]
  0x06040504, 0x08002a08, 0x64520409, 0x21006402,   // fr.fi.de_332 mt.no.un_430  fi.ha.lg_444 lg.jw.un_220
  0x19002009, 0x0f002309, 0x31003507, 0x10001308,   // sq.gl.un_440 ca.lv.un_440  zu.az.un_420 et.lt.un_430
  0x1e000404, 0x042010af, 0x1a0405ad, 0x1c0e280c,   // fi.ms.un_320 lt.sq.fi_655  fr.fi.tl_643 sw.is.id_543
  0x532a4aa0, 0x1700070c, 0x170a2111, 0x321768ac,   // yo.mt.ht_322 bg.sr.un_530  jw.pt.sr_653 ig.sr.bs_632
  // [7610]
  0x041b130c, 0x2d211f5a, 0x11522508, 0x1b003102,   // et.tr.fi_543 cy.jw.sk_553  eu.ha.ro_443 az.tr.un_220
  0x18030612, 0x132d29a0, 0x1e211ca7, 0x31251bec,   // de.nl.ga_654 sl.sk.et_322  id.jw.ms_532 tr.eu.az_644
  0x11190108, 0x1f1220ec, 0x0110070c, 0x321f0ead,   // en.gl.ro_443 sq.hu.cy_644  it.lt.en_543 is.cy.bs_643
  0x1e1c2da4, 0x07251108, 0x53004a0b, 0x35315502,   // sk.id.ms_433 ro.eu.it_443  yo.ht.un_520 rw.az.zu_222
  // [7620]
  0x0e211b0c, 0x530f0514, 0x0d13090b, 0x130420a0,   // tr.jw.is_543 fr.lv.ht_666  hi.bh.ne_542 sq.fi.et_322
  0x1b120f55, 0x13005202, 0x16005304, 0x13002304,   // lv.hu.tr_442 ha.et.un_220  ht.hr.un_320 ca.et.un_320
  0x0a002804, 0x122a0f08, 0x64094a09, 0x23003505,   // sw.pt.un_320 lv.mt.hu_443  yo.pl.lg_444 zu.ca.un_330
  0x0f5529a0, 0x190b2907, 0x55115308, 0x55006812,   // sl.rw.lv_322 sl.es.gl_432  ht.ro.rw_443 ig.rw.un_640
  // [7630]
  0x040b530c, 0x4a2864ec, 0x08031c08, 0x53002521,   // ht.es.fi_543 lg.sw.yo_644  id.nl.no_443 eu.ht.un_860
  0x3f6403a0, 0x3b004a04, 0x0b0528a7, 0x52003f04,   // nl.lg.af_322 yo.so.un_320  sw.fr.es_532 af.ha.un_320
  0x101b1112, 0x352068a4, 0x1c003504, 0x182721a9,   // ro.tr.lt_654 ig.sq.zu_433  zu.id.un_320 jw.gd.ga_544
  0x213b1aaf, 0x53002702, 0x3f005304, 0x2d1235af,   // tl.so.jw_655 gd.ht.un_220  ht.af.un_320 zu.hu.sk_655
  // [7640]
  0x20135555, 0x520625ec, 0x0d000b04, 0x20553513,   // rw.et.sq_442 eu.de.ha_644  es.cs.un_320 zu.rw.sq_665
  0x21051e0c, 0x07001e0d, 0x1b121aa7, 0x210e1a09,   // ms.fr.jw_543 ms.it.un_540  tl.hu.tr_532 tl.is.jw_444
  0x311b1cec, 0x07001e02, 0x21203b0d, 0x18000619,   // id.tr.az_644 ms.it.un_220  so.sq.jw_554 de.ga.un_750
  0x356801a4, 0x2a00520b, 0x35182112, 0x25115309,   // en.ig.zu_433 ha.mt.un_520  jw.ga.zu_654 ht.ro.eu_444
  // [7650]
  0x2d0d25af, 0x18000b02, 0x1f080e08, 0x1e1f1c0c,   // eu.cs.sk_655 es.ga.un_220  is.no.cy_443 id.cy.ms_543
  0x6b52090c, 0x2a0703a0, 0x08022302, 0x08020e14,   // pl.ha.ceb_543 nl.it.mt_322  ca.da.no_222 is.da.no_666
  0x16296b07, 0x3b000b02, 0x52002119, 0x0f000e09,   // ceb.sl.hr_432 es.so.un_220  jw.ha.un_750 is.lv.un_440
  0x13252d08, 0x551005a0, 0x0c0802ee, 0x3509040d,   // sk.eu.et_443 fr.lt.rw_322  da.no.sv_422 fi.pl.zu_554
  // [7660]
  0x06083fa0, 0x0a0f6b07, 0x683555a4, 0x2d0d3ba4,   // af.no.de_322 ceb.lv.pt_432  rw.zu.ig_433 so.cs.sk_433
  0x0c030612, 0x080a120c, 0x211335a6, 0x55351c0c,   // de.nl.sv_654 hu.pt.no_543  zu.et.jw_521 id.zu.rw_543
  0x10001118, 0x09066413, 0x12202114, 0x061e21a9,   // ro.be.un_740 lg.de.pl_665  jw.sq.hu_666 jw.ms.de_544
  0x06012708, 0x13001212, 0x64001a34, 0x1e172aa4,   // gd.en.de_443 hu.et.un_640  tl.lg.un_A80 mt.sr.ms_433
  // [7670]
  0x1e1c2308, 0x320d17a0, 0x03002318, 0x2a276ba7,   // ca.id.ms_443 sr.cs.bs_322  ca.nl.un_740 ceb.gd.mt_532
  0x32002013, 0x122135af, 0x040710a6, 0x120c080c,   // sq.bs.un_650 zu.jw.hu_655  be.bg.ru_521 no.sv.hu_543
  0x110427a9, 0x042821a9, 0x53004a07, 0x06000919,   // gd.fi.ro_544 jw.sw.fi_544  yo.ht.un_420 pl.de.un_750
  0x21353b04, 0x00006b37, 0x1e1a1c12, 0x0e000c21,   // so.zu.jw_332 ceb.un.un_B00  id.tl.ms_654 sv.is.un_860
  // [7680]
  0x044a1f07, 0x251a1ca4, 0x3f011a55, 0x253564ec,   // cy.yo.fi_432 id.tl.eu_433  tl.en.af_442 lg.zu.eu_644
  0x0f2d0d13, 0x52283b09, 0x685264ad, 0x256835a0,   // cs.sk.lv_665 so.sw.ha_444  lg.ha.ig_643 zu.ig.eu_322
  0x190a0bee, 0x2d0d31ee, 0x3f001313, 0x4a0e2ba9,   // es.pt.gl_422 az.cs.sk_422  et.af.un_650 vi.is.yo_544
  0x2a4a07af, 0x191206a6, 0x3f2835ad, 0x1a001221,   // it.yo.mt_655 de.hu.gl_521  zu.sw.af_643 hu.tl.un_860
  // [7690]
  0x2a001f0b, 0x215204ec, 0x1b6b6802, 0x3564250e,   // cy.mt.un_520 fi.ha.jw_644  ig.ceb.tr_222 eu.lg.zu_555
  0x1300061a, 0x0c002b04, 0x20123512, 0x070919a4,   // de.et.un_760 vi.sv.un_320  zu.hu.sq_654 gl.pl.it_433
  0x12003529, 0x1320030d, 0x046b4a0e, 0x551711a9,   // zu.hu.un_960 nl.sq.et_554  yo.ceb.fi_555 ro.sr.rw_544
  0x04100aec, 0x11100f13, 0x04132a07, 0x55001b08,   // mk.be.ru_644 lv.lt.ro_665  mt.et.fi_432 tr.rw.un_430
  // [76a0]
  0x32255514, 0x10250460, 0x1b552a08, 0x32002902,   // rw.eu.bs_666 fi.eu.lt_664  mt.rw.tr_443 sl.bs.un_220
  0x32172911, 0x35001e1a, 0x20000508, 0x32172d0c,   // sl.sr.bs_653 ms.zu.un_760  fr.sq.un_430 sk.sr.bs_543
  0x2a0f55a4, 0x2d681a08, 0x104a0f07, 0x1328070c,   // rw.lv.mt_433 tl.ig.sk_443  lv.yo.lt_432 it.sw.et_543
  0x130103a6, 0x110301ad, 0x0d005214, 0x1b185204,   // nl.en.et_521 en.nl.ro_643  ha.cs.un_660 ha.ga.tr_332
  // [76b0]
  0x05010c08, 0x270a18af, 0x0e3b12ad, 0x013b64a4,   // sv.en.fr_443 ga.pt.gd_655  hu.so.is_643 lg.so.en_433
  0x552852a4, 0x1c533bee, 0x0300350c, 0x553552ec,   // ha.sw.rw_433 so.ht.id_422  zu.nl.un_530 ha.zu.rw_644
  0x27171fa4, 0x35001a2b, 0x256b5212, 0x0f230560,   // cy.sr.gd_433 tl.zu.un_980  ha.ceb.eu_654 fr.ca.lv_664
  0x02250812, 0x2d0d2855, 0x052353ad, 0x0c0f25a4,   // no.eu.da_654 sw.cs.sk_442  ht.ca.fr_643 eu.lv.sv_433
  // [76c0]
  0x251b0413, 0x53232112, 0x1c6b2111, 0x166b1a0c,   // fi.tr.eu_665 jw.ca.ht_654  jw.ceb.id_653 tl.ceb.hr_543
  0x2b006412, 0x281a5205, 0x31002a05, 0x2d0d1017,   // lg.vi.un_640 ha.tl.sw_333  mt.az.un_330 lt.cs.sk_753
  0x21532312, 0x1b1e4a55, 0x3f1f0208, 0x21532307,   // ca.ht.jw_654 yo.ms.tr_442  da.cy.af_443 ca.ht.jw_432
  0x17111e0c, 0x0000172d, 0x3217030c, 0x033f04ee,   // ms.ro.sr_543 sr.un.un_A00  nl.sr.bs_543 fi.af.nl_422
  // [76d0]
  0x21235312, 0x1c25210c, 0x23005312, 0x1b00110c,   // ht.ca.jw_654 jw.eu.id_543  ht.ca.un_640 ro.tr.un_530
  0x1f013fa9, 0x11191fa0, 0x0c6808ee, 0x646b35a0,   // af.en.cy_544 cy.gl.ro_322  no.ig.sv_422 zu.ceb.lg_322
  0x063f1ba9, 0x114a16a4, 0x120425af, 0x556407ee,   // tr.af.de_544 hr.yo.ro_433  eu.fi.hu_655 it.lg.rw_422
  0x2a003509, 0x21685508, 0x04521ba4, 0x1a00530c,   // zu.mt.un_440 rw.ig.jw_443  tr.ha.fi_433 ht.tl.un_530
  // [76e0]
  0x10130cee, 0x100b050c, 0x091f3fa9, 0x022d0305,   // sv.et.lt_422 fr.es.lt_543  af.cy.pl_544 nl.sk.da_333
  0x041c1313, 0x52001707, 0x0302185a, 0x1c251eec,   // et.id.fi_665 sr.ha.un_420  ga.da.nl_553 ms.eu.id_644
  0x0e250fac, 0x2731250c, 0x060405ec, 0x033f2505,   // lv.eu.is_632 eu.az.gd_543  fr.fi.de_644 eu.af.nl_333
  0x1c110605, 0x0700100e, 0x20003102, 0x3f030ba9,   // de.ro.id_333 be.bg.un_550  az.sq.un_220 es.nl.af_544
  // [76f0]
  0x64006812, 0x130b3b0c, 0x16173212, 0x32286811,   // ig.lg.un_640 so.es.et_543  bs.sr.hr_654 ig.sw.bs_653
  0x231907ad, 0x0e030808, 0x0a17105a, 0x3b2319ec,   // it.gl.ca_643 no.nl.is_443  be.sr.mk_553 gl.ca.so_644
  0x0c130808, 0x3b642108, 0x270752ac, 0x1b536b09,   // no.et.sv_443 jw.lg.so_443  ha.it.gd_632 ceb.ht.tr_444
  0x13002811, 0x2917080c, 0x03130f05, 0x321b3512,   // sw.et.un_630 no.sr.sl_543  lv.et.nl_333 zu.tr.bs_654
  // [7700]
  0x0600310e, 0x2d0d2714, 0x120e18af, 0x080e02ac,   // az.de.un_550 gd.cs.sk_666  ga.is.hu_655 da.is.no_632
  0x53192811, 0x21002302, 0x0b1328a4, 0x07211008,   // sw.gl.ht_653 ca.jw.un_220  sw.et.es_433 lt.jw.it_443
  0x6b00101a, 0x6e2d29ad, 0x6b103513, 0x0a0b10a7,   // lt.ceb.un_760 sl.sk.hmn_643  zu.lt.ceb_665 lt.es.pt_532
  0x02005312, 0x13550208, 0x551b180c, 0x53230514,   // ht.da.un_640 da.rw.et_443  ga.tr.rw_543 fr.ca.ht_666
  // [7710]
  0x0b011904, 0x4a23530e, 0x060113a9, 0x0b6e19ee,   // gl.en.es_332 ht.ca.yo_555  et.en.de_544 gl.hmn.es_422
  0x19050a55, 0x030b0a0d, 0x1300010c, 0x3f2823ee,   // pt.fr.gl_442 pt.es.nl_554  en.et.un_530 ca.sw.af_422
  0x014a1905, 0x0c001813, 0x023b3f0d, 0x2d0e0dad,   // gl.yo.en_333 ga.sv.un_650  af.so.da_554 cs.is.sk_643
  0x35003b12, 0x35556b55, 0x3b00200b, 0x1b160fa4,   // so.zu.un_640 ceb.rw.zu_442  sq.so.un_520 lv.hr.tr_433
  // [7720]
  0x35002b29, 0x06180eee, 0x11200fee, 0x3f001005,   // vi.zu.un_960 is.ga.de_422  lv.sq.ro_422 lt.af.un_330
  0x122d0ca4, 0x2d060d0c, 0x09003f12, 0x0b0a4aa4,   // sv.sk.hu_433 cs.de.sk_543  af.pl.un_640 yo.pt.es_433
  0x12003113, 0x3b2718a9, 0x52352805, 0x18061fee,   // az.hu.un_650 ga.gd.so_544  sw.zu.ha_333 cy.de.ga_422
  0x100502ee, 0x27061807, 0x5500640b, 0x31001234,   // da.fr.lt_422 ga.de.gd_432  lg.rw.un_520 hu.az.un_A80
  // [7730]
  0x2d000d33, 0x0628530c, 0x0a000d04, 0x556b2da9,   // cs.sk.un_A70 ht.sw.de_543  cs.pt.un_320 sk.ceb.rw_544
  0x28550613, 0x32162014, 0x060d12a4, 0x0c1604a4,   // de.rw.sw_665 sq.hr.bs_666  hu.cs.de_433 fi.hr.sv_433
  0x0d0c2da4, 0x553228ad, 0x086431a4, 0x64010ba0,   // sk.sv.cs_433 sw.bs.rw_643  az.lg.no_433 es.en.lg_322
  0x552109ec, 0x2d0d12bb, 0x1325280c, 0x68001704,   // pl.jw.rw_644 hu.cs.sk_854  sw.eu.et_543 sr.ig.un_320
  // [7740]
  0x0811175a, 0x321620ec, 0x200b29a4, 0x10041b04,   // sr.ro.uk_553 sq.hr.bs_644  sl.es.sq_433 tr.fi.lt_332
  0x32162a0e, 0x0c002914, 0x12072a09, 0x25350da4,   // mt.hr.bs_555 sl.sv.un_660  mt.it.hu_444 cs.zu.eu_433
  0x29060c60, 0x1a001605, 0x176428ad, 0x64531713,   // sv.de.sl_664 hr.tl.un_330  sw.lg.sr_643 sr.ht.lg_665
  0x060304a9, 0x170c0612, 0x030619ee, 0x320e2802,   // fi.nl.de_544 de.sv.sr_654  gl.de.nl_422 sw.is.bs_222
  // [7750]
  0x1e1c0f07, 0x07122a11, 0x0200042b, 0x1e001a02,   // lv.id.ms_432 mt.hu.it_653  fi.da.un_980 tl.ms.un_220
  0x29132a09, 0x105525ac, 0x2d131212, 0x211b2012,   // mt.et.sl_444 eu.rw.lt_632  hu.et.sk_654 sq.tr.jw_654
  0x0b000519, 0x0e0864a4, 0x64040e08, 0x64253508,   // fr.es.un_750 lg.no.is_433  is.fi.lg_443 zu.eu.lg_443
  0x202928ec, 0x11016b08, 0x3f0429a4, 0x084a0e07,   // sw.sl.sq_644 ceb.en.ro_443  sl.fi.af_433 is.yo.no_432
  // [7760]
  0x52640e07, 0x31000e09, 0x551135ec, 0x23001313,   // is.lg.ha_432 is.az.un_440  zu.ro.rw_644 et.ca.un_650
  0x27003204, 0x13042909, 0x070b06a4, 0x1c2d25a0,   // bs.gd.un_320 sl.fi.et_444  de.es.it_433 eu.sk.id_322
  0x080c6412, 0x07060309, 0x352129a6, 0x040e2102,   // lg.sv.no_654 nl.de.it_444  sl.jw.zu_521 jw.is.fi_222
  0x351f06a4, 0x080221a0, 0x1b1a0a07, 0x27005319,   // de.cy.zu_433 jw.da.no_322  pt.tl.tr_432 ht.gd.un_750
  // [7770]
  0x03060714, 0x182d0e0c, 0x112155af, 0x35531aaf,   // it.de.nl_666 is.sk.ga_543  rw.jw.ro_655 tl.ht.zu_655
  0x53000704, 0x1b2006ac, 0x2000642b, 0x321609ee,   // it.ht.un_320 de.sq.tr_632  lg.sq.un_980 pl.hr.bs_422
  0x3b001a36, 0x0b2a19af, 0x1607280c, 0x640d01ec,   // tl.so.un_AA0 gl.mt.es_655  sw.it.hr_543 en.cs.lg_644
  0x1f00202a, 0x07062a12, 0x1e1c0fee, 0x043f55ad,   // sq.cy.un_970 mt.de.it_654  lv.id.ms_422 rw.af.fi_643
  // [7780]
  0x1f003f36, 0x230f09ee, 0x1c213512, 0x20002b0d,   // af.cy.un_AA0 pl.lv.ca_422  zu.jw.id_654 vi.sq.un_540
  0x1a6b2ba7, 0x35135304, 0x20001604, 0x35121e08,   // vi.ceb.tl_532 ht.et.zu_332  hr.sq.un_320 ms.hu.zu_443
  0x1e1c2802, 0x2b000a02, 0x0c000318, 0x12231b08,   // sw.id.ms_222 pt.vi.un_220  nl.sv.un_740 tr.ca.hu_443
  0x352011ad, 0x0b110604, 0x270518af, 0x19251004,   // ro.sq.zu_643 de.ro.es_332  ga.fr.gd_655 lt.eu.gl_332
  // [7790]
  0x08022309, 0x011803ee, 0x53002305, 0x0d2d270d,   // ca.da.no_444 nl.ga.en_422  ca.ht.un_330 gd.sk.cs_554
  0x10003f05, 0x2a3b2811, 0x0c000714, 0x27182860,   // af.lt.un_330 sw.so.mt_653  it.sv.un_660 sw.ga.gd_664
  0x3f001f12, 0x110d55a4, 0x1c1b28a0, 0x052707a7,   // cy.af.un_640 rw.cs.ro_433  sw.tr.id_322 it.gd.fr_532
  0x0e006e08, 0x190b55a0, 0x1107230d, 0x1e2135ac,   // hmn.is.un_430 rw.es.gl_322  ca.it.ro_554 zu.jw.ms_632
  // [77a0]
  0x2718070e, 0x13071bee, 0x2a111814, 0x3b354a13,   // it.ga.gd_555 tr.it.et_422  ga.ro.mt_666 yo.zu.so_665
  0x16290aa9, 0x130d090c, 0x0b0a0da6, 0x020c05ee,   // pt.sl.hr_544 hi.ne.bh_543  cs.pt.es_521 fr.sv.da_422
  0x521a6bad, 0x6b553507, 0x193b0ba0, 0x07000b04,   // ceb.tl.ha_643 zu.rw.ceb_432  es.so.gl_322 es.it.un_320
  0x64551ba0, 0x10082aad, 0x1b6b0ba4, 0x0900551b,   // tr.rw.lg_322 mt.no.lt_643  es.ceb.tr_433 rw.pl.un_770
  // [77b0]
  0x35001902, 0x185509ad, 0x64550960, 0x0621090c,   // gl.zu.un_220 pl.rw.ga_643  pl.rw.lg_664 pl.jw.de_543
  0x080206ec, 0x1b001a12, 0x536421a0, 0x09536404,   // de.da.no_644 tl.tr.un_640  jw.lg.ht_322 lg.ht.pl_332
  0x21121005, 0x55002902, 0x1a0510a4, 0x1b2731ee,   // lt.hu.jw_333 sl.rw.un_220  lt.fr.tl_433 az.gd.tr_422
  0x071b0513, 0x052918a0, 0x12001f0c, 0x01005502,   // fr.tr.it_665 ga.sl.fr_322  cy.hu.un_530 rw.en.un_220
  // [77c0]
  0x0e12040e, 0x04132a14, 0x120f0e07, 0x0c061b04,   // fi.hu.is_555 mt.et.fi_666  is.lv.hu_432 tr.de.sv_332
  0x1001230c, 0x030110a7, 0x08022305, 0x09320f0c,   // ca.en.lt_543 lt.en.nl_532  ca.da.no_333 lv.bs.pl_543
  0x290b28ad, 0x3f000904, 0x120805a4, 0x10200fa4,   // sw.es.sl_643 pl.af.un_320  fr.no.hu_433 lv.sq.lt_433
  0x191123a0, 0x320f165a, 0x20230baf, 0x176852a6,   // ca.ro.gl_322 hr.lv.bs_553  es.ca.sq_655 ha.ig.sr_521
  // [77d0]
  0x1300250b, 0x0f0510ee, 0x1b000412, 0x3f0f2da4,   // eu.et.un_520 lt.fr.lv_422  fi.tr.un_640 sk.lv.af_433
  0x0c001e02, 0x171029a0, 0x211355ec, 0x52350ea4,   // ms.sv.un_220 sl.lt.sr_322  rw.et.jw_644 is.zu.ha_433
  0x063f0b0c, 0x25290f12, 0x641a2108, 0x112307ad,   // es.af.de_543 lv.sl.eu_654  jw.tl.lg_443 it.ca.ro_643
  0x6435230c, 0x120e090c, 0x4a0a52a9, 0x2718230c,   // ca.zu.lg_543 pl.is.hu_543  ha.pt.yo_544 ca.ga.gd_543
  // [77e0]
  0x0d000208, 0x311b55a4, 0x190a2aee, 0x642d35ad,   // da.cs.un_430 rw.tr.az_433  mt.pt.gl_422 zu.sk.lg_643
  0x11290f07, 0x19230b0d, 0x2120230b, 0x17002008,   // lv.sl.ro_432 es.ca.gl_554  ca.sq.jw_542 sq.sr.un_430
  0x1f002307, 0x20063f09, 0x290d17a6, 0x01093b0b,   // ca.cy.un_420 af.de.sq_444  sr.cs.sl_521 so.pl.en_542
  0x0a1108ec, 0x55093b0b, 0x32100ba0, 0x55000819,   // uk.ro.mk_644 so.pl.rw_542  es.lt.bs_322 no.rw.un_750
  // [77f0]
  0x1a0b530b, 0x0f281005, 0x0d022d60, 0x23251914,   // ht.es.tl_542 lt.sw.lv_333  sk.da.cs_664 gl.eu.ca_666
  0x0f121008, 0x050607a0, 0x1a2120a4, 0x32000207,   // lt.hu.lv_443 it.de.fr_322  sq.jw.tl_433 da.bs.un_420
  0x022008a4, 0x0d6b2d0c, 0x043f1313, 0x2a071baf,   // no.sq.da_433 sk.ceb.cs_543  et.af.fi_665 tr.it.mt_655
  0x1c1e3b07, 0x1e000e13, 0x231f0e07, 0x011c0ea7,   // so.ms.id_432 is.ms.un_650  is.cy.ca_432 is.id.en_532

  // [7800]
  0x32166ea0, 0x0600110c, 0x05001821, 0x0900640c,   // hmn.hr.bs_322 ro.de.un_530  ga.fr.un_860 lg.pl.un_530
  0x64521e02, 0x11000a02, 0x02001804, 0x08210eee,   // ms.ha.lg_222 pt.ro.un_220  ga.da.un_320 is.jw.no_422
  0x6800351a, 0x06200c13, 0x01001113, 0x351827ec,   // zu.ig.un_760 sv.sq.de_665  ro.en.un_650 gd.ga.zu_644
  0x252a5312, 0x1a6b0b04, 0x060805a4, 0x0c1b53ec,   // ht.mt.eu_654 es.ceb.tl_332  fr.no.de_433 ht.tr.sv_644
  // [7810]
  0x200111ec, 0x071711ec, 0x19072313, 0x3200100c,   // ro.en.sq_644 ro.sr.bg_644  ca.it.gl_665 lt.bs.un_530
  0x06351f0c, 0x2505350c, 0x131911ad, 0x1c080c12,   // cy.zu.de_543 zu.fr.eu_543  ro.gl.et_643 sv.no.id_654
  0x071711a6, 0x17162da6, 0x023f0613, 0x130e35ee,   // ro.sr.bg_521 sk.hr.sr_521  de.af.da_665 zu.is.et_422
  0x01110808, 0x17102aa4, 0x130407a0, 0x64322808,   // no.ro.en_443 mt.lt.sr_433  it.fi.et_322 sw.bs.lg_443
  // [7820]
  0x0c100f05, 0x015318a0, 0x1b210e08, 0x0e0704a7,   // lv.lt.sv_333 ga.ht.en_322  is.jw.tr_443 fi.it.is_532
  0x04100614, 0x0e100c04, 0x3f2d0d13, 0x2d0b19af,   // de.lt.fi_666 sv.lt.is_332  cs.sk.af_665 gl.es.sk_655
  0x190a0e14, 0x063b35ec, 0x06113fad, 0x190a0609,   // is.pt.gl_666 zu.so.de_644  af.ro.de_643 de.pt.gl_444
  0x041f06ad, 0x1a3f3508, 0x110768a7, 0x0d202d0c,   // de.cy.fi_643 zu.af.tl_443  ig.it.ro_532 sk.sq.cs_543
  // [7830]
  0x04000f13, 0x25001f21, 0x1c281e55, 0x28351313,   // lv.fi.un_650 cy.eu.un_860  ms.sw.id_442 et.zu.sw_665
  0x061f35a4, 0x2a002007, 0x1204530b, 0x18021f07,   // zu.cy.de_433 sq.mt.un_420  ht.fi.hu_542 cy.da.ga_432
  0x0c6402af, 0x2d180dec, 0x0c1f640c, 0x174a28ac,   // da.lg.sv_655 cs.ga.sk_644  lg.cy.sv_543 sw.yo.sr_632
  0x17022a0c, 0x09004a1b, 0x5300280b, 0x25551007,   // mt.da.sr_543 yo.pl.un_770  sw.ht.un_520 lt.rw.eu_432
  // [7840]
  0x4a002814, 0x0e00230c, 0x31051ba7, 0x3b1e250b,   // sw.yo.un_660 ca.is.un_530  tr.fr.az_532 eu.ms.so_542
  0x13182760, 0x0c0b64ee, 0x2d000620, 0x532811ec,   // gd.ga.et_664 lg.es.sv_422  de.sk.un_850 ro.sw.ht_644
  0x64021f0c, 0x17002804, 0x0f233f08, 0x062a0f0c,   // cy.da.lg_543 sw.sr.un_320  af.ca.lv_443 lv.mt.de_543
  0x35003f02, 0x11001a02, 0x093b060c, 0x270364ee,   // af.zu.un_220 tl.ro.un_220  de.so.pl_543 lg.nl.gd_422
  // [7850]
  0x17161e02, 0x17000a34, 0x032d050c, 0x272a1fad,   // ms.hr.sr_222 mk.sr.un_A80  fr.sk.nl_543 cy.mt.gd_643
  0x11003204, 0x1b006e13, 0x0628640d, 0x05230fa7,   // bs.ro.un_320 hmn.tr.un_650  lg.sw.de_554 lv.ca.fr_532
  0x550628a7, 0x3b28530c, 0x1e121a12, 0x032b3fa0,   // sw.de.rw_532 ht.sw.so_543  tl.hu.ms_654 af.vi.nl_322
  0x3f1702a0, 0x18001908, 0x530d05ad, 0x1c213b0e,   // da.sr.af_322 gl.ga.un_430  fr.cs.ht_643 so.jw.id_555
  // [7860]
  0x2331100c, 0x12002702, 0x0e040cec, 0x55003504,   // lt.az.ca_543 gd.hu.un_220  sv.fi.is_644 zu.rw.un_320
  0x02003207, 0x1e64520c, 0x08110a05, 0x53001007,   // bs.da.un_420 ha.lg.ms_543  mk.ro.uk_333 lt.ht.un_420
  0x13200f05, 0x4a006405, 0x19070b07, 0x311e1a12,   // lv.sq.et_333 lg.yo.un_330  es.it.gl_432 tl.ms.az_654
  0x204a6412, 0x05000f13, 0x2500552a, 0x080220a4,   // lg.yo.sq_654 lv.fr.un_650  rw.eu.un_970 sq.da.no_433
  // [7870]
  0x351c1a0c, 0x32160fa4, 0x53232807, 0x02202508,   // tl.id.zu_543 lv.hr.bs_433  sw.ca.ht_432 eu.sq.da_443
  0x3f101fa7, 0x3f2520ee, 0x04120da0, 0x55641ea4,   // cy.lt.af_532 sq.eu.af_422  cs.hu.fi_322 ms.lg.rw_433
  0x64000219, 0x171c21a9, 0x642701a4, 0x1b005219,   // da.lg.un_750 jw.id.sr_544  en.gd.lg_433 ha.tr.un_750
  0x285368ec, 0x190b1ba0, 0x1f20090c, 0x1b552aa7,   // ig.ht.sw_644 tr.es.gl_322  pl.sq.cy_543 mt.rw.tr_532
  // [7880]
  0x0e0c1314, 0x12001604, 0x133b080b, 0x056b0807,   // et.sv.is_666 hr.hu.un_320  no.so.et_542 no.ceb.fr_432
  0x1b005504, 0x31253bec, 0x0c1b1009, 0x552b0508,   // rw.tr.un_320 so.eu.az_644  lt.tr.sv_444 fr.vi.rw_443
  0x07001e07, 0x55281ca7, 0x0800130d, 0x10202da4,   // ms.it.un_420 id.sw.rw_532  et.no.un_540 sk.sq.lt_433
  0x28532a0c, 0x052d11a0, 0x01003b07, 0x21002a23,   // mt.ht.sw_543 ro.sk.fr_322  so.en.un_420 mt.jw.un_880
  // [7890]
  0x20000f07, 0x03050604, 0x254a550d, 0x32200ea7,   // lv.sq.un_420 de.fr.nl_332  rw.yo.eu_554 is.sq.bs_532
  0x13091c5a, 0x2a000e0c, 0x212a6813, 0x28003502,   // mr.hi.bh_553 is.mt.un_530  ig.mt.jw_665 zu.sw.un_220
  0x312a2804, 0x23002008, 0x4a2568ad, 0x281318a4,   // sw.mt.az_332 sq.ca.un_430  ig.eu.yo_643 ga.et.sw_433
  0x183b2012, 0x11312012, 0x53232005, 0x32044a02,   // sq.so.ga_654 sq.az.ro_654  sq.ca.ht_333 yo.fi.bs_222
  // [78a0]
  0x1a00030d, 0x100f3b14, 0x08000908, 0x170429a0,   // nl.tl.un_540 so.lv.lt_666  pl.no.un_430 sl.fi.sr_322
  0x556425ee, 0x252855a0, 0x216455ec, 0x180e090c,   // eu.lg.rw_422 rw.sw.eu_322  rw.lg.jw_644 pl.is.ga_543
  0x110510a0, 0x211f55a0, 0x25231e0c, 0x13002522,   // lt.fr.ro_322 rw.cy.jw_322  ms.ca.eu_543 eu.et.un_870
  0x18001107, 0x05001b04, 0x0f043f14, 0x09001709,   // ro.ga.un_420 tr.fr.un_320  af.fi.lv_666 sr.pl.un_440
  // [78b0]
  0x2d0d08a0, 0x1e001c29, 0x1e211c0b, 0x04005513,   // no.cs.sk_322 id.ms.un_960  id.jw.ms_542 rw.fi.un_650
  0x281e1ba9, 0x12000202, 0x0c1b53ee, 0x3f2513a4,   // tr.ms.sw_544 da.hu.un_220  ht.tr.sv_422 et.eu.af_433
  0x256452ec, 0x166425ad, 0x19110b09, 0x28001805,   // ha.lg.eu_644 eu.lg.hr_643  es.ro.gl_444 ga.sw.un_330
  0x64105502, 0x64042dee, 0x64256b11, 0x2a0f120c,   // rw.lt.lg_222 sk.fi.lg_422  ceb.eu.lg_653 hu.lv.mt_543
  // [78c0]
  0x04001602, 0x00000901, 0x202a1b07, 0x556425ec,   // hr.fi.un_220 pl.un.un_200  tr.mt.sq_432 eu.lg.rw_644
  0x1e120da0, 0x6400252b, 0x64251008, 0x2900251a,   // cs.hu.ms_322 eu.lg.un_980  lt.eu.lg_443 eu.sl.un_760
  0x28520e0d, 0x52111ba4, 0x3b526ba9, 0x11005205,   // is.ha.sw_554 tr.ro.ha_433  ceb.ha.so_544 ha.ro.un_330
  0x1300352b, 0x2d0d280c, 0x52681ea9, 0x6b3b25a9,   // zu.et.un_980 sw.cs.sk_543  ms.ig.ha_544 eu.so.ceb_544
  // [78d0]
  0x231f06ad, 0x113f1308, 0x52551ba9, 0x023f1213,   // de.cy.ca_643 et.af.ro_443  tr.rw.ha_544 hu.af.da_665
  0x551a35a4, 0x11001e07, 0x6b552512, 0x6800522c,   // zu.tl.rw_433 ms.ro.un_420  eu.rw.ceb_654 ha.ig.un_990
  0x551e250c, 0x05011a0d, 0x12002520, 0x13251012,   // eu.ms.rw_543 tl.en.fr_554  eu.hu.un_850 lt.eu.et_654
  0x130c05ec, 0x0a131204, 0x253506ad, 0x280911ac,   // fr.sv.et_644 hu.et.pt_332  de.zu.eu_643 ro.pl.sw_632
  // [78e0]
  0x03040da4, 0x0d0c13a7, 0x12113f08, 0x532128ad,   // cs.fi.nl_433 et.sv.cs_532  af.ro.hu_443 sw.jw.ht_643
  0x1b55280d, 0x5500210d, 0x0802280c, 0x0d062d0c,   // sw.rw.tr_554 jw.rw.un_540  sw.da.no_543 sk.de.cs_543
  0x353b640d, 0x20000702, 0x350f3ba4, 0x35525512,   // lg.so.zu_554 it.sq.un_220  so.lv.zu_433 rw.ha.zu_654
  0x043f3ba4, 0x12000208, 0x3b2a520c, 0x17000402,   // so.af.fi_433 da.hu.un_430  ha.mt.so_543 ru.sr.un_220
  // [78f0]
  0x31021b55, 0x1f0e0cee, 0x283b53a4, 0x1f080213,   // tr.da.az_442 sv.is.cy_422  ht.so.sw_433 da.no.cy_665
  0x2a005223, 0x3b0b68ee, 0x0f003b0c, 0x29001309,   // ha.mt.un_880 ig.es.so_422  so.lv.un_530 et.sl.un_440
  0x53001f0e, 0x3f090d12, 0x021f08ec, 0x12002b1a,   // cy.ht.un_550 cs.pl.af_654  no.cy.da_644 vi.hu.un_760
  0x121f2da0, 0x08022007, 0x03002507, 0x01350708,   // sk.cy.hu_322 sq.da.no_432  eu.nl.un_420 it.zu.en_443
  // [7900]
  0x1a063fa0, 0x19001f07, 0x0e002512, 0x20291a09,   // af.de.tl_322 cy.gl.un_420  eu.is.un_640 tl.sl.sq_444
  0x050720ec, 0x0b252005, 0x0a5206a4, 0x322012ad,   // sq.it.fr_644 sq.eu.es_333  de.ha.pt_433 hu.sq.bs_643
  0x0200190d, 0x011868ee, 0x1216640c, 0x1c1e1a0c,   // gl.da.un_540 ig.ga.en_422  lg.hr.hu_543 tl.ms.id_543
  0x1e551c0c, 0x05001a0b, 0x190a5505, 0x0d292d0d,   // id.rw.ms_543 tl.fr.un_520  rw.pt.gl_333 sk.sl.cs_554
  // [7910]
  0x1c181e04, 0x06181f0d, 0x100f5211, 0x642916a9,   // ms.ga.id_332 cy.ga.de_554  ha.lv.lt_653 hr.sl.lg_544
  0x0b0e19a4, 0x0a001e08, 0x0a002322, 0x27281813,   // gl.is.es_433 ms.pt.un_430  ca.pt.un_870 ga.sw.gd_665
  0x25001008, 0x6800250c, 0x171b35ac, 0x18282bee,   // lt.eu.un_430 eu.ig.un_530  zu.tr.sr_632 vi.sw.ga_422
  0x16000207, 0x06000704, 0x190a0b11, 0x532d0604,   // da.hr.un_420 it.de.un_320  es.pt.gl_653 de.sk.ht_332
  // [7920]
  0x643b070e, 0x4a0c28a0, 0x04000b02, 0x0402280d,   // it.so.lg_555 sw.sv.yo_322  es.fi.un_220 sw.da.fi_554
  0x132d0904, 0x043f64a0, 0x25002107, 0x6b201aa0,   // pl.sk.et_332 lg.af.fi_322  jw.eu.un_420 tl.sq.ceb_322
  0x0a6b0ca4, 0x20000c02, 0x060c0513, 0x092568a0,   // sv.ceb.pt_433 sv.sq.un_220  fr.sv.de_665 ig.eu.pl_322
  0x1f1a0aa6, 0x05190a09, 0x2a092d60, 0x3b6852a9,   // pt.tl.cy_521 pt.gl.fr_444  sk.pl.mt_664 ha.ig.so_544
  // [7930]
  0x320d2aa7, 0x2a28680d, 0x6e092d12, 0x68214a0c,   // mt.cs.bs_532 ig.sw.mt_554  sk.pl.hmn_654 yo.jw.ig_543
  0x35000302, 0x2a080eac, 0x03350cad, 0x68184aa9,   // nl.zu.un_220 is.no.mt_632  sv.zu.nl_643 yo.ga.ig_544
  0x11520e0e, 0x091f1012, 0x2b520aa7, 0x3b4a520c,   // is.ha.ro_555 lt.cy.pl_654  pt.ha.vi_532 ha.yo.so_543
  0x08250e13, 0x3b1917a4, 0x28001107, 0x0a001c0d,   // is.eu.no_665 sr.gl.so_433  ro.sw.un_420 id.pt.un_540
  // [7940]
  0x2a2035a9, 0x13110cad, 0x0b3f04a4, 0x1900290c,   // zu.sq.mt_544 sv.ro.et_643  fi.af.es_433 sl.gl.un_530
  0x2a000f05, 0x120852a7, 0x521304ec, 0x3b002502,   // lv.mt.un_330 ha.no.hu_532  fi.et.ha_644 eu.so.un_220
  0x02000f19, 0x4a002812, 0x32000f0c, 0x523555af,   // lv.da.un_750 sw.yo.un_640  lv.bs.un_530 rw.zu.ha_655
  0x4a2010ec, 0x06002109, 0x2a640e07, 0x0d100908,   // lt.sq.yo_644 jw.de.un_440  is.lg.mt_432 pl.lt.cs_443
  // [7950]
  0x210952ee, 0x0802290c, 0x35525507, 0x20291055,   // ha.pl.jw_422 sl.da.no_543  rw.ha.zu_432 lt.sl.sq_442
  0x0e0c06ee, 0x6b051aa4, 0x02050812, 0x2d0f06a9,   // de.sv.is_422 tl.fr.ceb_433  no.fr.da_654 de.lv.sk_544
  0x1a52060b, 0x1b00070c, 0x10000d0d, 0x050253a0,   // de.ha.tl_542 it.tr.un_530  cs.lt.un_540 ht.da.fr_322
  0x1e641cee, 0x05010fa4, 0x0a001305, 0x18110713,   // id.lg.ms_422 lv.en.fr_433  et.pt.un_330 it.ro.ga_665
  // [7960]
  0x072a1208, 0x0e07050d, 0x130725a9, 0x112d2104,   // hu.mt.it_443 fr.it.is_554  eu.it.et_544 jw.sk.ro_332
  0x23000c04, 0x352568a0, 0x0b0e19a7, 0x25000d04,   // sv.ca.un_320 ig.eu.zu_322  gl.is.es_532 cs.eu.un_320
  0x190a0ca4, 0x11001708, 0x022b0e0b, 0x23050209,   // sv.pt.gl_433 sr.ro.un_430  is.vi.da_542 da.fr.ca_444
  0x1b181fee, 0x10072014, 0x07005514, 0x210753a7,   // cy.ga.tr_422 sq.it.lt_666  rw.it.un_660 ht.it.jw_532
  // [7970]
  0x2b550a0c, 0x072b21a4, 0x0e000913, 0x28002112,   // pt.rw.vi_543 jw.vi.it_433  pl.is.un_650 jw.sw.un_640
  0x121e10a7, 0x0f10200c, 0x28185202, 0x120d04a4,   // lt.ms.hu_532 sq.lt.lv_543  ha.ga.sw_222 fi.cs.hu_433
  0x1c32160d, 0x17000908, 0x1008070e, 0x16112da4,   // hr.bs.id_554 pl.sr.un_430  bg.uk.be_555 sk.ro.hr_433
  0x01005207, 0x190b0708, 0x1c006419, 0x350d2dec,   // ha.en.un_420 it.es.gl_443  lg.id.un_750 sk.cs.zu_644
  // [7980]
  0x06102aa4, 0x190a0502, 0x2a000413, 0x20041205,   // mt.lt.de_433 fr.pt.gl_222  fi.mt.un_650 hu.fi.sq_333
  0x0e070da9, 0x29682d11, 0x051227a0, 0x113155a0,   // cs.it.is_544 sk.ig.sl_653  gd.hu.fr_322 rw.az.ro_322
  0x12000b07, 0x0c2a10af, 0x13236b14, 0x2b1c2109,   // es.hu.un_420 lt.mt.sv_655  ceb.ca.et_666 jw.id.vi_444
  0x2d0d0b0c, 0x1f000202, 0x110468a0, 0x1c1929a0,   // es.cs.sk_543 da.cy.un_220  ig.fi.ro_322 sl.gl.id_322
  // [7990]
  0x132904ec, 0x52131013, 0x083132a0, 0x02080c55,   // fi.sl.et_644 lt.et.ha_665  bs.az.no_322 sv.no.da_442
  0x28216ba4, 0x1f350f12, 0x1107050c, 0x1f183b07,   // ceb.jw.sw_433 lv.zu.cy_654  fr.it.ro_543 so.ga.cy_432
  0x2753180c, 0x1e201c0c, 0x6b030612, 0x52531807,   // ga.ht.gd_543 id.sq.ms_543  de.nl.ceb_654 ga.ht.ha_432
  0x1b530108, 0x250405ec, 0x3127250c, 0x100e21af,   // en.ht.tr_443 fr.fi.eu_644  eu.gd.az_543 jw.is.lt_655
  // [79a0]
  0x3217040c, 0x27051f07, 0x03000519, 0x321217a0,   // fi.sr.bs_543 cy.fr.gd_432  fr.nl.un_750 sr.hu.bs_322
  0x2d0d31a0, 0x020e250c, 0x6b6401ec, 0x190b2511,   // az.cs.sk_322 eu.is.da_543  en.lg.ceb_644 eu.es.gl_653
  0x3b64280d, 0x1c001602, 0x2a003521, 0x2d0d05ee,   // sw.lg.so_554 hr.id.un_220  zu.mt.un_860 fr.cs.sk_422
  0x52181008, 0x1004180c, 0x251805ec, 0x52131008,   // lt.ga.ha_443 ga.fi.lt_543  fr.ga.eu_644 lt.et.ha_443
  // [79b0]
  0x5200181b, 0x6b0a0604, 0x07003520, 0x251a1f13,   // ga.ha.un_770 de.pt.ceb_332  zu.it.un_850 cy.tl.eu_665
  0x0728110c, 0x06002520, 0x1c130d05, 0x1b0e21a7,   // ro.sw.it_543 eu.de.un_850  ne.bh.mr_333 jw.is.tr_532
  0x013f1314, 0x28521f12, 0x1e1c6409, 0x1a1b6ba4,   // et.af.en_666 cy.ha.sw_654  lg.id.ms_444 ceb.tr.tl_433
  0x352319a9, 0x2531180c, 0x31681808, 0x551021a9,   // gl.ca.zu_544 ga.az.eu_543  ga.ig.az_443 jw.lt.rw_544
  // [79c0]
  0x0f000907, 0x131b040c, 0x531b0707, 0x6b641b12,   // pl.lv.un_420 fi.tr.et_543  it.tr.ht_432 tr.lg.ceb_654
  0x0c133108, 0x1b000f04, 0x1b3109a7, 0x11001308,   // az.et.sv_443 lv.tr.un_320  pl.az.tr_532 et.ro.un_430
  0x352b28ee, 0x0e0c1ba4, 0x29002511, 0x322a68a0,   // sw.vi.zu_422 tr.sv.is_433  eu.sl.un_630 ig.mt.bs_322
  0x0e3f1b02, 0x131a2113, 0x060823ee, 0x021b1c0c,   // tr.af.is_222 jw.tl.et_665  ca.no.de_422 id.tr.da_543
  // [79d0]
  0x2509200c, 0x530628a7, 0x0c1f3bad, 0x25350313,   // sq.pl.eu_543 sw.de.ht_532  so.cy.sv_643 nl.zu.eu_665
  0x1e2a3b07, 0x3b5264ec, 0x0a1a0408, 0x080228af,   // so.mt.ms_432 lg.ha.so_644  fi.tl.pt_443 sw.da.no_655
  0x11525507, 0x03203f08, 0x3b5520a4, 0x1e006405,   // rw.ha.ro_432 af.sq.nl_443  sq.rw.so_433 lg.ms.un_330
  0x18122dec, 0x2b000e1a, 0x3b0e64ec, 0x071f3b0c,   // sk.hu.ga_644 is.vi.un_760  lg.is.so_644 so.cy.it_543
  // [79e0]
  0x55312805, 0x2b001007, 0x0d0b0a05, 0x3f1b31a9,   // sw.az.rw_333 lt.vi.un_420  pt.es.cs_333 az.tr.af_544
  0x0d1208ad, 0x532055af, 0x1e5228ad, 0x1e6b1c0c,   // no.hu.cs_643 rw.sq.ht_655  sw.ha.ms_643 id.ceb.ms_543
  0x012005ad, 0x2a6435ec, 0x55072a09, 0x0d202812,   // fr.sq.en_643 zu.lg.mt_644  mt.it.rw_444 sw.sq.cs_654
  0x0800060b, 0x252007ad, 0x10201f0c, 0x0b1205ec,   // de.no.un_520 it.sq.eu_643  cy.sq.lt_543 fr.hu.es_644
  // [79f0]
  0x07002021, 0x0755200c, 0x210464a6, 0x3b0b52a0,   // sq.it.un_860 sq.rw.it_543  lg.fi.jw_521 ha.es.so_322
  0x033b1ba0, 0x095505a4, 0x0a551107, 0x16091b08,   // tr.so.nl_322 fr.rw.pl_433  ro.rw.pt_432 tr.pl.hr_443
  0x6b1a0eaf, 0x062725ec, 0x0f312512, 0x16203207,   // is.tl.ceb_655 eu.gd.de_644  eu.az.lv_654 bs.sq.hr_432
  0x0b310cee, 0x0500061a, 0x64001321, 0x64551113,   // sv.az.es_422 de.fr.un_760  et.lg.un_860 ro.rw.lg_665
  // [7a00]
  0x1b20310d, 0x022a080b, 0x1a000307, 0x11123f0d,   // az.sq.tr_554 no.mt.da_542  nl.tl.un_420 af.hu.ro_554
  0x180c0609, 0x23053f0c, 0x0f2a07ec, 0x09002921,   // de.sv.ga_444 af.fr.ca_543  it.mt.lv_644 sl.pl.un_860
  0x64551309, 0x32101712, 0x05122aec, 0x20132a0c,   // et.rw.lg_444 sr.lt.bs_654  mt.hu.fr_644 mt.et.sq_543
  0x4a642813, 0x2d0d2a05, 0x0a1307ee, 0x106b0f0c,   // sw.lg.yo_665 mt.cs.sk_333  it.et.pt_422 lv.ceb.lt_543
  // [7a10]
  0x0c001114, 0x0d0f2d07, 0x09204aee, 0x6b071ca0,   // ro.sv.un_660 sk.lv.cs_432  yo.sq.pl_422 id.it.ceb_322
  0x11070d0c, 0x64051309, 0x32175505, 0x162955a4,   // cs.it.ro_543 et.fr.lg_444  rw.sr.bs_333 rw.sl.hr_433
  0x6b051208, 0x28000e1a, 0x11003b0e, 0x32161eaf,   // hu.fr.ceb_443 is.sw.un_760  so.ro.un_550 ms.hr.bs_655
  0x29001b09, 0x0c2304ee, 0x10001e02, 0x2d0d2a0c,   // tr.sl.un_440 fi.ca.sv_422  ms.lt.un_220 mt.cs.sk_543
  // [7a20]
  0x081a0e04, 0x1c0e1e0c, 0x06081aa4, 0x160d1707,   // is.tl.no_332 ms.is.id_543  tl.no.de_433 sr.cs.hr_432
  0x1e1c2905, 0x12003118, 0x320d1bee, 0x18006e0b,   // sl.id.ms_333 az.hu.un_740  tr.cs.bs_422 hmn.ga.un_520
  0x091b1208, 0x1c031b0c, 0x3f230ea7, 0x080c3f0d,   // hu.tr.pl_443 tr.nl.id_543  is.ca.af_532 af.sv.no_554
  0x052927a0, 0x120905a4, 0x020c08a7, 0x29002319,   // gd.sl.fr_322 fr.pl.hu_433  no.sv.da_532 ca.sl.un_750
  // [7a30]
  0x0f1f1813, 0x52550aec, 0x07030e0c, 0x18006405,   // ga.cy.lv_665 pt.rw.ha_644  is.nl.it_543 lg.ga.un_330
  0x190a2dec, 0x0b191212, 0x111e20a4, 0x21070608,   // sk.pt.gl_644 hu.gl.es_654  sq.ms.ro_433 de.it.jw_443
  0x0a1b2b0c, 0x17212d07, 0x08020f09, 0x251b32af,   // vi.tr.pt_543 sk.jw.sr_432  lv.da.no_444 bs.tr.eu_655
  0x311f1ba4, 0x12184a0c, 0x6b004a14, 0x031f09a7,   // tr.cy.az_433 yo.ga.hu_543  yo.ceb.un_660 pl.cy.nl_532
  // [7a40]
  0x010464a0, 0x28000a02, 0x20051b0c, 0x0f090dec,   // lg.fi.en_322 pt.sw.un_220  tr.fr.sq_543 cs.pl.lv_644
  0x0b3f06ee, 0x05000408, 0x2d123502, 0x282a3f02,   // de.af.es_422 fi.fr.un_430  zu.hu.sk_222 af.mt.sw_222
  0x013b2aee, 0x21125507, 0x062a09ad, 0x12050fee,   // mt.so.en_422 rw.hu.jw_432  pl.mt.de_643 lv.fr.hu_422
  0x0f003112, 0x2a001802, 0x55001112, 0x0f002a04,   // az.lv.un_640 ga.mt.un_220  ro.rw.un_640 mt.lv.un_320
  // [7a50]
  0x0802350c, 0x05190a14, 0x19180bec, 0x0a052308,   // zu.da.no_543 pt.gl.fr_666  es.ga.gl_644 ca.fr.pt_443
  0x0d076455, 0x123510ac, 0x521a0612, 0x190b25ac,   // lg.it.cs_442 lt.zu.hu_632  de.tl.ha_654 eu.es.gl_632
  0x521c110c, 0x030620ad, 0x126407a9, 0x6b005305,   // ro.id.ha_543 sq.de.nl_643  it.lg.hu_544 ht.ceb.un_330
  0x13001904, 0x1b000704, 0x1c051ea4, 0x12060eee,   // gl.et.un_320 it.tr.un_320  ms.fr.id_433 is.de.hu_422
  // [7a60]
  0x281a64ec, 0x0d002312, 0x25002907, 0x111b3b0c,   // lg.tl.sw_644 ca.cs.un_640  sl.eu.un_420 so.tr.ro_543
  0x03002112, 0x311b64a9, 0x3b003107, 0x25032812,   // jw.nl.un_640 lg.tr.az_544  az.so.un_420 sw.nl.eu_654
  0x0a531ea4, 0x1c556409, 0x21641a5a, 0x250f0ca7,   // ms.ht.pt_433 lg.rw.id_444  tl.lg.jw_553 sv.lv.eu_532
  0x4a0b6408, 0x17003b04, 0x2128640d, 0x2100310e,   // lg.es.yo_443 so.sr.un_320  lg.sw.jw_554 az.jw.un_550
  // [7a70]
  0x120e2d04, 0x2a521055, 0x03193fa4, 0x090f25a0,   // sk.is.hu_332 lt.ha.mt_442  af.gl.nl_433 eu.lv.pl_322
  0x25001b07, 0x1a21010c, 0x20002118, 0x27182112,   // tr.eu.un_420 en.jw.tl_543  jw.sq.un_740 jw.ga.gd_654
  0x19530b55, 0x251c1eec, 0x23001f0c, 0x640a1ba4,   // es.ht.gl_442 ms.id.eu_644  cy.ca.un_530 tr.pt.lg_433
  0x100b0408, 0x1b001f0c, 0x53001b1b, 0x3b001a2c,   // fi.es.lt_443 cy.tr.un_530  tr.ht.un_770 tl.so.un_990
  // [7a80]
  0x32283bad, 0x3f35640e, 0x190a08a9, 0x29005504,   // so.sw.bs_643 lg.zu.af_555  no.pt.gl_544 rw.sl.un_320
  0x032508a9, 0x2d060d11, 0x2a1a3b08, 0x190a01a4,   // no.eu.nl_544 cs.de.sk_653  so.tl.mt_443 en.pt.gl_433
  0x32000a0c, 0x5511250c, 0x1b1c2112, 0x0325090c,   // pt.bs.un_530 eu.ro.rw_543  jw.id.tr_654 pl.eu.nl_543
  0x53000d19, 0x3b1c1eac, 0x550153ee, 0x1f006807,   // cs.ht.un_750 ms.id.so_632  ht.en.rw_422 ig.cy.un_420
  // [7a90]
  0x53556409, 0x21132a07, 0x280411a0, 0x0e17080c,   // lg.rw.ht_444 mt.et.jw_432  ro.fi.sw_322 no.sr.is_543
  0x13283bad, 0x11001702, 0x3208530c, 0x1e211c0d,   // so.sw.et_643 sr.ro.un_220  ht.no.bs_543 id.jw.ms_554
  0x202d07ac, 0x1f52535a, 0x230f3f08, 0x52531f0c,   // it.sk.sq_632 ht.ha.cy_553  af.lv.ca_443 cy.ht.ha_543
  0x06000913, 0x6e190a0e, 0x31285208, 0x2d0d2955,   // pl.de.un_650 pt.gl.hmn_555  ha.sw.az_443 sl.cs.sk_442
  // [7aa0]
  0x1e04530c, 0x06230baf, 0x53285208, 0x680952af,   // ht.fi.ms_543 es.ca.de_655  ha.sw.ht_443 ha.pl.ig_655
  0x1f3b0a5a, 0x5300320c, 0x271a6bad, 0x2a27520c,   // pt.so.cy_553 bs.ht.un_530  ceb.tl.gd_643 ha.gd.mt_543
  0x3b0f1fa9, 0x3f4a35ee, 0x25001318, 0x0800091a,   // cy.lv.so_544 zu.yo.af_422  et.eu.un_740 pl.no.un_760
  0x06091108, 0x07082b13, 0x0c010212, 0x05010614,   // ro.pl.de_443 vi.no.it_665  da.en.sv_654 de.en.fr_666
  // [7ab0]
  0x6b642d12, 0x112521ad, 0x6b101c0c, 0x0c06350e,   // sk.lg.ceb_654 jw.eu.ro_643  id.lt.ceb_543 zu.de.sv_555
  0x1e3b3112, 0x31121005, 0x1b0e120c, 0x1e1c64ec,   // az.so.ms_654 lt.hu.az_333  hu.is.tr_543 lg.id.ms_644
  0x06101ba4, 0x0d3121a0, 0x1c041eee, 0x021f0ca4,   // tr.lt.de_433 jw.az.cs_322  ms.fi.id_422 sv.cy.da_433
  0x011b0eee, 0x202855a0, 0x07281a0c, 0x0b1153af,   // is.tr.en_422 rw.sw.sq_322  tl.sw.it_543 ht.ro.es_655
  // [7ac0]
  0x2d002319, 0x0718645a, 0x0f002012, 0x110755af,   // ca.sk.un_750 lg.ga.it_553  sq.lv.un_640 rw.it.ro_655
  0x03230cee, 0x071328a9, 0x1e290fad, 0x27351fee,   // sv.ca.nl_422 sw.et.it_544  lv.sl.ms_643 cy.zu.gd_422
  0x3f000a14, 0x1a254a08, 0x1f001819, 0x18000509,   // pt.af.un_660 yo.eu.tl_443  ga.cy.un_750 fr.ga.un_440
  0x641b5512, 0x646b1b0c, 0x1e1c07a4, 0x2807215a,   // rw.tr.lg_654 tr.ceb.lg_543  it.id.ms_433 jw.it.sw_553
  // [7ad0]
  0x0b230aa0, 0x081f0e04, 0x0a070f12, 0x3100231b,   // pt.ca.es_322 is.cy.no_332  lv.it.pt_654 ca.az.un_770
  0x530b6ba0, 0x55070509, 0x0f182713, 0x210c2bee,   // ceb.es.ht_322 fr.it.rw_444  gd.ga.lv_665 vi.sv.jw_422
  0x071321a7, 0x6b005307, 0x6b354aec, 0x100e0cad,   // jw.et.it_532 ht.ceb.un_420  yo.zu.ceb_644 sv.is.lt_643
  0x190a1809, 0x08005302, 0x080e010c, 0x11071c07,   // ga.pt.gl_444 ht.no.un_220  en.is.no_543 id.it.ro_432
  // [7ae0]
  0x55211c09, 0x0b120a5a, 0x2d0d02ec, 0x682135a4,   // id.jw.rw_444 pt.hu.es_553  da.cs.sk_644 zu.jw.ig_433
  0x5300250c, 0x2000091b, 0x05270805, 0x08020c5a,   // eu.ht.un_530 pl.sq.un_770  no.gd.fr_333 sv.da.no_553
  0x1c211e08, 0x2d002314, 0x0c3518ec, 0x23002005,   // ms.jw.id_443 ca.sk.un_660  ga.zu.sv_644 sq.ca.un_330
  0x206e090c, 0x0a003b11, 0x53002908, 0x29096e0c,   // pl.hmn.sq_543 so.pt.un_630  sl.ht.un_430 hmn.pl.sl_543
  // [7af0]
  0x190b18a4, 0x0a283b0c, 0x35000212, 0x55002a29,   // ga.es.gl_433 so.sw.pt_543  da.zu.un_640 mt.rw.un_960
  0x520a3b12, 0x06012b04, 0x684a520b, 0x3f03230e,   // so.pt.ha_654 vi.en.de_332  ha.yo.ig_542 ca.nl.af_555
  0x18174a02, 0x6e00230d, 0x173132ee, 0x0c0604ec,   // yo.sr.ga_222 ca.hmn.un_540  bs.az.sr_422 fi.de.sv_644
  0x171e1107, 0x1e521c11, 0x19000702, 0x030f3fad,   // ro.ms.sr_432 id.ha.ms_653  it.gl.un_220 af.lv.nl_643
  // [7b00]
  0x03053f13, 0x29132dec, 0x04280dee, 0x35104aa7,   // af.fr.nl_665 sk.et.sl_644  cs.sw.fi_422 yo.lt.zu_532
  0x3b200f12, 0x1e00100c, 0x1b1f31ee, 0x05682813,   // lv.sq.so_654 lt.ms.un_530  az.cy.tr_422 sw.ig.fr_665
  0x1f4a0e08, 0x110c07a0, 0x0700050c, 0x5200071b,   // is.yo.cy_443 it.sv.ro_322  fr.it.un_530 it.ha.un_770
  0x10000f05, 0x03000819, 0x120855a7, 0x2b281c55,   // lv.lt.un_330 no.nl.un_750  rw.no.hu_532 id.sw.vi_442
  // [7b10]
  0x022d080b, 0x0e4a52a9, 0x32030eee, 0x10160707,   // no.sk.da_542 ha.yo.is_544  is.nl.bs_422 it.hr.lt_432
  0x1b524a0d, 0x0c006b02, 0x061103ec, 0x13253b5a,   // yo.ha.tr_554 ceb.sv.un_220  nl.ro.de_644 so.eu.et_553
  0x1c351eee, 0x020c03a0, 0x0b0f25a0, 0x131c08ee,   // ms.zu.id_422 nl.sv.da_322  eu.lv.es_322 no.id.et_422
  0x4a3f68ec, 0x213b0213, 0x13002919, 0x230b080e,   // ig.af.yo_644 da.so.jw_665  sl.et.un_750 no.es.ca_555
  // [7b20]
  0x2b350111, 0x0b006402, 0x0c08350b, 0x28001f04,   // en.zu.vi_653 lg.es.un_220  zu.no.sv_542 cy.sw.un_320
  0x210235ad, 0x21003119, 0x21313b13, 0x060d1fad,   // zu.da.jw_643 az.jw.un_750  so.az.jw_665 cy.cs.de_643
  0x6e002b09, 0x1a2b01ad, 0x061b12af, 0x3f1f35ee,   // vi.hmn.un_440 en.vi.tl_643  hu.tr.de_655 zu.cy.af_422
  0x091f64a4, 0x350231a0, 0x1f020812, 0x10043509,   // lg.cy.pl_433 az.da.zu_322  no.da.cy_654 zu.fi.lt_444
  // [7b30]
  0x0e081aee, 0x101235ee, 0x193b0a08, 0x0c042107,   // tl.no.is_422 zu.hu.lt_422  pt.so.gl_443 jw.fi.sv_432
  0x52002102, 0x3f0f050c, 0x050621ee, 0x32051707,   // jw.ha.un_220 fr.lv.af_543  jw.de.fr_422 sr.fr.bs_432
  0x11071760, 0x3b002d04, 0x04133b05, 0x0c003f13,   // sr.bg.ro_664 sk.so.un_320  so.et.fi_333 af.sv.un_650
  0x1f0335a4, 0x0c1f08a0, 0x1c681e55, 0x056421a7,   // zu.nl.cy_433 no.cy.sv_322  ms.ig.id_442 jw.lg.fr_532
  // [7b40]
  0x0b231109, 0x1a6b520e, 0x3500530c, 0x20001911,   // ro.ca.es_444 ha.ceb.tl_555  ht.zu.un_530 gl.sq.un_630
  0x4a002108, 0x1e1c0da4, 0x04060e04, 0x0c00280c,   // jw.yo.un_430 cs.id.ms_433  is.de.fi_332 sw.sv.un_530
  0x250f550d, 0x080229ee, 0x35642507, 0x3f020308,   // rw.lv.eu_554 sl.da.no_422  eu.lg.zu_432 nl.da.af_443
  0x1e08550c, 0x10066b0c, 0x12052aa7, 0x351123a0,   // rw.no.ms_543 ceb.de.lt_543  mt.fr.hu_532 ca.ro.zu_322
  // [7b50]
  0x1a104aa9, 0x21522812, 0x112923ee, 0x06080ead,   // yo.lt.tl_544 sw.ha.jw_654  ca.sl.ro_422 is.no.de_643
  0x00000101, 0x19090b12, 0x553220ad, 0x2b000521,   // en.un.un_200 es.pl.gl_654  sq.bs.rw_643 fr.vi.un_860
  0x0b00052b, 0x280f10ad, 0x531a1c0c, 0x1a6b1ca0,   // fr.es.un_980 lt.lv.sw_643  id.tl.ht_543 id.ceb.tl_322
  0x1c0f1ea4, 0x53002507, 0x17291aa9, 0x25000321,   // ms.lv.id_433 eu.ht.un_420  tl.sl.sr_544 nl.eu.un_860
  // [7b60]
  0x2a1b31a9, 0x31251b60, 0x320929ee, 0x0b050fec,   // az.tr.mt_544 tr.eu.az_664  sl.pl.bs_422 lv.fr.es_644
  0x2b100faf, 0x3b6b64a6, 0x090810a9, 0x0e29100c,   // lv.lt.vi_655 lg.ceb.so_521  lt.no.pl_544 lt.sl.is_543
  0x1a1204a9, 0x0b00210c, 0x0e0811ec, 0x033f68a0,   // fi.hu.tl_544 jw.es.un_530  ro.no.is_644 ig.af.nl_322
  0x27522904, 0x1e1c53a4, 0x0452550c, 0x2d0d0ea4,   // sl.ha.gd_332 ht.id.ms_433  rw.ha.fi_543 is.cs.sk_433
  // [7b70]
  0x32002504, 0x280e520d, 0x2855190b, 0x180a07a0,   // eu.bs.un_320 ha.is.sw_554  gl.rw.sw_542 it.pt.ga_322
  0x19000908, 0x072801a4, 0x076b1fa4, 0x1000281b,   // pl.gl.un_430 en.sw.it_433  cy.ceb.it_433 sw.lt.un_770
  0x093507ee, 0x092152ad, 0x08123b09, 0x2d0d53a4,   // it.zu.pl_422 ha.jw.pl_643  so.hu.no_444 ht.cs.sk_433
  0x2d0603ee, 0x1f0518a4, 0x072805af, 0x32171aa6,   // nl.de.sk_422 ga.fr.cy_433  fr.sw.it_655 tl.sr.bs_521
  // [7b80]
  0x190b35a4, 0x02002a02, 0x28001821, 0x55002a13,   // zu.es.gl_433 mt.da.un_220  ga.sw.un_860 mt.rw.un_650
  0x0c521aad, 0x230b530c, 0x681b0708, 0x0d092da7,   // tl.ha.sv_643 ht.es.ca_543  it.tr.ig_443 sk.pl.cs_532
  0x28000b09, 0x050108a0, 0x161118a7, 0x13520da4,   // es.sw.un_440 no.en.fr_322  ga.ro.hr_532 cs.ha.et_433
  0x01530ca0, 0x0c09020e, 0x550b4aee, 0x111368a9,   // sv.ht.en_322 da.pl.sv_555  yo.es.rw_422 ig.et.ro_544
  // [7b90]
  0x13002d22, 0x521155ad, 0x23002112, 0x166429a0,   // sk.et.un_870 rw.ro.ha_643  jw.ca.un_640 sl.lg.hr_322
  0x08025502, 0x202b31ee, 0x1b310e60, 0x0c0d3f04,   // rw.da.no_222 az.vi.sq_422  is.az.tr_664 af.cs.sv_332
  0x21526407, 0x211020a4, 0x211c200c, 0x1f000e2a,   // lg.ha.jw_432 sq.lt.jw_433  sq.id.jw_543 is.cy.un_970
  0x23110ead, 0x29021308, 0x20006e04, 0x0c190a14,   // is.ro.ca_643 et.da.sl_443  hmn.sq.un_320 pt.gl.sv_666
  // [7ba0]
  0x1b252005, 0x1b0e2aad, 0x192d0eb4, 0x200e1c0c,   // sq.eu.tr_333 mt.is.tr_643  is.sk.gl_754 id.is.sq_543
  0x0b230aad, 0x12002d21, 0x310e2008, 0x211f200c,   // pt.ca.es_643 sk.hu.un_860  sq.is.az_443 sq.cy.jw_543
  0x0e1f2009, 0x18122db6, 0x291317a0, 0x0b006b04,   // sq.cy.is_444 sk.hu.ga_766  sr.et.sl_322 ceb.es.un_320
  0x08001222, 0x53112012, 0x06072aa9, 0x281a350d,   // hu.no.un_870 sq.ro.ht_654  mt.it.de_544 zu.tl.sw_554
  // [7bb0]
  0x190b07ec, 0x321707ee, 0x110f25ad, 0x2835210e,   // it.es.gl_644 it.sr.bs_422  eu.lv.ro_643 jw.zu.sw_555
  0x080e3fa0, 0x110853ec, 0x55072a12, 0x530325ad,   // af.is.no_322 ht.no.ro_644  mt.it.rw_654 eu.nl.ht_643
  0x3b002121, 0x2a12070c, 0x28183b5a, 0x07002514,   // jw.so.un_860 it.hu.mt_543  so.ga.sw_553 eu.it.un_660
  0x6e006813, 0x0c192504, 0x0e0c010c, 0x64550c0d,   // ig.hmn.un_650 eu.gl.sv_332  en.sv.is_543 sv.rw.lg_554
  // [7bc0]
  0x05002102, 0x08250c08, 0x17080aac, 0x190a250d,   // jw.fr.un_220 sv.eu.no_443  mk.uk.sr_632 eu.pt.gl_554
  0x28182008, 0x2a0a6b12, 0x0c0806ee, 0x041a1fad,   // sq.ga.sw_443 ceb.pt.mt_654  de.no.sv_422 cy.tl.fi_643
  0x181a27ad, 0x1a0835ee, 0x3b2827a4, 0x321016a4,   // gd.tl.ga_643 zu.no.tl_422  gd.sw.so_433 hr.lt.bs_433
  0x351f2812, 0x230f02a4, 0x1e000b04, 0x273518af,   // sw.cy.zu_654 da.lv.ca_433  es.ms.un_320 ga.zu.gd_655
  // [7bd0]
  0x1a046bee, 0x230c020c, 0x0e271a0c, 0x6400290b,   // ceb.fi.tl_422 da.sv.ca_543  tl.gd.is_543 sl.lg.un_520
  0x2855010c, 0x09122a0e, 0x16292da6, 0x20001214,   // en.rw.sw_543 mt.hu.pl_555  sk.sl.hr_521 hu.sq.un_660
  0x063f08ac, 0x196401a7, 0x2b1c01a6, 0x2d090205,   // no.af.de_632 en.lg.gl_532  en.id.vi_521 da.pl.sk_333
  0x03000405, 0x041e1902, 0x25091208, 0x250d1ba4,   // fi.nl.un_330 gl.ms.fi_222  hu.pl.eu_443 tr.cs.eu_433
  // [7be0] --- double_langprob_start=7bea ---
  0x2a00201b, 0x521331ee, 0x2a00640e, 0x5368350e,   // sq.mt.un_770 az.et.ha_422  lg.mt.un_550 zu.ig.ht_555
  0x030d200c, 0x0100190b, 0x0e251fad, 0x0a112d04,   // sq.cs.nl_543 gl.en.un_520  cy.eu.is_643 sk.ro.pt_332
  0x080635a0, 0x286b11a0,                           // zu.de.no_322 ro.ceb.sw_322
                                                    //
  };

//  COMPILE_ASSERT(31722 <= 32768, k_indirectbits_too_small);

extern const CLD2TableSummary kQuad_obj = {
  kQuadChrome0122_19,
  kQuadChrome0122_19Ind,
  kQuadChrome0122_19SizeOne,
  kQuadChrome0122_19Size,
  kQuadChrome0122_19KeyMask,
  kQuadChrome0122_19BuildDate,
  kQuadChrome0122_19RecognizedLangScripts,
};

static const uint32 kQuadChrome0122_19_2Size = 16384;    // Bucket count
static const uint32 kQuadChrome0122_19_2KeyMask = 0xffffc000;    // Mask hash key

static const IndirectProbBucket4 kQuadChrome0122_19_2[kQuadChrome0122_19_2Size] = {
  // hash_indirect[4], tokens[4] in UTF-8
   {{0x65638002,0x64438003,0x2d930004,0x7fe90005}},	// [000] kenh, huni, _foxe_, _حروف_,
   {{0x63bbc006,0x7bc44007,0x67f5c007,0x7c2e0008}},	//   hiun, sniu, _išju, psbr,
   {{0xf536c009,0xaf06800a,0x63a9c00b,0xe8dfc00c}},	//   שטער_, апел, khen, _thổi_,
   {{0x6e24000d,0xeb9a400e,0xdfcf800f,0x394a4010}},	//   _kwib, _рим_, ويل_, _wcbs_,
   {{0xddc40011,0x63bbc012,0x7c290013,0x7bc60014}},	//   _mriž, diun, ćere, inku,
   {{0x24518015,0x77644016,0x98a30017,0x69d74018}},	//   _bơm_, leix, lajā_, coxe,
   {{0x26cd8019,0xddc2c01a,0x7c85401b,0x2816401c}},	//   _exeo_, _prož, _луѓе, _خوزس,
   {{0xdb0d401d,0x27ed800c,0x25a0c01e,0xa5bb001f}},	//   riaç, _ghen_, _œil_, nsór,
   {{0xe8d9c015,0x2007c020,0xa3d74021,0x44234022}},	//   _đỡ_, _auni_, ाकत_, _zwj_,
   {{0x27ed8023,0x6f040024,0xb997c025,0x68054026}},	//   _zhen_, _agic, ивых_, _sėdi,
   {{0x1ddf8027,0x59df8028,0x44234022,0x6d794009}},	//   _पीटत, _पीटर, _xwj_, אָרװ,
   {{0x2007c029,0xa6b2002a,0xeb9ac02b,0x2fc6802c}},	//   _duni_, _টুইট, _шие_, nnog_,
   {{0x7528802d,0x229cc02e,0x2fc6802f,0x1958c030}},	//   _kedz, _dákú_, inog_, _балы_,
   {{0xddc44017,0x23a20031,0x7173c032,0xddc9802d}},	//   ltiņ, _fójo_, _وهنا, _treť,
   {{0x63a64033,0x2007c034,0x6d470035,0x6db28036}},	//   _blkn, _guni_, rgja, sław,
   {{0x65638037,0x7afdc038,0x291ec039,0xdcfc403a}},	//   zenh, ľstv, lbta_, _sorğ,
   {{0x6b8d403b,0x69d7403c,0x6443803d,0x2f0d803e}},	// [010] rjag, toxe, zuni, _lógó_,
   {{0x67c1c03f,0x44314039,0x7e6d0040,0x2d8c0041}},	//   rēji, _pvz_, _isap, ödet_,
   {{0x7dddc042,0x75274043,0x2b148044,0xbf228045}},	//   mèst, _vejz, _ịkọ_, मरून_,
   {{0x44234046,0xdfc6c032,0x67c8c047,0xb0be4048}},	//   _vwj_, _ري_, dějo, ्थजग,
   {{0xd6ab8032,0x7c3e4049,0x672d404a,0x69d8804b}},	//   خدام_, arpr, maaj, fove,
   {{0x672d404c,0x4423404d,0x4431404e,0x7ae9804f}},	//   laaj, _twj_, _tvz_, _vzet,
   {{0x212cc050,0x3f9fc051,0x31580052,0x6d5a8053}},	//   dadh_, tkuu_, ייגן_, _dbta,
   {{0x69cac054,0xdfd48026,0x62804018,0x64454055}},	//   _ajfe, _досы, _ámoc, muhi,
   {{0x7bdd4056,0x3f9fc057,0x64454058,0x69d88059}},	//   _mksu, rkuu_, luhi, bove,
   {{0x4431005a,0xee3f005b,0x2475803f,0x3f9fc04c}},	//   ksz_, drý_, _tām_, skuu_,
   {{0x2ee0005c,0xddc4005d,0x3329005e,0xa787c05f}},	//   _syif_, _priž, _beax_, _پشاو,
   {{0xdb008060,0x6b82c061,0x929d8062,0x09b20063}},	//   _immò, _gnog, _zgła, ुच्य,
   {{0x44310064,0x68e18065,0x9c7c8066,0xda08c00c}},	//   esz_, _hyld, _vyče, _tỏa_,
   {{0x2007c067,0x3171405c,0xb276c052,0x4df98009}},	//   _tuni_, _nazz_, _לענג_, רפֿא,
   {{0x443ec068,0x98a3003f,0xe73a4069,0xa7fcc06a}},	//   crt_, tajā_, лев_, _arıy,
   {{0x6445406b,0x2a6d806c,0xdb19806d,0x6601806e}},	//   duhi, _oseb_, nnwä, _lilk,
   {{0x46ea406f,0x32090070,0x69d88071,0xd9460072}},	// [020] удан_, _guay_, yove, _лепи,
   {{0x7f5b8073,0x69d88074,0x66018025,0x79954075}},	//   _abuq, xove, _nilk, _cozw,
   {{0x645e0076,0xdceb0077,0x7ae90017,0x7c3e4078}},	//   _uppi, _ćiće, ļete, urpr,
   {{0x06d18079,0x3a3fc07a,0xf746807b,0xa2d3407c}},	//   ়েছি, krup_, седо, _भुक्,
   {{0x7e56807d,0x6609807a,0xddcb807e,0xdb06007f}},	//   стец, _cuek, _šišk, likó,
   {{0xa97a0009,0xe9df0032,0x25b8404f,0x65a04080}},	//   ראַכ, ltúr_, _umrl_, _möhk,
   {{0x8c434081,0x443e4082,0x6b840083,0xdb060064}},	//   _нере, _ít_, _onig, nikó,
   {{0x20024067,0x69c70084,0xddc40085,0xdb0d4086}},	//   _jiki_, znje, _ariż, nnað,
   {{0x5ebb4009,0x8f9b4087,0x6286806c,0x63a28088}},	//   ָזיק, טיקי, _škof, mkon,
   {{0x67c1c03f,0x69de0044,0xddcd0089,0x200a408a}},	//   dēju, _nkpe, _krať, _kubi_,
   {{0xcb04008b,0x629d002c,0xf64fc08c,0xddc44017}},	//   रखंड_, wyso, وئی_, ptiņ,
   {{0x443ec08d,0xd2510032,0xa5bb402e,0x65ab008e}},	//   rrt_, ونج_, _awól, _mühe,
   {{0xddc2c03f,0xb5fb403c,0xeabf405e,0x27fc802d}},	//   _esoš, _tráx, _ceùl_, ívny_,
   {{0xa2c5c08f,0x67c54007,0x61140090,0xfe37c009}},	//   ापर्, mėji, здру, _פרוי_,
   {{0x200a4091,0x5ba74092,0x71bbc093,0x31bbc093}},	//   _nubi_, браз, _תצוג, _תזונ,
   {{0x69de0094,0x2d8c0095,0x8aa70039,0x44310096}},	//   _ekpe, öder_, _грод, rsz_,
   {{0x85b94097,0x63a28098,0xc1b94099,0x672f0036}},	// [030] алас_, dkon, алах_, macj,
   {{0x200a409a,0x5a34409b,0x3f84809c,0x6729809d}},	//   _bubi_, янут, _anmu_, _seej,
   {{0x67298094,0x98afc06f,0x98b8409e,0x200a409f}},	//   _peej, ćaće_, _barı_, _cubi_,
   {{0x8f474051,0x8afdc0a0,0x7ae2c0a1,0x69c8c0a2}},	//   _уход, deřn, _oyot, hnde,
   {{0xd246c0a3,0x7ae2c0a4,0x317140a5,0x442580a6}},	//   _تن_, _nyot, _tazz_, _swl_,
   {{0x37cf0079,0x801580a7,0x69c8c0a8,0x441580a9}},	//   রতির, офиц, jnde, офит,
   {{0xa2c140aa,0x2903c0ab,0x388ec080,0x98a5c017}},	//   लपक्, žjak_, bəri_, kalā_,
   {{0xa3e94047,0xdb0bc0ac,0x2fc940ad,0x2a6d8046}},	//   यति_, _omgå, nnag_, _tseb_,
   {{0xf1bf00ae,0x7e7b4011,0x644700af,0x37cf002a}},	//   nsás_, _šupj, huji, রতার,
   {{0x6d5c405c,0xb21b40b0,0x3a3fc0b1,0x63ad40b2}},	//   _xbra, _træf, rrup_, hhan,
   {{0x644700b3,0x5c7580b4,0x98b840b5,0x3a26c0b6}},	//   juji, _флет, _yarı_, _ewop_,
   {{0x2451c0b7,0x8b67c0b8,0x67c54007,0xe3bf00b9}},	//   rám_, _دائم, bėji, giñ_,
   {{0x6db28036,0xa3d840ba,0x7ae2c0bb,0x63bb80bc}},	//   płat, िवस_, _gyot, _mmun,
   {{0x008600bd,0x63a280be,0xbebb40bf,0x67c1c017}},	//   олго, zkon, _geëi, rēju,
   {{0x63bb80c0,0xa06a00c1,0x6603c0c2,0x2fcd8033}},	//   _omun, шава_, _iink, _ojeg_,
   {{0xc052c0c3,0xe3bf0018,0x6d5c40c4,0x422640c5}},	//   _חזה_, ciñ_, _sbra, ждав,
   {{0xa3e60027,0xf11a4032,0xa2d980c6,0x25ba00c7}},	// [040] _बीए_, لغات_, _फुल्, _tmpl_,
   {{0x63a980c8,0x4427c0c9,0x660bc056,0x644700ca}},	//   _alen, _kwn_, _mugk, buji,
   {{0x7e7d40cb,0x998700cc,0x546a40cd,0x27e000b9}},	//   _ersp, şiţa_, раем_, _kkin_,
   {{0x2d8580ce,0x53370052,0xab8380cf,0xdce1c011}},	//   _anle_, ַנצן_, душк, jelč,
   {{0x69c8c0d0,0x98a580b6,0xbf9b40d1,0x7d0d4032}},	//   ynde, _delč_, _kiên, íosú,
   {{0xe3bf00b9,0x2b4fc0d2,0x69dac0d3,0x63bb80d4}},	//   ziñ_, _acgc_, xote, _emun,
   {{0x993980d5,0x8fa680d6,0xb21b40b0,0xf1bf402d}},	//   сячу_, _даве, _præg, _tvár_,
   {{0xe29a80d7,0x2002c0d8,0x6d58805c,0xaa4680d9}},	//   _каб_, öki_, sfva, _мебл,
   {{0x672bc0da,0x3ea040db,0x80da8048,0x316780dc}},	//   _degj, nyit_, _पुरे, benz_,
   {{0x81f6805f,0x672f0036,0x7d1b406f,0xdb1d00dd}},	//   _بہتر_, wacj, _đusk, misé,
   {{0x63bb80de,0x6ac640df,0x6441c0e0,0x27e0007a}},	//   _ymun, लपुर, grli, _bkin_,
   {{0x75ed80e1,0x27e000e2,0x68e3c0e3,0x4522802a}},	//   púzc, _ckin_, _dynd, _নাটক_,
   {{0x7ae4000d,0xa2d6c01c,0x2bdb80e4,0x200c80e5}},	//   _cyit, _بيشت, यकता, _hudi_,
   {{0x1dbc80e6,0x27e000e7,0x2a7f40b3,0x68e3c0e8}},	//   ्चित, _ekin_, _šubo_, _fynd,
   {{0x8438c032,0x98a30036,0xf1d280e9,0x7ae400ea}},	//   _اكبر_, kają_, _तदनन, _eyit,
   {{0x02a300eb,0x7e62c033,0x63a440ec,0x764280ed}},	//   _apụọ, _kpop, gkin, kroy,
   {{0x7aed00ee,0x98a30064,0x3f86c066,0x200c80ef}},	// [050] _uzat, dają_, _mnou_, _ludi_,
   {{0x200480f0,0x601340f1,0x6568c0f2,0xe1ff0036}},	//   _aimi_, _aħma, nedh, zwój_,
   {{0x20048031,0xddc28036,0xff188044,0x63ad40f3}},	//   _bimi_, stoś, _ịtụn, phan,
   {{0x27e6802c,0xedc380f4,0x8608001c,0x201ec026}},	//   glon_, वच्छ, _دقیق_, ipti_,
   {{0x6448c0f5,0xab5dc036,0x443340f6,0x261080d1}},	//   hudi, niże, ssx_, _cào_,
   {{0xbafa40c3,0x6448c0f7,0x3f86c0b6,0x27e680f8}},	//   _להרש, kudi, _anou_, alon_,
   {{0xe739c0f9,0x316780fa,0x98ba006a,0x6605009d}},	//   бей_, renz_, _yapı_, _mihk,
   {{0xfe6e40fb,0x64574046,0x3f9940fc,0x7f4d40f7}},	//   _جگہ_, mtxi, _josu_, ngaq,
   {{0x672bc0fd,0x3dcec0ce,0x645dc0b4,0x212c805e}},	//   _vegj, _bjfw_, ăsim, _fedh_,
   {{0xd6c680fe,0x27e000c3,0x6e2980ff,0x14198032}},	//   _عملی, _skin_, _iweb, _هيئة_,
   {{0x320d8100,0x6441c101,0x6448c102,0x3cdb0103}},	//   _huey_, urli, gudi, _खुले_,
   {{0x7bcb8104,0x660bc105,0x6441c106,0xe3b3c107}},	//   nngu, _tugk, rrli, _غرض_,
   {{0x68e3c108,0xb2c7c107,0x28df8109,0x7c95c01c}},	//   _wynd, _بغاو, _पुति, زشگا,
   {{0x660d0033,0x224940fc,0x68e3c10a,0xdb00c10b}},	//   _duak, duak_, _tynd, rimô,
   {{0x2a6dc10c,0x7e7bc10d,0x0c79010e,0x2b5f8043}},	//   lweb_, lvup, осты_, _obuc_,
   {{0x6443810f,0x661b8110,0x5f76008c,0x63a44111}},	//   irni, _otuk, _رابر, ukin,
   {{0x9f428112,0xdce38113,0x67228114,0xa9a64115}},	// [060] _óké_, denč, vboj, пиад,
   {{0x7bc0c116,0x69c1c117,0x64410118,0x98a5c119}},	//   zimu, nile, álic, cală_,
   {{0xddc9811a,0x1d19411b,0xa06740c5,0x76564051}},	//   _brež, юють_, заха_, styy,
   {{0x6e29811c,0x9f404070,0x7bc0c11d,0x644380e5}},	//   _bweb, rmió_, ximu, drni,
   {{0xff03811e,0x20048011,0xdb0f0018,0x7c2b411f}},	//   няшн, _vimi_, ticú, ćgra,
   {{0x27e68120,0x201ec121,0x69c1c122,0x6e2980c7}},	//   slon_, ypti_, jile, _dweb,
   {{0xdce38123,0x661b8124,0x29184125,0x39474018}},	//   benč, _etuk, _ifra_, ónse_,
   {{0x6b99c126,0x9734801c,0x6f164127,0x6448c128}},	//   _cowg, _آکاا, ncyc, vudi,
   {{0xb4e9008f,0x69c1c129,0x672d012a,0xb21b40b0}},	//   _बर्_, file, _reaj, _træe,
   {{0xa1c3812b,0xaf12c112,0xb21b010d,0x7bc2812c}},	//   _збуд, _aụtụ, lvæg, liou,
   {{0x442a412d,0x7bdd012e,0x7988800d,0x7644412f}},	//   _jwb_, tosu, _indw, hriy,
   {{0x65b0004c,0x6568c01c,0x69de4130,0x92028017}},	//   _lähd, sedh, hope, žāda,
   {{0x98a5803f,0x67244131,0x76444132,0x98a5c119}},	//   _ielā_, dbij, jriy, tală_,
   {{0x65b0004c,0x44444133,0x63bd407a,0xfdeb4027}},	//   _nähd, kr_, _smsn, _जींस_,
   {{0x66050134,0xab1a40eb,0xd31a4112,0xec09c0d1}},	//   _vihk, _ọlụs, _ọtụr, _yếm_,
   {{0x44444135,0x63a60136,0xc178c007,0x6142c031}},	//   dr_, ckkn, ldė_, _fílà,
   {{0xdb1d0137,0xe3b90138,0xdcfc4026,0xe2f84125}},	// [070] rnsä, ksız_, _korė, зеті_,
   {{0x64438139,0x7ae640d9,0x6458813a,0x200ec13b}},	//   yrni, _dykt, ktvi, _kufi_,
   {{0x7bcb813c,0x4444413d,0x6724413e,0x44384065}},	//   tngu, gr_, bbij, _cvr_,
   {{0x3ebf413f,0x21318123,0x2d9a0140,0xb6024018}},	//   _žutu_, _žzh_, _zope_, ñáro,
   {{0x78a10041,0xf8ae805f,0x9f9640c3,0xd8388141}},	//   älvf, یکم_, _חדרה_, _avč_,
   {{0xdcfc4039,0x442a4046,0xfa780093,0x64438142}},	//   _norė, _fwb_, פעות_, trni,
   {{0xd4984143,0x2006c140,0x62808144,0xa5bb4145}},	//   _ерт_, _bioi_, _ermo, _atóg,
   {{0xd8380066,0xbc564066,0xd52bc031,0x7bc28146}},	//   áči_, žšíc, _bò̟w, ciou,
   {{0x62808147,0xa3da8148,0x7769c149,0x6b9b805e}},	//   _grmo, ठकर_, reex, _ioug,
   {{0x442a4022,0xa3e6014a,0xfaff014b,0x6d1d0047}},	//   _ywb_, _बीज_, reël_, _ब्लग_,
   {{0x6b89814c,0xef198085,0x4b55c0c5,0x6b9b814d}},	//   _kneg, _anżi_, _жълт, _koug,
   {{0x2006c00c,0x7644414e,0x69de414f,0x21e400cb}},	//   _gioi_, yriy, zope, höht_,
   {{0xfd4ec044,0x69de4150,0x8db5c11b,0x27e94151}},	//   _jenụ, yope, _оскі, dlan_,
   {{0xb5fb4152,0x44444153,0x2ca9c047,0x3f890154}},	//   _spán, yr_, _řadu_, _enau_,
   {{0x65b00155,0x764b8010,0xeb9a0156,0x200ec157}},	//   _nähe, hugy, _мик_, _gufi_,
   {{0x23600158,0x27e94159,0x2fcdc15a,0x752e415b}},	//   _ubij_, glan_, nneg_, _sebz,
   {{0x7bc2815c,0x6e364039,0x76444057,0x6607415d}},	// [080] viou, usyb, uriy, _bijk,
   {{0x7644415e,0x6aa28150,0x69c3815f,0xfbd2805f}},	//   rriy, vyof, jine, ھتا_,
   {{0x6607415d,0x2a648033,0xdb0b8160,0x7bdf401f}},	//   _dijk, _spmb_, bigü, boqu,
   {{0x6b9b8161,0x660f4162,0x27444031,0xa3e94163}},	//   _coug, _fuck, _dènà_, यतः_,
   {{0x69c38164,0x660f40cb,0xe3b90165,0xb21b00b0}},	//   fine, _guck, tsız_, rvæg,
   {{0x443840b4,0x29cd0166,0xd01a8167,0x69ce0168}},	//   _tvr_, eľaj_, офи_, nnbe,
   {{0xe3b900b5,0xa9678169,0x64588125,0xf98f816a}},	//   rsız_, фија_, utvi, شبو_,
   {{0x200ec16b,0x644a816c,0xc6a6c16d,0x69cfc03c}},	//   _rufi_, rufi, дрои, écen,
   {{0xe6c80045,0x7c2d8013,0x290ac16e,0x8d6ac16f}},	//   रपोज, ćara, žbam_, ојна_,
   {{0x22468170,0xf1aa801c,0xd90dc01c,0xb7d54171}},	//   mrok_, _باره_, میه_, _iṣel,
   {{0x3178414d,0x799c415a,0x61e8c172,0xc178c026}},	//   _marz_, _morw, rldl, rdė_,
   {{0x7ac6c173,0x2d9e0174,0x68e34175,0x64a38176}},	//   _осле, öten_, ündi, _шаха,
   {{0x69cb4107,0xbebb4177,0x6d5cc0b2,0x27e04178}},	//   égek, _leër, õras, doin_,
   {{0x0cd4c179,0xddc9c047,0x3207c0d2,0xab5d817a}},	//   _полю, kteř, _giny_, _imże,
   {{0x224b0033,0x7bc0817b,0x27e04033,0x63ad017b}},	//   suck_, _ommu, foin_, _tlan,
   {{0x60d5405c,0x2246817c,0x6608817d,0x5fdec17e}},	//   _rxzm, krok_, _lidk, मविल,
   {{0x645ac17f,0x6b9b8180,0x33268181,0xdee70182}},	// [090] ltti, _roug, dbox_, _تأثي,
   {{0xf9934183,0x5c750184,0x6e2d000d,0xdb0d401e}},	//   خبر_, _злот, _iwab, chaî,
   {{0x2458c185,0x53354186,0x6b9b8011,0xb7d5402e}},	//   ném_, _пент, _poug, _aṣel,
   {{0xa2954187,0x68e74066,0x44214188,0xe3c24189}},	//   _замі, _vyjd, rph_, tmış_,
   {{0x9f5880d2,0xdb060051,0x2458c0a0,0x7bcf018a}},	//   _auró_, sikö, hém_, incu,
   {{0xe3c240b5,0x6e2d018b,0x018b8051,0x290c8085}},	//   rmış_, _mwab, ющей_, _cgda_,
   {{0x6e2d018c,0x764b8105,0x98be806a,0xafe5c18d}},	//   _lwab, sugy, _batı_, нокл,
   {{0x6282c18e,0x0ecac09d,0x7535018f,0xe64b8080}},	//   _broo, ापंड, hazz, şdığ,
   {{0xaf12c044,0xdb0b8019,0x63a48025,0xe81600b2}},	//   _pụrụ, sigó, öine, _दूना_,
   {{0x6f0d000d,0x753500f1,0x69c54190,0x200900f8}},	//   _agac, jazz, nihe, _aiai_,
   {{0x6ac80191,0x753500f1,0xfbc60192,0x2d9cc193}},	//   रप्र, dazz, ебно, _dove_,
   {{0xb5fb4194,0x7ae9811c,0x61f7005e,0x853cc007}},	//   _spál, _kyet, _ahxl, nkėj,
   {{0xe9f9c176,0x80d94079,0x443a0195,0x23ae410d}},	//   _енді_, ভেচ্, _svp_, _nýja_,
   {{0x4cc1002a,0x6e3b8196,0x69c54197,0x201140ce}},	//   _শুধু, _mvub, jihe, _ouzi_,
   {{0x27e04198,0x6f1b8199,0x61e1c19a,0xceb44080}},	//   toin_, _ofuc, moll, hbət_,
   {{0xeb97419b,0xe61a419c,0xe9df019d,0xebe3419e}},	//   нис_, зда_, rrúa_, госп,
   {{0x765bc19f,0x2b4000b3,0x366741a0,0x65ab00fa}},	// [0a0] ntuy, _idic_, нато_, _kühl,
   {{0xe1f20183,0xa5bb4031,0x6b8bc17b,0x628401a1}},	//   _حسب_, _atób, _lngg, _irio,
   {{0x75d34032,0x65ab00cb,0x8fa641a2,0xdca34077}},	//   ديلا, _mühl, _зане, лафи,
   {{0x80da8185,0x501b00c3,0x765bc010,0x3878c086}},	//   _पुगे, _מוטו, ktuy, ærri_,
   {{0x69c541a3,0xef8341a4,0x442c81a5,0xe1ff4031}},	//   bihe, _сляп, _swd_, _ipón_,
   {{0x7bc601a6,0x2ca5c1a7,0xc90ec036,0x224681a8}},	//   hiku, kyld_, _सलेम_, rrok_,
   {{0xf806c1a9,0xd90d81aa,0x6e2281ab,0x9f588157}},	//   нчин, زین_, spob, _durò_,
   {{0xedc8c1ac,0x7bc081ad,0x7bc60150,0xdb1d0066}},	//   िच्छ, _ummu, jiku, tisí,
   {{0x7ae981ae,0x98a78026,0xdd1f41af,0x224dc140}},	//   _gyet, vaną_, líši, guek_,
   {{0x6282c1b0,0x9f588016,0x7abb40c3,0x7564805f}},	//   _vroo, _turó_, פציו, _شیعہ_,
   {{0x61fe41b1,0xddcd01b2,0x6e2d01b3,0xdd8f81b4}},	//   impl, _praž, _swab, _دول_,
   {{0xd46981b4,0x645c01b5,0xb4cc81b6,0x38cb81aa}},	//   _تحكم_, dtri, रपी_, _عالی_,
   {{0x753501b7,0xddcd01b8,0x65ab00fa,0x21ef40fa}},	//   tazz, _vraž, _fühl, fühl_,
   {{0x645c00fa,0xb894c032,0x7c94c032,0x7bc6014b}},	//   ftri, _للتع, _للتص, aiku,
   {{0x645c01b9,0x7bc2c05c,0x2d9e80d9,0xdb09c032}},	//   gtri, _kmou, _mote_, mheá,
   {{0x61fe4127,0x201141a3,0x6f0d01ba,0xd37841bb}},	//   empl, _ruzi_, _ugac, нчу_,
   {{0x3df501bc,0x717941bd,0x5695011e,0xef6400c5}},	// [0b0] _изис, мбар_, _рапт, _също,
   {{0x201141be,0x63a9c0fc,0x644e01bf,0xb21b4086}},	//   _puzi_, zken, bubi, _fræn,
   {{0x765d00f8,0x22a741c0,0x6e20817b,0x63a9c1c1}},	//   ltsy, _bíkú_, _atmb, yken,
   {{0x660ac077,0xa5bb4031,0xa03a0009,0xb4ad01c2}},	//   _lifk, _awót, _קערפ, कनी_,
   {{0x8a1841c3,0xaf12c044,0x539a40c3,0x657a81c4}},	//   _пояс_, _rụpụ, _חירו, _bath,
   {{0x7ae981c5,0x44210041,0x89a8811b,0x201141c6}},	//   _vyet, _kth_, нків_, _tuzi_,
   {{0x69d5415d,0xdb0f0018,0xceb44080,0x63a9c1c7}},	//   _ijze, nicó, sbət_, tken,
   {{0x68e340fa,0x224dc0fc,0x291cc053,0x332941c8}},	//   ündu, tuek_, _afva_, nbax_,
   {{0x443cc1c9,0x6448c1ca,0x7bd881cb,0x325581cc}},	//   _avv_, erdi, évue, _швар,
   {{0x7c3ac1cd,0x4c85c1ce,0xb5fb4166,0x8d74801c}},	//   fstr, влов, _spáj, _ماما,
   {{0xb5fb41c0,0x64410066,0xaf12c112,0x200c4181}},	//   _apák, álil, _tụpụ, _édit_,
   {{0x2ca78086,0xdb0f0018,0x799e01cf,0x656e000b}},	//   mynd_, dicó, _sopw, webh,
   {{0x7c3ac156,0x6729c1d0,0xe56ec119,0x224941d1}},	//   astr, mbej, _кз_, jrak_,
   {{0x7c3ac1d2,0x7bc601d3,0x6f0f4018,0x6f1d41d4}},	//   bstr, siku, _agcc, _afsc,
   {{0x657c00cb,0x1fb601d5,0x69c3c1d6,0xcfaa401c}},	//   rdrh, _аспр, _imne, وارم_,
   {{0x6b8d01d7,0x8e4a0032,0x9f4201af,0x6fb1c0e9}},	//   _gnag, _قلبك_, blká_, जसिं,
   {{0x7e6981d8,0x245a80da,0x3ce88036,0x61e38051}},	// [0c0] _npep, zëm_, _चुने_, konl,
   {{0x61e381d9,0xa2b781da,0x7aebc007,0xaa370052}},	//   jonl, ्छन्, _mygt, _שטיק_,
   {{0x200b4020,0x7649c1db,0x505a41dc,0x644341dd}},	//   _fici_, hrey, ьшая_, šnin,
   {{0x657a81de,0x09d5c079,0x61e38157,0x7bda41cb}},	//   _sath, _সীমা, eonl, étud,
   {{0x61e381df,0x657a81e0,0xdce8c02d,0xadf6c047}},	//   fonl, _path, vedč, ुगमन_,
   {{0xdb0b810d,0x201a810b,0x7649c1e1,0x62964022}},	//   rigð, ípio_, drey, mxyo,
   {{0xd7fac0b4,0x02cac1e2,0x7c3ac127,0x741481e3}},	//   муи_, ाप्न, xstr, دوبا,
   {{0x65ab009d,0x657c41e4,0x7c3ac1e5,0x07a381e6}},	//   _rühm, _harh, vstr, _касн,
   {{0xda658182,0x33298004,0x245a813b,0x7c290013}},	//   _مالي, ñaxe_, sëm_, ćeri,
   {{0xa2bb81e7,0x213801e8,0x27edc1e9,0x7aebc065}},	//   _शेट्, jarh_, alen_, _dygt,
   {{0x628281ea,0x27edc144,0x6b8d00f8,0x3a26815d}},	//   lvoo, blen_, _pnag, lpop_,
   {{0x7649c10d,0x67f88047,0xfe46c1eb,0x6e3bc1ec}},	//   brey, bíje, _андо, bsub,
   {{0x628281ed,0x3c38c0a0,0x7c22002d,0x7f42c17a}},	//   nvoo, _bývá_, _čora, _idoq,
   {{0x200b41ee,0x442ec15a,0x6e22c1ef,0x3a26814d}},	//   _sici_, _twf_, _itob, ipop_,
   {{0xb7d541c0,0x443c8018,0xe4a401f0,0xdce88047}},	//   _aṣal, nsv_, арто, _radě,
   {{0xdb0f01f1,0x547b81f2,0x7f42c17a,0x6b8d01f3}},	//   ricó, וטלו, _jdoq, _unag,
   {{0x657c41f4,0xfe7041b4,0xdb00805f,0x200b41f5}},	// [0d0] _barh, يدك_, _elmú, _vici_,
   {{0x39584061,0x4c9501f6,0x700100eb,0x993541f7}},	//   _ccrs_, _биос, _ịcha, افات,
   {{0x443e81f8,0x69c8c149,0x80ca01f9,0x69c5005e}},	//   _nvt_, iide, _हेपे, _imhe,
   {{0x439541fa,0x7aed01ae,0x7f42c1fb,0x9b954119}},	//   _самс, _kyat, _ndoq, _симц,
   {{0x75ed81fc,0xeab08032,0x628281b0,0x9f4401cb}},	//   lúzi, يعه_, gvoo, ômé_,
   {{0x7aebc0b0,0x2fc94046,0xdddb81fd,0x601ec017}},	//   _rygt, liag_, _bruš, _zīme,
   {{0x6e22c1fe,0xac9441ff,0x75354157,0x2d18401c}},	//   _atob, _карш, _iezz, _شکلک_,
   {{0x7ff5c200,0xfe7381aa,0x63a080e2,0x27edc201}},	//   دستا, _پدر_, _gomn, ulen_,
   {{0x6f1bc202,0x657c40c9,0x0609c203,0x69c500bf}},	//   rcuc, _yarh, нник_, _omhe,
   {{0xdddb8204,0xb5fb4032,0xdb044032,0xdb0d001e}},	//   _fruš, _bpái, thiú, _plaî,
   {{0x27e90056,0xbb55c1aa,0x65ab009d,0x443e81ff}},	//   _bkan_, _مناب, _tühj, _gvt_,
   {{0x69c5002c,0x75354205,0x6e3bc206,0x4425c207}},	//   _amhe, _lezz, psub, rpl_,
   {{0x61e54208,0x2bc64191,0x63ad4209,0x245c4047}},	//   kohl, रोफा, dkan, zím_,
   {{0x69c8c20a,0x2619800c,0x2d98c20b,0x2bc60027}},	//   cide, _mèo_, öret_, _लगवा,
   {{0x75d2c20c,0xf746420d,0x7aed020e,0x4ddac0c3}},	//   _ديوا, лево, _eyat, _אחסו,
   {{0xa696020f,0x3a224033,0x96960210,0xb21b4211}},	//   _број, _ptkp_, _брош, _træl,
   {{0x6aa9c212,0x7aed0213,0x05664214,0x9c7c8215}},	// [0e0] nyef, _gyat, лван, _vyči,
   {{0x7c3e8216,0x44278033,0x201c401f,0x65b000cb}},	//   špri, kpn_, ívio_, _zähn,
   {{0x98a601fa,0xf536c009,0xacf64217,0x657c4218}},	//   _сине, רטער_, учај, _varh,
   {{0xe29a4219,0xaf36821a,0x27e9021b,0xb5fb0018}},	//   _зам_, ارات, _xkan_, ctáb,
   {{0xa2cb4185,0x657e021c,0x9757021d,0x645e421e}},	//   _सेप्, _kaph, רינו_, stpi,
   {{0x44f3c21f,0x245c4220,0xa0024094,0x6e24012c}},	//   _ọ_, pím_, _ọchị, _mtib,
   {{0xc9530093,0xdca34221,0xa5bb4036,0x7c294222}},	//   צמה_, _лари, _twór, _čerg,
   {{0xafe68223,0x9f420224,0x644a8225,0xbc678226}},	//   _собл, boké_, rrfi, امين_,
   {{0x27e68227,0x85568228,0x35b4c229,0xae43c01c}},	//   moon_, _مخاط, ибир, مپيو,
   {{0x63ad422a,0x104ac22b,0x237fc077,0x27e9022c}},	//   zkan, нями_, aduj_, _skan_,
   {{0xa2cb422d,0xb6038194,0xbca68182,0x9426822e}},	//   _सेन्, íšen, _حماي, _смее,
   {{0x2a60422f,0x63ad41a8,0x61e5400b,0x3f80413b}},	//   ktib_, xkan, zohl, jdiu_,
   {{0xb21b40b0,0x395a0053,0x62868011,0x44f3c02e}},	//   _præm, _bcps_, _škoj, _ẹ_,
   {{0x7bc64230,0x3eb98138,0x660e40f6,0xdd90c231}},	//   _amku, _üste_, _nibk, _ذوب_,
   {{0x753ac232,0x31710233,0x6e24003a,0x75354157}},	//   matz, rezz_, _etib, _rezz,
   {{0x753540f1,0x65ab0234,0x61e54235,0x68f5c236}},	//   _sezz, _mühi, wohl, üzde,
   {{0xec0a000c,0x443ec237,0x44234238,0x7c3e4239}},	// [0f0] _vết_, lst_, _stj_, espr,
   {{0x60d3c03f,0x7e6d023a,0x2fc9423b,0xca48420c}},	//   ņemš, _ipap, siag_, الله_,
   {{0x6d45023c,0xe895023d,0x7c2d823e,0x7535423f}},	//   _idha, _тань, ćark, _vezz,
   {{0x68ee4240,0x62844176,0x61e54241,0xa857c0c3}},	//   _dybd, bvio, sohl, ריאה_,
   {{0x443ec0fa,0x236900fd,0x69cb4107,0x7bc9c1cb}},	//   hst_, _mbaj_, éges, vieu,
   {{0x61e70242,0x3a248018,0x2fc6c010,0x69d500fa}},	//   nojl, _dtmp_, _amog_, nnze,
   {{0x9f6b80d7,0x7bc9c243,0x1128811b,0xa7b5c244}},	//   _праз_, tieu, уючи_, исиј,
   {{0xfe45c245,0xf771c246,0x660e4247,0xe3b38248}},	//   анио, زاب_, _zibk, _ارس_,
   {{0x7bcb8249,0x443ec24a,0xf77f406a,0xa3d6c048}},	//   migu, est_, _maç_, _सदर_,
   {{0x4465c24b,0x237f824c,0x753ac24d,0x62898033}},	//   авов, _hauj_, gatz, _ireo,
   {{0x232a024e,0x2d81424f,0x7c2200b3,0x237dc04d}},	//   кони_, idhe_, _čoro, _tawj_,
   {{0x888a8009,0xdb0d0250,0xb4e5c02e,0xd7060251}},	//   _שרײַ, _amañ, _alàà, изни,
   {{0x67d2003f,0x753ac0fc,0x38bbc031,0x777f00f6}},	//   nāji, batz, _báré_, _daqx,
   {{0x443ec252,0x61e70077,0x673bc007,0x6e29c253}},	//   bst_, gojl, lauj, mpeb,
   {{0xac16c1bd,0x7bcb8254,0x475a40c5,0xb21b4255}},	//   _коју_, kigu, края_, _fræk,
   {{0x764d4256,0xb21b40b0,0x9c1280eb,0x672d4257}},	//   fray, _græk, kọnd, gbaj,
   {{0x764d4258,0x25a34077,0xef174259,0x7bcb825a}},	// [100] gray, _bojl_, рму_, digu,
   {{0x64418047,0x1e3b00c3,0x3d1c0031,0xc046425b}},	//   _ovli, _שגיא, _dàwó_, لخصو,
   {{0xb607803f,0x9f404032,0xddcbc017,0x628441ff}},	//   _mašī, iliú_, _apgū, svio,
   {{0x1a2a811b,0xb4e6425c,0x317e80fa,0xaca4425d}},	//   вжди_, _पडी_, _satz_, _nwụr,
   {{0xdce18039,0x7e7b8107,0xdb00825e,0x25a3417a}},	//   _kalė, _csup, _komé, _fojl_,
   {{0x4425825f,0x3eaf40b0,0x224dc09d,0x63b6002c}},	//   _btl_, øgte_, drek_, _llyn,
   {{0x78808260,0x03968261,0xdca64262,0x9f44c263}},	//   dává, _края, _тави, lomé_,
   {{0x77b84004,0x2ca74264,0x66038046,0x207b4052}},	//   _fíxe, ände_, amnk, _באלא,
   {{0x62898265,0xddc2c089,0x6b82815a,0xd0548080}},	//   _greo, _apoš, mdog, _əbəd,
   {{0x200fc10d,0x237f805c,0x6b828266,0x50468267}},	//   _eigi_, _zauj_, ldog, _вежб,
   {{0x63b60268,0x63a40269,0x6b8080eb,0x9df7c039}},	//   _blyn, _boin, _kamg, рнэт_,
   {{0x224dc26a,0x3f80001d,0xaca440eb,0x237f823b}},	//   brek_, _caiu_, _gwụr, _xauj_,
   {{0xdcfc417a,0xddcd4089,0x6d5c426b,0x23b5426c}},	//   _barċ, braň, _ocra, _nåja_,
   {{0x394d00fa,0x7bcb826d,0x443ec26e,0x4425806a}},	//   ßes_, zigu, pst_, _ytl_,
   {{0x03c7426f,0x94a80270,0x3ce6417e,0xd5fbc0c3}},	//   асам, атта_, _जुले_, _שפור,
   {{0x5b154271,0x63b6002c,0x98b100b4,0x248d4272}},	//   смат, _glyn, ează_, _čem_,
   {{0x6d41010d,0x7bcb801e,0x673d0273,0x22404274}},	// [110] ólas, vigu, masj, gsik_,
   {{0xa2cb4275,0x247800b6,0xdb1d0025,0x61e8c276}},	//   _सेण्, _fōm_, sisä, nodl,
   {{0x2d8140fd,0x7bcb8277,0x7538c06a,0x3d024278}},	//   rdhe_, tigu, _mevz, वेले_,
   {{0x67d20279,0x237f8022,0x673d027a,0x7e7b805c}},	//   tāji, _qauj_, nasj, _psup,
   {{0x2018427b,0x27e9427c,0xb21b0086,0x2d8300a8}},	//   _euri_, moan_, kvæm, odje_,
   {{0x2d81027d,0x6722c1c0,0x85e8811b,0x628980b4}},	//   _jahe_, _afoj, адів_, _vreo,
   {{0xa4d440d9,0x2d81027e,0x58d4427f,0xb5b800c3}},	//   _дорі, _mahe_, _дорт, שלוח_,
   {{0x2d81009d,0xec0a00d1,0xba77801c,0xe3b1c280}},	//   _lahe_, _nếp_, _پارت, ثرت_,
   {{0x6ad10281,0x7bc9812c,0xef1980f6,0xdb04005e}},	//   सपोर, _imeu, _gaża_, _fliù,
   {{0x61e8c282,0x2fc900f8,0x67dac283,0x3a3fc033}},	//   godl, _amag_, rċja, rsup_,
   {{0x200fc284,0x2bc48285,0x2cacc1f4,0xb50ac1f9}},	//   _tigi_, लोवा, gydd_, _हृदय_,
   {{0x673d011b,0xf3ff400c,0xdb0d410b,0x79818177}},	//   gasj, _nhã_, chaç, _halw,
   {{0x7bcd4286,0x31af406a,0x753c0287,0x1b7a8009}},	//   diau, _kızı_, tarz, נטשע,
   {{0xa2c24288,0x64a60289,0xf77f001f,0x1303028a}},	//   _रेग्, бага, boço_, язям,
   {{0xe7e4428b,0x290c028c,0x6813c0b4,0x6455028d}},	//   ककला_, äda_, _pădu, guzi,
   {{0x2240428e,0x69d74018,0x2d8300a8,0x6d5c428f}},	//   tsik_, enxe, adje_, _scra,
   {{0x67f60066,0x644e011f,0x27f24290,0x07a34291}},	// [120] nájm, srbi, rlyn_, чатн,
   {{0x27ff8031,0x25a58292,0x04460293,0x29cd004f}},	//   _ahun_, _noll_, _леон, lžan_,
   {{0x7bcd4039,0xb5fb4031,0x22404294,0x7e7d4295}},	//   biau, _apás, ssik_, _essp,
   {{0x628bc296,0x7e628297,0xb73a81b4,0xa3bc4298}},	//   _orgo, ttop, اثاء_, _अति_,
   {{0x95ca8299,0x27ff829a,0x25a5829b,0xdd1c80a0}},	//   лука_, _dhun_, _boll_, _záři,
   {{0x3f82429c,0x6d5c429d,0x38cb81aa,0x3eadc29e}},	//   _haku_, _ucra, گاهی_, dyet_,
   {{0xdfd281b4,0x78b5803a,0x61e8c29f,0x6441c2a0}},	//   _فيس_, _üzvl, vodl, jsli,
   {{0xdbf10185,0x77b5c018,0xdcfc42a1,0xdce380a0}},	//   _příb, _páxa, _jarč, leně,
   {{0x1a9a4009,0x201a02a2,0x29cd02a3,0x6441c2a4}},	//   ריִע, _lupi_, džan_, esli,
   {{0x154382a5,0x25a5802c,0xbda58032,0xc27b42a6}},	//   _неум, _goll_, _وحلو, נריי,
   {{0x764400b6,0x27e942a7,0x2fcdc2a8,0x6d4882a9}},	//   _aviy, yoan_, bieg_, _idda,
   {{0x2240811f,0x6b84415d,0x25a580fa,0x78a10041}},	//   šiku_, jdig, _zoll_, älvm,
   {{0xa3e5c045,0xddc40166,0x2cacc1f4,0x69ce02aa}},	//   पकर_, _spiš, sydd_, fibe,
   {{0x6b8442ab,0xf1bf4018,0x673d02ac,0x67d2003f}},	//   edig, _atán_, sasj, dāju,
   {{0x6b8441c8,0x753a82ad,0xe81d417e,0xdc3c4007}},	//   fdig, _metz, _बंधा_, _išėj,
   {{0x5c0742ae,0x2fc902af,0xb5fb02b0,0x69dc4077}},	//   сяга, _umag_, ctán, _ajre,
   {{0x953942b1,0x27e942b2,0x6e9942b3,0x56944125}},	// [130] изат_, roan_, швар_, патт,
   {{0x27e942b4,0xb5fb4031,0x4427c05c,0x2737400c}},	//   soan_, _apár, _ytn_, ần_,
   {{0x7a3f4171,0x271e825d,0x25a582b5,0x26c041a8}},	//   _bàtá, _ịna_, _roll_, azio_,
   {{0x69d882b6,0x628d0231,0x63bbc2b7,0x776d00f6}},	//   enve, _krao, xhun, _jbax,
   {{0xa77c0009,0x1c1f02b8,0x444402b9,0x6d4342ba}},	//   טראפ, _मंडल_, _zv_, ónas,
   {{0x6e2d42bb,0x7dc902bc,0x98a7c047,0x31af4080}},	//   mpab, džsk, _ceně_, _qızı_,
   {{0x27ff82bd,0x799540fa,0x6b82c2be,0x4d5c0052}},	//   _thun_, _inzw, _baog, אדוצ,
   {{0xaba9c0c5,0x798182bf,0x7bc982c0,0xf625c2c1}},	//   рвиз_, _walw, _umeu, одио,
   {{0x2d8342c2,0x0d99c097,0x9599c2c3,0x798182c4}},	//   _kaje_, атны_, атну_, _talw,
   {{0x69ce02c5,0xfc45c05b,0xdcf8c03f,0x2b4902c6}},	//   xibe, žíme_, _savā, _adac_,
   {{0x2fcdc2c7,0x63bbc00b,0xdca5c1a9,0xa5bb402e}},	//   pieg_, phun, цани, _atók,
   {{0x4e1d82c8,0x2a7dc23b,0x628d02c9,0x2d8342ca}},	//   _पढाई_, _tswb_, _brao, _laje_,
   {{0x333fc2cb,0x644382cc,0x661b809d,0x213ec2cd}},	//   maux_, lsni, _juuk, bath_,
   {{0x3f8242ce,0x7769c018,0xe692c2cf,0x2443c138}},	//   _saku_, lfex, _آلود, pım_,
   {{0x03a602d0,0x3f8242d1,0xa7aa42d2,0x1faa42d3}},	//   _мико, _paku_, аква_, акви_,
   {{0xbebb00fd,0x628d02d4,0x04570032,0x7e6442d5}},	//   rbër, _frao, تلفة_, ttip,
   {{0x0dca4026,0xdb0682d6,0x6e2d42d7,0x49ca42d8}},	// [140] алай_, ümün, gpab, алан_,
   {{0xdb040018,0x2d8342d9,0x2ca9c047,0x2d85c2da}},	//   _noié, _caje_, _řady_, ndle_,
   {{0x3f6a42db,0x3f8242dc,0x6b8402dd,0x2a7f809d}},	//   _кино_, _taku_, _kaig, _asub_,
   {{0xb5fb0032,0x68404031,0x7e6442de,0x661b82df}},	//   htál, _aádá, ptip, _buuk,
   {{0x7c2e014b,0x26c201a8,0x5de68115,0x1ec782e0}},	//   lpbr, nzko_, ожда, олци_,
   {{0x7bcbc1f4,0x26c200fc,0x7983c09c,0x8d76401c}},	//   _amgu, izko_, _nanw, _باحا,
   {{0x69d882e1,0xc7b8c043,0xdcfc4085,0xc5f4409c}},	//   rnve, _luđe_, _forġ, guɓe_,
   {{0x938ac2e2,0x442a4063,0xdb0082e3,0x466ac2e4}},	//   рска_, _itb_, _homí, аром_,
   {{0x2d83400d,0x63a282e5,0x3f82c166,0x753c42e6}},	//   _yaje_, mjon, ľku_, _kerz,
   {{0x65b000cb,0x67fd0070,0x753c42e7,0x6b82c2c0}},	//   _fähi, déja, _jerz, _waog,
   {{0x7983c2e8,0x7c2882e9,0xa3ea42ea,0x64434089}},	//   _danw, _utdr, यवा_, šniv,
   {{0x3f8682eb,0x645882ec,0xc7c700d9,0xd7f900b4}},	//   ndou_, muvi, існи, ptăm_,
   {{0x444442ed,0x60158039,0x23694046,0xdcfe02ee}},	//   hs_, _išma, vfaj_, _dapč,
   {{0x65c0c02e,0x6b84017b,0x6756c2cf,0x98a5c017}},	//   _dáhù, _eaig, _ایکس_, galē_,
   {{0x7bcf02ef,0x442a40d9,0x6e2dc283,0xd90f02f0}},	//   picu, _ntb_, _ħabi, ضیح_,
   {{0x5f9442f1,0x2d9e0041,0xcf9841bd,0x3f868047}},	//   мист, öter_, оју_, jdou_,
   {{0x23ae4086,0x764441c8,0xf1db8036,0x7983c2f2}},	// [150] _nýju_, gsiy, _बदलन, _yanw,
   {{0x6b8402f3,0x9f44c2f4,0xab5d8085,0xd2504107}},	//   _zaig, domí_, _imżi, کنے_,
   {{0x2d83406c,0xe7198032,0x442a42f5,0x333fc01e}},	//   _vaje_, ميات_, _ctb_, yaux_,
   {{0xbbb582f6,0x69dac0fa,0x6c7a0009,0x661b82f7}},	//   ंसेक, hnte, _פארפ, _puuk,
   {{0xcb9a4093,0xa5f982f8,0xa7fd003a,0x2d8342f9}},	//   _הסרט, беду_, ytın, _taje_,
   {{0xd65800c3,0x798502fa,0xa5bb01ff,0x3d190062}},	//   קיות_, _jahw, mpós, _दलों_,
   {{0x628082fb,0x013800c3,0xb7d54031,0x2246c2fc}},	//   _esmo, חרות_, _aṣil, _avok_,
   {{0xee39c2fd,0x02a300eb,0x644542fe,0x65b002ff}},	//   бни_, _awọọ, mshi, _vähi,
   {{0x6e298300,0xd2518301,0x673d4302,0xdb064303}},	//   _uteb, _سنا_, _mesj, _cokè,
   {{0x79850056,0xd13181b4,0x77bcc018,0x201cc0bb}},	//   _nahw, _أما_, _réxe, _buvi_,
   {{0xa7fd00b5,0x1815c09d,0x64454304,0x661d4142}},	//   rtın, णदेव_, nshi, _lusk,
   {{0x628f4019,0x3e640051,0xf1bf4305,0x7983c306}},	//   _orco, töt_, _stál_, _wanw,
   {{0x42798009,0x661d4307,0x3a2f805c,0x44444017}},	//   זאָג, _nusk, npgp_, zs_,
   {{0x66154308,0x44444309,0x7bcd030a,0x27edc30b}},	//   _nizk, ys_, _emau, loen_,
   {{0x661d430c,0xf1b9811f,0xb5fb030d,0x79850303}},	//   _ausk, _guše_, ctám, _dahw,
   {{0xc7b8c0e0,0x661d4098,0x442a406f,0x6b84024f}},	//   _tuđe_, _busk, _rtb_, _uaig,
   {{0x753c430e,0xdee3430f,0x673d4310,0x2b404311}},	// [160] _perz, еоти, _desj, raic_,
   {{0x644540fd,0x27edc312,0x661d4313,0xa2bf8314}},	//   fshi, hoen_, _dusk, वनन्,
   {{0xdb0d0315,0x63a98316,0x27edc317,0x61ee0318}},	//   _plaç, _boen, koen_, mobl,
   {{0xe1ff0319,0x20094119,0x7644431a,0xae1bc027}},	//   ntón_, cmai_, psiy, नदान_,
   {{0x7bc380fd,0x628f8018,0x69dac31b,0x29cd0077}},	//   ënua, _ácol, ynte, džaj_,
   {{0x8afb4093,0x6283403f,0x3f84831c,0x7af60051}},	//   _להכי, ānot, _wamu_, _myyt,
   {{0x38c8801c,0x3c21c10d,0xe9df0004,0x69dc031d}},	//   غاتی_, _nóv_, nsúa_, inre,
   {{0xdcfc4017,0x27e00044,0x4fc6c31e,0x661540fc}},	//   _garā, _njin_, ясла, _zizk,
   {{0xa3c00298,0x661d41c8,0xc986c31f,0xd6d9c062}},	//   ंघन_, _xusk, пуни, tała_,
   {{0x6ce6c007,0x63a9815d,0xe1ff0019,0x273ac0d1}},	//   зіме, _zoen, etón_, ẫn_,
   {{0x61ee00e5,0x20094039,0x27edc320,0x213e8321}},	//   dobl, ymai_, boen_, _ieth_,
   {{0x57da8036,0x333dc0f6,0x63a44322,0xa4fb8323}},	//   _भदोह, _gewx_, jjin, _פלאט,
   {{0x201e8024,0xf0b0805f,0x2c0bc05f,0x6e2280f7}},	//   _huti_, _سیکھ, _اعلی_, nqob,
   {{0x673d4324,0xa91c802d,0x9f5dc1c0,0x213e8053}},	//   _sesj, _maľo, _fiwó_, _jeth_,
   {{0x657ac325,0x64454326,0x6842c02e,0x201e8303}},	//   meth, xshi, _dídá, _juti_,
   {{0x22468327,0x2d878328,0x63b64329,0x443a032a}},	//   ksok_, zdne_, gkyn, _dwp_,
   {{0x2009432b,0x201e832c,0x290c4089,0x52154125}},	// [170] rmai_, _luti_, _údaj_, ддат,
   {{0x27edc32d,0x63bb8185,0x63a9832e,0x673f00fd}},	//   zoen_, _slun, _soen, _heqj,
   {{0xb4d74045,0x752540cb,0x7bdd032f,0x69c08330}},	//   ापे_, rchz, onsu, वसनी,
   {{0x64454331,0x4a758097,0x68f54066,0x213e81f4}},	//   rshi, дыкт, _vyzd, _aeth_,
   {{0x645ac332,0x657ac333,0x64454334,0x3f994335}},	//   huti, keth, sshi, _insu_,
   {{0x628f8004,0x201e8336,0x93b5c0d1,0x79e7405f}},	//   _ácom, _buti_, _cũn, _روزہ_,
   {{0xe739c04c,0x213e8337,0x3f86c0b6,0xb7b5c0d1}},	//   оей_, _deth_, _baou_, _dụn,
   {{0x2fdf8231,0x98b80119,0x3f894338,0x9605c281}},	//   _ujug_, lară_, ndau_, रष्ट_,
   {{0x657ac339,0xdce74007,0x7c3a833a,0xd7668107}},	//   feth, _pajė, _ewtr, _تنقی,
   {{0x98b800b4,0x0c25c119,0x7762c060,0xb5fb0107}},	//   nară_, ммон, _ecox, stáj,
   {{0x3cf0805b,0x256f8165,0xe7c48045,0x60c4c020}},	//   čové_, rılı_, लोकप, _ƙima,
   {{0x24914011,0x7af60051,0xdb26c16a,0x917981c0}},	//   _mrzm_, _pyyt, _قومی, _fẹ̀_,
   {{0x201e82a3,0x657ac33b,0xdb00833c,0x2b4d805c}},	//   _zuti_, beth, _komá, _mdec_,
   {{0x6b89c33d,0x63bd415d,0x657ac231,0x6e2d0032}},	//   ldeg, _alsn, ceth, _dtab,
   {{0x2c870047,0x98ba433e,0x63a4433f,0x7afd80d9}},	//   vídá_, kapā_, tjin, _østf,
   {{0x3a2d8340,0x76460341,0x661f00f6,0x27e0013b}},	//   _otep_, psky, _fuqk, _ujin_,
   {{0xa3af4342,0x41aa4343,0xf1e1c0e9,0xa5bb0344}},	// [180] _कवर_, ован_, _पदान, rpór,
   {{0xdb008345,0x2d87c346,0x3f864347,0x9f4040c4}},	//   _romà, _jane_, žou_, gliò_,
   {{0x48064348,0x271840eb,0xdb09c051,0x764981cb}},	//   _опов, _ọnu_, lkeä, _avey,
   {{0x442c8349,0xe29a434a,0x2a694022,0xb7be802a}},	//   _rtd_, _дам_, btab_, েক্ট,
   {{0xe1ff0107,0x442c834b,0xdfcf8032,0x201e834c}},	//   któl_, _std_, جين_, _suti_,
   {{0x60c94047,0x9f40434d,0x645ac0f8,0xd12f820c}},	//   _řeme, plió_, yuti, لمه_,
   {{0x76498053,0x7bc0c34e,0x2c1840b2,0x701c002a}},	//   _evey, thmu, _बंटू_, _তবুও_,
   {{0x6284034f,0x4fbb4052,0x645c00cc,0x657c0350}},	//   _osio, ַציא, iuri, herh,
   {{0x7c2dc351,0x657ac352,0x7e69c353,0x2d9a0070}},	//   _čara, teth, gtep, _onpe_,
   {{0x7bc0c13b,0x201e8354,0x6028c0a0,0x7988c02c}},	//   shmu, _tuti_, _němc, uddw,
   {{0x6d4e405c,0x799a800d,0x2d87c355,0x22490356}},	//   _mdba, _intw, _dane_, _svak_,
   {{0xbb940051,0x2b400357,0x63abc157,0x9b93c032}},	//   вающ, _ceic_, _gogn, _للمت,
   {{0x661700fc,0x38b4c031,0x3a20005e,0x98ba00b6}},	//   _pixk, _búrú_, _cuip_, _depč_,
   {{0x6e208358,0x645500b3,0xb5fb0359,0x6447035a}},	//   _mumb, trzi, otái, tsji,
   {{0x645c035b,0x38b4c031,0xb4d9025c,0x69c68007}},	//   guri, _dúrú_, ़पे_, _įkel,
   {{0x6d4e4024,0x3eae013b,0x2d9a0141,0xd5b8c017}},	//   _adba, ëjtë_, _enpe_, lkā_,
   {{0x7c2e403f,0x27ef8240,0xde88c112,0x6e2440c2}},	// [190] _atbr, vogn_, _jị_, gqib,
   {{0xd6d9c036,0xd131035c,0x64550199,0xde88c35d}},	//   zało_, _حمد_, przi, _mị_,
   {{0x645c035e,0x81e48079,0xdb04035f,0x442ec360}},	//   curi, নতা_, _goiâ, _jtf_,
   {{0xa5bb4171,0x3f994020,0x98b800b4,0x7bc28361}},	//   _atót, _unsu_, sară_, ghou,
   {{0x79874362,0xee388363,0x443cc046,0x9f4d829a}},	//   _tajw, дні_, _lwv_, _bheò_,
   {{0x798881f4,0x63ad0364,0x20194365,0x65948366}},	//   _cadw, _loan, _hisi_, качу,
   {{0x1fb5c119,0x917bc104,0x6448c127,0x00000000}},	//   еспр, _lệ_, jsdi, --,
   {{0xc9180367,0x2d87c368,0x6448c369,0x7e69c36a}},	//   וחות_, _sane_, dsdi, ttep,
   {{0xc17581bc,0x2a690022,0x63abc36b,0x645c036c}},	//   _плащ, _nqab_, _vogn, zuri,
   {{0x69d50054,0x2019436d,0x4421036e,0xef1980f6}},	//   jize, _lisi_, _ouh_, _nażi_,
   {{0x63ad036f,0x2d87c370,0x28cf0371,0x6448c372}},	//   _boan, _vane_, _हेलि, gsdi,
   {{0x645c0373,0xdb0080b0,0x8cb04374,0x03a60375}},	//   vuri, _domæ, ंहतो, химо,
   {{0xef198283,0x69d50107,0x2b400017,0xeb970376}},	//   _bażi_, fize, _veic_, хия_,
   {{0xdb09c04c,0x1aec8079,0x7649c06a,0x22494377}},	//   rkeä, জেকে_, msey, dsak_,
   {{0x61e6c107,0x98b80007,0x3945c378,0xccf28052}},	//   ékle, karą_, mals_, ָכן_,
   {{0xd8d6c323,0x2249414b,0x63ad0379,0x6b9b817b}},	//   _רוקט_, fsak_, _goan, _nnug,
   {{0x3956401b,0x4421037a,0x3cfe402d,0xfbd14185}},	// [1a0] ењет, _euh_, _štv_, _सगरम,
   {{0xac86001b,0xe1f7437b,0x26c68022,0x6f0400f7}},	//   _згол, егу_, vzoo_, _izic,
   {{0x7988837c,0xa81a4200,0x7dc4c060,0x63ad037d}},	//   _radw, ستار_, _fòsf, _yoan,
   {{0xe889c0d1,0x6e20837e,0xdddb8085,0x63ad037f}},	//   _mẻ_, _pumb, _eruż, _xoan,
   {{0xb21b036b,0x7988814b,0x8574405f,0x9ad300eb}},	//   lvær, _padw, _لگائ, rịga,
   {{0x6d4e4380,0x6da38381,0x6b9b8382,0x6e20812c}},	//   _udba, лича, _enug, _vumb,
   {{0x7c2e4383,0x307a0009,0xa3c00384,0xde88c094}},	//   _utbr, לאַנ, ंघा_, _sị_,
   {{0x6618c120,0x7bd64385,0x6b898053,0x657e4386}},	//   _sivk, niyu, _gaeg, leph,
   {{0x442ec387,0x69d5000d,0x60c4c09c,0x63ad0388}},	//   _stf_, yize, _ƙimo, _roan,
   {{0xbbad4389,0xef1f038a,0xbe13838b,0xa7fd006a}},	//   _टक्क, rdüm_, _موقع, ptık,
   {{0x63ad038c,0x6448c039,0x645e438d,0x2006c00c}},	//   _poan, usdi, nupi, _thoi_,
   {{0x6d45438e,0xdddb838f,0xdb1d010b,0x657e400b}},	//   zaha, _isuš, visó, heph,
   {{0x63ad0390,0xfbdf001f,0x657e4391,0x69d50392}},	//   _voan, rnê_, keph, tize,
   {{0x443cc04d,0x6d418018,0xa6db410d,0xc9840393}},	//   _twv_, _xela, _neða, луси,
   {{0x661a8394,0xd90ec2f0,0xfd604112,0x443cc0a8}},	//   _mitk, _دید_, _wezụ, _uwv_,
   {{0x3cfbc093,0x62828395,0xd138c007,0x765d002f}},	//   _מלונ, kwoo, lbą_, pusy,
   {{0x672d0396,0x9f404397,0x798ac398,0x6d5a0359}},	// [1b0] _ifaj, rlið_, _kafw, ótac,
   {{0x62864033,0x22494399,0xdb1d0036,0x21f440cb}},	//   _dsko, rsak_, pisó, währ_,
   {{0x3b2e80eb,0xa3c0c39a,0xe889c0d1,0x645e439b}},	//   _ịyị_, ँसा_, _xẻ_, gupi,
   {{0x3fcf8079,0x661a839c,0x9e35839d,0x3e69839e}},	//   িক্ষ, _aitk, ведч, tút_,
   {{0x6b8d439f,0x6b898314,0xdd01c123,0x62864398}},	//   mdag, _vaeg, _čuča, _gsko,
   {{0xab5b40cb,0x3f8b4024,0x661a83a0,0x7bc083a1}},	//   _flüc, _hacu_, _citk, _elmu,
   {{0x443e83a2,0x7e6d43a3,0x645e43a4,0x661a83a5}},	//   _cwt_, ltap, cupi, _ditk,
   {{0xe65d83a6,0xe299c3a7,0x2d9cc053,0xaad283a8}},	//   ştığ, даи_, _anve_, _देवक,
   {{0x2485805c,0xba7483a9,0x69c380b6,0x798ac053}},	//   _wslm_, _مالت, phne, _bafw,
   {{0x64584007,0x224d83aa,0x6e22c026,0x6729c077}},	//   švie, _ivek_, _duob, scej,
   {{0xb902c11b,0x764d03ab,0x443e83ac,0x7659802c}},	//   изьк, _avay, _gwt_, lrwy,
   {{0x7e6d43ad,0xb909c3ae,0xc3cbc1f7,0x63af43af}},	//   ktap, _यश_, _عظام_, _nocn,
   {{0x5fa68045,0xae2183b0,0x3945c3b1,0x27e04147}},	//   कॉटल, मदिन_, pals_, vnin_,
   {{0xeab0c032,0xfce603b2,0xb88581c0,0x6b8d43b3}},	//   _دعم_, вого, _gríì, edag,
   {{0x2251c036,0x69d74018,0x2d8a43b4,0x186702d2}},	//   ązku_, dixe, _rabe_, кари_,
   {{0x16218185,0xc2c601b4,0x27e043b5,0xc0528323}},	//   मदार_, _ليبي, unin_, יזל_,
   {{0x7e6d43b6,0x69c183b7,0x442343b8,0x056641bc}},	// [1c0] gtap, _olle, _auj_, кван,
   {{0x27ed43b9,0x645e43ba,0x7c23c083,0xdb0403bb}},	//   čena_, tupi, _kunr, _goiá,
   {{0x224d83bc,0x0b46811b,0xc1bb03bd,0xdd8f43be}},	//   _avek_, внен, _חמיש, تول_,
   {{0x7c2dc3bf,0x63a9c3c0,0x2487c3c1,0x645e43c2}},	//   _čarl, jjen, _msnm_, rupi,
   {{0xb5fb001d,0x765980de,0x63bbc3c3,0xcf930052}},	//   rtáv, grwy, dkun, יטא_,
   {{0xf1b983c4,0x645883c5,0x3f8b41c6,0xa2cb4045}},	//   _dušo_, trvi, _zacu_, _सेट्,
   {{0xdca343c6,0x83fd03c7,0x18a343c8,0x628283b3}},	//   _кари, luđe, _карм, swoo,
   {{0x6d4703c9,0x6b8bc157,0xef1f0189,0x61e1c3ca}},	//   zaja, _cagg, rdük_, enll,
   {{0x6d4703cb,0x661a83cc,0x4423404d,0x2a6dc022}},	//   yaja, _titk, _zuj_, gteb_,
   {{0x3f9dc112,0x4423423b,0x7c23c359,0x6457803c}},	//   _enwu_, _yuj_, _bunr, áxic,
   {{0x2009000c,0x44234022,0x6b8d414b,0x2d8c806a}},	//   _phai_, _xuj_, ydag, _iade_,
   {{0x6d4703cd,0x63a9c3ce,0x68fc43cf,0x83fd02bc}},	//   waja, cjen, _myrd, kuđe,
   {{0x1958c3d0,0xe29800d7,0x27e6c303,0x63af43d1}},	//   _залы_, ваў_, _ijon_, _rocn,
   {{0x7bc2c047,0x6fdec017,0x69d743d2,0x69d883d3}},	//   _hlou, dīci, xixe, nive,
   {{0x2d8c83d4,0xc7c703d5,0x7640823b,0xf36743d6}},	//   _made_, _аспи, _lwmy, ктан,
   {{0x6d43c3d7,0x7e6d43d8,0x661c405e,0x6d4703d9}},	//   _zena, ttap, _airk, saja,
   {{0x2fc6801c,0xf96b43da,0x644e43db,0x557543dc}},	// [1d0] dhog_, дрей_, _avbi, лгат,
   {{0x44234046,0x69d8804f,0x26c94158,0x645ac3dd}},	//   _puj_, jive, rzao_, orti,
   {{0x63af43de,0x661c43df,0x7e60c3e0,0x67d543e1}},	//   _tocn, _dirk, hump, _бону,
   {{0xbddb43e2,0x27e6c011,0x2fc6802f,0x44314011}},	//   _avèt, _njon_, ghog_, _vtz_,
   {{0xa2cd8185,0xe78483e3,0x63a9c3e4,0x661c43e5}},	//   _देख्, рухо, vjen, _firk,
   {{0x2d8c83e6,0x1d0983e7,0x661c43e8,0x2d9e83e9}},	//   _cade_, нели_, _girk, _cnte_,
   {{0x2d8c83ea,0x63bbc3eb,0xddc44119,0x4433005c}},	//   _dade_, tkun, stiţ, _jtx_,
   {{0x2d8143ec,0x7afb8006,0x29058070,0x6b8d03ed}},	//   lehe_, _tyut, _vzla_, _naag,
   {{0x69d883ee,0x394783ef,0x7e60c3f0,0xddc283f1}},	//   bive, pans_, gump, stoš,
   {{0x6b8bc31c,0x6d4503f2,0x7bc2c3f3,0x9f60003c}},	//   _wagg, _neha, _elou, _ásúa_,
   {{0x1c1f03f4,0x6fdec017,0x63a9c0f6,0x2a6dc046}},	//   _मंगल_, zīci, pjen, steb_,
   {{0xf77203f5,0xe1ff0036,0xdb0643f6,0x6284402c}},	//   حاد_, otów_, _loká, ywio,
   {{0x7e60c319,0x6b8d0353,0x2d814303,0xee38c31e}},	//   cump, _daag, kehe_, _ані_,
   {{0x2d8c8018,0x6145c01b,0xddc44007,0x28d88384}},	//   _xade_, _сека, ktiš, _भेडि,
   {{0x437643f7,0x6d4503f8,0xa3ea40c5,0xbca8c032}},	//   луат, _deha, едва_, _لديك_,
   {{0xa76603f9,0xb5fb0166,0x7dd4003a,0x394583fa}},	//   _скид, tuác, _müsə, _lels_,
   {{0x7bc403fb,0xdce1c007,0x27ffc051,0xe81bc3fc}},	// [1e0] _iliu, telė, ilun_, _पूछा_,
   {{0x69d883fd,0x531b00c3,0xd5b180d1,0x10a640d9}},	//   xive, _אופצ, _nó_, лизн,
   {{0x69d883fe,0x7afd43ff,0x83fd038f,0x6289830d}},	//   vive, _eyst, suđe, _aseo,
   {{0x929d8064,0x3f8d803c,0xf1bf4400,0x98bec119}},	//   _czło, _caeu_, _stát_, lată_,
   {{0xe2978401,0x68ff8080,0xdcf88017,0x644e0402}},	//   лац_, əqdi, devā, lsbi,
   {{0x98bec119,0x74348403,0x65948404,0x6d48c405}},	//   nată_, анкф, раку, xada,
   {{0x6adcc3a8,0x7981c406,0x644e0407,0xe56f81e3}},	//   मप्र, delw, nsbi, سطو_,
   {{0x8b9580f9,0xdcfc0408,0x76aac409,0x93b4c40a}},	//   _круч, jerč, етов_, рбиц,
   {{0x798e440b,0x644180f1,0x386e840c,0xdcee4007}},	//   _kabw, _ewli, stfr_, _pabė,
   {{0xfd65825d,0xdb0f4016,0xc27b8052,0x7bd6040d}},	//   _metụ, _docè, _ארמי, _amyu,
   {{0x6d4a840e,0xb5fb0107,0xd917c051,0x7bc2c0a0}},	//   mafa, ktár, лью_, _tlou,
   {{0x7bc2c40f,0x7bc40321,0xddc40085,0x6d5a0410}},	//   _ulou, _cliu, _epiż, ótan,
   {{0x63bd0411,0x69c70412,0x321e8413,0xdb198414}},	//   rksn, thje, _kity_, chwä,
   {{0xb5fb001d,0x7afd4415,0x98bec0b4,0xa158c31e}},	//   etár, _ryst, gată_, _раку_,
   {{0x7bc402d4,0x69c70416,0xaca340eb,0x69c8c2d4}},	//   _fliu, rhje, _kwục, mhde,
   {{0x8aa70417,0x2bbb01b4,0x2d814418,0x20004419}},	//   _брод, _ساعة_, wehe_, glii_,
   {{0xdb1d01b4,0xbebb40da,0x2121005c,0xb4bd4185}},	// [1f0] bhsá, _afër, _tghh_, इन्_,
   {{0xd567041a,0x661e041b,0x6d4a841c,0x2b494018}},	//   _стип, _gipk, jafa, saac_,
   {{0x6565421b,0x2d8ec0e2,0x99d5801c,0x764d441d}},	//   rghh, _mafe_, یتتا, ssay,
   {{0x09e1c41e,0xb5fb041f,0xe71981b4,0x7981c0f7}},	//   _पद्य, ctár, نيات_, zelw,
   {{0xddc44420,0x6015c043,0x2f0b4031,0xbea58421}},	//   stiš, _ušmi, _dògí_, ралк,
   {{0xa3d2c185,0x2055834a,0x93bcc422,0x2c5e4044}},	//   होस_, атир, _stăp, _ọdee_,
   {{0x6b828423,0x44258424,0xdb028397,0x5b378425}},	//   beog, _qul_, skoð, _معذر,
   {{0x69c3c166,0xdb1d410d,0x2d830426,0x7981c427}},	//   _slne, _umsó, heje_, welw,
   {{0xdb09810d,0xae150428,0x6e948429,0x290c41b4}},	//   _gleð, णगान_, _литу, _údar_,
   {{0x2b46c141,0x2d9100b3,0x63ad42f7,0x224dc42a}},	//   _eeoc_, jdze_, hjan, rsek_,
   {{0x2d8ec42b,0x38bb802e,0x442581c8,0x98bec0b4}},	//   _dafe_, _dàrú_, _uul_, vată_,
   {{0xaca340eb,0x224dc42c,0xe0d6c42d,0x69c8c149}},	//   _gwục, psek_, рвю_, ahde,
   {{0x6da5c42e,0x7642c0bb,0x2ba8042f,0x69a20430}},	//   _вила, _gwoy, गाबा, खाली,
   {{0x69c50061,0x2d8301c6,0x628bc1c8,0xdce50053}},	//   _clhe, geje_, _isgo, _echč,
   {{0x3947c431,0x46d9c17e,0x15f4439a,0x753c0011}},	//   _iens_, _बेतह, अवसर_, rbrz,
   {{0x798e4432,0x6d4a81c6,0x69c50107,0x6b828004}},	//   _sabw, zafa, _elhe, xeog,
   {{0x09c1402a,0x3f8fc433,0xe1fa4434,0xb5fb0107}},	// [200] োচনা, _magu_, вга_, rtár,
   {{0x8af00435,0x7c274436,0x6d47434d,0x7dc4c0b6}},	//   _edəc, _bujr, _ceja, _kòsa,
   {{0x98a60437,0x4427c438,0x6e22023f,0x057700c3}},	//   _тине, _jun_, _èobb, _דגים_,
   {{0x628bc02c,0x63ad4036,0x7c294089,0x200d8439}},	//   _osgo, cjan, _čert, _chei_,
   {{0x2a7dc022,0x69dac43a,0x6b84443b,0x7bc9c0fd}},	//   _npwb_, yite, meig, dheu,
   {{0xf50a443c,0x51f7831e,0xfd6740eb,0xdb1d043d}},	//   _англ_, анію_, _merụ, cisõ,
   {{0x80b60079,0x4420043e,0x7dc4c29a,0x74168231}},	//   ৃপক্, _oii_, _nòsa, _نوسا,
   {{0x6b84443f,0xe7c10079,0xf1bf4018,0x290a4440}},	//   neig, _উদ্য, _juán_, _izba_,
   {{0x9df8c441,0xada68026,0x79a6c442,0x798380cb}},	//   лнит_, _каал, арне, benw,
   {{0x2259c443,0x3947c016,0xda164444,0x9f5940b6}},	//   áska_, _cens_, थगित_, _eksè_,
   {{0x7786c445,0x30868446,0x6005c2b0,0xba84803a}},	//   _влез, _خلاف, cómo, şçıs,
   {{0x7bc9c447,0x07a3c448,0x76440449,0xb33b41ff}},	//   cheu, _махн, _bwiy, _onça,
   {{0x5f94044a,0x2d83044b,0x91e6c44c,0x6b84444d}},	//   цият, teje_, _коде, deig,
   {{0x69dac0fd,0x27e6805c,0xa3d2c0e6,0x7644044e}},	//   qite, hnon_, होर_, _dwiy,
   {{0x0ce14079,0x6d47444f,0xdb1d010b,0xf2e8c079}},	//   _ভর্ত, _reja, visõ, _পরিণ,
   {{0x27e90450,0x394cc065,0xe4578009,0x61f88451}},	//   _ujan_, lads_, יילט_, hovl,
   {{0x241843d0,0x27e68105,0x7c2dc41b,0xac18426f}},	// [210] роты_, dnon_, _čari, роту_,
   {{0x69dc0452,0x63ad4453,0x14cac048,0xddc28017}},	//   cire, sjan, ानपण, lsoņ,
   {{0x409501b4,0x7c29405b,0x4427c057,0x6d474454}},	//   _الجر, _čers, _xun_, _veja,
   {{0xb9280112,0x2fc04455,0x0b588097,0x7d0800b2}},	//   kwuọ_, ckig_, аршы_, üdse,
   {{0x2bba0027,0xddc9c0b4,0x7c20813b,0x2d8741cb}},	//   _उकसा, nteţ, _dimr, ônes_,
   {{0xb602c066,0x683340f6,0xdcfe0047,0xce3800c3}},	//   _žánr, _aħde, _napě, סאות_,
   {{0x3f8fc456,0x97a78457,0x7bc9c1ff,0x645e4458}},	//   _pagu_, _крал, theu, crpi,
   {{0xf1d98459,0xdcfc0017,0xc245c0d9,0xab5b409d}},	//   _भगवन, nerā, бник, _olüm,
   {{0x4427c45a,0x5fa9c036,0x6d48845b,0x7bc9c1b0}},	//   _sun_, काबल, _feda, rheu,
   {{0x7bc9c127,0xbec40026,0xf9d4800a,0x76440449}},	//   sheu, šūki, _доуэ, _rwiy,
   {{0xdb0080ce,0xc8d60045,0x5dfa8052,0x2fc6c45c}},	//   _anmè, _डेंट, _עפענ, _flog_,
   {{0x3a29034d,0x3f84c45d,0x4815c45e,0x6e21845f}},	//   _buap_, cemu_, _умес, _hilb,
   {{0x6fc60032,0x37cd402a,0x7d018460,0x44440461}},	//   _cóca, রচার, _hyls, _sw_,
   {{0x6e3bc462,0x2901005c,0xfe70c01c,0x645cc30d}},	//   mpub, _byha_, _زده_, áric,
   {{0xd435c228,0x8fa64463,0x07a6419b,0x4427c057}},	//   _اعتب, баве, бавн, _uun_,
   {{0x44200033,0x645cc2bc,0x69dc0464,0xa7fd006a}},	//   _uii_, šric, sire, stır,
   {{0x2a7f8022,0x6e3bc465,0xbea34466,0x2c71c107}},	// [220] _npub_, npub, патк, lád_,
   {{0x5d8601b4,0xb5fb0467,0x645e4468,0x3f920469}},	//   _الدل, nuál, trpi, _hayu_,
   {{0x6fc6046a,0x27e68010,0x64578018,0xa3be025c}},	//   _zóca, tnon_, áxil, _ेता_,
   {{0x443a446b,0xddc2c0a0,0x629b8026,0xd62a846c}},	//   rpp_, _dvoř, _bruo, годе_,
   {{0x7f498057,0x248c805c,0x02d2846d,0x7c28846e}},	//   _deeq, _ssdm_, _देखभ, _sudr,
   {{0x9f49410d,0x4422427c,0x69c74011,0x27e6846f}},	//   llað_, _hik_, _glje, snon_,
   {{0x63a40470,0xf8c80471,0xc0f20015,0x629b80eb}},	//   _onin, रनिय, _rượu_, _eruo,
   {{0xa8574093,0x69c740b3,0x44224472,0x5a34c473}},	//   _לילה_, _zlje, _jik_, онит,
   {{0x25ef4474,0x44224475,0xe2978476,0x629b8039}},	//   _आदमी_, _mik_, _лат_, _gruo,
   {{0x9f420066,0x6d488396,0x5454c477,0xf400402a}},	//   roký_, _ueda, овот, ্দির_,
   {{0x02b30478,0xc7afc04c,0x69da8479,0x63a40010}},	//   ुन्न, _её_, _imte, _bnin,
   {{0x442a447a,0x63b6005e,0x69ddc01e,0x09c20079}},	//   _mub_, _coyn, éser, _ঈদগা,
   {{0x7bdd047b,0x2bbf4384,0x6e2d41c8,0x63a4005e}},	//   risu, _एकबा, xqab, _dnin,
   {{0x63a4047c,0x4438407a,0x7f4d4057,0x6ca6c47d}},	//   _enin, _otr_, waaq, _гриж,
   {{0x3f9200e2,0xdce38017,0x2a60409d,0x7c22c398}},	//   _fayu_, venī, erib_, _kior,
   {{0xa3abc0b2,0x6fc60004,0x2246c396,0xd8388011}},	//   खाय_, _tóca, _kwok_, _mtč_,
   {{0x78c60158,0xddc9c47e,0x95d9447f,0x3f868480}},	// [230] _čuvš, lteš, адат_, deou_,
   {{0x44224481,0x7f4f00c4,0x24898036,0x69de4482}},	//   _eik_, lacq, łami_, gipe,
   {{0x7d7bc323,0x6d4ac17b,0x249cc085,0x3f920231}},	//   רנבו, _mefa, _jrvm_, _yayu_,
   {{0x6d5e8483,0xfd1041b4,0x61fac484,0xb5fb0485}},	//   ópan, رجل_, hotl, zuál,
   {{0x6d58c486,0x7ae4c487,0x80da4079,0x6f02c094}},	//   _odva, _žitn, _বুদ্, _nyoc,
   {{0x2d85c488,0xdb1b8016,0x7bc28489,0x7bcd448a}},	//   xele_, _lluç, akou, lhau,
   {{0xa2db048b,0x442a448c,0x7c2ac060,0x6b5f4031}},	//   _पेस्, _gub_, _nufr, _gàgà,
   {{0x7c22c48d,0x2d93048e,0xe3b9c48f,0x7bcd4490}},	//   _cior, _laxe_, рби_, nhau,
   {{0x66038038,0x6d4e0491,0x27ff8492,0xb7b5c0eb}},	//   plnk, yaba, _ikun_, _bụr,
   {{0x2fc90010,0x6d4e0493,0x7bdf401e,0x225fc0bb}},	//   _alag_, xaba, hiqu, rruk_,
   {{0xb5fdc494,0x1d09c495,0x7bdf4396,0xcb090093}},	//   bušn, рени_, kiqu, _סל_,
   {{0x27ff81b7,0x69de4496,0x7bd9c00d,0xa91cc166}},	//   _jkun_, zipe, _umwu, peľn,
   {{0x8af0003a,0x44224497,0x27e94498,0xda094048}},	//   _edən, _rik_, dnan_, वतात_,
   {{0x7bc98499,0x27e9c0e0,0x7bc28185,0x2b4b449a}},	//   _lleu, čanu_, zkou, _aecc_,
   {{0x7f4f023f,0xcfaa049b,0x3f92049c,0xd10dc49d}},	//   bacq, _ناظم_, _tayu_, _हरिण_,
   {{0x29040279,0x6d4ac49e,0x0fb34064,0x6fda4047}},	//   āma_, _zefa, ीसगढ, můck,
   {{0x99890166,0x8236049f,0x442244a0,0x2b4044a1}},	// [240] _stať_, _بربا, _vik_, rbic_,
   {{0x7d03c4a2,0x7bc984a3,0x6abb00fa,0x6e23c283}},	//   _kyns, _aleu, äufe, _jinb,
   {{0x308644a4,0x7bcd44a5,0xa37b010b,0xc8d8809d}},	//   تلاف, bhau, siõe, _भेंट,
   {{0x7bcd44a6,0x443a0036,0x290340fd,0xfaa64039}},	//   chau, _itp_, _dyja_, _дамо,
   {{0xf38d0009,0x24864166,0xacf6001c,0x6e23c0b9}},	//   טראָ, ňom_, _دسکت, _oinb,
   {{0x27ed84a7,0x27e044a8,0x7ae4c06f,0x3e744051}},	//   _ejen_, liin_, _žito, mät_,
   {{0x216781bd,0x3160806a,0x7e7644a9,0x6d41c4aa}},	//   цији_, ğiz_, ltyp, dbla,
   {{0xb6024047,0x61fc04ab,0x6d4ac4ac,0x6e23c4ad}},	//   řáda, horl, _sefa, _ainb,
   {{0x3f98c047,0xa5bb41c0,0xa96a81cc,0x7c22c0b4}},	//   ěru_, _atóy, _виза_, _vior,
   {{0xe80ac4ae,0x69c384af,0x27e944b0,0x44248093}},	//   _हीरा_, ckne, znan_, _him_,
   {{0x443a04b1,0x61fac0d2,0xf1d9c4b2,0xdb0f44b3}},	//   _ntp_, rotl, योधन, _rocí,
   {{0x61b744b4,0x442c84b5,0x7c3a8283,0xc6a704b6}},	//   _आक्ष, _iud_, _ittr, орги,
   {{0x3e74404c,0x27e044b7,0x6b9641f4,0xddcd4119}},	//   jät_, diin_, ddyg, ntaţ,
   {{0x69ce0100,0x7d03c4b8,0x6e23c4b9,0x61fc04ba}},	//   ghbe, _fyns, _ginb, gorl,
   {{0x7c240057,0x27e944bb,0xdb008036,0xc1050032}},	//   _fiir, tnan_, _komó, سوري,
   {{0x7bcd44bc,0x3a2b4070,0xd6db0069,0x27e044bd}},	//   uhau, _pucp_, _вто_, giin_,
   {{0x6fc60018,0x6d41006a,0x2d8784be,0xb4c68185}},	// [250] _zóco, ılab, yene_, उनु_,
   {{0x443ec1d4,0x6455421b,0x683341d6,0x224901aa}},	//   opt_, _pvzi, _aħda, _iwak_,
   {{0x7bdf44bf,0x7c3e40f8,0x9f38825d,0x442c84c0}},	//   piqu, gppr, _ịmụt, _nud_,
   {{0x224904c1,0x443ec4c2,0xab5b00cb,0xe80ac0aa}},	//   _kwak_, ipt_, chüt, _हीला_,
   {{0xd6db84c3,0x6282c022,0xe5a584c4,0x6d41c32a}},	//   јте_, _npoo, зили, ybla,
   {{0xb5fdc011,0xe9d884c5,0x6448832a,0x3e7b40cc}},	//   gušl, окі_, _bwdi, râtă_,
   {{0xdd0e838a,0xddcd04c6,0x23bf44c7,0x3ea980b4}},	//   rışm, _opaž, _एकाद, ţat_,
   {{0x6e23c1a8,0x27ff84c8,0xa5bb401f,0x2cbc44c9}},	//   _sinb, _ukun_, _atóx, ävde_,
   {{0x7d03c4ca,0xddcd4119,0x6d41c4cb,0xf1b9841b}},	//   _syns, ctaţ, tbla, _sušu_,
   {{0x49b884cc,0xdcfc406f,0xedd58032,0x6d41c4cd}},	//   _والد_, _zarđ, _عياد, ubla,
   {{0x61fc036b,0xab2a04ce,0x27e04057,0x6e23c4cf}},	//   vorl, йона_, yiin_, _vinb,
   {{0x2cb8c041,0x2b4d80d2,0x7f5b8085,0x7c240149}},	//   ärda_, _jeec_, _jduq, _qiir,
   {{0x80b184d0,0x27e04051,0x6e23c4d1,0x443ec0a8}},	//   _अपडे, viin_, _tinb, apt_,
   {{0x6e2d0033,0x6b89c4d2,0x7c3a84d3,0xa2d4c09d}},	//   _duab, leeg, _yttr, _बेट्,
   {{0x7c2404d4,0x18a30030,0x22490303,0xa0a304d5}},	//   _tiir, нарм, _ewak_, нард,
   {{0xe8d6c0c3,0x672484d6,0x6e3b84d7,0xaabd84d8}},	//   _מוצר_, žiji, _otub, ्नाक,
   {{0x629bc051,0x61fc04d9,0xa3bd4045,0x799544da}},	// [260] nvuo, porl, _अवर_, _bazw,
   {{0x7d1a410d,0x4a9b02a6,0x672984db,0x7dcdc4dc}},	//   _útsk, _פייג, _agej, _húsb,
   {{0x7bcbc4dd,0x91bb00c3,0xec7a44de,0x3e744051}},	//   _olgu, _המיי, спе_, sät_,
   {{0x7649811c,0xd7af0048,0x5faf0048,0x63a640c3}},	//   _bwey, टायच, टायल, _unkn,
   {{0xf19484df,0x6005c019,0x7f5b8085,0xc33304e0}},	//   диль, cómi, _dduq, גוד_,
   {{0x442484e1,0x2b98c00c,0xf2d34009,0x7f5b84e2}},	//   _wim_, _ức_, _טער_, _eduq,
   {{0xd7cc008f,0xb5fb010d,0x7988c053,0x7c264150}},	//   ासाच, krán, vedw, _kikr,
   {{0x67364036,0x32078036,0xdb008060,0xddcd40b4}},	//   ncyj, alny_, _domò, ptaţ,
   {{0x2bbf44e3,0xe3afc032,0x764980bc,0xb5fb04e4}},	//   _एकसा, ارى_, _gwey, drán,
   {{0x7f4d005c,0xed5781a9,0x7c2644e5,0x2d8a0043}},	//   _seaq, _ноу_, _likr, jebe_,
   {{0xdcf5003f,0x7c3a84e6,0x645a0199,0x7988c02c}},	//   rdzī, _uttr, štij, redw,
   {{0x7aedc0a0,0xdb0d043e,0x7c264085,0x628404e7}},	//   _žate, _joaç, _nikr, _bpio,
   {{0x1ee704e8,0xe9a6c4e9,0x539bc0c3,0x2b524070}},	//   سوسی_, _надп, _ליאו, dayc_,
   {{0x6d5c44ea,0x64b54047,0x57b984eb,0x3ea004ec}},	//   _ndra, _hřiš, _आव्ह, _drit_,
   {{0xe97bc093,0xa97bc0c3,0x64b540a0,0x628400b9}},	//   _הנוש, _האוכ, _křiš, _epio,
   {{0xddeb001c,0x6284005e,0x6005c4ed,0x6458c17a}},	//   _گربه_, _fpio, tómi, _ivvi,
   {{0x6455005f,0xe66444ee,0xa3ca04ef,0x66f44186}},	// [270] sszi, етхо, लघर_, епту,
   {{0x7bcd04f0,0x2b4d8004,0xddcd4077,0x27e0c089}},	//   _hlau, _seec_, ftaš, činy_,
   {{0x442ec4f1,0x6fe8c047,0x6005c4f2,0xc178c007}},	//   _juf_, pěch, sómi, lnės_,
   {{0xf6f5801c,0x7c264449,0xdb0d043e,0x69c54098}},	//   وزشگ, _gikr, _coaç, skhe,
   {{0x61e1c4f3,0x7dcf8240,0x920cc027,0x6d4e44f4}},	//   yill, _løse, हताज_, _feba,
   {{0x27ed40e0,0x69c704f5,0x7bcd04f6,0x443cc0cc}},	//   čenu_, nkje, _llau, _otv_,
   {{0x846440c5,0xfc6440c5,0x29380323,0x6fc60359}},	//   _пъте, _пътн, לאגן_, _sócm,
   {{0x43948051,0xaac8c185,0xa247805f,0x291144f7}},	//   _пасс, ाईंक, _فیصل_, _izza_,
   {{0xc3344093,0x6d4544f8,0x3f8b04f9,0x63a984fa}},	//   עוץ_, obha, decu_, _inen,
   {{0x6d45424f,0x7bcd0007,0xde16c032,0xa2d684fb}},	//   nbha, _alau, وقيت_, _मेट्,
   {{0x9d0bc079,0xaf37c4fc,0x442ec4fd,0x20094039}},	//   রশ্ন_, _فرشت, _cuf_, klai_,
   {{0x6b8b84fe,0x6458c0b3,0x6d4544ff,0x67d4c04c}},	//   negg, _dvvi, hbha, _поху,
   {{0xb5fdc500,0x27edc501,0x7bc6004c,0x2d8a0502}},	//   nušk, mnen_, rkku, tebe_,
   {{0x4426c503,0x61fe40d2,0x61e38504,0xe3bf434d}},	//   _zio_, xopl, ninl, _riña_,
   {{0xabf6009b,0x6d454359,0x33f60505,0x9f8b4086}},	//   _очищ, dbha, _очис, töðu_,
   {{0x6441c506,0x7e644507,0x6d5c40c4,0x7dc04508}},	//   mpli, trip, _sdra, _löst,
   {{0x6e2741d4,0x6d4e407a,0x29114509,0xd12f00fb}},	// [280] _bijb, _peba, _azza_, امہ_,
   {{0x63a9850a,0x04464051,0x2bcc050b,0x7dcb050c}},	//   _anen, дежн, ासवा, _hüsn,
   {{0x7e64450d,0x225e0036,0xdb0f450e,0x63bb80c3}},	//   srip, ątku_, _vocá, _boun,
   {{0xddcd450f,0x83838051,0x6d454510,0x6b8b8511}},	//   rtaš, выше, abha, gegg,
   {{0x2fc6841b,0xb5fb0512,0x12e8c02a,0x29114513}},	//   rkog_, král, _পর্দ, _ezza_,
   {{0xb5fdc514,0x63a98515,0x7d788032,0x6d4340b5}},	//   sušj, _enen, سمبر_, ınac,
   {{0x64b54185,0x27edc0fa,0x6441c516,0x7c2e402f}},	//   _přiš, fnen_, jpli, _uubr,
   {{0x63bb8053,0x2d984517,0xdb0400d2,0x210301af}},	//   _goun, _hare_, _joió, _učiť_,
   {{0x443cc518,0x24858024,0x3f8b0011,0xdb19c0b6}},	//   _stv_, _eplm_, vecu_, _jowè,
   {{0x7bcd0519,0xa2a20185,0x27edc51a,0x63a98166}},	//   _slau, खिन्, anen_, _znen,
   {{0xd12f851b,0x63bb851c,0x2009402c,0x83fd0123}},	//   _ضمن_, _youn, ylai_, luđi,
   {{0xdb0d4086,0x3cf18089,0x4426c51d,0x61ee0127}},	//   kkað, ťový_, _uio_, enbl,
   {{0xb5fb051e,0x6458851f,0x7bd600fd,0xff040520}},	//   brál, lsvi, ëzua, вярн,
   {{0x3f824020,0x8c148079,0x7dc04521,0x51840522}},	//   _abku_, িদিন_, _möss, куса,
   {{0x6e288149,0x24194523,0xc04fc176,0x80e0802a}},	//   _midb, зовы_, _ші_, _পুত্,
   {{0x2a66805c,0x7bdf00c2,0x61e38189,0x6eb4c036}},	//   krob_, _umqu, zinl, ेहपु,
   {{0x9f4200fd,0x63bb8524,0xda784525,0x61e38526}},	// [290] zikë_, _roun, дях_, yinl,
   {{0x63bb8438,0x6d454527,0x6b8b80bc,0xbbc78428}},	//   _soun, ubha, wegg, लस्क,
   {{0x6b8b80c5,0xb5fdc06c,0xa3c60285,0x20094528}},	//   tegg, kršn, _एवम_, plai_,
   {{0x7dc044c9,0x7dcdc529,0x7998c3e2,0x6d47052a}},	//   _böss, _músa, _lavw, lbja,
   {{0x61e3852b,0xddc98047,0x6b8d452c,0x2d8cc52d}},	//   tinl, _zveř, meag, kede_,
   {{0x9f4200da,0x26c4c039,0x443e8263,0xba3d8047}},	//   tikë_, dymo_, _btt_, _průb,
   {{0x61e3852e,0x6b8b80c4,0x7e6d452f,0x61e5400b}},	//   rinl, pegg, luap, mihl,
   {{0x61e38530,0x6aa2c1f4,0x32014066,0x2907c05c}},	//   sinl, _brof, lohy_, _ryna_,
   {{0x60160531,0xba25c143,0xe3bf403c,0x644e8283}},	//   náme, ндик, _liño_, _ħbie,
   {{0x44290532,0xc6924093,0xf99383be,0xa805c004}},	//   _aia_, נאי_, _جبر_, fiñá,
   {{0x443e80e2,0x44314533,0x2c78c534,0x5eb78079}},	//   _gtt_, _juz_, géd_, _আইটে,
   {{0xb21b4535,0x69c8c010,0x764d0536,0x224d8537}},	//   _spæl, akde, _bway, _kwek_,
   {{0x7c298538,0x2d834539,0x5275053a,0x6aa2c53b}},	//   _mier, _obje_, куру, _grof,
   {{0x764d00b6,0x69c8c53c,0x7c29853d,0xb5fdc53e}},	//   _dway, ckde, _lier, kuši,
   {{0x3eb5c119,0x4429053f,0x44314540,0x997d0017}},	//   ţetă_, _fia_, _nuz_, kāņu_,
   {{0xee3a4541,0x7bc9c542,0xa2db0048,0x61f60007}},	//   зна_, nkeu, _पेक्, _šalč,
   {{0x3f994360,0x6f1d8089,0x764d0543,0x7dd004c9}},	// [2a0] _dasu_, _úsch, _gway, _väsb,
   {{0x24f64156,0xdb008544,0x7c298545,0x2bd24314}},	//   нчер, _komö, _aier, _सतवा,
   {{0x44290546,0xfb8a823d,0xab668547,0x290e0107}},	//   _yia_, збек_, евел, _áfa_,
   {{0x3e79c3bc,0xa6db4086,0x2d8cc548,0x3d150549}},	//   kèt_, _veðr, zede_, _धरते_,
   {{0x3d06c54a,0x224d8033,0x6601c066,0x2d8cc06a}},	//   _सुने_, _cwek_, kolk, yede_,
   {{0x7c29854b,0x245a8017,0x60160019,0x63bd4089}},	//   _eier, tīm_, námb, _zosn,
   {{0x6005c086,0x603c00ce,0xc7b08107,0x7a294026}},	//   jóms, _fčme, _پڑا_, _užta,
   {{0x3e79c3bc,0xdb2180fa,0xf76fc54c,0x443e854d}},	//   fèt_, _äuße, ماً_, _vtt_,
   {{0x4444454e,0x3ea2c086,0x798e031c,0x46b78036}},	//   lp_, íkt_, kebw, _आपयह,
   {{0x4444454f,0x7c298550,0x26c4c007,0x44314551}},	//   op_, _zier, rymo_, _yuz_,
   {{0x44444141,0x443e803f,0x6d550552,0xe0be402a}},	//   np_, _utt_, vaza, _আধুন,
   {{0x6aa40553,0x44290046,0x7c298283,0x61e540f7}},	//   _brif, _qia_, _xier, zihl,
   {{0x799a8554,0x44290555,0x44444556,0x160bc036}},	//   _katw, _via_, hp_, _सीकर_,
   {{0x27e6802c,0xceb382a6,0x7de6c396,0x63bd4036}},	//   hion_, איש_, _désè, _sosn,
   {{0x27e68557,0x6a140558,0xe1ff0559,0x6b8d455a}},	//   kion_, умру, brón_, teag,
   {{0x6d55055b,0x6aa4055c,0x6b84055d,0x7dd4805e}},	//   saza, _frif, _gbig, _fàsg,
   {{0x7c298315,0x3f994222,0x32014066,0x798e055e}},	// [2b0] _rier, _vasu_, tohy_, bebw,
   {{0xb21b0065,0xd056803a,0x2d8e8070,0x7e6d4230}},	//   dtæg, şbəx, jefe_, ruap,
   {{0xb4bd455f,0x98b80007,0x27e681f4,0x63ad00f8}},	//   ेने_, darė_, fion_, _knan,
   {{0xb8d940b2,0x2d9a0560,0x3244001c,0x636b8561}},	//   _अऊ_, _zape_, _جنیف, dönü,
   {{0xa4a5c031,0x44444562,0x9f494032,0x799a818b}},	//   _asọ̀, ap_, nnaí_, _batw,
   {{0xb5fb030d,0xdcfc4007,0x1d098563,0x59a48045}},	//   cuát, _narė, мели_, _गोदर,
   {{0x2ec9c564,0xe1f08183,0xace8805f,0x7640817b}},	//   िन्त, حسن_, ٹرول_, _etmy,
   {{0x3e79c565,0xddc28039,0x7dd24065,0x6b9d0566}},	//   tèt_, ruoš, _væse, jdsg,
   {{0x7e6f0011,0xa283c567,0x765b8449,0x37f88119}},	//   jucp, ایتو, _uvuy, _четэ_,
   {{0x799a8568,0xe530403a,0x64454569,0x645ac56a}},	//   _gatw, _müğə, ophi, fsti,
   {{0x9991c05f,0xbebdc039,0x644540d2,0x44330498}},	//   öző_, ncūz, nphi, _nux_,
   {{0x2d9a056b,0x3f8f80de,0x59a6c56c,0x7e7d056d}},	//   _sape_, negu_, _कोठर, ftsp,
   {{0xa91cc02d,0x799a8536,0xb5fb456e,0xdb008414}},	//   deľu, _yatw, _kvád, _womö,
   {{0x4444456f,0xdce182d6,0xddc44570,0x6d5cc571}},	//   yp_, _halı, kuiš, órat,
   {{0x3f8f80fc,0x7e7d0572,0x91a900d1,0x057602f0}},	//   kegu_, atsp, _quá_, _یادد,
   {{0x44330573,0x673bc574,0xe1ff0107,0x7dcdc02d}},	//   _dux_, ncuj, lról_, _kúso,
   {{0xf1b5c575,0x501b0093,0x2a7d8022,0x7e7d0576}},	// [2c0] _अचान, _קופו, jtwb_, ctsp,
   {{0x3ea04577,0xa2db0578,0xd9464579,0x7644402f}},	//   rvit_, _पेट्, тежи, rpiy,
   {{0x8e3a057a,0xdb064036,0xdcfc0017,0xd12f4032}},	//   _عسکر_, _pokó, idrī, زمن_,
   {{0x9c82406c,0xaa468297,0x83fd00ab,0x4444457b}},	//   ščob, ведл, buđu, rp_,
   {{0x98b80007,0x6d57457c,0x27f8c107,0x645c0372}},	//   tarė_, baxa, _írni_, lsri,
   {{0x9d43457d,0xda020021,0xe4e38185,0x3f8f809d}},	//   _верд, लकित_, _केहि_, aegu_,
   {{0x9f590107,0x91e3457e,0x64418247,0xf41f0025}},	//   őzés_, _торе, _ctli, ymä_,
   {{0xbeb78185,0x799c457f,0xdb1d4303,0x7c2bc580}},	//   _šíře, _harw, _bosè, _cigr,
   {{0x60c70036,0x765bc02f,0x39580581,0x66038582}},	//   zyjm, gsuy, kars_, bonk,
   {{0x71a38583,0x683ec017,0xdb1d4303,0x270140d1}},	//   _кауз, _līde, _dosè, ỗng_,
   {{0x6d588584,0x39580585,0xb5fb0107,0x7afd8586}},	//   mava, dars_, lság, _østr,
   {{0x7c2bc498,0xa91cc166,0xbb46c587,0x6d4100b5}},	//   _gigr, deľt, _редк, ılam,
   {{0x8bd7c0c3,0x6b9d0588,0x41e70589,0x61e700a8}},	//   _בואו_, rdsg, віва, tijl,
   {{0x2d850066,0x7dcf858a,0x799c4449,0x8af78080}},	//   ýle_, _løsn, _narw, _şəkl,
   {{0xdb0bc231,0x7e7d02ad,0xdce1806a,0x61e70206}},	//   _angè, stsp, _yalı, rijl,
   {{0x7bc0818c,0x2d9ec58b,0x938b01bc,0x6603858c}},	//   _nomu, ldte_, _цска_, zonk,
   {{0xb5fb0032,0x6603858d,0x3d06c58e,0x5b15458f}},	// [2d0] hrái, yonk, _सुते_, умат,
   {{0x68ee01b4,0x2004c590,0x2d9cc591,0x61554107}},	//   ándá, homi_, _jave_, انائ,
   {{0x48de854a,0x2d9cc0b0,0x3f86c047,0x2004c592}},	//   _कइगो_, _mave_, _obou_, komi_,
   {{0xb5fb001f,0x8af78080,0xe4a400d9,0x61e8c593}},	//   cuár, _çəkm, _трьо, hidl,
   {{0x8e858594,0x765d0595,0xb5fb0107,0x66038596}},	//   угле, nssy, gság, tonk,
   {{0x7c2bc597,0x2d910598,0x799c4599,0xdce1859a}},	//   _sigr, neze_, _garw, _salı,
   {{0x7c2bc59b,0xb4bf859c,0x61e8c066,0x2054859d}},	//   _pigr, ुने_, didl, атыр,
   {{0x3ea6c59e,0xd3a48505,0x2d9ec59f,0xdce1803a}},	//   _brot_, _круп, edte_, _qalı,
   {{0x3ea6c07a,0x6fca4066,0x673bc5a0,0x569485a1}},	//   _crot_, _dých, rcuj, _катт,
   {{0xb5fdc4f9,0x6d5545a2,0x2bcc05a3,0x3cde8384}},	//   jušt, _jeza, ास्थ, _केके_,
   {{0xa3ea05a4,0x442d85a5,0x1bea05a6,0x4375c5a7}},	//   една_, _kie_, едни_, _مهار,
   {{0xa3b685a8,0x2004c5a9,0xe1ff0107,0x6f0d01c6}},	//   जाय_, comi_, sról_, _byac,
   {{0xd37a8009,0x3ea6c5aa,0x4e79c052,0x7dc4c5ab}},	//   ערשט, _grot_, _נאַצ, _pòst,
   {{0xfce605ac,0xdb1d40d2,0x265ac0c3,0x442d85ad}},	//   гого, _gosé, _טכנא, _lie_,
   {{0x7c2d05ae,0x8fa605af,0x395805b0,0x3f9dc0e2}},	//   _fiar, _байе, rars_, _kawu_,
   {{0x6fc605b1,0x799c45b2,0xd6d9c064,0x61e50339}},	//   _cóct, _sarw, wały_, _emhl,
   {{0x395805b3,0x799c4396,0x0d8645b4,0xe9df0018}},	// [2e0] pars_, _parw, ллан, mpún_,
   {{0x69c185b5,0x7bc085b6,0x27e940c9,0x9f44c01e}},	//   _nole, _somu, aian_, rimé_,
   {{0x442d85b7,0x7bc0811a,0x6fd6c048,0xdce3c06a}},	//   _bie_, _pomu, बसमू, _kanı,
   {{0x2a7fc5b8,0x6b9d402c,0xd5e2c0eb,0x2e3983bc}},	//   ktub_, _gasg, _kpọ, _bèf_,
   {{0xa3b685b9,0x660545ba,0x799e05bb,0x41e680d7}},	//   जाब_, bohk, _kapw, ліка,
   {{0x7bc085bc,0x9f820031,0x00000000,0x00000000}},	//   _womu, _kóó_, --, --,
   {{0xb5fb005f,0xa3a9408f,0x3f6a85bd,0x99658176}},	//   sság, _गोड_, _пиво_, ртіл,
   {{0x3ea6c5be,0x645e41a7,0x291840e2,0x249a0011}},	//   _prot_, mspi, _izra_, _mspm_,
   {{0xd130c1b4,0x9fb8805b,0x46a385bf,0xfd768446}},	//   يمة_, nčí_, _латв, _مداخ,
   {{0x27e945c0,0x6e2e45c1,0xc6934093,0x5d54c47f}},	//   zian_, _jibb, צאת_, шкот,
   {{0x249a006f,0x7d0580fa,0x6299c053,0x2d9e85c2}},	//   _nspm_, ühst, _eswo, _iate_,
   {{0x7c228127,0x61ea85c3,0x2a7fc010,0x27e945c4}},	//   nmor, lifl, btub_, xian_,
   {{0x6e2e4022,0x6b9d45c5,0x2d9cc5c6,0x3205c17c}},	//   _oibb, _rasg, _tave_, boly_,
   {{0x6aa945c7,0x26dbc0c3,0x6f0d01c6,0x799e0085}},	//   _šefo, _אקדמ, _vyac, _capw,
   {{0x37ab45c8,0xa157c093,0x3f9dc020,0x799e00b6}},	//   нтан_, _גבוה_, _yawu_, _dapw,
   {{0x2d9e85c9,0x6280c4f1,0x6b8445ca,0x261685cb}},	//   _late_, otmo, gfig, _पीसी_,
   {{0x6d55448e,0x6e2e45cc,0x291845cd,0xfc3f805b}},	// [2f0] _peza, _bibb, _azra_, _čím_,
   {{0x61e50339,0xdcfc4017,0xbddb4141,0x78a885ce}},	//   _umhl, _garī, _etèn, _ordv,
   {{0x442d85cf,0x69c185d0,0x6e2e45d1,0x7cd3c080}},	//   _pie_, _role, _dibb, tərə,
   {{0xa3df8036,0x7c228484,0x200682a4,0x603c006f}},	//   धों_, gmor, gooi_, _učma,
   {{0x49b805d2,0xe50bc09d,0x128785d3,0x6e2e45d4}},	//   _شاید_, _सुनि_, امتی_, _fibb,
   {{0xada58039,0x4ade45d5,0x444405d6,0x684585d7}},	//   ракл, _नेटव, _yt_, анка,
   {{0xdb06405f,0xabd5c4c3,0x22494327,0x6d570080}},	//   _inká, ициј, lpak_, _mexa,
   {{0x6e2e4011,0x9e95801c,0x442d814b,0xb5fdc013}},	//   _zibb, _پارچ, _uie_, pršk,
   {{0x27e6c0b6,0x6b898024,0x1a68801c,0x8db5c289}},	//   _dmon_, _ibeg, _مینی_, асні,
   {{0x69d880fa,0x27e6c5d8,0x7dd240b0,0x98a1450c}},	//   chve, _emon_, _læsn, lahı_,
   {{0x6ce4811b,0x6ff2003f,0x2a7fc09d,0x2902c06a}},	//   _ліце, lāci, stub_, şkan_,
   {{0x6299c09c,0x2d9e804f,0x320785d9,0xf1eb85da}},	//   _tswo, _zate_, lony_, _झगड़_,
   {{0x2bbf45db,0x442fc15d,0x63a04019,0x60188089}},	//   _एकजा, _iig_, _ómni, níma,
   {{0x7649c5dc,0xe04600c4,0xa06a05dd,0x200b4047}},	//   mpey, инги, кага_, _akci_,
   {{0xa3ccc5de,0x2d9e0166,0x442fc5df,0xa50a05e0}},	//   _रकम_, ľte_, _kig_, тева_,
   {{0x0b46430f,0x395a4033,0x69c3c5e1,0x442fc5e2}},	//   рнан, waps_, _hone, _jig_,
   {{0xe61a05e3,0x8af0003a,0xee3745e4,0xe7374156}},	// [300] _иди_, _edər, инт_, реу_,
   {{0x27e9c5e5,0x7c2f4061,0x365b0323,0x7bc400b2}},	//   čany_, _eicr, _שכינ, _hoiu,
   {{0x2d9e8093,0x224940f8,0x60160018,0xb5fb0089}},	//   _rate_, apak_, námo, tráv,
   {{0x442fc02e,0x7afd4033,0x03a645e6,0x7dcdc5e7}},	//   _nig_, _fxst, _тимо, _búsk,
   {{0x2d850016,0x200680bf,0x6aa9802c,0x61ea85e8}},	//   òleg_, rooi_, _cref, tifl,
   {{0x7c24403a,0x046685e9,0x7dcb054a,0xf8ba04fb}},	//   lmir, атим, _püsi, _उपाय,
   {{0xdb0f4396,0x9f91c1c0,0x69d885ea,0x6aa985eb}},	//   _ancè, _báà_, rhve, _eref,
   {{0x2d9e8498,0x44384011,0x6016003c,0x4c9b40c3}},	//   _wate_, _iur_, dámo, _בבלו,
   {{0x6aa985ec,0xab5b038a,0xab2785ed,0x601d05ee}},	//   _gref, kkür, _вота_, néme,
   {{0x14cac051,0x127b8052,0x32078036,0x7dd485ef}},	//   выми_, _באמע, cony_, _fàsa,
   {{0x395845f0,0xd5b7c5f1,0x6280c5f2,0x443845f3}},	//   _mers_, рсы_, stmo, _jur_,
   {{0xb4c20185,0xe6950051,0x7bc4005e,0x6fc605f4}},	//   ्नै_, бимы, _coiu, _sócr,
   {{0x7c2f45f5,0x6d570004,0x926b00c5,0x0a6b00c5}},	//   _ricr, _pexa, ърна_, ърни_,
   {{0x60160004,0xf20700d9,0x601d05f6,0xab5d817a}},	//   bámo, рямо, déme, _moża,
   {{0xb4d101b6,0xb5fb05f7,0x60160480,0xb8ebc02a}},	//   वने_, drát, cámo, _রে_,
   {{0x320785f8,0x27ff40b3,0x9f98c031,0x628285f9}},	//   zony_, čuno_, _béé_, ktoo,
   {{0x9df9447f,0x63a285fa,0x9f8ac031,0x660705fb}},	// [310] гнат_, ddon, _bùú_, pojk,
   {{0x6d58c5fc,0x443845fd,0x628285fe,0x224940b1}},	//   _jeva, _bur_, dtoo, rpak_,
   {{0x799505ff,0x3958406a,0x31740166,0x7dcdc032}},	//   mezw, _ders_, ňazí_, _dúsh,
   {{0x69c50600,0x63a28601,0x79950602,0x6608c06c}},	//   _hohe, gdon, lezw, hodk,
   {{0x6fd5c019,0x61458603,0x7c3b406f,0xd9458604}},	//   _náca, бела, _čuru, бели,
   {{0x0cb68079,0xaca30044,0x25a1009c,0x6fd84047}},	//   জনৈত, _ndịd, _jahl_, _více,
   {{0x62828605,0x3c9382cf,0x25f641ac,0x6016003c}},	//   atoo, تیاز, ्वरी_, xámo,
   {{0xe3b38301,0xd0f803bd,0x9f91c031,0x79950606}},	//   _برس_, ימות_, _báá_, hezw,
   {{0xadc44031,0x6aa98150,0xdee5c607,0x62828127}},	//   _atẹs, _uref, сопи, ctoo,
   {{0x6d5c0608,0x7c244017,0x6f1b8570,0x7e62c11a}},	//   xara, zmir, _izuc, _dvop,
   {{0x02d00185,0x03a60609,0x2246c396,0xc7a60375}},	//   हन्न, бино, _etok_, бинк,
   {{0x27e9007a,0xb5fb060a,0x629d460b,0xdb0f460c}},	//   _cman_, krás, _osso, _encé,
   {{0xdb244189,0xddc44077,0x60160004,0x1e830026}},	//   üsün, hriš, sámo, плям,
   {{0x7995060d,0x6608c1c8,0x6143060e,0xddcd460f}},	//   gezw, codk, зера, etaž,
   {{0x92b80079,0x69c50610,0xc8854080,0x63a28611}},	//   চনে_, _dohe, naşı_, ydon,
   {{0xa3cac045,0x2a604612,0x6fcec05e,0x6d58c00b}},	//   रॉप_, tsib_, _cùch, _zeva,
   {{0x62828057,0x6ff3c0b4,0x63a08613,0x6fcec061}},	// [320] xtoo, găci, _ramn, _dùch,
   {{0x2b594085,0x7dd00614,0x25a10085,0x69c5015a}},	//   _eesc_, _mäsk, _gahl_, _gohe,
   {{0x2a604615,0x61ee0616,0x319b0093,0xe007c617}},	//   ssib_, mibl, _גבינ, शवाद_,
   {{0x53e580d9,0xab5d8036,0xb21b00b0,0x9f4b013b}},	//   оціа, _poża, ntæn, vicë_,
   {{0x69cc8027,0x443840e2,0x69c501c6,0x39584138}},	//   _तकदी, _wur_, _yohe, _ters_,
   {{0xddc44618,0xd838806f,0x443203e2,0x2d8a4619}},	//   briš, _puč_, _liy_, _ubbe_,
   {{0xa3ca061a,0x4420061b,0x63a08486,0x395a061c}},	//   ोसा_, _ohi_, _tamn, _meps_,
   {{0x7995061d,0x6d43c078,0x4f65861e,0xe50bc374}},	//   zezw, _afna, _واقف, _सुधि_,
   {{0x69dac61f,0x63b38531,0x9603c036,0x395a00bf}},	//   thte, šení, रकूट_, _oeps_,
   {{0x7f44005c,0x6aa940b3,0x104ac4df,0xdd9ac42e}},	//   _afiq, _šefk, лями_, уши_,
   {{0x442004ff,0x69c5009d,0x44320620,0x7e628621}},	//   _bhi_, _rohe, _biy_, lsop,
   {{0x9f4d80da,0x69c50056,0x63a44622,0x0c26c623}},	//   _vjeç_, _sohe, jdin, _умен,
   {{0x7995043a,0xdb1d4624,0x2246c105,0x6892c05f}},	//   tezw, _posí, _utok_, _کیجئ,
   {{0x2fc6c625,0x867bc626,0x6d5e4627,0x83fd00e0}},	//   _hoog_, _תרגו, japa, vrđu,
   {{0x7bc640f7,0x27e90033,0x7a294007,0x44268628}},	//   _boku, _tman_, _užti, kmo_,
   {{0x25a100fa,0x443a0629,0x60188004,0xb5fb062a}},	//   _wahl_, _dup_, dímo, grár,
   {{0x3941401e,0x61ee062b,0x6b8d062c,0x82f84032}},	// [330] tchs_, bibl, _ibag, مركز_,
   {{0x2fc6c23b,0x61ee062d,0x200b062e,0xb5fb005f}},	//   _loog_, cibl, loci_, rrás,
   {{0xddcd4039,0x69c58051,0xb5fb0004,0x9327401c}},	//   ptaž, öhem, brár, _گردن,
   {{0x63a2c150,0x27edc62f,0x395a0630,0x6d5a8631}},	//   _naon, xien_, _zeps_, _aeta,
   {{0x69d8c19d,0xb5fd8066,0xceeb81aa,0x601ec0fd}},	//   _olve, _avša, دران_, këmb,
   {{0x395ec016,0xa3c34632,0xdcfc0017,0xddcd4036}},	//   jats_, ्सक_, cerē, ntaż,
   {{0x59a6c185,0xf1c98031,0x201f800c,0x6025c039}},	//   _कोइर, _aláì_, _thui_, одка,
   {{0x7f5f4633,0x6aad0634,0x44268149,0x20d38112}},	//   naqq, _oraf, cmo_, ṛi_,
   {{0x6d5a8635,0x85b98636,0x7bdbc637,0x63a2c4f8}},	//   _feta, _клас_, rhuu, _daon,
   {{0xb8014079,0x649ec5c7,0x3ea9404c,0xb465c638}},	//   ্ষিত_, kšić, ivat_, окол,
   {{0x649ec639,0x628440fc,0x7e64010d,0xcea904e0}},	//   jšić, ztio, _svip, _שי_,
   {{0xdb040032,0x29c9c019,0x24658017,0x6d41c63a}},	//   _iniú, _púas_, mēm_, scla,
   {{0x2b4d046a,0xdb0080fd,0x443a063b,0x15fb463c}},	//   ñeca_, _ramë, _sup_, ्वार_,
   {{0x224dc63d,0xdb0d0018,0xa3ab809d,0x6d5e4498}},	//   mpek_, _coañ, _कोस_, xapa,
   {{0x61ee063e,0xe73a463f,0x412a0640,0x63a44641}},	//   ribl, иев_, рово_, tdin,
   {{0x7f5b846a,0x2fc6c057,0x61ee0642,0x200b0643}},	//   _neuq, _xoog_, sibl, coci_,
   {{0x764d40ec,0x62844644,0xdb008303,0x19c64645}},	// [340] gpay, utio, _gamè, обам,
   {{0xe6930646,0x7dcb00fa,0x62844647,0xb21b40b0}},	//   _کلید, _düss, rtio, _spær,
   {{0x5faf008f,0x601d0648,0x6d5a8649,0x443a064a}},	//   _जोडल, léma, _reta, _uup_,
   {{0x7e62864b,0x8c358031,0xb33b401f,0x60188004}},	//   tsop, _as̟o, _taça, rímo,
   {{0x3ea94119,0x25a34283,0xdb00864c,0x2fc6c64d}},	//   cvat_, _fajl_, _kamé, _roog_,
   {{0x2bd2c08f,0xc29141aa,0x98a5c189,0x6e3b81c8}},	//   तस्थ, _سیمب, halı_, _duub,
   {{0x2fc6c64e,0x30a383d0,0x2d98064f,0x63a2c157}},	//   _poog_, дрыв, iere_, _paon,
   {{0x6aa940e0,0x6d5a8650,0xaa66c651,0xd90d81aa}},	//   _šefi, _weta, оток, دیم_,
   {{0xa37b010b,0xc5f8c03f,0xa3d784b4,0x6fd8410b}},	//   nhõe, tnē_, िसर_, _xíca,
   {{0x186a8652,0x23604022,0x7e644653,0x601d01cb}},	//   _важи_, haij_, isip, déma,
   {{0x200b0067,0x6aad0654,0x2fc6c23b,0x2cac81f4}},	//   toci_, _sraf, _toog_, _urdd_,
   {{0x62860655,0x6aad00b4,0x764d40f8,0x7e644656}},	//   ftko, _praf, ypay, ksip,
   {{0x37070657,0x3949c658,0x2ba3c185,0x68358007}},	//   ючов, _şase_, _खोटा, _išda,
   {{0x7c3ec659,0x1e33c0d7,0x2b5f4011,0x19580523}},	//   _épro, _жніў, _žuc_, жары_,
   {{0x320cc65a,0xa80281df,0x7c22c65b,0x10170032}},	//   mody_, şıya, _khor, _وبعد,
   {{0x649ec013,0xdb1d40d2,0xb30c0112,0xd70c00eb}},	//   ršić, _posà, ọjịs, ọrịr,
   {{0x69da8119,0xa2ad40ba,0x764d421b,0x6aad0150}},	// [350] _olte, ीमध्, upay, _uraf,
   {{0x2901023b,0x7dd48321,0x64480004,0x764d465c}},	//   _txha_, _bàsm, ídic, rpay,
   {{0x7c22c1a8,0x9f490303,0xdb1d4047,0x6e3b865d}},	//   _ohor, _amaé_, _dosá, _suub,
   {{0x443cc47a,0xa3e68384,0x3cfbc009,0x9f4dc2a4}},	//   _muv_, योल_, סלאנ, rieë_,
   {{0xd945865e,0x7c3c40b9,0xd3468231,0x6145865f}},	//   пели, _eurr, سیله_, пела,
   {{0x2ba7c00c,0x64a58660,0x61458661,0x3ead80fd}},	//   _ốc_, зака, чека, _vret_,
   {{0x6360c0eb,0x50644662,0x3f9900e2,0x6e3d4663}},	//   _ịnab, _отта, kesu_, _husb,
   {{0x6e354664,0x3ead8665,0x6d5c4666,0x9f404086}},	//   _hizb, _tret_, _zera, nnið_,
   {{0x2d980667,0x291e8232,0x2d81025d,0x7c3c4668}},	//   yere_, _ezta_, _oche_, _zurr,
   {{0x7f5d4669,0x63a4066a,0xa3c90021,0x6e3d466b}},	//   _lesq, _sain, लॉस_, _musb,
   {{0x6016066c,0xb33b4018,0x1d09c66d,0x2fc90321}},	//   lámi, _naço, сени_, _boag_,
   {{0xdb0bc03c,0x62860383,0xd8d640c3,0x601d001c}},	//   _engá, ttko, פורט_, téma,
   {{0x98abc3a6,0x7dcdc66e,0x320cc66f,0xbb3ac4e0}},	//   ılık_, _búst, body_, _העני,
   {{0x853cc007,0x22840107,0xbea2c670,0x98a78526}},	//   ndėl, rök_, _чашк, lanı_,
   {{0x6d454671,0x6d5c4672,0x98a5c530,0x291e0673}},	//   dcha, _rera, palı_, åta_,
   {{0x2d810094,0xe1ff0036,0xdb0f4674,0x27ed80f8}},	//   _eche_, wrót_, _encí, _nmen_,
   {{0x6e3d41c8,0xdb1d4066,0xee374675,0xb77b00c3}},	// [360] _cusb, _posá, зну_, _האפש,
   {{0xa7fd0676,0x7bdb817b,0x3cec854a,0x7c3c4677}},	//   nsın, _aluu, _अइले_, _purr,
   {{0xd91004fc,0xb4d64678,0x7bc28679,0x98a781df}},	//   _شیر_, िने_, tjou, kanı_,
   {{0x6d5c467a,0x9343867b,0x3eafc67c,0xe456c052}},	//   _wera, енце, _orgt_, פינט_,
   {{0x741381aa,0x64414231,0x27ff81d6,0x7c29c67d}},	//   روها, _élin, _djun_, dmer,
   {{0x7c29c166,0x7c3e067e,0x3f9900fc,0x2d8100c4}},	//   emer, _kupr, zesu_, _xche_,
   {{0x61ee467f,0x7c29c0cb,0x2000025d,0x3f990680}},	//   _imbl, fmer, _ojii_, yesu_,
   {{0x8fa38007,0x320cc036,0x07a38681,0x7c3e0682}},	//   _пасе, wody_, _пасн, _mupr,
   {{0xb4ac4027,0x26c04018,0xa3c6017e,0x7f448070}},	//   _कछु_, nxio_, _एवज_, ñiqu,
   {{0x6d5e0683,0x6e938684,0x63a64685,0x7ddd83e2}},	//   _nepa, _سلما, _lakn, _pèse,
   {{0x2b4d034d,0x38c8c16a,0x53990051,0x7ddd8303}},	//   ñeco_, زادی_, овня_, _fèsb,
   {{0x2441c686,0xafe3c687,0x883b80c3,0x443cc398}},	//   _dóm_, _похл, _התאו, _vuv_,
   {{0x61ee4688,0x395e8033,0x7f5d4689,0xdb00830d}},	//   _ombl, _kets_, _resq, _inmó,
   {{0xdb0bc032,0x7c24017b,0x78bcc4c9,0x80a1817e}},	//   _ungá, _ehir, ärvs, _कैडे,
   {{0x6e3d468a,0xd48fc00a,0x3f990134,0x8504c68b}},	//   _susb, _яр_, pesu_, _توغن,
   {{0x69dc468c,0xd117c052,0x6d5e00f8,0x69cac68d}},	//   _alre, _מקוה_, _eepa, _hofe,
   {{0xb5fb0019,0xdb0bc1ff,0x2d8cc68e,0x25ed868f}},	// [370] lsám, _fogõ, ofde_, _अगली_,
   {{0x799ac690,0x69cac018,0x7bc98691,0x764d0692}},	//   netw, _jofe, _soeu, _itay,
   {{0x98a782d6,0xdb160141,0x27e04693,0x7c3e0396}},	//   yanı_, _anyè, bhin_, _gupr,
   {{0xbddb4694,0x7c24013b,0x398f80b5,0xb33b4138}},	//   _suèd, _xhir, zısı_, _kaçm,
   {{0x7bdd4695,0x98a78696,0x25a58697,0xe5a58348}},	//   _ilsu, vanı_, _pall_, дили,
   {{0x76ba40c3,0x69cac02c,0xf9c78698,0x6d470036}},	//   _ומשפ, _nofe, ящен, ncja,
   {{0x27ed807a,0x6aa2c171,0x98178032,0x601d0070}},	//   _tmen_, _asof, _فبرا, jémo,
   {{0x99994047,0x7415c699,0x764d00bb,0x2441c69a}},	//   _kusů_, بوعا, _otay, _róm_,
   {{0xa28281aa,0x98a782d6,0x200dc69b,0xaa58801b}},	//   _لینو, ranı_, roei_, _ниту_,
   {{0x27e10283,0x6b82c29d,0xb33b40b5,0x799ac4e1}},	//   _ċina_, _ecog, _saçl, getw,
   {{0x7dd004d3,0x443e869c,0x7c29c0d9,0x7ae4423f}},	//   _mäst, _gut_, pmer, zzit,
   {{0x7e698007,0x200f869d,0x764d00bb,0x27fd802c}},	//   _kvep, nogi_, _btay, nnwn_,
   {{0x398f8165,0x63a9c69e,0x3ce9c0a0,0xe7d54526}},	//   pısı_, mden, _živě_, _sığı,
   {{0x7bcbc070,0x6b9bc69f,0x601d0018,0x69cac6a0}},	//   _hogu, leug, bémo, _gofe,
   {{0x601d003c,0x63a646a1,0x6289c6a2,0x6b8d46a3}},	//   cémo, _pakn, lteo, ffag,
   {{0x7afb46a4,0x660e06a5,0x237fc6a6,0x27e040b9}},	//   _žuta, sobk, nguj_, uhin_,
   {{0x63a646a7,0x656386a8,0xa3e445d5,0x7ae442c0}},	// [380] _vakn, kanh, भोग_, uzit,
   {{0x6fdcc669,0x6aa400f7,0xc58ec00c,0x00da4032}},	//   _méca, _isif, _lồng_, يبات_,
   {{0x27e0418a,0x69de0157,0x7dcf86a9,0x7ae445ca}},	//   phin_, _ilpe, _løss, szit,
   {{0x7bcbc6aa,0x3eb20066,0x799ac036,0x395e80c3}},	//   _nogu, _kryt_, zetw, _sets_,
   {{0xddc9c6ab,0x91e686ac,0x6b9bc6ad,0x656381ff}},	//   zreš, моде, deug, fanh,
   {{0x61ee46ae,0x656386af,0xdd1c8089,0x7c65001c}},	//   _umbl, ganh, _váži, _تایل,
   {{0xf77286b0,0x224d806a,0x6feb0036,0xe36686b1}},	//   _لاء_, _etek_, ręcz, _окви,
   {{0x3f8046b2,0x601d0018,0x442486b3,0x799c06b4}},	//   ngiu_, vémo, _uhm_, herw,
   {{0x5a34c0c5,0x656386b5,0x442b003c,0x444446b6}},	//   ннит, banh, vmc_, lq_,
   {{0xddc9c6b7,0x63a9c6b8,0x20024077,0x236d804f}},	//   treš, aden, _ljki_, _zdej_,
   {{0x444446b9,0xdb0a0066,0x799c06ba,0x6aa406bb}},	//   nq_, čným, derw, _asif,
   {{0x6fd5c2f4,0x291846bc,0x7e7646bd,0x69d886be}},	//   _nách, _myra_, kryp, lkve,
   {{0x3eadc077,0x799c06bf,0xf743c0d9,0x6b840061}},	//   cvet_, ferw, _речо, _dcig,
   {{0x799c018b,0x69d886c0,0x224000bf,0x3ea040f8}},	//   gerw, nkve, _duik_, dwit_,
   {{0x3b4c4112,0x4395059d,0x9e3400b4,0xe8df80d1}},	//   _ọdịk, _зайс, терч, _kiềm_,
   {{0x656e4061,0x29050283,0x14cbc6c1,0x3f8046c2}},	//   _adbh, ħla_, ाहरण, ggiu_,
   {{0x645c417a,0xc309002a,0x6b8d46c3,0x2d9c80fd}},	// [390] _awri, রেজি_, rfag, keve_,
   {{0x63a9c6c4,0x7e7d0134,0x497446c5,0x6b8d40d9}},	//   zden, musp, клус, sfag,
   {{0xaca300eb,0x200f86c6,0x7e6986c7,0x3ea04340}},	//   _mpịg, togi_, _svep, awit_,
   {{0x61fe40bf,0x764086c8,0x291844a0,0x4f94801b}},	//   anpl, _bumy, _dyra_, вршу,
   {{0x9f8a409d,0x645c46c9,0x99674376,0x7c2b831d}},	//   tööd_, _ewri, _отвл, rmgr,
   {{0x61f500b5,0x8afd80a0,0x6fdcc1cb,0x645c402c}},	//   nizl, _neře, _réca, _fwri,
   {{0xd5fb8112,0xfc460166,0x2918409c,0x23d346ca}},	//   _asụ, žíva_, _gyra_, _सवाद,
   {{0x656386cb,0x7e7bc043,0xdb0080a0,0x7bcd06cc}},	//   sanh, tuup, _zamí, _noau,
   {{0x4426c6cd,0x291840fd,0x2b4b4011,0x7c2d46ce}},	//   _dho_, _zyra_, _mfcc_, imar,
   {{0x7bcbc6cf,0x2d9c86d0,0x7c2d46d1,0x60e9c6d2}},	//   _wogu, ceve_, hmar, змом_,
   {{0x9f4b0060,0x44394051,0x4426c6d3,0x76408024}},	//   ficà_, _ois_, _fho_, _zumy,
   {{0x799c06d4,0xdb0bc6d5,0xddc28047,0x2a69409d}},	//   werw, _angå, dpoř, ksab_,
   {{0x7ccac080,0xe80346d6,0xe6a84047,0x201e003f}},	//   lərl, रचना_, _příš, ēti_,
   {{0x270e800c,0x64a60007,0x69c1009d,0x6448001f}},	//   ộng_, нага, ölep, ídio,
   {{0xfce606d7,0x809f4285,0xc0e606d8,0x644186d9}},	//   хово, _गैले, ховк, _juli,
   {{0x63a986da,0x3ea046db,0xb8868004,0xdfd24032}},	//   _naen, twit_, laíñ, دير_,
   {{0x27e00435,0xe9da46dc,0x644186dd,0x442dc6de}},	// [3a0] _ilin_, пка_, _luli, ime_,
   {{0x2fdf8010,0x3d11008f,0x2b4b46df,0x644182a4}},	//   _alug_, _दुवे_, _efcc_, _ouli,
   {{0x63a982cd,0xdb064396,0x409646e0,0xbddb4580}},	//   _baen, _maké, эрат, _suèc,
   {{0x443946e1,0x2a694022,0xfc3980b6,0xddcd40b4}},	//   _gis_, bsab_, _ciŭ_, traţ,
   {{0x7e69c065,0x764446e2,0x2fcd80f8,0x656186e3}},	//   jsep, qqiy, _doeg_, _belh,
   {{0x2d8e801e,0xe4a686e4,0x645c402c,0x603c0053}},	//   uffe_, ерио, _twri, _fčmt,
   {{0x27ffc10d,0xdcfc003f,0x443946e5,0xc9530093}},	//   fnun_, derī, _yis_, נמה_,
   {{0x2d9c86e6,0x802685d3,0x2d85805e,0xf390035d}},	//   seve_, _سرزم, _ecle_, _sảng_,
   {{0x644186e7,0x672400bc,0xf5ea80b4,0x200046e8}},	//   _euli, _nzij, _емал_, inii_,
   {{0x64418057,0x8e978087,0xf1bac00c,0x245e0047}},	//   _fuli, _אדמו_, _thơm_, kům_,
   {{0x91a6c112,0x4426c6e9,0x442dc6ea,0x2918c6eb}},	//   _atọ_, _tho_, bme_, æra_,
   {{0x04db8093,0x1ae6c6ec,0x9f4b01ff,0x245e00a0}},	//   _מקבל, _поем, ficá_, dům_,
   {{0x6e3a8283,0x9f4b06ed,0x6d4a8032,0x2be2017e}},	//   _kitb, ricà_, ocfa, _पतरा,
   {{0x7afb40e0,0x7c2d46ee,0x2d8506ef,0xa2c18048}},	//   _žuto, wmar, üle_, लमत्,
   {{0xe4e4011b,0x6e3a80cb,0xddc2804f,0xddcd46f0}},	//   гітн, _mitb, krož, jraš,
   {{0x7bdf0070,0x7c83c42e,0x6fdcc1cb,0x7e7d06f1}},	//   _ulqu, _суше, _méco, pusp,
   {{0x63a986f2,0xd838c053,0x9f9c4031,0x249846f3}},	// [3b0] _raen, _asčk_, _díà_, _aprm_,
   {{0x442906f4,0x7ccac03a,0x79850036,0x443b013b}},	//   _hha_, yərl, _uchw, _hiq_,
   {{0x6fdcc004,0xe1f181aa,0x25aa46f5,0xc5f3c009}},	//   _néco, یست_, _dabl_, נדע_,
   {{0xdfd54186,0x98acc189,0xa85604e0,0x7f4d00f6}},	//   _ромы, nadı_, _שירה_, _jfaq,
   {{0x443b06f6,0x60db40e2,0x656186f7,0x442dc6f8}},	//   _miq_, _ƙums, _pelh, vme_,
   {{0xf9940009,0xddcd46f9,0x2d8306fa,0xbddb40b6}},	//   ָרק_, braš, ngje_, _etèr,
   {{0xd2620017,0x63ad46fb,0xdb00c255,0xb4db86fc}},	//   _ziņā_, odan, ndmæ, डने_,
   {{0xe739c6fd,0x6e3a81a8,0x403486fe,0xae0f86ff}},	//   мей_, _eitb, _бесс, िवहन_,
   {{0x69d8405f,0x66e5c700,0x6fd84032,0x7c3a80c4}},	//   öveg, топа, _dích, _ètra,
   {{0x6fd5c56e,0x3f86c379,0x4e358701,0x00000000}},	//   _nácv, _ecou_, _شفاء, --,
   {{0x27e00702,0x64418703,0x9b95c032,0xb33b413b}},	//   _plin_, _uuli, _للات, _daçi,
   {{0x31678704,0x3940c0b4,0x2d830206,0x7e69c0b2}},	//   lanz_, _şist_, egje_, psep,
   {{0xdb064166,0x15e58705,0x7d1a80b9,0x2d91014d}},	//   _také, _कतार_, _zyts, ffze_,
   {{0x63abc086,0xd24ec6b0,0x245e0047,0x68edc6df}},	//   _hagn, _بنو_, tům_, _ƙadd,
   {{0x703a4039,0x442f81c8,0xdca5c0b4,0xc95280c3}},	//   дчас_, kmg_, _райи, שמל_,
   {{0xeb974119,0x2d83015d,0xd00f0032,0xddcd404f}},	//   кис_, agje_, _ولو_, vraš,
   {{0x3a3a0706,0x249840c9,0x8ca9c707,0x0d864708}},	// [3c0] _tipp_, _sprm_, टिको, клан,
   {{0x68054039,0x7c3b8709,0xdb060107,0xdb008089}},	//   rėda, _aiur, ndkí, _namá,
   {{0x63ad470a,0x7dd486ed,0x7bdbc051,0x7bcf470b}},	//   bdan, _màst, kkuu, _focu,
   {{0x7c3ec23f,0x27e08032,0x6443c70c,0x69dc070d}},	//   _èpre, óin_, _muni, lkre,
   {{0x6b82870e,0x25aa470f,0x7c298710,0x69dac0d9}},	//   rgog, _tabl_, _dher, ykte,
   {{0x55738711,0x7dd48580,0x7644017b,0xa6138039}},	//   агшт, _nàst, _muiy, аміч,
   {{0xbf000036,0x7c298061,0x7c3b805e,0x7ae9c0a8}},	//   ैथुन_, _fher, _fiur, ezet,
   {{0x2d9ec712,0x6e3a8713,0x77640714,0x7982409c}},	//   wete_, _witb, _neix, ɗowa,
   {{0x2bab8715,0x6e3c4716,0xc2438717,0x63abc718}},	//   _घोटा, _kirb, _внук, _dagn,
   {{0x27e68719,0xf1bac0d1,0x7dd48580,0x443b013b}},	//   lhon_, _khơi_, _càst, _siq_,
   {{0x63ad471a,0x25be871b,0xb97b4093,0xddc28064}},	//   ydan, _intl_, וניי, zpoś,
   {{0x27e6871c,0xa785c71d,0x4429071e,0x6fd5c070}},	//   nhon_, _مشهو, _qha_, _bácu,
   {{0x051f0079,0xf8bf4285,0x7dd48016,0x98acc189}},	//   _দলের_, _एप्प, _fàst, radı_,
   {{0x69dc071f,0x6ab600b1,0x67fec017,0x2712c171}},	//   gkre, _dryf, dīji, _e̟nì_,
   {{0x6280c720,0x63ad40d9,0x2d830721,0x7bcf4722}},	//   lumo, tdan, rgje_, _pocu,
   {{0x442f0723,0x5fc5c048,0x6d4e4724,0xddc44011}},	//   _òg_, वायल, _afba, griž,
   {{0x6fdcc01e,0x63ad002f,0x76440725,0x7c3b8016}},	// [3d0] _récl, _iaan, _guiy, _riur,
   {{0x2d874726,0x7c3b8727,0x3ea90728,0x6568c729}},	//   üne_, _siur, _isat_, nadh,
   {{0x7ae9c72a,0x7c29872b,0x601ec0fd,0x6443c004}},	//   zzet, _pher, rëmj, _xuni,
   {{0x7ddd8565,0x1a6540fb,0x0135c052,0x776400d2}},	//   _pèso, _میری_, אָנט_, _xeix,
   {{0x3b098561,0x6568c72c,0x9a878244,0x81ac802a}},	//   çaq_, kadh, туел, গান_,
   {{0x6e3c472d,0x27e68340,0x3ea6401f,0x2fcfc157}},	//   _girb, ahon_, çote_, _sogg_,
   {{0xc984872e,0x7c3b872f,0x6563c730,0x31678252}},	//   ручи, _tiur, _renh, ranz_,
   {{0xa3ab8036,0x3d3c03bd,0x2496801c,0x3ea90051}},	//   _कोच_, וגוס, انيد_, _osat_,
   {{0x6563c731,0x7e6081f4,0x67d48119,0xdb008107}},	//   _penh, _gwmp, _тоту, _tamá,
   {{0x2d838065,0x23694022,0xdce38732,0x6443c733}},	//   _øje_, haaj_, lanč, _puni,
   {{0x77640734,0x69c4408f,0x228bc11b,0x3ea90735}},	//   _peix, राती, søk_, _asat_,
   {{0x9ac4c283,0x23694736,0x7bcb8123,0x442b4230}},	//   _biċċ, jaaj_, njgu, _nhc_,
   {{0xe8df80d1,0x69dc0737,0x6443c738,0x7e6d4011}},	//   _diễm_, tkre, _wuni, jsap,
   {{0x661500fc,0xc332c0c3,0x27e68739,0x6ab60177}},	//   gozk, _הוד_, zhon_, _vryf,
   {{0x3ea9073a,0xd1b8c05f,0x6fd5c019,0x6443c73b}},	//   _esat_, _جانا_, _fáct, _uuni,
   {{0xbea6473c,0x8c4341df,0x64450449,0x6ab6073d}},	//   лабк, ışla, _duhi, _tryf,
   {{0xdb064141,0x6b84473e,0xdce38007,0x2fc0073f}},	// [3e0] _ankò, rgig, danč, _inig_,
   {{0xef174740,0x2904003a,0x7a22402d,0x63ad0741}},	//   уму_, şmaq_, rôto, _zaan,
   {{0x69c28742,0xdceac590,0xcb6a4589,0x7406002a}},	//   लासी, ćiće, _пане_, রতীয়_,
   {{0x3ebf4451,0x6e3c40cb,0xb3c745bf,0xdce38026}},	//   _šute_, _wirb, _блюз_, ganč,
   {{0x7769c070,0x388e8080,0xa3c90743,0xdce18085}},	//   daex, _tərk_, लॉट_, _felċ,
   {{0x601d0744,0x27e68745,0xb866461e,0x7d1e0051}},	//   rémi, shon_, _مارو, _kyps,
   {{0xa3b94048,0x601d0746,0x7c3d4230,0x6aa980c2}},	//   चाच_, sémi, _yisr, _esef,
   {{0xb274c747,0xc274c748,0x3a74c19b,0x75f4003a}},	//   алиш, алиј, алир, _düzə,
   {{0x73068749,0x443dc3e2,0x3706874a,0x63a2874b}},	//   _спаз, _diw_, _спаг, meon,
   {{0x27134015,0x3f86874c,0x44324396,0x3914c74d}},	//   ệng_, lgou_, hmy_, импр,
   {{0xb97b4009,0x7646474e,0x6d5c074f,0x9f494086}},	//   ענטי, _luky, dbra, knað_,
   {{0x9a86c60e,0x6280c019,0x44324750,0x75288017}},	//   _букл, pumo, jmy_, _izdz,
   {{0x3f86809c,0xdb19c062,0x244a835d,0x7e7bc0d2}},	//   igou_, _dowó, _hùm_, crup,
   {{0xcee9c05f,0x6d5c0751,0x63a28145,0xa8a6c752}},	//   _جرمن_, gbra, heon, _брик,
   {{0x656500b3,0xdb1d4753,0x0b52425d,0x63a28754}},	//   _vehh, _insé, _ọkọl, keon,
   {{0x6d5c0755,0xdb0bc756,0x3b55401d,0xa3e90047}},	//   abra, _bagè, ркар, _यति_,
   {{0x5fc5c08f,0xa2c600b2,0xb33b010b,0x8c434165}},	// [3f0] वातल, ामण्, beça, ışma,
   {{0xdcfc0017,0x44324757,0xe1ff4303,0xdb19c141}},	//   sgrā, amy_, _lvóv_, _kowò,
   {{0x9f5900fd,0xa3e90758,0x43954039,0x67fec017}},	//   jisë_, _यता_, _канс, līju,
   {{0x78518017,0xa3bb0759,0x836781e3,0x7e7d075a}},	//   _jāve, घाट_, ادال, orsp,
   {{0x98b102d6,0x6d4180f8,0xdefb4097,0x272b41c0}},	//   mazı_, _pgla, _чын_, _dòní_,
   {{0x7987005c,0x2be2075b,0x867a40c3,0x9f59013b}},	//   ngjw, _पत्थ, _ברשו, fisë_,
   {{0x228f475c,0x7ccac03a,0x61fac080,0x8235c08c}},	//   lük_, bəri, ditl, یرخا,
   {{0x2a6dc54a,0x7df44036,0x244a800c,0x7bdf475d}},	//   tseb_, yńsk, _dùm_, nkqu,
   {{0x6447412c,0x6d5c075e,0x6aa980c3,0x64414157}},	//   _huji, ybra, _usef, _èlib,
   {{0x61fac0f8,0x846781bc,0xe8df8015,0x63af4038}},	//   gitl, _бъде, _niệm_, _lacn,
   {{0x9f5900da,0x6567475f,0x1d09c760,0x7843805f}},	//   cisë_, _mejh, тени_, _bőve,
   {{0x5b15c0c5,0xdb1d4070,0xdce18451,0xca2900c3}},	//   _кмет, _ensé, _jelč, _חם_,
   {{0xaa460761,0xfc49c00c,0x442d8150,0xa2c600ba}},	//   регл, _bậc_, _mhe_, ामध्,
   {{0x7c2d0762,0x3f8b4763,0x65674047,0x7ccac080}},	//   _ehar, _accu_, _nejh, zəri,
   {{0x443f8018,0x67e3454a,0xa9670764,0xb0a44036}},	//   _oiu_, _sõja, риса_, _गैंग,
   {{0x44204765,0x76464766,0x78ba4166,0x38a701f4}},	//   uli_, _puky, _štvo, _dŵr_,

   {{0x6fdcc669,0x64554767,0xfaa60768,0x67fec03f}},	// [400] _déch, _atzi, _тапо, cīju,
   {{0xc8c9c185,0x7ddd8769,0x48b640c5,0x6835c007}},	//   िमपट, _dèsk, ищет, _išdu,
   {{0x27e9476a,0x7b66876b,0x61fc076c,0x442d876d}},	//   bhan_, атле, mirl, _bhe_,
   {{0x69c1876e,0x443f8315,0x3218076f,0x03964770}},	//   _anle, _ciu_, lory_, _троя,
   {{0x61fc01b4,0x2fcdc2a3,0xe9f9002e,0x6d43c1c8}},	//   oirl, djeg_, _asẹ_, _ogna,
   {{0x442d8771,0x61fc0772,0xdd90838b,0x9f59013b}},	//   _ehe_, nirl, سوب_, tisë_,
   {{0x6c36861e,0x07e6c773,0x442d829a,0x63a28774}},	//   _نفسا, ицим, _fhe_, peon,
   {{0xdb008038,0x7e62c3bc,0x69c18775,0x61fc0776}},	//   _pamä, _pwop, _enle, hirl,
   {{0x3a2c8033,0x66e38777,0x67298085,0x61fac778}},	//   _thdp_, _дота, _gzej, titl,
   {{0x64408779,0x2d8ac06a,0xf8b880d1,0x61fc0573}},	//   _himi, übe_, _trĩ_, jirl,
   {{0x2702477a,0xa5b74009,0x63a4477b,0x7e6d80b3}},	//   लपुर_, בליק_, kein, šapt,
   {{0x7aed4096,0x7e62c141,0xe4f940e4,0xf8b340c3}},	//   yzat, _twop, ्पति_, קשר_,
   {{0x9f59077c,0x656881aa,0x63a4477d,0x59c94045}},	//   nisé_, _kedh, dein, रामर,
   {{0x67fec03f,0x3218077e,0x7e64042c,0x6fdcc01e}},	//   rīju, gory_, _dwip, _séch,
   {{0x7c22877f,0x65688780,0x67fec03f,0x27e04020}},	//   klor, _medh, sīju, fkin_,
   {{0x3edf0112,0xe3b044cc,0x6008038a,0x66188066}},	//   _apụọ_, ورق_, nıml, hovk,
   {{0x2d8c8781,0x809f4064,0xe69501b4,0xdcf5403a}},	// [410] _ocde_, _गैजे, _الخد, _razı,
   {{0x64474782,0x3eb9406c,0x27e04051,0x443f8783}},	//   _puji, _vrst_, akin_, _siu_,
   {{0xb4e1408f,0xfa3401b4,0x6808c047,0x6008006a}},	//   धने_, _بريد, vědn, kıml,
   {{0x64408784,0x27e04785,0x7c228786,0x656880bb}},	//   _cimi, ckin_, glor, _aedh,
   {{0x224900c9,0x7cfc4240,0x6447409c,0x75e40112}},	//   _juak_, _pårø, _wuji, _ọziz,
   {{0x78ba8458,0x6aad0150,0x764d403a,0xbb3a40c3}},	//   _brtv, _msaf, mqay, _תעשי,
   {{0x3ea94787,0x645540fc,0x64488788,0x27e6c789}},	//   lwat_, _utzi, _cudi, _blon_,
   {{0x27e6c070,0x1a68878a,0x6f04c47e,0x9178800c}},	//   _clon_, _چینی_, _žica, _với_,
   {{0xd7f8878b,0x64488303,0x6d45078c,0xdb04401f}},	//   _тур_, _eudi, _ogha, rdiç,
   {{0x63a4478d,0x6448878e,0x7bc2c093,0x27fd81f4}},	//   zein, _fudi, _enou, liwn_,
   {{0x6aad078f,0x64418790,0x64488791,0xa8794009}},	//   _asaf, _élis, _gudi, װאָר,
   {{0x3ead8011,0x20190792,0xef1f0165,0x63a44018}},	//   _kset_, gosi_, rgün_, xein,
   {{0x6b9b8793,0xe730c5a7,0xfaff42a4,0xdb1d4107}},	//   _mbug, _قصه_, _seën_, _mosó,
   {{0x2bc5c794,0x2be04185,0xed56c652,0x6d5cc1df}},	//   वावा, नस्थ, _лош_, ırac,
   {{0x8afdc047,0x3ea94010,0x04b5009b,0xb33b001f}},	//   daři, ewat_, остя, beço,
   {{0x2b408795,0x30da8052,0x20190796,0x680b0036}},	//   žici_, אַמע, cosi_, lędn,
   {{0xf4130093,0x64408797,0x61fc0798,0x32180799}},	// [420] _מפה_, _rimi, pirl, pory_,
   {{0x00ca079a,0xdce3c79b,0xc9aa079c,0x75eb0138}},	//   _блок_, _lenč, _свое_, _rüzg,
   {{0x656e00f7,0xb865479d,0x6abb802e,0xdb1d4019}},	//   mabh, قانو, _aruf, _bosó,
   {{0x9f5901cb,0x263d802d,0x6808c0a0,0x69d540b9}},	//   tisé_, _dňom_, vědo, _eoze,
   {{0xeafa879e,0x66188066,0x2b448033,0x2006801e}},	//   درات_, tovk, _vgmc_, rnoi_,
   {{0x656e068a,0x2d8a079f,0x41c947a0,0x244e0166}},	//   nabh, ngbe_, राणस, _kým_,
   {{0xa3cc4185,0x6618805b,0x764180de,0xd46781bd}},	//   लाप_, rovk, _dily, бије_,
   {{0x6b89c1b0,0x3254c47f,0x61fe47a1,0x69d547a2}},	//   ggeg, овир, lipl, _zoze,
   {{0x765bc105,0x201907a3,0xdb00c7a4,0xaac847a5}},	//   gpuy, vosi_, ndmø, रमिक,
   {{0xd910c4e8,0x9f44c34d,0x31c6c051,0x645c07a6}},	//   ویش_, timó_, ссив, kpri,
   {{0xfbc4008f,0xddc9c7a7,0x3ea007a8,0x2360415d}},	//   षांम, brež, _apit_, kbij_,
   {{0x7c294283,0x1ac84185,0x321a4089,0x75eb0138}},	//   ċerk, रमाथ, hopy_, _müze,
   {{0xa3cc47a9,0xead4c7aa,0x644840c4,0x321a47ab}},	//   लान_, _фоль, _èdif, kopy_,
   {{0xfc498089,0x645c0206,0x776d4149,0x656e07ac}},	//   slíš_, fpri, waax, gabh,
   {{0x439507ad,0xba3d8047,0x3756425d,0x3ea00053}},	//   _дайс, _průz, _ọdụ_, _epit_,
   {{0x6aad0360,0xd31a0044,0x224907a8,0x00000000}},	//   _tsaf, ọtụr, _tuak_, --,
   {{0x4424c54a,0x3a754119,0x3f8947ae,0x290bc0cc}},	// [430] ilm_, юлар, rgau_, şcat_,
   {{0x645c07af,0x6d45012c,0x6b9b8157,0x2717c0d1}},	//   bpri, _ugha, _sbug, ểng_,
   {{0x637f405e,0xdcf70080,0x7afb402d,0x645c07b0}},	//   _cànà, _taxı, _ľutu, cpri,
   {{0x60da009d,0xd5bf0017,0x680b0036,0x764987b1}},	//   ätme, žādi_, zędn, _puey,
   {{0xf41f4025,0x765d07b2,0xdce500e5,0xdce3c7b3}},	//   _ikä_, npsy, _mehč, _renč,
   {{0xc98784df,0xdce3c7b4,0x63a60017,0x95cb4477}},	//   суди, _senč, zekn, _сума_,
   {{0x6b89c7b5,0x224b41ff,0x3623805f,0x6280c049}},	//   tgeg, _huck_, _ہورہ, ermo,
   {{0xb0688032,0x59c78185,0x628607b6,0x8699c01d}},	//   حصول_, लाहर, yuko, атот_,
   {{0x7851803f,0x62494570,0x69c500bf,0xdb0bc7b7}},	//   _dāva, _džog, _onhe, _angò,
   {{0x644ac7b8,0x7a2d87b9,0xb33b07ba,0x7a2007bb}},	//   _bufi, sútb, reçl, nött,
   {{0x6280c321,0x672d0449,0xa069c6b1,0x8fa60156}},	//   armo, _azaj, јама_, оане,
   {{0xeaba07bc,0x644ac00d,0xe73a047f,0x61fe41a8}},	//   айм_, _dufi, иен_, zipl,
   {{0x81ac8079,0xf770c7bd,0xe56ec7be,0x6286002f}},	//   গার_, _سان_, _оз_, uuko,
   {{0x69d70018,0xed59c7bf,0x2cb80011,0x1a9ac052}},	//   _coxe, _ток_, tvrd_, _כינע,
   {{0x154307c0,0x7a3047c1,0xd618c05f,0x186a07c2}},	//   дерм, näte, _اتنا_, раби_,
   {{0x54360646,0xa6ca07c3,0x2475c03f,0xdb0d4032}},	//   _برتر, _نوبل_, mām_, adaí,
   {{0xf34ec0eb,0x2fc0c032,0xa3cc47c4,0x2475c017}},	// [440] _kụrụ_, _óige_, लाब_, lām_,
   {{0x201f87c5,0xf34ec044,0xa2b1c7c6,0xa2ccc7c7}},	//   _akui_, _jụrụ_, _अनन्, _तपस्,
   {{0xeb9a4119,0xf8c9c0aa,0x645a0047,0x397ac052}},	//   _кин_, िमिय, ítid, שטענ,
   {{0x27edc04f,0xa2be0045,0x032687c8,0xa3de4314}},	//   jhen_, शिप्, оден, _तकि_,
   {{0x7791405f,0xa92382f4,0x386d0013,0x8b04c09c}},	//   _سیلا, ížno, ćere_, ƙƙin,
   {{0xf34ec044,0x661c056e,0x6f04c0ab,0x3667459d}},	//   _nụrụ_, nork, _žico, _фаро_,
   {{0xafe68119,0xe7eac0b4,0x7ccac080,0x776bc75d}},	//   _довл, ифик_, hərr, _begx,
   {{0x6d4740fd,0x6458c0b3,0x6fdcc7c9,0x3ea2405c}},	//   _zgja, _rtvi, _néct, _kpkt_,
   {{0x661ac44e,0x3eafc0d1,0x386987ca,0x624b0085}},	//   totk, _csgt_, ćara_, _iżog,
   {{0x6fdcc669,0x764bc0f8,0x7643c6df,0x2be14036}},	//   _récu, _dugy, _ciny, _नवभा,
   {{0x2475c03f,0xdce70017,0xf3ff010b,0x3d1a0048}},	//   gām_, kajā, tiã_, _मुले_,
   {{0x2b408199,0x7a200107,0x6d480199,0x321c87cb}},	//   žicu_, zött, ždal, lovy_,
   {{0x2fc6c02f,0x764bc17b,0x67240024,0x7643c7cc}},	//   _inog_, _gugy, _cyij, _finy,
   {{0x7643c7cd,0x321c8066,0xe1ff4031,0x61ee00f8}},	//   _giny, novy_, _awón_, ghbl,
   {{0x765d0655,0x20078107,0xf3ff01ff,0xf1a9c7ce}},	//   spsy, énik_, piã_, _دانه_,
   {{0x7df9c047,0x7643c7cf,0x3d1a0048,0x2d8cc7d0}},	//   yňsk, _ziny, _मुळे_, lgde_,
   {{0x69d70018,0x321c8066,0x443907d1,0x7a200107}},	// [450] _toxe, kovy_, mms_, tött,
   {{0x2d8cc7d2,0x27edc0e2,0x68120017,0x44390663}},	//   ngde_, zhen_, rāde, lms_,
   {{0x2d8cc7d3,0x6d550036,0x27edc13b,0x7a2480d2}},	//   igde_, mcza, yhen_, còti,
   {{0x9f978016,0x27e98107,0x99984007,0x6aa2c713}},	//   _açò_, óan_, _virš_, _opof,
   {{0xb2ab87d4,0xed5987d5,0xc21ac17e,0xed15405f}},	//   ртеж_, бол_, नकाब_, _کہاں_,
   {{0x64584004,0x8cabc045,0xa37b40b2,0xe1f887d6}},	//   ívic, _जनलो, _slõh, огі_,
   {{0x7643c7d7,0xdb0a0066,0xf34ec25d,0x69cd4048}},	//   _riny, čném, _rụrụ_, साठी,
   {{0xf771c51b,0x2475c03f,0xab5d817a,0xdc39c50c}},	//   راب_, vām_, _inżo, tçın,
   {{0xdb0f430d,0xc7b284e0,0xeab087d8,0x35f587d9}},	//   _incó, _אבן_, _لعل_, _епар,
   {{0x443207da,0x28bd87db,0x271a400c,0x4c85c7dc}},	//   _shy_, ्मदि, ỏng_, плов,
   {{0xc6178742,0x69c747dd,0x31bd402a,0xeaf60314}},	//   दकीय_, _mnje, _আকাশ, ीप्त_,
   {{0x224d805c,0xeb9a07de,0x2d8cc4e1,0xade9c01c}},	//   _kuek_, щим_, agde_, _گفتم_,
   {{0xddcd47df,0x75edc166,0x7ddd87e0,0x7f1a023d}},	//   draž, _púzd, _fèst, сіну_,
   {{0xed5707e1,0x2ca98036,0x443907e2,0x645e4051}},	//   зор_, ładu_, ams_, yppi,
   {{0x412a07e3,0x75e0405f,0x200c410b,0x443207e4}},	//   сово_, _közv, édio_, _thy_,
   {{0x60dcc7e5,0x63a9c7e6,0xdcfa803a,0x6b9bc0bb}},	//   ärme, neen, _xatı, nfug,
   {{0x200207e7,0xca864119,0x63b647e8,0x6813c379}},	// [460] miki_, ягай, rdyn, căde,
   {{0x629647e9,0x3f9f81c8,0x661c01c8,0xe9d747ea}},	//   rtyo, _abuu_, qork, пку_,
   {{0x442687eb,0xdb060107,0x02a8c7ec,0x7a2b40cb}},	//   tlo_, deké, _कन्न, mütl,
   {{0x624947ed,0xd46941b4,0x3ebf87ee,0x3ce504f5}},	//   _džob, تحكم_, _brut_, ølve_,
   {{0xf1c7808f,0x44224211,0x6d4880f8,0xdee38417}},	//   लांन, _ikk_, _pgda, ноци,
   {{0x69c747ef,0x9f590066,0x44224011,0x200207f0}},	//   _gnje, visí_, _hkk_, hiki_,
   {{0x18a347f1,0x8afdc047,0x7bd9c7f2,0xdb00c571}},	//   _парм, kařs, _bowu, remí,
   {{0x64464067,0x6d550064,0x26c007f3,0xdcfa8080}},	//   _jiki, zcza, _orio_, _qatı,
   {{0x6d550064,0x3ebf87f4,0x776d0018,0x6d488077}},	//   ycza, _grut_, _reax, _tgda,
   {{0x2d8cc7f5,0x236d823b,0xddcd4158,0x644dc654}},	//   ugde_, _zeej_, zraž, _čair,
   {{0x2d8cc101,0x776d003c,0xf1afc032,0x98b80165}},	//   rgde_, _peax, اءً_, karı_,
   {{0x76450033,0xb904c7f6,0x656e47f7,0x27e687f8}},	//   _sihy, _नथ_, _lebh, nkon_,
   {{0x69da87f9,0x63b601c8,0xdce7406f,0xdfcfc032}},	//   _kote, _dayn, _rejč, _حين_,
   {{0x19580026,0x645c47fa,0x656e400b,0x69d8c7fb}},	//   зары_, _otri, _nebh, _uove,
   {{0x69da87fc,0xa99bc0c3,0x245180d1,0xdce74013}},	//   _mote, _הבור, _xám_, _pejč,
   {{0x26c007fd,0xdb0bc34d,0x1bd447fe,0x63b607ff}},	//   _frio_, _hagá, нося, _gayn,
   {{0x644e47b0,0x247780cc,0x5215024e,0xf1a74800}},	// [470] _aubi, zăm_, _одит, зрен,
   {{0xceb404e0,0x98b0c185,0x996701f0,0x394a405e}},	//   _טיפ_, _जनाए, _этил, _cgbs_,
   {{0x236d8046,0x63a9c801,0x26c0c007,0x67d58802}},	//   _peej_, yeen, _šiol_, можу,
   {{0x2a604022,0x27e68803,0x7c22c1c6,0x24518804}},	//   bpib_, gkon_, _nkor, _rám_,
   {{0x63a9c805,0xf3ff401f,0xdfce801c,0x2bb6c25c}},	//   veen, _imã_, شيو_, _अफजा,
   {{0x6abbc806,0x64464807,0x27e68286,0x3ebf8119}},	//   vvuf, _ziki, akon_, _vrut_,
   {{0x236d823b,0xdb0f4019,0x6d47c0ab,0x9e344808}},	//   _teej_, _mací, žjak, _черч,
   {{0x764f4809,0x247780b4,0x2d8c406a,0x6b9d00a8}},	//   _kucy, răm_, _öder_, jfsg,
   {{0x765b800d,0x52df4079,0x6b9bc1a7,0x7e69812c}},	//   _utuy, _নেতৃ, rfug, _uwep,
   {{0x24518015,0x68e1454a,0x63a9c80a,0x2fc9080b}},	//   _tám_, _ülds, seen, _anag_,
   {{0x644e480c,0xb21b080d,0x3eadc078,0x63a9c80e}},	//   _xubi, træn, swet_, peen,
   {{0x2734480f,0xddc2c810,0x63b6003a,0x2fc90811}},	//   _júní_, _gvož, _qayn, _cnag_,
   {{0xddcd0812,0x64464813,0xa3cc4814,0x8af04435}},	//   _svaš, _riki, लास_, hbər,
   {{0xc332c093,0x9f4b0815,0x44224166,0xf1d0c00c}},	//   _סוג_, ficó_, _skk_, _vạch_,
   {{0x81bcc03f,0x69b2c08f,0x44294816,0x7c29c817}},	//   klēj, _असती, fla_, oler,
   {{0x66038818,0x656e40f7,0x63ab8043,0xbf9b01ff}},	//   hink, _sebh, jegn, liên,
   {{0xe2974819,0x78a9481a,0xf1c9408f,0xcf92c81b}},	// [480] мат_, _ćeva, रांन, כטן_,
   {{0x7c29c81c,0xa3cc481d,0x5ef38260,0xee37481e}},	//   hler, लाह_, ्छन्_, дну_,
   {{0x2fc90056,0xe4f48185,0x27e6881f,0x16c68444}},	//   _ynag_, ेपछि_, tkon_, लम्ब,
   {{0xfbdf40d1,0x9f4b00c4,0x62860820,0x44224821}},	//   _hiên_, licò_, orko, _ukk_,
   {{0x44204822,0xfbdf400c,0xdb1d4065,0xbb4380d7}},	//   moi_, _kiên_, _ansæ, вецк,
   {{0xa06a4823,0x27ed8824,0x7853c0b4,0x27ff8545}},	//   _мага_, _elen_, _năvo, _emun_,
   {{0xdcfc406a,0x69da8825,0xfbdf40d1,0x212c4359}},	//   _tarı, _vote, _miên_, _ádh_,
   {{0xdb00c6ed,0x7c3bc826,0xb8d68705,0x21e9c070}},	//   temà, gmur, _छन_, _búho_,
   {{0x5186c827,0x12bec02a,0x7ae44828,0x2327c6b1}},	//   муна, েন্দ, nyit, моћи_,
   {{0x752fc064,0x7e628829,0x200dc0b4,0x6603882a}},	//   ęczn, mpop, anei_, cink,
   {{0x4420482b,0xca48c015,0x2c55803f,0x6d5a882c}},	//   koi_, _mời_, _tāda_, _ifta,
   {{0x442040fd,0x4429482d,0x7c36002c,0xd011020c}},	//   joi_, xla_, _chyr, الح_,
   {{0x2247c82e,0xfbdf4015,0xdb0bc82f,0x69dc4830}},	//   _fink_, _biên_, _tagá, _oore,
   {{0x395a0060,0xddcd46f0,0x7c20c831,0xd84f8112}},	//   _cfps_, ksaš, lomr, pọtu_,
   {{0xdce70036,0x26c280a0,0xb4ad40b2,0xfbdf435d}},	//   kają, _škol_, _कने_, _diên_,
   {{0x26c24043,0xb21b010d,0x61ee4832,0x1bb84032}},	//   _brko_, mræm, _albl, واقع_,
   {{0x6d5a8833,0x2bd14834,0x7e628835,0xdb064166}},	// [490] _ofta, हाबा, jpop, _zakú,
   {{0x7e6d0150,0x22474836,0x68edc047,0x442b02cd}},	//   _iwap, önk_, _řadi, llc_,
   {{0x7c29c3a6,0x62494837,0x3d100048,0x7c20c838}},	//   yler, _džoa, णपणे_, komr,
   {{0x44204839,0x3f15883a,0x7c24005c,0xdceac077}},	//   coi_, ндес, _xkir, _nefč,
   {{0xf770883b,0xed59883c,0xa3cc425c,0x7af64064}},	//   شان_, пол_, लार_, czyt,
   {{0x9f98c10d,0x28bd8617,0xdcf8c053,0x1c00883d}},	//   _séð_, ्मलि, _advč, लोबल_,
   {{0xdd944097,0x7c20c033,0xb7d581c0,0x6603883e}},	//   _шары, fomr, _aṣeh, rink,
   {{0x69cac83f,0x69dc4840,0xdb064166,0x7bdd4841}},	//   _anfe, _zore, _rakú, _josu,
   {{0x7bdd471c,0xc245c842,0x76488843,0xd709c844}},	//   _mosu, нник, _fidy, яние_,
   {{0xf1d24281,0x3c320166,0x44204845,0xb465c846}},	//   सायन, dáva_, zoi_, нкол,
   {{0x6729807a,0x20000033,0x6ab80285,0x7c2400f8}},	//   _hyej, _pmii_, इट्र, _pkir,
   {{0x2004c847,0x63ad4379,0x7e6d0848,0x7bdd4849}},	//   cimi_, jean, _bwap, _nosu,
   {{0x4420484a,0x65750033,0xdb06402e,0x6286084b}},	//   voi_, fazh, _fakù, urko,
   {{0xba39c009,0x63b9c283,0xe8020374,0xdce70036}},	//   _צײַט, _hawn, _लगवा_, zają,
   {{0xe1ff4064,0xa3e3c08f,0x3d1a049d,0x64a3084c}},	//   _twój_, _नका_, _मुखे_, лара,
   {{0x25b8401e,0x67248283,0xdcfe0080,0x3d02809d}},	//   _sarl_, żiji, _qapı, _वइसे_,
   {{0xf1d0c082,0x63bbc600,0xc4bd8045,0x2ecb084d}},	// [4a0] _mạnh_, idun, ्मुख, ामृत,
   {{0x660540c9,0x6e21c1f4,0x3116484e,0x7ae4484f}},	//   gihk, nolb, нфес, ryit,
   {{0x7bcbc0f7,0xdce70036,0x672983e0,0x2004c850}},	//   _ongu, tają, _ayej, yimi_,
   {{0xd36f8032,0x2cb8c0b0,0x672980bb,0x68e10851}},	//   مهم_, ærdi_, _byej, älde,
   {{0x63a40852,0x66054853,0xe7d3c0aa,0xa2e340c5}},	//   _mbin, bihk, थानप, _бояд,
   {{0x68318854,0x2004c855,0x63bbc856,0xcb078032}},	//   råda, wimi_, edun, عيون_,
   {{0x64498857,0x6722403f,0x22440066,0xe4da405f}},	//   _fiei, ļoju, ímky_, _عورت_,
   {{0x3266c858,0x63a4025d,0x44220859,0x6ec4485a}},	//   нтов, _nbin, jok_, रिपु,
   {{0x26c0485b,0x76488053,0x629bc71c,0x2006885c}},	//   nvio_, _tidy, gtuo, mioi_,
   {{0x6e21c85d,0x7c86c85e,0x75288036,0x27e9485f}},	//   golb, нуме, _tydz, zkan_,
   {{0xa37b009d,0x27e941c8,0x63a40860,0xe7e14185}},	//   lkõi, ykan_, _bbin, _नवलप,
   {{0x3c32002d,0x26c48147,0x988b8107,0x78550026}},	//   táva_, _krmo_, _رحمہ_, _sąvo,
   {{0x3205c05b,0x629bc861,0x7bdd4450,0x55e6c862}},	//   bily_, ctuo, _rosu, _подб,
   {{0x63a4031c,0x442b00d2,0x6d4e4863,0x26c04123}},	//   _ebin, slc_, _ngba, dvio_,
   {{0x386d02bc,0x66054864,0x23c4c1f9,0xf48407e3}},	//   ćero_, vihk, _वफाद, лутн,
   {{0x69de005c,0xf7734865,0x98bc8138,0x63a401c0}},	//   _eope, طار_, navı_, _gbin,
   {{0x7c228866,0x69de0498,0xbbe14285,0x7e6d0867}},	// [4b0] door, _fope, _नवीक, _uwap,
   {{0x64498018,0x69de00d1,0xfd50c112,0x3ea90303}},	//   _siei, _gope, _rudị, _ipat_,
   {{0x628f0868,0x7bdd4869,0xdb00c73b,0x66054033}},	//   luco, _tosu, lemä, rihk,
   {{0x987a0087,0x63af0066,0x27e9405c,0x6b67401e}},	//   _קארט, necn, qkan_, _dégâ,
   {{0x69c1486a,0xe8df800c,0x7bdf086b,0x326786b1}},	//   _óleo, _phỏm_, _moqu, хтев,
   {{0xeb9f4761,0xdee2886c,0xe5a5842e,0xd65800c3}},	//   _gjør_, роши, тики, עיות_,
   {{0x80bd8028,0x20024033,0x4422086d,0x81b38079}},	//   ्में, _ymki_, yok_, টাল_,
   {{0xe795805f,0x7bdf086e,0x9c7cc86f,0x3ea90870}},	//   _جاسک, _noqu, tyčn, _opat_,
   {{0x75e0405f,0xdcee4185,0x60dcc041,0xfbdf40d1}},	//   _közp, _odbě, ärmn, _niêm_,
   {{0x2292c5dc,0x629bc039,0x657740fd,0x316602bc}},	//   گلیس, rtuo, naxh, _đozo_,
   {{0x3ea90871,0x63b9c0f6,0x26c040e0,0x90998872}},	//   _apat_, _tawn, zvio_, _цвет_,
   {{0x69de0873,0x1ad88079,0x6ec44874,0x3f83c007}},	//   _sope, _দেয়া, रिमु, ėjus_,
   {{0x9f4f830d,0x644bc0f8,0x98a2c017,0x64c54199}},	//   ligó_, _iigi, ākā_, lčić,
   {{0x6825c019,0x7c2d4875,0x600b0051,0x7bcd0876}},	//   códr, elar, tömä, _enau,
   {{0x68388877,0xed5702f1,0xdce38047,0x7e7d4878}},	//   líde, тос_, vaně, _avsp,
   {{0xb7bc8879,0x644bc87a,0xdce70036,0xdb0f430d}},	//   _অক্ট, _jigi, naję, _sacá,
   {{0x660700b3,0x8c43487b,0x2019087c,0xf417802a}},	// [4c0] bijk, рете, érie_, ়তার_,
   {{0xf1d24028,0xa25b487d,0x64c542bc,0xa2c44036}},	//   साधन, _trôn, kčić, रिब्,
   {{0xdce38047,0x2fdf80ce,0x64c54013,0x81c3c02a}},	//   raně, _boug_, jčić, _একা_,
   {{0x644bc449,0x1867487e,0x7aeb4107,0xaf1280eb}},	//   _nigi, таци_, ölté, dụrụ,
   {{0x6d5c005e,0x27e0087f,0x22654089,0xa7fd0165}},	//   ocra, _moin_, čský_, tsız,
   {{0x27e00669,0x6289c655,0x2fcd8033,0x644bc880}},	//   _loin_, dreo, _eneg_, _aigi,
   {{0x4426c881,0x26d9801e,0xa7fd0165,0xa37b409d}},	//   _pko_, _àson_, rsız, _klõp,
   {{0x20124882,0xe4e3811b,0x0b8ac883,0x6ce380d9}},	//   nnyi_, рішн, фски_, ріше,
   {{0xfbd60047,0x31780036,0xf7438376,0xef1fc0b2}},	//   धानम, karz_, _вето, üüp_,
   {{0x443fc884,0xee3782b3,0x27e00755,0x09d0c02a}},	//   amu_, _ану_, _aoin_, িস্থ,
   {{0x0cd0c079,0x5a33c026,0x2caa405c,0x3ea90885}},	//   ান্ত, рнэт, _jpbd_, _spat_,
   {{0x6289c886,0x6a86c887,0xb4fb8009,0x3ea90033}},	//   breo, _алда, _קלאר, _ppat_,
   {{0xea00c00c,0x7c2d4888,0x68388018,0x24688031}},	//   _chảy_, vlar, cíde, _fìmò_,
   {{0x27e002d4,0xfbdf4015,0x24588015,0xe918c31e}},	//   _eoin_, _viêm_, _kém_, _полі_,
   {{0x2d580889,0x7c2441b4,0x6249488a,0x48e3c1e6}},	//   тись_, foir, _džol, _војв,
   {{0xdb19c88b,0x0a6b4267,0x6c6a005f,0x6608c1c8}},	//   _bawè, држи_, علقہ_, lidk,
   {{0x1959010e,0x3ea9071c,0x98bec696,0x386987ca}},	// [4d0] _папы_, _upat_, matı_, ćari_,
   {{0x35b5088c,0x98bec2d6,0x4439414b,0x644d015a}},	//   _сбор, latı_, _whs_, _hiai,
   {{0x7c24488d,0x68e8c0de,0x443fc88e,0x63a2888f}},	//   boir, nydd, ymu_, ffon,
   {{0x69ce4890,0x98bec2d6,0x7c24429a,0x21f4009d}},	//   _enbe, natı_, coir, _vähe_,
   {{0x2ba50891,0xc178c007,0x3b8486bc,0x7e62c892}},	//   ग्या, nkės_, рліг, _ntop,
   {{0xdb064047,0x1a6841aa,0x442dc893,0x9f40029a}},	//   _jaký, _شیمی_, wle_, _cliù_,
   {{0xa3cfc894,0x58d44895,0xd90f401c,0xa0b84896}},	//   शाल_, _корт, _بیا_, _игру_,
   {{0x64c5438f,0xa3d70027,0x81b38079,0x657540e2}},	//   rčić, साफ_, টাই_, _hezh,
   {{0x4a548897,0x0a49c441,0x6575407a,0x4649c3e1}},	//   _вкус, нзий_, _kezh, нзин_,
   {{0x644bc898,0x27e00899,0x6b82c89a,0x2009489b}},	//   _wigi, _soin_, _edog, hiai_,
   {{0x20094039,0x7c3b889c,0x644bc89d,0x27f20066}},	//   kiai_, _khur, _tigi, _plyn_,
   {{0xa25b41cb,0xdb19c303,0x644bc89e,0x8cc08163}},	//   _arôm, _lawé, _uigi, विरो,
   {{0x6455489f,0x2d834158,0x7c3b88a0,0x35a5c026}},	//   _luzi, _odje_, _mhur, _балг,
   {{0x6575456e,0xab5d817a,0x7bdbc8a1,0x64554053}},	//   _nezh, _inżu, ljuu, _ouzi,
   {{0x201908a2,0x7c3b825d,0x99e40089,0xa25b41cb}},	//   éric_, _ohur, šňov, _drôm,
   {{0x9c138112,0x644d00d1,0x6f1b8080,0xdb19c396}},	//   _sọnl, _giai, _oxuc, _pawè,
   {{0x25f7c0e4,0x8f75431e,0xaec641dc,0x657548a3}},	// [4e0] एसपी_, русі, ыбал, _bezh,
   {{0x7c2988a4,0x27edc033,0x63a288a5,0xe1ff0019}},	//   _aker, hken_, wfon, lpón_,
   {{0x6455401d,0x35c94027,0x7c3b88a6,0xe3bf0004}},	//   _cuzi, राज़, _bhur, loña_,
   {{0xe3b248a7,0x7c3b88a8,0xb4e00549,0x25f04048}},	//   _ارد_, _chur, थही_, _इतकी_,
   {{0xead488a9,0x91e684df,0x42d54007,0x6608c1c8}},	//   роль, лоде, _кіру, yidk,
   {{0x2fc048aa,0x61ee0498,0xdcba81bc,0x2fcfc8ab}},	//   ldig_, nkbl, ещи_, _angg_,
   {{0xea00c00c,0x3c3ac0fd,0x6608c8ac,0x63a448ad}},	//   _nhạy_, hëve_, vidk, ofin,
   {{0x3a2a48ae,0x764e4024,0x2b4d0011,0x7c2980b9}},	//   _hkbp_, _hiby, žeci_, _gker,
   {{0x224c8056,0x35f4c58f,0x3df4c8af,0x644d0359}},	//   _tidk_, ипир, изис, _riai,
   {{0xa96a81b4,0x27edc8b0,0xceb343bd,0x64428051}},	//   _أمام_, aken_, צית_, lmoi,
   {{0xf9934093,0xbc6688b1,0xddcd08b2,0x63a448b3}},	//   זרת_, _свек, _ataş, kfin,
   {{0x442688b4,0x2fc041d4,0x78ba805f,0x2a64821b}},	//   noo_, jdig_, _istv, _ktmb_,
   {{0x518708b5,0x6b8400de,0x644d0018,0xeb0708b6}},	//   лува, _ddig, _viai, учно,
   {{0xdb064107,0x6595001b,0x5a3400d9,0x5283c032}},	//   _lakó, јаву, йнят, _الوك,
   {{0x7c86c8b7,0x9f520053,0x7a34c060,0xd7d148b8}},	//   _суле, _olyè_, làto, हालच,
   {{0xf1d2c8b9,0x2fc04871,0x3a2a407a,0x7bc0c54a}},	//   तावन, gdig_, _akbp_, ndmu,
   {{0x557548ba,0xa295431e,0x645548bb,0xfba6c8bc}},	// [4f0] игат, разі, _suzi, क्यम,
   {{0x6e3c4166,0x27edc8bd,0x61ee08be,0xdb040545}},	//   _chrb, zken_, ckbl, _gaiñ,
   {{0x7c3b805e,0x44b54156,0xdb0f0018,0x27edc8bf}},	//   _phur, рбес, decé, yken_,
   {{0x628b87dd,0x5695423d,0xce9540c5,0xa3ce08c0}},	//   trgo, _камт, _камъ, राए_,
   {{0xdb1d413b,0x6fa708c1,0x60c88145,0x645a48c2}},	//   _masë, ट्यू, _ardm, _étin,
   {{0x88c581b4,0xac7744e8,0xaca4c171,0x657ac8c3}},	//   لتعل, _مارش, _asọy, jath,
   {{0x28c588c4,0x14b0c281,0x7c3b828f,0xc21240c3}},	//   विधि, _जनगण, _thur, _והם_,
   {{0xddc98054,0x6a85c0c5,0x69c948c5,0x645708c6}},	//   _uvež, алиа, _होती, _muxi,
   {{0xde59811b,0x45d580b4,0x6b9b805e,0xa7fd050c}},	//   _разі_, _коас, _icug, rpıl,
   {{0x7a304051,0xe7d14036,0x7bdbc09d,0x7afbc036}},	//   vätk, हाँप, sjuu, rzut,
   {{0x7cd988a7,0x6fca808f,0x98a5c119,0x628d4359}},	//   _جواز_, _सोडू, шине, hrao,
   {{0x245ac13b,0xf3f1c35d,0x3ea04218,0xdb064141}},	//   _dëm_, _dục_, ytit_, _makò,
   {{0x46a9c0b2,0xd343c01c,0x681208c7,0x6e67c8c8}},	//   _कहिह, _افشی, nādi, _стеж,
   {{0x6145c43e,0x7e64005b,0xdce388c9,0x645708ca}},	//   _кела, _vtip, lanđ, _buxi,
   {{0x63a988cb,0x442688cc,0x61ee08cd,0xd94608ce}},	//   _oben, yoo_, rkbl, реви,
   {{0x69c1c8cf,0x442b4498,0x764e44db,0xe3bf003c}},	//   ldle, _ckc_, _siby, poña_,
   {{0x61e3c8d0,0x7a2b405f,0x442b4077,0xa2064039}},	// [500] _konl, yütt, _dkc_, апад,
   {{0x645ec7b0,0x7aeb8065,0xe1f748d1,0x2fc00060}},	//   _épic, dygt, агу_, _haig_,
   {{0x63a448d2,0x69c1c02c,0xe1ff4031,0x645700fd}},	//   pfin, idle, _awós_, _guxi,
   {{0x3ead80b3,0x8fa688d3,0x2d9803bc,0x2ca70041}},	//   _bpet_, раде, lgre_, _ända_,
   {{0x660a87c5,0x3ead88d4,0xa3d708d5,0x68120017}},	//   tifk, _cpet_, सात_, gādi,
   {{0x657c08d6,0x6444404c,0x3ead807a,0x645e810b}},	//   narh, lmii, _dpet_, ípio,
   {{0x2c6c48d7,0x644f48d8,0x9f420051,0x69c1c8d9}},	//   _dòdò_, _yici, lkkä_, ddle,
   {{0x764388da,0x25a08047,0x69c1c8db,0xdb1d48dc}},	//   amny, řil_, edle, _basè,
   {{0x68388018,0x69c1c15d,0x7d0f8080,0x776d8004}},	//   cída, fdle, _əksə, ñaxe,
   {{0xe7a6c062,0x7f86c107,0x69c1c206,0xb21b069a}},	//   _कॉरप, _چلان, gdle, nræt,
   {{0x2fc008dd,0x68360089,0x2360404f,0x395744e0}},	//   _baig_, rádn, kcij_, ישים_,
   {{0x7afd00cb,0xfaa6c8de,0x657707a6,0x387ec414}},	//   tzst, _вадо, _sexh, rstr_,
   {{0x644f48df,0x443248e0,0x442b48e1,0x683605e5}},	//   _rici, dly_, _rkc_, pádn,
   {{0x683d0004,0x683608e2,0x6282c8e3,0x6280c3ad}},	//   déde, ládl, _ivoo, msmo,
   {{0x02b6c617,0x6e2708e4,0x245c005f,0x200b08e5}},	//   _अनुन, rojb, _cím_, pici_,
   {{0xc5f4009c,0x64570041,0x2fc000d2,0x61e3c0a8}},	//   _ruɓe_, _vuxi, _gaig_, _zonl,
   {{0x67ea410d,0xdb2382d6,0x62848039,0xe3bf0018}},	// [510] _nýju, ürül, šioj, loño_,
   {{0xfba6c1e2,0x216748e6,0x628d48e7,0x6b9b8157}},	//   क्तम, ртаг, rrao, _scug,
   {{0x2c558017,0xceb48080,0xdb1d48e8,0xb9c44032}},	//   _tādi_, çən_, _masé, تقلي,
   {{0x644f45ef,0x2009009c,0x6280c8e9,0x443240c3}},	//   _uici, _jmai_, ksmo, cly_,
   {{0xdce38054,0x69c1c8ea,0x27e480cc,0x7c2d08eb}},	//   vanđ, ydle, _domn_, _mkar,
   {{0x61e500f6,0x681208c7,0x3a3e843e,0x962188b8}},	//   _johl, rādi, _chtp_, यवेट_,
   {{0x7aed48ec,0x26cb4011,0x601ec017,0x490d0045}},	//   lyat, _hrco_, zīme, _डेमो_,
   {{0x81c3c079,0xc9180626,0x2d980458,0x7c2d08ed}},	//   _একই_, יחות_, zgre_, _nkar,
   {{0xf1d2c08f,0x61e3c8ee,0xa3bc8048,0xdb1d48ef}},	//   तांन, _ponl, _असत_, _basé,
   {{0x7a3048f0,0xdce38077,0x61fac0c3,0x079240a0}},	//   täti, sanđ, ghtl, _čímž_,
   {{0x443241e2,0x225948f1,0xddc18053,0x61e3c8f2}},	//   yly_, _lusk_, _pilņ, _vonl,
   {{0x69c388f3,0x26cb4157,0x7a3048f4,0x98160032}},	//   ldne, _orco_, räti, إبدا,
   {{0x290bc064,0x7a30404c,0x6458c004,0x657c08f5}},	//   ńca_, säti, _euvi, tarh,
   {{0xd999c78a,0xdb0f4004,0x7c29c8f6,0x3edf0044}},	//   _صنعت_, _facú, loer, _gwọọ_,
   {{0x67f5c166,0x9f4240fd,0x291e006a,0xfbdf40d1}},	//   _zája, _tokë_, çta_, _liêu_,
   {{0x443f8015,0x7ddd8565,0xf662c044,0x2bdac045}},	//   _nhu_, _vèsy, _họọr, भाया,
   {{0xf662c112,0xe7e94027,0x26cb4085,0x6458c8f7}},	// [520] _kọọr, _टकरा_, _crco_, _zuvi,
   {{0xab8c83a6,0x200e0064,0xa7fcc1df,0x8d5648f8}},	//   _çözü, ślić_, _atıl, стач,
   {{0x7c29c8f9,0x92d78079,0x224bc166,0x75e04107}},	//   koer, ানো_, ícky_, _közz,
   {{0x2aa083bc,0x6280c8fa,0x38a18086,0xa3ce08fb}},	//   tòb_, ysmo, dór_, राट_,
   {{0x63b641c8,0x68388047,0x1aecc079,0xe3bf0018}},	//   meyn, bídn, _জেনে_, zoño_,
   {{0x3ea0c04c,0xe2a70086,0x7bc088fc,0x443f88fd}},	//   _äiti_, óðir_, _wamu, _ehu_,
   {{0x657e4339,0xf1b30093,0xa3c80314,0xd90d808c}},	//   maph, פסה_, ईया_, پین_,
   {{0x67f5c815,0x7bc084fd,0x5f94c457,0x9f4243bc}},	//   _pája, _uamu, циит, _pokè_,
   {{0xa3dc0047,0xfc4a035d,0xdb1d48fe,0x920588c7}},	//   ठान_, _rập_, _pasé, _spāņ,
   {{0xf2e781aa,0xceb34626,0x38a18036,0x6280c8ff}},	//   _دکمه_, ליח_, bór_, rsmo,
   {{0x6ca3c051,0x2813c05f,0x61e50900,0x200dc0cc}},	//   пряж, _کونس, _rohl, biei_,
   {{0x62964901,0xdb0f403c,0x442940fc,0x7c29c902}},	//   kuyo, _vacú, xoa_, coer,
   {{0x69c18903,0x6e28c06c,0x44294904,0x657e400b}},	//   _yale, podb, voa_, kaph,
   {{0x7aed4905,0x7afd806a,0x2bcf8045,0x7bc2c906}},	//   vyat, _üste, _सोना, _haou,
   {{0x7bc2c907,0xdcf88908,0x317ec0b3,0x645a8909}},	//   _kaou, kavč, matz_, _juti,
   {{0xdb0b803c,0xdb0f090a,0x237d8046,0x7a3dc01e}},	//   hegá, lecí, xawj_, rète,
   {{0x44c842d6,0x1a5b41b4,0x61e50047,0x79888010}},	// [530] _ağ_, اشرة_, _tohl, _oddw,
   {{0x442b090b,0x657e4339,0xdb0f02b0,0x63ad090c}},	//   loc_, gaph, necí, _hban,
   {{0x2bbdc047,0x6aa4407a,0xfc3f4015,0x645a890d}},	//   ्यमा, atif, _thí_, _nuti,
   {{0x4374890e,0xdb0f001f,0x38a1890f,0x753a00cb}},	//   пушт, mecâ, vór_, ütze,
   {{0x201c801d,0xe70b81aa,0x3f89012c,0x6286c007}},	//   évia_, دتان_, _mdau_, škoj,
   {{0x237d8022,0x657a801c,0x2ba6c0e6,0x657e40c2}},	//   sawj_, _ceth, क्सा, caph,
   {{0x91bf8112,0x61428910,0x16d1c064,0x4429c015}},	//   _atụ_, меша, तम्ब, _ưa_,
   {{0x4fe9c911,0x442b0912,0x628281c8,0x798880bc}},	//   рмин_, joc_, bsoo, _eddw,
   {{0x200dc913,0x2bcf8794,0x2bdd0914,0x2a690046}},	//   riei_, _सोया, याना, _ntab_,
   {{0xc9a6c04c,0x7ae6c041,0x645a8915,0x27e6c053}},	//   овье_, äkta, _futi, _eoon_,
   {{0x442b0016,0xddcd4077,0xf2c90916,0x63ad01ae}},	//   foc_, ksaž, _שע_, _bban,
   {{0xddcd40b3,0x81bcc03f,0x1b4a0917,0x69dcc041}},	//   jsaž, slēp, изни_, örer,
   {{0x657a8339,0xddc28017,0x645a8918,0x201dc1c6}},	//   _yeth, lpoš, _zuti, _ijwi_,
   {{0xf3f1400c,0x2a6dc022,0xd7f140d1,0xf77f401f}},	//   ện_, mpeb_, ễn_, _roça_,
   {{0xb147c01c,0x27158919,0x765b811c,0x75e0491a}},	//   _دیدم_, तपुर_, _luuy, _gözy,
   {{0x6b9bc91b,0x25ad091c,0x7a30491d,0x6aa4491e}},	//   ngug, đela_, hätt, ttif,
   {{0x7bd6091f,0xc7b2c3bd,0x6d4ec38f,0x2a690033}},	// [540] _inyu, ובן_, žbat, _gtab_,
   {{0x61e74077,0x63b6403a,0xe9d74920,0x13a6005f}},	//   _cojl, seyn, оку_, _اچھی_,
   {{0x78ad0047,0x20dcc166,0x67f5c166,0xad65401c}},	//   čová, pšiť_, _nájo, ساله,
   {{0x5fdd008f,0x62964921,0x200f8922,0x67f8434d}},	//   यायल, puyo, gigi_, _fíja,
   {{0x254ec03a,0x657a8923,0x60134283,0x2a6dc022}},	//   zəl_, _peth, għmu, jpeb_,
   {{0x657e40f7,0x27e6c924,0xdbdd0031,0x7bc4009d}},	//   qaph, _soon_, _dáùs, _laiu,
   {{0x2bdd00ba,0x6282832e,0xdb0b856e,0xdb0f0018}},	//   यामा, ssoo, regá, vecí,
   {{0x442fc05c,0x63a9c1f4,0x62844007,0x6b9bc925}},	//   _ckg_, gfen, osio, ggug,
   {{0xfba6c926,0x26cd8010,0x27e6c05c,0x442fc927}},	//   क्षम, _greo_, _voon_, _dkg_,
   {{0xc3334093,0x80bb0079,0x63ad0928,0x628441f4}},	//   ווח_, _উপস্, _sban, isio,
   {{0x442b0929,0x96c28028,0x657c43a6,0x41de0185}},	//   toc_, लिकॉ, _merh, मानस,
   {{0xc5f400e2,0x69c3c17b,0xdb0bc92a,0x765b817b}},	//   _ruɓa_, _eane, _yagü, _yuuy,
   {{0x63a0821b,0x61e8892b,0x6b80c0f8,0xf77f0138}},	//   _mcmn, _kodl, mamg, raç_,
   {{0xc69381f2,0x628e8017,0x3ea68017,0x69c541c8}},	//   ואש_, _ābol, itot_, xdhe,
   {{0xf77f06ed,0x62864854,0x61e88750,0x7126c032}},	//   paç_, _avko, _modl, _برشل,
   {{0x6d584007,0x3ea68274,0x68e804c9,0x602406b1}},	//   žval, ktot_, ädda, _одја,
   {{0x78b3c0e0,0x6442c92c,0x69c3c92d,0xdb1d40b6}},	// [550] čevš, _mhoi, _yane, _ansò,
   {{0x35b4492e,0xe2a70086,0x26c9492f,0x6b8980c4}},	//   мбур, óður_, rvao_, _sdeg,
   {{0x61e1010d,0x645c4129,0x61e74077,0xef658165}},	//   öllu, _curi, _vojl, şımı_,
   {{0xab5d8930,0x3c3c8931,0x69c70932,0x799b0020}},	//   _baża, tíva_, ldje, ɗuwa,
   {{0x645c4933,0xa9698081,0x3e60c3bc,0x61e8802c}},	//   _euri, била_, _nòt_, _bodl,
   {{0x2366c011,0x29074032,0x8e08811b,0x6d430070}},	//   _afoj_, únas_, онів_, _únas,
   {{0xdb1d4934,0x2d814935,0x6b80c0eb,0x69c5c086}},	//   _masí, mahe_, _ịgab, _óhei,
   {{0x7c2d4232,0x251c0009,0x26cd8936,0x260d00b3}},	//   noar, יווא, _treo_, džom_,
   {{0x7e698937,0x68360089,0x61e8802c,0x7bc40938}},	//   _utep, sádk, _fodl, _raiu,
   {{0x69c50939,0xc9f78032,0x3e60c0ce,0xddcac06a}},	//   _nahe, _بسرع, _dòt_, ğişe,
   {{0x2fc48056,0x2a6dc022,0x27e90053,0xf865c0d9}},	//   _yamg_, speb_, _boan_, явно,
   {{0x442fc93a,0x7a32093b,0x2c63806a,0x3e60c141}},	//   _ukg_, hætt, _gıda_, _fòt_,
   {{0x9665c523,0x61e8893c,0x9f594053,0xdb0600b0}},	//   _экле, _yodl, _ilsè_, nekø,
   {{0xee38c93d,0x69c70011,0x27ffc6df,0xfce6093e}},	//   _дні_, gdje, lhun_, пого,
   {{0x63af4321,0x6f0280c4,0x2901c0d9,0x1fb6093f}},	//   _bbcn, zzoc, _åha_, _еспр,
   {{0x683d0940,0x69c7015d,0x27ffc010,0x7bd60941}},	//   lédn, adje, nhun_, _unyu,
   {{0xdb9b0942,0x69c701be,0x657c4943,0xdce1c007}},	// [560] _הספר, bdje, _perh, talė,
   {{0x61460039,0xb21b010d,0xdcfc0944,0xada6802d}},	//   _непа, nsæl, larč, _krúž,
   {{0xe7bdc945,0x62860946,0x6456011c,0x645c4573}},	//   ्याप, lsko, _kiyi, _quri,
   {{0x62844947,0x7981c948,0xdb1d4047,0xfaa68949}},	//   psio, halw, _zasí, задо,
   {{0x645c4813,0x60c18056,0x6456094a,0x27ffc94b}},	//   _wuri, _aslm, _miyi, dhun_,
   {{0x3ea6894c,0x6736004c,0x6f02894d,0x3f82094e}},	//   rtot_, _myyj, rzoc, haku_,
   {{0x3f8200fd,0x3243411b,0x26cfc94f,0x44320950}},	//   kaku_, _черг, _argo_, _oky_,
   {{0xfaa68951,0x3e60c3e2,0x64560952,0x6286051f}},	//   _набо, _pòt_, _niyi, ksko,
   {{0x614281c0,0x2007813b,0x7981c02c,0xf422002a}},	//   _bílí, ënie_, falw, নতার_,
   {{0xf1aa81aa,0x7c2d4953,0x3dc581f4,0x3e60c3e2}},	//   _داره_, zoar, _galw_, _vòt_,
   {{0x64488954,0x67f5c047,0x62860955,0xdb0f0018}},	//   _èdis, _zájm, esko, decá,
   {{0xdcfc0077,0x9f590070,0xa3df8048,0x23668956}},	//   garč, visó_, ताय_, ncoj_,
   {{0x2d814957,0x69c50958,0x6abd015d,0x26cfc011}},	//   yahe_, _pahe, uwsf, _grgo_,
   {{0x171bc093,0xa3b38959,0x657e095a,0x765d495b}},	//   _פוגע, _जॉन_, _ceph, _rusy,
   {{0x28f8004c,0xd90f01aa,0x27e9000c,0xa3df80e9}},	//   перь_, ایج_, _toan_, ताम_,
   {{0x20004119,0x03c4495c,0x69c5095d,0x624b0085}},	//   ghii_, нсум, _wahe, _ażot,
   {{0x2d9ec101,0x765d421b,0xa3d3095e,0x6b82895f}},	// [570] ogte_, _qusy, _होय_, daog,
   {{0x61eac2bc,0x7bc6421b,0x7e6d0960,0x2fc6c0f8}},	//   _jofl, _eaku, _itap, _laog_,
   {{0x64560961,0x2d814962,0x7a320963,0x645e0964}},	//   _yiyi, rahe_, rætt, _gupi,
   {{0x7bc64965,0x09aa8079,0xe3b381b4,0x657e0966}},	//   _gaku, _গোলা, عرض_, _zeph,
   {{0x442dc570,0x6d5a80c9,0x7e690119,0xd90f805f}},	//   voe_, _bgta, _împă, گیا_,
   {{0x2fc94967,0x6147001e,0xfe708968,0xdcfc004f}},	//   ldag_, célé, ادن_, zarč,
   {{0x63ad4150,0x3f820738,0x6449c969,0x7981c96a}},	//   ofan, yaku_, tmei, valw,
   {{0xb4e9496b,0xdcf8c077,0x6286096c,0xa2e44079}},	//   यही_, _cevč, ysko, _নেটও,
   {{0x26cb896d,0x2d83096e,0xdcfc0795,0x63ad496f}},	//   _éco_, kaje_, varč, ifan,
   {{0xa8794052,0x6b8d0970,0x44390971,0x64488157}},	//   ֿאָר, _adag, els_, _èdir,
   {{0x7e6d0972,0xf8afc973,0x9327c05f,0x442dc314}},	//   _atap, اکت_, _کران, poe_,
   {{0xe7d84079,0x2ef5c974,0x44390975,0x7e7b8044}},	//   _সত্য, _озер, gls_, _kwup,
   {{0x6b8d00bc,0xef0ec976,0x62860025,0x67f5c5ca}},	//   _ddag, _рм_, usko, _lájk,
   {{0x63bbc977,0xdb0f419d,0x4abcc3b0,0x44390978}},	//   leun, _lacó, ्टरव, als_,
   {{0xdca30979,0xa0a3097a,0xeb9f0240,0x6d5846f0}},	//   кари, кард, giøs_, žvak,
   {{0x6f0441d4,0x2e3440fa,0x645a0016,0x680b0036}},	//   tzic, häft_, ítiq, zędz,
   {{0xf412c093,0x2d83097b,0xb226001d,0xdb0f001f}},	// [580] דפן_, baje_, _омил, pecá,
   {{0x98b0497c,0x6838897d,0xa3b3846d,0x3f8d8060}},	//   žači_, mídi, _जॉब_, _adeu_,
   {{0xfaff00da,0x442f897e,0x09f70093,0x046546bc}},	//   ncën_, fog_, _חמים_, етім,
   {{0x225f8010,0xf77f43a6,0x1ee8405f,0xa3d701f9}},	//   _buuk_, _geç_, _فوجی_, साए_,
   {{0x6aa9c2bc,0x7bc9c97f,0x5694806f,0x69c74980}},	//   jtef, ddeu, халт, _faje,
   {{0xab5d817a,0xdcfe402d,0xb806002a,0x2edac5da}},	//   _fażo, lapč, োকিত_, _बपौत,
   {{0xa2c280a0,0x63a40981,0x35a34982,0x2a60029a}},	//   लिङ्, _ocin, _шарг, _luib_,
   {{0x828ac051,0x7bc9c983,0x3f8000b2,0x26d200bb}},	//   особ_, gdeu, _neiu_, _oryo_,
   {{0x7c2f0011,0x69c74398,0x6fdd0048,0xdb1d456e}},	//   vocr, _yaje, यासं, _kasá,
   {{0x4422407a,0x68388018,0x3e6444c9,0x6b8084c9}},	//   _ljk_, dídi, _möt_, _hemg,
   {{0x2d9ec984,0x63ad4985,0x91e38119,0x6b844986}},	//   rgte_, yfan, _шофе, kaig,
   {{0x83fcc0e0,0x2d830987,0x629bc010,0x6e950670}},	//   _buđe, waje_, buuo, ниму,
   {{0x6b808056,0xaac78260,0x44390988,0xb4bb43ae}},	//   _memg, लिएक, rls_, _अन्_,
   {{0x442240c9,0x442f8989,0x69ca898a,0x7c22c98b}},	//   _ajk_, zog_, ndfe, _hjor,
   {{0x395cc004,0x6b844032,0x2465c017,0x5558098c}},	//   _igvs_, faig, _tēma_, даря_,
   {{0xa00801b4,0x63a4098d,0x60c94017,0x442f8022}},	//   _يقول_, _gcin, _ņemo, xog_,
   {{0xdb1d434d,0x7e6d098e,0x6838810b,0x26c5003f}},	// [590] _basá, _utap, cídi, ālos_,
   {{0x2fc9498f,0x3f84c990,0xcec8c015,0xd71b0045}},	//   sdag_, hamu_, _mộ_, नपीठ_,
   {{0xcec8c082,0xdb0f010b,0x225f8006,0x26cdc158}},	//   _lộ_, fecç, _suuk_, zveo_,
   {{0x6d5c4991,0x63bd0007,0x2fc9014b,0x27e68992}},	//   _egra, nesn, _jaag_, gjon_,
   {{0x2fc90993,0x69c74994,0x6d418036,0xef198085}},	//   _maag_, _taje, _szla, _beża_,
   {{0xd94580c5,0x216984df,0x6d87405f,0x6d5c417a}},	//   нели, чики_, _زمرہ_, _ggra,
   {{0x442f8351,0x6fa5008f,0x644d4995,0xdb0f4996}},	//   pog_, _काढू, omai, _tacó,
   {{0x69c8805e,0x16bcc064,0x79838997,0x629d0998}},	//   _eade, ्टूब, sanw, kuso,
   {{0x63bbc999,0xdb1d099a,0xb065c051,0x17f88032}},	//   reun, ndsä, kyää, _غرفة_,
   {{0x89a9c99b,0x644d4032,0x2d8100eb,0x6f2580b4}},	//   чков_, hmai, _nehe_, ărcă,
   {{0x66150232,0x7c22c4f5,0x6aa9c99c,0xc1e68107}},	//   dizk, _fjor, stef, _سکول_,
   {{0x63bd099d,0x26c041f4,0x7981899e,0xfaff013b}},	//   gesn, ywio_, _helw, rcën_,
   {{0xdea94020,0x60c50573,0x27ed84f5,0xaffa8052}},	//   ƙoƙi, _ashm, _moen_, פּטי,
   {{0x2002099f,0x11d9c032,0x1d09c9a0,0x5bbc81f9}},	//   shki_, _روعة_, _нели_, _ईस्व,
   {{0xc5f28009,0x6459c9a1,0x27ff838a,0x44224056}},	//   נדל_, _kiwi, _olun_, _pjk_,
   {{0x7bc9807a,0x2bcf808f,0x63bd09a2,0x225849a3}},	//   _naeu, _सोला, cesn, _sirk_,
   {{0x2d9649a4,0x629d09a5,0x7c3bc9a6,0x6b8449a7}},	// [5a0] ерес, cuso, ilur, raig,
   {{0x2d810600,0x6289c9a8,0x167700c3,0x290c0018}},	//   _gehe_, iseo, _רגיל_, údas_,
   {{0x6b8449a9,0xddd8c053,0x27ed815a,0x225849aa}},	//   paig, _divň, _boen_, _virk_,
   {{0x7bcf801d,0xff47c9ab,0xa3e7809d,0x7c24017b}},	//   _ócul, _مخ_, मउग_, _jjir,
   {{0x7985400d,0x7d06c9ac,0xb5fb40d1,0x7981875d}},	//   bahw, _kéré, _quác, _belw,
   {{0x3f84c9ad,0x09e387ea,0x63bd09ae,0x64a640d6}},	//   wamu_, лочн, zesn, _пага,
   {{0x8cd309af,0x9d4349b0,0xeac8c015,0xa3ea8844}},	//   डियो, _берд, _sỹ_, _едва_,
   {{0xb4b0854a,0xcb0ac0c5,0x7658c12c,0x661501a8}},	//   _ओही_, зход_, _sivy, zizk,
   {{0x3a2689b1,0x6d43c9b2,0x2d85c36b,0xe297801b}},	//   _змаг, _azna, fale_, _пат_,
   {{0x63a289b3,0x7c2404fd,0x3f868053,0x44ce8064}},	//   lgon, _ajir, laou_, _tę_,
   {{0x2bdd09b4,0x98b3491c,0x7c3bc9b5,0x69dd8914}},	//   याला, čeće_, blur, पारी,
   {{0x388c8047,0x20000061,0x644d4010,0x27ff09b6}},	//   měr_, _clii_, xmai, óun_,
   {{0xddc400ab,0xee3f0066,0xdcf8c017,0xdbdc01c0}},	//   _stiš, stým_, _devā, _dáàb,
   {{0xb5fd89b7,0x9f5dc0b6,0x2fc9068e,0x6286c9b8}},	//   _tuše, _alwè_, _waag_, škos,
   {{0x7f44000b,0xdbdc002e,0xb5fb41ff,0xadc340d1}},	//   _eziq, _fáàb, _otár, _ngạc,
   {{0xd7cf89b9,0x765a89ba,0x61ee405e,0x69cac9bb}},	//   _सोंच, _lity, _aobl, _hafe,
   {{0x644d49bc,0xdd018011,0x65870156,0x3b5549bd}},	// [5b0] rmai, _čuče, _пынз, ткар,
   {{0x64584157,0x61fac9be,0xbd684007,0xb4b0809d}},	//   _èvin, nktl, ерце_, _ओहू_,
   {{0x25de0275,0x3f824077,0x236940b3,0xdcfc0017}},	//   खारी_, _feku_, pcaj_, parā,
   {{0xe71981b4,0x6d4509bf,0xdb1d013b,0xc61dc6fc}},	//   ويات_, _izha, jesë, _पद्य_,
   {{0x7bdd49c0,0x765a89c1,0x69a1c08f,0x27e949c2}},	//   _insu, _bity, _खाली, mjan_,
   {{0x61ee49c3,0x6aad412c,0xa2a640f4,0xdb044086}},	//   _gobl, mtaf, _चमत्, meið,
   {{0x7c3bc0b4,0x765a8231,0xe7e4075b,0x2a6fc414}},	//   tlur, _dity, गामा_, _stgb_,
   {{0x765a8026,0xdce180cc,0xdb1d013b,0xe29f0086}},	//   _eity, _află, gesë, kuð_,
   {{0x27e949c4,0xa3e5017e,0x2fc0809d,0x4a558119}},	//   ijan_, नान_, õige_, _акас,
   {{0x5b148466,0x765a89c5,0xc1cb008f,0x7bdd4010}},	//   _смут, _gity, ायोग, _lnsu,
   {{0x6289c9c6,0x69c50384,0x443249c7,0x67298085}},	//   sseo, ाजनी, yoy_, _hxej,
   {{0x629f4339,0x2b9ac0b5,0x7d06c1cb,0x9f404086}},	//   kuqo, rücü_, _séré, kkið_,
   {{0x628b89c8,0x6b86021b,0x72c300d7,0x7c3a801e}},	//   nsgo, rakg, абяз, _être,
   {{0x2d8786bc,0x7bdd49c9,0xfb1ac0c3,0x645c80c4}},	//   nane_, _ansu, _קוסמ, _èric,
   {{0x2aabc9ca,0x15f489cb,0x764e00fd,0x75fd80b6}},	//   løb_, _अवसर_, rmby, _lèzo,
   {{0x61ee49cc,0x7ae440fc,0x7bcd4105,0x601b4051}},	//   _sobl, txit, gdau, vämä,
   {{0x66060051,0xdcfa803f,0x1f6349cd,0x63a68041}},	// [5c0] _аппа, _metā, ркум, _ökni,
   {{0xd90d0646,0x628b89ce,0x7bdd49cf,0x68360004}},	//   _کیف_, dsgo, _ensu, cádr,
   {{0x69de01a8,0x7af64051,0x2d8349d0,0x602640d7}},	//   _inpe, syyt, _deje_, _адна,
   {{0xe29a8077,0xddc3c05f,0x645b829a,0x442049d1}},	//   дад_, _minő, _ciui, qni_,
   {{0x2d8789d2,0xc178c039,0x4422005f,0xc7a389d3}},	//   fane_, ybė_, ink_, ричк,
   {{0x998cc047,0x61fc0070,0x7d0200e2,0x3eadc9d4}},	//   vodů_, nkrl, _ƙosh, dtet_,
   {{0x6cd48280,0xdb1d013b,0x38634303,0x7e64068e}},	//   اقبا, tesë, _gujr_, _luip,
   {{0x1de049d5,0xb4de4048,0x6b8409d6,0x2fcdc1c8}},	//   नावत, तमी_, _neig, gdeg_,
   {{0x3f98c9d7,0x63a449d8,0x3eadc065,0x765c49d9}},	//   ğru_, igin, gtet_, _kiry,
   {{0xa80642d6,0x7c2289da,0x20128011,0xdb1ec086}},	//   llığ, lnor, žaić_, _þvíl,
   {{0xa5c6c031,0x4fc6c9db,0x765c49dc,0x2a6480fd}},	//   _abóò, _асла, _miry, _humb_,
   {{0x69de03bc,0x26c6c04d,0x69ce09dd,0xdb1d0107}},	//   _anpe, _tsoo_, edbe, lesé,
   {{0x3f8489de,0x79870150,0x26c6c057,0x6f09c9df}},	//   _memu_, tajw, _usoo_, czec,
   {{0xe4d4c3be,0x3205c9e0,0x63b600bb,0xb60200a0}},	//   _مقتد, chly_, _ebyn, _žáro,
   {{0xaa580698,0x22580051,0xab95481e,0xde888112}},	//   тиру_, тиры_, ливі, hị_,
   {{0x69de09e1,0x2d8349e2,0x63a449e3,0x7af200fd}},	//   _enpe, _seje_, ggin, ëjtë,
   {{0x7e6409e4,0x3869c0ab,0x765c49e5,0x7bcd49e6}},	// [5d0] _guip, _čari_, _biry, rdau,
   {{0x2d8789e7,0x7bc0c9e8,0x645b805e,0x7c2281f4}},	//   xane_, hemu, _siui, enor,
   {{0x2d8349e9,0x7bcd00f8,0x644989ea,0xe7e5c926}},	//   _veje_, _kaau, _phei, कामा_,
   {{0x7bc0c9eb,0x6e350242,0x60d54158,0x4426c9ec}},	//   jemu, lozb, _vrzm, _njo_,
   {{0x645d4871,0x12e44097,0xa3e1c045,0x3a84410e}},	//   _iisi, _кірг, दास_, _высв,
   {{0x7bcbc9ed,0xb5fd8158,0x7988c9ee,0x645d49ef}},	//   _sagu, _buša, jadw, _hisi,
   {{0xb4bd809d,0x3f8480c7,0x20024469,0x5f18c062}},	//   इबे_, _femu_, _ylki_, _बेब्_,
   {{0x44394020,0xbb45c523,0x5ac9c9f0,0x2d8789f1}},	//   _jks_, лейк, елим_, sane_,
   {{0x2fcdc9f2,0x63a989f3,0x27efc240,0x7983c02c}},	//   rdeg_, _icen, _vogn_, _penw,
   {{0x7bcbc9f4,0x3dcc81f4,0x6f09c036,0xa5c5c031}},	//   _wagu, _gadw_, rzec, _gbọ́,
   {{0x3ea049f5,0x7c29406c,0xa2ca49f6,0x7e640755}},	//   zuit_, čerj, _सैन्, _suip,
   {{0x7d1cc032,0x6724c066,0x7bcbc398,0x201909f7}},	//   úrsa, _žije, _uagu, gisi_,
   {{0xab5d8283,0x6ef9c1c0,0xf409402a,0xe9cec9f8}},	//   _bażi, _dùbú, রচার_, _лк_,
   {{0x645d49f9,0x831ac009,0x2292c1b4,0xd83909fa}},	//   _aisi, _אונז, _الوس, ruča_,
   {{0x69ce09fb,0x2fc049fc,0x63a44820,0xa3c049fd}},	//   rdbe, teig_, tgin, ंजल_,
   {{0x443fc0b5,0x201909fe,0x63a44007,0x3e69c9ff}},	//   nlu_, cisi_, ugin, _kút_,
   {{0x63a44a00,0x2baa4047,0x60060019,0x628d4105}},	// [5e0] rgin, ङ्गा, _cóme, gsao,
   {{0x2d858a01,0x443fca02,0xa50a493f,0xd8398053}},	//   _nele_, hlu_, неза_, _akō_,
   {{0x5a16c009,0x3ea20a03,0xb7d68171,0xa80642d6}},	//   נקען_, lukt_, _aṣay, tlığ,
   {{0xdc9b04e0,0x2a694022,0xf3f1400c,0x9d1b0052}},	//   _איטל, bqab_, ệt_, _טויט,
   {{0x2d858a04,0x877b0009,0x68e34041,0x765e0a05}},	//   _bele_, גאני, ändr, _kipy,
   {{0x645d4a06,0x7a3040fa,0x443fca07,0x765e0150}},	//   _zisi, hätz, elu_, _jipy,
   {{0x20190a08,0x5faa008f,0x295541bc,0x443fca09}},	//   yisi_, _काढल, _вътр, flu_,
   {{0x7c244a0a,0x3a3a0033,0xa3ab809d,0x57a6ca0b}},	//   nnir, _lkpp_, _खाय_, ушка,
   {{0xb21b4065,0xcff780c3,0x5186c7ad,0xf7438119}},	//   _ivær, _עצמה_, луна, _гето,
   {{0x32b7c1b4,0xdcfa8119,0x2d858a0c,0x6b8640c7}},	//   ادية_, _cetă, _gele_, _lekg,
   {{0x7988c1f4,0x2d8a0a0d,0xaca300eb,0xb5fd8043}},	//   radw, dabe_, _kwụg, _kušn,
   {{0x443fca0e,0x69ce4a0f,0xb5fd8120,0x9f490397}},	//   clu_, _labe, _jušn, _blað_,
   {{0x765e017b,0xa7fd0080,0x4ea70119,0x3e69c35d}},	//   _bipy, qqım, ырна, _gút_,
   {{0xd250ca10,0x2fcd0a11,0x6440ca12,0x682800b5}},	//   _بنت_, žeg_, llmi, rıda,
   {{0xafdb00b0,0x2a694a13,0x765e002c,0xc8a8c07c}},	//   rløb, wqab_, _dipy, _कमिट,
   {{0xddc28a14,0x6282ca15,0x645d4a16,0x69ce4a17}},	//   jpož, _kwoo, _qisi, _aabe,
   {{0x26c90a18,0x8e154a19,0x7bc28a1a,0x7a304051}},	// [5f0] _usao_, адац, deou, läty,
   {{0x2bdd0a1b,0x44290a1c,0xd9994a1d,0x7a3dc6ed}},	//   याका, _hja_, ئنات_, tèti,
   {{0x645f0669,0x61fa009d,0x7a304051,0x628d4025}},	//   _épis, ötle, näty, ssao,
   {{0xe8d7c0c3,0x60060070,0x25ad041b,0x44394a1e}},	//   טובר_, _tóme, đelu_, _uks_,
   {{0x66f70191,0x443fca1f,0xc7d845f5,0xa2e58077}},	//   ुनिक_, vlu_, _смях_, ролд,
   {{0xb882c531,0x3f8b0639,0xe9d88039,0x7c958a20}},	//   _číns, hacu_, лкі_, ариц,
   {{0xd83900b3,0x3dd70079,0x2aaf403a,0x3f8b0242}},	//   jučo_, _সকাল, lüb_, kacu_,
   {{0x67ff00fd,0xaca30112,0x6282c40d,0xdcfa80b4}},	//   _bëjm, _gwụg, _bwoo, _setă,
   {{0x628f0064,0x6b8b8a21,0x7c3b8a22,0x80048a23}},	//   jsco, magg, _ikur, _учре,
   {{0x7bcf4a24,0x27e001b7,0x5fa7c7f6,0x91f5c119}},	//   _lacu, _snin_, _गावल, рчич,
   {{0x7c298a25,0x14260441,0x629d0a26,0x20094a27}},	//   _kjer, идом, erso, khai_,
   {{0x26d9423f,0x60dc8086,0x7c2980bb,0x8fa603fe}},	//   _orso_, _árma, _jjer, шаме,
   {{0x20094a28,0x27edc0fd,0xdb160070,0x628f0a29}},	//   dhai_, mjen_, _rayó, gsco,
   {{0xcaf4c05f,0x78a1c70d,0x27ffca2a,0xd167c0c5}},	//   _دسمب, pulv, lkun_, _съди,
   {{0x7afbc080,0x628f0a2b,0x78a38080,0xf7724a2c}},	//   lyut, asco, nunv, قاء_,
   {{0x27edca2d,0xa3d3008f,0x7c3b800d,0x27ffca2e}},	//   njen_, _होऊ_, _nkur, nkun_,
   {{0x0d864a2f,0x2bbb8444,0xddc287ca,0xfbbb8a30}},	// [600] илан, ोजना, vpož, ोजनम,
   {{0x27edc0fd,0x2d87ca31,0xe8fa0119,0x93594a32}},	//   hjen_, _jene_, _ало_, урсу_,
   {{0x27edc0da,0xdce8c03f,0x7bcf4a33,0x27ffca34}},	//   kjen_, vadī, _facu, kkun_,
   {{0x661aca35,0x2d87ca36,0x27edc0f1,0xddcd42bc}},	//   zitk, _lene_, jjen_, rpaš,
   {{0x661ac07a,0xdb0b819d,0x7c298a37,0x213e802c}},	//   yitk, degó, _djer, _syth_,
   {{0x25aa4010,0x7bc28a38,0x82d701f2,0xd90d816a}},	//   _ucbl_, seou, יונג_, کیم_,
   {{0x6b8b81ae,0x082ac897,0xa3c80a39,0x4fc6c026}},	//   bagg, кции_, ैया_, аспа,
   {{0x27edc0fd,0x2b5f00b3,0x32058a3a,0x3c3c802d}},	//   gjen_, žuci_, _elly_, tívu_,
   {{0x644d0a3b,0x656943a6,0x6fa7ca3c,0x3f8b07ca}},	//   _rhai, _şehi, _गारं, vacu_,
   {{0xceb34093,0x78be011b,0x67fcc070,0x6b960396}},	//   קית_, _oppv, _méji, _adyg,
   {{0x7d0dc813,0x2d87ca3d,0x661aca3e,0x3a380353}},	//   _ƙasa, _dene_, ritk, dorp_,
   {{0xb4c6c260,0x661aca3f,0x79888a40,0x644d0046}},	//   _उनी_, sitk, _hedw, _qhai,
   {{0x628f023f,0x2d87ca41,0x629d0a42,0x78be0556}},	//   usco, _fene_, urso, _appv,
   {{0x1866c1bd,0xfa33c1aa,0x3f8b011f,0x2d87ca43}},	//   _књиг, _ورود, sacu_, _gene_,
   {{0xe7fb408f,0x44268a44,0xb7fb4a45,0x6605005b}},	//   _एकदा_, kno_, _एकदम_, _vlhk,
   {{0xa3bb0446,0x2d87ca46,0x1473c05f,0xd3784a47}},	//   _شاعر_, _zene_, _باوج, ичу_,
   {{0x6b8b8a48,0x21674a49,0x44c84a4a,0x69c38a4b}},	// [610] vagg, атег, _aş_, yene,
   {{0x44268a4c,0x2d874a4d,0x201b403a,0x6b8b8a4e}},	//   eno_, úne_, siqi_, wagg,
   {{0xd010405f,0x2f748044,0x27edc051,0xdcfc0123}},	//   سلے_, _ịnọ_, yjen_, varć,
   {{0x2a690046,0x2d98c064,0xe29f069a,0xa425802a}},	//   _kuab_, órej_, orð_, বত্য_,
   {{0x6b8b8a4f,0x60da8a50,0x2a690022,0x201c86ed}},	//   ragg, _artm, _juab_, èvia_,
   {{0x6b8b8a51,0x2006ca52,0xf99181b4,0x72054032}},	//   sagg, _aloi_, سبت_, _اوسم,
   {{0xdb0b8a53,0x27edca54,0xac944a55,0x2a690046}},	//   tegó, tjen_, _марш, _luab_,
   {{0x6ebb4260,0x2d87ca56,0x7afbca57,0x7afd0a58}},	//   _उहाँ, _sene_, tyut, kyst,
   {{0x69c38a59,0x2d87ca5a,0x2d8cca5b,0xdb0b8a5c}},	//   pene, _pene_, fade_, regó,
   {{0x44390a5d,0x2006ca5e,0x69c54a5f,0x27ffca60}},	//   eos_, _eloi_, nehe, skun_,
   {{0x63ad0033,0xddc64007,0x7afbc05c,0x7e698398}},	//   _bcan, _sukū, syut, _huep,
   {{0x6b8d4a61,0xdb044359,0x68fcca62,0x2d87c0b1}},	//   jaag, rfiú, ørda, _wene_,
   {{0x60060018,0x3a380041,0x6b8d4a63,0x7c260a64}},	//   _cóma, torp_, daag, rnkr,
   {{0xdb06001c,0x6d418a65,0x7e96ca1d,0xdb1d0004}},	//   ngké, _kyla, _انور_, cesí,
   {{0xddcd0119,0x7643807a,0x644f4061,0x1d070a66}},	//   _staţ, ilny, _bhci, бери_,
   {{0x1f664a67,0x66074158,0x60dcc240,0x7afd0166}},	//   скам, _aljk, ærme, byst,
   {{0x3ebf8a68,0xfe720032,0x644f405e,0x60060a69}},	// [620] _nput_, _عدة_, _dhci, _góma,
   {{0xe8194a6a,0xe05841aa,0x200041c8,0x49ca0a6b}},	//   नोबा_, _چیست_, skii_, _слон_,
   {{0x6b898a6c,0x69ad06c1,0x09f70093,0x7c2dc06c}},	//   _beeg, _जाती, _המים_, čarj,
   {{0x2a690022,0xb5fd87ef,0x63a9ca6d,0x44d80347}},	//   _yuab_, _dušm, jgen, _ič_,
   {{0xb4e088b8,0x6d4181df,0x38b1ca6e,0x44d800b3}},	//   दम्_, _ayla, hár_, _hč_,
   {{0x41e28064,0x63a9ca6f,0x798e0a70,0x25db8a71}},	//   पाइस, egen, nabw, _गोदी_,
   {{0x23698a72,0x64428a73,0xdca34a74,0x2d8cca75}},	//   žaja_, ploi, _нари, vade_,
   {{0x3a3a44d3,0x7bf8c2f1,0x2ca5ca76,0x798e000d}},	//   lopp_, рнир_, duld_, habw,
   {{0xf76fc5a7,0x798e0a77,0xa3d3025c,0x7bc60a78}},	//   راي_, kabw, _होग_, deku,
   {{0xea01000c,0x63ad0a79,0x2ca5c065,0x44390024}},	//   _đắt_, _scan, fuld_, wos_,
   {{0x7bc60a7a,0xd7efc747,0x89db8093,0x2d8cca7b}},	//   feku, _еу_, _תחבי, rade_,
   {{0x2a69004d,0x44d7c119,0x3f8dc004,0x2d8a4414}},	//   _puab_, _dă_, caeu_, _lebe_,
   {{0xe7e5ca7c,0x6ee5c032,0x41e704c5,0x661e40f8}},	//   कारा_, _وسهل, біва, kipk,
   {{0x2a690022,0xdb0f801e,0x3ea04a7d,0x6e248032}},	//   _vuab_, édér, drit_, éibh,
   {{0x19590039,0x60254007,0x3ea04a7e,0x555905f5}},	//   равы_, lėmi, erit_, равя_,
   {{0x61f5450c,0x44d800b6,0x60060086,0x93f64080}},	//   _sozl, _dč_, _tóma, _şərə,
   {{0xa3ba454a,0x35f54348,0x68e80041,0xe3b04032}},	// [630] _आउर_, опар, äddr, عرف_,
   {{0x6b8d4a7f,0x7e7d0a80,0x21674a81,0xafdb4a82}},	//   saag, mpsp, стаг, _skød,
   {{0x3ea040fd,0x61e50339,0x6b89809d,0x61f540e5}},	//   arit_, _inhl, _peeg, _vozl,
   {{0x6e3aca83,0xab9480d9,0x7f42c073,0x6d418a84}},	//   hotb, зиці, _oyoq, _ryla,
   {{0x7e61807a,0x35de0027,0x443b40c7,0x2d8e809c}},	//   _pilp, _फोड़, moq_, fafe_,
   {{0x69c70a85,0x2d8a4a86,0x04c94a87,0xa3e74048}},	//   neje, _gebe_, _پوري_, पाव_,
   {{0x7bc60a88,0x92e98079,0x2baa0a89,0xfbdac3f4}},	//   yeku, মনে_, _काला, _मोहम,
   {{0x2bd90a8a,0x7c2d0a8b,0x2d8144ff,0xf41f0051}},	//   _बोला, _njar, lbhe_, jiä_,
   {{0x34c60027,0x3f8dc004,0x6003409d,0x2d9840b0}},	//   _लन्द, raeu_, _nõmm, _ydre_,
   {{0x3f8f8a8c,0x78a700fd,0xdd0e42d6,0x3125c051}},	//   lagu_, kujv, nışa, ждог,
   {{0x25ddc08f,0xa3e50a8d,0xa3ea0603,0xb4e3c09d}},	//   _कोणी_, नां_, адна_, नमे_,
   {{0x290bc064,0x38b1ca8e,0x443dca8f,0x3f8f8a90}},	//   ąca_, rár_, _ukw_, nagu_,
   {{0x2903c06c,0xe2dac05f,0x34c20a91,0xdb23c051}},	//   šja_, _پانچ_, शब्द, öräi,
   {{0x201fc039,0xa7fb4070,0x27e08017,0x200dc01f}},	//   liui_, _riña, ķini_, lhei_,
   {{0xdd8ec032,0x7e6bca92,0x3f8b4054,0x798e01c6}},	//   _شوي_, _hugp, _becu_, rabw,
   {{0x3f8b4a93,0xa3e50a94,0x200dc10b,0x201fc039}},	//   _cecu_, नाः_, nhei_, niui_,
   {{0x661e4a95,0x644445f9,0x3ea042a4,0x291100c4}},	// [640] tipk, rlii, urit_, azza_,
   {{0x7c2d00da,0x3ea04a96,0xbb1b0669,0x2bd1c08f}},	//   _zjar, rrit_, raît, _दोघा,
   {{0xec13001c,0x6444409d,0xceb44080,0x64460a97}},	//   _روید, plii, stə_, olki,
   {{0x661e4a98,0x6d43c15a,0x2d8a4166,0xfe67c032}},	//   sipk, _myna, _webe_, _يد_,
   {{0x7c29ca99,0x61f70080,0x443f8396,0xa3cdc09d}},	//   dner, _yoxl, _dku_, शजन_,
   {{0xdd924973,0x9f4fc070,0xddd54017,0x59b20045}},	//   _زور_, _cogí_, _aizņ, _जाफर,
   {{0x321eca9a,0x61434a9b,0xd5ad805f,0xe7aa0a9c}},	//   vity_, _жера, اہم_, _कांप,
   {{0x3f8f884f,0xa0674119,0xaa7b4047,0x78fb0052}},	//   cagu_, _фата_, _frýd, יפצו,
   {{0x7e63ca9d,0x3b0780c5,0xe5c6ca9e,0xc05344e0}},	//   _binp, _дето_, осно, וזה_,
   {{0x7c2d0a9f,0xa2db4aa0,0x60254026,0x7c29caa1}},	//   _sjar, नित्, rėmi, aner,
   {{0xd8390aa2,0x7c3bcaa3,0x321ec3d4,0x104b004c}},	//   luči_, bour, rity_, иями_,
   {{0x2d8c8aa4,0xdb214066,0x7c3bcaa5,0xf77f401f}},	//   _hede_, _štíh, cour, _onça_,
   {{0x2d8c8aa6,0x6e3ac107,0x7d04c09c,0x27e6caa7}},	//   _kede_, potb, _ƙiss, _inon_,
   {{0x69d5003f,0xf287c05f,0x644601c8,0x41e40589}},	//   udze, _بھٹو_, alki, міса,
   {{0x2d8c8aa8,0x3f820056,0x22be8017,0xf41f0051}},	//   _mede_, bbku_, lākā_, piä_,
   {{0x7a3f8669,0x386c8066,0x7e7d0aa9,0x83fcc077}},	//   nêtr, _mudr_, ppsp, _buđi,
   {{0x799a8036,0x7f4d0080,0x3f8f841b,0xfe704aaa}},	// [650] _odtw, _uzaq, vagu_, ندل_,
   {{0x2d8c8aab,0xd8390043,0x78a7013b,0x442d8aac}},	//   _nede_, duči_, pujv, _sje_,
   {{0x2d8300fd,0x81bcc017,0x7c29caad,0x60320017}},	//   mbje_, tnēj, yner, sāme,
   {{0x61f8c240,0x44294aae,0x7c294066,0x3e708321}},	//   _lovl, qna_, čers, _bàt_,
   {{0xeb764009,0xde46401c,0x7c29c7a4,0x69c8caaf}},	//   _מערץ_, _کیلو_, vner, kede,
   {{0x28b981b4,0xbb3c0052,0x6b8d0ab0,0xe2968ab1}},	//   مطبخ_, בעדי, _leag, чаш_,
   {{0xeb99cab2,0x6b8bc0c5,0x7c29c36b,0xc7b9c05f}},	//   бий_, _pegg, tner, tfő_,
   {{0x7c29cab3,0x95f5c6ff,0x7e63c0fc,0x442d8ab4}},	//   uner, ेस्ट_, _sinp, _uje_,
   {{0x7c3bc119,0x6b9b8105,0x7c29cab5,0x201fc007}},	//   rour, _idug, rner, riui_,
   {{0x7e7b8ab6,0x7c3bc093,0x69d54ab7,0x11d5c032}},	//   _itup, sour, _jaze, ستخد,
   {{0x61f8cab8,0x29014107,0x6b8bc157,0x7c3bcab9}},	//   _dovl, nyha_, _tegg, pour,
   {{0x6b8d005e,0x24520089,0x7a3f81cb,0x63ad4127}},	//   _ceag, káme_, cêtr, jgan,
   {{0xdee5c8d3,0x66e5caba,0x26ddc00d,0x1dac408f}},	//   _холи, _хола, _urwo_, _चालत,
   {{0x63ad4abb,0x7e6d0033,0x2d910abc,0x7bc9c4e1}},	//   egan, _duap, gaze_, leeu,
   {{0x25e8cabd,0xd83f004f,0xd942cabe,0xa7fcc138}},	//   जारी_, ščaj_, _пеши, _atıy,
   {{0x80b1c079,0x68fccabf,0x661c4ac0,0x83fcc011}},	//   _জনপ্, ärde, _smrk, _puđi,
   {{0x2d910793,0x63bbcac1,0xd3874ac2,0x389780cc}},	// [660] baze_, ifun, яйте_, hăr_,
   {{0x4a434ac3,0x63ad4ac4,0x7bd60ac5,0x6e21c693}},	//   енув, agan, _hayu, nilb,
   {{0x26df8112,0xdb1d4ac6,0x63bbcac7,0xb5fd80ab}},	//   _aruo_, _basó, kfun, _guši,
   {{0x68e30004,0x443d8ac8,0x6e21c620,0x442041c8}},	//   _ánda, gow_, hilb, qii_,
   {{0x6b844ac9,0x63bbc085,0x6d4000b5,0x3ea94aca}},	//   mbig, dfun, şmad, cuat_,
   {{0x6b9b8acb,0xec168396,0x6e21cacc,0x6aa28060}},	//   _edug, _کورد, jilb, rrof,
   {{0x58868007,0xdb1d4acd,0x645840c4,0xbfa3c0d1}},	//   чыла, _absè, _èvis, _tiề,
   {{0x69d54073,0x22be8017,0x02a6cace,0x8cbd8036}},	//   _zaze, tākā_, пром, _शहरो,
   {{0xa5ad0036,0x442b0010,0x6b8445bb,0x2cbf46f0}},	//   _जालौ, vnc_, ibig, _ćudi_,
   {{0xdd90c16a,0x2c71805e,0x2a658061,0x27e088c7}},	//   خود_, _fád_, _gilb_, ķinu_,
   {{0x40350acf,0x26d9c4c9,0xd250c05f,0xaf36c16a}},	//   денс, åsor_, ٹنگ_, _کرات,
   {{0xa3d7caa0,0x27e6c010,0x2ee001f4,0xab5b0ad0}},	//   ायः_, _unon_, _brif_, nfüg,
   {{0xe2dac107,0x2d910ad1,0xa3b488b8,0x63ad4ad2}},	//   _دباؤ_, taze_, _ञान_, vgan,
   {{0x69ca8ad3,0x9c830166,0x18054ad4,0x3205cad5}},	//   nefe, účov, रस्व_, ckly_,
   {{0x49bbc942,0xc1bbc093,0x877a425d,0x38a040b4}},	//   _המוס, _המוש, _ọwụw, nără_,
   {{0xa7fb4ad6,0x69ca8ad7,0x61fa80f8,0x99980047}},	//   _viño, hefe, _lotl, borů_,
   {{0x8f9c0093,0x69d54ad8,0x2fc942d4,0x27e90ad9}},	// [670] _היחי, _paze, reag_, _inan_,
   {{0xdb07801e,0x7bc0817b,0x2bf9802a,0xf8ae02f0}},	//   _élég, _abmu, _আগেই_, دکی_,
   {{0x7fd580d9,0x63ad4ada,0xee78008c,0x798e40ce}},	//   ділі, pgan, _وصیت_, _debw,
   {{0x76418007,0x38b54adb,0x6b8441c8,0x5ba74523}},	//   _skly, rår_, cbig, _эроз,
   {{0x69ca8123,0x7c2b8adc,0x7d0dc09c,0x443d8add}},	//   fefe, rngr, _ƙask, row_,
   {{0xdb1b8086,0xa925002d,0x68e14107,0x7c2d4ade}},	//   _dauð, poľč, _áldo, lnar,
   {{0x1dd7c021,0x69d70adf,0x3866cae0,0x2d934ae1}},	//   _भोगत, _maxe, _bior_, maxe_,
   {{0x1309c09b,0x63bd015d,0x27e9009c,0x44220ae2}},	//   жний_, jfsn, _nnan_, xik_,
   {{0x7bcb8ae3,0x7c284018,0xef19cae4,0x69ca8ae5}},	//   megu, édri, юми_, befe,
   {{0x61fa8041,0x7ae2004f,0x5fdf4549,0x2ee00011}},	//   _gotl, _šoto, _पोसल, _rrif_,
   {{0x3205c126,0xc60984e3,0x23728007,0x6b8440f8}},	//   rkly_, वसीय_, žyje_, ybig,
   {{0x99980047,0x25ddc045,0x27e9005e,0xc20900c3}},	//   torů_, _कोरी_, _cnan_, _דה_,
   {{0x6449cae6,0x81d08079,0x69d701c8,0x61e88211}},	//   mlei, ষার_, _baxe, _yndl,
   {{0x35fbc1aa,0xd9f08959,0x2d8ec6df,0xe7e5cae7}},	//   _درصد_, चायत_, _gefe_, काका_,
   {{0xde6d0015,0x61430ae8,0x7c2d410d,0x7bd60ae9}},	//   _vươn, вера, fnar, _tayu,
   {{0xa3b1cad4,0x6e238aea,0x6aa44aeb,0xed570aec}},	//   ञ्च_, hinb, trif, фос_,
   {{0x60c942bc,0x7c294066,0x7bcb8aed,0x1dae8048}},	// [680] _ćema, čerp, degu, _घालत,
   {{0x62964aee,0x6449c0fa,0x3f924aef,0x7d038af0}},	//   rsyo, hlei, sayu_, kyns,
   {{0x62964af1,0x7643c033,0x04034079,0x200d84f5}},	//   ssyo, _mkny, রোধী_, _blei_,
   {{0x629643bc,0xc314c079,0x6aa44af2,0x7d034af3}},	//   psyo, াপতি_, prif, ønsa,
   {{0x6d474086,0xf1aa401c,0xb86582cf,0x6449caf4}},	//   _eyja, _واسه_, رامو, dlei,
   {{0xe607c2f0,0x3e7404c9,0x3866c8a6,0x44ce80a0}},	//   _شش_, _mät_, _sior_, _př_,
   {{0x7c228af5,0xd5ed00d1,0x6449caf6,0x61fa8af7}},	//   pior, _quả, flei, _votl,
   {{0x61fc4af8,0xc6f8caf9,0x8af8cafa,0xdb044004}},	//   _horl, зних_, знис_, lfiñ,
   {{0x61fa8125,0x3e7b8379,0x6f044449,0x00000000}},	//   _totl, _câtă_, nyic, --,
   {{0x44f4c87b,0x61e88afb,0xbafb80c3,0x3f868afc}},	//   епос, _undl, _והמש, lbou_,
   {{0x6449cafd,0x61fc4afe,0xa3b6ca3c,0xb4bc4048}},	//   blei, _morl, _जाप_, _अहो_,
   {{0x3f8fc031,0x2d85caff,0x6449cb00,0x3e72c104}},	//   _gegu_, able_, clei, _tât_,
   {{0x63b40089,0x6282831d,0x3f86809c,0xdb24c051}},	//   _žená, npoo, ibou_, äräy,
   {{0x25754b01,0x69c1805c,0x2d8ec011,0x6444040d}},	//   _múló_, _xble, _uefe_, _ekii,
   {{0x7c2d4b02,0x387cc011,0x7ae2cb03,0xb5fc81d6}},	//   tnar, _utvr_, _hrot, _riġl,
   {{0x44dec283,0x44200b04,0x80c4c02a,0x7bcb8018}},	//   _iċ_, _gmi_, ষিদ্, xegu,
   {{0xa3e88b05,0xcd040047,0xdb098b06,0xb5fd83aa}},	// [690] बाई_, vněž_, _oceá, _kušt,
   {{0xf3ff4015,0x7c2d4b07,0xa3eacb08,0x61fc4b09}},	//   _giãn_, snar, माँ_, _corl,
   {{0xe7e40048,0xdb044107,0x38b8cb0a,0x2f7c8044}},	//   गाचा_, rgiá, nér_, _ịmụ_,
   {{0x6440cb0b,0x3f8680b1,0xc6a74b0c,0xdcf8c077}},	//   jomi, gbou_, _орги, _jevđ,
   {{0x3d178b0d,0x3f8fcb0e,0x26c6c23b,0x6d474064}},	//   _भेजे_, _regu_, _npoo_, _wyja,
   {{0xc3324093,0x443fc141,0x6aad405c,0xb5fd8011}},	//   _תוך_, wou_, muaf, _nušt,
   {{0xa3eac028,0xe3b1c1b4,0x6449c26e,0xeb99c156}},	//   मां_, هرة_, tlei, пий_,
   {{0x6440cb0f,0x248c8018,0xeb99c04c,0x7ae2cb10}},	//   gomi, _dwdm_, чии_, _brot,
   {{0x3947cb11,0x0e358974,0x3ea68033,0x963586e4}},	//   _syns_, _знаю, crot_, _знац,
   {{0x7c244b12,0x7ae2cb13,0x69c18b14,0x4424c2d4}},	//   ziir, _drot, _uble, aim_,
   {{0xb4be0834,0x38b8cb15,0x6449cb16,0x6d4881f4}},	//   _इहे_, gér_, plei, _gyda,
   {{0x4424cb17,0xe73a0b18,0x69d8cb19,0x38690321}},	//   cim_, зем_, _eave, _ciar_,
   {{0xb3b1008b,0x62998a26,0x38690b1a,0x2ac34017}},	//   _झारख, nswo, _diar_, nībā_,
   {{0x9c7c8b1b,0x2c750065,0xdd92000f,0x20cb0b1c}},	//   _hrča, _båd_, طور_, ाबंध,
   {{0x7c244b1d,0x69c3cb1e,0x7bcd40cc,0x3869005e}},	//   tiir, _ibne, feau, _fiar_,
   {{0x7bdbcb1f,0x7bd9c09c,0x2fcdc022,0x2fd9429a}},	//   nduu, _jawu, neeg_, _casg_,
   {{0x7bd9cb20,0xdcf440ab,0x9c7c8077,0x7bc4001f}},	// [6a0] _mawu, đačk, _mrča, _ibiu,
   {{0xb5fb4b21,0x68e3cb22,0x2bc10b23,0x5fc10185}},	//   _suár, _krnd, ष्ठा, ष्ठल,
   {{0x2a7f8010,0x1bea4b24,0xa3e50048,0x69dc0b25}},	//   _atub_, _едни_, नाच_, mdre,
   {{0x601140d9,0xe7aecb26,0x2486402d,0x7cd38080}},	//   _påme, _टाइप, ďom_, _gərə,
   {{0x3f868b27,0x7bdbcb28,0x6b9649c7,0x69c3c04f}},	//   rbou_, dduu, mayg, _obne,
   {{0x7ae40b29,0x3f868b2a,0x52c0809d,0x6b964b2b}},	//   _mrit, sbou_, _एहीस, layg,
   {{0x7f498073,0xb4be0834,0x39e74466,0x44224ae0}},	//   _eyeq, _इहो_, _ядро_, _kmk_,
   {{0xd9434b2c,0x69d8cb2d,0x69c3cb2e,0xd467c1bd}},	//   _сеси, _save, _abne, није_,
   {{0x6d488b2f,0x442240f8,0x7bd9cb30,0x3eadcb31}},	//   _wyda, _mmk_, _dawu, guet_,
   {{0xb9068079,0xe3bf003c,0x69dc00a8,0x64428b32}},	//   _পথ_, diña_, jdre, looi,
   {{0x6440cb33,0x64464b34,0x91f1cb35,0x7ae2cb36}},	//   pomi, _okki, _अचरज_, _wrot,
   {{0x69dc0b37,0x7bd9cb38,0x4424cb39,0x6440c0c2}},	//   edre, _gawu, qim_, qomi,
   {{0x93fbc0c3,0xdcfac017,0x290ac04f,0x78bac011}},	//   _מלאי, tatē, šba_, sttv,
   {{0x24520b3a,0x2905c047,0x61fe0b3b,0x7cd38080}},	//   ráma_, byla_, _copl, _sərə,
   {{0x07e74b3c,0xc0c80b3d,0x27fdc0f8,0xba3b0016}},	//   нцам, нуте_, _yown_, duït,
   {{0xe3bf0004,0x80c201f9,0x69dc0b3e,0x657ac359}},	//   biña_, _लहरे, adre, lcth,
   {{0x4034404c,0x7b7441b4,0xb5fd8639,0xfe734b3f}},	// [6b0] уетс, اطفا, _mušr, ادر_,
   {{0x2fd941f4,0x2fcdc022,0x7bcf0b40,0x64464b41}},	//   _wasg_, zeeg_, lecu, _ekki,
   {{0x02b10b08,0xd4e44844,0xaefb41c0,0x629b823f}},	//   _जमुन, люци, _agùt, _svuo,
   {{0x38ba80fd,0x2d21408f,0x7bcf0b42,0x64428b43}},	//   dër_, _मधील_, necu, gooi,
   {{0x38ba82a4,0xa7fb4070,0x6abd0b44,0xed46c2cf}},	//   eër_, _niñi, ntsf, _چپ_,
   {{0x7c2603e2,0x2fcdcb45,0x644d4b46,0x60060344}},	//   zikr, weeg_, llai, _vómi,
   {{0x7bcf01c6,0x9c7c8077,0x8c3d00b5,0x200fc0f8}},	//   kecu, _prča, luğu, _plgi_,
   {{0xa2d5817e,0x6abbcb47,0x6abd02e9,0xddc980e5}},	//   _मैथ्, ttuf, ktsf, _utež,
   {{0xe3bf003c,0xb52145a8,0x6d4fc062,0x2fcdcb48}},	//   xiña_, _मधुप_, ęcam, reeg_,
   {{0x6abbcb49,0x85b88b4a,0x7bd9c0f7,0x69ad0a30}},	//   rtuf, _плус_, _wawu, _जागी,
   {{0x7ae40039,0x7bdb802f,0x6abbcb4b,0x38ba813b}},	//   _srit, _kauu, stuf, cër_,
   {{0x7bdb807a,0x6abd0b4c,0x69c50b4d,0x6d4ac02c}},	//   _jauu, ftsf, _abhe, _dyfa,
   {{0x6b89cb4e,0x644d4b4f,0x2bdac4fb,0x2019013b}},	//   mbeg, dlai, _मोटा, ëria_,
   {{0xf1c48281,0xbea2c1f0,0x7ae400fd,0x6015c02e}},	//   ल्पन, _ташк, _vrit, _bámg,
   {{0x6d4ac0de,0x3e76480d,0x3ea94b50,0x3f8940fa}},	//   _gyfa, _sæt_, erat_, fbau_,
   {{0x3f894b51,0x7bdb8871,0x386b4b52,0x76438b53}},	//   gbau_, _nauu, _cicr_, hony,
   {{0xe9da4b54,0x3ea94b55,0xba3b06ed,0x6d554b56}},	// [6c0] мка_, grat_, tuït, _azza,
   {{0x20000303,0x27ed813b,0x6aa9c181,0x600a48f1}},	//   _hoii_, _anen_, iref, _kýmk,
   {{0x44224197,0xa3b90428,0x940cc080,0x6aa9c32a}},	//   _tmk_, _चाम_, _evdə_, href,
   {{0x09cf402a,0x661d8007,0x62844b57,0xd83906f0}},	//   রাগা, _įska, ppio, trči_,
   {{0x3ea94b58,0x8c3d006a,0x644280bf,0x6d5541ae}},	//   crat_, cuğu, rooi, _ezza,
   {{0x7c22cb59,0x6aa9c02c,0x1dac4045,0xe5348b5a}},	//   _smor, dref, _चाटत, лель,
   {{0x6aa9c414,0xa7fb40b9,0x7c22c230,0x6443443e}},	//   eref, _siñi, _pmor, _ínic,
   {{0x34c28342,0xa3b64b5b,0x6b89cb5c,0x4fd4cb5d}},	//   _शहीद, च्च_, gbeg, ужит,
   {{0x44324b5e,0x20d3c119,0x44248b5f,0x0e66859d}},	//   iny_, _aţi_, _imm_, _акан,
   {{0x7bc28b60,0x2a6ac107,0x2bd4c027,0x69de4b61}},	//   lfou, öbb_, _दसवा, ndpe,
   {{0x26c90158,0x2d930004,0x291884f5,0x29078036}},	//   _spao_, _rexe_, _åra_, cyna_,
   {{0x0326cb62,0x27ff010d,0x7ac6cb63,0x657ac032}},	//   _иден, ðun_, _аске, scth,
   {{0xdcf5003f,0x25a10b64,0x40340b65,0x38bc4a2c}},	//   pazī, _pdhl_, реяс, hír_,
   {{0xc0aacb66,0x7bc64020,0xa3eac2ea,0x386b402c}},	//   _قابل_, _abku, माक_, _sicr_,
   {{0x69c50b67,0x6b84c0b2,0x6e270206,0x644d4b68}},	//   _vbhe, _õigs, rijb, tlai,
   {{0xdcfc406f,0xaca3025d,0xb5fc80f1,0x32114089}},	//   _nerđ, _ntụg, _diġi, _slzy_,
   {{0x26c90068,0x5a354b69,0x3b55431e,0x7d070036}},	// [6d0] _upao_, гнат, укар, syjs,
   {{0x25e28260,0x61ee4033,0x6e28c0e0,0x644d4b6a}},	//   _टोली_, _cnbl, nidb, slai,
   {{0x44324b6b,0x99674887,0xe3bf003c,0x644d40c3}},	//   bny_, ттал, niño_, plai,
   {{0x76438b6c,0xb8cb4b6d,0x69dc4b6e,0xafdb0240}},	//   wony, _खि_, _eare, mløs,
   {{0xceeb84e8,0x6282c04d,0xe5a58b6f,0x2a6c805e}},	//   بران_, _ntoo, гили, _bidb_,
   {{0xdce8803a,0x201e4017,0x629d0b70,0x3eaf8963}},	//   _addı, ītie_, isso, rugt_,
   {{0x5e580009,0x3f990b71,0x6ecf8185,0xafdb07fb}},	//   דיגע_, kasu_, _धनकु, nløs,
   {{0xa3eac342,0x8af7c435,0x27ed8b72,0x7643811c}},	//   माग_, _çəki, _unen_, sony,
   {{0xfe45c01b,0x985f0283,0xc245cb73,0x36d480d9}},	//   лнио, _eċċ_, лник, _котр,
   {{0xe8f9cb74,0x44324b75,0x63a2cb76,0x2d980b77}},	//   ело_, zny_, _edon, xare_,
   {{0xbef38b78,0xabb5cb79,0xaad8c707,0x6282cb7a}},	//   _आपुन_, _مماث, _बैठक, _etoo,
   {{0x66018047,0x3f990013,0xb8ebcb08,0x7cca8080}},	//   _holk, gasu_, _रङ_, _sərg,
   {{0x386d8b7b,0x69c1c0fa,0x2ee6cb7c,0x46a5cb7d}},	//   _mier_, pfle, _grof_, _салв,
   {{0xddcd0b7e,0x600600ae,0xee3f0066,0x386d8b7f}},	//   _etaž, _rómu, brým_, _lier_,
   {{0x8fa640d7,0x03a64b80,0x44324b81,0x26cb421b}},	//   лаве, ливо, tny_, _apco_,
   {{0x66018b82,0xdd4141ae,0x38bc4b83,0x200dcb84}},	//   _lolk, _eŋŋa, vír_, nkei_,
   {{0x7bdd4b85,0x6113c03a,0x6b9981c8,0x64460b86}},	// [6e0] _dasu, dələ, dawg, moki,
   {{0x4d164523,0x7bdd4b87,0x44248b88,0x2d98013b}},	//   льет, _easu, _smm_, qare_,
   {{0x7bc28b89,0x244e8066,0x200dcb8a,0xd00a80c5}},	//   tfou, lými_, kkei_, неже_,
   {{0x69dc4b8b,0x64460b8c,0x7c29cb8d,0x3cf10066}},	//   _ware, noki, jier, ňová_,
   {{0xc7a38b8e,0x3e798303,0x20024303,0x63a40349}},	//   сичк, _cèt_, _ioki_, _mdin,
   {{0x6446000b,0x6b9605d1,0x6449809c,0x7ae44240}},	//   hoki, _leyg, _ekei, mvit,
   {{0x2fddc046,0x7ae44b8f,0x6e28c13f,0x645b8b90}},	//   _bawg_, lvit, vidb, _fhui,
   {{0x244e805b,0xe3bf0250,0x7bdd4057,0x63a40b91}},	//   kými_, viño_, _xasu, _ndin,
   {{0x2245c36b,0x69c144eb,0x6d5a0166,0xf5b68b92}},	//   folk_, र्वी, ýtaj, _مصاد,
   {{0x32bb4009,0x290a0007,0x4086cb93,0x27e04051}},	//   עזיד, kyba_, лумб, hdin_,
   {{0x7f4d0056,0x44294b94,0xf1c6422d,0x3f99009d}},	//   _syaq, yia_, र्यन, tasu_,
   {{0xe8d78093,0xb4d4c045,0x63a2cb95,0x6ee6c182}},	//   _תואר_, _हनी_, _udon, _مستل,
   {{0xdddbc91c,0x63a401f4,0x69c88010,0x3ea00011}},	//   spuš, _ddin, _kbde, _cvit_,
   {{0xd576c051,0x3f9901c6,0x44e3806a,0xe3bf003c}},	//   _судь, sasu_, _yı_, piño_,
   {{0x3ea00b96,0x7cca8435,0x799acb97,0xdb0d41b4}},	//   _evit_, _hərb, matw, rgaí,
   {{0xafdb0240,0x64c70043,0x3a7501f6,0x2a6ec05e}},	//   rløs, jčiš, _клир, _hifb_,
   {{0x69c8806c,0x7bdf0157,0xdcfc0007,0x69de01ff}},	// [6f0] _obde, _iaqu, karė, _fape,
   {{0x799acb98,0x69de0b99,0x63a40011,0xafdb0b9a}},	//   natw, _gape, _zdin, pløs,
   {{0x3e7983bc,0x601381df,0x6113c03a,0x7ae44b9b}},	//   _sèt_, _açma, tələ, avit,
   {{0x442940fd,0x66018b9c,0x7ae44033,0x99644b9d}},	//   qia_, _solk, bvit, стул,
   {{0x2d940038,0x66018b9e,0x6113c03a,0x3ec44047}},	//   ždeň_, _polk, rələ, ěstí_,
   {{0x386d8206,0x867c0009,0x9f5f801e,0x68e34b9f}},	//   _wier_, ערוו, _joué_, ånds,
   {{0x3d0ec036,0x9f424051,0x8015cba0,0x6446078f}},	//   ानों_, _enkä_, ифиц, yoki,
   {{0x6b8d4ba1,0x673b8046,0x69c54ba2,0x645b8ba3}},	//   nbag, _txuj, lfhe, _uhui,
   {{0x6d4e4498,0x64460ba4,0xee39cba5,0x7af68051}},	//   _zyba, voki, кни_, äytt,
   {{0x27e0497c,0x6f1bc036,0x7625cba6,0x20c5c0d9}},	//   zdin_, rzuc, рмоз, айом,
   {{0x2fddc04d,0xd13181b4,0x22478085,0xa8a48748}},	//   _tawg_, _بما_, monk_, _грчк,
   {{0x244e8066,0xe36606b1,0x7bdf0ba7,0x504600b4}},	//   tými_, икни, _caqu, ремб,
   {{0x7d010041,0xc7d680c3,0x2ee9099e,0xe708cba8}},	//   älsn, בורי_, _craf_, _متون_,
   {{0x2fdf804d,0x6b9bcba9,0x1dd9c08f,0x290a0007}},	//   _laug_, laug, _बघित, tyba_,
   {{0x9103034a,0x8b96495c,0x442b0baa,0x7bdf0bab}},	//   опре, ирач, bic_, _faqu,
   {{0xe8e04015,0xb38640b4,0x3b864097,0x636bc06a}},	//   _hiệp_, рлал, рлаг, _gönü,
   {{0x27e004ff,0x2d9a4669,0x42264bac,0xd7074156}},	// [700] _iain_, tape_, адав, анте_,
   {{0x7bc980d2,0x6b9bcbad,0xac76001c,0x63b6415a}},	//   _abeu, haug, _پادش, sgyn,
   {{0x224783bc,0x799c0bae,0x3eadcbaf,0x7ae44bb0}},	//   donk_, marw, hret_, svit,
   {{0xdce1c676,0x6603c0f7,0x3eadc4ec,0x5c73411e}},	//   nalı, _lonk, kret_, іліт,
   {{0x245c8066,0x6b9bcbb1,0x2d9a4bb2,0x5fdf4045}},	//   jíme_, daug, pape_, _पोटल,
   {{0x799c0067,0x442b0bb3,0x30a68bb4,0x2cacc1f4}},	//   narw, zic_, арив, yrdd_,
   {{0xdce1c165,0x24590bb5,0x3eadcbb6,0x1dc644fb}},	//   kalı, héma_, eret_, र्णत,
   {{0x57f4cbb7,0x6015c531,0x3f804bb8,0x28a783a8}},	//   спит, _rámc, nciu_, _गिरि,
   {{0x799c0bb9,0xdefacbba,0xf1a7054a,0x442b0bbb}},	//   karw, тый_, _कएलन, vic_,
   {{0x9e06cbbc,0x4426c0a8,0x3ea04bbd,0x64a68bbe}},	//   рчил, _wmo_, isit_, _важа,
   {{0x397b8087,0x799c0067,0xe3bac457,0x3f804166}},	//   _סטאנ, darw, _абе_, kciu_,
   {{0xb8cec5da,0x2ee90119,0x6f1d0bbf,0x20dac2a3}},	//   _ओट_, _praf_, tzsc, všić_,
   {{0x787ec017,0xa3c94bc0,0x9c380bc1,0x20048bc2}},	//   _dīva, ल्फ_, рпят_, _momi_,
   {{0x44d800ce,0x9f594157,0x27e005ef,0x5d84c032}},	//   _bō_, _rosà_, _eain_, _الغل,
   {{0xe45300b8,0x691e8011,0x6e3dc107,0xdce1c165}},	//   _وضع_, _ušeć, ésbe, balı,
   {{0xdce1c189,0x20dac043,0x2ee90bc3,0x27e00bc4}},	//   calı, ršić_, _traf_, _gain_,
   {{0x2d9c8bc5,0x78758039,0x601841c0,0xdd9b4bc6}},	// [710] kave_, _išve, _bímb, вше_,
   {{0x80dac9af,0x27e00bc7,0x44290046,0x2ca74815}},	//   _बनाइ, _zain_, _hma_, ándo_,
   {{0x27e0009c,0xa3d6c045,0x69c54359,0xa3b6cbc8}},	//   _yain_, ाजा_, rfhe, जला_,
   {{0x1b058079,0x3f8040c4,0x24858bc9,0x200481ff}},	//   _শেষে_, cciu_, _rtlm_, _comi_,
   {{0x7648cbca,0x3f99402c,0x1708405f,0x66e5823d}},	//   kody, _iesu_, _پہلی_, сола,
   {{0x7c2b8bcb,0x7ae98bcc,0x14040048,0x3f994340}},	//   sigr, _vret, _लव्ह_, _hesu_,
   {{0x2d81405e,0x6b9d0bcd,0xdce1c1df,0x7c2b80c4}},	//   mche_, kasg, yalı, pigr,
   {{0x2d984044,0x6603cbce,0x29380093,0x69d50bcf}},	//   _zere_, _sonk, יאון_, heze,
   {{0x799c0067,0x6f0d4bd0,0x2d9843a6,0x6603cbd1}},	//   yarw, nyac, _yere_, _ponk,
   {{0x7c2d4bd2,0x2d984018,0x245c8166,0x3f9d8bd3}},	//   hiar, _xere_, ríme_, lawu_,
   {{0x245c8531,0xdce1c676,0x78b502bc,0x4c6a0bd4}},	//   síme_, talı, juzv, лион_,
   {{0x799c0067,0x6d40006a,0xc50c8052,0x3eadcbd5}},	//   warw, şmak, _שלאָ, pret_,
   {{0xdce38bd6,0x7bdac3bd,0x3954c038,0x5285c1b4}},	//   manı, _תקנו, _časť_, _التك,
   {{0x27e00bd7,0x61e18bd8,0xb7bdc119,0x50b60bd9}},	//   _wain_, _jall, diţi, йсбу,
   {{0x442dc68e,0x7c2d4bda,0x16d0408b,0x291ec036}},	//   oie_, fiar, हब्ब, czta_,
   {{0x38a3c03a,0x7c3b8bdb,0x93f6403a,0x600ec68a}},	//   mır_, _njur, _şəbə, _cùmh,
   {{0x7cca803a,0x60dc4010,0x7d034041,0x3f7ac009}},	// [720] _məra, _ssrm, änsn, אָבע,
   {{0xc301c079,0x3ea20bdc,0x66050303,0x61e18bdd}},	//   এনপি_, mskt_, _gohk, _nall,
   {{0xdce38bde,0x7c2d4bdf,0x386000c9,0xad5a4be0}},	//   kanı, biar, _khir_, урах_,
   {{0x6f0d4070,0x3f9941d6,0x61e18be1,0xad36c009}},	//   byac, _gesu_, _aall, זנעס_,
   {{0x9f49810d,0xdcfc003f,0x7aedc066,0x7e2a831e}},	//   ðað_, karī, _šatn, ліка_,
   {{0x7bcbc17b,0x7c3b8024,0xe3b242f0,0x9e7b0052}},	//   _abgu, _ejur, _برگ_, אנספ,
   {{0xdcfac03f,0x859b4093,0x7cca8080,0x291e40d9}},	//   ratī, _תשלו, _bəra, _åta_,
   {{0x2d9a0be2,0x5b14c051,0x6449c004,0x6e2e0be3}},	//   _lepe_, жмит, goei, hibb,
   {{0xc224801c,0xdcfac017,0x610ac080,0xe73a801d}},	//   _وکتو, patī, zəld, _сеа_,
   {{0x44290be4,0x61e18be5,0x1dd84a3c,0x7c298be6}},	//   _sma_, _gall, ड़ित, _zmer,
   {{0xa3c94191,0x6d5a8be7,0xa158cbe8,0xa3b6cbe9}},	//   ल्ड_, _uzta, рану_, _जाऊ_,
   {{0xc605408f,0x6015c107,0x6f0d4360,0x6aa28033}},	//   _शक्य_, _táma, yyac, osof,
   {{0x7ae20077,0xdb008047,0x6b9d0bea,0x1dd8417e}},	//   _šotr, _odmí, rasg, ड़ात,
   {{0x7f3bc052,0x2006cbeb,0x09e3c051,0xbb3bc052}},	//   _געדו, _hooi_, _ночн, _געדי,
   {{0x9c7c8011,0x6c850032,0xddc8c066,0x3f994134}},	//   _brči, تلزم, vodň, _pesu_,
   {{0x2d9ecbec,0x0855411e,0x50674660,0xb7bdc119}},	//   late_, іваю, стга, tiţi,
   {{0x6e2e0bed,0xd9dd402a,0x6d5c4bee,0x798200eb}},	// [730] bibb, ঠাসম, _azra, ọwad,
   {{0xdce38676,0x2d814bef,0x2d9ecbf0,0x6f0d40e2}},	//   zanı, uche_, nate_, ryac,
   {{0x4d7bc009,0xe4d54200,0x7cd947be,0xfcd54032}},	//   ארבע, تقاد, рмер_, تياج,
   {{0x4cbbc009,0x2006c14b,0x321840bb,0x64414018}},	//   רמאג, _nooi_, _elry_, élid,
   {{0xc9874bf1,0x61e18bf2,0x51874bf3,0x6d5c4053}},	//   _губи, _pall, _губа, _ezra,
   {{0xa3b6cbf4,0x853c8039,0x628d4bf5,0x2d830036}},	//   _जाउ_, _idėj, mpao, ncje_,
   {{0x600a4166,0x7c2980fd,0x38a3c080,0x6d4a4080}},	//   _týmt, _tmer, xır_, üfat,
   {{0x61e18bf6,0x44390bf7,0x6009cbf8,0xa685cbf9}},	//   _wall, jns_, рним_, олид,
   {{0x1dc64bfa,0x27ffcbfb,0x66074022,0xe619cbfc}},	//   र्वत, rjun_, _kojk, иди_,
   {{0xdce389d7,0x61e1868a,0x6b840bfd,0xf625c11b}},	//   sanı, _uall, _sfig, ідно,
   {{0x6b9b821b,0xbf9b401e,0x20e786f0,0xafdb4176}},	//   _keug, _poêl, _uđi_, _gjøg,
   {{0x2006c369,0x7e7b8bfe,0x644b8bff,0x799a83bc}},	//   _gooi_, _kuup, nogi, _zetw,
   {{0xa9a5cc00,0x2fcd8024,0x386000d2,0x6da5c92f}},	//   _дилд, _mbeg_, _vhir_, _дила,
   {{0x2d81c54a,0x442f8c01,0x66074077,0x7aed0c02}},	//   _ühe_, hig_, _nojk, _drat,
   {{0x7d0344d3,0x6b828100,0x7aed0c03,0x44390053}},	//   änsl, ycog, _erat, bns_,
   {{0x64470199,0x28dc8314,0x4439005e,0xdfd24032}},	//   čkic, _मनसि, cns_, بير_,
   {{0x3207cc04,0x628d4c05,0x245c8166,0x799e4c06}},	// [740] _kony_, gpao, jíma_, tapw,
   {{0x1816cc07,0x6d594020,0x8d56418d,0x442f8580}},	//   _तत्व_, ƙwal, отеч, eig_,
   {{0x628989e4,0xe7d9c027,0x6015c5e5,0xb4c7c54a}},	//   _ateo, ढ़ाप, _námo, _उहो_,
   {{0x46ea8c08,0x6d5e0c09,0x2d8580b4,0x7ae9cc0a}},	//   иден_, _izpa, _afle_, kvet,
   {{0x6aa2805c,0x6441401e,0x66da8051,0x658901cb}},	//   usof, élie, рьер_, _éphé,
   {{0xee378026,0x63a98c0b,0x3c3ac03f,0x61e3c274}},	//   онч_, _eden, tīvo_, _nanl,
   {{0x6d5c4c0c,0x644b8060,0x44390c0d,0x6aa28c0e}},	//   _uzra, bogi, yns_, ssof,
   {{0x799c4c0f,0x6b844c10,0x998980ab,0x26d200f8}},	//   _herw, ncig, đaš_, _opyo_,
   {{0x81cf8079,0xf1c34085,0xdb0400cb,0xdcfc4007}},	//   ষয়_, _feġġ_, _reiß, _perė,
   {{0x6b9b80cb,0x3207c060,0x63adc020,0x27e484a0}},	//   _zeug, _cony_, _ƴanc, _hamn_,
   {{0xb97b43bd,0x7ae9c23f,0x799c42a4,0x6d410283}},	//   יניי, avet, _merw, żlaz,
   {{0x81c2402a,0x3eb24c11,0x799c4c12,0xb4d68c13}},	//   ্যি_, kryt_, _lerw, िबी_,
   {{0x7336c05f,0x2ee00018,0x7ae9cc14,0x2eed8010}},	//   _برائ, _csif_, cvet, _xref_,
   {{0x60c54c15,0x7c2f0c16,0x27e68051,0x601cc01e}},	//   ythm, sicr, hdon_, _déme,
   {{0xdce5403a,0x644b8c17,0x3a2c8070,0x64b88045}},	//   yahı, yogi, _mmdp_, _इमोश,
   {{0x2280c3e2,0x799c499e,0x61e3c138,0x69ce4c18}},	//   _kòk_, _aerw, _zanl, _abbe,
   {{0x61e3c38a,0x69d884f5,0x442f8c19,0x27e68c1a}},	// [750] _yanl, keve, vig_, ddon_,
   {{0xd25140b8,0x628d4c1b,0x51f84589,0x2009035d}},	//   رنا_, rpao, оную_, _hoai_,
   {{0x799c4c1c,0x644b8c1d,0x59c40028,0x628985ef}},	//   _derw, togi, _लॉटर, _steo,
   {{0x69ca8098,0x245c8086,0x6015cc1e,0x442b4206}},	//   effe, tíma_, _rámo, _umc_,
   {{0x25aa40b3,0x7ccc403f,0x387cc077,0x3eb9009d}},	//   _fdbl_, vērš, _luvr_, nust_,
   {{0x38694c1f,0xab5b00fa,0x644b8c20,0x601cc396}},	//   lmar_, rfüh, sogi, _némb,
   {{0xab5b0600,0x4395899b,0x5ba78c21,0x644b8c22}},	//   sfüh, _навс, _мраз, pogi,
   {{0x7ae9c0fd,0x2eed8c23,0x2019cc24,0xfc400574}},	//   tvet, _tref_, ósi_, čík_,
   {{0x2be08048,0x6d46c06a,0x7bc9cc25,0xb6a3c35d}},	//   _नसता, şkal, rfeu, _giấ,
   {{0x80d20879,0x6015c05f,0x7e7d4c26,0x443f806f}},	//   হিত্, _támo, _musp, _hju_,
   {{0x81bd402a,0x610ac080,0x79854414,0x61ee80d2}},	//   _আসা_, vəlc, ichw, _óbla,
   {{0xe61f402d,0xb33b4080,0x7ae9c107,0xd3b8c0d9}},	//   _stôl_, _keçd, pvet, _душі_,
   {{0x3eb90c27,0x644d40fc,0x38694147,0xb77ac0c3}},	//   gust_, doai, dmar_, _האנש,
   {{0xfc3f434d,0x7afdcc28,0x2738835d,0xa50a00bd}},	//   _ají_, ästu, ẩng_, бега_,
   {{0xe3b201b4,0x99fac0c3,0x25a14098,0x8dfac0c3}},	//   _كرة_, _לפספ, dahl_, _להסת,
   {{0xa3cb06ff,0x201fcc29,0xafdb40b0,0x601cc0d2}},	//   र्द_, nhui_, _skør, _téme,
   {{0x93434156,0x6b844057,0x3eb90c2a,0x3f924340}},	// [760] енте, rcig, cust_, rbyu_,
   {{0x2d85cc2b,0x2d9cc004,0x7e7d4043,0x7c2d0036}},	//   ncle_, _xeve_, _dusp, _zmar,
   {{0x64414c2c,0xa3c9454a,0x6aa44c2d,0x7d7b00c3}},	//   élic, ल्ह_, ssif, _לניו,
   {{0x7c2d0c2e,0x69c1805e,0x38694018,0xdc3a850c}},	//   _xmar, _acle, cmar_, tçıs,
   {{0x1e83411e,0xa3dd009d,0x7e7d40d2,0x69d88c2f}},	//   _плям, ड़त_, _gusp, teve,
   {{0xf8b000df,0x69ca8c30,0x672442bc,0x69348c31}},	//   _जटाय, uffe, mzij, وکار,
   {{0x69ca80de,0x27e68c32,0xdb0284f2,0x80dac036}},	//   rffe, pdon_, rgoñ, _बनें,
   {{0x93a9849f,0xa3b6c103,0xebe38c33,0xef868c34}},	//   _واقف_, _जाओ_, _посп, _хлап,
   {{0x8c4381bc,0x764e0166,0xb2268c35,0xe29780cc}},	//   _чете, koby, _емал, _нат_,
   {{0x63a0c10d,0x7c42c077,0x3f868004,0x3f9dc02e}},	//   samn, _štrč, lcou_, _eewu_,
   {{0x61e5004f,0x443246e2,0x3ea688c7,0xdce3c138}},	//   _rahl, kiy_, lsot_, _benı,
   {{0x3f868c36,0x5ed6002a,0x2d9e8c37,0x43940c38}},	//   ncou_, দিনে, _hete_, наюс,
   {{0x67244c39,0xe81e009d,0xe66705f5,0x7bc2c0c7}},	//   jzij, _पतरा_, зтво, _icou,
   {{0x67244c3a,0x29e2c0f6,0xb33b001f,0x68fcc4c9}},	//   dzij, _bħaż_, gaça, ärds,
   {{0x644d4c3b,0xddde0107,0xdcfc4017,0x2b528062}},	//   toai, _cipő, _derī, żych_,
   {{0x2d9e8c3c,0xc2994768,0x9c7c8066,0xd3db0032}},	//   _lete_, жках_, _urču, _طبعا_,
   {{0x61e50c3d,0x25a14c3e,0x984ec080,0x644d4c3f}},	// [770] _tahl, tahl_, nğın_, roai,
   {{0x69dacc40,0x99674119,0x2d9e8c41,0xb33b001f}},	//   nete, птел, _nete_, caça,
   {{0xf48504e8,0x44204c42,0x442d8c43,0x78bac854}},	//   _تاخی, bhi_, _pme_, nutv,
   {{0x7e7d40b3,0x7ae2cc44,0xa3dd009d,0x69c8406a}},	//   _tusp, _osot, ड़ि_, _öden,
   {{0x601f00da,0x7cca8080,0x9f4480ce,0x1e84859d}},	//   _këmb, _dərm, _jamè_, елім,
   {{0x7e770085,0x41e44039,0x3f9dc01c,0x7bc2cc45}},	//   _jixp, _піса, _sewu_, _acou,
   {{0x63a28c46,0x27e6cc47,0xa4d4411b,0x7ae2cc48}},	//   baon, _baon_, _порі, _asot,
   {{0x63a2829a,0x61f8c0ce,0x3e640041,0x443f8c49}},	//   caon, _anvl, möte_, _uju_,
   {{0x27e94c4a,0x8ca98c4b,0xa2d585a8,0x660ac127}},	//   idan_, _टिको, _मैच्, _bofk,
   {{0xbebb00fd,0x7bc2cc4c,0xa3dd054a,0xf8a9c4df}},	//   tzën, _ecou, ड़ऽ_, овок_,
   {{0x6d450022,0xa3c8c028,0x186a0c4d,0x4d65c11b}},	//   _nxha, _लॉक_, жани_, ьков,
   {{0xe4d4805f,0x2d9e8570,0x44324573,0xf0924052}},	//   _ستمب, _zete_, xiy_, כנט_,
   {{0xe2970c4e,0x63ad01f4,0x69dacc4f,0xddc18007}},	//   мая_, _ddan, bete, _milž,
   {{0x0478c01c,0x63ad0c50,0xce6bcc21,0x9e64c0d9}},	//   _کليک_, _edan, _уред_, _звід,
   {{0x4252c05f,0x764e0c51,0x27e6c5bb,0x69cd00ba}},	//   _جنور, roby, _yaon_, द्धी,
   {{0xdb1b8250,0x63ad0c52,0x1dbdc758,0x442fcc53}},	//   _acuí, _gdan, ्भवत, _jmg_,
   {{0x6d450c54,0x7aed4c55,0xe5a6424e,0x67244097}},	// [780] _exha, gvat, дизи, uzij,
   {{0x63ad0c56,0xb21b07a4,0x60184c57,0x9f494086}},	//   _zdan, spær, _tímo, rjað_,
   {{0xa2a4009d,0x9f42c038,0xd9460819,0x661e021b}},	//   _कबड्, ľké_, _цени, _ilpk,
   {{0x2d9e8c58,0xf77f410b,0xdb1bc004,0xaca44112}},	//   _sete_, _taça_, agué, _nkụp,
   {{0xd6d08c59,0x3f868c5a,0x69dacc5b,0x6d5c8066}},	//   اقت_, rcou_, yete, _úraz,
   {{0xb21b4065,0x3eaf00b0,0xdce88166,0x69dac580}},	//   _stæv, _ægte_, _vedľ, xete,
   {{0x291d00e2,0xa3be0c5c,0x68e340b0,0xdce8c526}},	//   _ƙwai_, आला_, ændt, yadı,
   {{0x69c3cc5d,0xdb00cc5e,0x61e74107,0x44c80414}},	//   _acne, lamé, _zajl, iß_,
   {{0x7c228c5f,0xd6dac11b,0xc8ca801c,0xa1c68c60}},	//   mhor, іти_, _ژوئن_, _обад,
   {{0x27e94c61,0x6015c1b4,0x63ad0056,0x63a08300}},	//   zdan_, _lámh, _sdan, _hemn,
   {{0x7a204c62,0x7aed4812,0x7cca8435,0x26020c63}},	//   _göte, zvat, _mərk, शानी_,
   {{0x442fc157,0x27e94c64,0x320c8089,0x4de7025c}},	//   _gmg_, xdan_, _hody_, _छोड़े_,
   {{0x63a0806a,0x27e94c65,0xb917002e,0x44c800cb}},	//   _memn, vdan_, _fifọ_, eß_,
   {{0x9f594032,0x62808c66,0x63ad009c,0x81b0802a}},	//   _tosú_, _mumo, _wdan, ট্র_,
   {{0x3866c05c,0x200b4396,0x7c228c67,0x63a44c68}},	//   _khor_, _poci_, khor, fain,
   {{0xa3cb0945,0x63a084f5,0x5fc60045,0x91cac3a8}},	//   र्श_, _nemn, _वायल, त्रै,
   {{0x80a0008f,0x61fa8353,0x7c228c69,0x628d0150}},	// [790] गीबे, _ontl, dhor, _utao,
   {{0x27e94c6a,0xa3cb0c6b,0x7865c01d,0x7bdd0c6c}},	//   sdan_, र्र_, móve, lesu,
   {{0xdb1bc49a,0x61e74c6d,0x31c440c5,0x5c7542d5}},	//   rgué, _vajl, ъств, _плот,
   {{0x7c228c6e,0x62808c6f,0xb33b0018,0x61fa8c70}},	//   ghor, _bumo, naço, _antl,
   {{0x7ae40010,0xe2998c71,0x6abd0c72,0x244400b5}},	//   _xsit, чал_, nusf, nıma_,
   {{0x7bdd0c73,0x63a080a8,0xfc3f0c74,0x2ba74048}},	//   hesu, _eemn, hní_, गणका,
   {{0x38794077,0x7bdd0c75,0x3866c061,0x601ccc76}},	//   _kisr_, kesu, _bhor_, _séma,
   {{0x7d2444e8,0x7bdd0c77,0x3f894c78,0x2a7f8112}},	//   _شفقن, jesu, ncau_, _tuub_,
   {{0x3ea94c79,0xf771c54c,0x1dc64285,0x69c50c7a}},	//   nsat_, داث_, र्कत, _oche,
   {{0x63a08c7b,0x7bc40c7c,0x7e78c053,0x6d58cc7d}},	//   _zemn, _sciu, _civp, _byva,
   {{0x62808070,0x69c48c7e,0x81bc803f,0x82348032}},	//   _zumo, _राती, _slēg, _شركا,
   {{0xdb040004,0x69dc0c7f,0x7bdd0c80,0x628f4c81}},	//   _adiá, were, gesu, _otco,
   {{0x9f9d010d,0x7d188166,0x6e350c82,0x4b5505f5}},	//   ræði_, časť, fizb, върт,
   {{0x20190051,0x22844c83,0x7c228c84,0x25aec303}},	//   aksi_, _rök_, zhor, _gdfl_,
   {{0x63a448a8,0x15430c85,0x81c8c079,0x321802a4}},	//   tain, герм, _লোক_, rkry_,
   {{0xd0074c86,0x3c3ac03f,0xb90805a8,0x645bcc87}},	//   несе_, tīvi_, _यन_, nlui,
   {{0xb90704d0,0x671fc281,0x443fcc88,0x7ae40c89}},	// [7a0] _मै_, यनिक_, inu_, _usit,
   {{0x4420024c,0x25a5c92c,0x386dc0fa,0xfde74c8a}},	//   _hli_, nall_, hmer_, ндук_,
   {{0x62808c8b,0x6b9645e7,0x7c228093,0x320c8061}},	//   _sumo, pbyg, thor, _rody_,
   {{0x59cfcc8c,0x6444017b,0x81c2402a,0x7dd38080}},	//   त्तर, _jjii, ্যই_, hısı,
   {{0x61e88c8d,0x386dc99e,0x25a5cc8e,0xddcf40a0}},	//   _padl, dmer_, kall_, řeše,
   {{0xfc3f0185,0x7d0ec065,0x386dc166,0x25a5cc8f}},	//   zní_, øbsk, emer_, jall_,
   {{0xf1d20617,0x63a08c90,0x291a8c91,0xeb9a801b}},	//   द्यन, _temn, ápa_, _нив_,
   {{0xaa0d0185,0x61e88c92,0x81d40079,0xd5c2c036}},	//   _सक्छ_, _wadl, _সোম_, _शाहज,
   {{0x6aa9cbdc,0x09bf802a,0xf7438c93,0x7bdd0c94}},	//   gsef, _ইসরা, _бето, vesu,
   {{0xf3ff400c,0x69de4c95,0x660e4329,0x7cca8561}},	//   _nhãn_, nepe, _jobk, _ləri,
   {{0xa3dd0834,0x7bdd0c96,0x3a3740c3,0x610ac080}},	//   ड़ल_, tesu, תרים_, cəll,
   {{0x6abd00b2,0x7cca8080,0x44320c97,0x25fe8063}},	//   tusf, _nəri, _cmy_, लावी_,
   {{0xee3f4185,0x44200061,0xe29800d7,0x601cc1cb}},	//   _svým_, _dli_, наў_, _hémo,
   {{0x9325c107,0x7e7d8c98,0xdb02c10b,0x3edf00eb}},	//   _جرمن, _èspe, _adoç, _nwụọ_,
   {{0x7bdd0c99,0x63a60c9a,0x248d4043,0x378e4112}},	//   pesu, bakn, _čemo_, _ọgọ_,
   {{0xb4e1007c,0x7bdd013b,0x7cca8080,0xa6f50119}},	//   _धनी_, qesu, _cəri, _азиш,
   {{0x610ac080,0xaae70032,0x9f400580,0xc87f4526}},	// [7b0] zəll, _أسبو, _gaià_, ışma_,
   {{0x3ea94c9b,0x200d8033,0x386dcc9c,0x6ca74187}},	//   rsat_, _soei_, zmer_, ердж,
   {{0x6ad9808f,0xd5b84026,0xdb0080fd,0x81e9802a}},	//   णब्र, эст_, _femë, যাম_,
   {{0x9f5fc10d,0x6015c004,0xa3bb4389,0x3869009c}},	//   kkuð_, _támi, _घाट_, _jhar_,
   {{0x66e58c9d,0x7dd383a6,0x6448401e,0x69de44e1}},	//   тола, yısı, édie, bepe,
   {{0x7bdf4c9e,0xde948032,0x6d5a8c9f,0x7cca8080}},	//   lequ, اجنب, _byta, _zəri,
   {{0x24590066,0x386901a8,0x6e20013b,0x64470123}},	//   lému_, _ohar_, ëmbi, čkij,
   {{0x7cca8080,0xcec18062,0x7ae28ca0,0x660e40e5}},	//   _xəri, _pięć_, bwot, _zobk,
   {{0x3a758ca1,0xdb0d0019,0x1db10ca2,0xa3e68048}},	//   _алар, _ocañ, _जयंत, _बघत_,
   {{0x69c1cca3,0x6b89c23f,0x7bdf4ca4,0xee36c026}},	//   ugle, sceg, hequ, кны_,
   {{0x7dd381df,0x38690755,0x25a5cca5,0x6ea405da}},	//   rısı, _bhar_, rall_, _कबहु,
   {{0x7e7a80a8,0x69de4ca6,0x09ca0ca7,0x69c380b2}},	//   _zitp, zepe, िभ्य, lgne,
   {{0xdb064089,0x38690ca8,0x69c24047,0x63a60ca9}},	//   _odká, _dhar_, _लाली, rakn,
   {{0x3cfe4018,0x44e1c007,0xdb008caa,0x200fccab}},	//   _átvg_, _tų_, _demè, _hogi_,
   {{0xf3ff401d,0x2731800c,0x44200cac,0x200fccad}},	//   _chão_, ạnh_, _tli_, _kogi_,
   {{0x26cdc2d8,0x200fc05f,0x44320033,0x68434cae}},	//   oteo_, _jogi_, _umy_, анса,
   {{0x25a3406f,0x7bd6000d,0x200fc01f,0x4de5c39a}},	// [7c0] _bejl_, _ibyu, _mogi_, _कसाई_,
   {{0xdb1d4018,0x61eac057,0xdb04001f,0x42234ac3}},	//   _absó, _xafl, _adiç, адув,
   {{0x62840caf,0x61fe0cb0,0x48dd854a,0x27edccb1}},	//   _huio, _inpl, _कईगो_, kden_,
   {{0x6d5a8007,0x6284012c,0xe73a81d5,0x3d0e054a}},	//   _ryta, _kuio, мее_, सहीं_,
   {{0x25a349ca,0x27e04cb2,0x6272c064,0x7ad481b4}},	//   _fejl_, mein_, _głow, اقتص,
   {{0xdb04001b,0x27edccb3,0x63a2ccb4,0x7ae4443a}},	//   _ediç, eden_, _seon, mwit,
   {{0x29180cb5,0x64a3423d,0x7a204041,0x7bd600f8}},	//   nyra_, _васа, _göta, _obyu,
   {{0x200fc070,0xaca400eb,0x27e04cb6,0xaab20048}},	//   _cogi_, _nhọt, nein_, _जिंक,
   {{0x629643bc,0xa3bb409d,0x1dcf44fb,0x28ae817e}},	//   npyo, _घाघ_, स्वत, _टिकि,
   {{0xdb008cb7,0xae054617,0x49ba8973,0x27e04cb8}},	//   _remè, रायन_, _زائد_, hein_,
   {{0x332940f6,0x21bb4093,0x386900f8,0x55bb40c3}},	//   zzax_, וזיא, _phar_, ומיו,
   {{0xd6d2c684,0xe7b4809d,0x3ebfccb9,0x63a40cba}},	//   _نقص_, ुलिप, buut_, _cein,
   {{0x3fcbc49b,0x26cdc004,0xf11b0cbb,0x81cb002a}},	//   _آدمی_, cteo_, नन्द_, _রোগ_,
   {{0x752dc0a0,0xe717c0c3,0x7bc440b2,0x7af60cbc}},	//   _řaze, _בחדר_, egiu, _dryt,
   {{0x55580623,0x03c745dd,0xc27bc087,0x4a7bc3bd}},	//   варя_, ксам, _קרוי, _קרוב,
   {{0x6b8080f8,0x27e04cbd,0xe3c9c018,0xa177c0c3}},	//   _ngmg, gein_, mañá_, _בעוד_,
   {{0x245c8066,0x1dcfc0e9,0x7af60383,0x6d5c4cbe}},	// [7d0] cími_, त्वत, _gryt, _ayra,
   {{0x9f448315,0x63a400fc,0x2ee90cbf,0xcfebc079}},	//   _camí_, _zein, _isaf_, কায়_,
   {{0x2d810cc0,0x44224303,0xd7b708b8,0x64484cc1}},	//   _ighe_, _flk_, _अयाच, édic,
   {{0xbde5c031,0x6442801e,0xc86481f0,0x3ea00053}},	//   _abẹ̀, gnoi, атчи, _ywit_,
   {{0x7cca8080,0x6746402d,0xab5b0cc2,0x8c168032}},	//   _məru, čujú, zgün, طيور_,
   {{0x6d5c44cf,0x26368036,0x7875c007,0x65c58466}},	//   _fyra, słon_, _išvi, убка,
   {{0x200fc340,0x4426800b,0xdb1bccc3,0x4879ccc4}},	//   _pogi_, bho_, rguí, нсия_,
   {{0x63ad810d,0x26cdccc5,0x317c0093,0x32cbc11b}},	//   ðand, tteo_, ורומ, tøy_,
   {{0x9f424cc6,0x6d5c413b,0x19958119,0x69ca4c13}},	//   _kaká_, _zyra, _базя, स्की,
   {{0xf9938005,0x27edccc7,0x7ae98cc8,0x7bd60033}},	//   _ضبط_, sden_, _iset, _sbyu,
   {{0x7c22ccc9,0x9ad3c0eb,0x2ee90cca,0x76438033}},	//   _flor, _gịnw, _asaf_, mnny,
   {{0x6aad4ccb,0x24858157,0xf5ec009d,0x7c22cccc}},	//   ksaf, _iulm_, _छोड़ि_, _glor,
   {{0x6b9bcccd,0xdcee02d6,0x76438cce,0x6459c1c6}},	//   mbug, vabı, onny, _ikwi,
   {{0x20f34011,0x3d28001c,0x7ae9812c,0x6b9bc02f}},	//   _oći_, نتزی_, _mset, lbug,
   {{0x70d24a3c,0x2ee900eb,0x28c6884d,0x44268066}},	//   _सहेल, _esaf_, रूपि, yho_,
   {{0x69c54ccf,0x7d1cc36b,0x7afb44f9,0x2d810044}},	//   eghe, ørse, _šuta, _eghe_,
   {{0xdb060534,0x7ae980eb,0x386b40b6,0x27e04cd0}},	// [7e0] kaké, _nset, _dhcr_, rein_,
   {{0x26c20cd1,0x7ae44cd2,0x869b0052,0x7cca803a}},	//   muko_, rwit, _רייז, _zəru,
   {{0x60c1ccd3,0x26c20cd4,0xd4168026,0xe3ba8cd5}},	//   nulm, luko_, льды, ебе_,
   {{0xc1780039,0x249741aa,0x44268047,0x44224cd6}},	//   žės_, انند_, uho_, _ulk_,
   {{0xdb00ccd7,0x26c20cd8,0x1b17802a,0x7e7c4cd9}},	//   tamí, nuko_, _দেবে_, _tirp,
   {{0x25a58cda,0x6459c1c6,0x60c1ccdb,0x628640f8}},	//   _cell_, _akwi, kulm, _iuko,
   {{0x26c2043a,0x7c22ccdc,0x83fdc05f,0x216740c4}},	//   huko_, _plor, klőd, _бири_,
   {{0x6d5e0cdd,0x3a3a4cde,0x4422c05f,0x7e7e0cdf}},	//   _mypa, lipp_, ók_, _lipp,
   {{0x57468ce0,0x81e74079,0x610ac03a,0xe3afcce1}},	//   _снаб, ভার_, məli, سري_,
   {{0x6459cce2,0xf1c6c185,0x26c20ce3,0x20000119}},	//   _ekwi, _část_, duko_, _anii_,
   {{0x32574093,0x7c24005e,0x38604ce4,0x6abbc12c}},	//   רסים_, _blir, klir_, aruf,
   {{0x2fc6871c,0x7c22c75d,0x25a58ce5,0x69c54379}},	//   ngog_, _ulor, _zell_, zghe,
   {{0x64444149,0x69c540b0,0x26c20ce6,0x6b82cce7}},	//   dnii, yghe, guko_, _igog,
   {{0x6594cce8,0x7e6dc0c4,0x63a640b9,0x9f448ce9}},	//   _таку, _èapp, _aekn, _mamà_,
   {{0x555900c5,0x76550cea,0x23b8c09d,0x43950ceb}},	//   тавя_, rozy, _इयाद, _кайс,
   {{0x201206df,0x43954097,0x26c205bc,0x2ee900e2}},	//   _goyi_, раас, buko_, _tsaf_,
   {{0x76550064,0x6b82c150,0x62864cec,0x6448401e}},	// [7f0] pozy, _mgog, _cuko, édia,
   {{0x6aad4ced,0x62864cee,0xbb3bc009,0x64444cef}},	//   rsaf, _duko, געמי, anii,
   {{0xddc88077,0x99674ce0,0x32114047,0x2012009c}},	//   _bidž, утал, _vozy_, _yoyi_,
   {{0x67d58cf0,0x6abd005c,0x6b82ccf1,0x3e6bc0d9}},	//   роду, orsf, _ngog, møte_,
   {{0x44294cf2,0x25a58499,0xb33b403a,0x60c1ccf3}},	//   mha_, _pell_, _keçm, zulm,
   {{0x4424803a,0x443b4cf4,0x6b82ccf5,0x48b58525}},	//   _elm_, liq_, _agog, ащит,
   {{0x25a58cf6,0xe8080185,0x4429409c,0x63a9ccf7}},	//   _vell_, षामा_, oha_, taen,
   {{0xc88881b4,0x26c20cf8,0xa802c2d6,0x2a7e80fc}},	//   دخول_, yuko_, şınm, _eitb_,
   {{0xd347c01c,0x7ae98cf9,0x672d4cfa,0x3f8dccfb}},	//   دیشه_, _uset, nzaj, rceu_,
   {{0x7c36069a,0x8539c09c,0x69c700fd,0x6b9bc71c}},	//   _smyr, _haɗɗ, jgje, sbug,
   {{0x9f42c166,0xcb0903bd,0xeb9a0cfc,0x27e200b3}},	//   ľká_, _קל_, кин_, tekn_,
   {{0x44294cfd,0x6459c00d,0x25a0c077,0x67fb0051}},	//   jha_, _ukwi, _đile_, _räjä,
   {{0xd90fc0fb,0xde05c11b,0x7afb4cfe,0x59da8028}},	//   تیں_, _впли, _šutn, _मॉडर,
   {{0x387f8cff,0x6da30d00,0x99830007,0x7cca8080}},	//   _liur_, жира, dijų_, _tərt,
   {{0x6286c05b,0x63a64d01,0x443b4d02,0x61ee4d03}},	//   íkov, _pekn, fiq_, _rabl,
   {{0x6d5e0d04,0x26c20150,0x7c29cd05,0xdb0b8086}},	//   _vypa, puko_, nher, yggð,

   {{0x66e60d06,0x81c14079,0xb0690301,0x6444409d}},	// [800] _топа, ্জন_, _حصول_, rnii,
   {{0x61ee4d07,0x386d8033,0x3c3f4051,0x3ead0283}},	//   _qabl, _aher_, tävä_, ġett_,
   {{0x38604016,0x443b4080,0x78a240b3,0xdcfc40f6}},	//   plir_, biq_, ćovo, _berġ,
   {{0xeaa7c032,0x6aa40d08,0x41d206fc,0xb4e64185}},	//   _وع_, _kwif, द्रस, _भनी_,
   {{0x64460d09,0x8539c09c,0xe809c814,0x44248011}},	//   inki, _daɗɗ, वाना_, _vlm_,
   {{0x7bd9cd0a,0xfaa345f5,0xca5686b1,0x3ceb4025}},	//   _abwu, _фаро, штењ, äivä_,
   {{0x68ed8036,0x6b840d0b,0xa491401c,0x69ce0314}},	//   ładn, _ogig, _فیلت, _तानी,
   {{0x6a6b40cb,0xf09300c3,0x247ec112,0x691e01d6}},	//   rüfe, חנה_, _ọmba_, _iħeġ,
   {{0xfa88c35d,0x29050d0c,0x7af9c2cd,0x62804396}},	//   _bừa_, ̣la_, _crwt, _émos,
   {{0x60de011b,0x3eb8c06c,0x2480005e,0x7afd810d}},	//   _oppm, črt_, _aiim_, _ásta,
   {{0x7416c01c,0x443b4080,0x7a24c061,0x752dc020}},	//   _پوشا, yiq_, _còta, _ƙaza,
   {{0x7c3bc119,0xdb5ac051,0xeb9acd0d,0x76588d0e}},	//   ciur, _июл_, _рид_, lovy,
   {{0x81ac4079,0x5e94c1b4,0x3294c1b4,0x6e3ac5bb}},	//   _গান_, _التط, _التأ, pitb,
   {{0x20c9408f,0x7c2640bb,0x25a7c14b,0x6356c1c0}},	//   ांमध, _alkr, _genl_, _e̟nì,
   {{0x44204d0f,0x2ba7420f,0x5fd78444,0x443b4d10}},	//   fki_, ијав, ण्डल, tiq_,
   {{0x44204498,0x63b60d11,0xd0420080,0x69c8cd12}},	//   gki_, _gdyn, ktlə, lgde,
   {{0xa3cc0d13,0xf773c009,0x7c3d0d14,0x2d83434d}},	// [810] _लात_, ַקע_, misr, _pgje_,
   {{0x6015cd15,0x601cc01e,0xc7b1005f,0x7c3bc007}},	//   _lámp, _démi, _بڑھ_, ziur,
   {{0x672d4036,0xfb87410e,0x4426cd16,0x63b601f4}},	//   szaj, _выгн, _olo_, _ydyn,
   {{0x059601aa,0x1dc9808f,0x442940f1,0x26c4cd17}},	//   _پایگ, _राहत, qha_, kumo_,
   {{0xc2938646,0x7c3bc016,0x68fa8d18,0x6eaa02f6}},	//   زیاب, viur, _artd, जीपु,
   {{0x7c3d0010,0xa802c0b5,0x8539c09c,0x9ce7405f}},	//   hisr, şılm, _waɗɗ, _پورے_,
   {{0x81e98079,0x44394d19,0x3d20c027,0x61e5400b}},	//   যাল_, _kms_, मनों_, mehl,
   {{0x13aa84fc,0x26c4cd1a,0x1dc98617,0x61e54d1b}},	//   _منفی_, fumo_, _रावत, lehl,
   {{0x645d4033,0x64598036,0x61e38d1c,0xdb00cc24}},	//   _mksi, mowi, penl, tamá,
   {{0x69c8c300,0x7a24c3bc,0x63a9884b,0x8e09c1fa}},	//   ggde, _pòta, _heen, унов_,
   {{0x44204d1d,0x7cca803a,0x2496c1aa,0x6d400189}},	//   yki_, _fərq, ینید_, şmaz,
   {{0x7aed00f6,0x6a25c01c,0xdee60d1e,0x44394176}},	//   _bsat, _گفتم, боми, _nms_,
   {{0xd00ecd1f,0x734900b4,0x9f0bc032,0x2bcb4d20}},	//   _سلو_, ачёв_, _جزاك_, िलना,
   {{0x69ddc107,0x7afb88c3,0x7c3d026b,0x2374c1af}},	//   őseb, _mrut, aisr, ňajú_,
   {{0x6fc10048,0xfa34c1aa,0x601ccd21,0x50dbcd22}},	//   _वाचू, _برند, _sémi, _बहिष,
   {{0xdb06005f,0xa3ba08a7,0x44204d23,0x3f808007}},	//   lakí, _صابر_, uki_, žiui_,
   {{0x61e540fa,0xc0530093,0x7afb8112,0x44f740f6}},	// [820] fehl, _מזה_, _nrut, _aħ_,
   {{0xdcfc4d24,0xd0f985a3,0x81e9802a,0x601845ca}},	//   _agrā, ्माण_, যাঁ_, _címr,
   {{0xe8048048,0x2e3ac009,0xd23ac052,0x7bdb80bb}},	//   ळाला_, נגענ, נגעל, _bbuu,
   {{0x443d8d25,0x20f80011,0x44220d26,0x26c4c006}},	//   giw_, _iči_, nkk_, yumo_,
   {{0xdb008344,0x92f6411b,0x69c8cd27,0x4426c011}},	//   _temí, _учні, ygde, _rlo_,
   {{0x765c4d28,0xe4a68d29,0x62818d2a,0x644bc0d2}},	//   _ukry, брио, _cilo, _ajgi,
   {{0x6f1d0036,0x44394051,0x44f7417a,0x26c04157}},	//   zysc, _yms_, _għ_, lrio_,
   {{0x3ebfc17a,0xf2e881aa,0x26c4cd2b,0x26004285}},	//   frut_, _نکته_, tumo_, राकी_,
   {{0x7a2044c9,0xaadc809d,0x9c7cc053,0xf1cf40a0}},	//   _nötk, _यहिक, _osčv, स्कन,
   {{0x63ad41ae,0xba238d2c,0x20f7c0b4,0x9e06c0b4}},	//   zaan, _едук, _băi_, счил,
   {{0x63a98d2d,0x865b42a6,0x8afd8047,0xba3d80a0}},	//   _yeen, רדיי, _vyře, _tvůr,
   {{0x2d910064,0x4420c00c,0x69d84d2e,0x6362c112}},	//   wcze_, _ôi_, न्ती, _ọnun,
   {{0xe043c025,0xa805c019,0xdcfc41d6,0x628180f7}},	//   _энци, señá, _ferħ, _yilo,
   {{0x69ca8d2f,0x659400c5,0x7c228402,0xf1c747c7}},	//   ngfe, зару, hkor, _लाइन,
   {{0x2019c0c4,0x9f5dc171,0x765acd30,0xceb40080}},	//   _ègià_, _fowó_, moty, _evə_,
   {{0x44f880d1,0x44394060,0xef994271,0x27f20d31}},	//   _mĩ_, _qms_, ркаш_, _gayn_,
   {{0x52154d32,0x4439409d,0x69dc4085,0x98aa0017}},	// [830] одат, _vms_, _bbre, ākās_,
   {{0xfc3f0066,0x8cbfc1f9,0xf1a70bfc,0x3e6f40b2}},	//   lií_, लूको, _урин, küte_,
   {{0x442902a4,0x7c2b80f6,0xdb160053,0x628181d9}},	//   _kla_, thgr, _adyè, _rilo,
   {{0x60c54056,0x44394d33,0x7aee4051,0x61e70d34}},	//   ruhm, _ums_, äntä, lejl,
   {{0x63a98d35,0x6e95416d,0xdcf50189,0x443b0157}},	//   _veen, _фигу, mazı, _mmq_,
   {{0x2c4cc047,0x786a8066,0x44290d36,0x6e944d37}},	//   věda_, rýva, _lla_, _хиру,
   {{0xec6b8b8e,0x4422011b,0x63a98d38,0x7a2b00cb}},	//   _брак_, ykk_, _teen, _güte,
   {{0x7ae9cd39,0x44f8800c,0xaca30112,0x291ec007}},	//   twet, _dĩ_, _ntọg, dyta_,
   {{0xdb1d0095,0xfc3f0347,0x20d1c070,0x63b480a0}},	//   ngsä, dií_, wái_, řený,
   {{0xfe42c11b,0x765acd3a,0x44220033,0x9f4b40e1}},	//   дньо, goty, wkk_, _nací_,
   {{0x67d5c761,0xfc3f005b,0xf9888032,0x7ae9cd3b}},	//   _можу, fií_, _انمي_, swet,
   {{0xfc3f0066,0x60c70011,0x44220033,0x7c3b817a}},	//   gií_, dujm, ukk_, _jmur,
   {{0x6449cd3c,0xb6a3023f,0x61e70107,0x25fe8048}},	//   mnei, миял, fejl, लाची_,
   {{0x7bcf4d3d,0x27f20057,0x7c228d3e,0xdb0b801e}},	//   _accu, _wayn_, zkor, gagé,
   {{0x186a002b,0x64958085,0x25eec048,0x7c228d3f}},	//   _каки_, _fġie, _असती_, ykor,
   {{0x6283cd40,0xb46649b1,0x628bcd41,0xccf28093}},	//   _hino, ікал, _kugo, וכל_,
   {{0xfe0546ff,0x38600303,0x6a704d42,0xe889c35d}},	// [840] रांस_, _ikir_, häfe, _kẻo_,
   {{0x26c04d43,0xa3dc8891,0x55e34d44,0x6283c047}},	//   rrio_, त्न_, моуб, _jino,
   {{0x765c0d45,0xae038d46,0x78a74022,0xd46a4441}},	//   mory, लाईन_, _cwjv, _вине_,
   {{0x7c2d4d47,0x228f02d6,0x6299c036,0x645bc01e}},	//   char, _yük_, _otwo, joui,
   {{0xdd94823d,0x27e68d48,0x43764d49,0x645bcd4a}},	//   палы, reon_, _фунт, doui,
   {{0x236d8077,0x27e68d4b,0xdb044018,0xfa674d4c}},	//   _dzej_, seon_, caiá, _маяк_,
   {{0x69ca8d4d,0xc27b00c3,0x628bc017,0xceb44080}},	//   rgfe, ברסי, _augo, lsə_,
   {{0x2900c0d7,0x765c0d4e,0x6283c04c,0x628bcd4f}},	//   _čia_, hory, _aino, _bugo,
   {{0x11d6831e,0xceb44080,0xaa4680b4,0xa2b24d50}},	//   _міжр, nsə_, _деал, ेंट्,
   {{0x601cc01e,0x9f424d51,0x38600231,0x7afb4043}},	//   _rému, _bakú_, _akir_, _šutk,
   {{0x9354c0fb,0x442dcd52,0x59cf44e3,0x1958c39d}},	//   _کراچ, bhe_, स्टर, саны_,
   {{0xe3b2c08c,0x6449c357,0x25ba0011,0x8c14c079}},	//   _آرا_, cnei, _adpl_, ়োজন_,
   {{0x249a007a,0x81b6c079,0x4424c033,0x765c0d53}},	//   _atpm_, ঙ্গ_, mkm_, fory,
   {{0x09b4c02a,0x8546c0b4,0xddda8053,0x8ccb4062}},	//   জ্জা, _мэйе, _oktō, _हमलो,
   {{0x7afd4089,0xfc3f0089,0xdb0b81cb,0x56378052}},	//   _srst, pií_, ragé, קאלע_,
   {{0x6f0d4016,0x25a60013,0x60c8c02f,0x248480cb}},	//   txac, _đole_, mudm, _nimm_,
   {{0x26020c4b,0x8d870d54,0xdcf50696,0x63ad0061}},	// [850] शाखी_, _мунд, razı, _iean,
   {{0x442dc0fd,0x6280423f,0x69dac0cb,0x6449c0cb}},	//   zhe_, _èmol, nfte, znei,
   {{0x60184004,0x83988112,0xa5c48036,0x6449c051}},	//   _tímp, _ịhụg, _राजौ, ynei,
   {{0x155a0093,0x7afd4487,0x68ed8036,0x61e8c010}},	//   _לכתב, _trst, ładk, hedl,
   {{0x06fb0c63,0x62850d55,0xdb008018,0x1b1d0079}},	//   एटिव_, _kiho, _pemá, _পেতে_,
   {{0xa3e201e7,0x7e794009,0x6618c41b,0x6565809d}},	//   _नॉन_, _לאָז, _novk, ühho,
   {{0x7aed4d56,0x20194d57,0x6283cd58,0x6299c036}},	//   lwat, _kosi_, _rino, _stwo,
   {{0x63ad0d59,0x7c298232,0xe6c4c0ab,0x7bcd4d5a}},	//   _nean, _uler, _žešć, ngau,
   {{0xd706c04c,0xf77f010b,0x26004a1b,0x9c13c0eb}},	//   зные_, deço_, राची_, _lọgh,
   {{0xdb008065,0x80e10079,0x63abcd5b,0x629b8340}},	//   _bemæ, _পছন্, _wegn, _ituo,
   {{0x3ea90d5c,0x443fcd5d,0x24848033,0x6fcb4048}},	//   _awat_, piu_, _yimm_, िलां,
   {{0x7c2dc05b,0x3ea903bc,0xfaff40da,0xdee60896}},	//   ďars, _bwat_, _orë_, поми,
   {{0x62850d5e,0x644b8d5f,0x6299c036,0x59d28a89}},	//   _biho, ingi, _utwo, _सामर,
   {{0x3ea903bc,0xe8028027,0xa6e3010d,0x2d874166}},	//   _dwat_, _रोना_, óðar, žnej_,
   {{0xa3bc8d60,0x20194d61,0x2bd40185,0x6e2040cc}},	//   _आयल_, _bosi_, _थापा, _îmbi,
   {{0x3ebf060f,0xa3ad0d62,0x63bb8d63,0x0446499b}},	//   šuta_, गरण_, _ndun, чебн,
   {{0xa2c34028,0x6fad43fc,0x38668041,0x27e006df}},	// [860] िंग्, _ज़रू, vlor_, _ibin_,
   {{0x4efb0052,0xa3ce43ae,0x6b898d64,0x27044036}},	//   _פליג, _राव_, _ageg, रमौर_,
   {{0xa3aecd65,0x69c34019,0xfaff413b,0x2bfd80b2}},	//   करम_, ónea, _erë_, _रोहू_,
   {{0x644b8d66,0x6aa9840d,0x59c98314,0x62850d67}},	//   gngi, _bwef, _राउर, _ziho,
   {{0x9f5201c0,0x62850d68,0xdb0bc13b,0xab838523}},	//   _bayé_, _yiho, _degë, нушк,
   {{0xa8a68a2f,0x7ae40d69,0xfec3c079,0x30a686b1}},	//   прик, _mpit, ্বাধ, прив,
   {{0x6440cd6a,0xb8668d6b,0xe6a90d6c,0x03a687e3}},	//   timi, _فارو, _कब्ज, _ниво,
   {{0x289b02a6,0x81e98079,0x92c183a6,0xb60341b7}},	//   זיקא, যাগ_, üğün, ġġet,
   {{0x44268d6d,0xb8d38b08,0x6aa980de,0x6618c022}},	//   mko_, _जौ_, _gwef, _povk,
   {{0x765e4d6e,0x248c821b,0x64428d6f,0xf8e04374}},	//   nopy, _tudm_, lioi, _नहाय,
   {{0x69dc0d70,0x69dacd71,0xdb0f0319,0xaa578d72}},	//   dfre, rfte, macé, _علما_,
   {{0x62850d73,0x6440cd74,0xdcb100d1,0x63a44d75}},	//   _siho, qimi, ẩm_, jbin,
   {{0x62850d76,0x81c80079,0x7641cd77,0x661a8d78}},	//   _piho, োজন_, bily, _kotk,
   {{0x27e94231,0xa2c48c4b,0xcf2ec1df,0x61f88101}},	//   wean_, _रिन्, ığım_, ndvl,
   {{0x27e94d79,0x63ad0d7a,0x78a90aa2,0x5fc6008f}},	//   tean_, _tean, ćevo, _वाचल,
   {{0x65c2c031,0x7c260136,0x27e0002e,0xc5f8c017}},	//   _fíhà, ckkr, _gbin_, ldē_,
   {{0x20090d7b,0xd76700fb,0x601f00fd,0x3ea045bb}},	// [870] _inai_, _ڈاکٹ, _dëmt, gpit_,
   {{0x26cb0d7c,0x7ed40032,0x9c13c0eb,0x6d480032}},	//   muco_, _أزيا, _tọgh, údac,
   {{0x7afd036b,0x2019404c,0x61ea806a,0x629b8d7d}},	//   lvst, _tosi_, defl, _stuo,
   {{0x7a2f811b,0xc95203bd,0x8d7448a7,0x057443be}},	//   _møte, _ימי_, رالا, رالد,
   {{0x26d90ce7,0x9f52001e,0x644d4269,0xb6a3c0d1}},	//   ntso_, _payé_, mnai, _chấ,
   {{0x628f8d7e,0x644b802f,0x61ea8d7f,0x2bbf025d}},	//   _écom, sngi, gefl, ọchi_,
   {{0x44268d80,0xfbbf04fb,0xf0f98b35,0xf1b08032}},	//   bko_, ्लाम, ्मेद_, اءه_,
   {{0x64428d81,0xf8dd88b8,0xdb008851,0x7bdd00a8}},	//   cioi, _महीप, _bemä, jfsu,
   {{0x7641cd82,0x69dc002c,0x44ef402a,0xaad184d8}},	//   tily, yfre, _টপিক_, _समिक,
   {{0x69dc0d83,0x80d9c0d9,0x41b5801c,0x443f817b}},	//   xfre, оєму_, _آمار, _hmu_,
   {{0x442d8d84,0x7641cd85,0xa25b001b,0x443f8d86}},	//   _kle_, rily, trôn, _kmu_,
   {{0x7a300041,0x629d4d87,0xaad188b8,0x41dd43a8}},	//   _mäte, _otso, _समाक, न्तस,
   {{0x2101438f,0xdb06430d,0x3e640d88,0x683144c9}},	//   lčić_, _pekí, kött_, _mådd,
   {{0xdee2c156,0xdb0bc0d2,0xceb2cd89,0x7a2f8240}},	//   _роши, _regè, _ייד_, _føte,
   {{0x69dc0d8a,0x44268007,0x38694a1f,0x1ddf8419}},	//   rfre, yko_, flar_, प्यत,
   {{0x442d8d8b,0x81e9802a,0x68314377,0xdb0bc303}},	//   _nle_, যাট_, _nådd, _pegè,
   {{0x61f70d8c,0xdd8f00fb,0x2c56003f,0x321a0799}},	// [880] _faxl, اوہ_, gāde_, _topy_,
   {{0x3ea04d8d,0xb0dd88c0,0x38694d8e,0xae0e46ff}},	//   rpit_, _महंग, alar_, साधन_,
   {{0x3ea0406a,0x3cf98036,0x8705016a,0x64428051}},	//   spit_, ्मों_, _قبیل, tioi,
   {{0x442d8d8f,0x38694d90,0xddc1c166,0x50c5cd91}},	//   _cle_, clar_, silň, _विनष,
   {{0x9f404d92,0xa3cc0d93,0x61ea8d94,0x64428051}},	//   rdió_, _लाई_, tefl, rioi,
   {{0x2cb840ab,0x64428051,0xc5f540c5,0xf8e20048}},	//   _tvrd_, sioi, _пясъ, _पहाय,
   {{0xc0e38d95,0x44268d96,0x64428d97,0xdb060d98}},	//   војк, pko_, pioi, lakä,
   {{0x661c4d99,0x38604c76,0xb6a3c0d1,0xc7c6cd9a}},	//   _hork, noir_, _thấ, фски,
   {{0x6b638d9b,0x6724491f,0x64408d9c,0x09c6002a}},	//   _акта, nyij, _immi, শ্যা,
   {{0x6aa2800b,0x661c4d9d,0x81dc802a,0x4d768d9e}},	//   mpof, _jork, _তোর_, _قطار,
   {{0x6e2040b4,0x661c4d9f,0x62888da0,0x644d4da1}},	//   _îmbu, _mork, _iido, ynai,
   {{0x26cb0da2,0xd00fc01c,0x26054a7c,0x7a3004c9}},	//   tuco_, _پله_, _होनी_, _nätb,
   {{0xd838c0b6,0xe66700d9,0xdb008588,0xdb1d0586}},	//   _dwčt_, дтво, _femå, ngsø,
   {{0x386942cd,0x88c780a0,0x2b1bc047,0x2bde88b8}},	//   wlar_, spěš, यहरु_, फ्ता,
   {{0xe8004a3c,0x6d4fc0b4,0x79940da3,0x81e9802a}},	//   _लोहा_, şcar, тисф, যাচ_,
   {{0x4ea7420f,0xc6a748b5,0xd6f2c371,0xc2994da4}},	//   држа, држи, _अनाथ_, зках_,
   {{0x58844097,0x7a300da5,0x443f82bc,0x3a754da6}},	// [890] тыра, _säte, _rmu_, елар,
   {{0xdcfac9d7,0x386941df,0x356b48d3,0x2c560017}},	//   latı, slar_, орен_, rāde_,
   {{0x80dd83ae,0x7a204da7,0x644f00c4,0x439c825d}},	//   _महें, _rött, onci, _ịrụ_,
   {{0xdfa741b4,0x443f8033,0x6aad0da8,0x25e5c045}},	//   _تحدي, _qmu_, _kwaf, _जॉनी_,
   {{0x442d8da9,0x6287410b,0x6b8d0c05,0x644f0032}},	//   _vle_, _tijo, _mgag, inci,
   {{0x62888daa,0x661cc041,0x9f424047,0x6aad0dab}},	//   _cido, örkl, _jaký_, _mwaf,
   {{0x69d70834,0x694501be,0x2489005c,0xdcfac2d6}},	//   _बानी, _učeć, _oiam_, katı,
   {{0x442d8dac,0x3e7440fa,0xc7c480b4,0x6f02cdad}},	//   _ule_, räte_, _асфи, _broc,
   {{0xa3e58028,0x3255811e,0x7876010b,0xe8df400c}},	//   _बॉय_, _звар, náve, _khỏa_,
   {{0x6f02cb90,0xa2c48185,0x6f9fc048,0xe611c032}},	//   _droc, _रित्, _ग्रू, اشة_,
   {{0xe0460dae,0x9046001c,0xdcfac696,0x6445cdaf}},	//   енни, فنده, fatı, éhis,
   {{0xfc320032,0xa3decdb0,0x2c758329,0xdce888c7}},	//   احد_, द्द_, både_, _uzdā,
   {{0xd12ecdb1,0x44294db2,0x69d54036,0x7876001f}},	//   لمی_, dka_, _ocze, jáve,
   {{0x68260018,0x61f8c5ce,0x236900b6,0x644f0db3}},	//   _módi, _gavl, _dyaj_, anci,
   {{0xb4ad8834,0x32d9c3bc,0x2166c640,0x9f474047}},	//   _कबो_, lèy_, _пиши_, ěný_,
   {{0x6b8d00bb,0xdb0f4303,0x2e35c02e,0x59dd4db4}},	//   _ggag, _kecè, _fùfù_, न्सर,
   {{0x442fcdb5,0x7876010b,0x661c4db6,0x2bbf009d}},	// [8a0] _mlg_, gáve, _pork, ्लरा,
   {{0xd12f005f,0xa3e58045,0x6b8d0db7,0x5efe8314}},	//   جمہ_, _बॉब_, _zgag, लिस्_,
   {{0xe1c985db,0x62888db8,0xd8268db9,0x661c4dba}},	//   _राजघ, _rido, нджи, _vork,
   {{0x1e1cca89,0x7e61cdbb,0xdb1b82b0,0xa01b0dbc}},	//   _पक्ष_, holp, _acuñ, rmög,
   {{0x44f180d7,0x63b64057,0x7876010b,0xeafa86b0}},	//   _aš_, mayn, cáve, ثرات_,
   {{0x7c29cdbd,0x78ad8570,0x6b9b840d,0x3ead8141}},	//   eker, ćavn, _efug, _dwet_,
   {{0x8858cdbe,0x7e7e40f8,0x6abd0036,0xed574dbf}},	//   микс_, mmpp, _ऍट्र, _зор_,
   {{0xa3cc054a,0x64460dc0,0xddcbc0b3,0xd90d81aa}},	//   _लाग_, jiki, _čiši, تیم_,
   {{0x26cdc019,0x682ec061,0x9cecc02a,0x61ee0dc1}},	//   gueo_, _cùda, _ওপেন_, kebl,
   {{0xd010c0fb,0x7bd6084f,0x682ec05e,0x442fcdc2}},	//   الک_, _acyu, _dùda, _elg_,
   {{0x44f182bc,0x2489004d,0x3a374093,0x6d4900b4}},	//   _gš_, _piam_, גרים_, şeaz,
   {{0x24890dc3,0x61fa8dc4,0x6f040dc5,0x682ec061}},	//   _qiam_, _hatl, _bric, _fùda,
   {{0x6fa6c63c,0x6f02c036,0x63ad8086,0xbea3c072}},	//   _ट्यू, _uroc, ðani, _бачк,
   {{0xf10c08b8,0x5187001d,0xfaff06a6,0xaa57c359}},	//   हमूद_, еуба, rvë_, _كلنا_,
   {{0x64460dc6,0xa3c28dc7,0xf8074dc8,0xdcfac06a}},	//   biki, ूला_, нчан, patı,
   {{0x7876001d,0xbbcb4185,0x63b64dc9,0x2c09c036}},	//   táve, िलेक, gayn, वाएं_,
   {{0xf9c74dca,0xdb064066,0x9f424166,0x649580f6}},	// [8b0] ещен, _peká, _taký_, _aġil,
   {{0x61ee0dcb,0xddde0077,0x63b640f8,0x321e8799}},	//   cebl, _tipš, aayn, _noty_,
   {{0x628acdcc,0x682601f1,0xdcfc0189,0xd7c50048}},	//   _mifo, _sódi, barı, _वयाच,
   {{0x68260dcd,0x2b20c185,0x4429413b,0x99644119}},	//   _pódi, यहाँ_, qka_, утул,
   {{0x44f18113,0x80380052,0xdb0f00a0,0x7a3244f5}},	//   _sš_, ענדע_, kací, _sæte,
   {{0x69d54064,0xdb0640b0,0xa9698dce,0x78bacdcf}},	//   _ucze, _bekæ, мила_, kstv,
   {{0x9f42c038,0xed1540fb,0xa3e20dd0,0x28c5c7db}},	//   ľký_, _جہاں_, न्ड_, _विधि,
   {{0x44f18089,0x6b9b812c,0x9c134044,0xd709c051}},	//   _vš_, _ufug, bọel, дние_,
   {{0x7e61cdd1,0x6847c303,0xf1a78dd2,0x35f58dd3}},	//   tolp, _aèdè, _зрен, _ипар,
   {{0xdb0f0dd4,0x7c2b84d3,0x63b64dd5,0x7ae98dd6}},	//   gací, lkgr, zayn, _ipet,
   {{0xf9924093,0x26cf8dd7,0x65158dd8,0xaca38112}},	//   ירי_, lugo_, _جوائ, _kpọl,
   {{0x26c9441b,0x27edc1c8,0x04460dd9,0x7c2b814d}},	//   krao_, qeen_, темн, nkgr,
   {{0xdb0f0dda,0x64460ddb,0xdcfc00b5,0x26cf8c47}},	//   bací, riki, varı, nugo_,
   {{0x628acddc,0xdb0f0019,0x7d03cddd,0x63b641c8}},	//   _gifo, cací, _trns, wayn,
   {{0xfa88c0d1,0x2ee900d2,0xd7b38715,0x63b64149}},	//   _cừu_, _epaf_, ुणाच, tayn,
   {{0x61ee0b45,0xde88c00c,0x6b9bc0b3,0x442b0033}},	//   sebl, _dịu_, ncug, ckc_,
   {{0x27e04dde,0x26c94aa2,0x7e638ddf,0x27fd80de}},	// [8c0] rfin_, grao_, konp, ddwn_,
   {{0xb69b401d,0x69c180f7,0x66e34652,0x200d8de0}},	//   _trân, _ndle, рофа, _anei_,
   {{0x22478b45,0xdb098018,0xf767cde1,0x09b8002a}},	//   dink_, _odeó, _چا_, _জাপা,
   {{0xfbdf0015,0x69c18de2,0x386dcde3,0x61e90a93}},	//   hiên_, _adle, jler_, đele,
   {{0xe8e20c63,0x61fa8de4,0x7ae98018,0xe2978de5}},	//   _पहुच, _patl, _cpet, вач_,
   {{0x6da340d9,0x61fa8de6,0xa4d88de7,0xadba401c}},	//   _вира, _qatl, едку_, _زهرا_,
   {{0xa2c4846d,0xc6c3c079,0x61e3006a,0xd12f8182}},	//   _रिव्, ্বোচ, _önle, يمه_,
   {{0xd7068604,0xaca40112,0x7c3640de,0x63a9cde8}},	//   _изби, _akịt, nhyr, gben,
   {{0x9f4b046a,0x7c20868a,0x9f4fc7c9,0xa6868d7d}},	//   pecé_, _iomr, _pagá_, _алад,
   {{0x386dc70d,0x64560024,0x6206c0d9,0xde88c35d}},	//   aler_, _ajyi, тчиз, _nịt_,
   {{0x68314041,0x2c758041,0xdb0f0089,0x7a348580}},	//   _låda, låda_, rací, _càte,
   {{0x9f520031,0x9f594303,0x386dc7b0,0x9b43cde9}},	//   _bayà_, _fasè_, cler_, انیو,
   {{0x3ea683e2,0x8cca8c4b,0x28a6c09d,0xde88c0d1}},	//   npot_, संको, कीजि, _bịt_,
   {{0x7a24c0ce,0x3ea680b1,0x00000000,0x00000000}},	//   _pòtu, ipot_, --, --,
   {{0xa3d74b64,0x7648cdea,0x00000000,0x00000000}},	//   _साद_, midy, --, --,
   {{0xdb0f40cc,0xfa00802a,0x61fe43b3,0x853cc026}},	//   _decî, ্সটল_, edpl, ybėj,
   {{0xa85800c3,0x59b6c048,0x61fe40a8,0xeb0d4047}},	// [8d0] _שיחה_, _आजार, fdpl, समेत_,
   {{0xdb00cdeb,0x26cf800d,0x41b54032,0x0514c02a}},	//   lamó, vugo_, امار, ানীর_,
   {{0x4420007a,0x387fc080,0x6835c086,0x9f594396}},	//   _yoi_, ymur_, _háde, _masé_,
   {{0x2d9e8dec,0x05d301f9,0x61fe414d,0x7a39c171}},	//   _afte_, _ताँब, adpl, _kùtù,
   {{0x27ef8ded,0x7648c0f8,0x63a9c3ad,0xc6950052}},	//   regn_, kidy, vben, נאַ_,
   {{0x69d500cb,0xbb3a4052,0x9f5201c0,0x61fc4dee}},	//   ngze, _טערי, _jayá_, _garl,
   {{0xb7d5c1c0,0xa069cdef,0x78760df0,0x5edf002a}},	//   _aṣat, нака_, háva, মিটে,
   {{0x1bb9c032,0x63a9cdf1,0xa3e3c045,0x7e638df2}},	//   رابع_, uben, _पॉश_, sonp,
   {{0x387fcdf3,0x9f59401e,0x7ae980f7,0x3e79c01e}},	//   rmur_, _basé_, _upet, hète_,
   {{0x96d5446d,0x7c3f0007,0x3c31c166,0x7bc2cdf4}},	//   यूयॉ, _įpra, _dáva_, _edou,
   {{0x3f8fcdf5,0x248d8df6,0x9f5b013b,0xd5b180d1}},	//   _tggu_, _kiem_, _faqë_, _nói_,
   {{0x6e218df7,0xb8ebc281,0x7c2d4df8,0xfaa60df9}},	//   _holb, _लि_, jkar, ламо,
   {{0x6e218dfa,0x7c2d4dfb,0x44f50185,0xef0ec00e}},	//   _kolb, dkar, _ať_, _ум_,
   {{0x27ffc232,0x6835c018,0xa3e58959,0x42550dfc}},	//   ldun_, _dáde, _बॉस_, атст,
   {{0xed570dfd,0x69c3c185,0x69d8c08f,0xa7fb0018}},	//   гор_, _idne, _माती, coño,
   {{0x09cc4048,0xaca9005f,0x248d8dfe,0x24804199}},	//   ाल्य, کھیے_, _niem_, umim_,
   {{0xdb0f001f,0x22998231,0x673bc8f1,0x9f4480ce}},	// [8e0] racã, _nèk_, nzuj, _lamò_,
   {{0x2907cdff,0x442dce00,0x62960010,0x63b60e01}},	//   _krna_, hke_, _iuyo, _heyn,
   {{0x7c2d4080,0xf4be802a,0x8c464e02,0x63a48070}},	//   bkar, _আহ্ব, _бене, ñino,
   {{0x68fcc065,0xdbd740cb,0x3eb20177,0x3cf840d2}},	//   ærdi, mäßi, _kwyt_, _vsrv_,
   {{0x7852003f,0x6d5f8080,0x81b3402a,0x4af88e03}},	//   tāvj, şqal, _টার_, телю_,
   {{0x27f24149,0x22998303,0x3ea6814d,0x2907c3ad}},	//   leyn_, _dèk_, rpot_, _orna_,
   {{0xe8070260,0x78760443,0x0466c9d3,0x6449c1f4}},	//   षयमा_, záva, лтим, fiei,
   {{0x69c3c02c,0x68260107,0x27f24e04,0x3b06ce05}},	//   _adne, _móds, neyn_, _proq_,
   {{0x2907ce06,0x91fcc03f,0xd5d6805f,0x386680b1}},	//   _arna_, klāt, _متاث, moor_,
   {{0xe29fc80f,0x7c2d4e07,0x44224e08,0xdb164565}},	//   íða_, zkar, _lok_, rayè,
   {{0x26c00e09,0x7d9381b4,0x64464e0a,0x628e4e0b}},	//   _avio_, _المؤ, _omki, _mibo,
   {{0x6449ce0c,0x38668b45,0xe29ace0d,0x61fe0e0e}},	//   ciei, noor_, _зад_, _aapl,
   {{0x74c0ce0f,0x2907ce10,0x9f520070,0x7c2d4377}},	//   _विकृ, _erna_, _payá_, vkar,
   {{0x7c2d4e11,0x6f044e12,0x200041c8,0x69d5806a}},	//   wkar, dvic, edii_, _özet,
   {{0x7a36c119,0xe809c08f,0x55580e13,0x195801dc}},	//   _câte, वाचा_, гаря_, гары_,
   {{0x78760c1e,0x386681b0,0x7c22cd31,0xa3e7c4fb}},	//   páva, joor_, _joor, म्प_,
   {{0x35b54e14,0xb69b4e15,0xead547d6,0x61fe014d}},	// [8f0] ибар, _trâm, розь, _fapl,
   {{0x644640b3,0x7d088e16,0x7f3c0052,0x6d410e17}},	//   _emki, _ords, _רעזו, úlas,
   {{0xdb0bc05f,0x7a36c01e,0x1c004e18,0x2abb455d}},	//   _megá, _gâte, _लोकल_, _bàbá_,
   {{0x44224e19,0x2ba4ce1a,0x69da8e1b,0x3866814b}},	//   _gok_, _ग्ला, _acte, goor_,
   {{0xb3ba4093,0x26d24070,0x6f1b00cb,0x7aed0085}},	//   _במרכ, cuyo_, äuch, _jpat,
   {{0xa3e7c8b9,0xdb0bc2e3,0x628e4e1c,0x7aed0e1d}},	//   म्न_, _negá, _gibo, _mpat,
   {{0x7c22ce1e,0x6449c018,0x7876005b,0x6e218185}},	//   _boor, tiei, dávn, _volb,
   {{0x6009ce1f,0x2d9ec119,0x26dfc0c4,0x628e4e20}},	//   тним_, ecte_, ttuo_, _zibo,
   {{0xe739c43e,0x2003c185,0x27ffce21,0xb3a982d6}},	//   теп_, ěji_, rdun_, ğıdı,
   {{0x32014033,0x69d740f7,0x6f098e15,0x80cc4045}},	//   ndhy_, ngxe, _irec, _हिमे,
   {{0x63ad4e22,0x787883e9,0x62960e23,0x6281ce24}},	//   kban, líva, _suyo, rmlo,
   {{0x62960e25,0x7c22c057,0x20004057,0x61fe0e26}},	//   _puyo, _goor, xdii_, _sapl,
   {{0xeb8ec186,0x2babc185,0x8c1a84e0,0x43760c9d}},	//   _фи_, _ट्या, דורי, рунт,
   {{0x68384004,0xdb0f4e27,0xed5a01bd,0x260542f6}},	//   _míde, _cecí, вог_, _होली_,
   {{0x44c10039,0x7aed0e28,0x2ba705d5,0x7c22c07a}},	//   gė_, _epat, _क्वा, _yoor,
   {{0x644b8b1f,0x62960e29,0x6f044e2a,0x7afb854a}},	//   jigi, _tuyo, tvic, _osut,
   {{0x6aa4ce2b,0x20120e2c,0x3ebfc033,0x4a464039}},	// [900] _çift, _inyi_, nsut_, анав,
   {{0x62838158,0x3ebfce2d,0xb77b04e0,0x27f24e2e}},	//   jmno, isut_, _באפש, seyn_,
   {{0x63bbce2f,0x261989af,0x44224e30,0x1dddce31}},	//   kaun, पानी_, _tok_, _मानत,
   {{0x63bbc03f,0x4ea68e32,0x628e4e33,0xc6a683d5}},	//   jaun, арка, _wibo, арки,
   {{0x46f68e34,0x38668e35,0x63bbce36,0x20000e37}},	//   рчет, roor_, daun, _maii_,
   {{0x20c5c045,0xda190027,0x7bdb80bb,0xd043c080}},	//   _विंध, दायत_, _ecuu, munə,
   {{0xdb0bc066,0x26df8e38,0x2ce88de9,0xdd9986bc}},	//   _regá, _equo_, اظتی_, уші_,
   {{0x4814c547,0x644b8e39,0xb7bb40d1,0xed574077}},	//   смис, cigi, _loãn, _тос_,
   {{0x6e23ce3a,0x26c0402c,0x2498421b,0xc2e9883b}},	//   _bonb, nsio_, _hurm_, _معلم_,
   {{0xa3e7c1ac,0xc986c00a,0x27ff8414,0x7d010e3b}},	//   म्ब_, иуни, _zaun_, ælsk,
   {{0x7bc64e3c,0xde88c00c,0xc914c079,0x4ac2c08f}},	//   _odku, _dịp_, ান্ত_, _शिकव,
   {{0x629800e0,0x26cdce3d,0xe786c00a,0x7aed0033}},	//   _čvor, breo_, _куло, _ppat,
   {{0x2f0fc086,0x6e23c053,0x442480c3,0x63ad464b}},	//   rögð_, _fonb, _mom_, vban,
   {{0x644b8e3e,0x7a324065,0x6e23ce3f,0x3e34c2cf}},	//   zigi, _sætn, _gonb, _دفتر,
   {{0x38958017,0xeabf00c4,0x7ae28134,0x7c3607fb}},	//   _pāri_, ssù_, htot, _flyr,
   {{0x44f8800c,0x44c10007,0xdb0080cb,0xe3b34e40}},	//   _mũ_, rė_, _bemü, ترس_,
   {{0x44c10039,0x44f8800c,0xdb0f4018,0x207c0009}},	// [910] sė_, _lũ_, _tecí, _באהא,
   {{0x44248e41,0x644b8e42,0xf41f0051,0x24984303}},	//   _aom_, wigi, ljä_, _burm_,
   {{0x7cec0107,0x92584466,0x7c398e43,0x69dd4048}},	//   _vörö, шафт_, thwr, _पाठी,
   {{0x69d88b43,0x61f50e44,0x63a2c0d2,0x2fc6c396}},	//   egve, lezl, _nfon, _ndog_,
   {{0x7cec005f,0xee874ce8,0xe8004e45,0x99984166}},	//   _törö, _выво, _लोटा_, _smrť_,
   {{0x2ca58018,0x6ca74e46,0xdb0605e5,0x78788018}},	//   _ptld_, _враж, jaký, ríva,
   {{0x62838158,0x2ef5403a,0x261ace47,0x69c74303}},	//   rmno, şafı_, बानी_, _idje,
   {{0x80c0c894,0x3ebfce48,0x80cc4045,0x44248e49}},	//   _विजे, tsut_, _हिते, _gom_,
   {{0x672d4e4a,0x64498e4b,0x1dcb4e18,0xdb064e4c}},	//   nyaj, _imei, ाणपत, _sekú,
   {{0x30e78761,0x4424823b,0x644d4e4d,0x645b8570}},	//   _відб, _zom_, hiai, _hjui,
   {{0x69d8c09d,0x63bd0e4e,0x2c72005f,0xa3bb85da}},	//   _मारी, fasn, ládi_, _आजा_,
   {{0x62854321,0x2bddc0b2,0x6e25005e,0xa416002a}},	//   hmho, क्खू_, _aohb, াস্য_,
   {{0x644d4e4f,0x2bdcc5de,0x539ac093,0x201fc12c}},	//   diai, _याता, _עיסו, mjui_,
   {{0x64958570,0xdb19801c,0xc692c052,0x98b406f0}},	//   _išib, gawé, _זאג_, _žeđi_,
   {{0xe6430e50,0x386d81a8,0x644d4e51,0xc987c0b4}},	//   черп, _oker_, fiai, _туди,
   {{0x7aef4e52,0x201200eb,0x44e18070,0xdb0f40d2}},	//   _bpct, _unyi_, ió_, _becà,
   {{0x87b9459d,0x69c74043,0x64564e53,0x63a40e54}},	// [920] руст_, _bdje, rnyi, _ifin,
   {{0xdb1603bc,0x60c90017,0x645b8e55,0x9f5dc88b}},	//   _reyè, ņema, _ajui, _cawé_,
   {{0x5fbe0021,0x2bf9ce56,0x764e090c,0x387f8269}},	//   _्याल, ्यां_, miby, _bhur_,
   {{0x44f8800c,0xaa7b4e57,0xb9004e31,0x7e68c574}},	//   _rũ_, _spýt, _दम_, zodp,
   {{0xa2c2454a,0x27e68e58,0x44e18018,0x24984e59}},	//   _लिट्, rfon_, eó_, _wurm_,
   {{0x3e3644fc,0x46a34e5a,0x44248e5b,0x509641bd}},	//   _افسر, _харв, _wom_, _грађ,
   {{0xa2c48045,0xa0a3823d,0x44204007,0x96c48036}},	//   _रिक्, пшыл, oji_, _रिकॉ,
   {{0xdb008580,0x7d5740c3,0x7a2b00cb,0x7c264085}},	//   _demò, _הילד_, _hütt, _jokr,
   {{0x9f494086,0x7a2b009d,0x64438e5c,0x63a28e5d}},	//   ndað_, _kütt, ënie, mcon,
   {{0x3a2580f8,0x26cac04f,0x6299ce5e,0xd6258032}},	//   _golp_, čbo_, _duwo, _وعلي,
   {{0x290ac10b,0xe3bf4018,0xdd90ce5f,0x7a2b0e60}},	//   íba_, _loña_, بود_, _mütt,
   {{0x7ae44e61,0x7c2644f5,0x78788166,0xdb00ce62}},	//   ktit, _nokr, zívn, damö,
   {{0x644d4e63,0xdb1d4066,0x95cb001b,0x6299c0bc}},	//   viai, _odsá, лува_, _guwo,
   {{0x2bdb0e64,0x68fcc0b0,0x25ad4013,0x9f4b4107}},	//   _भावा, ærds, _đelo_, ámít_,
   {{0x63a285f5,0x487741b4,0xd90f05d3,0x63a40e65}},	//   kcon, مدرس, ریح_, _ffin,
   {{0x6299c033,0x26c209a2,0xf485005f,0x672d4024}},	//   _yuwo, bsko_, _باتی, tyaj,
   {{0x78788e66,0x7ae44e67,0x91b942b1,0xe3bf430d}},	// [930] tívn, gtit, игат_, _coña_,
   {{0x44e18e68,0x6f0d0e69,0xdb0f4018,0xe3bf42b0}},	//   yó_, _irac, _cecá, _doña_,
   {{0xdce88185,0xdb0f430d,0x44204e6a,0x4ada4045}},	//   _vzdě, _decá, bji_, यूबव,
   {{0x4426ce6b,0x66018e6c,0x33758e6d,0x644f0e6e}},	//   _noo_, _salk, огер, nici,
   {{0x7d030e6f,0xcee88d9e,0xd7fc0052,0xf41f40cb}},	//   bírá, مرون_, טהאל, _diät_,
   {{0x24868166,0x8cbb4e70,0x7c2d84c9,0x63a28e71}},	//   amom_, _مدرس_, öarb, acon,
   {{0x7c3bce72,0x44394e73,0x6299ce74,0xf1dc0c4b}},	//   thur, _kls_, _suwo, _बासन,
   {{0x69c8811c,0x261749af,0xddd4c38f,0x29078e75}},	//   _edde, नावी_, _čaši, rvna_,
   {{0xc0528087,0x7c3bce76,0x6f0d0112,0x7c43c242}},	//   _חזן_, rhur, _nrac, _ćurč,
   {{0x44e18e77,0x26c20e78,0x63b9c064,0x317cc97c}},	//   pó_, vsko_, _wewn, _bzvz_,
   {{0x6e274be6,0x26c20036,0x35d30036,0x7a3b401e}},	//   _mojb, wsko_, _ताज़, _gîte,
   {{0x2003c017,0x68e5402c,0x787ec13b,0x546a0051}},	//   ējis_, ithd, tëve, рамм_,
   {{0x645d0e79,0x6f0d0e7a,0x63bb8e7b,0xdb0bce7c}},	//   éria, _crac, _meun, _begå,
   {{0x80ca402a,0x63a28018,0x442042c0,0x7a300025}},	//   _রহস্, zcon, wji_, _käti,
   {{0xa2c24260,0x3ea90e7d,0x764e0e7e,0x20024e7f}},	//   _लिङ्, _etat_, riby, _paki_,
   {{0xf1dc0e80,0xdbf28185,0xe3bf403c,0x2360024c}},	//   _बावन, _příz, _poña_, _txij_,
   {{0x7ae4434d,0x26c2ce81,0xdb0d010b,0x6f0d0e82}},	// [940] utit, škov_, _reaç, _grac,
   {{0x7ae44e83,0x7bc98e84,0x78788e85,0x68384580}},	//   rtit, _adeu, tívo, _dída,
   {{0x44204e86,0x6f0d05c7,0xe816808f,0x7c26406c}},	//   pji_, _zrac, णाला_, _tokr,
   {{0x44e3c140,0x2aaa8c86,0x6d41c7ef,0x44394e87}},	//   iñ_, атко_, izla, _gls_,
   {{0x63bb8e88,0x63ad846a,0x62818e89,0x7bc981f4}},	//   _deun, ñana, _bhlo, _ddeu,
   {{0x63a44e8a,0x3af94009,0xd838c0e0,0x644bc006}},	//   lcin, _פּרע, _muče_, _amgi,
   {{0xd0b1c080,0x61ee40f6,0x2c720089,0x26174e8b}},	//   _təəs, _ibbl, ládu_, नारी_,
   {{0x3ae40e8c,0x6d41c05c,0x27e0009c,0xa7fb0004}},	//   köp_, dzla, _ncin_, poñi,
   {{0x62818e8d,0x7c3d06a6,0x2ca9c1af,0x00000000}},	//   _fhlo, ërrm, _čada_, --,
   {{0x290c80e5,0x62818e89,0x7c228e8e,0x6f0d013b}},	//   _trda_, _ghlo, ljor, _rrac,
   {{0x4426c093,0xc22381aa,0x64958047,0xa3e7c4ef}},	//   _too_, _تکنو, _všic, म्ह_,
   {{0x20068e8f,0x8b6ace90,0x35e0817e,0xd6d9c036}},	//   ndoi_, _киев_, _नाड़, szła_,
   {{0x1be1054a,0x2d9848c7,0xfad800c5,0x2fc04e91}},	//   ग्गल_, _ogre_, одящ_, daig_,
   {{0x44fac59d,0xa2cd8191,0xfc4680a0,0xfc460086}},	//   _tū_, _सिस्, řího_, _þína_,
   {{0x6ce400d9,0x27e00061,0x6e288df2,0x2aa0c061}},	//   міте, _fcin_, _modb, _hòb_,
   {{0x63a44339,0xafdb036b,0x26118064,0x6603c147}},	//   gcin, riøs, _धोनी_, _zank,
   {{0x3a3a0033,0x260fc08f,0xd838c06f,0x26174cbb}},	// [950] _flpp_, _थोडी_, _guče_, नाली_,
   {{0x9f4b446a,0x69dc0e92,0x26054834,0x1a65001c}},	//   _sacó_, cgre, _होखी_, _ریزی_,
   {{0x7c228761,0x765ace93,0x682a4066,0xa3dac0b2}},	//   fjor, inty, _výdr, ़ला_,
   {{0x62818e94,0x49080e95,0x8ccc46d6,0x2c560017}},	//   _shlo, हिरो_, _हिरो, tādi_,
   {{0x24894e96,0x20048871,0x8c1a4093,0x3b098e97}},	//   mmam_, _dami_, _הורי, село_,
   {{0xdddac0a0,0xaad30e98,0x9e348e99,0x6e288149}},	//   potř, _तिनक, мечч, _codb,
   {{0x239840eb,0x25ec809d,0xa158423d,0x7762c75d}},	//   _ọji_, _आउरी_, _дару_, _axox,
   {{0x60c540fd,0x3b0d8033,0x78760e9a,0x200486df}},	//   mshm, _treq_, rávk, _gami_,
   {{0x290ec0e2,0x44c58017,0x3da780c5,0x05dc0185}},	//   _arfa_, sē_, _дреб, _बालब,
   {{0x62818e9b,0x7a3000fa,0x7c298e9c,0x29054070}},	//   _uhlo, _täti, _hoer, _álas_,
   {{0x200480f7,0xa969ce9d,0x62954e9e,0xdb1d40b0}},	//   _yami_, сина_, _mizo, _udsæ,
   {{0x63bd4e9f,0xaacf8027,0x32058066,0x29364009}},	//   _nesn, _हटाक, _haly_, פארן_,
   {{0x7c298ea0,0x987ac2a6,0x386dcea1,0x60c5413b}},	//   _moer, _פאנט, moer_, hshm,
   {{0x60c540da,0xd945cea2,0x386dc101,0x6441414b}},	//   kshm, _нели, loer_, ëlin,
   {{0x63bd4ea3,0xe610c78a,0x61e1809c,0x32058ea4}},	//   _besn, _جشن_, _mcll, _maly_,
   {{0x26d90ea5,0x629540d2,0x63bd4ea6,0xfc3f0359}},	//   buso_, _aizo, _cesn, chí_,
   {{0x60c540da,0xe29f410d,0xe2974119,0x443fcea7}},	// [960] eshm, _yrði_, зау_, ihu_,
   {{0x60c5413b,0x38a1c410,0x629d4ea8,0x26c40089}},	//   fshm, _kór_, _duso, ámou_,
   {{0x7bc0cea9,0x62954eaa,0xdb19c396,0x8fa64eab}},	//   yamu, _dizo, _dewé, _нане,
   {{0x63bd4eac,0x2611825c,0x7c3b8ead,0x6e28806c}},	//   _gesn, _धोबी_, _clur, _sodb,
   {{0x20048eae,0xf3f9c0b4,0x6e288eaf,0x63bb40b2}},	//   _vami_, deţ_, _podb, _õuna,
   {{0xdd9080fb,0x7ae4c051,0x7bc0ceb0,0x4b7b40c3}},	//   نڈا_, _äiti, wamu, _לאכו,
   {{0x5fbe0047,0x60268eb1,0x463b4052,0x321840b1}},	//   ्णाल, _едва, _פעלע, _inry_,
   {{0x443fc283,0x4394ceb2,0x62954eb3,0xb3c6ceb4}},	//   ghu_, майс, _zizo, रृंख,
   {{0x6fd60063,0xa3e588b8,0x7a3347ba,0xa3e18eb5}},	//   _भाजू, _बॉट_, _fıtı, _दात_,
   {{0x683842b0,0x24848033,0xdce74036,0x61e9013f}},	//   _oído, _hhmm_, _wyją, đelk,
   {{0x44290eb6,0x645d0eb7,0x09c888b8,0x05ddc314}},	//   _poa_, ério, रणीय, _मारब,
   {{0x39574093,0x7c2441ae,0xdb064107,0xe7e80b5b}},	//   לשים_, jjir, _bekü, ट्ला_,
   {{0xaa7b0066,0x6483809d,0x69dc84c9,0xdb160031}},	//   stým, sõig, _öres, _feyí,
   {{0xe45f4eb8,0x28c5c8d5,0x26d90eb9,0x6283c5ef}},	//   _sjö_, _विचि, ruso_, _ghno,
   {{0x629d402f,0x63bd4eba,0xe9ff400c,0xab5dc036}},	//   _suso, _pesn, _ngạc_, raże,
   {{0x61facebb,0xdb0bc004,0x4424c0b3,0x415bc0c3}},	//   letl, _regú, njm_, _לדוג,
   {{0x63bd4ebc,0xa3dfc08f,0x66050ebd,0xe81a0371}},	// [970] _vesn, _तास_, _tahk, धारा_,
   {{0xaad4cebe,0x175800c3,0xe3bf430d,0xb2bc00c3}},	//   _दिनक, _מסחר_, _toño_, _המזר,
   {{0xfe704032,0x7a2f80d9,0x645d01c8,0x29010ebf}},	//   ادق_, _møtt, onsi, _usha_,
   {{0xe0d04ec0,0x61facec1,0xdb0d4019,0x32184157}},	//   ازل_, hetl, lbaí, _enry_,
   {{0x6440c1b4,0xfaff03e9,0x645d0ec2,0xd7db017e}},	//   dhmi, nwë_, insi, _भाईच,
   {{0x7c298ec3,0x69d8c048,0x645d00cb,0x6aad012c}},	//   _woer, _मागी, hnsi, _mtaf,
   {{0x6f0d430d,0x2089c844,0xa889cec4,0x9f404397}},	//   lvac, ойки_, ойка_, leið_,
   {{0x9f5900fd,0x7a3d80b6,0x52a9cec5,0x645d001e}},	//   gesë_, _bètc, овим_, éril,
   {{0x66074ec6,0x6d43805f,0x1306c04c,0x2009409c}},	//   _kajk, szna, дный_, idai_,
   {{0x05dc0260,0x645bc119,0x68e14041,0x6483809d}},	//   _बाइब, snui, _älds, sõid,
   {{0x6d454ec7,0x63a4810d,0x6f02cec8,0x7a300ec9}},	//   nzha, þing, _esoc, _mätt,
   {{0x78a94eca,0x291140b3,0x26118ecb,0x9f40410d}},	//   _čevl, _mrza_, _धोती_, keið_,
   {{0x4374c16f,0x66ff81f9,0x1c430768,0x27edc020}},	//   _пушт, ोटिक_, тням, mfen_,
   {{0x68384018,0x62850053,0x7a34805e,0xd29500d9}},	//   _pído, _chho, _càth, ерсь,
   {{0xd4f5010e,0x6da302d8,0xfce30ecc,0x1606c027}},	//   няты, тиса, коро, _वोटर_,
   {{0xd838c043,0x2fdfc010,0x3ead8379,0x683cc88b}},	//   _kuča_, ngug_, _otet_, _kéda,
   {{0x27edc0fa,0x2fc0c54a,0x1a06460e,0xa2d548c0}},	// [980] ifen_, _õige_, мпам, यंग्,
   {{0x7c364039,0x7a3fc669,0xaad3008f,0x683ccd21}},	//   skyr, _fête, _तितक, _méda,
   {{0x3207c3d4,0x7ae9cecd,0xae1b0009,0x8c464ece}},	//   _many_, htet, _וויכ, _жене,
   {{0x7ae9cecf,0x3c31c066,0x6485ced0,0xdb0640b6}},	//   ktet, _kávu_, nóid, _dekò,
   {{0x7c3d00fd,0xe7e6050b,0xbea38ed1,0xdb0b8ed2}},	//   ërri, _काना_, вачк, dagó,
   {{0x63a98ed3,0x2006ced4,0x09d5402a,0x0caa8ed5}},	//   _efen, _saoi_, স্বা, отии_,
   {{0x16db02c8,0x6440ced6,0xafdb40b0,0x9f5900fd}},	//   _बम्ब, thmi, _flød, tesë_,
   {{0x683cced7,0x27edc1f4,0x248480f8,0xec168303}},	//   _béda, gfen_, _uhmm_, _تورد,
   {{0x61faced8,0x3207c016,0xa3adc027,0x9f5900fd}},	//   tetl, _bany_, कड़_, resë_,
   {{0x645d0ed9,0xddc8c064,0xdb040086,0xdb00801f}},	//   wnsi, widł, _reið, _demô,
   {{0x44268eda,0x9f4fc0d2,0x7af60026,0x3207cedb}},	//   ojo_, _bagó_, _apyt, _dany_,
   {{0x6e3e0570,0x60dc0edc,0x3cdfc036,0x7c2bc396}},	//   _alpb, durm, _कमरे_, _gogr,
   {{0x4426810b,0xd838c06f,0xa3e1817e,0x7bdf8016}},	//   ijo_, _guča_, _दास_, òqui,
   {{0x6aa08edd,0x7641cede,0x27e041c8,0x442b4edf}},	//   _mumf, chly, egin_, _soc_,
   {{0x62970004,0xe5f7c093,0x6d5cc032,0x6aa080e2}},	//   _vixo, _חזור_, úrad, _lumf,
   {{0x7c2bc004,0xd308c00c,0x4426831c,0x443d4036}},	//   _xogr, _kệ_, jjo_, ów_,
   {{0x62970ee0,0x20094ee1,0x6aa086df,0x66074ee2}},	// [990] _tixo, rdai_, _numf, _pajk,
   {{0xb3a9838a,0x69c380d2,0x44390ee3,0x7a348060}},	//   ğımı, xane, lks_, _fàti,
   {{0x7c2d0140,0x2ee94ee4,0x3e744041,0xdb0b8018}},	//   _koar, staf_, vätt_, sagü,
   {{0x6298cee5,0x442b4ee6,0x3157c009,0x76550141}},	//   _livo, _uoc_, ויבן_, lizy,
   {{0x6607479b,0x7c2d0156,0xfb358026,0x160a4064}},	//   _tajk, _moar, эндэ, _होकर_,
   {{0xdb1d4ee7,0x7a3d8053,0xdeba44e0,0xfb164052}},	//   _odsú, _bèta, _ממשל, _אַלט_,
   {{0x9f5903bc,0x2486c061,0x7a348016,0x3207c881}},	//   sesè_, _bhom_, _xàti, _rany_,
   {{0x2c640435,0x2bdb008f,0x27edc600,0x3e7444d3}},	//   kıda_, _भागा, ufen_, sätt_,
   {{0x61e50066,0x24994070,0x69c38ee8,0x3207c060}},	//   _ochl, _mism_, pane, _pany_,
   {{0x26c9400c,0xd838c6f0,0xe29f4086,0x6495c026}},	//   isao_, _vuča_, _urðu_, _išim,
   {{0xdb1d4004,0x7c2bc032,0xdb044ee9,0x27edc0fa}},	//   _desé, _togr, rcié, pfen_,
   {{0xcfe9c1aa,0x3958c032,0x66088113,0x61e5002c}},	//   _رفته_, úrsa_, _zadk, _achl,
   {{0x2fc006ed,0x6287421b,0x7d05009c,0x7a348060}},	//   _veig_, _ohjo, _ashs, _sàti,
   {{0x3ea006ed,0x7a300eea,0x248dceeb,0x2ca10303}},	//   _vuit_, _räts, lmem_, _buhd_,
   {{0xae034eec,0x6aa441c8,0x78a180d2,0x27e04eed}},	//   रजनन_, wqif, _julv, tgin_,
   {{0x61fc0eee,0xafdb436b,0x7b05004c,0x1de2408f}},	//   serl, _smør, ättä, _पाहत,
   {{0x9c82c05b,0xab664eef,0x69dcc064,0x3d018ef0}},	// [9a0] íčin, хвал, óreg, _वैसे_,
   {{0x9f404ef1,0x6aa08ef2,0x6b840ef3,0x7a300041}},	//   lgië_, _rumf, _izig, _väts,
   {{0x1636c009,0x66088ef4,0x44268ef5,0x3f9dc25d}},	//   ענער_, _radk, tjo_, _ogwu_,
   {{0xdfd281aa,0x3a3e807a,0x7d0e84f2,0x3f9dc0eb}},	//   ايش_, _sltp_, _ábsi, _ngwu_,
   {{0x26dd842c,0x2905806a,0x38604086,0x92078017}},	//   guwo_, _asla_, mnir_, zgāš,
   {{0x442d8018,0x64428c99,0x69ce4065,0x7bc60ef6}},	//   _eoe_, shoi, _udbe, haku,
   {{0x645d01aa,0x96634ef7,0xc7c6c93f,0xc05ac176}},	//   érik, _скре, нспи, зіп_,
   {{0x2c640165,0x442d8ef8,0x69c18314,0x63a9cef9}},	//   yıda_, _goe_, _eele, gcen,
   {{0xc6f7cefa,0x9c7d00b3,0x8c438051,0x6e2e4efb}},	//   еных_, stčk, _сете, _kobb,
   {{0x3f9dcefc,0x78a180c4,0x5a34cb24,0x61fe4efd}},	//   _egwu_, _fulv, тнот, nepl,
   {{0xb7bd8119,0x3ea24efe,0x7bc60398,0x6b840eff}},	//   _soţi, _lukt_, faku, _azig,
   {{0x63a9cf00,0x44cc8185,0xd308c00c,0x415b4052}},	//   ccen, mě_, _tệ_, לדיג,
   {{0x27e6cf01,0x7c2d0f02,0x787d0047,0x3eafc0d1}},	//   _icon_, _voar, lévk, _gtgt_,
   {{0x9606c1b4,0x2c6400b5,0xfc3f4032,0x69c18140}},	//   _سبتم, rıda_, _slí_, _xele,
   {{0x44cc8185,0xbd680f03,0x6146c01e,0x443900b3}},	//   ně_, ерте_, _délé, pks_,
   {{0x7bc601c6,0x6d7bc0c3,0x69c54f04,0x7bc2c0ce}},	//   caku, _מאוח, wahe, _jeou,
   {{0x657a815a,0x442d8f05,0xe9f9035d,0x7bc2c053}},	// [9b0] _lyth, _roe_, _cuả_, _meou,
   {{0x99674f06,0x7a36c669,0x442d8f07,0x54e4c09d}},	//   нтел, _bâti, _soe_, _कमाए_,
   {{0x443f8f08,0xdcf3c0ab,0x26c9401f,0x41e24cbb}},	//   _plu_, čaće, ssao_, _पारस,
   {{0x3ea24854,0xb9094abd,0x644440cc,0x26cb0f09}},	//   _fukt_, _मम_, chii, osco_,
   {{0x442d843e,0x6f844f0a,0x260c49d5,0x68e30329}},	//   _voe_, _бурж, _डोकी_, _åndb,
   {{0x442d8c2a,0xaad28275,0x6e2e4f0b,0xd838c60f}},	//   _woe_, _सिरक, _gobb, _bučo_,
   {{0x443f8f0c,0x442d854f,0xd469cf0d,0x657a815a}},	//   _tlu_, _toe_, мике_, _cyth,
   {{0x443f8f0e,0xb8c98048,0x6e2e40e2,0x248900d1}},	//   _ulu_, _गं_, _zobb, _nham_,
   {{0x200b4f0f,0x9e65cf10,0xdb00810d,0x7bc60f11}},	//   _maci_, квид, _afmæ, vaku,
   {{0xc3344626,0x64564f12,0x7c2f40c4,0x629a8f13}},	//   רוץ_, ziyi, _locr, _gito,
   {{0x5589cf14,0xd46a0f15,0x6b84005f,0x38604f16}},	//   ьбом_, дине_, _szig, ynir_,
   {{0x24890f17,0x629a8f18,0x7d1cce7c,0x387ac01c}},	//   _cham_, _zito, årsa, _قشنگ_,
   {{0x09cc4079,0x67244283,0x3f9f812c,0x6605cf19}},	//   র্টা, xxij, _mguu_, _апла,
   {{0x2d9c4038,0x44294f1a,0x7a3d8f1b,0x69c70f1c}},	//   ľvek_, eja_, _mèto, gaje,
   {{0x2175c009,0x6145c077,0xdca60f1d,0xa3e8c9fd}},	//   _בײַם_, _шека, таби, _बाम_,
   {{0x2907c057,0xbc634f1e,0x6e2e4157,0x320a40f8}},	//   _isna_, авск, _sobb, _saby_,
   {{0x6495c0b3,0x64564f1f,0x69c3cf20,0x6da64f21}},	// [9c0] _ašik, riyi, _kene, виза,
   {{0x3f9f80eb,0x442fc093,0x78a3cf22,0xd5e08285}},	//   _aguu_, _log_, _kunv, _नाइज,
   {{0xa5d90009,0x77698018,0x4dd90009,0x68384f23}},	//   _אַרי, _axex, _אַרױ, _lídi,
   {{0x76418f24,0x657a8669,0x6aa40f25,0x78adcf26}},	//   _ally, _ryth, _kuif, _čavl,
   {{0x200040b4,0xdee38f27,0x63a90026,0x657a8f28}},	//   meii_, иоци, ženg, _syth,
   {{0x442fc061,0x76738289,0xa01b0086,0x7bc4009d}},	//   _aog_, аліф, nmör, _leiu,
   {{0x717643a9,0x0466cf29,0x200b46df,0x2bb50045}},	//   _شهرا, ктим, _yaci_, ंडमा,
   {{0x7c3bcf2a,0x06b80079,0x660acf2b,0x46d301f9}},	//   gkur, _জিনি, _safk, _तिलह,
   {{0xc0534093,0x6f044f2c,0xe7e60027,0x4e0686b1}},	//   יזה_, nwic, कलना_, _изаб,
   {{0x78a3cf2d,0x44cc80a0,0x8f7580d9,0x442fc2cd}},	//   _bunv, pě_, _сусі, _eog_,
   {{0x7c29c9ca,0x787d0f2e,0xd48fcf2f,0x3949c067}},	//   bjer, lévi, _вр_, _ƙasa_,
   {{0x6f160f30,0x629c40fd,0xdceb40b3,0xe3bf4019}},	//   _bryc, _liro, žići, _toñi_,
   {{0xa2a24b35,0x6442cf31,0x63ad8070,0xdb0d41ff}},	//   _कूल्, _iloi, ñani, mbaç,
   {{0xcf9380c3,0xa3e8c0b2,0x78a3c17b,0xc21140aa}},	//   יטר_, _बाड_, _funv, _डोंब_,
   {{0xa3d54077,0x64484017,0x7ae0c0fd,0xe80b854a}},	//   ловч, īdin, lumt, _सोझा_,
   {{0x69c3cf32,0x46d28f33,0x09cb408f,0x2369004d}},	//   _zene, _सिंह, ाण्य, _txaj_,
   {{0xc6a44f34,0x4ea449bd,0x6aa40016,0x6f0dc004}},	// [9d0] архи, арха, _guif, _áact,
   {{0x69c3c48e,0xe1f04f35,0xe821008f,0x9f590019}},	//   _xene, قسم_, यावा_, nesí_,
   {{0xda784f36,0x645a46ed,0x26cd8158,0x7fd58f37}},	//   тят_, ètic, _sveo_, гілі,
   {{0x645a4669,0xdb1d4018,0x7ae0cf38,0xddd880a0}},	//   étit, _hesí, kumt, livň,
   {{0xe7e80a30,0x0523402a,0x60ce488b,0x629c4f39}},	//   ट्टा_, পনের_, _evbm, _firo,
   {{0x69dd408f,0x69c8cf3a,0x442fcf3b,0x7ae0c010}},	//   _पाटी, jade, _sog_, dumt,
   {{0x320c8f3c,0xdb1d4019,0xf41f4041,0x3f86c053}},	//   _dady_, _mesí, _knä_, _azou_,
   {{0x6442cf3d,0x6edb825c,0xa2db8027,0x2fc94057}},	//   _cloi, _निपु, _निप्, naag_,
   {{0x97ea8f3e,0x26cd85c7,0x69c8cf3f,0xab5dc036}},	//   ıştı, _uveo_, fade, rażo,
   {{0x629c4f40,0x27e90f41,0x7c29c0d9,0x442fcf42}},	//   _xiro, _acan_, sjer, _wog_,
   {{0xdb1d0107,0x6442cb87,0x63ad4f43,0xf3f5c231}},	//   vasá, _floi, kcan, _متشک,
   {{0x2fc942a4,0xb809c359,0x6835c43e,0x7b15c231}},	//   jaag_, _سيتم_, _pádu, _مبتذ,
   {{0xeaaec00a,0x7bc9c303,0xba3b4f44,0x60dac0a8}},	//   _ый_, maeu, _ruïn, artm,
   {{0xe814009d,0x7afb8f45,0x69c3c2c0,0x2bb3c314}},	//   _तोरा_, _mput, _uene, ीरवा,
   {{0x15430077,0xa2ca80e4,0x6601cf46,0x2aa9c02d}},	//   берм, _सौन्, melk, _húb_,
   {{0x60da44d3,0x2a784f47,0x40950039,0x320c0066}},	//   _åtmi, _skrb_, _крыт, ždy_,
   {{0x69c50f48,0x27f24f49,0x6444012c,0xb8eb0f4a}},	// [9e0] _fehe, rfyn_, _ilii, _रौ_,
   {{0x1a060f4b,0xdee34210,0x539b00c3,0x9c14c0eb}},	//   _спом, софи, _איפו, _nọny,
   {{0x4ac68028,0x64440f4c,0x629e0340,0x38cb408c}},	//   रीनव, _klii, _iipo, فانی_,
   {{0xdd8f4f4d,0xf7464c9d,0x50db0009,0x2fc94022}},	//   سون_, _бемо, _אקטא, caag_,
   {{0x4420042c,0xda7a8466,0x629e0f4e,0x69c50f4f}},	//   _mni_, няк_, _kipo, _yehe,
   {{0x7bc640fd,0x69c500fc,0x9985c007,0xf41f0051}},	//   _heku, _xehe, nklų_, lmät_,
   {{0x6442c119,0x9c14c112,0x765883e2,0x59ddc027}},	//   _ploi, _dọny, rivy, _माजर,
   {{0x44cec007,0x660e41c8,0x44320f50,0x8c43847f}},	//   vę_, _habk, _noy_, _лесе,
   {{0xdb044f51,0x05248079,0xdb0d4f52,0xef1a860e}},	//   mbió, বনের_, rbaç, _яма_,
   {{0x64440f53,0x64a6811b,0x7ae0cf54,0x26f7c1b4}},	//   _alii, _бажа, rumt, اريخ_,
   {{0x9c7d0068,0x2d98cf55,0x68e1cf56,0x64440061}},	//   jučc, äre_, guld, _blii,
   {{0x629e0f57,0x44200f58,0x71f7c0fb,0x44cecf59}},	//   _aipo, _cni_, پریس_, rę_,
   {{0x44ee4194,0x7ae28039,0x78a500b3,0xe4578009}},	//   hý_, nuot, _suhv, ריכט_,
   {{0x629e0f5a,0xdb1d401f,0x85044185,0xc6948052}},	//   _cipo, _lesã, रबाट_, יאָ_,
   {{0x7e750799,0x19950f5b,0xdd950007,0xe7ed0185}},	//   rozp, равя, равы, _झापा_,
   {{0x44ee4066,0x36d5404c,0x69c50f5c,0x69ca8f5d}},	//   dý_, иобр, _wehe, hafe,
   {{0x7ae28039,0x69ca8f5e,0x660e4f5f,0x320ec09c}},	// [9f0] juot, kafe, _babk, _kafy_,
   {{0x629e0f60,0x7c208053,0x6835c0a0,0x81c28017}},	//   _gipo, _anmr, _jádr, šēja,
   {{0xdb0bc69a,0x24804f61,0x98aa0026,0x497400b4}},	//   _legð, blim_, kybę_, _глэс,
   {{0x27e68f62,0xf42a0051,0x3f1581ce,0xf34e80eb}},	//   ggon_, mpää_, идес, pụlụ_,
   {{0xf21a056c,0x765acf63,0x998c8047,0x7ae28007}},	//   _फोड़_, kity, _bodů_, guot,
   {{0xa2c18260,0xe80d4185,0x6a7dc3bc,0x27e982c7}},	//   रीष्, ाएका_, pèfi, żan_,
   {{0x63bbcf64,0xe8108045,0x776d001f,0xe7e60b26}},	//   tbun, _ठोका_, _lxax, _काला_,
   {{0x3ff98009,0xfc31c6b0,0x6601cf65,0x98aa0026}},	//   _שפּע, تحت_, welk, gybę_,
   {{0x44d14f66,0x53478f67,0x249f805c,0x69ca8f68}},	//   lą_, _схва, _iium_, bafe,
   {{0xdb0d0018,0xa2dd40aa,0x63bbcf69,0x387fc086}},	//   _neañ, _पिन्, sbun, slur_,
   {{0x60260f6a,0xafdb0065,0x8bd5c71d,0xd8260f6b}},	//   адна, dkøb, _نقاش, адни,
   {{0xd756c1aa,0x5c560f6c,0xa2d70185,0xed56cf6d}},	//   الیت_, ртоф, _बिश्, рою_,
   {{0x442dcf6e,0x765acf6f,0x657e03ab,0xfaa60007}},	//   mje_, bity, _syph, раго,
   {{0x66038f70,0x44200f71,0xa2d7096b,0x6ed709b4}},	//   nenk, _wni_, _बिर्, _बिरु,
   {{0x5d79c81b,0x7ae28039,0x2aab8065,0x645d06ed}},	//   _באַק, zuot, _løb_, èric,
   {{0x200fc303,0x68434f72,0x7c2d4f73,0x660e409c}},	//   _jagi_, онса, gjar, _sabk,
   {{0xd00742d2,0x63a40f74,0x237f804d,0x63a9006c}},	// [a00] шете_, _igin, _nyuj_, ženc,
   {{0x41b64f75,0x248d80f8,0xa2d8cf76,0x7ae28f77}},	//   рсат, _ahem_, _मिस्, vuot,
   {{0x09064f78,0x4fc68039,0x6281cf79,0xa4f48048}},	//   рпен, асла, illo, _आहेच_,
   {{0x7ae28f7a,0x68e38f7b,0x249f8f7c,0xf0930009}},	//   tuot, dund, _cium_, ַנג_,
   {{0x69c74f7d,0xc5fec079,0xddc1c06c,0x66038f7e}},	//   _feje, ্ঞতা_, dolž, fenk,
   {{0x442dc064,0xaa464f7f,0x63a2cf80,0xaa538039}},	//   eje_, _тегл, _sgon, овіш,
   {{0xdb0bc397,0xdb1d401d,0x442dcf81,0x765ac04c}},	//   _segð, _tesã, fje_, vity,
   {{0x10a34ba0,0xd838c013,0x69ca8f82,0xdca34ba5}},	//   _фитн, _kuči_, safe, _фати,
   {{0x2338c04c,0x779481aa,0x44224123,0x2cad406f}},	//   уппы_, _ایشا, _mnk_, _čedi_,
   {{0x2ca7cf83,0xa2db807a,0x69da00ae,0x2c720066}},	//   _bund_, _नित्, ótel, mády_,
   {{0xd838c06c,0x09b480b2,0x273ccf84,0x2918cf85}},	//   _luči_, ुरीय, _bánú_, íra_,
   {{0x63a2c4fd,0xdb19c0cb,0x3f80009c,0xd9eac549}},	//   _ugon, _bewä, _byiu_, ज्जत_,
   {{0xfe7f0016,0x44d14f86,0xbf16c5d3,0x9a86cf87}},	//   juïc_, zą_, _خوشب, _кукл,
   {{0x44224f88,0x291a007a,0x7bcb8f89,0x6483854a}},	//   _ank_, _brpa_, zagu, võim,
   {{0xf09f4157,0x34950119,0xdd8fc3a9,0x2ca7c053}},	//   _pià_, _лакр, _قوه_, _gund_,
   {{0x7bcb8f8a,0xdff8cf8b,0x6440cf8c,0x7127416a}},	//   xagu, ्जिद_, nkmi, یرال,
   {{0xf1a74f8d,0x765c0f8e,0x66fa803f,0xdb0f4f8f}},	// [a10] арен, biry, nākā, _recó,
   {{0x2004cf90,0x7bcb8f91,0x683ccf2e,0x74bdcf92}},	//   hemi_, wagu, _dédi, वीकृ,
   {{0xd041c03a,0x24594f93,0x80f54f94,0x9f4b001f}},	//   _evlə, _бань_, спех, pecó_,
   {{0xf39101c0,0x44224f95,0x2004cf96,0xa2db86fc}},	//   _aṣia_, _gnk_, jemi_, _निद्,
   {{0x93fa4093,0xa28245dc,0x3b6441bc,0x2ee4c3c7}},	//   _גלרי, _کیلو, _дърв, jumf_,
   {{0x645d0f97,0x44d14f66,0xa96982b3,0xe81b4b35}},	//   hisi, pą_, лила_, _पोता_,
   {{0xd49b8bf9,0x7bcb8f98,0xd5ae879e,0x38668f99}},	//   _ара_, pagu, رفي_, bnor_,
   {{0xccf24093,0x69c88057,0x645d0f9a,0x765c0f9b}},	//   _מכל_, _eede, jisi, ziry,
   {{0x6f0d0112,0x27ed809c,0x3cfe8f9c,0x93ef4048}},	//   _nsac, _icen_, _eptv_, _छानच_,
   {{0x3e7b8669,0x4a45cf9d,0x79e7c05f,0x44f180d1}},	//   rêts_, снов, جودہ_, _tơ_,
   {{0x3f860f9e,0xc7a600b4,0x651586b0,0x1ab3402a}},	//   _šou_, йинк, _دوائ, টওয়া,
   {{0x2004c047,0x68384066,0xaadc05da,0x6f1b8f9f}},	//   cemi_, _lídr, _बिदक, _kruc,
   {{0xaad4c260,0x1474c1b4,0x765c0bd1,0x6f63010e}},	//   _दिएक, _بالج, tiry, звяз,
   {{0x291a0158,0xdb02810b,0x3dccc010,0x69c880fc}},	//   _prpa_, scoç, cadw_, _xede,
   {{0x9c7d05c7,0x6efd0041,0x6e23cfa0,0x27ed8fa1}},	//   mučn, _påbö, _innb, _ocen_,
   {{0x6f1b8fa2,0x683ccfa3,0x44f1cfa4,0x27ed888b}},	//   _oruc, _pédi, má_, _ncen_,
   {{0x20124006,0x9ce8002a,0x81df802a,0xb6038089}},	// [a20] rdyi_, খবেন_, ধ্য_, _kráč,
   {{0x291a06f0,0x239bc007,0x201200c2,0x175700c3}},	//   _trpa_, mąjį_, _hayi_, _לספר_,
   {{0x2004cfa5,0x69ce0fa6,0x69c8857b,0x9f594070}},	//   yemi_, mabe, _rede, _basó_,
   {{0x9f59430d,0x03268a23,0xa3d80fa7,0xe7ef4fa8}},	//   _casó_, йден, ाणि_, _छाया_,
   {{0x21d84646,0x66e3824e,0x20120fa9,0x7ff740fe}},	//   _نژاد_, зоча, _mayi_, _اسپا,
   {{0x6e3547ca,0x290c8033,0x29188107,0x44f1c066}},	//   _gozb, _psda_, _árak_, ká_,
   {{0x645d0faa,0xfce34156,0x64b740b3,0xb3a9859a}},	//   yisi, _норо, _aćif, ğırı,
   {{0x09e10079,0x62838835,0x69ce0fab,0x765e4fac}},	//   ম্পা, alno, habe, lipy,
   {{0x2ee041f4,0x26d24fad,0x2fc045bb,0x0b468119}},	//   nrif_, nsyo_, ibig_, _унан,
   {{0x27e94017,0x645d0fae,0x9c7d0faf,0x07374093}},	//   zgan_, wisi, gučn, צאים_,
   {{0x78bc0185,0x69ce0fb0,0x3b00007a,0x27e94fb1}},	//   jprv, dabe, _apiq_, ygan_,
   {{0x7a3d8053,0x9f40434d,0x7ae60854,0x64428025}},	//   _bètw, nfió_, fukt, nkoi,
   {{0x9c7d01b8,0xf1ac8fb2,0x7c2400b9,0xaa7b002d}},	//   bučn, _चलान, _dnir, jrýc,
   {{0x61ea8fb3,0x38ae0086,0x27e944b9,0xdb1d0107}},	//   ngfl, _býr_, wgan_, nbsé,
   {{0x64428051,0x44f1cfb4,0x78a2cfb5,0xf65f0329}},	//   kkoi, cá_, _kiov, dsæt_,
   {{0x8c3d8119,0x38ae0086,0x6b820112,0x7e7ac9e6}},	//   _mişc, _dýr_, ịgas, lotp,
   {{0x2ee0402c,0x27e94fb6,0x78a2c0cc,0x9c7d0089}},	// [a30] grif_, rgan_, _miov, lučo,
   {{0x9f594031,0xbfed40eb,0x6aad413b,0xa3e18185}},	//   _basò_, _ṅụọ_, rqaf, _दाङ_,
   {{0x2fc04fb7,0x7bcf0070,0x64b3c0cc,0x6b82c0bc}},	//   bbig_, oacu, _tăie, _lyog,
   {{0xb9014945,0xdd7bc323,0xd1b80de9,0x6e24c09c}},	//   _दि_, נטאל, _پایا_, _ɗiba,
   {{0xa3ea814a,0xab298fb8,0x6aa98fb9,0x23298b0c}},	//   _मार_, рола_, _quef, роли_,
   {{0x69cacfba,0x6f1b8fbb,0x7bcf0fbc,0x7a3000cb}},	//   _nefe, _vruc, hacu, _sätz,
   {{0xc212421d,0x27ed8157,0x2e3c00c3,0x7bcf0449}},	//   _קהל_, _tcen_, רגונ, kacu,
   {{0x7bcf0fbd,0x26dfc34d,0x81c10079,0xeaf88646}},	//   jacu, truo_, ুলি_, _گرفت_,
   {{0xe7338e5f,0x69ce0fbe,0x1c0d0021,0x20120fbf}},	//   _عصر_, yabe, िजनल_, _rayi_,
   {{0x6f09c0cb,0x8f9c4052,0x2fcdc09d,0x3eadcfc0}},	//   rwec, ניזי, saeg_, rqet_,
   {{0x291cc4d6,0x24614039,0x61fa405f,0x26c6c112}},	//   _crva_, nėms_, _ötle, _ewoo_,
   {{0x60dccfc1,0x44f38fc2,0x6b8d0024,0x7bcf0fc3}},	//   árma, mã_, _bzag, gacu,
   {{0x38694fc4,0x2901075d,0x44f1cfc5,0x291ccfc6}},	//   dnar_, _apha_, sá_, _erva_,
   {{0x44f1cfc7,0x98a60fc8,0x2caac032,0x683cc01e}},	//   pá_, живе, úidí_, _dédu,
   {{0x76438dff,0xf3f9c119,0xada3023d,0x20120fc9}},	//   ikny, enţi_, дарл, _tayi_,
   {{0x7c240fca,0x1ae600b4,0xe3b20968,0x6aa3cfcb}},	//   _unir, _доим, _غرب_, _hinf,
   {{0x44c7c05f,0xd838c077,0x644282bc,0x63a48007}},	// [a40] lő_, _guču_, vkoi, žink,
   {{0x386d8fcc,0x387f8fcd,0x69cac03c,0x5e570032}},	//   _ajer_, _akur_, _xefe, _وليس_,
   {{0x25eb4471,0x69c1cfce,0x44248056,0xda1b4a3c}},	//   _चारी_, ible, _pnm_, _नफरत_,
   {{0x7983cfcf,0x26d2402f,0xdb1d4fd0,0x69c1c6a0}},	//   _mynw, psyo_, _besä, hble,
   {{0xda09cfd1,0xa01b44c9,0x3eb94206,0x38604149}},	//   _वसंत_, _thör, _gtst_, miir_,
   {{0x21764fd2,0x64428fd3,0x6b840449,0x6b82c024}},	//   _дубр, skoi, _myig, _ryog,
   {{0xf84acfd4,0x78a2cfd5,0x7c0681b4,0xbc4acfd6}},	//   ичий_, _piov, _وبرك, ичие_,
   {{0x386d84f5,0x76438033,0x75214018,0x3c31c066}},	//   _gjer_, akny, _álza, _kávy_,
   {{0x3a3840f1,0x53374009,0xa2cd4045,0xdb1d4b4c}},	//   _korp_, ַנטן_, दीप्, _gesä,
   {{0x3207865a,0xb0660051,0x7cdc40cc,0xa2dd4330}},	//   ceny_, ytää, pără, _पिस्,
   {{0x64444051,0x7e7c0fd7,0x6b840fd8,0xe45f0051}},	//   kkii, dorp, _ayig, tiö_,
   {{0xfaa6cfd9,0x69c1cfda,0xfbd2c05f,0x26c6cfdb}},	//   _дадо, able, _آتا_, _twoo_,
   {{0x6aa3cfdc,0x24868166,0x386944f5,0x0665cfdd}},	//   _finf, ilom_, vnar_, _کانپ,
   {{0xb0660051,0x28d18036,0x44d5c017,0x69d8c0b0}},	//   ttää, _सबमि, bā_, _udve,
   {{0x38694fde,0x7ae28414,0x7bcf0fdf,0x6b840fe0}},	//   tnar_, hrot, pacu, _eyig,
   {{0x7ae28fe1,0x32078347,0x80dc0c4b,0x2c210036}},	//   krot, zeny_, _फिरे, याओं_,
   {{0x4426cfe2,0xe8df4015,0x628540c7,0x8c3d81df}},	// [a50] _mno_, _thừa_, tlho, _nişa,
   {{0x3255093d,0x644d4fe3,0x645f4fe4,0x6f1d4077}},	//   _хвор, shai, siqi, _vrsc,
   {{0x7bcd0033,0xdb078018,0x32078fe5,0x644441c8}},	//   _keau, _ámús, veny_, bkii,
   {{0x3a384061,0x6e38c7fb,0x7bc280a8,0x224a40b9}},	//   _eorp_, _lovb, gbou, _elbk_,
   {{0x069b41aa,0x32078fe6,0x2fcf8fe7,0xfc47c089}},	//   _نخست_, teny_, ragg_, šíky_,
   {{0xd126c1b4,0x26c90150,0x58d54051,0xc178c007}},	//   _كم_, _mwao_, _ногт, ngės_,
   {{0x0445cfe8,0xe5a283fe,0x68e8c1ae,0x7ae28157}},	//   зейн, ниши, judd, arot,
   {{0x64498119,0xe45f8fe9,0x661540fc,0x7bcd0fea}},	//   _ulei, _öö_, _hazk, _neau,
   {{0x66154039,0xddc3c06f,0x7bcbcfeb,0x787ec0fd}},	//   _kazk, _ajnš, _vegu, tëvr,
   {{0x1dcb4314,0x6abb80eb,0x78a40051,0xfe71c032}},	//   िरित, _ituf, _siiv, عدة_,
   {{0x44394fec,0x68e8cfed,0xfbcf80b2,0xd90ccde9}},	//   _oos_, gudd, _हजाम, لیو_,
   {{0x186a0698,0xafdb0b9a,0x2ca404c9,0x78fa80c3}},	//   сами_, skøn, ömd_, _לפעו,
   {{0x09e34079,0x3ea580b6,0x6aa3c0f1,0xa2dd4045}},	//   ন্যা, _kilt_, _tinf, _पिष्,
   {{0x44d5c017,0x25fd4444,0x471ac323,0x645d4fee}},	//   pā_, र्मी_, _לונג, _amsi,
   {{0x8c4600b4,0x3ebfc07a,0x38b18107,0x291e0fef}},	//   _неке, lput_, _jár_, íta_,
   {{0x6aad010f,0x2167001d,0x09e34079,0xa3ea8d60}},	//   _fuaf, чиси_, ন্মা, _माइ_,
   {{0xdcf483c7,0x62870ff0,0x38b181b4,0x38604057}},	// [a60] _đačk, bljo, _lár_, riir_,
   {{0x3af444c9,0xa5964051,0x7e61c018,0x2fcd8157}},	//   räp_, прещ, nilp, _aeeg_,
   {{0x44394ff1,0xaca44044,0x38b181b4,0xe9f9000c}},	//   _fos_, _ahụt, _nár_, _huế_,
   {{0x3a3a0ff2,0xb7eacf8b,0x3ea58032,0x44d78119}},	//   _hopp_, _टाइम_, _ailt_, dă_,
   {{0xa7fb003c,0x3a384588,0x2cbf4199,0x7e61cff3}},	//   niña, _torp_, _čude_, kilp,
   {{0x7bc28ff4,0x24868ff5,0x82d70009,0x80d08079}},	//   sbou, slom_, לונג_, সংস্,
   {{0x7ae28ff6,0xa7fb0018,0x6608c240,0x20568077}},	//   srot, hiña, vedk, _етар,
   {{0x68e8c11c,0x3a3a0041,0x6d41cff7,0xbab8c896}},	//   vudd, _lopp_, dyla, огих_,
   {{0xdee38ff8,0x2286cff9,0x3ea58655,0x96b98ffa}},	//   _поти, зунг, _filt_, _духу_,
   {{0x68e8c1ae,0x2eb5831e,0x2fcd823b,0xf3f9c0b4}},	//   tudd, _ісус, _zeeg_, riţa_,
   {{0x7d03c033,0x2fcd8022,0x44d84f3c,0x55bb80c3}},	//   _cpns, _yeeg_, nč_, _המבו,
   {{0x765e0ffb,0x7c39c149,0x6e3a8ffc,0xa2dd448b}},	//   _ampy, _gowr, _hotb, _पिल्,
   {{0x6e3a80f1,0xfaf7cde9,0xbebd8ffd,0xab83cffe}},	//   _kotb, _فروغ_, _grūd, _пушк,
   {{0xbeed0fff,0x7689010d,0xe81d0d91,0x4ea41000}},	//   _जमीन_, mþyk, _बोरा_, ерса,
   {{0xd7cc808f,0x09e34079,0x01fbc0c3,0xdb0d4032}},	//   ाराच, ন্ডা, _הפול, rcaí,
   {{0xf1bf8015,0x628700b3,0xe8e0000c,0x44f54d27}},	//   _đám_, sljo, _giọt_, vå_,
   {{0xa7fb048e,0x6fc31001,0xa2d703b0,0x7a3d9002}},	// [a70] ciña, _व्यं, _बिट्, _mètr,
   {{0x929d8064,0x9f40410d,0x768b43a6,0xddc8c0b3}},	//   _opła, rfið_, rüyo, hodž,
   {{0xddc8c0b3,0x6abb9003,0x6f1bc7ca,0x6443801f}},	//   kodž, _stuf, zvuc, ênio,
   {{0x9cd600c3,0xf9904032,0xaaddc2f6,0xf1cb4185}},	//   _קורה_, ابك_, _मिलक, िरहन,
   {{0xf41f0051,0x38b19004,0xe46a0025,0x6e3a8127}},	//   ylän_, _sár_, ltöä_, _botb,
   {{0x2fcd868e,0x2d859005,0x3cf81006,0x41bf00e6}},	//   _weeg_, _pyle_, _بعید_, ्रिस,
   {{0x3ea59007,0x200b0166,0x569447bc,0x2fcd8022}},	//   _vilt_, keci_, _чарт, _teeg_,
   {{0x3cde856c,0x27ff812d,0x7ae9c0fc,0xdb02d008}},	//   _गिरे_, _ubun_, tuet, _egoí,
   {{0xd5b1800c,0x7d1c0618,0x2ca6c02c,0x59bf08fb}},	//   _các_, zvrs, _diod_, ्रार,
   {{0x7c3b9009,0x7ae9c0fc,0x4ad7c05f,0x9c7d0123}},	//   _hour, ruet, _ہاتھ_, vrča,
   {{0x6f1bc41b,0x7aeb900a,0x7c29900b,0x7bcf4127}},	//   svuc, lugt, _kner, _oecu,
   {{0x7ae4900c,0xc1c60dd0,0x9c7d00e0,0x644d100d}},	//   šite, वर्ग, trča, _clai,
   {{0x386dc6bc,0x64bac1d6,0xa2c18048,0xe9f900d1}},	//   mner_, _aċid, रीच्, _quế_,
   {{0x7ae4500e,0x3d0a01f9,0xb69b40cc,0x6446100f}},	//   vrit, ाबले_, _spân, skki,
   {{0xfaa31010,0x6d439011,0x320a00c3,0xafdb07fb}},	//   таро, nyna, reby_, rhør,
   {{0x7c3b9012,0x33201013,0xa7fb003c,0xdd8f021a}},	//   _nour, _trix_, piña, شوق_,
   {{0xd910478a,0xd5af00fb,0x69ce4065,0x6d4381f4}},	// [a80] گیز_, افہ_, _pebe, hyna,
   {{0xe297459d,0x6aa741d4,0x7aeb9014,0xff5f0669}},	//   дау_, _cijf, dugt, raît_,
   {{0xf8d20a6a,0x3ea7d015,0x7c298033,0x26c04043}},	//   _तबिय, _mint_, _bner, spio_,
   {{0x3ea7d016,0x2d87c2a4,0x7bcf5017,0x6d6206df}},	//   _lint_, _myne_, _gecu, _ƙwaƙ,
   {{0x17c740d9,0x2d87c14b,0x2ac441c0,0x2d91440d}},	//   _ігри_, _lyne_, _débò_, _ezze_,
   {{0xda0e1018,0x4dfd4185,0xa01b04c9,0xf647c032}},	//   ाजित_, र्दै_, tlök, _شئ_,
   {{0xa6b0402a,0x7aeb8007,0x7a3d8303,0x20d38359}},	//   _ছবিট, augt, _pètr, نتيج,
   {{0x9c7d00ab,0x69c5810d,0x3ea7d019,0x5b14c47f}},	//   ručk, ðher, _aint_, емит,
   {{0xd90e805f,0x2fc6901a,0x200b101b,0xda0e0048}},	//   _چیت_, mbog_, veci_, ाजात_,
   {{0x2bcc8e0f,0xd90e84e8,0xe7eac048,0x648380b2}},	//   ारवा, _نیت_, _टाका_, sõit,
   {{0x386dd01c,0x7c3b8093,0xf1bf00e9,0x629ac838}},	//   bner_, _your, ्रसन, rmto,
   {{0xdb210089,0xccf8c0a0,0x3eafc329,0x387fd01d}},	//   štíh, rtě_, _fugt_, cour_,
   {{0x6e3c47f5,0x644d101e,0x200b101f,0x386001d6}},	//   _oorb, _vlai, reci_, _dmir_,
   {{0x69a00063,0x7d1cd020,0x61fe4206,0x00000000}},	//   _गृही, årss, jfpl, --,
   {{0x200b1021,0x6ca75022,0xb88600a0,0x3a2d435d}},	//   peci_, драж, _smíš, _đep_,
   {{0x9c7d1023,0x439508de,0x66170149,0x764e415a}},	//   kuči, _пайс, _waxk, _alby,
   {{0x672940b3,0xdef845f1,0x61fe482e,0x81ca4079}},	// [a90] _šejb, дых_, ffpl, োলন_,
   {{0x6722d024,0x6618c247,0x2ca90145,0x7a3fc7b0}},	//   _mroj, _javk, _hiad_, _hêtr,
   {{0xe3b040fb,0x6aa741d4,0x69c700fd,0x67d55025}},	//   ارہ_, _vijf, mbje, _пону,
   {{0x22840041,0x7aeb829e,0x6618c0d9,0xe81ec25c}},	//   sökt_, tugt, _lavk, _मोला_,
   {{0x386dc36b,0x442b5026,0xdee59027,0xfbd081aa}},	//   vner_, _inc_, холи, شتن_,
   {{0x02e087f6,0x44f8d028,0xa2b20a7c,0x69d51029}},	//   _निरभ, ké_, _इंस्, naze,
   {{0x7c3b902a,0x63ad102b,0x3ea7c05e,0x6722c1c0}},	//   _tour, _ogan, _rint_, _aroj,
   {{0x44f8d02c,0x2ca90022,0x6594502d,0x0ccb408f}},	//   dé_, _niad_, _расу, ाठीम,
   {{0x64aa8047,0x6285000b,0xd706c051,0xb6a5c119}},	//   _přic, _okho, еные_, ниил,
   {{0xd9ee054a,0x6722d02e,0x6b898f2d,0x77eb41f9}},	//   _जाइत_, _droj, _iyeg, टलुक_,
   {{0x44f8cf2e,0x2019502f,0x6d454107,0x09c8c02a}},	//   gé_, _oasi_, nyha, _শাখা,
   {{0x6e2ac053,0x6285000b,0x63ad0024,0x6b8980bc}},	//   _enfb, _akho, _cgan, _kyeg,
   {{0xd9f04048,0x3949c09c,0x443dc303,0x64aa80a0}},	//   _चालत_, _ƙass_, _iow_, _třic,
   {{0x6449c051,0x2451c066,0xa7fb0018,0xdb16069a}},	//   lkei, _dáme_, biño, _deyð,
   {{0x63bb9030,0x61138080,0x23b54112,0x7c3d4a26}},	//   _ofun, _bələ, _ụja_, _bosr,
   {{0x6449d031,0x6485c018,0x7e76006f,0x9873c017}},	//   nkei, cóit, _šapč, mžēl_,
   {{0x7aed5032,0xadee008f,0x27e01033,0x649601b4}},	// [aa0] guat, _जाऊन_, _idin_, ráid,
   {{0x69d51034,0x248480c9,0x6618c022,0x64960032}},	//   caze, _skmm_, _xavk, sáid,
   {{0x20195035,0x2484805c,0x09d88079,0xaf368567}},	//   _fasi_, _pkmm_, সলমা, کرات,
   {{0x442b434d,0x2ee69036,0xfbd2805f,0x32185037}},	//   _gnc_, trof_, اتا_, _wary_,
   {{0x3f890022,0x0c2340c5,0x200dc0fc,0x47d2802a}},	//   _xyau_, _смян, deei_, _হাদী,
   {{0x2fc69038,0x67240043,0xdb02c0d1,0x443dd039}},	//   sbog_, _mrij, _ngoá, _aow_,
   {{0x27e0103a,0xa7fb0018,0x63bb903b,0x44f8d03c}},	//   _odin_, xiño, _ffun, xé_,
   {{0x6618c242,0x64a3903d,0xd497c10e,0x6603c0f8}},	//   _savk, _баса, нры_, _abnk,
   {{0x7bdf0061,0x57cc8185,0x6618c6f0,0x44f8d03e}},	//   _rdqu, ारीह, _pavk, wé_,
   {{0x63a4903f,0x63ad1040,0x1f639041,0xf1c3802d}},	//   žins, _sgan, _скум, čší_,
   {{0x44f8c1cb,0x753a0414,0x200dc545,0x27474031}},	//   ué_, ätzl, beei_, _kínú_,
   {{0xa3c3c22d,0x38669042,0xf1bf80d1,0x320cc56e}},	//   ्रण_, nior_, _đái_, sedy_,
   {{0x661a9043,0x4ab54a3c,0xc43bc093,0x2486c0eb}},	//   _katk, _अंधव, _מתאי, _ikom_,
   {{0x7c3d4b0e,0x38668449,0xa7fb0004,0x34a9484d}},	//   _sosr, hior_, piño, कद्द,
   {{0x7c2bd044,0x5ce41045,0x2db7c093,0xc693c052}},	//   _yngr, люта, _אלון_, _גאס_,
   {{0x69d51046,0x7bd65047,0x92ab802a,0x661a9048}},	//   saze, gayu, কীয়_, _latk,
   {{0x747c02a6,0xdb1d0032,0x69d5010b,0x78a99049}},	// [ab0] _מנהג, rasó, paze, _riev,
   {{0x83fdc05f,0x661a904a,0x628500f7,0x6d588066}},	//   lnőt, _natk, _ukho, kzva,
   {{0x7c2d104b,0xf124410e,0x290746ed,0x442b504c}},	//   _knar, льцо, ïna_, _tnc_,
   {{0x6aaac69d,0xae0244fb,0x7c3f0085,0x2d8a4329}},	//   _liff, र्बन_, _joqr, _dybe_,
   {{0xa2cd4c5c,0xd874861e,0x6d45504d,0x1474904e}},	//   दीश्, دالب, syha, دالج,
   {{0xa50988b5,0x78a980fa,0x68e30af3,0x98be0007}},	//   дека_, _wiev, _ånds, štą_,
   {{0x44fa80da,0xa19440c4,0x93c64119,0xa3d54036}},	//   gë_, _барч, sfăş, _सजा_,
   {{0x6aaac15a,0xcf7b8032,0x25fd48b8,0x4809c1cc}},	//   _aiff, _فإذا_, र्री_, феин_,
   {{0xa3b94a30,0x32cf4036,0x2486c396,0x62834077}},	//   _चलन_, nży_, _dkom_, čnof,
   {{0x6485c1b4,0x7bd64150,0xdb19c053,0x443dd04f}},	//   góir, zayu, _bewò, _wow_,
   {{0x7bd64498,0x26c00157,0x44fa813b,0x798ac02c}},	//   yayu, _stio_, cë_, _cyfw,
   {{0x6281d050,0x3f6a1051,0x6485c1b4,0x201d9052}},	//   solo, димо_, róis, ndwi_,
   {{0x7bc9c5ef,0x249fd053,0x37760823,0x60c4c04f}},	//   mbeu, mmum_, тынс, _čime,
   {{0x31cb45a3,0x63bd44b8,0x9f610107,0xdb19c0b6}},	//   िरोध, _afsn, ását_, _fewò,
   {{0x32cf4036,0xfc3f5054,0x672400a8,0x660e0036}},	//   eży_, _boí_, _wrij, rebk,
   {{0x62839055,0x3eaa4283,0x7c2d1056,0xa3c3d057}},	//   hono, _sibt_, _gnar, ्रि_,
   {{0x93435058,0x7bd65059,0x6e3e105a,0xf4870973}},	// [ac0] анте, rayu, _topb, _جاوی,
   {{0x443f905b,0xddd8860f,0x660246f0,0x27f2402c}},	//   _aou_, kovš, đoko, sgyn_,
   {{0x7bd6505c,0xd87700fb,0x6493403a,0x69cec086}},	//   payu, _سمیت_, mçin, ðbei,
   {{0x076a849f,0x5ee9017e,0xd5b180d1,0xb90a505d}},	//   وماً_, _जिम्_, _báo_, _मि_,
   {{0xd5b180d1,0x2ca0409d,0x3eaa4303,0x25fd48b8}},	//   _cáo_, mmid_, _tibt_, _रॉकी_,
   {{0x975b00c3,0x2ca0409d,0xad65801c,0xee3f40d1}},	//   ודנט, lmid_, گاهه, _quýt_,
   {{0x320e8062,0x661a905e,0xddd88247,0x621b505f}},	//   refy_, _vatk, govš, _קולק,
   {{0x442d8321,0x8c43806f,0xe4e38285,0x38c88031}},	//   _gne_, _кесе, _गिरि_, _aìrò_,
   {{0x6aaac3ad,0x7afd0041,0xdb0d410b,0xc6f7c04c}},	//   _piff, xtst, rcaç, вных_,
   {{0x22f78093,0x44fa80fd,0xd05d003a,0x62834451}},	//   _בזמן_, pë_, əyəc, čnog,
   {{0x39589060,0x38c881c0,0xe1f3005f,0xc5f340c3}},	//   _års_, _dìrò_, یسس_, בדת_,
   {{0x2ee95061,0x98aa4039,0x60dad062,0x442d1063}},	//   yraf_, mybė_, rstm, ñe_,
   {{0xa3d6425c,0x7afd1064,0x657a805e,0x5fab825c}},	//   हरन_, utst, _hxth, _छलछल,
   {{0x2ca0409d,0xe29805dd,0xc6948052,0xf526d065}},	//   emid_, каў_, טאָ_, _афин,
   {{0x26c25066,0xadf7c1b4,0xc7c70748,0xdb04405f}},	//   _atko_, _شروط_, _испи, kció,
   {{0xbbcc8185,0x64409067,0x7c2d1068,0x7afd00cb}},	//   ारोक, _nomi, _unar, ptst,
   {{0xdddc4158,0x62839069,0x6724c2bc,0x7d18c06f}},	// [ad0] _skrš, yono, _šijj, _hsvs,
   {{0xa2b0106a,0x2ee9506b,0xfaff00fd,0x1d6b449f}},	//   ंदर्, rraf_, mtë_, وصاً_,
   {{0x7ae9d06c,0x248dca30,0x69d7506d,0x661c4d6a}},	//   zret, ylem_, raxe, _dark,
   {{0x62804018,0x67220077,0x7ae9c8bf,0x9c7d00e5}},	//   _ímon, _šoji, yret, drčk,
   {{0x81d60079,0x91e5801b,0x69d8906e,0x629a8011}},	//   _হাত_, голе, fave, _bhto,
   {{0x69d8906f,0x661c5070,0x2006c018,0x7ae9d071}},	//   gave, _gark, _aboi_, vret,
   {{0x64409072,0xa01b1073,0xdddc411f,0x81ab8079}},	//   _fomi, nlös, _ukrš, কুন_,
   {{0x644d5074,0xae1bcb26,0x38695075,0x3a2ec070}},	//   nkai, _भोजन_, niar_, _anfp_,
   {{0xca85c23f,0x7bc9d076,0xa3e4c185,0xf3f9c0b4}},	//   лгий, rbeu, _भएर_, niţi_,
   {{0xa3c3d077,0x62854066,0x7bc9d078,0x248dd079}},	//   ्रह_, noho, sbeu, slem_,
   {{0xa06a107a,0x248dd07b,0x04460651,0x64bc01af}},	//   еана_, plem_, генн, _očia,
   {{0x6285507c,0x78ad107d,0xa01b04c9,0x6d5900e2}},	//   hoho, _ciav, dlös, _ƙwan,
   {{0x3869507e,0xdb1d4019,0x6b8d01c6,0x6f074017}},	//   diar_, _mesó, _cyag, nībā,
   {{0x7bd9907f,0x2cad9080,0x6b8d00ce,0x7641814d}},	//   hawu, _lied_, _dyag, _joly,
   {{0x7c2f01b4,0x610a803a,0x201dd081,0xd00a4119}},	//   áirí, _gəld, _kawi_, неве_,
   {{0x3dcd4079,0x8c3d8119,0x70d18185,0x201fd082}},	//   _লাগল, _fişi, _सबैल, ndui_,
   {{0x8c1dc02a,0x6b8d1083,0x442fd084,0x69d88073}},	// [ae0] থাপন_, _gyag, _mng_, yave,
   {{0x661c5085,0xed5a5086,0x7e1d9087,0xbbcc9088}},	//   _qark, ноз_, पयोग_, ार्क,
   {{0x9d461089,0xd94606c5,0x44fc508a,0x4996508b}},	//   _сенд, _сени, uí_, ушат,
   {{0x201dc056,0x69d8908c,0xa2cb0045,0x15f0508d}},	//   _nawi_, wave, तीक्, _चाकर_,
   {{0xa3b9454a,0xdb1d4070,0x6d48c036,0x7c3bd08e}},	//   _चलत_, _desó, zyda, djur,
   {{0x764e108f,0xd25248a7,0x2ab98053,0x5b7b0052}},	//   nkby, _انس_, _dèb_, ערסא,
   {{0x67229090,0x44205091,0x3eac836b,0x76419092}},	//   svoj, odi_, _vidt_, _doly,
   {{0x69d55093,0x8fa689cd,0x3ed69094,0x6d48d095}},	//   _zeze, _бабе, _مقرر, vyda,
   {{0x3254c156,0x78a28157,0xa2dd4027,0xdc3742a6}},	//   ивир, mmov, _पिछ्, ראפט_,
   {{0x2d8c9096,0xdb04403c,0x6d48d097,0x291a1098}},	//   _tyde_, nciñ, tyda, _ospa_,
   {{0x78ad023f,0xa194d099,0xbebb40fd,0x6244c05e}},	//   _piav, ранч, _rrëm, _bòor,
   {{0x6ac3c079,0x442fc0f8,0x2486909a,0x8c3d80b5}},	//   _শিরো, _gng_, noom_, _pişi,
   {{0x629c405b,0xdd25003f,0xf3ff010b,0x290d80ab}},	//   _ohro, dīša, sião_, čkaš_,
   {{0xa546c107,0x24868022,0xf3ff001f,0x20d1c04f}},	//   _مضبو, hoom_, pião_, bši_,
   {{0xfe7f06ed,0xa4d5011b,0x78ad0022,0x201dc105}},	//   duït_, робі, _tiav, _yawi_,
   {{0x2418509b,0xf3f9c0b4,0x645a509c,0x62854010}},	//   лосы_, tiţi_, ūtin, woho,
   {{0x629c4b90,0xdb1d4018,0x69d540fc,0xfaff00fd}},	// [af0] _bhro, _resó, _peze, qtë_,
   {{0xa01b0041,0xf3f9c119,0x62804018,0x479c00c3}},	//   plös, riţi_, _ímol, _איחס,
   {{0x629c424f,0x98518064,0x57b5909d,0x6285509e}},	//   _dhro, nąć_, абет, roho,
   {{0x6f0d0044,0xa3b9454a,0xa3d6509f,0xdddc00b4}},	//   _kpac, _चलि_, हरण_, porţ,
   {{0x67244077,0x649d0359,0x629c48a6,0xa3cb48b8}},	//   cvij, méid, _fhro, _र्य_,
   {{0xbea58717,0x7bcd50a0,0x629c4755,0x6cc590a1}},	//   шалк, lbau, _ghro, айка,
   {{0x7a414047,0x4879d0a2,0x6f074017,0x201dc0f8}},	//   _vítě, ксия_, sībā, _pawi_,
   {{0x7aed50a3,0x3eb983e9,0x64bc013f,0x629c4574}},	//   orat, _ésto_, _očin, _zhro,
   {{0xbebd90a4,0x2bb84f4a,0x442fd0a5,0x7aed50a6}},	//   _krūm, _अलसा, _vng_, nrat,
   {{0x6aae4046,0xdd250017,0x9a878119,0xc33240c3}},	//   _xibf, zīša, _субл, קוי_,
   {{0x290150a7,0x201dd0a8,0x7aed50a9,0x628710aa}},	//   ntha_, _tawi_, hrat, dojo,
   {{0x6442c15d,0x38cac1aa,0xa06a02d8,0xff26105e}},	//   _gooi, کایی_, тама_, аммо,
   {{0x62870bf5,0xe8e0000c,0x6496003e,0x661e10ab}},	//   fojo, _kiệt_, báin, _papk,
   {{0x6da5d0ac,0x3eaec663,0x33290303,0x79e7c05f}},	//   _кила, _gift_, _drax_, _صوبہ_,
   {{0xdd25003f,0x7aed4038,0xdddc0068,0x287610ad}},	//   tīša, erat, gorš, _выпр,
   {{0x6724cb22,0x629c50ae,0x7bcd50af,0x7bdbc340}},	//   _šiji, _shro, gbau, nauu,
   {{0x7aed50b0,0xdd25003f,0x2d85008e,0xa3c74027}},	// [b00] grat, rīša, üler_, _उभर_,
   {{0x442050b1,0x9adb0323,0xd5eb40d1,0xdd250017}},	//   sdi_, _שחיט, _địn, sīša,
   {{0x7aed50b2,0x6f1b8018,0xaa7b4047,0xdb19c0fa}},	//   arat, _asuc, _svýc, _gewö,
   {{0x649d0032,0x321e87cb,0xe4828526,0x3fc68231}},	//   réig, _saty_, _öpüş, شگری_,
   {{0x29014b90,0x6442d0b3,0x60c950b4,0xf1da0027}},	//   atha_, _rooi, _čeme, _बजान,
   {{0x290c805c,0x3866c570,0x248690b5,0x6ce5ca7c}},	//   _ppda_, _smor_, soom_, _किंग_,
   {{0x29014032,0xa3c3cb64,0x09cf8079,0x69dc10b6}},	//   ctha_, ्रं_, _রাখা, iare,
   {{0xd90d816a,0xc034c6b1,0x7643c2c0,0x69c18855}},	//   عین_, сниј, _aony, _efle,
   {{0x25fd48b9,0x610a803a,0x7d094123,0x25abc080}},	//   र्की_, _qəlb, _ćesi, əklə_,
   {{0x6444005e,0x62728036,0x442010b7,0x6456017b}},	//   _aoii, dłog, _aai_, _alyi,
   {{0x7643c5dc,0x628710b8,0x45b74052,0x64560053}},	//   _dony, vojo, יפיל_, _blyi,
   {{0x7c2090b9,0xe704c1aa,0x4cb8c079,0x9f404070}},	//   _jamr, _هستی, _আবদু, ngió_,
   {{0x44320185,0x27e6c360,0x7c2090ba,0x64960032}},	//   _dny_, _idon_, _mamr, páin,
   {{0x7ae2d0bb,0x7ea000cb,0x69dad0bc,0x7643c17b}},	//   _ivot, höpf, qate, _gony,
   {{0x7e7dc34d,0x6e3cc4d3,0xa3e68048,0x5e57c052}},	//   éspe, örbu, पणा_, _דיגע_,
   {{0x290ec84f,0x228bc125,0x64b3d01e,0x7c228206}},	//   _ipfa_, søkt_, _căiu, jdor,
   {{0x451c8079,0x291e45c7,0x7aed50bd,0xdb9950be}},	// [b10] থমিক_, _štap_, urat, увач_,
   {{0x78b8c06a,0x60c94077,0xab8450bf,0x7aed50c0}},	//   _kuvv, _čemb, цуск, rrat,
   {{0x645990c1,0xe4a790c2,0x67298077,0x6f1b8123}},	//   thwi, ардо, _srej, _ssuc,
   {{0x7ae2c123,0x23bd402e,0x320a4031,0x661501a8}},	//   _ovot, _dájó_, _ebby_, lezk,
   {{0xa2cb008f,0x64960032,0x3869009c,0x69d8c0a8}},	//   तीच्, dáil, _mmar_, _oeve,
   {{0x6288c033,0x7bc2c004,0xdd28003f,0x66150232}},	//   jodo, _afou, lēša, nezk,
   {{0x999a003f,0xc2124093,0x290310c3,0x349590c4}},	//   _kopš_, _מהם_, ntja_, _гавр,
   {{0x3eb950c5,0x260f4027,0x67294283,0x64960032}},	//   _kust_, ड़की_, _ġejj, gáil,
   {{0x7bdd10c6,0x261804ef,0x290ec449,0x6f1b90c7}},	//   dasu, _फसली_, _apfa_, _usuc,
   {{0x98c602a3,0x27e6c3e2,0x6b9b90c8,0xee39c6b1}},	//   _žuči_, _edon_, _izug, уно_,
   {{0x4432007a,0x4c860a74,0x249f90c9,0x29010022}},	//   _pny_, йлов, _khum_, _nqha_,
   {{0x237dc23b,0x64960032,0x629e013b,0xed56c0d9}},	//   _txwj_, cáil, _shpo, сою_,
   {{0x645bc2d4,0x8b68c11b,0x907a8916,0xddc380b4}},	//   mhui, _київ_, רטרי, cinţ,
   {{0x65c310ca,0xe815c0b2,0xf770c7ce,0x539a8323}},	//   збра, ढ़वा_, _تام_, טירו,
   {{0x6e2190cb,0x7d1cc10d,0xdd92083b,0xa3aa4d22}},	//   _malb, ærst, سور_, गेन_,
   {{0x7bdd10cc,0x443205b2,0x7d1c410b,0x248d80eb}},	//   casu, _uny_, _rsrs, _nkem_,
   {{0xbbb8408f,0xe73750cd,0xf09f468a,0x3eb14545}},	// [b20] _अलीक, бет_, _dhà_, _bizt_,
   {{0x68f510ce,0x69dc10cf,0xb69b10d0,0xd9f9c045}},	//   buzd, qare, ltân, ्भित_,
   {{0x2ee04669,0x7ae4011b,0x7c20801c,0x09064ce0}},	//   ssif_, _hvit, _pamr, спен,
   {{0x7ae404f5,0x443fd0d1,0xfd50c1c0,0xb69b10d2}},	//   _kvit, jju_, _aidọ, ntân,
   {{0x9f40446a,0xf77241b4,0xb9214044,0x09cf8079}},	//   rgió_, _راح_, _kasị_, _রাজা,
   {{0x9416803a,0x6f0290d3,0x46a3411b,0x645bd0d4}},	//   _əgər_, rtoc, _наяв, ehui,
   {{0x6288d0d5,0x3d018064,0x6e2181c8,0x7ae2c0e0}},	//   vodo, gów_, _dalb, _svot,
   {{0x6288c064,0x2480c11a,0xdd1c0066,0x69c3d0d6}},	//   wodo, čimo_, káže, _afne,
   {{0x236050d7,0x22458ab5,0x69d8c795,0x68e3c17b}},	//   nzij_, _folk_, _peve, _avnd,
   {{0xddc38156,0x443fc171,0x69de50d8,0x644650d9}},	//   rinţ, aju_, nape, _loki,
   {{0x994a90da,0x4614c5ca,0x7c2450db,0x2ca0005e}},	//   _حلال_, موکر, kdir, _bhid_,
   {{0x628a90dc,0x7645007a,0x3202c047,0x69d8c206}},	//   lofo, _sohy, řky_, _weve,
   {{0x7c2450dd,0x66150232,0x09e34079,0x3f67c051}},	//   ddir, tezk, ন্টা, _лицо_,
   {{0xa3cb408f,0x44e3c0b5,0x7ae900b3,0x64bc06f0}},	//   रुन_, bı_, šeto, _ičij,
   {{0x260090de,0xd12fd0df,0x7ea94007,0x19580039}},	//   _रानी_, _эх_, _užpi, бары_,
   {{0x628a90e0,0x290310e1,0x7ae290e2,0x661500fc}},	//   hofo, rtja_, ksot, sezk,
   {{0xdd28003f,0x7d1e0010,0x66030107,0xeabf400c}},	// [b30] rēša, _esps, _önko, _trùm_,
   {{0x386dc1d4,0x7c22cc4b,0x69de50e3,0x27e910e4}},	//   zier_, _laor, gape, _hdan_,
   {{0x442240b1,0x104b8ae4,0xdd9b4bd4,0x984b90e5}},	//   _fak_, ляди_, уша_, ляда_,
   {{0x644650e6,0x19a850e7,0xa01b50e8,0x69c1c070}},	//   _goki, ступ_, _sjöf, zcle,
   {{0x705541aa,0x923990e9,0x200950ea,0xc1e94107}},	//   _هنگا, ичку_, mfai_, _نکال_,
   {{0x442250eb,0x7bdf50ec,0xe3bf4070,0x2fdd8022}},	//   _zak_, laqu, _dañe_, sawg_,
   {{0x249f90ed,0x7bd9c21b,0x7c22c053,0x8459c119}},	//   _thum_, _pewu, _baor, ирит_,
   {{0x09e1c08f,0x25e1c021,0x237f824c,0x27e910ee}},	//   पण्य, पण्ण, _txuj_, _ndan_,
   {{0x69da90ef,0xe3bf4004,0x09d88079,0x7c22ce94}},	//   _fete, _gañe_, _সারা, _daor,
   {{0x645bd0f0,0x3d018064,0xdd1c0066,0x7c2450f1}},	//   shui, pów_, váže, zdir,
   {{0x64a610f2,0x6145d0f3,0x3ea5c010,0x672d10f4}},	//   жана, цена, rmlt_, _araj,
   {{0x27e910f5,0x80b8c02a,0xb4fa40c3,0x629500a8}},	//   _cdan_, _আবশ্, ספרי, elzo,
   {{0xeb8ed0f6,0x765c10f7,0x12d7802a,0x09e5cb24}},	//   _ци_, thry, _সমুদ, _долн,
   {{0xda0b4a3c,0x27e910f8,0xe939c78a,0x76904051}},	//   स्मत_, _edan_, _نسبت_, näyt,
   {{0x7bdf40fd,0x27e900f6,0x602641a4,0xa966d0f9}},	//   faqu, _fdan_, одва, _миша_,
   {{0x22944051,0x6d4e0026,0x236040a8,0x74b910fa}},	//   mäki_, ryba, tzij_, сурс_,
   {{0xc5d90079,0x64464039,0x442250fb,0x47a80079}},	// [b40] _তারপ, _voki, _vak_, _ক্রী,
   {{0x2d9650fc,0x7c2410fd,0x2fdfc125,0x7c2610fe}},	//   орес, _hair, haug_, ldkr,
   {{0xdd0f03a6,0x2905c34d,0x7bdb8033,0x09d88079}},	//   mışt, ntla_, _beuu, _সালা,
   {{0x7c2610ff,0x87b9411e,0x6e23d100,0x7ae28051}},	//   ndkr, _гурт_, _lanb, tsot,
   {{0x69da9101,0xa01b44c9,0x78ba8007,0xc879c080}},	//   _pete, _sjög, _sutv, dnş_,
   {{0x7aeb0065,0x6459c0f6,0x7bc2902a,0x2ca69102}},	//   _ægte, _alwi, scou, smod_,
   {{0x7c22c06f,0x81cfc079,0x261b8185,0x1fa70047}},	//   _paor, ষণা_, _यसरी_, _गण्ड,
   {{0x7c241103,0x27e05104,0x260b45da,0x3013c1bc}},	//   _nair, nain_, ठ्ठी_, ддър,
   {{0x44269105,0xdd0f0138,0x27e90061,0x78a2856e}},	//   mdo_, kışt, _rdan_, ňovs,
   {{0xb50e4027,0x6e23d106,0xda4ac0c1,0x6459c15a}},	//   _सहाय_, _canb, рчил_, _elwi,
   {{0x6802c185,0x91bb4093,0x7c22d107,0xd257c5dd}},	//   _půjč, ימיי, _taor, іць_,
   {{0x64429108,0xd7f7d109,0x6618910a,0x2ef2414b}},	//   njoi, _душ_, levk, kryf_,
   {{0x8af8003a,0x92e8802a,0x59de8d50,0x78a2d10b}},	//   _şərt, _বহু_, _नजार, _ihov,
   {{0x6e23d10c,0xfe6fc032,0x539b8323,0x7c240061}},	//   _ganb, _لدى_, ייכו, _eair,
   {{0x6d56c09c,0xec6b510d,0x768fc125,0x7ae4510e}},	//   _ƙyau, арак_, røyt, esit,
   {{0xa8a4412b,0x3ced110f,0x27e91110,0x91cb0db4}},	//   друк, čev_, _udan_, _त्रै,
   {{0xb6068166,0x387e4534,0x06cf802a,0xf7704032}},	// [b50] _kráľ, étra_, _রিভি, ناك_,
   {{0x7bdf41ff,0x20094004,0x7648802c,0x6cea8045}},	//   saqu, sfai_, _nody, _टिंग_,
   {{0x30158505,0x48158dd2,0x78bc5111,0x2d8701cb}},	//   здер, змес, _curv, _âne_,
   {{0xb17bc009,0x9d1a0093,0x69dc5112,0x7bc44157}},	//   סטאר, _פורט, _eere, cciu,
   {{0xf7708de9,0x80dc402a,0x20190157,0xce9580c5}},	//   پان_, মূল্, iesi_, падъ,
   {{0x245c4047,0x2905d113,0xc98745ac,0xb2ba40c3}},	//   _víme_, ytla_, _дуби, _למשר,
   {{0x6e2500f6,0x20191114,0x67d58ce8,0x98179115}},	//   _mahb, kesi_, _нову, _وبرا,
   {{0x78a2cd04,0x787ec03f,0x44268057,0x69dc5116}},	//   _chov, tīva, cdo_, _zere,
   {{0x20191117,0x610a803a,0x69c55118,0xfe024045}},	//   desi_, _həll, oche, र्कस_,
   {{0x2ca95119,0x57b84b35,0x0565c051,0x2fdfc022}},	//   hmad_, _अल्ह, звон, saug_,
   {{0x3218111a,0x645b911b,0xdbd9010d,0x6729d11c}},	//   very_, _klui, tæði, svej,
   {{0x69c5511d,0x3218111e,0xf1cf84fb,0x2d840138}},	//   hche, wery_, _स्तन, şmek_,
   {{0x6e23d11f,0xdbd9080f,0x32181120,0x7ae4806c}},	//   _tanb, ræði, tery_, šitv,
   {{0x645b8315,0xaadd8285,0xd019c036,0x248dc4f1}},	//   _llui, नीयक, leń_, loem_,
   {{0xceb28367,0xdca64081,0x69dc5121,0x6abd4600}},	//   תים_, зави, _rere, _ausf,
   {{0x2451c1c0,0x98a30bba,0xd37f0011,0x387f801c}},	//   _bámi_, _пище, šćak_, _njur_,
   {{0x78bc5122,0xab664c34,0xdd0f006a,0xe7375123}},	// [b60] _surv, чвал, pışt, пет_,
   {{0xada61124,0x387f888b,0x2451c031,0x442681c8}},	//   _напл, _ajur_, _dámi_, wdo_,
   {{0x69de1125,0x7bdd5126,0x7bc24004,0x20e7c011}},	//   _iepe, _fesu, ñous, nđi_,
   {{0xdd8f47c3,0x7469811b,0x76488007,0x442481d6}},	//   دوم_, орів_, _sody, _qam_,
   {{0x2007403a,0xe29a823d,0x7ae61127,0x2a6c9128}},	//   əni_, бад_, nskt, _pmdb_,
   {{0x290787ca,0x19949129,0x386d80fd,0x78a2d12a}},	//   ftna_, маля, _emer_, _shov,
   {{0xfaa3512b,0x6493403a,0x80dbc079,0x66188077}},	//   _чаро, rçiv, _মৎস্, revk,
   {{0x628e091f,0x4424912c,0x44268057,0x78a2c046}},	//   hobo, _uam_, qdo_, _qhov,
   {{0xaae6c032,0x3860409c,0x59be0047,0x649d112d}},	//   أسبو, ihir_, ्डार, féin,
   {{0x20c1c0d1,0x78a40024,0xc986d12e,0x3ebdc206}},	//   _bói_, _ahiv, зуми, _duwt_,
   {{0xcfe10079,0xfe4582cf,0x386d912f,0x2d9e8140}},	//   _ভাবন, _تکنی, _ymer_, _uzte_,
   {{0x6b82c022,0xb6068066,0xf8aac6b1,0x20c1c01f}},	//   _txog, _dráž, _увек_, _dói_,
   {{0x7ac70e50,0xa3be02f6,0xcfaac02a,0x6d56c09c}},	//   ясне, ेड़_, _গ্রন, _ƙyas,
   {{0x8ca24036,0x1958d130,0x61eac0b0,0x6722d131}},	//   _कीबो, _малы_, _udfl, _isoj,
   {{0x4c955132,0x91b7c032,0x25ba0149,0xac955133}},	//   дивс, _عطور_, _dgpl_, давш,
   {{0x5597c0c3,0x78a400b4,0xe3bf5134,0x6abd50a4}},	//   _מדוע_, _ghiv, _baña_, _pusf,
   {{0x2ca95135,0xa2b5411b,0x7bdd5136,0x76438036}},	// [b70] rmad_, дбач, _vesu, yjny,
   {{0x645f40fd,0xd019c036,0xe3bf434d,0x037800c3}},	//   shqi, zeń_, _daña_, _מתחת_,
   {{0x39a30031,0x8c3d806a,0x8c20002a,0x25fe40b2}},	//   _désí_, _ahşa, ধারন_, _लारी_,
   {{0xd126d137,0xfc6480c5,0x7bdf1138,0x661ad139}},	//   _یم_, нъчн, _jequ, hetk,
   {{0xe3bf4ad6,0x645d40f1,0x68e5405c,0x7ea0113a}},	//   _gaña_, _ilsi, sshd, löpa,
   {{0xef18913b,0x660d8158,0xf1bac0d1,0xc293801c}},	//   ямі_, đako, _ngơ_, ریاب,
   {{0x3a258854,0x644980d1,0x649d0359,0x387f913c}},	//   _valp_, _toei, véin, _tjur_,
   {{0xfbd3913d,0xcac9c04c,0x68fac010,0x97d9c289}},	//   _ستر_, огие_, dutd, цьку_,
   {{0x2d98d13e,0x63bb913f,0x764ac12c,0x64935140}},	//   üren_, _igun, _bofy, lçis,
   {{0x4426d141,0x2bffc02a,0x1dc69142,0x6ab7017a}},	//   _eao_, ্যেই_, रुआत, _nixf,
   {{0x27e20056,0x355584cc,0x64aac047,0x3ebf8010}},	//   takn_, _تناز, _přit, _huut_,
   {{0x9ce7c0fb,0x628e1143,0xecd54036,0x20e7c199}},	//   _ہوتے_, wobo, डीएफ, rđi_,
   {{0x61fe44d3,0x9c7cd144,0xf403402a,0x09e2002a}},	//   ygpl, _ovčj, উজার_, _বাবা,
   {{0x3ebf804c,0xe3bf4004,0xda0ec00c,0x7afbc2f7}},	//   _muut_, _raña_, _hỏng_, muut,
   {{0x644bc360,0x44395145,0xe7d1d146,0xb6068089}},	//   _kogi, _bns_, _सभाप, _uráž,
   {{0x61e39147,0x98a35148,0x10a34748,0x69d50022}},	//   hanl, висе, висн, abze,
   {{0x672d47ed,0x7afbc04c,0xda0ec00c,0x7c2640d9}},	// [b80] gvaj, nuut, _mỏng_, _vakr,
   {{0x67241149,0x27ed914a,0x2480c04f,0xda0ec0d1}},	//   _isij, _aden_, čimi_, _lỏng_,
   {{0x7c29d14b,0xa3bdc08f,0x823b00c3,0xfd5681c0}},	//   kder, _आलं_, _ועיצ, _dibọ,
   {{0x644bd14c,0x6ee3825d,0xd7ef8032,0x6f09d14d}},	//   _nogi, _ọbar, لكم_, ktec,
   {{0xa3aa495e,0xa37b401f,0xdb1d40b0,0x6f09d14e}},	//   गेश_, _peõe, _afsæ, jtec,
   {{0xdd1d0347,0x3a27c010,0x644bc05e,0x26d24105}},	//   lášt, _nanp_, _aogi, mpyo_,
   {{0x90c34030,0x5cf54030,0x6281843e,0x68fc114f}},	//   _абсе, _пяту, _djlo, nurd,
   {{0x7766005c,0x32c4406a,0x661c1150,0xada35151}},	//   kzkx, _köy_, herk, _расл,
   {{0x20048033,0x84ea89cb,0x644bc449,0x61e39152}},	//   _icmi_, _टिकट_, _dogi, banl,
   {{0x274500fd,0x661c1153,0x65798032,0x8d568c71}},	//   _lënë_, jerk, ábhá, _отеч,
   {{0x27e01154,0x984cc036,0x672d406c,0x67241155}},	//   _bein_, jść_, zvaj, _asij,
   {{0x6e2881c8,0x274500fd,0x24760017,0x644bc32a}},	//   _hadb, _nënë_, dāms_, _gogi,
   {{0xfc67c973,0x69c70043,0x6f09d156,0x984cc062}},	//   _تخلی, tcje, ctec, eść_,
   {{0x7af65157,0x65950589,0x9c7cc147,0xdb23c43e}},	//   dryt, еагу, _ovčk, _àsáb,
   {{0xdd9400d7,0xa3b15158,0x274500fd,0xafdb0240}},	//   вары, टेन_, _bënë_, ljøm,
   {{0x6e288655,0x61e38526,0x27e01159,0x3eb8515a}},	//   _ladb, zanl, _gein_, _airt_,
   {{0x5a3540c5,0x7af6515b,0x78c4425d,0x20c44112}},	// [b90] ннат, gryt, _ịkpọ_, _ịkpụ_,
   {{0x3b094085,0xc5fb4032,0x8009405f,0x68fc033d}},	//   rtaq_, تعرض_, _کردہ_, burd,
   {{0x3de3c079,0x6c8404fc,0x7afd115c,0x672d515d}},	//   _মামল, _سلیم, lust, svaj,
   {{0x603e8119,0x260ed15e,0x6f09d15f,0xdb0d4070}},	//   _rămâ, त्ती_, ytec, scañ,
   {{0x6e2741b7,0x61e39160,0x09e20079,0x38a1c086}},	//   _tajb, tanl, _বাতা, jóra_,
   {{0x38a1d161,0x7afbc051,0xdce88189,0x2745013b}},	//   dóra_, vuut, _azdı, _zënë_,
   {{0x629ad162,0x2055c245,0xe8200048,0x6e288149}},	//   dlto, етпр, _बसला_, _dadb,
   {{0x7c29d163,0x6f09d164,0x22944041,0x2ca6d165}},	//   uder, ttec, säkt_, _chod_,
   {{0x2b9081aa,0xfe0ec00c,0x38a1d166,0x26065167}},	//   _پیوس, _vững_, góra_, स्की_,
   {{0x61e3803a,0x7afbd168,0x60c7c166,0x68fc02d6}},	//   qanl, ruut, íjmo, yurd,
   {{0xd70b4079,0x200041c8,0x68fc1169,0x7c29916a}},	//   রিয়া_, ygii_, xurd, _kaer,
   {{0x68fc0240,0xf1bf80d1,0x4429116b,0x62590321}},	//   vurd, _đáy_, _caa_, _dìom,
   {{0x4429116c,0x200ac03a,0x274500fd,0xdbc6809d}},	//   _daa_, əbi_, _rënë_, _tööd,
   {{0x7c2982a4,0x3e60c3e2,0x2cb94061,0x27e000cb}},	//   _laer, _pòte_, _aisd_, _wein_,
   {{0x7c3b916d,0xf0fe4471,0xdd920e40,0xe3bf434d}},	//   _onur, _उमेद_, اوز_, _caño_,
   {{0xa3cb454a,0xfbda0079,0x9f4205dc,0xf41f4041}},	//   रुल_, _থাকত, haké_, _skär_,
   {{0xd9f3d16e,0x6724116f,0xf8b2c916,0x51f64032}},	// [ba0] _आयात_, _usij, רשן_, فسار,
   {{0xdbd64051,0xcfb700c3,0xa9261170,0x7c3b9171}},	//   _sääd, _אלפי_, _здол, _anur,
   {{0x2cadc09d,0x645a5172,0x64bc0061,0xdbd65173}},	//   kmed_, ëtis, _cčit, _pääd,
   {{0x62955174,0x68fcc6ed,0x7ae9d175,0x44291176}},	//   _ekzo, àrdi, kset, _xaa_,
   {{0x4525c02a,0x81d6c02a,0x628100e5,0x321c802d}},	//   যমিক_, িণত_, člov, tevy_,
   {{0x7c299177,0x67265178,0x2ca6c147,0x7bcbd179}},	//   _eaer, _iskj, _shod_, _afgu,
   {{0x35a3517a,0x7afd117b,0xfaff00fd,0x6da347e3}},	//   _барг, zust, jzën_, _бира,
   {{0x60c181c8,0x6459917c,0x63a4117d,0x764e4149}},	//   _dulm, ckwi, _ozin, _hoby,
   {{0xb5fc81d6,0x2ca6cc90,0x27e6917e,0x68fe459d}},	//   _alġe, _vhod_, maon_, lupd,
   {{0xb602c260,0x7afd117f,0x60c180c4,0x649d0032}},	//   _část, vust, _fulm, réim,
   {{0x7afd0353,0x60c19180,0x63a41181,0xa3d50ce8}},	//   wust, _gulm, _azin, конч,
   {{0x2cadc033,0x81574052,0x62834570,0x3d11c54a}},	//   cmed_, גסטע_, čnoi, _तहरे_,
   {{0x61e55182,0xf1d1c047,0x44291183,0xf1ac8314}},	//   yahl, _द्वन, _vaa_, टेरन,
   {{0x61e18283,0x24804033,0x69cac32a,0x6d550036}},	//   _xell, enim_, _uffe, tyza,
   {{0x29881184,0x199500c5,0x26c25185,0xdff4c54a}},	//   есто_, тавя, _auko_, _इयाद_,
   {{0xa3cb48b8,0x6aba9186,0x3860002c,0xfc3f402e}},	//   रुं_, _litf, _glir_, _ehín_,
   {{0x7afd0080,0x09e6802a,0x610a8080,0x7c29817b}},	// [bb0] qust, _নানা, _dəli, _raer,
   {{0x765ac007,0x26cf4017,0x7aed1187,0x26c240b9}},	//   nkty, īgo_, _ivat, _duko_,
   {{0x764e4799,0x290cc6e2,0xa3ce8112,0x69c7d188}},	//   _doby, ntda_, _ịbịa_, žjeg,
   {{0x43759189,0x64960032,0x61e5518a,0xf993c052}},	//   култ, láir, sahl, ארע_,
   {{0x61e5400b,0x09d8802a,0xe75880d9,0x7cc1c017}},	//   pahl, _সাজা, ниці_, _pērk,
   {{0x6f0d46df,0x7c29897f,0x50d402cf,0x64960359}},	//   mtac, _waer, _جزیر, náir,
   {{0xc98446dc,0x442b518b,0x27e68d45,0x9f4201aa}},	//   _бути, _kac_, baon_, raké_,
   {{0x7aed118c,0x61e1918d,0x64960359,0x765ac036}},	//   _ovat, _well, háir, ekty,
   {{0xef19c11b,0xd706c04c,0x09e20079,0x4aa9c887}},	//   ємо_, вные_, _বাসা, мкин_,
   {{0x64aac020,0x442b518e,0x68e140b0,0x61e707ef}},	//   _aƙid, _lac_, _ælds, jajl,
   {{0x2ca9029a,0x7aed118f,0x6f0d5190,0x6d45413b}},	//   _bhad_, _avat, htac, nxha,
   {{0x6e2ac061,0x6f0d5191,0x765ad192,0x2ca90129}},	//   _eafb, ktac, akty, _chad_,
   {{0xb8138045,0xa3ac07db,0x9985c5ca,0xc8fe48b8}},	//   ण्यम_, कें_, relő_, _उम्म_,
   {{0x7c2bd193,0x6b9b884f,0x99878107,0xb6a61194}},	//   _hagr, _myug, lenő_, тигл,
   {{0x2ca9024f,0x2d9a1195,0x09b50079,0x67228036}},	//   _fhad_, _qype_, _জ্বা, zwoj,
   {{0x3e645196,0x61e3d197,0x6f0d4020,0x3860007a}},	//   _möte_, _henl, ftac, _ulir_,
   {{0xf7461198,0x88bcc047,0x644f5199,0x130a40d7}},	// [bc0] _репо, svět, _doci, ьнай_,
   {{0x7c2d519a,0x442b519b,0x8bffc079,0x6281d19c}},	//   adar, _eac_, ্যটন_, nnlo,
   {{0x661e4534,0x610a803a,0xbf9b001f,0x644f4107}},	//   repk, _təli, ngên, _foci,
   {{0x68fe407a,0x644f4077,0x61e3c040,0x78a9919d}},	//   rupd, _goci, _lenl, _chev,
   {{0xf11ec705,0x2ee003bc,0xa3e0c036,0x68fe519e}},	//   _बन्द_, _jwif_, थरस_, supd,
   {{0xdce181df,0x27e68105,0x443dc127,0x13e7402a}},	//   _aylı, saon_, _anw_, _ফায়,
   {{0xc0e3519f,0xe2974119,0x60c3c0cb,0x321ec56e}},	//   _воск, _рар_, _nunm, vety_,
   {{0xbbc10285,0x83fd8107,0xd7f0c032,0x6e2ac02c}},	//   _एलेक, _előb, حكة_, _safb,
   {{0x9f49410d,0x7eb8d1a0,0x2ca901f4,0xa09b40c3}},	//   ngað_, нгис_, _rhad_, ויקט,
   {{0x443dc0de,0x61e3d1a1,0x60c3d1a2,0xf412c05f}},	//   _enw_, _cenl, _bunm, اؤں_,
   {{0x442dc240,0x7c2d51a3,0x26d211a4,0x1958c59d}},	//   bde_, ydar, _atyo_, ханы_,
   {{0x290cd1a5,0x7e788123,0x78a9813b,0x442051a6}},	//   rtda_, livp, _xhev, jei_,
   {{0x61e3d1a7,0x69ce4086,0xab870589,0x2d9e00cb}},	//   _fenl, _ofbe, тунк, üten_,
   {{0x60c3c031,0x442b51a8,0x26c48986,0x4256c267}},	//   _funm, _sac_, _mumo_, _штет,
   {{0xac1951a9,0x645d00fd,0x25a50041,0xa3e6c027}},	//   нову_, ëris, åll_, _बजा_,
   {{0x2004cb0e,0x9c7d0007,0x4e0ec185,0x2458c031}},	//   ngmi_, ksči, त्रै_, _bémi_,
   {{0x3eaa405e,0x291a0085,0x2617d1aa,0x7c3f11ab}},	// [bd0] _bhbt_, _eppa_, _बॉडी_, _inqr,
   {{0x6d454022,0x7cc1c017,0x20c7009d,0x3a3e8157}},	//   txha, _sēri, _tõi_, _nntp_,
   {{0x442dd1ac,0x9f4e005f,0x854701dc,0x50f546b1}},	//   yde_, önöm_, _рэпе, узет,
   {{0x442b51ad,0x5fb4c045,0x644f46f0,0x26c491ae}},	//   _uac_, ुशाल, _uoci, _bumo_,
   {{0x37078f93,0xdd1085e5,0xd00e81e3,0x6abc4149}},	//   тчев, výše, سلو_, _firf,
   {{0x65954026,0xd25b8007,0x61e500a0,0xdb1d04c9}},	//   _багу, ьце_, _jehl, bbsö,
   {{0xd7e30048,0x6d434854,0x26c480d2,0x27e48053}},	//   पराच, ånad, _eumo_, _femn_,
   {{0x0c25d1af,0x2499421b,0x7af68039,0x349591b0}},	//   умин, _jksm_, šyta, _сабр,
   {{0x645bd1b1,0x387c801e,0xf77f010b,0x290151b2}},	//   rkui, èvre_, daço_, luha_,
   {{0x645bd1b3,0x1dc79158,0x61e511b4,0xd9e3c079}},	//   skui, _ललित, _nehl, _মাহম,
   {{0x442d801c,0xed59c077,0x442dd1b5,0x67244036}},	//   _kae_, хон_, pde_, zwij,
   {{0xe43c4047,0x8335c200,0xbbebc5d3,0x26c482c0}},	//   _příč, _مرتض, _آرام_, _yumo_,
   {{0xc879c9d7,0x27e0869a,0x81e94079,0x61e8d1b6}},	//   miş_, ðini_, _যান_, badl,
   {{0x7aed51b7,0x3f9e003f,0xfc3f4031,0x61e8d1b8}},	//   dsat, ātu_, _aní_, cadl,
   {{0xfe70c78a,0xa96a0217,0x672440f1,0x95e9402a}},	//   _بدن_, хива_, wwij, খলাম_,
   {{0x442d91b9,0xc00611ba,0x3eaa405c,0x1df3c028}},	//   _nae_, _спик, _shbt_, _आयुष_,
   {{0x61e511bb,0x7ae90166,0x42560c59,0x78bd4157}},	// [be0] _fehl, šetr, _منظر, _disv,
   {{0x291a021b,0x27e480b4,0x26c4810b,0x6e21d1bc}},	//   _tppa_, _semn_, _rumo_, nelb,
   {{0x672451bd,0xf1a80260,0xe3b251be,0xea76c009}},	//   swij, _गरिन, _گرد_, נגער_,
   {{0x443f8033,0xb4fb11bf,0x7aed41c8,0x0446400a}},	//   _cnu_, _אפטי, bsat, _семн,
   {{0x6b9d415a,0x442201a8,0x7afbc570,0x81bcc017}},	//   _gysg, iek_, jrut, ldēt,
   {{0x442d80fc,0x623491c0,0xe3bf0018,0x7d01d1c1}},	//   _eae_, реку, meñe_, kuls,
   {{0x442d82cd,0x96634115,0xa3cb4cbb,0x69dc11c2}},	//   _fae_, _укре, रुक_, ibre,
   {{0x6e2e51c3,0x6d4151c4,0x5454d1c5,0x629511c6}},	//   _habb, _šlag, рвит, zozo,
   {{0x7c2d11c7,0xa8574093,0x160b51c8,0x6e21c372}},	//   _raar, טיקה_, स्कर_, felb,
   {{0x5c140079,0x37e1002a,0x9c7cc0b6,0x7c228379}},	//   িযোগ_, _ভাইর, _avčt, leor,
   {{0x442211c9,0x61e5005c,0x249fd1ca,0x44fa83be}},	//   fek_, _rehl, blum_, _سراج_,
   {{0x6e2e51cb,0x60c511cc,0xdee6d1cd,0x69c1806c}},	//   _labb, _ruhm, _боди, _zgle,
   {{0x7c93c1b4,0xd9e44028,0x290140ab,0x70e14045}},	//   _النص, गरात_, zuha_, _पब्ल,
   {{0x7c2291ce,0x25eec048,0xae034b26,0x69dc054b}},	//   heor, _आयटी_, _लाइन_, gbre,
   {{0x629511cf,0x27e6c010,0x48ab51d0,0x7c228125}},	//   rozo, _keon_, етам_, keor,
   {{0x7ae2d1d1,0x291cc01f,0xfc3f40d1,0x6e2e41c8}},	//   _kwot, _ipva_, _thím_, _aabb,
   {{0xf3ff001d,0x69dc11d2,0x61e511d3,0x78bd51d4}},	// [bf0] lhão_, bbre, _tehl, _visv,
   {{0x290151d5,0x443f91d6,0xe704005f,0xb8fb002a}},	//   tuha_, _snu_, _اسٹی, _ডট_,
   {{0x261445de,0x442d8314,0xc879c59a,0xfbd6802a}},	//   न्धी_, _pae_, yiş_, _হয়ত,
   {{0x44e18039,0x473591d7,0x6f0280c4,0x6abe11d8}},	//   vų_, инес, fuoc, _zipf,
   {{0x2903004c,0x29110232,0x290151d9,0x443f8053}},	//   luja_, ltza_, suha_, _vnu_,
   {{0x2bd58045,0x644091da,0x27e9c79b,0x20ca800c}},	//   _ड्रा, _enmi, _žan_, _bùi_,
   {{0x32580093,0x83fd805f,0x6845d1cd,0x7afd00fa}},	//   רסום_, _előa, инка, hrst,
   {{0x3ebe8ae6,0x62974004,0x29110232,0x6d5ad1db}},	//   _eitt_, loxo, itza_, dyta,
   {{0x44e18007,0x27e6c14b,0xb225c60e,0xae06c25c}},	//   sų_, _deon_, ампл, _शाशन_,
   {{0xaa7b4d01,0x62728064,0x3ebe811b,0x61e74570}},	//   _zvýr, dłow, _gitt_, _jejl,
   {{0xc4f8854c,0xe80a0a3c,0xa9a5d0a2,0x4c860f34}},	//   _معنا_, _वादा_, ринд, илов,
   {{0x7c2f4a11,0x54a7cd6b,0x61e751dc,0x7c84d1dd}},	//   _nacr, _صحاف, _lejl, _луче,
   {{0x76b2c064,0xdee5c6b1,0x673b40b3,0x24890303}},	//   _płyt, _толи, _šujn, _djam_,
   {{0xe7f20185,0x2ca051de,0xb0c4817e,0x7d01c277}},	//   _आएका_, wlid_, _लूँग, puls,
   {{0xcec8c015,0x7afd11df,0xde94d1e0,0x64a611e1}},	//   _tộc_, arst, _اجنب, _кака,
   {{0x6e2391e2,0x8ccace31,0x63a991e3,0x251ac0c3}},	//   henb, _संतो, _ozen, _יוצא,

   {{0xe29a401d,0xb89b0093,0x29110232,0x4e058185}},	// [c00] ваа_, _בבקש, atza_, रलाई_,
   {{0x2ca051e4,0x2abc0031,0x4a4351e5,0x9dba416a}},	//   slid_, _dábì_, онув, نداز_,
   {{0x6e2391e6,0x6e2e45f5,0x7e7c02bc,0xd9460dfc}},	//   denb, _vabb, mirp, _тени,
   {{0x6e2e51e7,0x7e7c005c,0x78ad00fd,0x4907454a}},	//   _wabb, lirp, _xhav, _हमरो_,
   {{0x61ea8397,0xd70791e8,0x59f89045,0x6d5c11e9}},	//   tafl, инце_, геля_, lyra,
   {{0x81b54079,0x7ae411ea,0xe2838b8e,0xe9df800c}},	//   ছুই_, _mwit, олчи, _đúc_,
   {{0x7c22830d,0x721b421d,0x2bd34374,0x6d5c11eb}},	//   peor, _שולח, धुवा, nyra,
   {{0x8af0403a,0x245c41c0,0x20ca835d,0xe7f20062}},	//   yyəl, _bími_, _vùi_, _आएगा_,
   {{0xbebb40fd,0x32cb80d9,0x3ebe8d27,0xd24f405f}},	//   _rrëz, _gøy_, _titt_, _عنہ_,
   {{0x443251ec,0x7c2451ed,0x442fc755,0x59aa48fb}},	//   hdy_, heir, _eag_, _करार,
   {{0xdd94c026,0x7e7ac041,0x7ae411ee,0x7d0391ef}},	//   саны, ritp, _awit, cuns,
   {{0x7d0346ed,0xd498000a,0x7ae4000d,0x61e883ad}},	//   ànsi, иря_, _bwit, _hedl,
   {{0x236dc064,0x78a2805b,0x6442c232,0x3ce98158}},	//   czej_, ilov, _inoi, ćave_,
   {{0x7ae40056,0x3d074036,0x386941c8,0x60c091f0}},	//   _dwit, _हमले_, whar_, _limm,
   {{0xadd7c093,0x62728064,0x20194033,0x6ce6c4f5}},	//   _דווח_, słow, _pbsi_, _тіле,
   {{0x4e1951f1,0x60c091f2,0x61e74065,0x6e2391f3}},	//   न्नई_, _nimm, _sejl, zenb,
   {{0x386951f4,0xf9c751f5,0x3e644041,0x629751f6}},	// [c10] rhar_, ащен, _söta_, toxo,
   {{0x7e6040b4,0x291e91f7,0x79810112,0x2489c6b7}},	//   _împl, _opta_, _ịwul, čami_,
   {{0x61134185,0x6e239062,0x7ae411f8,0x69c511f9}},	//   dělá, venb, _zwit, _ighe,
   {{0x83fd8107,0xbd444032,0x6e238127,0x629c49d2}},	//   _előn, تنمي, wenb, _ekro,
   {{0x5334404c,0x61e747dd,0x7d0391fa,0xda06cfd1}},	//   _деят, _tejl, wuns, _शांत_,
   {{0x95cb51fb,0x7ead8166,0x98a80047,0x5f088314}},	//   _шума_, kúpe, _brně_, _समर्_,
   {{0x245c51fc,0x6e2391fd,0xb4c188c5,0x649d0032}},	//   _sími_, renb, ंदे_, néis,
   {{0x628ac054,0x442fc046,0x6b84c0b3,0x30858032}},	//   _ajfo, _qag_, _žiga, _الرف,
   {{0x09e6802a,0xe299c43e,0x62870013,0xd8b6805f}},	//   _নারা, лаи_, knjo, _اگلا_,
   {{0x7c24401d,0x20f300b3,0x3866d1fe,0xd4d9c0d7}},	//   zeir, kći_, _elor_, льмі_,
   {{0x25578047,0x443251ff,0xfaff013b,0x98bf0026}},	//   _dělá_, ydy_, erë_, nytė_,
   {{0xed35805f,0x27e90061,0x673b813b,0x649d0018}},	//   _پوچھ, _cean_, _kruj, xéit,
   {{0x44324066,0xae0e8c4b,0x8c16c032,0x672d0107}},	//   vdy_, _सामन_, _طيور_, _csaj,
   {{0x1d0a1200,0xa50a1201,0x539ac0c3,0x78a29202}},	//   леги_, лега_, _גינו, zlov,
   {{0xa9670b24,0x7cc1c017,0xa3ac109f,0x24869203}},	//   бира_, _vērs, केज_, ynom_,
   {{0xae13c09d,0xfc3f0089,0x27edd204,0x673b9205}},	//   त्रन_, smír_, naen_, _oruj,
   {{0x628700b3,0xe73a0dfc,0xcec8c00c,0x3fcb45d3}},	// [c20] bnjo, _сеп_, _lộn_, ادفی_,
   {{0x62989206,0x44325207,0xb7d7001c,0x1a060b57}},	//   xovo, sdy_, _پویا_, _упом,
   {{0x27edc9b0,0x629e0044,0x7c2442eb,0xd910049b}},	//   kaen_, _ikpo, peir, _تیز_,
   {{0x61e89208,0xe3bf02b0,0x2effd209,0xa3af0c63}},	//   _sedl, leña_, kruf_, _करम_,
   {{0x645603bc,0x4df9c185,0x673b834d,0x60c0920a}},	//   _moyi, ूलाई_, _cruj, _vimm,
   {{0x4424c064,0xa4d88768,0x13e0c045,0xd9464ce0}},	//   wem_, адку_, नर्भ, _леги,
   {{0x27edd20b,0xdd384017,0xc27b4052,0x2905d20c}},	//   faen_, bāša, _ערלי, jula_,
   {{0x78a4520d,0xb881c166,0x27e0520e,0x61e8920f}},	//   nliv, _šíre, nbin_, _wedl,
   {{0xe80d9210,0xdee3842e,0xc1eac11b,0xafdb00d9}},	//   _हाता_, _ноти, льне_, kjør,
   {{0x7e7e5211,0xa3af054a,0x44321212,0x629e00eb}},	//   nipp, _करब_, _aay_, _nkpo,
   {{0xd9439213,0xfe9b42a6,0x1a9b4009,0x6da69094}},	//   _нефи, ריימ, רייע, _امام,
   {{0x44321214,0x8c6704d5,0x61ee0019,0x69c50157}},	//   _cay_, стод, eabl, _sghe,
   {{0x28be4314,0xd544c02e,0x25a40080,0x27e04149}},	//   ्दनि, _bẹ̀r, əmli_, dbin_,
   {{0x649d0032,0x27ed4047,0xae1b8045,0xa6b6c0c5}},	//   téis, _žen_, प्पन_, _усещ,
   {{0x7c261215,0xdd3a00b4,0xe7314080,0x27e9009d}},	//   bekr, văţa, _köçü, _tean_,
   {{0x985d0036,0x63a2c31c,0x20094007,0x73d9401d}},	//   _błąd_, _kyon, ugai_, рдар_,
   {{0x61ee0642,0x386900e2,0x6d480041,0x7cd18975}},	// [c30] babl, _ilar_, ädar, _māra,
   {{0x6dc74051,0x67ff402e,0x200940fc,0xe3bf0070}},	//   ссаж, _bàjà, sgai_, ceña_,
   {{0x64561216,0xddc8c077,0xc9844119,0xb1134044}},	//   _yoyi, kidž, пуци, rụok,
   {{0x3e6b811b,0xbd88001c,0x63a2d217,0xcec8c0d1}},	//   _møte_, _چنین_, _oyon, _rộn_,
   {{0x65c591d7,0x387d802c,0xddc88053,0x9f4b07b0}},	//   обла, riwr_, _modņ, facé_,
   {{0x34b3c46d,0xddc500a0,0x2bda4047,0x78760411}},	//   ुद्द, _pohř, युठा, ršvi,
   {{0x63a2d218,0xb7fb07db,0xde948032,0x6d5906df}},	//   _ayon, ्लाम_, أجنب, _ƙway,
   {{0x661c46f0,0xf8c9c00c,0x6ee38112,0xd9e1c045}},	//   _zbrk, _bẩn_, _ọbur, फर्ट,
   {{0x62728036,0x7d034018,0x248d888b,0x44321219}},	//   głos, ánsf, _ijem_, _ray_,
   {{0x0696c032,0x78a447cb,0x60d8c0d2,0xbbc648b8}},	//   ينية_, zliv, _btvm, _वल्क,
   {{0x44320093,0xf3f980b4,0xdddc0007,0xe3bf0018}},	//   _pay_, _alţi_, sirū, veña_,
   {{0x6288d21a,0x7645002c,0x99584166,0x26d9521b}},	//   ando, _anhy, náša_, _otso_,
   {{0x26d94046,0x09c50079,0x7afb0242,0xeb970db9}},	//   _ntso_, ্রনা, šutn, жия_,
   {{0x95cbd21c,0x7fb6c5a7,0x11da0032,0x68f54089}},	//   _суда_, _ظهور_, شورة_, _ovzd,
   {{0x0595c1aa,0x6456121d,0x629e00b3,0x63ad121e}},	//   _باشگ, _toyi, _vkpo, _ezan,
   {{0x70b440df,0x60c2c070,0xdb0d0545,0x0443521f}},	//   ंगेल, _xiom, _egañ, месн,
   {{0x27e05220,0x07a34401,0x26cb430d,0x2ca0002f}},	// [c40] rbin_, датн, _cuco_, _ikid_,
   {{0x249f805c,0x6d5e5221,0x63a41222,0x6a860119}},	//   _akum_, typa, _iyin, _флоа,
   {{0xb5fac052,0x3cddc048,0x25df45da,0x78b64181}},	//   שלעכ, कीचे_, गरजी_, pmyv,
   {{0xa5da414a,0x1b20c02a,0xdfd08ce1,0xa2aa442f}},	//   _प्रौ, বিতে_, ريت_, _जीर्,
   {{0x81e94079,0xc5f38079,0xc1a6c028,0x160e9223}},	//   _যার_, চ্ছা_, _ऑर्ग, _सादर_,
   {{0x63a401c6,0x248d8070,0x60c2d224,0x7c365225}},	//   _myin, _ejem_, _siom, ldyr,
   {{0x35a35226,0xe5a34911,0x20e800b4,0xed5a40d9}},	//   _жарг, _жири, nşi_, _тов_,
   {{0x65634065,0x386dd227,0x9f54c0d9,0x245c402d}},	//   ønhe, gher_, звич, _tímu_,
   {{0xfd62d228,0x368ad229,0x6f16522a,0xddc8c53e}},	//   _fitọ, исон_, ntyc, ridž,
   {{0xde888044,0x6288c1ff,0x6f02922b,0xf8c9c0d1}},	//   bịa_, undo, mroc, _vẩn_,
   {{0xddc8c2bc,0x2bba8384,0xd7efc0a7,0x4035122c}},	//   pidž, ेशवा, _оу_, пенс,
   {{0x248d001f,0x6a64c580,0x2baf0048,0x4e168047}},	//   õem_, _tòfo, _घरदा, प्रै_,
   {{0xdfa70359,0xf8c9c35d,0x78a080c7,0x78a38379}},	//   تحدي, _uẩn_, _mkmv, învi,
   {{0xf8ca4314,0xcfe7402a,0x7afb03aa,0x95c805f5}},	//   िदाय, _ফাইন, šuto, жута_,
   {{0x26cb43bb,0xc7adc05f,0x2ca68c47,0x7cc20017}},	//   _suco_, _لڑی_, klod_, _tērp,
   {{0x7658c2c0,0x63ad00b1,0x2c050063,0x3f8c0138}},	//   _hovy, _tzan, _वाटू_, ğdur_,
   {{0xa3af009d,0xe3bf05b1,0x63ad122d,0xa3de8428}},	// [c50] _करि_, meño_, _uzan, _द्ध_,
   {{0x0b88411b,0x2451c066,0x3a75122e,0xea00435d}},	//   істи_, _dámy_, _хлор, _đản_,
   {{0x20e800cc,0x9c7cc053,0x2907922f,0x2ca69230}},	//   cşi_, _pwčl, xuna_, flod_,
   {{0x32d08015,0x6fda4045,0x69c880d9,0xa3d4409d}},	//   _bày_, युदं, _agde, सुआ_,
   {{0x3d07454a,0x130880d9,0xfe734e40,0xddc19231}},	//   _हमके_, жній_, _قدس_, _bolş,
   {{0xe8e000d1,0x9ad38112,0x7d08c0b0,0x7658c089}},	//   _nhớt_, lịkw, kuds, _novy,
   {{0x2ca68588,0xe3bf0070,0x61fb4020,0x6b8d80b4}},	//   blod_, keño_, _ɓull, _ţigă,
   {{0x9f448047,0x20e7c107,0x9ad38044,0xde888efc}},	//   _zemí_, vői_, nịkw, rịa_,
   {{0xaca3c0eb,0x9f44c018,0xa3ea0103,0x68e8817b}},	//   _nhụj, tamá_, यरस_, _ewdd,
   {{0x2fc91232,0xa3e241f9,0x20e7c107,0x9ad3825d}},	//   _agag_, _न्न_, tői_, hịkw,
   {{0xe9d08968,0x99910107,0x69d50036,0x60da817b}},	//   _شغل_, kező_, dcze, _gttm,
   {{0xaca3c0eb,0xa3bd4281,0x2489c070,0x3de3c02a}},	//   _kwọl, ेखा_, _ñam_, _মাওল,
   {{0xdd108166,0x32114036,0x7ae981d6,0x888cc052}},	//   _výťa, _oczy_, _jwet, _דראַ,
   {{0xad25c49f,0x09e20079,0x6459d233,0xdbf64045}},	//   _فرعو, _বাঙা, _howi, ेल्ड_,
   {{0x5fcb8f92,0xe3bf0019,0x9f40434d,0x7e6040b4}},	//   िशाल, beño_, mbié_, _împi,
   {{0x6281d234,0xfd6481c0,0x27ed80a8,0x16194288}},	//   lilo, _airọ, _neen_, न्सर_,
   {{0x29031235,0x7ae98efc,0x63a4000b,0x83fd8107}},	// [c60] arja_, _nwet, _uyin, _elők,
   {{0x6a6044c9,0x1ddd80e9,0xee3700b4,0x7bc981f3}},	//   _löfv, नुमत, _ень_, _ageu,
   {{0x2f1609ca,0x44295236,0xaca3c031,0x4a5b00c3}},	//   læg_, bea_, _awọl, _הדיו,
   {{0xdfcf81b4,0x425641aa,0x6281d237,0x7c29d238}},	//   هيم_, _کنسر, hilo, jeer,
   {{0x290a1239,0x1634923a,0xa3e24021,0x27f24057}},	//   luba_, деля, _न्य_, mayn_,
   {{0x27f2523b,0xa3af054a,0x20d180d1,0x48e30047}},	//   layn_, _करस_, _bái_, टीको_,
   {{0x290a123c,0x7ae9825d,0xf8c9c0d1,0x6f04523d}},	//   nuba_, _ewet, _bẩm_, lric,
   {{0xae0e923e,0x3f6a804c,0x44200327,0xdca3800e}},	//   _सावन_, _либо_, _nbi_, _заси,
   {{0xa01b410d,0x69d50036,0x7ae980bc,0x7658c089}},	//   _kjör, ycze, _gwet, _povy,
   {{0xe678c11b,0x2903123f,0x20d18086,0x60c64017}},	//   ійні_, yrja_, _fái_, _likm,
   {{0x29180166,0x290a1240,0x67240077,0xceb8c036}},	//   jtra_, juba_, _apij, rmę_,
   {{0xb69b010b,0x442940fc,0x38669241,0x7af64051}},	//   grân, xea_, nkor_, ksyt,
   {{0xe29acd9b,0x6f09c070,0x5334cb24,0xf1bf402d}},	//   _лад_, cuec, _целт, čšie_,
   {{0x6447c017,0x442942c0,0xccf88047,0x6459d242}},	//   ējie, wea_, _kvě_, _zowi,
   {{0x69d51243,0x8bec002a,0x6e94043e,0x38669244}},	//   rcze, _কারন_, хиру, kkor_,
   {{0x9f4b0347,0x765a9245,0x69b34314,0x2b401246}},	//   lací_, _loty, _अरबी, _fric_,
   {{0x5a3543f7,0xb066004c,0xfbd041b4,0x27ed814b}},	// [c70] мнат, ssää, اتف_, _reen_,
   {{0x201f8077,0x27ed8093,0x7c29d247,0x290a1248}},	//   _sbui_, _seen_, zeer, buba_,
   {{0x51f44032,0x7c29d249,0x32d2c0d1,0x44b54cfc}},	//   عسكر, yeer, _lây_, _обос,
   {{0x09c5002a,0x6b82124a,0x78a2d24b,0x27f24149}},	//   ্রদা, _žogi, _nkov, cayn_,
   {{0xcc564942,0x9f4b0047,0x27ed84f1,0x26c58140}},	//   _חברי_, kací_, _veen_, _pilo_,
   {{0x61ee524c,0xddc882bc,0x9f4486ed,0x6281c232}},	//   _gebl, _emdž, _demà_, xilo,
   {{0x6281d24d,0x9f4b0531,0x19944dae,0x6e37124e}},	//   vilo, dací_, _заря, _maxb,
   {{0x7648924f,0x69c3c036,0x2ca945bb,0x0b45c7c2}},	//   _endy, _रणबी, nlad_, днин,
   {{0x26c580e2,0x2ca941f4,0x386d8469,0x28cfc4fb}},	//   _tilo_, ilad_, _iler_, _संहि,
   {{0xddc3c0b4,0x4d65d250,0x27f242d6,0x673bc089}},	//   _conş, дков, zayn_, rvuj,
   {{0x382a0167,0x67241251,0x356b9252,0x44201253}},	//   ожно_, _spij, _уран_, _pbi_,
   {{0x6279c066,0x6a605254,0xdb1bc018,0xddd886f0}},	//   jňov, _höft, scuñ, mivš,
   {{0x7bcbd255,0x61aa40e9,0xddd882a3,0x0876c009}},	//   _iggu, _कर्ष, livš, _קענט_,
   {{0x38669256,0x9f4f801e,0x27f241c8,0x6f045257}},	//   zkor_, gagé_, wayn_, vric,
   {{0x845a5124,0x2ca941c8,0x386d8070,0xdca651fb}},	//   орат_, flad_, _oler_, дави,
   {{0x290a1258,0x2b40068a,0x6f0b8339,0x2ca95259}},	//   ruba_, _tric_, kugc, glad_,
   {{0x32d2c082,0xdca3525a,0x672400e0,0x60ce525b}},	// [c80] _xây_, тати, _upij, _subm,
   {{0x66f30027,0x2ca9525c,0x60ce525d,0x7af6525e}},	//   _अबतक_, alad_, _pubm, rsyt,
   {{0xddd8841b,0x9f42002d,0x78a9d25f,0x60c65260}},	//   jivš, jakú_, klev, _tikm,
   {{0x06e3c079,0x81e78079,0x78a9c047,0x9f4b0047}},	//   _মিনি, _ভাগ_, jlev, zací_,
   {{0x20d3c00c,0xa51e0d13,0xfc3f4359,0x61ee5261}},	//   _lãi_, _पहुच_, _thír_, _tebl,
   {{0xa3c1c5cb,0x6d418056,0x200f823f,0x44225262}},	//   ंधन_, _brla, aggi_, _hbk_,
   {{0x628e1263,0x2ba50d6c,0x645b9264,0x9985c0a0}},	//   inbo, _गुना, _foui, delů_,
   {{0x26cfc6df,0x628fc01e,0x8b26801b,0x6c31805f}},	//   _bugo_, écon, _одбе, _مہما,
   {{0x765a9265,0x41c9c9cb,0x2905cbf5,0x7d0a8570}},	//   _toty, रशंस, erla_, sufs,
   {{0x5186c1c3,0x6d418011,0x32d2c0d1,0x7bcbc11c}},	//   дума, _frla, _vây_, _eggu,
   {{0x6d419266,0x765c5267,0x4422414d,0xfca9c68b}},	//   _grla, _mory, _obk_, _کالو_,
   {{0x628e0820,0x32060020,0xcec8c0d1,0x7af68026}},	//   enbo, _ɓoye_, _lội_, šytu,
   {{0xa6db4086,0x7ae29268,0x44fa8017,0x2c75002e}},	//   _orða, npot, lī_, _aúdù_,
   {{0x31351269,0x4422526a,0x1994c039,0x7c2b8036}},	//   негр, _abk_, _паля, zegr,
   {{0x44fa8017,0x3e7081c0,0x20d3c35d,0x9f4f87b0}},	//   nī_, _gàte_, _gãi_, ragé_,
   {{0x26cfc070,0x628e126b,0x99580047,0xa3b5c17e}},	//   _yugo_, anbo, náře_, छेक_,
   {{0x9c1300eb,0x26cfc004,0x44224011,0x7c22d26c}},	// [c90] _fọre, _xugo_, _dbk_, _mbor,
   {{0xcec8c0d1,0x44224140,0xfc4605e5,0x2ba502ea}},	//   _bội_, _ebk_, šíte_, _गुया,
   {{0x61f500b5,0x69dcc086,0xf1a7473c,0x25a980e2}},	//   mazl, ðrey, фран, ƙali_,
   {{0x7aed126d,0x1bd58e03,0xf1df4c4b,0x6283926e}},	//   _kwat, ходя, _प्रन, wino,
   {{0x290cd26f,0x38b201fc,0x443b4070,0x645d5270}},	//   huda_, nára_, mdq_, _iosi,
   {{0x8cb95271,0x290cd272,0x7bcbc05c,0x765c5273}},	//   ्दको, kuda_, _sggu, _gory,
   {{0x290cd274,0x64ca5275,0x442b85f4,0x6da29276}},	//   juda_, िदृश, _ºc_, лиша,
   {{0x64499277,0x44395278,0xfc31c1aa,0x38b21279}},	//   _unei, _jas_, احث_, kára_,
   {{0x386946eb,0x7f42d27a,0x7aed025d,0xa3d44185}},	//   ikar_, _croq, _nwat, सुट_,
   {{0x6285527b,0xc3324626,0x7c22d27c,0x60c9804c}},	//   niho, נוי_, _ebor, _hiem,
   {{0x27efd27d,0x3869527e,0x7c2d41a8,0x0086127f}},	//   _tegn_, kkar_, kear, елно,
   {{0x38694041,0xac19d280,0x7c22c171,0xa775d281}},	//   jkar_, _ходу_, _gbor, _плеч,
   {{0x270d808f,0x442244f5,0x38b205ca,0x26ddc449}},	//   _समोर_, _rbk_, gára_, _utwo_,
   {{0x7c22d282,0x877a821d,0x64620036,0xa3e25283}},	//   _zbor, לארי, _świą, नुन_,
   {{0x26179284,0xaca3c112,0x8af0403a,0xe8180185}},	//   _नानी_, _ebụm, yyəs, _थापा_,
   {{0x38b20083,0x645d5285,0x6b84c077,0xdca640a9}},	//   bára_, _cosi, _žigi, хаби,
   {{0x2d8742b0,0xdb1c4080,0x69c3003c,0x765c5286}},	// [ca0] únen_, _özüm, _únen, _pory,
   {{0x60c9804c,0x44395287,0x62855288,0xa3cc4027}},	//   _aiem, _eas_, giho, _ललक_,
   {{0x4422407a,0x644bd093,0x63a980f7,0xe853001c}},	//   _tbk_, _ongi, _ayen, _شنید,
   {{0x61e34676,0xcec8c00c,0x63a99289,0x26d200f7}},	//   ınla, _vội_, _byen, _kuyo_,
   {{0x60c9928a,0x9f3480d9,0x80d60045,0x27f2002f}},	//   _diem, телі, _मंडे, _meyn_,
   {{0x290cd28b,0x6e2e128c,0x2000007a,0xe45fc051}},	//   yuda_, nebb, _ldii_, öön_,
   {{0x4420528d,0x26d2002f,0x69dc528e,0x2b40528f}},	//   ofi_, _luyo_, _ifre, lvic_,
   {{0x20125290,0x7ae44150,0x44205291,0x6e2e1292}},	//   ngyi_, opit, nfi_, hebb,
   {{0x91fc805e,0xdb1d0107,0x78a0d293,0x3d1c825c}},	//   _blāt, lcsö, romv, _महके_,
   {{0x7c2d4232,0x7c3bd294,0xda1040e4,0x38b201fc}},	//   zear, adur, ालित_, vára_,
   {{0x6d43d295,0x6594d296,0x7c24011c,0x44249297}},	//   _crna, тану, _bbir, _kbm_,
   {{0x26d200f8,0x7f441298,0xa3b141f9,0x7c39d299}},	//   _buyo_, _briq, _ओरल_, _gawr,
   {{0xbfab03d0,0x4424929a,0x7c2d529b,0x386940e5}},	//   ятое_, _mbm_, vear, vkar_,
   {{0x1ee7405f,0x9c138044,0x386940e2,0x78a280b2}},	//   ہوری_, pọgh, wkar_, hoov,
   {{0xe80a129c,0x38b2129d,0x6e3a929e,0x3ced05c7}},	//   _वाचा_, sára_, _matb, ćevo_,
   {{0xe8e000d1,0x7f4400d2,0x40344026,0x91fc8017}},	//   _chốt_, _friq, лесс, _klās,
   {{0x3eb84639,0x9e07529f,0x76890039,0xf8bf001e}},	// [cb0] _bhrt_, ечел, ržyb, mmé_,
   {{0x69dad2a0,0x645d52a1,0x80b34028,0x7c2f12a2}},	//   ncte, _wosi, _आठवे, lecr,
   {{0xf77f4669,0x6f0f12a3,0x63a98105,0x7c2d52a4}},	//   _reçu_, lucc, _syen, pear,
   {{0x3ea5805c,0x6f1d015d,0x69dc52a5,0x81e9402a}},	//   _sklt_, otsc, _efre, _যাও_,
   {{0x442dc32e,0x60c992a6,0x6f0f102f,0x6e3a92a7}},	//   vee_, _viem, nucc, _batb,
   {{0x7cc90036,0x44248402,0x27e952a8,0x2f234017}},	//   _ośro, _ebm_, lban_, rīgā_,
   {{0xba74861e,0x69c8006f,0x6f1d1062,0x3869c09c}},	//   دانت, ždev, htsc, _ƴar_,
   {{0x6f0489b7,0x69ce4011,0x69dac0b4,0x442dc0f8}},	//   šica, _zgbe, ecte, uee_,
   {{0x9f4b12a9,0x6f0f00b3,0xaed5811b,0x6d5cd2aa}},	//   yacá_, jucc, _розш, äran,
   {{0x6f1bd2ab,0x78ad52ac,0x6d43c450,0x200012ad}},	//   rtuc, hlav, _prna, _sdii_,
   {{0x628712ae,0x6d450046,0xd00a12af,0x6e2e0107}},	//   dijo, _nrha, мене_, vebb,
   {{0x9f52401e,0x644d0032,0x224986df,0x6aa1ccbc}},	//   sayé_, _cnai, ɓaka_, solf,
   {{0x51218834,0x207ac009,0x443b0085,0x62870732}},	//   _महुआ_, _קאנא, _daq_, fijo,
   {{0x412a12b0,0x7c3b92b1,0x24868036,0x3e644107}},	//   мого_, _laur, ziom_, _jött_,
   {{0xada607de,0x442052b2,0x6f1d12b3,0x443b12b4}},	//   тавл, tfi_, atsc, _faq_,
   {{0x6e2e12b5,0x69dc52b6,0x7c240682,0x6f0f12b7}},	//   sebb, _sfre, _ubir, bucc,
   {{0x7d1c12b8,0xbc1b0093,0x6b634823,0x2ee0ce2b}},	// [cc0] strs, _חופש, акта, _çift_,
   {{0x09c5c02a,0x2b404247,0x7afbc8a1,0x7bcf475d}},	//   _শ্যা, rvic_, isut, _egcu,
   {{0x3860021b,0xa3a8d2b9,0x67298083,0x6f09c0fa}},	//   _koir_, _खुन_, _apej, hrec,
   {{0x78ad52ba,0x442f80ed,0x443b0057,0xe7868119}},	//   clav, geg_, _xaq_, куло,
   {{0x6aa383ad,0x6f09d2bb,0x3eacc415,0x3860005e}},	//   fonf, jrec, yldt_, _moir_,
   {{0x442f809d,0x3e7085ef,0x3860001e,0x290e8cc6}},	//   aeg_, _bàta_, _loir_, tufa_,
   {{0x442f92bc,0x764e4041,0xeb9f0240,0x3e644041}},	//   beg_, _inby, ngør_, _dött_,
   {{0x291c805f,0x6d41c6f0,0x290e8283,0x75374009}},	//   rtva_, dvla, rufa_, _באלד_,
   {{0x6f09d2bd,0x290e92be,0x221692bf,0x38b90107}},	//   grec, sufa_, _афер, nére_,
   {{0x290a006c,0x27e94107,0x3e6444c9,0x91ba92c0}},	//   krba_, zban_, _gött_, _قطار_,
   {{0xf8ca00d1,0x7afbc0b2,0xd82fc186,0x78a44051}},	//   _lẩu_, asut, _кэ_, koiv,
   {{0x59d50185,0xb97b8087,0x5f06c026,0xdddc0007}},	//   _दलहर, _קנאי, _азда, virš,
   {{0x7f4292c1,0x38b9005f,0x9b5801bc,0xdca3cb3d}},	//   nvoq, jére_, вият_, _таци,
   {{0x26f312c2,0x7f4292c3,0x7aedc2d6,0x21384011}},	//   _अबीर_, ivoq, _çata, _osrh_,
   {{0x644d0871,0x9f4b4166,0x2ba50b35,0x6d4a4854}},	//   _tnai, _vecí_, _गँवा, åfal,
   {{0x644d12c4,0x6d414032,0x764e4141,0x2246009c}},	//   _unai, _álai, _anby, _ɗoki_,
   {{0x6e3c52c5,0x78ad52c6,0x59a992c7,0x26cc846a}},	// [cd0] _barb, rlav, _चुनर, _oido_,
   {{0x442f92c8,0x160e863c,0x2ba75223,0xd5674176}},	//   weg_, _सागर_, _कुणा, ктеп,
   {{0x442f92c9,0x5bcb915e,0x7afd12ca,0x63ad01aa}},	//   teg_, िश्व, lsst, _hyan,
   {{0x63ad12cb,0xb4bf8a3c,0x9f520053,0x3e6444c9}},	//   _kyan, ीदे_, _beyè_, _sött_,
   {{0xef1f00b5,0x7875c070,0xe7e28b35,0xe73d4047}},	//   ntü_, _jáve, खड़ा_, _kříž,
   {{0xa3acc08f,0x6288c46a,0x9f420531,0x248952cc}},	//   _गरज_, jido, jaký_, liam_,
   {{0x33d5d2cd,0x63abd2ce,0x4426c1ae,0xdb008089}},	//   ліпт, _sygn, _bbo_, _vymá,
   {{0x7afbd2aa,0x6e3c417a,0x7c3d405c,0x6d4752cf}},	//   tsut, _zarb, _jasr, _irja,
   {{0x7c84809b,0x7c3d52d0,0x2cadd2d1,0x7afd12d2}},	//   _туре, _masr, rled_, jsst,
   {{0x7ead8166,0x2489423b,0x78a292d3,0xb062c051}},	//   kúpi, hiam_, čove, _äänt,
   {{0xb7d601c0,0x644f52d4,0x24894007,0xa3d780aa}},	//   _aṣap, _onci, kiam_, _सला_,
   {{0xa3df09fd,0xf2c90009,0x6f09d2d5,0x63ad12d6}},	//   दुल_, _זע_, prec, _byan,
   {{0x7cd3c119,0xc8cfce18,0x2b46c016,0x9ac4c085}},	//   _mări, _संकट, _groc_, _baċċ,
   {{0x63ad12d7,0xa8064676,0xd295011b,0x7c2292d8}},	//   _dyan, zdığ, арсь, zfor,
   {{0x05a40027,0x7c9652d9,0x64aac020,0xf1a4017e}},	//   _खुशब, грац, _iƙir, _खुशन,
   {{0x63ad0053,0x6a79c031,0x248952da,0x645bd2db}},	//   _fyan, _fùfù, giam_, njui,
   {{0x443fd2dc,0x3eba000c,0x4e138185,0x2b59c4c9}},	// [ce0] idu_, _thpt_, ठलाई_, äsch_,
   {{0x66c94007,0xfaaa401c,0x24924036,0x443fd2dd}},	//   _užkl, رهاي_, snym_, hdu_,
   {{0x5d8641b4,0x8c4692de,0x85f6c009,0x600a8505}},	//   دلال, леже, רמעס_, енем_,
   {{0xfc32479d,0x248952df,0x7ae40077,0x6288d2e0}},	//   _احد_, ciam_, _ktit, zido,
   {{0x2ca4c2bc,0xf41f12e1,0xab62803a,0x628501f4}},	//   vomd_, onär_, _şübh, _ymho,
   {{0x291ed2e2,0x443252e3,0x2c71c047,0xda72405f}},	//   ytta_, ley_, _ráda_, _اُس_,
   {{0x20258397,0xaad84048,0x46d84d91,0x386240e5}},	//   úsið_, _भूतक, _भूतह, _kokr_,
   {{0x386dcb0e,0x6603c23f,0x6d5cc09d,0x8c3dc0b4}},	//   gker_, _adnk, äram, toşa,
   {{0xb274c01b,0x60cd12e4,0x3a74d2e5,0x2e168646}},	//   илиш, _riam, илир, _مباح,
   {{0x27e002cb,0x44324057,0x60c292e6,0x2bc0c715}},	//   _afin_, hey_, lmom, शेषा,
   {{0x6a64c0b6,0x1da405b9,0x59d6c062,0x443dd2e7}},	//   _bòfr, _खुलत, डखबर, _faw_,
   {{0x443dd2e8,0x628a92e9,0x291ed2ea,0x7ae40303}},	//   _gaw_, lifo, rtta_, _btit,
   {{0x27e000f6,0x7ae2c12c,0x7afd12eb,0x3ea5c107}},	//   _dfin_, _utot, usst, bolt_,
   {{0x6440d2ec,0x6e3e12ed,0x27e0005e,0xf2df42cd}},	//   ldmi, _capb, _efin_, _brân_,
   {{0x7c3d52ee,0x443dc0e2,0xdcbb41bc,0xceb38087}},	//   _pasr, _yaw_, еща_, מיש_,
   {{0x60d547ca,0x443dd2ef,0x9c1380eb,0x7afd12f0}},	//   _ruzm, _xaw_, kọah, psst,
   {{0x2ca692f1,0x6e95011b,0x3b55431f,0x9c1400eb}},	// [cf0] dood_, _випу, шкар, _mọlt,
   {{0x6d4892f2,0x248952f3,0xda7847ea,0xdddc4053}},	//   _orda, siam_, лях_, _forō,
   {{0x386dd2f4,0x66010086,0x628fc01e,0xa9354156}},	//   yker_, ólku, écoi, рееш,
   {{0x60c292f5,0x261b00b2,0x443fd2f6,0x7cd18017}},	//   gmom, _बाडी_, xdu_, _mārt,
   {{0x64db008f,0x7e6192f7,0x07a58748,0x61f552f8}},	//   _मंडळ, _polp, јалн, _tezl,
   {{0x6d488043,0xcb668c4d,0x20048141,0x443dc0c3}},	//   _brda, раше_, _edmi_, _saw_,
   {{0x3ea5d2f9,0xe509c8c0,0xe6dec044,0xf40280b4}},	//   volt_, _विधि_, _rịọ_, faţă_,
   {{0x34958077,0x9b05c077,0xfaff013b,0x2019c0b2}},	//   _табр, азид, ksë_, üsi_,
   {{0xe456c097,0x6d4892fa,0x2ba50e31,0x645bd2fb}},	//   ржы_, _erda, _गुला, rjui,
   {{0x161c8028,0x443240b5,0xe8180185,0xa2b38048}},	//   _नायर_, zey_, _थाहा_, ेगळ्,
   {{0x672d12fc,0x3ea5c05f,0xb035c04c,0x6e3e007a}},	//   _apaj, rolt_, _внеш, _rapb,
   {{0x6739c23b,0x60cf4047,0x7ae401cb,0xf7460c71}},	//   _tswj, _nicm, _ptit, аемо,
   {{0x61f712fd,0xe3b20425,0x38624010,0xe7b04079}},	//   _bexl, ترد_, _rokr_, _কল্য,
   {{0x2b4906ed,0x6d4e8004,0x3ea78053,0x60cf4032}},	//   _drac_, _ábac, nont_, _aicm,
   {{0x442902cd,0x6f0d52fe,0x33f652ff,0xb05b0025}},	//   _fba_, erac, ичас, mmän,
   {{0xcec8c015,0xa7fb403c,0x27edd300,0x60cf4dda}},	//   _hộp_, _poña, nben_, _cicm,
   {{0x06865301,0xfc3f410b,0x7eb04051,0x1e86478b}},	// [d00] аган, _daí_, läpi, алам,
   {{0x38b91302,0x3ea780c4,0x228c0031,0x63a680d9}},	//   méra_, jont_, _dókè_, _økni,
   {{0x60c29303,0x61fc1304,0x1dabc6ca,0x38b91305}},	//   tmom, marl, _घुमत, léra_,
   {{0x320580e2,0xa01b0025,0x628b41cb,0x62874073}},	//   _adly_, tiöi, égor, _emjo,
   {{0xeb97402b,0x78785306,0x3ea79307,0x27e04360}},	//   _вия_, _cíve, font_, mcin_,
   {{0xcec8c00c,0x60c45308,0x7c299309,0x62348156}},	//   _nộp_, lmim, _eber, секу,
   {{0xb05b0fd0,0x2ca680b2,0xe2a70397,0x20dc0031}},	//   dmän, pood_, úðir_, _jíi_,
   {{0xec168646,0x27edc107,0x628a930a,0x26ced30b}},	//   _خورد, gben_, sifo, _sifo_,
   {{0x61faced8,0x66e3930c,0xee3a85e4,0xc6f7c039}},	//   tatl, _мота, _ина_, аных_,
   {{0x644281a8,0x645d0022,0xdd1c002d,0xa6ca930d}},	//   ldoi, wjsi, _záťa, _شوال_,
   {{0x44290d6e,0x26cec150,0x67d50119,0x272083e2}},	//   _pba_, _vifo_, йону, lòn_,
   {{0x4fa6c4df,0x61f70098,0xe7e84285,0x7c29821b}},	//   _киев, _sexl, टुमा_, _xber,
   {{0x26ced30e,0x7ae9c016,0x61fad30f,0x44291310}},	//   _tifo_, cpet, patl, _vba_,
   {{0x4efbc093,0x248b02bc,0x64428051,0x20dc0083}},	//   _יהדו, sicm_, hdoi, _bíi_,
   {{0xe937c032,0xfc3f4070,0x3abbc21d,0x67229311}},	//   _نسيت_, _paí_, _שמונ, htoj,
   {{0x38a1c036,0x7cd3c119,0x63af5312,0x6f02c123}},	//   wórz_, _căru, _pycn, _kvoc,
   {{0xe2ab03be,0xb4b74027,0xcc340701,0x78ad0f2d}},	// [d10] _لادن_, _छठी_, _ذريع, _ikav,
   {{0x64409313,0x27edc05f,0xe6135314,0x7e5440d9}},	//   _aami, zben_, تشر_, овує,
   {{0x44269315,0x27edc05f,0x67229316,0x06e6802a}},	//   ffo_, yben_, etoj, _নিষি,
   {{0x6288805e,0x88bcc047,0x291348ca,0x2ba8839a}},	//   _amdo, _zpěv, ruxa_, _छुहा,
   {{0x28c80f92,0x60db4011,0x3ea79317,0x60d8c0d2}},	//   रगति, _čumu, tont_, _luvm,
   {{0x7878430d,0x29134018,0x53380052,0x673d4085}},	//   _víve, puxa_, ינדן_, _issj,
   {{0x26d95318,0x20d180f6,0x5d33805f,0x60408112}},	//   _huso_, _aġir_, تہائ, _ịmef,
   {{0x7875ca5d,0x67228022,0xfc3f0032,0xa7fb4070}},	//   _báva, btoj, ilís_, _moño,
   {{0x61fc1319,0x161e4045,0x2901531a,0x61f8d31b}},	//   yarl, _पामर_, lsha_, _bevl,
   {{0x6f02c038,0x27edc05f,0x26d9531c,0x63bb931d}},	//   _dvoc, sben_, _muso_, _izun,
   {{0x81a94079,0x8d74849f,0x61408107,0x2901516b}},	//   খের_, _واما, rálá, nsha_,
   {{0xfc320032,0x3e764086,0xb05b131e,0x06e8402a}},	//   أحد_, _mæta_, smän, _পিসি,
   {{0x38b2131f,0x889a8087,0xe7a75320,0xb05b0051}},	//   nári_, רברי, _कुलप, mmäl,
   {{0x7cd3c0cc,0x27fd802c,0x2c754854,0xd5b1835d}},	//   _săru, hawn_, _råda_, _ký_,
   {{0x76438033,0x6f02c570,0x7cd3c0cc,0x673d40f6}},	//   idny, _zvoc, _păru, _assj,
   {{0x28d0048b,0x475a00c5,0x38b2002d,0x63bb9321}},	//   _सूचि, _броя_, kári_, _ozun,
   {{0x6e35006f,0x27e05322,0x63a91323,0xd5b180d1}},	// [d20] bezb, rcin_, üent, _lý_,
   {{0x77c74187,0x78a9c15d,0x26d1409c,0xe3b2005f}},	//   слуг_, hoev, _cizo_, _ورک_,
   {{0xa96a1324,0x628e1325,0x26195326,0xd6cf4032}},	//   _сина_, mibo, _पारी_, رقم_,
   {{0x67228051,0x69d55327,0x7af6014b,0xdbd70414}},	//   ttoj, _egze, _kwyt, _mäßi,
   {{0x44269328,0x6722839d,0x44f5402d,0x64429329}},	//   rfo_, utoj, ať_, rdoi,
   {{0x628e132a,0x8b060064,0xbb3b0087,0x6440932b}},	//   nibo, częś, טעני, _wami,
   {{0x649601b7,0x4426800d,0x61fe532c,0x8c46932d}},	//   rġij, pfo_, mapl, _леве,
   {{0x6f0400b3,0xb176c015,0x76438033,0x6ab2c288}},	//   _ovic, _ngượ, adny, ुग्र,
   {{0xe819d32e,0xb8ff89fd,0x25b8509f,0x6d4ac247}},	//   _धारा_, _धू_, _अरुण, _srfa,
   {{0x527b4009,0x7641932f,0xda658182,0x9f4fc060}},	//   ָנטא, _galy, _والي, _degà_,
   {{0xa96a879e,0x499a80c5,0x321e82c0,0x915f00d1}},	//   _حمام_, _стая_, _icty_, _mặt_,
   {{0x6a6b00cb,0x7af601f4,0x2db78052,0x6f028070}},	//   _lüft, _bwyt, _פלאן_, osoc,
   {{0x3e970032,0x83a7417e,0x9f4000b9,0x6f040c81}},	//   مؤسس, _कुंआ, _beiñ_, _cvic,
   {{0x629880fa,0x3f804007,0x628e1330,0x171bc052}},	//   nnvo, dziu_, gibo, _עווע,
   {{0x26d14019,0x3866d331,0x05d3c25b,0x7d1c8730}},	//   _rizo_, _koor_, _عزوج, _årsd,
   {{0x248900e2,0x5b151332,0x99850107,0x63ad8036}},	//   _umam_, _дмит, ülő_, żani,
   {{0xf2df40d1,0x0ea888b8,0x3e764086,0x20090398}},	// [d30] _trâm_, गवाड, _sæta_, _idai_,
   {{0x51f8410e,0x6442c24f,0x248dd333,0xacf80036}},	//   йную_, _laoi, ziem_, _żółt,
   {{0xd9994032,0x629c4303,0x27e989e4,0x3e6b8125}},	//   جنات_, _djro, ñano_, _møtt_,
   {{0x29015334,0x6442d335,0x68e4c5e5,0x9f4000b9}},	//   rsha_, _naoi, _čidl, _zeiñ_,
   {{0x4ad9008f,0x290140f6,0x27fd802c,0x6aaa9336}},	//   ढदिव, ssha_, rawn_, foff,
   {{0x63bd4017,0x6d46c017,0x59c8d337,0xbebb413b}},	//   _izsn, ākaj, रधार, _epër,
   {{0x6cc5d338,0x7aed5339,0xf5568032,0x44294032}},	//   ойка, lpat, قلوب_, ofa_,
   {{0x7b08410d,0x628e00f7,0x76438033,0x38bac13b}},	//   _ástæ, zibo, sdny, tëra_,
   {{0x61e3c4a7,0xb7bd8119,0x7641933a,0xeb99c911}},	//   _pfnl, _obţi, _taly, рип_,
   {{0x29030374,0x2f100086,0xd10983a9,0x69a488c5}},	//   ksja_, _lögð_, _نقطه_, _चुकी,
   {{0x7f4d133b,0x16200028,0x645dc0fa,0xa3d9533c}},	//   _araq, _बाबर_, ösis, ाशा_,
   {{0x2bbe4045,0x22434043,0x4429533d,0x644441c8}},	//   ्धमा, _lajk_, jfa_, xdii,
   {{0x27ff0086,0x7c29d33e,0x7f4d133f,0x3e70805e}},	//   ðuna_, mfer, _craq, _bàth_,
   {{0x479ac052,0x8f9ac323,0x7ae982c0,0x7c2d1340}},	//   _דינס, _דיני, _mtet, _ebar,
   {{0xe2971341,0x9f59413b,0x76454402,0xa01b0d42}},	//   цар_, _fesë_, ddhy, giös,
   {{0x7ae9804c,0x7c2d1342,0x7f4d1343,0x57ea532d}},	//   _otet, _gbar, _fraq, рдам_,
   {{0x61fe5344,0xd5b8403f,0x22434043,0x6d415345}},	// [d40] tapl, _šā_, _bajk_, _šlap,
   {{0x3f805346,0x7c2d1347,0xaec3411b,0x29058011}},	//   rziu_, _zbar, дбул, _ovla_,
   {{0x7c2d002f,0x64441348,0xed5a0798,0x6ee502cf}},	//   _ybar, _kaii, _тон_, _وسیل,
   {{0x136a9349,0xfbae0048,0xf220009d,0x2b4d8061}},	//   ишли_, _घडाम, _बाड़_, _brec_,
   {{0x2b4d8315,0x644405bb,0x91de0314,0xf047805f}},	//   _crec_, _maii, _मलाई, تعلی,
   {{0x2c7c4031,0x0cb4c3af,0x25ad00cc,0x2a67c0ce}},	//   _díde_, ुष्म, şele_, _nonb_,
   {{0x6aaa8824,0x61fa934a,0xa5074def,0x64560094}},	//   roff, _vetl, _мера_, _onyi,
   {{0x6aaa934b,0x3a38015d,0x629e0011,0x7643d34c}},	//   soff, herp_, _ljpo, _aany,
   {{0x6f04534d,0x2b4d934e,0x63068de9,0x1fa3c0b4}},	//   nsic, _grec_, _ذوال, дрэг,
   {{0x7c2d134f,0x0f574093,0x6d4e5350,0xf76fc032}},	//   _sbar, קיים_, _krba, ضاً_,
   {{0x98ba40ce,0x3866c2a4,0x2b401351,0x80d603ae}},	//   _aspč_, _toor_, _asic_, _मंगे,
   {{0xd6e2002a,0x06e2002a,0x2c620089,0xb05b0025}},	//   _বিজয, _বিজি, _kódy_, mmäk,
   {{0x27e6c3e2,0x6b829352,0x2b401353,0x68edc011}},	//   _ifon_, nzog, _csic_, _čade,
   {{0x64461354,0x29110036,0x2c620089,0x44201355}},	//   adki, trza_, _módy_, _eci_,
   {{0xb05b0025,0x6f064147,0xf3ff435d,0xafdb0176}},	//   nmäk, _avkc, _doãn_, ldøm,
   {{0x2b4951ae,0x9b894032,0x69d84007,0x7643d356}},	//   tvac_, منزل_, žvel, _zany,
   {{0x6f04405e,0xa3e00021,0x752dc11f,0x6d4804c9}},	// [d50] gsic, _तलत_, _ćazi, ådar,
   {{0x9f44802e,0x66c0105e,0x69d70073,0x06e21357}},	//   _lemó_, töke, _ugxe, _বিচি,
   {{0x629ac051,0x2fd981b4,0xa3cac048,0x61fc5358}},	//   into, مواد_, ळेत_, _derl,
   {{0x7c594032,0x7e7a9359,0x44200303,0x60c2d35a}},	//   _الحر_, _altp, _xci_, _nhom,
   {{0xa85a40c3,0x9f408086,0xdddc402d,0x91e5935b}},	//   _הדרכ, úið_, _smrť, поле,
   {{0x3897c0b4,0x7aedd35c,0x00000000,0x00000000}},	//   mări_, _çati, --, --,
   {{0x61e541b4,0xe5f800c3,0x2d830036,0x6d4e8359}},	//   mchl, חזור_, nzje_, _ábal,
   {{0x442d8ef3,0x2b4d935d,0x319c0916,0xa99c00c3}},	//   _ube_, _trec_, יבונ, יבור,
   {{0x61e54e89,0x60dc409c,0xbc568089,0x80d480aa}},	//   ochl, _zurm, ššíc, _बूटे,
   {{0x2918000d,0x27e6c171,0x673bc1e7,0x60c2d35e}},	//   yura_, _efon_, rwuj, _ehom,
   {{0x6444135f,0x3eb9c017,0x291800fc,0x7c29d360}},	//   _paii, ēst_, xura_, pfer,
   {{0x6f044be5,0x3a3807f5,0x6b8dc06f,0x88bd0047}},	//   ysic, werp_, _žagu, stěn,
   {{0x7645005c,0x7bd9c112,0x20c1c032,0x64960166}},	//   _bahy, _igwu, róid_, jšie,
   {{0x2cadc0bf,0xbb42c7e3,0x68e95361,0xb6ccc91a}},	//   loed_, _чешк, _čedn, şürü,
   {{0x44390642,0x95cbc051,0x81b4002a,0x15fac0c3}},	//   bes_, _туда_, জেন_, _ההצע,
   {{0x6601d362,0x53a61363,0x26ddd364,0x60c9d365}},	//   lalk, _найб, _kuwo_, nmem,
   {{0x3aeb405f,0x60c41366,0x6d419367,0x941d408f}},	// [d60] مبلی_, _ihim, _lsla, _फारच_,
   {{0xdb064036,0x27f25368,0x2cadd369,0xf09f4031}},	//   _szkó, sbyn_, hoed_, _ejà_,
   {{0x78b64166,0x7bd9c0eb,0xf992001c,0x4ddb00c3}},	//   plyv, _ogwu, _سبد_, _לחיו,
   {{0x6d5c84ff,0x7eb4c6ed,0xdca64d9a,0x3897c119}},	//   _àrai, ràpi, _хами, bări_,
   {{0x60c2c07a,0x3897c119,0x2245936a,0x6d46c017}},	//   _rhom, cări_, _balk_, ākai,
   {{0x6601d36b,0xd6d9811b,0x2905d36c,0x61fe0303}},	//   jalk, іті_, ksla_, _jepl,
   {{0xa9678267,0x442fd36d,0x427b4052,0xe820c036}},	//   зија_, _bbg_, _פאלג, _यादा_,
   {{0x387fd36e,0xc19b4093,0x4439136f,0x0d77401c}},	//   ghur_, _השלי, xes_, _عینک_,
   {{0x98a38119,0x76aac051,0x44224b87,0x38960017}},	//   _чите, йтов_, _mck_, nāru_,
   {{0x44391370,0x7bd9cefc,0x877b84e0,0x3a06c05f}},	//   wes_, _egwu, _האמי, سکتی_,
   {{0x3897c119,0x2cadc033,0x24804033,0x60c41371}},	//   zări_, boed_, khim_, _bhim,
   {{0x387fc269,0x60c41372,0x5fbe4fb2,0x43951373}},	//   chur_, _chim, ्धाल, дамс,
   {{0x61e55374,0x3869050e,0x291a402f,0x60d602cd}},	//   ychl, _voar_, hupa_, _diym,
   {{0x6d419375,0x60c40053,0x6d5cc09d,0xd357c0c3}},	//   _ysla, _ehim, äras, _מידי_,
   {{0x68e9406f,0x44e1c02e,0xf1a40b54,0x78ad5376}},	//   _čedo, _gó_, ертн, toav,
   {{0x3897c119,0x2db7c093,0x60c400b4,0x6e3ac107}},	//   tări_, _מלון_, _ghim, letb,
   {{0x32014047,0x27e9015a,0xe2aa001c,0x78ad5377}},	// [d70] tahy_, _ifan_, _ژاپن_, roav,
   {{0x60c9c156,0xf7704865,0x3897c119,0x7648c1f4}},	//   zmem, داف_, rări_, nddy,
   {{0x61e55378,0x291a4034,0x32014089,0xd5c101f9}},	//   rchl, gupa_, rahy_, _एरिज,
   {{0x6a734165,0x81d9002a,0x32014089,0xe3b085d3}},	//   _sıfı, ারও_, sahy_, گرم_,
   {{0x6e3ac8e9,0x6601d379,0x6016c526,0xceb8c026}},	//   ketb, yalk, zümü, klę_,
   {{0x7c2d435b,0x2905d37a,0x52da002a,0xe3b08231}},	//   lfar, ysla_, বীকৃ, درم_,
   {{0x6d344819,0x787f00fd,0x27e9010d,0xa2d98045}},	//   _перф, _zëve, _ofan_, _फंक्,
   {{0x6a70137b,0x248d806f,0x7658c0b6,0x01bf002a}},	//   _häft, _umem_, _anvy, _আলাদ,
   {{0x22458093,0xaec5c119,0x7aed137c,0x7c22c05e}},	//   _talk_, мбил, _ntat, _dcor,
   {{0x3e89c11b,0x4df4c09b,0xfe71c032,0x3e7bc1cb}},	//   ійно_, няют, ئدة_, _bêta_,
   {{0x3896003f,0x64a6137d,0x6601d37e,0x7d1ad37f}},	//   kārt_, дана, ralk, guts,
   {{0x2905cae6,0x39434070,0x27e9005e,0x2d724199}},	//   rsla_, _msjs_, _cfan_, _uđeš_,
   {{0x2905d380,0x7c3bd381,0xac18d2b0,0x442dd382}},	//   ssla_, meur, _хочу_, mfe_,
   {{0x20021383,0xaec4c11b,0x3329405c,0x7afb80eb}},	//   saki_, _збіл, dtax_, _mwut,
   {{0x60c41384,0x2c7c4019,0x64465385,0x7d1ad386}},	//   _thim, _aída_, _paki, cuts,
   {{0x3994454a,0x6b9b4011,0xf1a7c01c,0xae20025c}},	//   _तs_, _žuga, _واژه_, _बावन_,
   {{0x4432000d,0x7647400d,0xe7ed4027,0x2619409d}},	// [d80] _iby_, _bajy, जड़ा_, _पाखी_,
   {{0x200d805c,0x291a5387,0x7f4400f7,0xfbd146b0}},	//   _adei_, tupa_, _isiq, اتِ_,
   {{0x2247c3e2,0x24805388,0x3a3a4bdc,0x29078158}},	//   _mank_, phim_, repp_, jsna_,
   {{0xa927c066,0xe3ba9389,0xccf304e0,0x6703825d}},	//   _zaží, обе_, _שכר_, _ọkar,
   {{0xc6f7812b,0x44e38070,0x7c22c018,0x1eaa81b4}},	//   дніх_, _añ_, _rcor, ياتي_,
   {{0x44fa83a0,0x7d1ad38a,0x35cec25c,0xea0040d1}},	//   tū_, yuts, हेड़, _đặn_,
   {{0x4420402c,0xb05b4041,0x9c7cd38b,0x38960017}},	//   ogi_, _ohäl, _luče, nārs_,
   {{0xa01b538c,0xf8c800b2,0x7bdb840d,0x3e79802e}},	//   _glöd, रगोप, _gguu, _fèto_,
   {{0x6f1641f4,0x290781c8,0x7647538d,0x69da8157}},	//   nryc, asna_, _yajy, _tgte,
   {{0x7c24138e,0x787cc5f6,0x7791c01c,0xf2df40cc}},	//   _acir, _déva, دیها, _grâu_,
   {{0x6d5c8654,0x7c2d41f4,0x018ac051,0xa3ce4048}},	//   _šraf, yfar, ющий_, षेत_,
   {{0xdefac039,0x3eb98017,0x6f164036,0x7c3bd38f}},	//   _дык_, _īsti_, kryc, ceur,
   {{0x2247c077,0x6d43d390,0x6a748031,0x7d1ad391}},	//   _fank_, _esna, _aàfi, suts,
   {{0x69dc5392,0x44205393,0xeb918052,0x7e7e0053}},	//   _ngre, egi_, אָל_, _clpp,
   {{0xa3e5c036,0x7d1ac0c7,0xc693c323,0x40355394}},	//   बुक_, quts, _באס_, невс,
   {{0x6e3c00c4,0x6497c0cc,0x4424843e,0x670e8045}},	//   aerb, pţie, _ncm_, _सिंक_,
   {{0x9c7cc077,0x6483409d,0x4ade82ea,0x7ae4475d}},	// [d90] _guče, _lõig, _फूलव, gqit,
   {{0x78a2c06f,0x645a0017,0xadf30b35,0x66039395}},	//   _ljov, ētie, _अभिन_, xank,
   {{0x6f099396,0x44204010,0x7c3bc01e,0x6449c02c}},	//   _svec, bgi_, yeur, ydei,
   {{0x44204010,0x76474449,0x7c3d011a,0x3866813b}},	//   cgi_, _wajy, nesr, gjor_,
   {{0x7bdd471c,0x7c3bd397,0x785e80b4,0x27e95398}},	//   _igsu, veur, _săvâ, mcan_,
   {{0x28bf41f9,0x638581cb,0x388cc0a0,0xceb44080}},	//   ्षवि, _aîné, měry_, stər_,
   {{0x76488149,0xddc19399,0xf20480d9,0x27ff8206}},	//   _dady, _bolš, тячо, _teun_,
   {{0x6d45139a,0x60cd438a,0x88bd0185,0x6729d39b}},	//   _msha, nmam, stěj, ttej,
   {{0xa3cac08f,0x443d939c,0x28df908d,0x7d1c139d}},	//   ळेल_, mew_, _पूरि, zurs,
   {{0xdb0ec1b4,0x7c3bd39e,0xa3d01275,0xda0f539f}},	//   ádál, seur, _वृष_, ाणित_,
   {{0x27298032,0x386d809d,0x442dd3a0,0x9f5e006a}},	//   lún_, _koer_, pfe_, ştü_,
   {{0x6e2500b6,0x660193a1,0x6a7240b0,0x2c71c089}},	//   _achb, _helk, _hæft, _pádu_,
   {{0x78bbc047,0x4e0393a2,0x386d8713,0x249fc397}},	//   mluv, _रजाई_, _moer_, mnum_,
   {{0x629513a3,0x249fc086,0x614613a4,0x6e3c0c3e}},	//   gizo, lnum_, нега, uerb,
   {{0x3205c02d,0x6da30c86,0x443d93a5,0xa564c032}},	//   maly_, гира, kew_, _لدين,
   {{0x6601805f,0x442053a6,0x7f440056,0x443d93a7}},	//   _lelk, ugi_, _tsiq, jew_,
   {{0x7875c004,0xa7a753a8,0xfd65c00c,0xaade8027}},	// [da0] _cávi, екта_, _nhuậ, _फूंक,
   {{0x27e953a9,0x660553aa,0x60cd4157,0x6629002d}},	//   acan_, gahk, amam, ľský,
   {{0x249fc10d,0x38668016,0x66c00051,0x7afd4085}},	//   knum_, tjor_, löko, _ewst,
   {{0x44fe0047,0x3ae453ab,0x645b829a,0x3d01c314}},	//   mů_, _töp_, _cnui, वीये_,
   {{0xfe1e408f,0x25864047,0x44fe0047,0x386d93ac}},	//   _पाऊस_, _bílé_, lů_, _doer_,
   {{0x78a2c9ca,0x6f09d3ad,0x38bac0fd,0xa50a4245}},	//   _sjov, dsec, mëri_, _нега_,
   {{0xfaa353ae,0x78a40070,0x6f1d00cb,0x76488007}},	//   _саро, _ojiv, zusc, _vady,
   {{0x6601809d,0x9553800f,0x2ca0409d,0x6f1d0070}},	//   _eelk, اخوا, nnid_, yusc,
   {{0xfe200027,0x8fa382fd,0xddc18077,0x272993af}},	//   _बांस_, _бате, _volš, cún_,
   {{0x2004d3b0,0x200253b1,0x26da13b2,0x7e6e501c}},	//   sami_, _leki_, _nipo_, _jobp,
   {{0x2d9883ad,0xbbbe4d91,0x60cd53b3,0xa2d982ea}},	//   _äre_, ्धुक, ymam, _फूट्,
   {{0x6f1d13b4,0x78784047,0xdee6d3b5,0x38cbc08c}},	//   tusc, _dívk, _зоди, _فانی_,
   {{0xcfaac6b0,0x5f73c425,0x6d5a13b6,0x3205d3b7}},	//   _عاصم_, _ماور, åtan, baly_,
   {{0xb05b04c9,0xdcdf839a,0x388cc0a0,0x248013b8}},	//   kläg, _पूँछ, věry_, _elim_,
   {{0x98c753b9,0x62950d6a,0x200253ba,0xa15811a9}},	//   есал, rizo, _beki_, нару_,
   {{0xae1e4185,0xfe1e4048,0x64960026,0x2480014d}},	//   _पाउन_, _पाउस_, pšia, _glim_,
   {{0x2002406a,0x48140051,0x27e953bb,0x291813bc}},	// [db0] _deki_, _смыс, rcan_, arra_,
   {{0x78bd13bd,0x261b01b6,0x6f0d13be,0xdb9c0093}},	//   llsv, _बाटी_, _ivac, _מסחר,
   {{0x7ae2c04c,0x4426c03c,0x443d93bf,0x4ea44c34}},	//   _luot, _oco_, tew_, урта,
   {{0xb0660051,0xb05b0051,0x272993c0,0x224a40b9}},	//   mpää, mmäs, tún_, _eabk_,
   {{0x386d93c1,0x645d4193,0x6483454a,0x291ed3c2}},	//   _voer_, _insi, _võid, huta_,
   {{0xe9d342f0,0x70b2c01c,0xc334021d,0x88bd00a0}},	//   _مغز_, یموض, רוס_, stěh,
   {{0x386d82a4,0x272993c3,0xa3d953c4,0x249fc086}},	//   _toer_, sún_, ाशक_, tnum_,
   {{0xd9de0f8b,0x64960007,0xddc3c6f0,0x387f80fd}},	//   _मल्ट, ešin, _nonš, _ulur_,
   {{0x660713c5,0xd84280a0,0x69c84089,0xb05b0025}},	//   kajk, áčů_, _úder, hmäs,
   {{0xb05b04c9,0xd011c05f,0x63a980d2,0x6285435d}},	//   kmäs, _چلا_, _ixen, nhho,
   {{0x672d53c6,0x6da5d3c7,0x6f0d13c8,0x3205c512}},	//   htaj, тина, _avac, raly_,
   {{0x672d53c9,0x69c3d3ca,0xf770c01c,0x320793cb}},	//   ktaj, _vzne, _گام_, lany_,
   {{0x672d4011,0x200253cc,0xab5b4107,0x386943ad}},	//   jtaj, _reki_, _szün, djar_,
   {{0xaca4425d,0x09e2c95c,0x320793cd,0x70ad846d}},	//   _mmụt, _кошн, nany_, टकुल,
   {{0x910306b1,0xb7ef40eb,0xc7ef425d,0xa3c58045}},	//   ипре, _ụbụb, _ụbụr, ॉइड_,
   {{0x63a98041,0x644d4a92,0xa3e801ac,0xfe21c374}},	//   _oxen, gdai, मुख_, _माँस_,
   {{0x4cc80079,0x6603d3ce,0x6d5553cf,0xdee353d0}},	// [dc0] _রংপু, _kenk, _arza, иоти,
   {{0x44fe0047,0x9c7cc011,0x60db93d1,0x2b588047}},	//   pů_, _muča, _aium, _črc_,
   {{0x200253d2,0x7ae413d3,0x787853d4,0xa3e900b2}},	//   _teki_, _huit, _lívi, _बलम_,
   {{0x7d1e53d5,0x38bac0da,0xd7064495,0x628193d6}},	//   rups, përi_, _изми, _allo,
   {{0x200681b4,0x27e093d7,0xb606006c,0x60c993d8}},	//   raoi_, žino_, pušč, _dhem,
   {{0xca76410e,0xbebb00fd,0x60c993d9,0x290c815d}},	//   _румы, stëv, _ehem, _pvda_,
   {{0x4a9b0009,0x1a9b0009,0x443fc912,0xa3d3828b}},	//   ויסג, ויסע, feu_, हेब_,
   {{0x7d1c93da,0x7ce78138,0x69b5c062,0x442284f5}},	//   _årsm, _tırn, _उड़ी, _øk_,
   {{0x64960185,0x787853db,0x7ae413dc,0xc24693dd}},	//   tšin, _cívi, _nuit, _инак,
   {{0x24868283,0x64960007,0xd8f8c11b,0x9c7cc123}},	//   lhom_, ušin, нної_, _duča,
   {{0x621b4009,0x6298806c,0x644bd3de,0x660713df}},	//   וויק, mivo, _fagi, vajk,
   {{0x78a293e0,0x44e70082,0x0446cf15,0x60db93e1}},	//   nnov, _rõ_, _једн, _xium,
   {{0x9f5904c9,0x6234d3e2,0xadc40031,0x78a288f1}},	//   kaså_, _белу, _ijẹu, inov,
   {{0x68e3cd6a,0x644bd3e3,0x6497c156,0xadc381c0}},	//   _fund, _zagi, nţin, _abẹl,
   {{0x6d34cb6f,0x3ce885da,0x7c3f4561,0xd7e753e4}},	//   _сейф, _चूमे_, teqr, візо,
   {{0x44e70015,0x6abd4f92,0x7ae41397,0x3f8940b0}},	//   _võ_, ्ग्र, _fuit, tzau_,
   {{0xb05b13e5,0x645f13e6,0x24868283,0x26dcc011}},	// [dd0] smäs, _inqi, dhom_, _kivo_,
   {{0x644d468a,0x60db8df2,0xdce70036,0x68e3d3e7}},	//   sdai, _sium, zyję, _yund,
   {{0x6b89d3e8,0x291e4041,0xbff0825d,0x83fdc107}},	//   zzeg, _åtal_, _ịhọr, rkőz,
   {{0x224c821b,0x78a293e9,0xb4bf93ea,0x7d1c8051}},	//   _aadk_, gnov, ुगे_, _ärsy,
   {{0x862551be,0x3e740041,0xe8e0c00c,0x291a40c4}},	//   _مکال, _tätt_, _ướt_, arpa_,
   {{0x2b1b0b35,0x644d014b,0x6d474967,0xf8bf13eb}},	//   _बिनु_, _laai, _tsja, hlé_,
   {{0x6605006c,0xd5b853ec,0x6608c1c8,0xceb240c3}},	//   _mehk, _аст_, dadk, _הים_,
   {{0xfd5e0044,0x9c7cd1ae,0x66050047,0xe81f0045}},	//   _anyị, _puča, _lehk, _भागा_,
   {{0x6eb94185,0x67d48156,0xf8bf0089,0xe3b880b4}},	//   ्तपु, _воту, dlé_, _алтч_,
   {{0x6b89c036,0xb63487c3,0x7c2983aa,0x6f0d53ed}},	//   rzeg, _نعمت, _hcer, isac,
   {{0x443fd3ee,0x200493ef,0x7ce783a6,0xbebb00fd}},	//   peu_, _yemi_, _kırm, htës,
   {{0xdb0d03d2,0x7ae413f0,0x44e8c669,0x3205805f}},	//   _azañ, _puit, _dû_, _hely_,
   {{0x27edd3f1,0x3205823d,0x7ae413f2,0x7d1ac0bf}},	//   mcen_, _kely_, _quit, arts,
   {{0xdee313f3,0x7c298123,0x8f9ac323,0x66e313f4}},	//   сори, _lcer, _איני, сора,
   {{0x644d01c8,0x9c130044,0x249913f5,0x25eb809d}},	//   _faai, _kọle, bism_, _चलनी_,
   {{0x9f4b4157,0xb6034089,0x78a293f6,0xb5fc81d6}},	//   _recò_, hráč, xnov, _inġe,
   {{0x69c7417a,0x5aca53f7,0x5f46001c,0x7ce78138}},	// [de0] _azje, елам_, _صندل, _sırl,
   {{0x4a4613f8,0x644d00a8,0x38b90107,0xf41f0025}},	//   _снов, _zaai, sért_, nhän_,
   {{0xed458a87,0x8d764032,0xaf36001c,0x200953f9}},	//   _بھ_, داءا, _شرکت, baai_,
   {{0xb19b0323,0x78a28011,0x3b8693fa,0x2bca93fb}},	//   _טייכ, unov, ллег, нуло_,
   {{0x7c298347,0x7641d045,0x6496004f,0x3205814b}},	//   _dcer, kely, jšim, _bely_,
   {{0x248680f1,0x32058574,0x65ba41dc,0x24990402}},	//   shom_, _cely_, _зубр_, zism_,
   {{0x6497c0b4,0x7f4993fc,0xe567d115,0x2bbe4db4}},	//   rţin, _eseq, _اط_, ्धका,
   {{0x26dcc11a,0x5b14cc21,0x6f1bc2ad,0xdb6ad3fd}},	//   _sivo_, амит, fruc, ерол_,
   {{0x7e2ac11e,0x649609a2,0x64428032,0x6608cc9f}},	//   ніна_, ršil, meoi, tadk,
   {{0x320593fe,0x320a0010,0x644d13ff,0xe96a8d4c}},	//   _gely_, jaby_, _saai, _пазл_,
   {{0x09d7c079,0x7ae65400,0x52759401,0x44269402}},	//   _দ্বা, _lukt, _туту, ogo_,
   {{0x644281b4,0xb4af0021,0x5b270d9b,0x2cbfc0b4}},	//   neoi, कवे_, льга, clud_,
   {{0x60dd4469,0xe6c4c10d,0x46f6c623,0xf8bf001e}},	//   _rism, þjóð, _счет, rlé_,
   {{0x64428032,0xf8bf0066,0x200940bf,0x644d0fd7}},	//   heoi, slé_, waai_, _waai,
   {{0x6d5a538b,0x867bc3bd,0x067bc093,0xf8bf1403}},	//   _štan, _ארגו, _אנגל, plé_,
   {{0x57f5411b,0x6d58c033,0x6605015d,0x67228007}},	//   рпат, _irva, _wehk, kuoj,
   {{0xe7f7c617,0x660a805c,0x200947f5,0x60cd1404}},	// [df0] ीरता_, kafk, raai_, _iham,
   {{0x200b1405,0xbebb00fd,0x51870051,0x291c80ab}},	//   laci_, rtës, _бума, krva_,
   {{0xa3e90027,0x3ceac0b2,0x2243006f,0xbebb013b}},	//   _बला_, _घूमे_, mejk_, stës,
   {{0x200b1406,0xd5b85407,0x7ae64383,0x7ce78080}},	//   naci_, усу_, _fukt, _qırm,
   {{0x67228007,0x6f0f412c,0x26de84db,0x66059408}},	//   guoj, _uvcc, _bito_, апла,
   {{0x8704804c,0x6b8d40b3,0xd3364916,0x764e5409}},	//   сяце, mzag, _דרשה_, _gaby,
   {{0x442b540a,0xa01b140b,0x9c7cc97c,0x365c00c3}},	//   _kcc_, rhöj, _vučn, תכונ,
   {{0x200b0ff5,0x7ae64303,0x26de8018,0x78adc158}},	//   jaci_, _yukt, _eito_, čavo,
   {{0x0685d40c,0x6283c05b,0x68e740b3,0xfd4c8015}},	//   игин, _plno, _hujd, _khiể,
   {{0x26de940d,0x44ea940e,0xa7748051,0x7f848032}},	//   _gito_, _fù_, _улуч, _الكن,
   {{0x442b4060,0x3da7940f,0x60cd005e,0x6f1d1410}},	//   _occ_, _сраб, _bham, ersc,
   {{0x7521c05c,0x200b1411,0x229bc031,0x2bd2c045}},	//   rulz, gaci_, _bákè_, देहा,
   {{0x98484435,0x9c130112,0x69c1006a,0x6d4ad412}},	//   xşı_, _gọme, ülen, _esfa,
   {{0x7ccac09c,0x387fd413,0x6288d414,0xe299c7c2}},	//   _iƙra, lkur_, chdo, _шал_,
   {{0x78bb9415,0x67228039,0x3aeb80d9,0x6f1d00a8}},	//   _okuv, zuoj, _løp_, arsc,
   {{0x76439416,0x3207c033,0x200b1417,0x7d1cc571}},	//   heny, _heny_, caci_, árse,
   {{0x4e1a004c,0x60d70087,0xa2064299,0xbebb00fd}},	// [e00] _июня_, _דוקא_, ипад, rtër,
   {{0xef1f0107,0xda7940d9,0xff7b01f2,0x2fc00303}},	//   zzük_, ляє_, _סטימ, _iyig_,
   {{0x76439418,0x3207d419,0xb14649cd,0xd8268393}},	//   deny, _meny_, рнел, иджи,
   {{0x3136c009,0x6f04000d,0x7ae6541a,0x38cb808c}},	//   ינעם_, _kwic, _tukt, نانی_,
   {{0x6497c119,0x87038dd2,0xf4170009,0x6607541b}},	//   rţil, ояще, בֿות_, _fejk,
   {{0x200b0047,0x644f541c,0x8c46c080,0xe2088031}},	//   zaci_, _zaci, mişə, _gbó̟_,
   {{0x644f541d,0x4439407a,0x67228ce8,0x660a941e}},	//   _yaci, _ybs_, suoj, rafk,
   {{0x395a0018,0x6f02c3bc,0x629ac809,0x98a68b0c}},	//   _mrps_, _pwoc, wito, _тибе,
   {{0x3207d41f,0x60cd032a,0x4fc6c026,0x60c2800b}},	//   _beny_, _rham, шска, mlom,
   {{0x76438033,0x3eb81060,0x60c29420,0x200b1421}},	//   ceny, jort_, llom, waci_,
   {{0x6b8d5422,0x200b1423,0xfc66c0c5,0x272f41df}},	//   zzag, taci_, _вълн, zün_,
   {{0xa17b8009,0x657ad424,0xe2f906bc,0x2ca6802c}},	//   _שטאט, ryth, лемі_, nnod_,
   {{0x24805425,0xfbd2c926,0x2d9e1426,0x07a400d7}},	//   dkim_, देशम, úten_, жаўн,
   {{0x386240ce,0x61e3c17b,0x66088247,0xfd97c16a}},	//   _ankr_, _ggnl, _jedk, ائیت_,
   {{0xbc0742d0,0x60c29427,0x98b88141,0x6d4700a8}},	//   ичай, klom, _aprč_, uwja,
   {{0x6b8d40fc,0x76439428,0x22844041,0x59f5c01c}},	//   tzag, zeny, _röka_, _پکیج_,
   {{0x60c29429,0x7643942a,0xc61c002a,0x3ce885da}},	// [e10] dlom, yeny, দ্ধা_, _चूसे_,
   {{0x442b41ae,0x7c2d001c,0x272f542b,0x2ca9c2a3}},	//   _wcc_, _hcar, rün_, čadi_,
   {{0x9967542c,0x26c300e5,0x7ed40032,0x248940d1}},	//   штал, mljo_, _بزيا, pham_,
   {{0x2ca6942d,0xe4a480d9,0x2480542e,0x5dd9c052}},	//   gnod_, орчо, ckim_, אַנס,
   {{0x6607413b,0x6298cb32,0xa01b00cb,0xa8024004}},	//   _tejk, _omvo, rhöh, óñen,
   {{0x291ec033,0xa5f8542f,0x2486d430,0x7c39c02c}},	//   krta_, _веру_, _alom_, _sbwr,
   {{0x3207c0b6,0x60c29431,0x628740c4,0xddc88089}},	//   _reny_, blom, _iljo, _podš,
   {{0x75238bc9,0xdb1d434d,0xfbdf0fc2,0x63a4c007}},	//   runz, _aysé, ndês_, _žina,
   {{0x76439432,0x442d9433,0xb3d2c17e,0x1bbb8a2c}},	//   peny, _ice_, देलख, _شارع_,
   {{0x387fc086,0x628a9434,0xca7481b4,0x386dc0d9}},	//   skur_, chfo, _والغ, sjer_,
   {{0xe820c08f,0x5f13c374,0xc2128093,0xfc460574}},	//   _याचा_, _दिक्_, _זהב_, šíme_,
   {{0xcb6a0f7f,0x1bef8185,0x661b409c,0x98774526}},	//   гаме_, _छलफल_, _ɓuka, kçı_,
   {{0x442d9435,0x6d5a811f,0x69c183cf,0x929d8036}},	//   _mce_, _zrta, _hyle, _zwła,
   {{0x69c19436,0x7ae180f1,0x7ae99437,0xb3480085}},	//   _kyle, _jilt, _muet, _naħż,
   {{0xbcf5d438,0x6da2cfc8,0x7e7cc0cb,0xd17900d9}},	//   _استغ, _ниша, örpe, асті_,
   {{0x69c19439,0x6e3b0077,0x62874147,0x7c2d0359}},	//   _myle, đuba, _aljo, _gcar,
   {{0x7c36543a,0x7ae1892c,0x7c29d43b,0x53ca543c}},	// [e20] rfyr, _oilt, iger, угам_,
   {{0x4226143d,0xdfcf4a10,0xc619c079,0x7ae1943e}},	//   _удов, ريل_, ত্রা_, _nilt,
   {{0x2b4941c8,0xb05b1073,0xd5b80017,0xd6db00c3}},	//   awac_, ilän, ļās_, _תחיל,
   {{0x68e8943f,0x7ae19440,0xac0a9441,0x8fa64e5a}},	//   _rudd, _ailt, унда_, _гаме,
   {{0x290581d6,0x20005442,0xb05b44c9,0x2ca6815a}},	//   _awla_, mbii_, _skäg, rnod_,
   {{0x64461443,0xbae5811b,0x68e892d1,0x2486c0ab}},	//   heki, іцій, _pudd, _slom_,
   {{0x66088240,0x7c29d444,0x320cc089,0x2486c580}},	//   _vedk, fger, vady_, _plom_,
   {{0x7c3b825d,0x2b401445,0x64461446,0xd90d82cf}},	//   _gbur, _opic_, jeki, ئین_,
   {{0x7afbc274,0x68e8809c,0xd20ac59d,0x66c00051}},	//   gput, _wudd, лэнд_, löku,
   {{0x9c7cc7ca,0x7bcf8018,0x660e1447,0x9f52034d}},	//   _kučk, _ºcur, jabk, _leyó_,
   {{0x320cc750,0x3abb4087,0x7c29d448,0x291ec1c8}},	//   rady_, רמינ, bger, urta_,
   {{0x64461449,0x7e63c17b,0xab5d8062,0xc17340c3}},	//   geki, _ennp, _wyże, לחת_,
   {{0x4429544a,0xeb97c051,0x937ac61e,0x6d5887fb}},	//   vga_, _лиц_, _حصار_, lvva,
   {{0x291ec04f,0x8bd7c4e0,0x66c0144b,0x25580141}},	//   prta_, _הודו_, köku, _bčl_,
   {{0xa2b94abd,0x2732802c,0x660ac127,0xc61f402a}},	//   ्तस्, hân_, _iefk, ন্ডা_,
   {{0xd01100fb,0x7f4d0056,0x18a41025,0x9f494032}},	//   _کلک_, _tsaq, _најм, scaí_,
   {{0x6287441b,0xf09f0016,0xc299460e,0x41e74a2c}},	// [e30] _pljo, mià_, аках_, مساف,
   {{0xf09f06ed,0x7aed4573,0x9c7cc9a2,0x629e544c}},	//   lià_, rqat, _bučk, gipo,
   {{0x60c44277,0x442946bc,0x7afd144d,0x648340b2}},	//   blim, pga_, lpst, _hõim,
   {{0xa3d0144e,0x71f8005f,0x3aef0a1f,0xcc0b944f}},	//   वेक_, _پریس_, _küp_, ازان_,
   {{0x2019407a,0x24890033,0xcb699450,0xe3b38032}},	//   _idsi_, _mlam_, рале_, أرض_,
   {{0xf09f0157,0x2902c011,0x96935006,0x2b4d8147}},	//   hià_, ćkaj_, _عیاش, _vsec_,
   {{0x64461451,0xb9228112,0x1bf900e9,0xb14580d9}},	//   yeki, mkpọ_, ंडाल_, інил,
   {{0x442d9452,0x7f5b9453,0xa01b4041,0x6aa8d454}},	//   _uce_, _truq, _slöj, endf,
   {{0xd9fb0048,0x7b67820d,0x6497c0b4,0xfdfb08fb}},	//   ्रात_, _утве, nţii, ्रास_,
   {{0x27ffc21b,0x2cbf8123,0x2ca941f4,0x8cc9c2b8}},	//   sbun_, _hkud_, hnad_, _हीरो,
   {{0xc66888b5,0xddab8051,0x2ca95455,0x9f468086}},	//   _уште_, _стал_, knad_, lboð_,
   {{0xb05b1456,0x2ee3415d,0x7afbc051,0xfd108032}},	//   slän, _lijf_, pput, _أجل_,
   {{0x78ad011f,0x78a9d457,0x78bbd458,0xe7f90374}},	//   _djav, mnev, mouv, ंड़ा_,
   {{0x24891459,0x78a9d45a,0x248dd45b,0xefb3c01c}},	//   _elam_, lnev, lhem_, _ویژگ,
   {{0x660e145c,0xe7fc8185,0x7d1c945d,0x7aebc086}},	//   rabk, उँमा_, _årst, _hugt,
   {{0x7ae3d45e,0x9f5203bc,0x07a6011b,0xf09f0016}},	//   _hint, _deyò_, _майн, cià_,
   {{0xdca343a7,0x8af7403a,0x3eba40a8,0x2d910157}},	// [e40] фати, _şəra, topt_, azze_,
   {{0x21a640cc,0x44ee145f,0x78ad002d,0x8d5a46b1}},	//   оизм, _tý_, _zjav, ишет_,
   {{0x4fea819b,0x249fc05c,0xb5ca01aa,0x7aebd460}},	//   амен_, kium_, _خودم_, _lugt,
   {{0x320a405b,0x9c7cc5c7,0x68e401c8,0x200f9461}},	//   _weby_, _vučk, _jiid, gagi_,
   {{0x6497c0b4,0x69c3d462,0xa01b1463,0x7d0001c0}},	//   cţii, _lyne, kkön, _fàrò,
   {{0x68e41464,0x442fc061,0x6d5e0795,0x629e40fd}},	//   _liid, _acg_, _krpa, qipo,
   {{0x629c5465,0xc0468280,0xcb1c8048,0x320e9466}},	//   _imro, _وخرو, _निवड_, rafy_,
   {{0x7ae3d467,0x442fd468,0xc05ac125,0xc61f402a}},	//   _aint, _ccg_, рік_, ন্দা_,
   {{0x3ea68623,0x78ad006c,0xd7ef8032,0xb6a69469}},	//   _диаг, _rjav, _شكل_, _диал,
   {{0x7aebd46a,0x6146946b,0xa3ab4036,0x5a34c95c}},	//   _dugt, _меза, गपत_, чнот,
   {{0x6abc146c,0xd00fd46d,0xe3afc2cf,0xdb0f546e}},	//   dorf, _оф_, فری_, _excè,
   {{0x27e08a11,0x57f401bc,0x6e3e005c,0x69c3c3cf}},	//   žinu_, мпют, _abpb, _dyne,
   {{0xc87fc600,0x320c8038,0x20194018,0x2ca94300}},	//   öße_, _kedy_, _rdsi_, vnad_,
   {{0x69ce409c,0x69c3c02c,0x1994d46f,0x200f9470}},	//   _ozbe, _fyne, _наля, zagi_,
   {{0xb05b091d,0x628ac0b4,0x20194010,0x91c1c185}},	//   lläm, _ilfo, _pdsi_, _रुपै,
   {{0x6d5e0011,0x7528c247,0x5b15016f,0x9c7cc732}},	//   _drpa, mudz, _емит, _buči,
   {{0x27e900f8,0x7ae3d471,0x2a785472,0xfc3f00a0}},	// [e50] _igan_, _yint, _borb_, nním_,
   {{0x9c7cc590,0x78bd1473,0x7cf3417a,0x67229474}},	//   _duči, losv, _aħra, droj,
   {{0x64a402a3,0x9bf880eb,0x200f9475,0x5f74001c}},	//   rđiv, _ịsụg, tagi_, _فایر,
   {{0x2ca04057,0x63adc086,0x7648c274,0x78a95476}},	//   ciid_, _þang, hedy, čevs,
   {{0x161f056c,0x6d5ec113,0x29e10020,0x2bde0047}},	//   _बयार_, _špal, lɗa_, नेपा,
   {{0xfce5879a,0x3f4d4011,0x7648c036,0x3866d477}},	//   поко, _ižu_, jedy, _anor_,
   {{0x7f4d4283,0x7f42c070,0x6285400b,0x661a0036}},	//   lwaq, _apoq, mkho, ótki,
   {{0xddc7002d,0x3a3e8085,0x6d41804f,0xb4b50185}},	//   rejň, _ebtp_, _vpla, जको_,
   {{0x66d05478,0x78bbd479,0x69c5147a,0xf559816a}},	//   säke, rouv, _lyhe, _گلاب_,
   {{0xc879806a,0x26c5c0c4,0x78bbd47b,0x320c947c}},	//   _hoş_, ullo_, souv, _gedy_,
   {{0x25de4045,0x7f42c7b0,0x7e7cc4c9,0x78a9d47d}},	//   केपी_, _epoq, örpa, pnev,
   {{0x69c3c066,0x7ae3d47e,0x26c5c018,0x5064c99b}},	//   _vyne, _wint, sllo_, _отча,
   {{0xb4b7c08f,0x27e90056,0x7d1c947f,0x7c3bd480}},	//   चकी_, _dgan_, _årsr, mfur,
   {{0x7c2d5481,0xfc3f41c0,0x33294033,0xaa41c051}},	//   egar, _abí_, duax_, ärää_,
   {{0x7ae5041b,0x01631482,0x6d46c036,0xe2971483}},	//   _diht, нкро, łkar, чар_,
   {{0x443f9484,0x27345485,0x7afb9486,0x7ce7806a}},	//   _nbu_, tän_, _otut, _hırs,
   {{0xaefb4031,0x7afb825d,0xfbd1405f,0x6f098112}},	// [e60] _arùb, _ntut, ہتے_, _nwec,
   {{0x6d5e1487,0xfc3f402e,0x67365286,0x64561488}},	//   _trpa, _ebí_, rtyj, _hayi,
   {{0xf67b0093,0xc87981df,0x8e7b00c3,0x200d8031}},	//   _האימ, _boş_, _הניה, _beei_,
   {{0xd12f43a9,0x9f590070,0x645603f3,0xd49980d9}},	//   طمه_, casó_, _jayi, орі_,
   {{0x6d5c1489,0x7f1944c5,0xf0930052,0x443f948a}},	//   lvra, _міру_, ענד_, _dbu_,
   {{0xa96a4f8d,0x7c3bc033,0x442dd48b,0x78bb4158}},	//   _лига_, efur, ege_, čuve,
   {{0x6d5c148c,0x6aa1c4a7,0xa4d8c660,0x9c83510f}},	//   nvra, dilf, одку_, ščev,
   {{0x7bc6417b,0x7e78d48d,0x399cc02d,0xb4c8c5cb}},	//   _kyku, _sovp, násť_, ोगे_,
   {{0x68e6409c,0xaed4c077,0x2486867d,0x2bde115e}},	//   _mikd, моиш, mkom_, नेमा,
   {{0xbafb8093,0x8af0403a,0xfc3f0047,0xb05b0041}},	//   _להמש, vvəl, rním_, rläm,
   {{0x2fc74015,0x7648d48e,0xd05c803a,0x8c46c34a}},	//   ́ng_, redy, _surə, _неже,
   {{0x66cd8166,0x2bd98794,0x7c2d41c8,0x6d5ad48f}},	//   núkn, बेवा, xgar, rvta,
   {{0x64561490,0xfc3f005b,0x60c2d491,0x32110047}},	//   _dayi, lník_, _ikom, tazy_,
   {{0x356ac8b1,0x7aed0303,0x7528d492,0x61edd14f}},	//   _грин_, _vuat, pudz, _şalv,
   {{0x9412403a,0x44f180d1,0x7ae50134,0xc7fa4112}},	//   liyə_, _xá_, _viht, _ọsụs,
   {{0x20125493,0x98c440b4,0x64561494,0x26da4070}},	//   gayi_, есул, _gayi, empo_,
   {{0x24869495,0x443f807a,0x649603aa,0x7ae5009d}},	// [e70] dkom_, _rbu_, ršit, _tiht,
   {{0x61224112,0x1eea001c,0xf8bf1496,0xd138d497}},	//   _ọlae, _گویی_, loé_, otą_,
   {{0x442dc7fb,0x7afc9498,0x41fb00e9,0xfc3f0089}},	//   yge_, _črta, ्रीः_, jník_,
   {{0x60c2d499,0x6496006f,0x7684c0b6,0xd138c007}},	//   _nkom, lšir, _bòyk, itą_,
   {{0x3dc580de,0x69a28045,0xaefb405e,0xe7d7c02a}},	//   _sylw_, _केबी, _drùc, _সভ্য,
   {{0x64960158,0x61458119,0x62870402,0x64860359}},	//   nšir, дека, nkjo, _róim,
   {{0x2486949a,0x20c1c032,0x3f82149b,0xd9fe809d}},	//   bkom_, dóir_, zyku_, _उभरत_,
   {{0xa3ad05de,0xb4b7cc4b,0x7c3d00a8,0x7e68834b}},	//   कपा_, चके_, jfsr, _endp,
   {{0x7afb949c,0x68ee40e2,0xe78480b4,0x6b828024}},	//   _utut, _zubd, _пуфо, cyog,
   {{0x442dc68a,0xfc3f0066,0x7d1a0166,0x3ebed49d}},	//   sge_, bník_, átsk, gott_,
   {{0x2012549e,0x6f03c171,0x1fda4185,0xfc3f0089}},	//   yayi_, _bíbò, _भण्ड, cník_,
   {{0x20c1d49f,0xe73a109b,0x78ad54a0,0x3ce6c157}},	//   róis_, оем_, jnav, _giov_,
   {{0x60c9d4a1,0x3ebed4a2,0x7983802c,0xf3ff41ff}},	//   mlem, bott_, lynw, _anão_,
   {{0x69a28384,0x6aa394a3,0x645614a4,0x273614a5}},	//   _केडी, ninf, _wayi, ræn_,
   {{0xa01b14a6,0xed570d44,0x6d4e01d4,0xf1d1c314}},	//   rhör, мор_, uwba, _हरिन,
   {{0x1867492f,0x3f89c017,0xa0674077,0x291c402d}},	//   маси_, _ļauj_, маса_, ávam_,
   {{0x644b94a7,0xfc3f005b,0xb8d64c63,0x07a34f1e}},	// [e80] degi, zník_, _जद_, ватн,
   {{0x248694a8,0x2d81c09d,0x59dd8419,0x629e14a9}},	//   wkom_, _ühes_, मधार, _umpo,
   {{0x6abe4414,0x7bc64062,0x3d01c048,0x44f3c43e}},	//   ropf, _wyku, वीचे_, _jã_,
   {{0xe1f894aa,0x248d94ab,0x201dc84f,0x98a64ed5}},	//   ुर्ण_, _clem_, _ndwi_, _циме,
   {{0x7bc6406a,0xcce58032,0x60c402c0,0x76570149}},	//   _uyku, رسمي, _mkim, _yaxy,
   {{0x6b8294ac,0x9f5dc031,0x26c354ad,0x64598820}},	//   ryog, _fewú_, _gkjo_, adwi,
   {{0x9f4b4086,0xa3de0048,0x248d86bc,0x2167831f}},	//   élög_, थेत_, _flem_, дији_,
   {{0xfc3f0066,0x60dbc871,0x30a3cc4e,0xd90d801c}},	//   rník_, gmum, крыв, صیه_,
   {{0x20c1c032,0x6d5e4af3,0xab658017,0x6aa394ae}},	//   tóir_, lvpa, _peļņ, binf,
   {{0x4974c34a,0xfc3f0089,0xa01b0414,0xceb44080}},	//   елос, pník_, rköm, qsəd_,
   {{0x60f8c289,0xb05b0025,0x2cbfc177,0x3eaccd4d}},	//   яння_, lläi, boud_, rndt_,
   {{0xc0aacc59,0x44f3c00c,0x671e4045,0x7ae880b0}},	//   _باطل_, _dã_, _पिंक_, _hidt,
   {{0x7875c089,0xddce4036,0x7e7c4713,0x60c0d4af}},	//   _návy, _jabł, _oorp, momm,
   {{0x3b53c11b,0x03200374,0xd138c007,0x6d5cc4c9}},	//   _шкір, _बिरह_, ptą_, åras,
   {{0x44f3c00c,0x7ae7415d,0x78ad4206,0x9f404107}},	//   _gã_, _rijt, tnav, kció_,
   {{0x2bdbc705,0xbf3500d9,0x8f350119,0x3869084f}},	//   मेवा, _знищ, _зеиц, _unar_,
   {{0x38b90089,0x7762c0f6,0x3f84d4b0,0x92c2c02a}},	// [e90] xéry_, _jrox, nymu_, ্দী_,
   {{0x60c9d4b1,0x78ad54b2,0x60c0d4b3,0x765ac0b1}},	//   zlem, snav, homm, ndty,
   {{0x3ce90046,0x69c894b4,0x60c9c3a6,0xa01b4041}},	//   _kiav_, _nyde, ylem, _blöt,
   {{0x80d10079,0x290140f6,0x6aa38127,0x7aef54b5}},	//   _সূত্, rpha_, winf, _tuct,
   {{0x60c0d4b6,0x909841bc,0x290c805c,0x6d5a54b7}},	//   domm, _цвят_, _awda_, _štat,
   {{0x7e7c4232,0x2cbfd4b8,0x69c8854e,0x442f8018}},	//   _gorp, woud_, _byde, sgg_,
   {{0x7ae8871c,0x60dbd4b9,0x644b94ba,0xa01b54bb}},	//   _didt, tmum, pegi, _flöt,
   {{0x1017805f,0x672614bc,0x7d024077,0x644d54bd}},	//   _زبرد, yrkj, ćost, neai,
   {{0x661514be,0x6f0d009c,0x6442c05e,0x200fc66e}},	//   kazk, _nwac, _dboi, _vegi_,
   {{0x60c9d4bf,0x60dbc0bb,0xa3b880b2,0x26c1402d}},	//   slem, smum, _घुट_, noho_,
   {{0x2169cd44,0x3205d4c0,0x60c0d4c1,0x2bcc4314}},	//   чини_, rbly_, bomm, _ार्थ,
   {{0xb05b420b,0x44f3d4c2,0x672d54c3,0x6442c031}},	//   _skän, _vã_, kuaj, _gboi,
   {{0x6d5cc673,0x68fe0b64,0x7dee4107,0x443fd4c4}},	//   årar, _stpd, nősí, mfu_,
   {{0x20068119,0x6459c057,0x6288d17c,0x24894017}},	//   zboi_, _hawi, ckdo, ekam_,
   {{0x224e4435,0x27ed81d4,0x6f028064,0x7bcb40fa}},	//   _ölkə_, _ogen_, zpoc, ügun,
   {{0xfa09402a,0x443fd4c5,0x644d41cb,0x6459d4c6}},	//   _লাগল_, nfu_, geai, _jawi,
   {{0x7bc98150,0x443fc150,0x672d54c7,0x68434119}},	// [ea0] _nyeu, ifu_, guaj, ынта,
   {{0x201f8150,0x225846a6,0x82a340b4,0x6b844f2d}},	//   _adui_, _qark_, гауж, ryig,
   {{0xdb1d4066,0x3947c21b,0xd7fa8156,0x764e14c8}},	//   _vysá, _jpns_, пул_, meby,
   {{0x442014c9,0x3ea5d4ca,0x776400b9,0xaefb4031}},	//   _jdi_, hilt_, _krix, _irùn,
   {{0x9f4046ed,0x98a7c047,0x672d4070,0x69c887fb}},	//   rció_, stně_, cuaj, _syde,
   {{0x6459cc47,0x628e4010,0x471b0009,0x764e14cb}},	//   _aawi, _ulbo, לונג, neby,
   {{0x443fd4cc,0x6444017b,0x7ae894cd,0x6abe45a3}},	//   ffu_, _obii, _vidt, ्तीर,
   {{0x63add4ce,0x68e99492,0xc0e39373,0x7643c024}},	//   _žana, _gied, _боск, _abny,
   {{0xc6a6d4cf,0x69c780b0,0x4ea6c259,0x3ea5d4d0}},	//   ерни, _øjen, ерна, filt_,
   {{0x443fd4d1,0x3d1100b2,0x07a38c93,0x644414d2}},	//   afu_, _तबले_, _саун, _abii,
   {{0x7d0900b3,0x4c950949,0xe89500d7,0x4420013b}},	//   ćesk, винс, вань, _bdi_,
   {{0x44f50ded,0x60c294d3,0x2360460f,0x776406bc}},	//   _rå_, noom, kvij_, _brix,
   {{0xa887c844,0x3ce90046,0x442014d4,0x7cffc0b4}},	//   _яйца_, _viav_, _ddi_, vârş,
   {{0xdfcfc1b4,0x6f0454d5,0xaefb405e,0x7d1c4b1b}},	//   _ايه_, dpic, _brùn, _ovrs,
   {{0x765a94d6,0x776414d7,0x0467478b,0x20d20032}},	//   _maty, _erix, нтам, máin_,
   {{0x20d20032,0x6ca454d8,0x443254d9,0xf7eb0032}},	//   láin_, груж, ggy_, _عربى_,
   {{0xfaf3405f,0x7e7e14da,0x644d450e,0x7aeac09c}},	// [eb0] اثر_, _fopp, reai, _kift,
   {{0x645bc0b4,0x20d20032,0x2012009c,0x645d05e7}},	//   zdui, náin_, _zeyi_, ldsi,
   {{0x6d5a54db,0x26c30039,0x48158623,0x26c14150}},	//   _štar, mojo_, вмес, roho_,
   {{0x9f4045f5,0x6aa7015d,0x26c140b3,0x251a021d}},	//   rciò_, lijf, soho_, _קורא,
   {{0x6d4894dc,0x673d0631,0x20d90032,0x6fd54027}},	//   _apda, ntsj, méid_, _दरिं,
   {{0x6abac342,0x26c30007,0x20d90032,0xe5a592bf}},	//   ईकोर, nojo_, léid_, кили,
   {{0x60c294dd,0x20d20032,0x8cb5d4de,0xddde00ce}},	//   boom, dáin_, ксич, _enpņ,
   {{0x2739d4df,0xa4d5893d,0x2eea4077,0x644f14e0}},	//   tèn_, _робі, _zibf_, jeci,
   {{0x6d5a4018,0x26c314e1,0x9e1580d7,0x91f580d1}},	//   _átar, kojo_, _адзі, _các,
   {{0x3947c033,0x645bd4e2,0xb05b4041,0x201214e3}},	//   _ppns_, sdui, _skäl, _seyi_,
   {{0x69cac0de,0x6459d4e4,0x443fc00d,0x7d1ac03f}},	//   _cyfe, _tawi, pfu_, gsts,
   {{0x7e7e14e5,0x644f034d,0x98a608c8,0x673bc064}},	//   _sopp, geci, тиме, ptuj,
   {{0x6d5701c8,0x3b07c171,0x442014e6,0x289acd89}},	//   _asxa, _dípò_, _vdi_, _קינא,
   {{0x60cd45da,0x20d2003e,0x6729d4e7,0x48ed0045}},	//   elam, cáin_, mrej, _आंखो_,
   {{0x673d00a8,0x6d5c8086,0x64a65129,0x7164c032}},	//   atsj, _árat, вава, _مايك,
   {{0xeaed4a30,0x7641c51f,0xb4be54e8,0x044614e9}},	//   जदूत_, lfly, ेते_, _реин,
   {{0xc0e354ea,0x69d554eb,0x44324093,0x69c1006a}},	// [ec0] ротк, _azze, rgy_, üler,
   {{0x6aa7015d,0x60c281ae,0x26c314ec,0x3ceb4024}},	//   cijf, woom, cojo_, _eicv_,
   {{0xd826401b,0x98ad406a,0x321800c3,0x60c294ed}},	//   _идни, _çoğu_, mary_, toom,
   {{0x20d90359,0x47c8002a,0xf8d2017e,0x67290011}},	//   céid_, রেণী, सतिय, šeje,
   {{0xb8f94021,0x929dc036,0x3ea794ee,0x03e4002a}},	//   _ठी_, zpła, fint_, কুরী_,
   {{0xb1465065,0xe45f04c9,0x648ec061,0x96348210}},	//   _ингл, tlök_, _cùin, ункц,
   {{0x387f94ef,0x648ec29a,0x645b8061,0x205680b4}},	//   _four_, _dùin, _faui, _итар,
   {{0x7528c570,0x644f0004,0x60c44025,0xdfd2801c}},	//   vrdz, xeci, noim, _نيز_,
   {{0x69cac2a4,0xa3d68cbb,0xaab201f9,0xa03b8052}},	//   _syfe, _हरि_, ँचाक, _קעמפ,
   {{0x7afdd4f0,0x8c3dc696,0x20c7809d,0x78a40107}},	//   ísta, lişl, sõit_, _amiv,
   {{0x20d20032,0x2d9884cf,0x60cd54f1,0x7aeac1a7}},	//   ráin_, _åre_, ylam, _vift,
   {{0xa9c3c761,0x2ebd04d0,0x8c3dc676,0x60cd403a}},	//   рськ, ोत्त, nişl, xlam,
   {{0xe0df023f,0x20d20359,0x909805f5,0x6495cb87}},	//   rmò_, máil_, твят_, _dáid,
   {{0x672f0158,0x673d0b61,0x78a400bc,0x2918d4f2}},	//   rucj, rtsj, _emiv, áras_,
   {{0x6aa700a8,0x26c314f3,0x66d04402,0x9c834089}},	//   rijf, rojo_, räkl, áčov,
   {{0x2366d4f4,0x26c314f5,0xb5fc81d6,0x20d20359}},	//   _kroj_, sojo_, _inġu, náil_,
   {{0x9ed9495c,0x05c6c17e,0x7c22d4f6,0x661888f1}},	// [ed0] емат_, _रुतब, _mdor, kavk,
   {{0x765c432a,0xb05b00cb,0x24800011,0xaab4c1f9}},	//   _cary, rläu, _zoim_, ुविक,
   {{0x7690004c,0x20d901b4,0x69c8527d,0x2bd554f7}},	//   _käyn, péid_, _ødel, _दरवा,
   {{0x7c22d4f8,0xb4ccc048,0x6fb9865e,0x2eec884f}},	//   _ndor, ळतो_, нгер_, _aidf_,
   {{0x96b801aa,0x2366c23b,0x44f8888b,0x68ed14f9}},	//   _سایز_, _nroj_, _aé_, _miad,
   {{0x201914fa,0x2bc6c342,0xaec489b1,0x2557803a}},	//   hasi_, _लड़ा, абіл, _hələ_,
   {{0x4439406f,0x41e44363,0x387f94fb,0x98acc189}},	//   _kcs_, _віта, _tour_, _ardı_,
   {{0x799ac064,0x20190efa,0x4439405c,0x6379cdce}},	//   dztw, jasi_, _jcs_, есор_,
   {{0xaca3c094,0xb5fc80f6,0x2d87814b,0x60c9884f}},	//   _ndụm, _anġu, syne_, _ikem,
   {{0x2fcd8303,0x2ca9402c,0x6f1d14fc,0xaca3c1c0}},	//   _iyeg_, hiad_, dssc, _ikọj,
   {{0x8c3dc3a6,0x273d54fd,0x60db94fe,0x68ebc105}},	//   lişm, hìn_, _khum, _tigd,
   {{0xe45f4041,0x27e9841b,0x68ed0321,0x443943ad}},	//   _skön_, žanu_, _ciad, _ncs_,
   {{0x6d5ec185,0xf1a78834,0xaa45d4ff,0x44f8810b}},	//   _špat, _केतन, _белл, _zé_,
   {{0x44f88083,0x645d5500,0x2fcd805c,0xf207c4df}},	//   _yé_, _aasi, _myeg_, _рядо,
   {{0x4422413b,0x2b4b40d2,0x98a600b4,0x1545d2cd}},	//   _pdk_, _apcc_, gulă_, _сейм,
   {{0x48c44079,0x78a40618,0xa3ea4c4d,0x7d1c010b}},	//   ্দ্র, _umiv, едба_, rsrs,
   {{0xb05b0041,0x60c45501,0x99980007,0x6b9bc0fa}},	// [ee0] rlät, roim, terų_, nzug,
   {{0x9419003a,0x645d4093,0xa68342f1,0x78a9c0c3}},	//   disə_, _easi, блуд, hiev,
   {{0x248dd502,0x26c5c0c4,0x98a64119,0x648ec05e}},	//   kkem_, iolo_, _бине, _bùil,
   {{0x628e1503,0x98a34036,0xa8564217,0x44394359}},	//   lkbo, tują_, _стој, _gcs_,
   {{0x5fe04c6b,0xa3e0461a,0xa3aa0578,0x7bcd004d}},	//   पेशल, धेश_, _गेम_, _xyau,
   {{0x628e1504,0x28d840aa,0x386fc053,0x20190cc2}},	//   nkbo, _भीति, _angr_, zasi_,
   {{0x78a9c157,0x98a34062,0xddc3c1cb,0x321a5466}},	//   fiev, sują_, _manœ, mapy_,
   {{0x27f200f8,0x645d4c64,0x3e81c0a0,0x395a005e}},	//   _ngyn_, _xasi, _létě_, _msps_,
   {{0x68ed0038,0xb05b0600,0x44f8855d,0x2aaacf34}},	//   _riad, klär, _wé_, етно_,
   {{0x26c5d505,0xfb1b83bd,0x68ed1506,0x88bcc047}},	//   golo_, _נובמ, _siad, _svěd,
   {{0xaa63c026,0x44f8801f,0xa01b1507,0x88c5c0a0}},	//   стык, _ué_, kköt, _svěř,
   {{0x6f040157,0x81b9402a,0xeb9acc21,0x2d959281}},	//   _btic, _চরম_, _пие_, _трус,
   {{0x44395508,0x86270be0,0x2366c0fd,0x57a71509}},	//   _rcs_, льве, _uroj_, ушна,
   {{0x2ca9550a,0x6281950b,0xb05b4051,0x3eaa00cb}},	//   wiad_, _xolo, _ikäi, gibt_,
   {{0x644442df,0xdd94023d,0x2419439d,0x58d511cd}},	//   ffii, бары, ковы_, _кокт,
   {{0x291ed50c,0x6d5a8150,0xb05b099a,0x2b4040b3}},	//   msta_, _msta, rläs, ftic_,
   {{0x4439401d,0x7bcd00f8,0x443b02ad,0x60db950d}},	// [ef0] _vcs_, _uyau, _icq_, _rhum,
   {{0x69ce550e,0x2ca941f4,0x8f9c0009,0x68f5402d}},	//   _bybe, siad_, _ריזי, _puzd,
   {{0xb9b55438,0x60db950f,0xf4879510,0x7c879511}},	//   جماع, _phum, лудн, луде,
   {{0x297a0087,0xa7fb42b0,0x80d34079,0xbebdd09c}},	//   _סטרא, _bañe, _দূর্, trūk,
   {{0xdc36481b,0x44fac0fd,0x225e8303,0x648ec05e}},	//   _דארט_, _lë_, _batk_, _cùim,
   {{0xd019c036,0x8afc0009,0xa7fb4070,0x39ae8080}},	//   wań_, עהוי, _dañe, _bəs_,
   {{0x4095d512,0x26c5c0c5,0x44248065,0xd019c036}},	//   ирит, volo_, _fdm_, tań_,
   {{0x4c85d513,0xcf278032,0x06b180a0,0x60db931d}},	//   рлив, _مرئي, _řídí_, _uhum,
   {{0x661ad514,0x23690046,0x6c8481b4,0xe7e0c54a}},	//   fatk, _nraj_, _القم, खेला_,
   {{0x672d44f9,0x44fac0fd,0x78a9d515,0x248dd516}},	//   iraj, _bë_, siev, skem_,
   {{0x291ed517,0xade185de,0x39415518,0x6f041519}},	//   gsta_, गेशन_, nths_, _stic,
   {{0x64bc951a,0x9f5dc0b6,0x78ab8078,0x290580f6}},	//   mčic, _dewò_, nigv, _itla_,
   {{0x64860145,0xa3e9c2c8,0x7ff4cb3f,0x645f01c8}},	//   _sóis, _मणि_, _اسما, _daqi,
   {{0xa3da916e,0x672d551b,0x99580066,0x395a007a}},	//   डेट_, draj, ráže_, _psps_,
   {{0x99580066,0xd17503d0,0x6b8b951c,0x645f151d}},	//   sáže_, быты, hygg, _faqi,
   {{0x2eeed51e,0x6d41c041,0xb05b0fd0,0x26c7800b}},	//   _ziff_, mtla, slär, hono_,
   {{0x6444551f,0x4fea5520,0x68e29521,0x6d5ec004}},	// [f00] rfii, тман_, vmod, _ápar,
   {{0x386000c3,0xe9a7001c,0x76900051,0x6283d522}},	//   _hair_, اگین_, _käym, _jono,
   {{0x867b0093,0x26c780c5,0x645f1523,0x2baa08b9}},	//   _סרטו, dono_, _yaqi, _चेता,
   {{0xab668be8,0xeb068def,0x38605524,0x6449805e}},	//   ивел, ачко, qdir_, _cbei,
   {{0x6283c033,0x76948031,0x15e88045,0x776980d2}},	//   _oono, _aàya, टेनर_, _crex,
   {{0x291ed525,0x386001aa,0x69ce5526,0xafdb0240}},	//   ysta_, _lair_, _tybe, dføl,
   {{0xbbd31527,0x68e29528,0xddc8c036,0x2bb800eb}},	//   _सर्क, pmod, zedł, ọch_,
   {{0x661ad529,0x2000552a,0x6d5a952b,0x2fcfcff2}},	//   watk, ncii_, _vsta, _bygg_,
   {{0x44fc152c,0x26c780f7,0x6d41c036,0xdce406f0}},	//   _lí_, bono_, etla, _crnč,
   {{0x68e4552d,0x44fc0070,0x9987002d,0xd05c809c}},	//   hmid, _oí_, _čiže_, _turɓ,
   {{0xd48fd52e,0x99f743d4,0x656880da,0x291ed52f}},	//   _др_, יזיה_, _urdh, usta_,
   {{0x2aad1530,0xa2da8314,0x9c83c0b3,0x321c8066}},	//   džba_, _पीत्, _ščvr, lavy_,
   {{0x6283d531,0xe3b2cc59,0xbfa81532,0x7f428157}},	//   _fono, _برا_, атре_, ntoq,
   {{0x68e4409d,0x6d4e40b0,0x645f1533,0x2986c051}},	//   emid, _opba, _waqi, _выиг,
   {{0x57d3807a,0x45d51534,0x69d8d0aa,0xaadbc21d}},	//   _तर्ह, совс, _uzve, _שחור,
   {{0x26c79535,0x80d10079,0x27e08066,0x386001f4}},	//   zono_, _সংক্, žiny_, _gair_,
   {{0x80c7c027,0x68ef4189,0x7cf58007,0x661c1536}},	// [f10] ावते, _vicd, _išre, bark,
   {{0x6f024032,0x260752da,0x5d67474d,0x44fc0083}},	//   íoca, рчаг, итез, _fí_,
   {{0x44fc002e,0xd5b80698,0x29054283,0x38600070}},	//   _gí_, _вся_, _ħlas_, _yair_,
   {{0xb4c0c185,0x76551537,0x26c79538,0x3f42800c}},	//   ंको_, lezy, wono_, _bưu_,
   {{0x2ca900eb,0x291e0458,0x201940b4,0x08764052}},	//   _mmad_, štat_, _iesi_, _הערט_,
   {{0x6d41c080,0x2fcfd539,0x321842a4,0x6b8d553a}},	//   ytla, _rygg_, _gery_, myag,
   {{0x1a6845dc,0x60cd005b,0x26c7953b,0xb99541b4}},	//   _خیلی_, _okam, rono_, _الأب,
   {{0x45b80093,0xf3f98119,0x9601c9cb,0x26c7953c}},	//   יפול_, _faţa_, ोर्ट_, sono_,
   {{0x200dd53d,0x321c8066,0x63a48032,0xaefb4321}},	//   rbei_, bavy_, úint, _brùi,
   {{0xafdb036b,0x80d10079,0x7535153e,0x201d953f}},	//   rføl, _সংগ্, kuzz, lawi_,
   {{0xa2ba4891,0xa3e74048,0xa01b04c9,0x6283d540}},	//   ्वत्, येत_, vkör, _vono,
   {{0x160b9541,0x661c1542,0x753501b7,0xb4d21543}},	//   _स्तर_, wark, duzz, वते_,
   {{0x80d10079,0x7e619544,0x443dc033,0x64b740b3}},	//   _সংখ্, _kalp, _icw_, rćil,
   {{0x78bb84c9,0x2cadd545,0xe3b0d546,0x44390a26}},	//   _ljuv, lied_, _ترم_, ags_,
   {{0x753c80fa,0x69a74a39,0x64b74639,0xdddc40b4}},	//   _ärzt, _टेली, pćil, _morţ,
   {{0xa9244166,0x64a34c9d,0xe0df5547,0x6618c06a}},	//   _úžit, паса, _chò_, _zevk,
   {{0x09e54079,0xd70a5548,0x3f8dc839,0x777bc03c}},	// [f20] _প্লা, унзе_, nyeu_, nxux,
   {{0x78a99549,0x60c9c14b,0xe45f04c9,0x20194031}},	//   _amev, hoem, slöt_, _eesi_,
   {{0x44fc0032,0x7bdb80bc,0x443dd54a,0x26ca00f8}},	//   _uí_, _azuu, _ocw_, mobo_,
   {{0xdcee4007,0xe81a8968,0xb6064066,0x2019412c}},	//   vybė, ازات_, dráž, _gesi_,
   {{0x543b4052,0x6d418149,0x7e618127,0x2cadd54b}},	//   _געכא, _aqla, _balp, died_,
   {{0xb4c2c09d,0x6456554c,0x25df0c63,0x7f42954d}},	//   ृत्_, leyi, _गरमी_, rtoq,
   {{0x6d5c554e,0x3e854185,0x2bac4048,0x60c9c674}},	//   _usra, _dítě_, _घेता, foem,
   {{0x8c43816d,0xb4d20048,0x8366d54f,0x63a48359}},	//   _несе, वतो_, مدخل, úins,
   {{0x649cc1b4,0x6618d550,0x9e3a8032,0xa01b0041}},	//   _léig, _pevk, _مساء_, dköp,
   {{0xa75b4009,0x3ce68eae,0xd25ad27f,0x2d8cd551}},	//   נדיר, lmov_, уци_, tyde_,
   {{0x26ca1552,0x7d0a88b1,0x2d678013,0x98c4c06a}},	//   dobo_, _снег_, _gđe_, ştım_,
   {{0x8c3dc03a,0x24805553,0x7f44405c,0x63bb4086}},	//   yişi, jjim_, ktiq, _þung,
   {{0x26ca1554,0x27ed0051,0xb4c30ca7,0xb4e90048}},	//   fobo_, äen_, ्तौ_, _बळी_,
   {{0x1994c43c,0x20020065,0x768f80d9,0x96f80b8e}},	//   _маля, acki_, _røyk, серт_,
   {{0x6495c359,0xe3b80138,0xc693cd89,0x6aaac247}},	//   _máin, şıp_, _מאס_, _imff,
   {{0x67229555,0x661a9556,0x64bc8007,0xf1bfc0a0}},	//   ksoj, _letk, yčia, ášek_,
   {{0x78ad5557,0x6f16002c,0xbd0200eb,0x3cfa0060}},	// [f30] riav, _gwyc, _ọktọ, _eupv_,
   {{0x8c3dc530,0x26ca1558,0x75350c87,0x6b8d484f}},	//   rişi, cobo_, puzz, ryag,
   {{0x290740fd,0x64565559,0xf96b4097,0x625ec0f6}},	//   ëna_, beyi, ырай_, _għoż,
   {{0x29074017,0xd05c80e2,0x78af0077,0x7cef4031}},	//   īna_, _murɗ, nicv, _dòrì,
   {{0x98b84119,0x7f44555a,0x2121407a,0x41cfc185}},	//   stră_, ctiq, sshh_, _सुनस,
   {{0x171c0009,0x8cd98036,0x649380b5,0xb6064089}},	//   נווע, _फीरो, _içim, tráž,
   {{0x64bc955b,0x91e2955c,0x7bc08070,0x3ce68010}},	//   sčia, моше, _exmu, bmov_,
   {{0x4429155d,0x6d45555e,0x3eaa4639,0x6ea6c185}},	//   _nda_, mtha, _zmbt_, टोसु,
   {{0x6495c032,0x3f42c086,0x68fa80d2,0x20d9155f}},	//   _fáin, gðu_, _eutd, téin_,
   {{0xb4d20cbb,0x6f0d43c1,0x92b787c3,0x64bc87a7}},	//   वत्_, ipac, _احرا, nčin,
   {{0x44290d0a,0x3ce00022,0x645645b6,0x66d04041}},	//   _bda_, _phiv_, yeyi, mäkt,
   {{0x2caf815d,0x25e142f6,0x644d005e,0xe8eec589}},	//   nigd_, _करनी_, _cbai, _іл_,
   {{0xa01b0d4d,0x78bd003c,0x649cc755,0x7c3bc09c}},	//   rköp, érva, _déid, mgur,
   {{0xa7fb4004,0x3ce69560,0x2bdc9561,0xd49140d1}},	//   _raña, zmov_, _बरसा, ền_,
   {{0x3ce0023b,0x67248283,0xed5a1562,0x64565563}},	//   _thiv_, ġiji, шов_, teyi,
   {{0x6449d564,0x672482a3,0xdbd4c30d,0x644d0061}},	//   nfei, šiji, _zúñi, _gbai,
   {{0x629c1565,0x6d4540de,0x7afb8b45,0x2caf81d4}},	// [f40] phro, etha, _nuut, digd_,
   {{0x44291566,0x7f445567,0x6ee94011,0xb87b435d}},	//   _zda_, rtiq, _ožbu, _phíc,
   {{0xed5a488c,0x6d455568,0x201fc21b,0x7de001c0}},	//   рое_, gtha, kaui_, _dásí,
   {{0x7f445569,0x69dc40e5,0x59c480b2,0x0b8a8ba5}},	//   ptiq, _vzre, _लुगर, исли_,
   {{0x443f956a,0x7ae1805e,0x249900fd,0x67568e40}},	//   _dcu_, _bhlt, ërmi_, تخار,
   {{0x6724556b,0x752fc064,0xe5a64f4b,0x7ae1805e}},	//   msij, ńczy, _диги, _chlt,
   {{0x321ec089,0xdddc556c,0xd1308032,0x41274077}},	//   vaty_, _forš, رمة_, _моро_,
   {{0xd90d801c,0x7afb840d,0x228b8125,0x6ef041c0}},	//   این_, _fuut, _søkt_, _fóbì,
   {{0x66d0404c,0x4429156d,0x22580353,0x236d956e}},	//   säku, _rda_, kerk_, _grej_,
   {{0x68fa8080,0x7c298062,0x6724556f,0x368ac43e}},	//   _tutd, _zder, isij, рсин_,
   {{0x7f441514,0x321ed570,0xa3ac5571,0x2b44c34d}},	//   _aqiq, raty_, _केस_, stmc_,
   {{0x92cac079,0x76589572,0x6d5c002c,0x7d0d8013}},	//   লগে_, levy, dwra, ćast,
   {{0x7cf58007,0x69de00fc,0x64409573,0x91cac045}},	//   _išra, _azpe, _mcmi, _सुरै,
   {{0x96a6c048,0x63a28157,0x7e63c02e,0x7c20d574}},	//   टोशॉ, izon, _ganp, lamr,
   {{0x34951575,0x60d6402c,0x7ea05293,0x98504526}},	//   _накр, flym, _köpf, _ağız_,
   {{0x90c40748,0x6d454046,0x212d004f,0x7e63d576}},	//   _обје, vtha, čeh_, _zanp,
   {{0xe71941b4,0x656e4e89,0x2287023d,0x249d8022}},	// [f50] صيات_, _arbh, _дунг, vhwm_,
   {{0x661c5577,0xa2b4004c,0x7afb8c99,0x6d455578}},	//   _cerk, _обыч, _ruut, ttha,
   {{0xa90742cf,0x661c5579,0xddc18017,0x2caf80a8}},	//   زبان, _derk, _valū, tigd_,
   {{0x660dc2bc,0xaefb429a,0x68014031,0x4420557a}},	//   _đakm, _brùt, _dájó, cai_,
   {{0x7d0200b3,0x5344540c,0x6d47157b,0xa2ba557c}},	//   _čosi, _охра, ltja, ्वश्,
   {{0x260684ef,0x68fc5379,0x768f80d9,0x66d20086}},	//   सुली_, _furd, _løyv, bæku,
   {{0x78ad054a,0x7bc2c004,0x7afd557d,0xa2ba4298}},	//   _omav, _axou, _hust, ्वर्,
   {{0xa7fb4019,0x66d04041,0x31bc0323,0x7c29957e}},	//   _maño, säkt, יזונ, _uder,
   {{0x442b557f,0x68fc5580,0x68e2c396,0x998ec053}},	//   _mdc_, _zurd, _dhod, _jefņ_,
   {{0x68fc4189,0x75280166,0x6d5c0e43,0xe299c6b1}},	//   _yurd, ádzk, ywra, сао_,
   {{0x186a0d9a,0xa06a1581,0x76b28036,0xc69281f2}},	//   бани_, бана_, słyc, _ראב_,
   {{0x6459802c,0x2a659582,0x62889583,0x443d8024}},	//   newi, _halb_, _zodo, ngw_,
   {{0x2be2c2ea,0x3f8f0283,0xbf9b001f,0xd5b700d1}},	//   _परया, _żgur_, scên, ống_,
   {{0xf8bf4171,0x64bc8007,0x7d095584,0x98a0c007}},	//   _ajé_, yčio, _česn, čią_,
   {{0xd5b20032,0xfce65585,0xe7f84eb4,0x66cfc0d9}},	//   رفر_, зово, ंखला_, søks,
   {{0x68e9d586,0x2360023b,0x7af5403f,0xf09f005e}},	//   nmed, _tsij_, _aizt, chà_,
   {{0x649ccb87,0x7d1b02bc,0x28ccd3ea,0xf1fa4a2c}},	// [f60] _héic, ćusa, ावति, معات_,
   {{0x66d0404c,0x6e21d587,0x7bd60360,0xd910008c}},	//   väks, nalb, _iyyu, _لیس_,
   {{0x7afd40fc,0x44220232,0x7ce5c018,0x60d64010}},	//   _eust, oak_, mórf, plym,
   {{0x63a29588,0x6ba103a6,0x629dc13b,0x60cd41ff}},	//   tzon, _özgü, ësoj, coam,
   {{0x44220232,0x38669589,0x67244283,0x7bcb4283}},	//   iak_, rdor_, qsij, żgur,
   {{0x68e9d58a,0x2a6580d2,0x64bc83aa,0xbea3958b}},	//   emed, _calb_, mčim, начк,
   {{0x81d48079,0x6459958c,0xda6581b4,0xfd654044}},	//   সেন_, bewi, باني, _masị,
   {{0x5ba6c589,0x957c8036,0x7ce3809d,0x78bbc043}},	//   зроз, _rząd, võrg, gnuv,
   {{0x3f804018,0xa87b4052,0x7c2287fb,0x8c3dd58d}},	//   nxiu_, מאקר, maor, vişt,
   {{0x245700d1,0x44221351,0xb9210044,0x81cb802a}},	//   _ầm_, eak_, gasị_, রেই_,
   {{0x68e4068a,0x59be558e,0x8c3dd58f,0x27e00020}},	//   _bhid, ्थिर, tişt, _azin_,
   {{0xa7fb4018,0xddc1c107,0x249fc106,0x26ccd590}},	//   _raño, gelő, chum_, sodo_,
   {{0xcb1b4045,0x8143c01c,0xbd0200eb,0x6502025d}},	//   _पौंड_, ونین, _ọkpọ, _ọkpụ,
   {{0x7cc1c279,0xf1be4945,0x1adc8028,0x66ddc01c}},	//   mēra, ्थान, यतिथ, pèka,
   {{0x27e00e07,0x661e1591,0xa4d5431e,0x7de7005f}},	//   _ezin_, _depk, дові, désé,
   {{0x768f80d9,0xb87b4031,0x628ac3ad,0x68f6006a}},	//   _høyt, _ehín, _hofo, _giyd,
   {{0xc3118079,0x2009034d,0x7af540fc,0xe3bf0070}},	// [f70] _হয়নি_, _ifai_, _pizt, fañe_,
   {{0x290c8053,0x81d6402a,0x68e9d592,0x68e41593}},	//   _otda_, াইন_, zmed, _zhid,
   {{0xf3ff001f,0x68e9d594,0xe80a8044,0x60cd5595}},	//   ndão_, ymed, _ịbịa, poam,
   {{0x20d20032,0xddc70036,0x628ad596,0x57b5827f}},	//   láir_, zejś, _lofo, мбет,
   {{0x68e9d597,0x6265806f,0x26ce8398,0x66ddc303}},	//   vmed, двла, fofo_, dèkn,
   {{0x2a658283,0x7af70283,0x62838022,0x88bcc047}},	//   _qalb_, _jixt, ujno, _dvěm,
   {{0x6e21d4c1,0xbd454032,0x7af71598,0xddc1c107}},	//   valb, _تنزي, _mixt, yelő,
   {{0x3866ce94,0x442200fc,0xd709c0b4,0xc21fc027}},	//   _caor_, xak_, оние_, _मजहब_,
   {{0x20d20004,0x44221599,0x628ad59a,0x3866c269}},	//   záis_, vak_, _bofo, _daor_,
   {{0x6f1b8024,0xaabf4d22,0xe3b6d59b,0x7af70283}},	//   _iwuc, ्विक, ьбы_, _nixt,
   {{0x68e9d59c,0x6da5caba,0xe5a5d59d,0x6e21d59e}},	//   pmed, фина, фини, ralb,
   {{0x20d20019,0x7c3a0007,0x648ec321,0x7c2d00b9}},	//   váis_, ėtro, _dùis, _cdar,
   {{0xc058c589,0xa3ac52c7,0xfd654112,0x64bc8077}},	//   _хіх_, _कें_, _pasị, fčij,
   {{0x6726011b,0x7af7159f,0xa3e2c471,0x20d205b1}},	//   rskj, _cixt, _धरत_, táis_,
   {{0xaca3800c,0x61430a6b,0xf2d28052,0x443fd5a0}},	//   _chừn, кера, דעם_, ogu_,
   {{0x2ca04056,0x6e2395a1,0x7f49c6ed,0x6ac64c4b}},	//   uhid_, hanb, oteq, वव्र,
   {{0x9f44004c,0xaec615a2,0x661e006a,0x4b2605dd}},	// [f80] ämä_, _обил, _tepk, _ўмов,
   {{0x64b895a3,0xed5a15a4,0x3f804018,0xb87b4032}},	//   ेक्श, _доо_, rxiu_, _fhío,
   {{0xe45f4041,0x644d55a5,0x63a455a6,0xfe140185}},	//   _bjöd_, bfai, szin, _त्यस_,
   {{0xa3c955a7,0x290c8024,0x648ec321,0x80dc402a}},	//   _लुक_, _rtda_, _lùir, _মূর্,
   {{0xaca440eb,0xa3c855a8,0x2be2c0b2,0xb87b4359}},	//   _laịt, _ऊँट_, _परधा, _mhíl,
   {{0xc3334087,0x6d48c561,0x67298007,0x9f4000a8}},	//   _בוש_, ytda, _dvej, _azië_,
   {{0x645bd5a9,0xd826816f,0x249dc2cd,0x6f1b8073}},	//   feui, _одви, _blwm_, _ewuc,
   {{0x443fd5aa,0xa01b0086,0x91e355ab,0x249dc99e}},	//   ggu_, gjöl, _росе, _clwm_,
   {{0x63add5ac,0x6442c35d,0x2ef4d5ad,0x29038303}},	//   _žanr, _vcoi, нзир, _éjan_,
   {{0xb347817a,0x443fd5ae,0x7c2083ad,0x386955af}},	//   _duħħ, agu_, _hemr, zdar_,
   {{0x386955b0,0x6f0d15b1,0x644d55b2,0x765c15b3}},	//   ydar_, _stac, yfai, dery,
   {{0x6d48d5b4,0xf3ff010b,0x753ac232,0x6736465a}},	//   rtda, rdão_, rutz, kryj,
   {{0x7d0945c7,0x2a7a0033,0x7c2095b5,0xfbe2c42f}},	//   _česm, _bnpb_, _memr, _परिम,
   {{0x7ce5c004,0x765c00b1,0x629895b6,0x78a2800b}},	//   tórg, gery, nkvo, hhov,
   {{0x7e6880b0,0x7c2455b7,0x78a280c7,0xa01b04c9}},	//   _madp, fair, khov, ljöm,
   {{0x260f0028,0x78a28c82,0xfbe2cf92,0xfaff413b}},	//   _त्री_, jhov, _पराम, _orët_,
   {{0x7e7a8353,0x4424d5b8,0x60c2c12c,0x442d8147}},	// [f90] _ontp, iam_, _mjom, _rde_,
   {{0x7e689466,0x644d55b9,0x5a344e1f,0x2b4955ba}},	//   _nadp, sfai, кнут, rtac_,
   {{0x6e2395bb,0x383595bc,0x7c2455bd,0x673d00d9}},	//   vanb, енер, bair, lusj,
   {{0xe80a95be,0xdbd94086,0xa3c8461a,0x60c2d5bf}},	//   हुला_, _fæði, _ऊँच_, _njom,
   {{0x7e6895c0,0xdef881d6,0xfd5e835d,0xaefb4061}},	//   _badp, _biċ_, _tuyề, _grùp,
   {{0x9f9c8086,0xb4c9c8b8,0x9e648e99,0x24668026}},	//   ræða_, ोत्_, квід, _rūmų_,
   {{0x6e2395c1,0x7ae7409c,0x290115c2,0x60c2c085}},	//   ranb, _ihjt, _juha_, _bjom,
   {{0x6e2395c3,0xfdf80093,0x2b15d5c4,0x443fd5c5}},	//   sanb, וצות_, ньор, ugu_,
   {{0x60c2c077,0x59e182f6,0x3f99c066,0x645bd5c6}},	//   _djom, _फरवर, ásu_, reui,
   {{0x0d85cb69,0x68ed55c7,0xe611c1b4,0x6444023f}},	//   елон, hmad, دشة_, _scii,
   {{0x248d8077,0xd49c41c0,0x765c15c8,0xdd9183be}},	//   _koem_, _bọ̀_, very, _حوا_,
   {{0x77640080,0x7ea044c9,0x20050036,0xa3d48045}},	//   _psix, _köpc, ślin_, _सुड_,
   {{0x7d0195c9,0x69cec0fa,0x68ed41c8,0x47d1802a}},	//   _huls, über, dmad, _তৃতী,
   {{0xcb36c323,0x7c2455ca,0x753c03af,0xa3b8c032}},	//   _נאצי_, wair, turz, _تامر_,
   {{0x649ccb87,0x649a4077,0x69c740da,0x442fd5cb}},	//   _méin, птар_, _nxje, _kdg_,
   {{0x649cc1b4,0xa01b005f,0x753c07ca,0x7ce5d0ec}},	//   _léin, zköz, rurz, bóre,
   {{0x69cb406a,0x60c40085,0x442fd5cc,0x6f1d499e}},	// [fa0] şgel, _ijim, _mdg_, _cwsc,
   {{0x60dbd5cd,0x7641d2ca,0xb87b01ab,0xf09f4031}},	//   hlum, ngly, glíf, _elà_,
   {{0x7c2095ce,0x321800c9,0x20074064,0x290101c6}},	//   _pemr, mbry_, śnia_, _guha_,
   {{0x64a655cf,0x6729c04a,0x661b4654,0xe3bf0019}},	//   _чама, ksej, _đuke, laña_,
   {{0x69c74070,0xafdb127d,0x44225593,0xe80f83fc}},	//   _exje, lfør, _iek_, ाड़ा_,
   {{0x78a295d0,0xb87b0018,0x6d4a82e1,0x11d640d9}},	//   shov, lmít, ttfa, _зібр,
   {{0x2ca0054a,0x442fd5d1,0x3ce6c022,0x672bc11b}},	//   _olid_, _bdg_, _phov_, _avgj,
   {{0x442255d2,0xf8bf002d,0x2a6a4085,0xa3e74048}},	//   _jek_, xné_, _habb_, येक_,
   {{0x7af8c022,0x3869015d,0x64a395d3,0x22b68036}},	//   _pivt, _raar_, _сата, ałka_,
   {{0x649cc145,0x610c43a6,0x386915d4,0xe35780c3}},	//   _géin, _eğle, _saar_, _אשמח_,
   {{0xd5bad5d5,0xa3d48314,0x2be2cb05,0xb6374009}},	//   яси_, _सुत_, _परवा, ערטס_,
   {{0x4424d5d6,0xafdb058a,0x673d15d7,0x7792c1aa}},	//   qam_, dfør, tusj, _میبا,
   {{0x386902a4,0x20094046,0xddc755d8,0x26d101c6}},	//   _vaar_, vcai_, _pajū, tozo_,
   {{0x60c415d9,0x69d8c240,0x442240fc,0x6234c156}},	//   _ejim, _tyve, _aek_, _реку,
   {{0x41d050de,0x26d10247,0x6ee004c9,0x673d0043}},	//   _तुलस, rozo_, möbl, susj,
   {{0x68ed55da,0x645d00fd,0x768f80d9,0x69da95db}},	//   umad, qesi, _løyp, _myte,
   {{0xe3bf046a,0x248d868e,0x6fb900d9,0x36d54119}},	// [fb0] baña_, _roem_, _ігор_, воар,
   {{0x6eba4b6d,0x60dd0655,0x7c22d5dc,0x7aedc23f}},	//   ्वगु, llsm, _leor, _èatt,
   {{0x442695dd,0x81d8002a,0x68ed55de,0xb40e8112}},	//   fao_, ়েব_, pmad, _ịpịa_,
   {{0x4c954949,0x442255df,0x7afa83a6,0xa3e8009d}},	//   _римс, _gek_, _aitt, _भरम_,
   {{0x649cc032,0x442fd5e0,0xb4bf4163,0xf41f0025}},	//   _péin, _rdg_, ेवी_, yjän_,
   {{0x248955e1,0x6e270451,0x6e2195e2,0x7bd9c1f4}},	//   ljam_, najb, _qelb, _rywu,
   {{0x6fc9c028,0x60dbd5e3,0xa15686b1,0xdca5c051}},	//   _हुजू, tlum, вају_, каки,
   {{0x397c02a6,0xb17c0087,0x6729d5e4,0xe3bf030d}},	//   לטונ, לטור, tsej, zaña_,
   {{0x81d70079,0xa7fb430d,0x7082c025,0x6d58d09c}},	//   িধি_, _bañi, ргыз, _apva,
   {{0x7ea04041,0x79a795e5,0xa7fb430d,0x7c2d8086}},	//   _köpa, _прее, _cañi, ðarf,
   {{0x7c2615e6,0x60dbd5e7,0x26c1410b,0x7bdb8033}},	//   takr, plum, inho_, _hyuu,
   {{0x6f02c0c5,0x660943a6,0x7bdb95e8,0xf3ff400c}},	//   _fuoc, _şekl, _kyuu, _ngã_,
   {{0x386dd5e9,0xab6315ea,0xfb85c01c,0x68fb82eb}},	//   mder_, авял, _جدای, _miud,
   {{0xed5a15eb,0x68fb8007,0x672d01fd,0x200b00c4}},	//   мог_, _liud, _dvaj, acci_,
   {{0xe3bf15ec,0x7c22c033,0xada5c43e,0x2d8ac065}},	//   raña_, _yeor, _шакл, øbet_,
   {{0x442695ed,0x92b2002a,0xc5f8c8c7,0xe7f68047}},	//   xao_, টকে_, rdēt_, ेशमा_,
   {{0x386dd5ee,0x6456091f,0x4432009c,0x26d34018}},	// [fc0] ider_, _ibyi, _idy_, foxo_,
   {{0x442255ef,0xdebbc09c,0xb69b40cc,0x2d9655f0}},	//   _wek_, ttuƙ, _stâr, крес,
   {{0x386dc21b,0xa2b781f9,0x7bdb81c8,0x958640c5}},	//   kder_, ्चन्, _ayuu, ълже,
   {{0x7d0dc0b3,0x6aa18b25,0x2ca08032,0xb4dc8814}},	//   _časl, _allf, óid_, डते_,
   {{0xef17404c,0x7d03d5f1,0x69da95f2,0xb05b4041}},	//   _имя_, _luns, _syte, _mjäl,
   {{0x395a0033,0x5f9395f3,0x6d4e014d,0x6389013b}},	//   _kpps_, ришт, otba, _hënë,
   {{0x2d9815f4,0x3cfdc027,0x3f8080b4,0x98c6d5f5}},	//   nyre_, _रंगे_, ţiu_, ксил,
   {{0x3eb80359,0x7c2415f6,0x70ccc09d,0x769d8053}},	//   hirt_, _neir, ावेल, _fèyo,
   {{0x78a340b4,0x442495f7,0x4734c6b1,0x6f02c0d1}},	//   _înve, _iem_, ћнос, _quoc,
   {{0xd9e64021,0xd138c007,0x64560449,0x33d58039}},	//   _करात_, trą_, _abyi, _сіст,
   {{0x3ce90046,0x2294054a,0x629c0113,0x069740c3}},	//   _phav_, _läks_, dkro, דדים_,
   {{0x2366d5f8,0x6e23d5f9,0x638900fd,0x7c2415fa}},	//   _tsoj_, _eenb, _nënë, _ceir,
   {{0x0eb68185,0x6d4e04f1,0x3cfbc027,0xa3e8084d}},	//   _अगाड, etba, _लूटे_, _भरण_,
   {{0xf2c40051,0x645601c6,0x26d3400b,0x3cfdc25c}},	//   ассн, _ebyi, xoxo_, _रूके_,
   {{0x3ce90022,0x69d8127d,0x60c280b1,0x403555fb}},	//   _thav_, _øvel, knom, левс,
   {{0x6e23ce07,0x7f4d55fc,0x61e50185,0x3a2783bc}},	//   _zenb, ttaq, _vzhl, zanp_,
   {{0x68e981f4,0x7afc55fd,0x68fb8016,0x58844007}},	// [fd0] _rhed, _birt, _riud, шыра,
   {{0x64bc8039,0xceb8c064,0x78a2d5fe,0x6abf4021}},	//   ičiu, nię_, _llov, ्वेर,
   {{0x443201f4,0xb90b81c0,0x69dc547c,0xf19515ff}},	//   _ydy_, _dajọ_, _cyre, _синь,
   {{0xc953c009,0x2aad0066,0x0577401c,0xd4e480d9}},	//   ימע_, ržbu_, _یازد, аючи,
   {{0xab845600,0x3a235601,0x6f040004,0x649cc032}},	//   _курк, _tejp_, _xuic, _céim,
   {{0x69dc436b,0x38a21602,0xc105400f,0x29035603}},	//   _fyre, _móra_, _موسي, _tuja_,
   {{0xddc1806f,0xddc88077,0x6fd50045,0xb812802a}},	//   _balš, _endž, _युसू, _হযরত_,
   {{0x657a4a2c,0x7ce5c1b4,0x7d03c051,0xb05b4041}},	//   _átha, fóra, _runs, _ojäm,
   {{0x2bd30d91,0xe3bf0018,0x629c014b,0x6e23c15a}},	//   _धुला, daño_, ykro, _penb,
   {{0x27e6c077,0x7ea04041,0x386dd604,0x7afc41c8}},	//   _dzon_, _löpn, sder_, _xirt,
   {{0x2913023b,0xd00ed605,0xaca34031,0x69c480b4}},	//   _ntxa_, غلی_, _asọd, şier,
   {{0x2375c6b0,0x7ce5c018,0x7f4d0085,0x93e34048}},	//   _ماتح, bóra, _bqaq, _खरंच_,
   {{0x6e28d606,0x7ce5c018,0x386d8fcf,0xef0ec1d5}},	//   badb, córa, _maer_, _ым_,
   {{0x6d4e1607,0x38a21608,0x6f040011,0xd946127f}},	//   ttba, _dóra_, _vuic, леги,
   {{0x64a640d7,0x2d9e1609,0xed570fd4,0x610c459a}},	//   гава, áte_, лор_, _oğla,
   {{0x661b4a18,0x18674244,0x7c29d60a,0xe3bf0019}},	//   _đuka, ласи_, naer, caño_,
   {{0x78a404fd,0xb87b0185,0x3eb800fd,0xc0e34d9b}},	// [fe0] _iliv, blíb, pirt_, сотк,
   {{0x5a660ff9,0x68fd560b,0x610c41df,0x3a258033}},	//   _скоб, _eisd, _ağla, _nelp_,
   {{0x672340e0,0x7afc560c,0x26da0044,0x78a4160d}},	//   ćnja, _virt, _ikpo_, _kliv,
   {{0x673b006c,0x20d90032,0x7cfed5c5,0x1b19c079}},	//   šuje, léir_, _jūra, _দিনে_,
   {{0x3ce040d9,0x60c4560e,0x78a40230,0x14d740c3}},	//   mliv_, mnim, _mliv, _תוכל_,
   {{0x6ffbc279,0x60c4560f,0xf96a800a,0xa7fb4070}},	//   _mācī, lnim, ерий_, _cañu,
   {{0x249d8022,0x6d41c073,0x6e28d610,0xc5f540c5}},	//   bkwm_, jula, vadb, _вятъ,
   {{0xa4f88973,0x290582a7,0x69de021b,0x7afe1611}},	//   _شکار_, _dula_, _mype, _lipt,
   {{0x8626d612,0x38bac031,0xec13805f,0xf09344e0}},	//   льне, _aàrè_, _چوہد, מנה_,
   {{0x44295613,0x35d940b2,0x3266d614,0xa5da8032}},	//   zaa_, _बुड़, утив, _كبار_,
   {{0xceb8c064,0xe3bf02b0,0x6e28d615,0xac191616}},	//   rię_, taño_, radb, кону_,
   {{0x629dc0fd,0x7c29d617,0x60c45618,0xb4ce4185}},	//   ësor, caer, jnim, शको_,
   {{0xceb8c036,0x6108c0a0,0xfcd3c01c,0xb7bf402a}},	//   pię_, _tělo, _اينج, _আর্ট,
   {{0x3eba40fd,0x4ea70a67,0x78a4000b,0x6d41d619}},	//   jipt_, урма, _eliv, bula,
   {{0x81dd0079,0x69de161a,0x30eb527f,0x38bac1c0}},	//   তেন_, _cype, ефан_, _gàrè_,
   {{0x26c3161b,0x8933c6b0,0x2fc600e5,0x5f950119}},	//   snjo_, _اعوا, _žoge_, _виит,
   {{0x2d8c0065,0x26c3004f,0x4426c35d,0x23ab0031}},	// [ff0] øder_, pnjo_, _meo_, _dòjé_,
   {{0x20d9161c,0xb6030185,0xb87b003c,0x7bdd4089}},	//   péis_, část, blíc, _vysu,
   {{0x78a40051,0x27ec0036,0x386d80d2,0x66d04025}},	//   _yliv, ędne_, _paer_, näky,
   {{0xddde0185,0xb4bed283,0x44294149,0x6f0d85f4}},	//   _např, ँचो_, qaa_, íaco,
   {{0x68ff0080,0x7658c347,0x7ce5d426,0x3f69961d}},	//   _miqd, _obvy, fórn, тило_,
   {{0xd126c182,0x6495c359,0x68ed0303,0x8237961e}},	//   _وم_, _náir, _lhad, ارشا,
   {{0xa2d6161f,0x6722c1c0,0x7e61c127,0x7c29d620}},	//   णवत्, _awoj, velp, taer,
   {{0x64498018,0x673bcf5f,0x29059621,0x6e354043}},	//   _ucei, truj, _vula_, _hdzb,
   {{0x2d98c36b,0xd05d003a,0x200dd622,0x2905809c}},	//   øren_, _üzər, rcei_, _wula_,
   {{0x6495c145,0x60c4404f,0x81b9c09c,0x7c29d623}},	//   _páis, znim, _haɓɗ, saer,
   {{0x68ed1624,0x60c9811b,0x332dd625,0x91e5d626}},	//   _bhad, _kjem, ssex_, роне,
   {{0x3ced805c,0x7d0e8066,0x6495c018,0xe45f4041}},	//   _jhev_, žisé, _váis, _sjön_,
   {{0xa7fb0004,0x68ed1627,0x78a40047,0x7e61d628}},	//   teña, _dhad, _vliv, pelp,
   {{0x6495c032,0x249fd629,0x7e63962a,0x60c4562b}},	//   _gáir, lkum_, nenp, wnim,
   {{0xb8250079,0x61038107,0x2f0b80b0,0xa7fb0019}},	//   _ভারত_, _főle, _løg_, reña,
   {{0x64bac1b7,0x2ca9562c,0x78a4162d,0xe3bf430d}},	//   nċip, ghad_, _uliv, _seña_,

   {{0xb2265000,0x7afe162e,0xb4c4162f,0x3b86460e}},	// [1000] имал, _tipt, ्वी_, шлаг,
   {{0x26da0112,0x249fc696,0x2216423d,0x27e0002e}},	//   _ukpo_, hkum_, рфар, _iyin_,
   {{0x7c2643a6,0x5be2cf76,0x14c841aa,0x26d81630}},	//   _tekr, _पर्व, _مهدی_, moro_,
   {{0x6d439631,0x6d5e0283,0x67241632,0x2ca944ff}},	//   duna, _ippa, _kwij, chad_,
   {{0x91fcc03f,0x7e638572,0xe45f5633,0x3d1c0031}},	//   ndār, fenp, _mjöl_, _fàwò_,
   {{0x35db056c,0x60db9634,0x7e638484,0xfaa64495}},	//   _मुड़, _ekum, genp, _таго,
   {{0xe2978afa,0x5066c097,0x442b12f6,0xed8780c5}},	//   рај_, атпа, yac_, исък_,
   {{0x2d68406a,0x78a9c23f,0xea00000c,0x62819635}},	//   _işe_, ghev, _giấu_, _enlo,
   {{0x6b9bd636,0x2ca040f8,0xa6869637,0x7ac6d638}},	//   gyug, ikid_, _клад, исое,
   {{0x68e29639,0x26d8163a,0x7224402a,0x68ed163b}},	//   llod, joro_, _পাঁচ_, _shad,
   {{0x64a6d63c,0x2be2c021,0x672401c0,0x5886c3d0}},	//   _кажа, _परका, _awij, _выла,
   {{0x08fac4a4,0x27e00053,0x22998031,0x672404db}},	//   _شراب_, _byin_, _dèku_, _bwij,
   {{0x26d8163d,0xb05b0025,0x6b9bcf2d,0x58f78d89}},	//   foro_, snäo, cyug, ימטע_,
   {{0x2907d63e,0x6724044e,0x539bc0c3,0x1de6409d}},	//   _funa_, _dwij, _בידו, _करूष_,
   {{0xfc3f4070,0x2ca9468a,0x7d088053,0x6113c0b4}},	//   _alía_, thad_, _juds, _căld,
   {{0x673d07ca,0x20d20018,0x7e638206,0x6e28963f}},	//   prsj, záiz_, zenp, _ledb,
   {{0x5a3540c5,0x90a7005f,0xb6038066,0xa7fb034d}},	// [1010] йнат, _محکم, áško, meño,
   {{0x63ad5640,0x6e2881e5,0x7d088353,0xda78404c}},	//   rzan, _nedb, _ouds, иях_,
   {{0x63ad5641,0x67241642,0xfc3f4070,0x5d555198}},	//   szan, _zwij, _elía_, скет,
   {{0xb87b4b87,0x32110062,0x00000000,0x00000000}},	//   _chít, lczy_, --, --,
   {{0x947483be,0xb87b4032,0x98b840b4,0x69ce4303}},	//   تدلا, _dhít, sură_, _exbe,
   {{0xaa499643,0xbbb79561,0x7d074247,0xdd39c379}},	//   упка_, _अधीक, _tujs, năţe,
   {{0x6e2880e2,0xdf738031,0x7e639644,0x78a9c13b}},	//   _dedb, _bẹ̀é, renp, thev,
   {{0x644d004d,0x60c99645,0xa3e8054a,0x2907d646}},	//   _ncai, _ujem, _भरल_, _runa_,
   {{0xdd9180fb,0x62955647,0x657a80de,0x249fc086}},	//   توں_, _kozo, _erth, rkum_,
   {{0xb7bdc119,0xe3bf4019,0x6b9d01f4,0x44290b87}},	//   naţi, _leño_, dysg, _aea_,
   {{0x62955648,0x7d088ded,0x382a0051,0x27e6006f}},	//   _mozo, _guds, лжно_, _šon_,
   {{0x6b9d01f4,0x644d005e,0x31ba80c3,0x6f1600b9}},	//   fysg, _ccai, _גזענ, _ptyc,
   {{0x6abc0086,0xbf67c2cf,0xe28ec156,0x201fd649}},	//   tirf, _خداو, _еа_, mbui_,
   {{0x7e654033,0x6295564a,0x6f1bd64b,0xd8398053}},	//   jehp, _nozo, mpuc, _blōk_,
   {{0x6f01964c,0x09e605a6,0xe5a3164d,0xada3164e}},	//   _milc, совн, пири, парл,
   {{0x442dc12c,0x644d01b4,0x672401d4,0xe3bf4070}},	//   nae_, _gcai, _twij, _ceño_,
   {{0x7e9a0425,0x26d8164f,0x6f0983e9,0x7f4a4032}},	// [1020] _منظر_, poro_, _nuec, طلاق_,
   {{0x387247fb,0x629540cc,0xe45f0025,0xe29741ff}},	//   sdyr_, _cozo, nnön_, бау_,
   {{0x6e2e1650,0x442dd651,0x6d5e1652,0x84e3454a}},	//   mabb, kae_, _uppa, _कीकट_,
   {{0x7ce5c2b0,0xe3a7ce5f,0x7c2981c8,0xa01b1633}},	//   fórm, _فر_, _ceer, ljör,
   {{0x6283c101,0xdee68aba,0x2f569653,0x7c2d8397}},	//   _onno, боди, стес, ðara,
   {{0xa01b0041,0x56939654,0x427a0052,0x7d0880b0}},	//   njör, зашт, ראַג, _puds,
   {{0xb9964032,0x44205655,0x7c299656,0xd90d816a}},	//   _الزب, obi_, _feer, نیل_,
   {{0x5066d657,0x5fc80185,0x3ebc9127,0x290a4010}},	//   стка, रपाल, sivt_, _iuba_,
   {{0x6e2e0d39,0x68e45658,0xa6e28397,0x691340f6}},	//   kabb, ilid, óðsk, _għeb,
   {{0x44205659,0x2d78165a,0x7c29965b,0x7c2d565c}},	//   hbi_, _oče_, _zeer, zaar,
   {{0x867b8093,0x6e2e00f1,0x1958c007,0x2fc7400c}},	//   _תרבו, dabb, шаны_, ̃ng_,
   {{0x290a565d,0x232acb8e,0x2fc9c0e5,0xdb0a0089}},	//   _muba_, _боди_, _žage_, žným,
   {{0x4394c747,0x6e2e0a48,0x274b0051,0x9e34c47f}},	//   _фалс, fabb, ычно_, _делч,
   {{0xa7fb0319,0x6e2e12cf,0x46f6c051,0x7bdcc1df}},	//   seño, gabb, _учет, ğrud,
   {{0xb05b004c,0x62954166,0x27e240f8,0xc984083a}},	//   nnäk, _rozo, _aykn_, пути,
   {{0x29024067,0x5ba711cd,0x7cff0031,0xddc7565e}},	//   _cika_, _гроз, _dàrì, _najš,
   {{0x60cd091f,0x7c298057,0x7d02d65f,0x6d455660}},	// [1030] _ijam, _reer, _mios, wuha,
   {{0x2fc74015,0xaca38015,0x3ebed661,0x683f4031}},	//   ăng_, _khủn, nitt_, _bàdà,
   {{0x78a285a0,0x29184560,0x6d41003e,0xe509c0d1}},	//   fkov, _ctra_, álad, _lặn_,
   {{0x2006c0d1,0x60cd00bb,0x7c2d4149,0x6f0185d1}},	//   _ngoi_, _jjam, qaar, _silc,
   {{0x6f098b72,0x442dc230,0x62955662,0x66059637}},	//   _quec, vae_, _tozo, опла,
   {{0x26da5663,0x6d455664,0x88cf0079,0xbdfb405f}},	//   copo_, puha, রতিক, _مرزا_,
   {{0x78a28066,0x6f018017,0x31355665,0x59a48036}},	//   bkov, _vilc, _фебр, गैलर,
   {{0x60cd1666,0x7ce5c036,0x802785d3,0x61054007}},	//   _njam, mórk, _درآم, _dėlt,
   {{0xf8bf0669,0x986880fb,0x3ebed667,0x6d471668}},	//   dié_, _دینے_, fitt_, huja,
   {{0x6449d669,0x4420566a,0x60cd166b,0x21f9c119}},	//   sgei, zbi_, _ajam, ихнэ_,
   {{0xf866044c,0x6e2e166c,0x645d566d,0x644b80c4}},	//   овно, vabb, _obsi, oggi,
   {{0x3947966e,0x62850065,0x6b84c0b3,0x7d02d66f}},	//   muns_, _anho, _šige, _gios,
   {{0xb87b1670,0x78ad5671,0xa85680c3,0x6297056e}},	//   plín, dhav, חירה_, _boxo,
   {{0xe8e04015,0x645d4252,0x644f4129,0x44204033}},	//   _đốc_, _absi, _acci, wbi_,
   {{0x660302d0,0x442b5672,0x44205673,0x7c96535b}},	//   дпра, _bec_, tbi_, орац,
   {{0x442f9674,0x6ab68191,0x62851675,0xf8bf001e}},	//   jag_, _अग्र, _enho, cié_,
   {{0x7eab03a6,0x6d550232,0x765c810d,0x26da47f3}},	// [1040] _süpe, atza, _öryg, topo_,
   {{0x78a99676,0x60c9c113,0x61e3c086,0x78bb9677}},	//   _alev, hnem, _kynl, _amuv,
   {{0x65618046,0xe96a5512,0xa3e64678,0x26da5678}},	//   _nplh, раел_, _फरक_, ropo_,
   {{0x442b5679,0x6f000031,0x442f8149,0xb7e68cc4}},	//   _gec_, _fábì, gag_, ожек,
   {{0xbe8a967a,0x8af04080,0x236fc398,0xa3bd4c8c}},	//   иске_, rtəb, _nsgj_, ेपण_,
   {{0x649cc1b4,0x6297167b,0x5f2748a9,0xdddc4e05}},	//   _léit, _xoxo, _форм_, _garş,
   {{0x6e2ad67c,0x7d02c064,0xda6581b4,0x3ebed67d}},	//   _refb, _pios, ثاني, vitt_,
   {{0x442f8057,0x224081df,0x6d41c561,0xd91b44e0}},	//   cag_, şik_, drla, _כולל,
   {{0x7c2bd67e,0x613081c0,0x7bc00fc2,0x9e3a8a2c}},	//   _degr, _bólá, úmul, _نساء_,
   {{0xe509c0d1,0xb50bd67f,0x78a980a0,0xc178c026}},	//   _vặn_, _संशय_, _zlev, tvė_,
   {{0xf8bf0669,0x39479680,0x7d040051,0x78a442f7}},	//   tié_, cuns_, _biis, kkiv,
   {{0x7d040057,0x60dbc018,0x2cadd681,0x7642009c}},	//   _ciis, coum, ched_, _ɓoye,
   {{0xf8bf1682,0x9c134044,0x44394379,0x78fb8323}},	//   rié_, _kọva, _rds_, יפטו,
   {{0x442f8932,0x60c0d683,0x7d04017b,0x4abc8048}},	//   zag_, limm, _eiis, ्चिव,
   {{0x3ce69684,0x78ad5685,0x7c229686,0x25db1687}},	//   klov_, thav, kbor, _खुशी_,
   {{0x291ed688,0x7d040006,0x6f03d689,0x60cd168a}},	//   mpta_, _giis, _zinc, _ujam,
   {{0x290c80ab,0x78ad44a9,0x3ce68498,0x442f968b}},	// [1050] _luda_, rhav, dlov_, vag_,
   {{0x5187168c,0xc987168d,0x7c2d168e,0x78ad568f}},	//   _дума, _думи, _hear, shav,
   {{0x802751e0,0x290c9690,0xbc19811e,0x78ad411b}},	//   _ورحم, _nuda_, білі_, phav,
   {{0x6f0d04fd,0xf993c2a6,0x26c40166,0x6298d691}},	//   _kuac, ורע_, émov_, _lovo,
   {{0x7c2d1692,0x60c9d693,0xb4d7422d,0x386951ed}},	//   _mear, vnem, ाकी_, mear_,
   {{0x7c2d1694,0x644d5695,0x2486d696,0x6f0d000c}},	//   _lear, lgai, _anom_, _muac,
   {{0x3d06c834,0x7762c004,0x60c9d697,0x290480e2}},	//   _संगे_, _apox, tnem, _fima_,
   {{0x6d574022,0x26c15698,0x7c2d1699,0x78a9969a}},	//   mtxa, liho_, _near, _ulev,
   {{0xf7708a1d,0x5f7781aa,0x63a0c655,0xddc1c047}},	//   _لال_, _بازر, gymn, telů,
   {{0xe3b085a7,0x7c2bd69b,0xf3f9c119,0x60dbc907}},	//   _شرق_, _wegr, neţi_, soum,
   {{0xfce60717,0x6d5740fc,0x60cb80d1,0x6729817a}},	//   зоно, ntxa, ongm, _hwej,
   {{0x3869434d,0x60c0c09c,0x7ce5d69c,0x7c3b817a}},	//   jear_, cimm, kóri, _jdur,
   {{0x6f03d69d,0x7c3b80b3,0x3869569e,0x09b8509f}},	//   _tinc, _mdur, dear_, _आध्य,
   {{0x5239c009,0x247840eb,0xb77ac0c3,0x6729817b}},	//   _הײַנ, _ọm_, _לאנש, _mwej,
   {{0xea000082,0x7c3b969f,0x386941b4,0xdca60bf3}},	//   _khẩu_, _odur, fear_, _наки,
   {{0x7c3b96a0,0x7c2d8086,0xb4c78185,0x6d3ac0c3}},	//   _ndur, ðarl, ैको_, _התקנ,
   {{0xe73a4119,0x630649ab,0x7e7540b9,0x38600024}},	// [1060] сез_, سوال, _bazp, _ibir_,
   {{0x0f7b01f2,0xb05b44c9,0x2cab488b,0x442d96a1}},	//   _פריל, _sjät, _elcd_, _aee_,
   {{0x7c2296a2,0x729b00c3,0x6e934a2c,0xa06a4c85}},	//   tbor, _הסיס, علما, _лана_,
   {{0x38a201c0,0x6abe0303,0x672996a3,0x261800b2}},	//   _bóri_, _hmpf, _bwej, बुरी_,
   {{0x60c0c051,0x20074047,0x59ddc25c,0x8fa38030}},	//   vimm, ěnit_, _नुसर, наце,
   {{0x7c244498,0x7e7556a4,0x291ed466,0xf3f9c119}},	//   lbir, _gazp, ypta_, ceţi_,
   {{0x7e68c240,0x4c94c99b,0x98bf00b4,0x7d0656a5}},	//   vedp, дийс, nută_, _kiks,
   {{0x661b56a6,0x7e754232,0x338f4031,0x6298c147}},	//   _đuki, _zazp, _aáṣé, _sovo,
   {{0xe6468b9d,0x6e2e56a7,0xf74396a8,0xe509c0d1}},	//   _неап, _kebb, _пето, _dặm_,
   {{0x7cf196a9,0x7b0b003f,0x9c134112,0x1c020045}},	//   råre, _kļuv, _họta, ोशनल_,
   {{0x386956aa,0x9c134112,0x765c002c,0x94d50afa}},	//   year_, _kọta, dfry, донц,
   {{0x629a96ab,0x7e68c472,0x4ff68171,0x6d4a89dc}},	//   _hoto, sedp, _aṣiṣ, mufa,
   {{0x68e2d6ac,0x99878077,0x38694070,0x2d6e80a0}},	//   _ikod, manš_, vear_, _hře_,
   {{0xdb23405f,0x2ac2c1c0,0x2be1c048,0x36d516ad}},	//   ہوری, _débè_, _पडता, фогр,
   {{0x63a296ae,0x997e00b4,0x7d0648c7,0x6d5896af}},	//   hyon, văţa_, _biks, ntva,
   {{0x4de6454a,0xc7b9c107,0x63a296b0,0xe89440d7}},	//   _करजई_, kből_, kyon, нась,
   {{0x386956b1,0xe71941b4,0x6e2e56b2,0x78ad16b3}},	// [1070] rear_, زيات_, _bebb, _ilav,
   {{0x9bf403d0,0x443249c7,0x7c2441ae,0x7cd20975}},	//   _языч, aay_, abir, māra,
   {{0x26ccc01d,0x26c156b4,0x98bf0119,0x26c3004f}},	//   indo_, riho_, cută_, mijo_,
   {{0x644f000b,0x6d574232,0x6e2e41c8,0x2bde817e}},	//   ngci, rtxa, _eebb, _फुहा,
   {{0x442d96b5,0x69d8127d,0x78ad006f,0x60cd56b6}},	//   _vee_, _øver, _mlav, mnam,
   {{0x6447c039,0x68e941b7,0x60cd4645,0x68e2d6b7}},	//   ėjim, ċedu, lnam, _akod,
   {{0x24890053,0x7d0e4033,0x63a296b8,0x78ad16b9}},	//   _onam_, _gubs, ayon, _olav,
   {{0xb4ac0185,0xef19c434,0x92cd8079,0x628896ba}},	//   _गते_, оми_, রতে_, _endo,
   {{0x98bf00b4,0x63a2884f,0x26c316bb,0x657c0089}},	//   zută_, cyon, kijo_, zvrh,
   {{0x26ded6bc,0x38c3c171,0x290ec060,0x60cd56bd}},	//   goto_, _bèrè_, _bufa_, hnam,
   {{0xa3e44758,0x3ce943e2,0x904601aa,0x645d16be}},	//   _पुन_, klav_, ونده, ffsi,
   {{0x7c244561,0x777bc4c9,0x644a4107,0xfd69425d}},	//   xbir, pvux, őfiz, wupụ,
   {{0x290ec09c,0xe72ed0c4,0x68fbd6bf,0xddc18011}},	//   _eufa_, _ше_, mmud, _jalž,
   {{0xda0d96c0,0x26c316c1,0xcc12c112,0xf8bf56c2}},	//   िखित_, gijo_, _fọsị, _amé_,
   {{0x78ad16c3,0x2cad854a,0x6e2e40f1,0x63a296c4}},	//   _flav, _oled_, _rebb, zyon,
   {{0x6e2e56c5,0x7f4456c6,0x68e9d6c7,0x2aa0c031}},	//   _sebb, triq, nled, _dòbu_,
   {{0x26c316c8,0xcc12c0eb,0x765c0838,0x6d4540fa}},	// [1080] bijo_, _kọrị, pfry, erha,
   {{0x60cd468a,0x81dd0079,0xadc4c02e,0x44388036}},	//   anam, তেই_, _ayẹy, _śr_,
   {{0x68e9d6c9,0x2cad89b7,0x7cff0007,0xb87b41c0}},	//   kled, _bled_, _sūri, _ikín,
   {{0x63a28141,0x6aaad6ca,0x3ce956cb,0x291c4017}},	//   tyon, _छत्र, clav_, īva_,
   {{0x4ad20d91,0x38aac321,0x6f0dc359,0x3d0702ea}},	//   _सदाव, _bùrn_, _éach, _संघे_,
   {{0x6d4a96cc,0x2be1c027,0xcc12c0eb,0x68e340fd}},	//   tufa, _पड़ा, _nọrị, _ëndr,
   {{0x6d4540de,0x7cf6003c,0x21384043,0x60c28157}},	//   crha, cárg, _uvrh_, piom,
   {{0x3f8241b8,0x6d5896cd,0x2cad85ce,0x5ba6c0d9}},	//   _krku_, rtva, _gled_, дроз,
   {{0x2002c051,0xb4da8c4b,0x290ed6ce,0xb87b0305}},	//   äki_, ठकी_, _sufa_, slík,
   {{0x26ccd6cf,0x24890157,0x610c4138,0xd6d9c036}},	//   undo_, _snam_, _eşle, kułu_,
   {{0x4424d6d0,0x442fc402,0x7ae8d6d1,0xfe78c026}},	//   pbm_, _feg_, rldt, rdį_,
   {{0x4fc6c911,0x7ea04041,0x7ae3c17b,0x442fd6d2}},	//   _осла, _köps, _eknt, _geg_,
   {{0x27e6d6d3,0x26ce823f,0x60c456d4,0x5f9400c5}},	//   _uyon_, onfo_, diim, вият,
   {{0x7c2f56d5,0x68e416d6,0x60cd56d7,0xc33380c3}},	//   _secr, _ekid, wnam, כוש_,
   {{0xafdb0065,0x9d180883,0x7c2d8086,0x7ea044c9}},	//   ggør, дост_, ðark, _löps,
   {{0x2cb241f4,0xddc380b4,0x63a440c3,0x442696d8}},	//   ghyd_, lenţ, fyin, jbo_,
   {{0x6d5ad6d9,0x2bde958e,0xfbde96da,0x7c2f4017}},	// [1090] ltta, _फुला, _फुलम, _vecr,
   {{0x291e96db,0x3d1741d6,0x63a004c9,0x49750cae}},	//   _otta_, _aħwa_, ämne, _злос,
   {{0x60cd41b0,0x7ea4c016,0x69158283,0x201e4119}},	//   pnam, _còpi, _aġen, _ştie_,
   {{0x628ac010,0x6f0f4157,0x20c54017,0x63a441c6}},	//   _lnfo, _tucc, rķis_, byin,
   {{0x2366c23b,0x6b82c022,0xe76b8228,0x628ad6dc}},	//   _npoj_, _nrog, تحان_, _onfo,
   {{0xfaa7809b,0x68e9d6dd,0x672d16de,0x99674376}},	//   ьшен, wled, _mwaj, _отбл,
   {{0x91e28299,0xdbfc0a94,0x38a740b2,0xb05b16df}},	//   лоше, _एण्ड_, _nõrk_, nnäs,
   {{0x2ca944c9,0x75ce05ca,0x7aea80b1,0x672d00c7}},	//   nkad_, lőzé, alft, _owaj,
   {{0xf1df854a,0x291e96e0,0x6d5acb6f,0x672d009c}},	//   _पुरन, _etta_, etta, _nwaj,
   {{0xef1f40b2,0x2d58c1cb,0x629c56e1,0x2bda16e2}},	//   _mtü_, fée_, _xoro, _युगा,
   {{0x2f140041,0x7ea056e3,0x27e916e4,0x6d5ac0b0}},	//   _säg_, _köpr, _ayan_, gtta,
   {{0x6e3e00b3,0x672d04db,0x628ad6e5,0x63a456e6}},	//   _sdpb, _bwaj, _enfo, yyin,
   {{0xf1c38028,0x850bc75b,0xe3aec7ea,0x6d4116e7}},	//   _वेतन, _संकट_, _сб_, álan,
   {{0x9f568107,0xddc380b4,0xd6d9c036,0x68fd075a}},	//   égét_, cenţ, tułu_, amsd,
   {{0x2d98c240,0x442681c8,0x291e013b,0x27e916e8}},	//   øret_, ybo_, ëta_, _eyan_,
   {{0x291e003f,0xf708c00c,0x443f825d,0x386dc54f}},	//   īta_, _rủi_, _ndu_, neer_,
   {{0xff2440fb,0x60c616e9,0xcb6756ea,0x60d700c3}},	// [10a0] ئبری, mikm, нате_, _רופא_,
   {{0xfc3f0032,0x7d0996eb,0x45d641eb,0x44320378}},	//   bhís_, _aies, нцет, _hey_,
   {{0x63b64064,0x98a68687,0x3a0600fe,0xb5fcc283}},	//   szyn, ниже, _سکسی_, teġi,
   {{0x7d0996ec,0xddc38119,0x62814018,0x443f96ed}},	//   _cies, zenţ, _ólon, _cdu_,
   {{0x4426883e,0x7c364498,0x26c5d6ee,0xc8798080}},	//   rbo_, mayr, kilo_, _daş_,
   {{0x2b468016,0x2d58c01e,0x6b82c13b,0x443f905f}},	//   rroc_, yée_, _rrog, _edu_,
   {{0x629e0051,0x3f8056ef,0x2d58c1cb,0x443f8449}},	//   _mopo, lviu_, xée_, _fdu_,
   {{0xea0000d1,0x2b468379,0x0f26c0d9,0xb05b0414}},	//   _nhậu_, proc_, ньом, hnär,
   {{0x60c60033,0x291156f0,0x6b8416f1,0xbbcac048}},	//   dikm, _zuza_, _nrig, ापेक,
   {{0xb87b4031,0x26c5d6f2,0x443216f3,0x0f5740c3}},	//   _akíl, gilo_, _aey_, עיים_,
   {{0xddc38119,0x443216f4,0x6d5ac051,0xd2b74093}},	//   renţ, _bey_, utta, גלית_,
   {{0x6d5c16f5,0x7cd3c0b4,0xea0000d1,0xb4cb0048}},	//   dtra, păra, _chậu_, ळचे_,
   {{0xfaa6c0d6,0x7c2d8086,0x7b6416f6,0x69c816f7}},	//   _падо, ðari, лтре, úden,
   {{0x443201c8,0x6b84072b,0x7cf60089,0x69dc8211}},	//   _eey_, _drig, váre, _øres,
   {{0xd5afd6f8,0x443216f9,0x656940b3,0x386056fa}},	//   _сс_, _fey_, _ćeho, ffir_,
   {{0x27e90340,0x67208043,0x68e296fb,0x672d16fc}},	//   _tyan_, _otmj, jood, _twaj,
   {{0xa9238039,0x3d1102ea,0x443f8010,0x7bc056fd}},	// [10b0] ąžin, _दूरे_, _rdu_, _žmur,
   {{0x59b08314,0x6f0701c0,0x386dd6fe,0x6d48d6ff}},	//   जनार, _débì, zeer_, orda,
   {{0x3ce6c013,0x44321700,0x15a845f5,0x35f51701}},	//   _okov_, _yey_, нъци_, _шпор,
   {{0x2ea986fc,0xcd9600c3,0x61eac053,0x7afe4177}},	//   कस्त, _סדרת_, _myfl, ampt,
   {{0xa03640c3,0xc88640cb,0x7f4d443e,0x09c980e9}},	//   _בארה_, ößen_, quaq, िप्य,
   {{0x2a7c80b3,0xf09f400c,0x21699702,0xd6e24036}},	//   gdvb_, _hoà_, дики_, _całą_,
   {{0x08d5c376,0x823485a7,0xfa7800c3,0x78a9c007}},	//   кция, ارها, געות_, tkev,
   {{0x68e281c8,0x611188c7,0x7d0980b1,0x00000000}},	//   cood, _jāli, _uies, --,
   {{0x6d48d703,0x2369024c,0x78a9d704,0x248d8019}},	//   erda, _npaj_, rkev, _inem_,
   {{0x25e64028,0x78a9d705,0x7ec6c1cb,0x59df82ea}},	//   _जुडी_, skev, _répè, _पुअर,
   {{0x6d48c0b3,0x6b840b0e,0x236901c0,0x63210079}},	//   grda, _srig, _apaj_, _বিষয়_,
   {{0x2b495706,0xe73a1707,0x249f8053,0x25a5d708}},	//   krac_, мем_, _joum_, ryll_,
   {{0x26c5d709,0x68ed570a,0xcc3a8009,0x6d5c170b}},	//   pilo_, dlad, וערט, wtra,
   {{0x2b49570c,0x6d4e170d,0xbb42c748,0xfaa2d70e}},	//   drac_, tuba, _тешк, _вашо,
   {{0x09e6170f,0xceb2c2a6,0xc7b9c05f,0x290b5710}},	//   товн, _דיג_, lző_, _bica_,
   {{0xf74a01b4,0x6d5c1711,0x7cf60107,0x7a3f006a}},	//   _قلبي_, rtra, sárb, _açtı,
   {{0x6d435712,0x6b841713,0x96ba4032,0x38605714}},	// [10c0] ánan, _urig, وائز_, rfir_,
   {{0x96fa01b4,0x26c79715,0xd0f4408f,0xe610403a}},	//   _تعبر_, jino_, _आठवण_, _düşə,
   {{0x98c609af,0x68e29716,0xe45a82b1,0xda654032}},	//   _लगाए, tood, дже_, طالي,
   {{0xd308c0d1,0x290b5717,0xa8034526,0x8c46806f}},	//   _hệt_, _gica_, ğırs, теде,
   {{0xd34841aa,0x7e7a8340,0xc326002a,0x249f80b6}},	//   _سیاه_, _patp, _বিডি_, _doum_,
   {{0x290b5718,0x2d858011,0x2ab081c0,0x68e29719}},	//   _zica_, _brle_, _bàba_, sood,
   {{0xd308c00c,0x7c29ccb8,0x60c4025d,0xd5af8182}},	//   _mệt_, fber, _omim, يفه_,
   {{0x2918c43d,0x38b5571a,0xb87b0107,0x5c74cc21}},	//   íram_, _gård_, nlít, улит,
   {{0xa067c6b1,0x7ae3971b,0x3a380c4b,0xe29f4397}},	//   тања_, bont, karp_, _guðs_,
   {{0x200fd71c,0x41db0036,0x7c2d8086,0xe814c5da}},	//   _eggi_, _मुझस, ðarv, _डलवा_,
   {{0xa3e7c045,0x3a3740c3,0x6e3884c9,0x6da180e2}},	//   _मुठ_, כרים_, mavb, rɓac,
   {{0x60c400fd,0x60c2c6df,0x6ca70708,0x69da81a8}},	//   _cmim, _umom, трож, _ixte,
   {{0x6d5e571d,0x2d9e171e,0x68e4529a,0x6d48c011}},	//   htpa, äten_, doid, srda,
   {{0x7ac70b54,0x3866c123,0x2d854077,0x2913001f}},	//   тсме, _hbor_, _šlem_, _puxa_,
   {{0x68ed571f,0x3f86c089,0x2d8509a8,0x1ea9c032}},	//   tlad, _hrou_, íle_, _ثاني_,
   {{0xf0471720,0x5597c4e0,0x60d6013b,0x28c49721}},	//   _рэко, _ידוע_, _gjym, लोमि,
   {{0x7ae39677,0x290b5722,0x3866c303,0x59d55723}},	// [10d0] yont, _vica_, _mbor_, _दशहर,
   {{0x3a381724,0x71791725,0x7e7c5726,0xd51a40d1}},	//   carp_, _збор_, _carp, _bằn,
   {{0x38b1c55d,0xceb3c009,0x25a504d3,0x78a09727}},	//   _lára_, סיע_, älld_, _bomv,
   {{0x7ae39728,0xac199729,0x30a780c5,0x628e41a8}},	//   wont, ходу_, ързв, _enbo,
   {{0x38b544d3,0xe50409af,0x7e7c45ef,0x64db8314}},	//   _vård_, रगति_, _farp, यकौश,
   {{0xeb908a1d,0x63a00211,0xe1f98911,0x130880d9}},	//   تظم_, ømni, нгл_, вній_,
   {{0x3f86c018,0x7eadd72a,0xdd9440d7,0x6594572b}},	//   _arou_, _dúpl, _кары, _кару,
   {{0x78ad572c,0x3f86d72d,0x48d1c079,0x22498165}},	//   nkav, _brou_, াত্র, şak_,
   {{0xdce5403f,0xb87b402e,0x2d9a80d9,0x7cf60107}},	//   _arhī, _akík, øper_, jára,
   {{0x7cf60018,0x81e2802a,0x38b1c083,0x68fb80bb}},	//   dára, নেই_, _dára_, _hhud,
   {{0x3a380086,0x200fc05c,0x68fb81c8,0x7d0bc006}},	//   varp_, _tggi_, _khud, _tigs,
   {{0x78ad438f,0x6e35572e,0x6722c13b,0xa3ca8036}},	//   jkav, _lezb, _ftoj, _ऊधम_,
   {{0x3f86c820,0x6aa1972f,0x68fb82c0,0x68e45730}},	//   _grou_, _kolf, _mhud, void,
   {{0x6e355731,0x63a9d732,0x7eb480d2,0x80c147a9}},	//   _nezb, myen, _tàpe, रोसे,
   {{0xdb06005f,0x7643c033,0x6d5e5733,0x68e45734}},	//   nyké, _idny, xtpa, toid,
   {{0x60c9d735,0x261800b2,0xb4ae4045,0x039605f5}},	//   niem, बुजी_, कसे_, _броя,
   {{0x7e7c5736,0x38cb41aa,0x387dc0de,0x64440057}},	// [10e0] _parp, رافی_, _mawr_, _idii,
   {{0x63bbd737,0x68e45738,0x68fb9739,0x6724173a}},	//   izun, soid, _ahud, _itij,
   {{0x7e7c573b,0x7c360086,0x67240451,0x27ed80ce}},	//   _varp, _keyr, _htij, _ayen_,
   {{0x7e7e173c,0x27ed973d,0xbf0f8064,0x26ca173e}},	//   _happ, _byen_, ादून_, libo_,
   {{0x04438495,0x7c36173f,0x8c438640,0x9b94819b}},	//   сечн, _meyr, сече, рилц,
   {{0xdee38698,0x248040b5,0x23604022,0x61058007}},	//   бочи, ldim_, mtij_, _mėly,
   {{0x6aa19740,0x35a34119,0xb42683be,0x6b829741}},	//   _dolf, _ларг, _معذو, svog,
   {{0x44200171,0xa3dd0028,0xacea81b4,0x60c9d742}},	//   _nfi_, _तुझ_, _أرسل_, giem,
   {{0x24804032,0x7d028b57,0x04578032,0xa3e7c2ea}},	//   idim_, mmos, _حلقة_, _मुद_,
   {{0x64441743,0x7cf61744,0x7643c033,0x3ce68022}},	//   _adii, vára, _cdny, loov_,
   {{0x7d0d1745,0x24804cb1,0xc61081f9,0x7cfd0cc6}},	//   _pias, kdim_, ाशीय_, nérg,
   {{0x6aa180c4,0x7c361746,0x6f160b87,0x37d9002a}},	//   _zolf, _ceyr, _buyc, _সরবর,
   {{0xdb045744,0x9a86c59d,0xc387802e,0x644401ae}},	//   nzió, _буйл, _bẹ́ẹ, _ddii,
   {{0x5693d408,0x6444040d,0xaca380d1,0xdb2405ca}},	//   _гашт, _edii, _kiển, ásáb,
   {{0x4420002c,0x2d854016,0x31351747,0x67240085}},	//   _ffi_, _àlex_, ребр, _etij,
   {{0x6d435748,0x30a4401d,0xd46806b1,0x44200b87}},	//   ánam, брув, _биће_, _gfi_,
   {{0x9259401b,0x7afc405e,0xa01b44c9,0x38691749}},	// [10f0] каат_, _bhrt, _snös, _ibar_,
   {{0x68e9974a,0x09d7c079,0x78a2c09d,0x60c9d74b}},	//   _sked, _হরতা, _loov, ziem,
   {{0xef1f40fa,0xd0115438,0x78ad4017,0xa49b40d2}},	//   _grün_, _ولد_, pkav, _biòt,
   {{0x7c360080,0x60c9c1cb,0x78a2c17b,0x6e3ac127}},	//   _xeyr, xiem, _noov, hatb,
   {{0x6aa18147,0x7988974c,0x6e3ac3ad,0x7cfd01ff}},	//   _polf, _ardw, katb, pérf,
   {{0x6aaec045,0xe463c50c,0x8937416a,0x63bbc561}},	//   टसोर, şmüş, _معرا, vzun,
   {{0x7c2d8086,0x7cf60066,0x9ed84244,0xf2d240c3}},	//   ðars, dárn, _смрт_, _ועם_,
   {{0x58d5811b,0x3f89002c,0xe188868b,0xdb0a002d}},	//   _тобт, _orau_, ائون_, ľném,
   {{0x229582cf,0x7524c6f0,0x6eefc211,0xc87f40cb}},	//   _پلاس, _čiza, løbi, _maß_,
   {{0x7c2d513e,0x88bd0185,0x387f8232,0x44200ccb}},	//   hbar, spěl, _haur_, _sfi_,
   {{0xbd4b81b4,0xe8fa15a4,0x3f8900fc,0x443b40fd}},	//   _سؤال_, кло_, _arau_, kaq_,
   {{0x7c2d4064,0xb4c14285,0x443b405c,0xf8b58374}},	//   jbar, ्चो_, jaq_, ंसिय,
   {{0xb8de03b0,0x29020054,0x443b46b9,0x7cd20017}},	//   _इत_, rmka_, daq_, nāri,
   {{0x644b45e7,0x6eefc0b0,0x2360423b,0x2327043e}},	//   ógin, købi, vtij_, рори_,
   {{0xddc70c9c,0x7c2d574d,0xba74c49f,0x443b574e}},	//   tejš, fbar, _دانت, faq_,
   {{0x1426574f,0xb4d04048,0x26ca1750,0xb4e040aa}},	//   рдам, वचे_, sibo_, दके_,
   {{0x7e7e1751,0xddc712b8,0x7a405752,0x2c01408f}},	// [1100] _tapp, rejš, játí, लेलं_,
   {{0x6aa3d753,0xaa4645bd,0xddc89754,0xf4879755}},	//   _jonf, режл, _radž, یانی,
   {{0x23605756,0x2d85098b,0x7d0f42d4,0xddc88570}},	//   stij_, ålet_, _fics, _sadž,
   {{0x9c144094,0x1b1d8079,0x7cf60018,0xef868640}},	//   _kọmp, _নিজে_, iáro, илеп,
   {{0x387f89ee,0x44225757,0x5f0690a1,0xdddc005f}},	//   _daur_, _ifk_, азда, merő,
   {{0x7d029758,0x6b899759,0x442dd75a,0x6e3c175b}},	//   smos, _dreg, ebe_, narb,
   {{0x9d434119,0xe5a640b4,0x8c9680d7,0x7cfd0fa3}},	//   _мерд, _тиви, _краі, lére,
   {{0x3cfdc046,0x78a4175c,0xa3e7ca3c,0x6e3c175d}},	//   _chwv_, _noiv, _मुह_, harb,
   {{0x649cc018,0x4420575e,0x7cfd175f,0xdddac107}},	//   _méix, ici_, nére, vető,
   {{0x442dc0bc,0xfaa6d702,0xf992816a,0x78b60007}},	//   abe_, ршин, _وبا_, _alyv,
   {{0x44225760,0x7b0940b3,0x6e3ad761,0x021744e0}},	//   _ofk_, _džuh, ratb, יחים_,
   {{0x2b40411f,0x6281d762,0x649cc6ed,0x26ef0c4b}},	//   ksic_, adlo, _néix, छत्र_,
   {{0x44205763,0x78a40669,0x274b00c5,0x6e3c1764}},	//   dci_, _doiv, ъчно_, farb,
   {{0x3f89013b,0x78b60024,0x7c2d4206,0x387f0013}},	//   _vrau_, _elyv, wbar, žur_,
   {{0x443b4080,0xd6d80186,0x7cf6003c,0x4a31c166}},	//   taq_, ртя_, cáro, äčší_,
   {{0xdddc0107,0xc0350217,0x6eed8359,0x6113c0cc}},	//   gerő, _униј, lúbt, _călu,
   {{0x29185765,0x2fcf04d3,0x649cc03c,0x5c0741bc}},	// [1110] _aura_, _ägg_, _déix, рява,
   {{0x44205766,0x9f66400c,0x443b5767,0x7cf88047}},	//   aci_, _đuôi_, saq_, víra,
   {{0x443b51a5,0x442dd768,0x3a384e15,0x7afdca26}},	//   paq_, ybe_, _derp_, ïsti,
   {{0x26ccc018,0x2723c02d,0x7cfd00dd,0x6205c080}},	//   hido_, nčný_, bére, ürlə,
   {{0x7bd843a6,0x7cf19539,0x4abb0021,0x2d8a5769}},	//   şvur, nåri, _उताव, _erbe_,
   {{0x63ad576a,0x7d07c05f,0x9e3c8166,0x1fd9002a}},	//   myan, _éjsz, _poďa, _সরাস,
   {{0x27fa8064,0x3cfdc022,0x6a2240fb,0x6aa3d76b}},	//   ępna_, _phwv_, _رہنم, _ronf,
   {{0x7cf6005f,0x2b4dd76c,0x3a384011,0x9dd800c3}},	//   váro, trec_, _zerp_, יווק_,
   {{0x7c3bd76d,0xdcb1c00c,0x2918576e,0x6aa3c2b0}},	//   raur, _của_, _zura_, _ponf,
   {{0x26ccd635,0x6729d76f,0x2918407a,0x7c22c119}},	//   gido_, rpej, _yura_, _efor,
   {{0x7d045770,0xea00000c,0x3cfdc022,0x20d20166}},	//   ymis, _khấu_, _thwv_, hšie_,
   {{0xe50a0015,0x442f806f,0x24800022,0xc0c8d771}},	//   _cặp_, nbg_, _qaim_, _куче_,
   {{0x60c98094,0x63ad491f,0x6aa3d772,0x3ea580b3}},	//   _mmem, jyan, _tonf, _kolt_,
   {{0x62819773,0x6abad774,0x64464033,0xed59c007}},	//   _jalo, chtf, _sdki, _бок_,
   {{0x44205775,0xa0a60c9d,0x6d551776,0x6d4e1777}},	//   tci_, _гайд, guza, urba,
   {{0x60cd5778,0x672dc1b7,0x6e3c1779,0xb920802e}},	//   giam, _ħajj, sarb, _aarọ_,
   {{0x63ad577a,0x29184ba3,0x6a164a10,0x6b9bcad6}},	// [1120] gyan, _sura_, مبار, nxug,
   {{0x60db8031,0xee375626,0x60c9977b,0x4422177c}},	//   _ajum, йну_, _amem, lck_,
   {{0x5d8601b4,0xdb060096,0x4d4a540f,0xaca3c02e}},	//   _الجل, szkó, упен_, _amọj,
   {{0x2912177d,0x7d1b406c,0xb87b4031,0x63ad577e}},	//   _jiya_, _čust, _ajíf, byan,
   {{0x2912177f,0x99938013,0x291a1780,0xdd8f02f0}},	//   _miya_, _češe_, _hupa_, _قوی_,
   {{0x44395781,0xdee3858f,0x60db817b,0x6da500e2}},	//   _zes_, почи, _ejum, iɗan,
   {{0x44395782,0x918681b4,0xaadd408f,0xae07485a}},	//   _yes_, إجتم, _मदतक, वेदन_,
   {{0x60db80fd,0xd00a81a0,0x6cd6849f,0x7cf60019}},	//   _gjum, _бебе_, _اقرا, fárm,
   {{0xf09f4015,0x7c3d0119,0x2fc05783,0x1b1e002a}},	//   _giàu_, vasr, nzig_, বীতে_,
   {{0x29121784,0x291a02a4,0xbda6c280,0x7c39c085}},	//   _aiya_, _oupa_, محجو, _eewr,
   {{0x7eadc004,0x2d8ad785,0x63ad5786,0x98a74077}},	//   _xúpi, íbe_, zyan, _žiča_,
   {{0x6d4341b4,0x2ca041d1,0x6b9bc018,0x7c39d787}},	//   ánai, jjid_, bxug, _gewr,
   {{0x62819788,0x7c3d021b,0x6111c03f,0x2fc0415d}},	//   _yalo, rasr, _tālr, jzig_,
   {{0x9985c007,0x60cd4036,0x7cf18588,0x3d11417e}},	//   galų_, wiam, råri, _दूजे_,
   {{0x2ca6d789,0xa49b4060,0x6a13c3be,0x4424978a}},	//   _kood_, _biòp, _عبور, _ofm_,
   {{0x7cd3c119,0x26ce978b,0x8cf5493d,0x6ca4426f}},	//   tări, hifo_, ізац, пруж,
   {{0x4034404c,0x6fb8c027,0xddd446f0,0x7cfd0019}},	// [1130] яетс, इनिं, _čaša, pérb,
   {{0x6b8d178c,0x7cd3c119,0xb87b4031,0x7055049b}},	//   _irag, rări, _akít, _انکا,
   {{0x257ac03f,0x6281978d,0x09ad8079,0x7cd3c0b4}},	//   _jūl_, _ralo, _কেনা, sări,
   {{0x2ca6d78e,0x7cd3c0b4,0x63ad578f,0xa49b4061}},	//   _nood_, pări, pyan, _dhòc,
   {{0x291a1790,0xfaa59791,0xb87b4031,0xfd10838b}},	//   _zupa_, жало, _ajíg, رجم_,
   {{0x7cf89792,0x2d87426c,0x79824036,0xf77080b8}},	//   bíro, ånes_, łowa, عان_,
   {{0x7cf89793,0xea0000d1,0x6d41c51f,0x62839794}},	//   círo, _thấu_, xsla, rdno,
   {{0x60c9939a,0x7d1a9795,0x2fdf8046,0x2d87910f}},	//   _umem, _duts, _txug_, rvne_,
   {{0xdbf20185,0x68e9c1f4,0x78bbd478,0x386d80d2}},	//   _přír, roed, rhuv, _iber_,
   {{0x78bbd796,0x672d5797,0x68eb9798,0x68e9d799}},	//   shuv, ipaj, logd, soed,
   {{0x2169cd32,0x2ca6c093,0x2912179a,0xa2af0185}},	//   шини_, _food_, _piya_, ुसन्,
   {{0xa3e941ac,0xd00a05af,0x443b005e,0x3a3a179b}},	//   यथा_, иене_, _ceq_, _sepp_,
   {{0x291a179c,0x78a64077,0x38694032,0x6d450854}},	//   _supa_, _rokv, dfar_, _avha,
   {{0x99834085,0xf8b58036,0xdcb140d1,0x6285579d}},	//   _bejż_, ंसुप, ển_, jdho,
   {{0x6449810b,0x29120537,0x7cf60c1e,0x7cf88004}},	//   _odei, _tiya_, nárk, xíro,
   {{0x3ea7c053,0x6e3e4033,0xfc3f0032,0x64498032}},	//   _hont_, wapb, caí_, _ndei,
   {{0x6729979e,0x7ce5c004,0xeab2405f,0x06ca4b18}},	// [1140] _ntej, fórz, وٹر_, агай_,
   {{0x7cf89792,0x7cf6002d,0x7c228127,0xb87b4086}},	//   tíro, kárk, wcor, _skít,
   {{0xb05b04d3,0x6d41005f,0x7cfd001e,0x291a0033}},	//   miär, álat, léra, _uupa_,
   {{0x6283d79f,0x3f8d8016,0x62954c87,0xd7248031}},	//   _lano, _breu_, _enzo, _aṣọg,
   {{0x2ca6c1d4,0x443257a0,0xf4878646,0xdb0ec066}},	//   _rood_, mby_, تالی, ždém,
   {{0x7f4291a5,0x765c014b,0x26ca412c,0x3a258053}},	//   rsoq, ngry, _umbo_, _cflp_,
   {{0x01634b65,0x6d4397a1,0xe1e7c4a4,0x2ca6c09d}},	//   _окро, gsna, _آس_, _pood_,
   {{0x7c3b97a2,0x2005003a,0x6449806f,0x26ce800b}},	//   _geur, əlif_, _gdei, sifo_,
   {{0xd7fac363,0x3ea7d7a3,0x7c244011,0x7c290018}},	//   шук_, _bont_, icir, ñerm,
   {{0x6e3c4123,0x395817a4,0x7c3b97a5,0x7aea80fd}},	//   _jerb, kurs_, _zeur, qoft,
   {{0xdd90cec0,0x6b8d17a6,0xac19011b,0x317e821b}},	//   روح_, _srag, йону_, _ustz_,
   {{0x7e7740d1,0x395817a7,0xe5714052,0x2e0ec080}},	//   zexp, durs_, ײַט_, rəf_,
   {{0x6283d7a8,0x2366813b,0xfbc50b23,0xd7fb17a9}},	//   _fano, ntoj_, _लेखम, рун_,
   {{0x248497aa,0x672d4022,0xa3c200aa,0x7c2657ab}},	//   _lamm_, vpaj, ्पज_, _afkr,
   {{0xcd33c032,0x395817ac,0x2720c0d1,0x7d1c57ad}},	//   _قريب, gurs_, _hòn_, _nurs,
   {{0x4c944051,0x20d3c0b4,0x7cf88018,0x6ab78891}},	//   мисс, pţie_, fírm, _अत्र,
   {{0x2366813b,0x4adb8045,0x200f40b2,0x2720c141}},	// [1150] jtoj_, _बदलव, ägi_, _jòn_,
   {{0x672d57ae,0xe8014064,0xda78c166,0x443fd7af}},	//   rpaj, लेगा_, neď_, zau_,
   {{0x61404b01,0x4426c171,0x20d20166,0x628557b0}},	//   _rálá, _ofo_, lšia_, rdho,
   {{0xa8794009,0x317a0009,0x7e7757b1,0x628517b2}},	//   _פאָר, _פארד, sexp, _haho,
   {{0x248497b3,0x290957b4,0x241880d9,0x60cd040d}},	//   _damm_, mmaa_, цією_, _mmam,
   {{0xcf580093,0x3d168045,0x6440c070,0x6d574004}},	//   קבות_, _पंखे_, eami, puxa,
   {{0x69158085,0x201e40b4,0x99878007,0x24848053}},	//   _aġer, _ştii_, vanų_, _famm_,
   {{0x237f804d,0x2720c141,0x7d02d7b5,0x6b89d7b6}},	//   _tsuj_, _bòn_, _chos, tveg,
   {{0x6f1d57b7,0x20d20166,0x26d117b8,0x2d8ec0e2}},	//   _jusc, jšia_, kizo_, _arfe_,
   {{0x44324574,0x6726c5e7,0x4426d7b9,0x6f1d57ba}},	//   zby_, íkja, _efo_, _musc,
   {{0x6440d7bb,0xe8e0000c,0x6b89d7bc,0x26d117bd}},	//   bami, _ngợi_, sveg, dizo_,
   {{0x6285002f,0x6d4557be,0x2a7800fa,0x01fa80c3}},	//   _aaho, isha, werb_, _הפעל,
   {{0x2d8117bf,0x7c2457c0,0xa295c11b,0x78bb8185}},	//   _ashe_, vcir, _наді, _mluv,
   {{0x752940ab,0x80b9802a,0x1e84c0d9,0x2bef409d}},	//   _čezn, েকট্, _олім, _आड़ू_,
   {{0x78bb831c,0x7c3d4199,0x7cf18854,0x2a3ac21d}},	//   _oluv, _besr, nårs, _העצמ,
   {{0xb87b57c1,0x64a34f37,0xc879c06a,0x629703bb}},	//   _ajíb, наса, neş_, _enxo,
   {{0xef1757c2,0xd0074640,0x248681be,0x395817c3}},	// [1160] зму_, зете_, vdom_, surs_,
   {{0x443dd7c4,0x26d117c5,0x7d09d7c6,0xd6c405d3}},	//   _lew_, cizo_, hmes, _آمدی,
   {{0x6aa897c7,0x7d0417c8,0x24848033,0x22650066}},	//   _rodf, _khis, _pamm_, žský_,
   {{0xa50797c9,0x7eab009d,0x68ed4019,0xfce647e3}},	//   пеха_, _hüpp, coad, _хомо,
   {{0xfe70405f,0x24848053,0x6f1d40c4,0x33f68032}},	//   _لگا_, _vamm_, _gusc, أساس,
   {{0x48f64185,0xdfcf8182,0x6d4541c8,0x6440d7ca}},	//   ्षको_, ديه_, bsha, wami,
   {{0x7c3b010d,0x69dc97cb,0x248480b2,0xfaff00fd}},	//   ðurk, _žreb, _tamm_, ktën_,
   {{0x5f94cf7f,0xc879c0b4,0xc1730323,0xa0678b69}},	//   диит, geş_, גחה_, _наса_,
   {{0xb763c59d,0x68e3830d,0x7aee17cc,0x80c1442f}},	//   нтэй, énde, kobt, रोटे,
   {{0x35b4c7ea,0x644286d3,0x68ed4004,0x7d02c0c3}},	//   дбор, laoi, zoad, _whos,
   {{0xf8bf0e5d,0x7d09d7cd,0xc879d7ce,0x200000c7}},	//   thé_, bmes, beş_, _azii_,
   {{0x2eb9417e,0xbec34017,0xdfd50039,0x69c140b2}},	//   _इत्त, _ķīmi, домы, _ülee,
   {{0x291e97cf,0x3f8fc0b3,0x7641d7d0,0x645d17d1}},	//   _huta_, _grgu_, baly, rgsi,
   {{0x7d0417d2,0x20d217d3,0x88bcc0a0,0xe8030062}},	//   _ehis, ršia_, _stěh, रेगा_,
   {{0x628517d4,0x7cd3c0b4,0x65940ce8,0x29048011}},	//   _vaho, părt, нару, _ohma_,
   {{0x628517d5,0xfdf7c2a6,0x7d0417d6,0x5577c009}},	//   _waho, _מצות_, _ghis, _זעהן_,
   {{0x290957d7,0x6d4557d8,0x64428311,0xb87b17d9}},	// [1170] rmaa_, wsha, daoi, eníg,
   {{0x6288d7da,0x2d81023b,0x60c0c0f8,0x7cf880a0}},	//   nddo, _tshe_, hhmm, bírk,
   {{0xf5794183,0x60dd17db,0xe1394176,0x2bd2839a}},	//   تماع_, onsm, ізді_, _देबा,
   {{0x6e2540cb,0x2904805e,0x6d4557dc,0x3157c052}},	//   schb, _chma_, rsha, ליבן_,
   {{0x6b82cefc,0xfaf8c017,0x2bc84d0d,0x4e94801c}},	//   _nsog, klī_, _еуро_, کشنر,
   {{0x7cf19551,0xe29697dd,0xdb060107,0x6d5517de}},	//   tårs, даш_, szkö, orza,
   {{0x644d0061,0x6f170070,0x7d09d7df,0x0d84410e}},	//   _odai, _mixc, tmes, _плён,
   {{0x7cf1836b,0xa3e60275,0x442917e0,0x64429335}},	//   rårs, _बुझ_, _nfa_, caoi,
   {{0x27ff89d7,0x6aaad7e1,0x60dbd7e2,0x628757e3}},	//   _uzun_, _boff, rnum, _kajo,
   {{0xfc3f57e4,0xe9d9d7e5,0x6d5ad7e6,0x7d16009c}},	//   _leí_, жко_, futa, _siys,
   {{0xdddc52ae,0x291e97e7,0x6d550036,0x1d0a0dfc}},	//   _karš, _guta_, jrza, жени_,
   {{0x644bc9ca,0x2b52c676,0x8d74878a,0x7641d7e8}},	//   _udgi, üncü_, _ساما, saly,
   {{0x672bc11b,0x38b8c01e,0xfaff00fd,0x7cfd0019}},	//   _utgj, _zéro_, rtën_, pérn,
   {{0x443f97e9,0x291e97ea,0xfaff00fd,0x386dd7eb}},	//   _leu_, _yuta_, stën_, lfer_,
   {{0x7769cfd0,0xe45f17ec,0x6d55c107,0x8c3d8138}},	//   ltex, giös_, ázad, _coşk,
   {{0x7c2d846a,0xdddc4039,0xc5f2c0c3,0x26d34018}},	//   ñarl, _narš, _שדה_, eixo_,
   {{0xd5b8003f,0x4de64036,0x2d854077,0xbebb00fd}},	// [1180] šā_, _जुड़े_, _šlep_, rpër,
   {{0xb605c007,0x442902c0,0x7cf8817c,0x3ce0c199}},	//   _tušč, _zfa_, pírk, čivi_,
   {{0xf1c38007,0xb05b4041,0x64490086,0xe29b00c3}},	//   nešė_, _bläd, ðeig, _ושיר,
   {{0x44290070,0x395a57ed,0x69da01cb,0x258700a0}},	//   _xfa_, rups_, ûteu, sílá_,
   {{0xe3b24865,0x4e220260,0x2eee97ee,0x91ce4185}},	//   _شرح_, _मलाई_, toff_, _धेरै,
   {{0x7769c396,0x7bc6006c,0x6d5ad7ef,0x386dd7f0}},	//   dtex, izku, yuta, efer_,
   {{0x386dcab5,0x7c248070,0xe2a70086,0xdc300026}},	//   ffer_, ñirs, æðir_, _užėm,
   {{0xb05b44d3,0x6d5ac54a,0x98bf003f,0xdddc403f}},	//   _gläd, vuta, kstā_, _garš,
   {{0x3f14c895,0xc7c6c051,0x61ed850c,0x6aaad7f1}},	//   ндис, ьски, ğala, _poff,
   {{0x7eadc166,0xeb914009,0x443f97f2,0x998cc2bc}},	//   _súpr, אָט_, _zeu_, radž_,
   {{0x2bd2855f,0x32574093,0x20d211ae,0x867b44e0}},	//   _देता, וסים_, ršin_, חריו,
   {{0x20d3c0b4,0x7cfec0fd,0x60c287b0,0x7cf88359}},	//   pţia_, mëro, nhom, fíri,
   {{0x63a28060,0x20d20077,0xdfa6c032,0x2d9acb1b}},	//   nxon, pšin_, _تحضي, _šped_,
   {{0x63a2975c,0x20d3c0b4,0x7cfd17f3,0x6d4717f4}},	//   ixon, nţin_, péro, tsja,
   {{0x48ab4039,0x6127806a,0xf1a2c045,0x9f99014d}},	//   отам_, _kıla, _ओपिन, _dáár_,
   {{0x442917f5,0x6d48c4f5,0x38604086,0xaca380d1}},	//   _ufa_, msda, ggir_, _thỉn,
   {{0x6d4717f6,0x60c2817a,0x3d16c2f6,0x3f85003f}},	// [1190] ssja, dhom, _पूछे_, ālus_,
   {{0x32c0c031,0x7cfd0107,0x78ad17f7,0xf388c35d}},	//   _fòye_, zérl, _hoav, _mợ_,
   {{0x628a80de,0x7c2980fa,0x248905d1,0x54558911}},	//   ddfo, _pfer, _kaam_, евет,
   {{0x6fd04048,0x66c04041,0x628757f8,0xfc309546}},	//   _ठेवू, _röke, _wajo, لحه_,
   {{0x2258078a,0x248917f9,0x291945bb,0xe299940c}},	//   _عجیب_, _maam_, _iisa_, зал_,
   {{0x68e2c02e,0x7cfd07c9,0x629a8303,0x644081c0}},	//   _ajod, dérm, _cnto, _eemi,
   {{0x6d4ed7fa,0xdddc4026,0x7c2980f6,0x6d48c2a0}},	//   ábal, _tarš, _tfer, jsda,
   {{0x6915c05b,0x764544a7,0x7769d7fb,0xd788c00c}},	//   _všeo, lahy, ttex, _bể_,
   {{0x2d98d7fc,0x6d4ac383,0xfe75801b,0x76758173}},	//   åren_, _avfa, _плаќ, _плаф,
   {{0x628897fd,0xfaa78026,0xb4bc4045,0x2cad97fe}},	//   _gado, _ўшан, _अत्_, _hoed_,
   {{0x6f18d7ff,0x7d0d406a,0x7f5bc1c8,0xa2b25158}},	//   _divc, kmas, suuq, _आकस्,
   {{0x2ec810de,0x18a61229,0x3cfb4036,0x7769c303}},	//   रफ्त, хамм, ्षों_, ptex,
   {{0xeb99c0c5,0x76418007,0x7eb48016,0xa49b45ef}},	//   _хил_, _kely, _sàpi, _chòm,
   {{0x7c29d6d7,0x8bd6c0c3,0x44295800,0x98bf0017}},	//   lcer, _אונו_, eca_, rstā_,
   {{0x91e3019b,0x11d5011b,0xf8bf41cb,0x7c364c9f}},	//   горе, вітр, _blé_, tbyr,
   {{0x6b8406df,0x8fa6459d,0xadd6c2a6,0x76419801}},	//   _tsig, набе, _רוקח_, _lely,
   {{0x64409802,0x6b841803,0x798503f3,0x7f49d804}},	// [11a0] _remi, _usig, _eshw, nseq,
   {{0x611c0053,0x38b1c107,0x7c290018,0x7d0d5805}},	//   _bčlt, _zárt_, ñerv, amas,
   {{0x44294166,0x6d5c1806,0x24890046,0xd00f405f}},	//   bca_, qura, _yaam_, للہ_,
   {{0x2cad802c,0x53a65807,0x5c068660,0x44f681aa}},	//   _coed_, _замб, няла, رساز,
   {{0x2b4940cc,0x2cad82cd,0xf09f4104,0xfbd28231}},	//   csac_, _doed_, _khàn_, دتا_,
   {{0x29195808,0x60c45809,0xd788c0d1,0x09bf402a}},	//   _zisa_, lhim, _rể_, _আশরা,
   {{0x7cf6180a,0x69d80007,0xceb300c3,0x2d9e4011}},	//   nárs, _žvej, ריו_, _štef_,
   {{0x6f18c077,0x7d03911b,0xceb8c036,0x97a6c42e}},	//   _sivc, ïnst, wkę_, ерол,
   {{0x6288980b,0x248901ea,0x6f18c3aa,0xceb8c036}},	//   _tado, _raam_, _pivc, tkę_,
   {{0x8c3d8119,0xa49b0016,0x7cf60166,0x6b82980c}},	//   _roşi, ològ, kárs, mwog,
   {{0x6eb4c036,0xceb8c9ae,0x49ba805f,0x7d0d580d}},	//   ेसबु, rkę_, _عائد_, ymas,
   {{0xdd1201df,0x6d48d80e,0x6446180f,0x7e7e5810}},	//   rüşl, rsda, gaki, hepp,
   {{0x2726000c,0x629c40a8,0xe0df023f,0xf09f429a}},	//   _côn_, _onro, rnò_, _bhàn_,
   {{0x6442c755,0x245ac138,0x2726032a,0xe3e2802a}},	//   _heoi, bümü_, _dôn_, _বরাব,
   {{0xddc8d811,0x6d5e4521,0xf09f4321,0x98b3404f}},	//   ledž, jupa, _dhàn_, žeče_,
   {{0xd5fbc4e0,0x64461812,0x68e94011,0xc4c48107}},	//   _מפור, caki, čedo, _طے_,
   {{0x6d589813,0x48155575,0x09d5c079,0xddde0011}},	// [11b0] hrva, тмас, _সুপা, _vapš,
   {{0x65954bf8,0x3f9bc03c,0xaca3800c,0x7cf60166}},	//   казу, _áque_, _thịn, bárs,
   {{0xa2b24191,0x20049814,0x44295815,0x2d930004}},	//   _आकर्, _azmi_, pca_, _urxe_,
   {{0x6d5880b3,0x254c8047,0x48cf8079,0x6d4a95db}},	//   drva, děl_, িক্র, dsfa,
   {{0x7c2d1816,0x6fd0d337,0x245ac91a,0x6f1a9817}},	//   _mfar, _तेलं, zümü_, _bitc,
   {{0xf77403bd,0x628ad818,0xb4be08b8,0x2ca9409d}},	//   רקס_, _nafo, _इत्_, ljad_,
   {{0x09d5c02a,0x76418026,0x2245d819,0x7c29d81a}},	//   _সুনা, _vely, valk_, tcer,
   {{0x692380ab,0x3af444c9,0xa99c0323,0x7eb0181b}},	//   _uđem, läpp_, לבור, _läpp,
   {{0xb0c94028,0x290dd81c,0x3f158097,0x628ad81d}},	//   _रतनग, rmea_, _адас, _bafo,
   {{0x7d1b981e,0x60c440fd,0xa695c1e6,0x69358654}},	//   _hius, zhim, триј, _анжу,
   {{0xdcf40944,0xf09f40d1,0x09e5c259,0xb05b0d42}},	//   žača, _nhào_, тонн, rhän,
   {{0xe3b0c78a,0x20d200ab,0xe508c032,0x26c1010b}},	//   _گرم_, pšim_, _كيلو_, _alho_,
   {{0x291b017a,0xa3d04036,0xd10ec1f9,0xb3830026}},	//   _diqa_, _वें_, ागरण_, алял,
   {{0x6d5e581f,0x7cf61820,0x8afdc047,0x290901a8}},	//   yupa, társ, ktři, _ehaa_,
   {{0xf09f4015,0xa06a5821,0x78af4013,0xd9431822}},	//   _chào_, мава_, _bocv, иери,
   {{0x7643d823,0xc95282a6,0x98bf00b4,0x63a45824}},	//   _heny, ימל_, rstă_, txin,
   {{0x7523d825,0xb05b4041,0x166641f6,0x7bc9d826}},	// [11c0] _hunz, _släc, квам, nzeu,
   {{0x7523cfaa,0x7d099827,0xa9261828,0x387fd829}},	//   _kunz, _ahes, _идол, heur_,
   {{0x546a839d,0x387fc7f5,0x224782a4,0x60c4582a}},	//   даем_, keur_, dank_, phim,
   {{0x387fc01e,0x628e182b,0x290f8010,0x248dd82c}},	//   jeur_, ldbo, gmga_, jdem_,
   {{0x387fd82d,0xa2b384fb,0x7e7e582e,0x61ed80b5}},	//   deur_, _अवश्, pepp, şall,
   {{0x254c8047,0x2480582f,0x626381bd,0xc882c03a}},	//   těl_, leim_, авља, mişə_,
   {{0x6df641b4,0x7d1b805c,0x7523ca48,0x44201830}},	//   _شكرا, _fius, _nunz, _ogi_,
   {{0x78a9c4f5,0x6b960064,0x4420008a,0x67240085}},	//   gjev, _oryg, _ngi_, _ouij,
   {{0x6d4a9831,0x6f1a8498,0x8c3d80b4,0x38b1c070}},	//   ssfa, _titc, _coşu, _párr_,
   {{0xcc12c112,0xddc8d832,0x26d81833,0x7523d834}},	//   _fọnị, redž, jiro_, _bunz,
   {{0x387fcb45,0x6f1c5835,0x44200056,0x6444005e}},	//   beur_, _mirc, _bgi_, _beii,
   {{0x387fc01e,0x629e00ce,0x98bf0007,0x6444005e}},	//   ceur_, _anpo, kstą_, _ceii,
   {{0x7643d836,0x7cf60019,0x628ac15a,0x2d87d837}},	//   _feny, gárq, _tafo, _esne_,
   {{0x44201838,0x67240206,0x6b9d8086,0x60c2c0c7}},	//   _egi_, _duij, _ásge, _hlom,
   {{0x7648d839,0x7cfd01cb,0x442b183a,0xa5f8183b}},	//   mady, héri, pcc_, веру_,
   {{0x7648d6d7,0x387241f4,0x48c3402a,0x4420040d}},	//   lady, gfyr_, ্ক্র, _ggi_,
   {{0xb7d903be,0x66c04041,0x2ca9583c,0x7cf6030d}},	// [11d0] _سودا_, _söka, rjad_, párr,
   {{0x539a0093,0x7d09983d,0x387fd83e,0x60c2d83f}},	//   _ניתו, _shes, zeur_, _llom,
   {{0xe70380d1,0x8af04080,0x7d1b9840,0x7af51841}},	//   _nướ, mrəl, _pius, mozt,
   {{0x6f1c5842,0x6d5ac4f5,0xde15c052,0x4420005e}},	//   _eirc, irta, אַנץ_, _xgi_,
   {{0x20c2001f,0x6ec5c314,0x7648c02f,0x752dc123}},	//   _jóia_, िसमु, kady, _čazm,
   {{0x36d55843,0x61ed891a,0xf09f405e,0xc6950052}},	//   _согр, şalm, _mhàm_, ראַ_,
   {{0x7643d844,0x78a9c0fd,0x80ba408f,0x78bbd845}},	//   _reny, tjev, _एकमे, tkuv,
   {{0xc485c0b4,0x7d768032,0x7bc9d846,0x05768032}},	//   улик, امير_, tzeu, امية_,
   {{0x7af5005f,0x7cfd1847,0x8c3d803a,0xec76c039}},	//   kozt, céri, _qoşu, упы_,
   {{0x60c2d848,0xceb4403a,0x7523d849,0x527485d3}},	//   _elom, qqət_, _punz, _نامز,
   {{0x6d5ac06f,0x211f0048,0x7cf88070,0x8c46184a}},	//   grta, _मंगळ_, círs, лене,
   {{0x6b84414b,0xa49b4321,0x20c201ff,0xc795c25b}},	//   ywig, _fhòi, _bóia_, _مشتب,
   {{0xfc470319,0xe918c11b,0x7e9b403f,0x6724184b}},	//   ñías_, _році_, _kāpē, _quij,
   {{0x291dc274,0x6b9602a4,0x7db5c3be,0x290b4053}},	//   _hiwa_, _vryg, _مصبا, _ahca_,
   {{0x291dd84c,0x7ae3984d,0x3f89184e,0x5d79c009}},	//   _kiwa_, innt, _esau_, _טאַק,
   {{0x4420184f,0xa7d6083b,0x26d81850,0x777b8004}},	//   _ugi_, _متخص, siro_, _opux,
   {{0x20d207ca,0x03a345e4,0x2bd9d851,0x78ad0047}},	// [11e0] vših_, бито, _बेमा, žová,
   {{0xdd0442d6,0x7f3b0093,0x442dd852,0x26c7804f}},	//   ırır, _רעיו, hce_, jhno_,
   {{0x68e29853,0x3abac009,0x7cd20017,0x7c2d4e5d}},	//   tnod, עמענ, dārz, bcar,
   {{0x68469854,0x442dd855,0x2bd5408f,0x136a82e2}},	//   унда, jce_, _ठेवा, ешки_,
   {{0x60c40150,0x68e28154,0xa3d3c021,0x6561d856}},	//   _mlim, rnod, _हेल_, hulh,
   {{0x44224f26,0x64465857,0x2b4dc0b3,0x3ce6c065}},	//   _hgk_, _heki, dsec_, _sjov_,
   {{0x3cffc05c,0xf1a7c032,0x68e45858,0x291dcb4e}},	//   fluv_, _اء_, onid, _biwa_,
   {{0x26da44fd,0x442240c9,0x37e8c079,0x6f1e0064}},	//   lipo_, _jgk_, _পরবর, _lipc,
   {{0x6d5c00fa,0x7cfec0fd,0x8af04080,0x7648c340}},	//   hrra, nëri, hrəm, tady,
   {{0x628e5859,0x386681f4,0x6d4e0854,0xb05b0041}},	//   _jabo, lgor_, ksba, rhäm,
   {{0xb9098044,0x61278165,0x2b91002d,0xdef74052}},	//   _nchọ_, _yılm, _môcť_, רמיט_,
   {{0x628e4e6e,0x7c3bc2d6,0x2bef4079,0x291dd85a}},	//   _labo, cbur, চেয়ে_, _giwa_,
   {{0xcc12c112,0x7cfec0fd,0x2d9e0383,0x6d5c126a}},	//   _kọmị, jëri, åten_, erra,
   {{0x6234d85b,0x59d6108d,0x2d8a40fd,0x6594c34a}},	//   _теку, _डेहर, _osbe_, _ваку,
   {{0x05bb005f,0xd12fc523,0x67264127,0x63b98062}},	//   ردست_, _ых_, _aukj, zywn,
   {{0x628e585c,0xd138d286,0x3ced4ee2,0xd7c48048}},	//   _aabo, mpą_, čevo_, वनाच,
   {{0xafdb00b0,0xa01b185d,0xd25b585e,0x4bdb401c}},	// [11f0] dbøg, rdös, еце_, ربرد_,
   {{0x25a504d3,0x7c2d585f,0x7c3bd860,0xaa670e03}},	//   älls_, scar, zbur, _стик,
   {{0x60c40051,0x7c3bd861,0x7c2d5862,0x7bdcc91a}},	//   _ylim, ybur, pcar, ğruy,
   {{0x64465863,0x69c1454a,0x6d5a006f,0xbf0d87f6}},	//   _geki, _ülem, štac, िग्न_,
   {{0xb87b0032,0x628e5864,0xa3d3cfa8,0x7eb240b0}},	//   hnío, _fabo, _हें_, _tæpp,
   {{0xf8bf1865,0x6b89806c,0x055580c5,0xed598698}},	//   hké_, _vseg, атия, вок_,
   {{0x80b9c02a,0x38bb013b,0x20c740b2,0x3eb30085}},	//   ইফস্, _tërh_, _tõid_, _moxt_,
   {{0x52d10e45,0x248d8070,0xb97c0052,0x6281d866}},	//   सफुस, _uaem_, גנהי, welo,
   {{0x7e9b403f,0x20d3c156,0x2019c04c,0xe3b381aa}},	//   _tāpē, nţii_, äsi_, _ارز_,
   {{0x27ff9867,0x681bc03f,0x7f5bd868,0x6561d869}},	//   _iyun_, _rādī, rruq, tulh,
   {{0x60c4186a,0x68e980d9,0x7c3bc0b1,0x38bb00fd}},	//   _plim, _kjed, pbur, _zëri_,
   {{0xcebac6df,0x386b412c,0x27ff888b,0x9abd817b}},	//   _riƙe_, _nccr_, _kyun_, _kuŋo,
   {{0x3ceb0066,0xb4e601c0,0xdcfac007,0x76554036}},	//   _živé_, _alàá, _artė, _odzy,
   {{0xed5a0f15,0x6d4e186b,0x59b54549,0xe737092e}},	//   ког_, tsba, ंहार, рер_,
   {{0x272b96a9,0x6d5c186c,0x3f9946df,0x63a9c018}},	//   _løn_, urra, _arsu_, lxen,
   {{0x60c4186d,0x7d0d186e,0x2247c4f1,0xc952c093}},	//   _ulim, _ghas, _henk_, _ומה_,
   {{0xc246586f,0x9c134044,0x6d4e1870,0x69c1409d}},	// [1200] инак, _fọma, ssba, _ülej,
   {{0x63a9d871,0x68e45872,0x68fb9873,0x628e41c8}},	//   ixen, snid, _akud, _qabo,
   {{0x35a601cc,0x290d8011,0x68e98011,0x2127c0d2}},	//   _танг, _bhea_, _bjed, _junh_,
   {{0xe73a9874,0x27ff93e1,0x63bbd875,0x7bcd423b}},	//   вед_, _byun_, kyun, bzau,
   {{0xddd88185,0x38669876,0x290d929a,0x186780a9}},	//   devš, rgor_, _dhea_, рачи_,
   {{0x68fb800b,0x2247c303,0xd70786e4,0xfd4cc104}},	//   _ekud, _nenk_, анче_, _chiệ,
   {{0x27ff81c0,0x27e0c0b4,0x290d805e,0x68e980b0}},	//   _eyun_, _ţin_, _fhea_, _fjed,
   {{0x290d8033,0x21201877,0xd497d878,0x25f9c17e}},	//   _ghea_, _niih_, арь_, _उड़ी_,
   {{0xa8054070,0x7d029879,0xc6f8c6b1,0xab2a8210}},	//   muñé, mlos, лних_, _роза_,
   {{0x623381bd,0x597683d0,0x23bcc171,0x63ab537b}},	//   _међу, _выду, _aájú_, ägni,
   {{0xfd530112,0x2ef800fa,0x2163c07d,0x6d608e9a}},	//   _dofọ, dorf_, отяг, ývač,
   {{0xd7fac0b4,0x211ac231,0x63bbc84f,0xddd8c247}},	//   _иул_, _شتاب_, byun, _tavž,
   {{0xf8bf187a,0x7648987b,0x20d20166,0xdc2e403a}},	//   rké_, _kedy, jšiu_, _sığo,
   {{0x2484d87c,0x7b1040cb,0x7d0d034d,0x4b7bc052}},	//   lemm_, läuf, _whas, _סאוו,
   {{0x78ad587d,0x764743e2,0x2d85430d,0x20cac061}},	//   tjav, _rejy, _álex_, _cùig_,
   {{0x30a4401b,0x7cfd0107,0x6283987e,0x31578052}},	//   орув, gért, zeno, יילן_,
   {{0x2f0bc0b0,0x644b8de0,0x3ce6804f,0x98afc570}},	// [1210] søge_, vagi, dnov_, žaće_,
   {{0x20d3c119,0x60dbd87f,0xddd88011,0x76488231}},	//   rţii_, zium, zevš, _nedy,
   {{0xb99501b4,0xa49b429a,0xe3b004e8,0x212740d1}},	//   _الجب, _bhòt, _فری_, ênh_,
   {{0x78a2c070,0x20d3c0b4,0x7cfd0107,0xf3ff001f}},	//   _nnov, pţii_, mérs, ngão_,
   {{0x68e980da,0xa28341aa,0xcc12c044,0x7ce802d6}},	//   _vjed, _ویرو, _dọkị, dırl,
   {{0x75289880,0x141a44e0,0xdc3c40f6,0xddc580d9}},	//   _budz, _תושב, _iġġo, йбли,
   {{0xdddc1881,0xd6580093,0x7c2d82b0,0x2247c06a}},	//   zdrž, ביות_, ñars, _renk_,
   {{0x68fb8339,0xb05b4041,0x15b8859d,0xe5768523}},	//   _ukud, _oläm, рышы_, ёзы_,
   {{0x28a9c384,0x395ec31d,0x7ebd8303,0x3f89402c}},	//   काबि, erts_, _lèpi, nwau_,
   {{0x26c580e2,0x21200033,0x7528806f,0x2cbfd882}},	//   _ullo_, _siih_, _fudz, skud_,
   {{0x7cfd0107,0x64498061,0x2fcdc107,0x317e8398}},	//   yért, _keei, szeg_, _gptz_,
   {{0x60dd1883,0x7c84d0e9,0x20cac05e,0x3915d884}},	//   gism, _муче, _cùid_, _умер,
   {{0x395ec0bf,0x62855885,0x2005003a,0x2247d886}},	//   arts_, keho, əlik_, _tenk_,
   {{0x23271887,0x69ce00cb,0xa3af9888,0x7d1845ca}},	//   сори_, tzbe, _ओपन_, _évsz,
   {{0x0135c7c3,0x68fd4033,0x7196c1aa,0x64a65889}},	//   _اعتد, _bksd, _هنوز_, бава,
   {{0x65654033,0x6b9b8019,0xb886c004,0x69ce00cb}},	//   duhh, _orug, muíñ, rzbe,
   {{0x1d074c86,0x3fe28079,0x6b9b8112,0x4fa340c5}},	// [1220] сети_, _বর্ষ, _nrug, питв,
   {{0x8e860032,0x38694359,0x49000185,0x77830c38}},	//   _الده, agar_, रतको_, _эльз,
   {{0x644980fa,0xfaff00fd,0x7ce801df,0x98b846e2}},	//   _beei, rtët_, yırl, strı_,
   {{0xcebac6df,0x232a988a,0x20d217d3,0x6d5e4402}},	//   _miƙa_, годи_, pšiu_, rrpa,
   {{0xcebac09c,0x6d4340cc,0xc0530052,0x44324062}},	//   _liƙa_, ânar, לזא_, mcy_,
   {{0x954a4c59,0x60dd188b,0x386d8056,0x7afe005c}},	//   _مشرق_, zism, _ecer_, _jkpt,
   {{0x60dd188c,0xed35459d,0x80a4c444,0xb05b188d}},	//   yism, _мэтэ, काले, shäi,
   {{0xccf9c036,0x764881f4,0xb87b0047,0x2d98001e}},	//   goś_, _wedy, tním, ivre_,
   {{0x7d04588e,0x39aec03a,0xf7438b8e,0x28cc00e4}},	//   ilis, məsi_, _нето, ासनि,
   {{0x60dd0033,0x4154d702,0x5d54d07a,0x3869588f}},	//   wism, овос, окот, zgar_,
   {{0x57b31890,0x8af04080,0x60c29891,0xb87b0089}},	//   ुन्ह, msəd, okom, sním,
   {{0x48ab1892,0xb87b0574,0x7cfec13b,0xd12f8032}},	//   утом_, mník, tëru, _أمن_,
   {{0x9e4b0156,0x6d5a0038,0x68e382b0,0x02fa5893}},	//   ţămâ, átan, éndi, ्ताह_,
   {{0x7cfd0066,0x2904d894,0x7d045895,0x38bc4047}},	//   térs, llma_, elis, _míru_,
   {{0xd6d81896,0x7d045897,0x91fcc017,0x62855898}},	//   стя_, flis, zgāj, veho,
   {{0x6b8d1899,0xdddc43bf,0x59dec384,0x2486806f}},	//   _tsag, _barž, _फेयर, jeom_,
   {{0x9ed9532d,0xb8d14028,0x63a9098b,0x7e7c4033}},	// [1230] амат_, _टच_, åend, _bbrp,
   {{0x59a88f76,0xa49b429a,0xfaff013b,0x80b8802a}},	//   कमार, _chòr, rtës_, _আগষ্,
   {{0x65654033,0x6d340523,0x9865405f,0x39aec080}},	//   uuhh, _неэф, _ویسے_, fəsi_,
   {{0x7afad89a,0x46a70314,0x6721989b,0x2d9cc011}},	//   hott, खावह, _silj, _mrve_,
   {{0x68ed0150,0xdbe34018,0x6285589c,0x68f9989d}},	//   _mjad, _téño, peho, rowd,
   {{0x26ded89e,0x644f189f,0x91fcc017,0x8f344bf1}},	//   jito_, haci, rgāj, _херц,
   {{0x39aec03a,0x5fe00045,0x0319c01c,0xb6bc0323}},	//   bəsi_, _पेनल, یتخت_, רצוי,
   {{0xf8c941f9,0x66c4c053,0x6b9b98a0,0xa3b905da}},	//   रसिय, _bòko, _trug, चहा_,
   {{0x752ac0fa,0x2d98c240,0xb05b00cb,0x7522c1a8}},	//   _aufz, æren_, nhäu, _dioz,
   {{0x63ad58a1,0x78b60070,0x2904c0f8,0x7d1658a2}},	//   ixan, _soyv, alma_, zmys,
   {{0xb035c0c5,0x764ad8a3,0xdb060036,0xfc33c16a}},	//   _днеш, _defy, zykó, _فحش_,
   {{0x224e0077,0x673bc051,0x6915c089,0xe0df0157}},	//   _žfk_, ppuj, _všes, giò_,
   {{0x232a18a4,0xb05b404c,0xb4fa8052,0x7d044138}},	//   роги_, _eläk, שפרי, vlis,
   {{0x272f006a,0x2360415d,0x644bc449,0x629500a8}},	//   _dün_, vrij_, _hegi, gdzo,
   {{0x7cfec0da,0x249218a5,0xdd1c8347,0x60db98a6}},	//   përt, _taym_, vážn, _omum,
   {{0x68fbd8a7,0xdca34d9a,0x25a50041,0xa3ea401b}},	//   noud, маси, ålla_, адба_,
   {{0x644bd8a8,0x29120843,0x8b26411b,0xcb6a58a9}},	// [1240] _megi, _ihya_, ідже, разе_,
   {{0x6723d8aa,0xb05b4051,0xb05b1368,0x7d1640a0}},	//   _jinj, _yläk, nkän, smys,
   {{0x39aec03a,0x60c998ab,0xdd1c8066,0xa50a423d}},	//   təsi_, _blem, rážn, _вена_,
   {{0x03a64895,0xb17ac052,0x63ad4080,0xfbc9c047}},	//   _димо, יטער, bxan, िनाम,
   {{0xb05b04c9,0x7afac7b0,0x290002c0,0xadc381c0}},	//   phäv, yott, _mkia_, _ifẹl,
   {{0x60db825d,0x179b0087,0xe0df023f,0x39aec03a}},	//   _emum, יינב, ziò_, səsi_,
   {{0x2912007a,0x60c288ff,0xb87b0047,0x7cfec0fd}},	//   _ohya_, pkom, bníh, dërr,
   {{0x68e9d8ac,0x68fbc907,0xa0678f8d,0x320c980a}},	//   gned, goud, _маса_, _vzdy_,
   {{0x2002c10d,0xb87b0066,0xe0df0157,0xfd4e0044}},	//   æki_, sník, viò_, takị,
   {{0x60c458ad,0x6457c020,0xb87b0089,0x4b7b4323}},	//   hkim, _ɗaiɗ, pník, סטיג,
   {{0xa2a7863c,0xa2b98281,0x1df8c1dc,0x7afc18ae}},	//   चार्, ्सर्, сены_, dort,
   {{0x644bd8af,0x7afad8b0,0x3eb840b0,0x68fbd8b1}},	//   _gegi, sott, _lort_, coud,
   {{0x7c290011,0x99980007,0x7afc18b2,0xe7e08374}},	//   žero, karų_, fort, _खेमा_,
   {{0x70dac374,0x6b82c157,0xe20a4045,0x68e0d8b3}},	//   _बगुल, _ipog, _वरूण_, limd,
   {{0x28bf46d6,0x6d584077,0x853c8007,0x290681a8}},	//   _एकदि, švaj, _drėg, kloa_,
   {{0x6568d8b4,0x68e0d8b5,0x6723d8b6,0x115b8052}},	//   mudh, nimd, _zinj, ידלע,
   {{0x628718b7,0x6b82c085,0x3ce958b8,0x6723d8b9}},	// [1250] pejo, _jpog, rnav_, _yinj,
   {{0x501bc0c3,0x644d005e,0xb4c7c5cb,0x7f8402cf}},	//   שומו, _heai, _उत्_, _کلین,
   {{0x3f824011,0xf09f4061,0x3ced8043,0xdddc417a}},	//   _epku_, _bhàt_, _pjev_, _garż,
   {{0x397bc009,0x7bc0c007,0x672d18ba,0x6ab8c240}},	//   שטאנ, kymu, _kuaj, _lovf,
   {{0xa3cb054a,0xdc3f4531,0x644d0032,0x28a9c285}},	//   लनि_, níčk, _meai, कासि,
   {{0x6b8d57b8,0x23694022,0x7bc0c007,0x248958bb}},	//   mwag, muaj_, dymu, leam_,
   {{0xf2d24009,0x672bc0fd,0x23694022,0xb05b04c9}},	//   _װען_, _sugj, luaj_, vkän,
   {{0x6603d8bc,0x644d15c5,0x65774022,0x248958bd}},	//   _rynk, _neai, mtxh, neam_,
   {{0x6603d8be,0x66e5d23a,0x68fbd8bf,0x7c2998c0}},	//   _synk, зопа, roud, _iger,
   {{0x68e9d8c1,0x69c5c54a,0x644bd8c2,0x68fbd8c3}},	//   sned, _ühek, _wegi, soud,
   {{0x7641d8c4,0xe5a5cdce,0x7afc18c5,0x60c458c6}},	//   rbly, чини, vort, ykim,
   {{0x644d18c7,0x81e9002a,0x6723c1c6,0xbfb7d546}},	//   _ceai, _বরং_, _winj, _وحشت,
   {{0x672d00e1,0x2004010d,0x76438022,0x257544c9}},	//   _cuaj, æmi_, obny, hål_,
   {{0x8f9ac052,0x25dc454a,0x38984112,0x25754730}},	//   _ליני, _गइली_, _ọr_, kål_,
   {{0x505a410e,0x6d55005f,0x65774046,0x20c7409d}},	//   йшая_, gsza, jtxh, _võin_,
   {{0x55bac093,0xa3ab8185,0x4429017b,0x60c44007}},	//   _למצו, गमा_, _gga_, ukim,
   {{0xab6658c8,0xdce3cf26,0x87b91269,0x6b8d58c9}},	// [1260] явал, junč, _дуэт_, gwag,
   {{0xdce3d8ca,0x7afc01c8,0x26c5c007,0x80aa0b5b}},	//   dunč, qort, nklo_, टावे,
   {{0xdebb0093,0xe9f9c00c,0x673b8f9b,0xdcf4c199}},	//   _המיל, _đẻ_, _atuj, _šači,
   {{0x248958cb,0xeb9f4240,0x186a98cc,0xf8cc08c1}},	//   ceam_, _frø_, сади_, ासिय,
   {{0x3eb8418a,0x6e3b406a,0xb09b40c3,0xa3fc802a}},	//   _tort_, _şube, _היכר, েশ্য_,
   {{0x3eab4283,0x6b8418cd,0xcebac09c,0x80d84045}},	//   ċità_, _mpig, _riƙo_, नोरे,
   {{0x68e0c91a,0x7ebd8016,0x38a58112,0xb87b00a0}},	//   timd, _rèpt, ịram_, mnív,
   {{0x66cb003a,0x7bc0c007,0x2bc8c185,0x776298ce}},	//   _müka, tymu, ाईला, prox,
   {{0x68e0c0b5,0x6d46c6f0,0xdd1f00a0,0x7ebd80d2}},	//   rimd, ćkam, tížn, _pèpt,
   {{0x672d00da,0x68e298cf,0x6b82c04f,0x86ea8032}},	//   _ruaj, liod, _vpog, _اعرف_,
   {{0x6aa889ca,0x69c1409d,0xe3afc2f0,0x2d8cc0a8}},	//   _indf, _ület, نری_, uwde_,
   {{0x2347c01c,0xdc3f4089,0x764e4855,0x7bfdc35d}},	//   _کلوپ_, tíčk, _leby, ợtốt_,
   {{0x98a780e0,0x28a9c4d0,0x8c43c717,0x6568d024}},	//   šići_, कारि, _чече, sudh,
   {{0x44290498,0x629898d0,0x628a851f,0x96eb00cf}},	//   _wga_, ndvo, nefo, сьма_,
   {{0x4ddc40b2,0x692a8047,0xa3e3825c,0x183a4094}},	//   _गेलै_, _hřeb, _फेन_, _ọmụm,
   {{0x672d00da,0x2bde47f6,0xb9250032,0x1cbb4032}},	//   _tuaj, _नेहा, _تفعي, حاسب_,
   {{0xaca34112,0x248958d1,0x60cd18d2,0x23db8048}},	// [1270] _nsụd, ream_, _ilam, _मेंद,
   {{0x290240bc,0xb05b00cb,0xab61c06a,0x6d5518d3}},	//   _ekka_, chär, _şüke, psza,
   {{0x629558d4,0x752641a8,0xa4d998d5,0x5c758026}},	//   _vazo, _fikz, оджу_, длет,
   {{0x2ee301d4,0x7ae1c3bc,0xec6b4179,0x04674051}},	//   lijf_, zilt, _урок_, _этом,
   {{0x6d4ac02c,0x22684047,0x46d101f9,0x3a384f2d}},	//   _lwfa, átké_, _हताह, _ffrp_,
   {{0xc3324009,0x255780b4,0xde058764,0x66058156}},	//   _בוך_, tăl_, мпли, мпла,
   {{0x386dd8d6,0xb05b0051,0x7ae1d8d7,0xd16440c5}},	//   tger_, tkäl, vilt, _пъти,
   {{0x7c2998d8,0x7f59c8b5,0x386dd8d9,0xb4bc054a}},	//   _uger, ојот_, uger_, _आके_,
   {{0xcd028036,0xa22781aa,0xc178c007,0x3af5c0d9}},	//   _dość_, _فراه, etė_, дянс,
   {{0x672758da,0x1306c051,0x644f58db,0xd706c051}},	//   _jijj, мный_, _leci, мные_,
   {{0x693c00ab,0x208a18dc,0x29094025,0x67274085}},	//   _ičeg, ойни_, klaa_, _mijj,
   {{0x2f144314,0xd00a001d,0x672740bc,0xf9fa80c3}},	//   mäge_, жеме_, _lijj, _והעמ,
   {{0x69c398dd,0x3ea7c0b3,0x2f145456,0xdce20017}},	//   lyne, _tnnt_, läge_, gulā,
   {{0x69080004,0x645d4e05,0x0693c05f,0x68ed443e}},	//   iñei, _adsi, _ساتھ, enad,
   {{0x60cd18de,0x78a9919e,0x20cac05e,0x75264127}},	//   _flam, _onev, _mùin_, _pikz,
   {{0xe8f60032,0x65610107,0xb4e78048,0x442b58df}},	//   _تستخ, álha, यचो_, _cgc_,
   {{0x7d0418e0,0x672741ae,0x6b84012c,0x752e4379}},	// [1280] _ikis, _bijj, _upig, _subz,
   {{0x776458e1,0x7bc298e2,0x629700b9,0x78a9901e}},	//   rrix, vyou, _gaxo, _anev,
   {{0xb87b0560,0x628a98e3,0xdce9406a,0x442b4580}},	//   rnív, vefo, _çoğu, _fgc_,
   {{0x644f58e4,0x7bcdc017,0xcdb6c0c3,0x7c838051}},	//   _geci, _ļaun, ופעה_, вуше,
   {{0x62988158,0x764e58e5,0x62818085,0xba5640c5}},	//   tdvo, _teby, _bblo, _отвъ,
   {{0x290040fc,0x6281805e,0x6d574080,0x6727440d}},	//   loia_, _cblo, bsxa, _gijj,
   {{0x6aba8077,0xf8d24384,0x62818085,0x20cac29a}},	//   _votf, _सताय, _dblo, _dùin_,
   {{0x78a98a93,0x23c9c048,0x68e458e6,0xb05b0025}},	//   _gnev, िनंद, niid, tkäm,
   {{0xa29f8063,0x6d41d8e7,0x00000000,0x00000000}},	//   _गोव्, epla, --, --,
   {{0x29004140,0xc17ac0d9,0x6d41d8e8,0x6abc4060}},	//   hoia_, оїм_, fpla, _jorf,
   {{0x68ed58e9,0x290041a8,0xab5b0107,0x7afd85e7}},	//   ynad, koia_, gyün, _ísta,
   {{0xbfc6c1bc,0x629718ea,0x6d5898eb,0x7d02c150}},	//   _обек, _saxo, msva, _ukos,
   {{0xb33b401d,0x351bc009,0x44394498,0xc178c039}},	//   _orça, _וואנ, _rfs_, stė_,
   {{0x213cc0d1,0x20c740b2,0xdce3c8c7,0x98bf0138}},	//   _ttvh_, _võim_, munā, rttı_,
   {{0x442b58ec,0x45d518ed,0x2ee300a8,0xdcbb40d9}},	//   _pgc_, ховс, rijf_, оща_,
   {{0x23668077,0x66d004c9,0x68ed58ee,0x66088303}},	//   kroj_, _räke, unad, _mydk,
   {{0x6298d8ef,0x6abc58f0,0x660887fb,0x78bb98f1}},	// [1290] _kavo, _borf, _lydk, _rouv,
   {{0x672882bc,0x290498f2,0x6d5898f3,0x442b4070}},	//   _nidj, _akma_, ksva, _wgc_,
   {{0x644f58f4,0x7d09d8f5,0x68e458f6,0x78a9806c}},	//   _teci, yles, biid, _pnev,
   {{0x200917a6,0x21290033,0x645d4065,0x7d04005c}},	//   _kyai_, _jiah_, _udsi, _xkis,
   {{0x7d09d8f7,0x2129005c,0x7d00d8f8,0x9f4b8189}},	//   vles, _miah_, doms, _ömür_,
   {{0x6d41c125,0xe802c17e,0x499598f9,0xda7e41af}},	//   ypla, _लड़ा_, ешит, íďte_,
   {{0x6d5898fa,0x225e0062,0x7f4d075d,0x7c2d18fb}},	//   gsva, ótki_, _lwaq, _ogar,
   {{0x236680e0,0x1fb5cf6b,0xa29f98fc,0x69c398fd}},	//   broj_, есор, _गोर्, ryne,
   {{0xf77088a7,0x6298d8fe,0x5bc9c25c,0x76550036}},	//   _نال_, _bavo, िनेव, kazy,
   {{0x6298c5f5,0x3f4d18ff,0xb659c051,0x6728817a}},	//   _cavo, džu_, чших_, _gidj,
   {{0x69c10240,0x3f86c053,0xaaac8047,0x7f4d0073}},	//   ølel, _epou_, चारक, _awaq,
   {{0xdb008060,0xcdda4052,0x65938561,0x27340053}},	//   _armè, פֿיר, _nəhə, _pän_,
   {{0x61fb03a6,0x2be00758,0x290053f3,0x68e4409d}},	//   şull, _पेशा, voia_, viid,
   {{0x76550036,0x75299900,0x6d420077,0xb05b44c9}},	//   gazy, _liez, _čoab, _oläs,
   {{0x6f01c06c,0x7d161901,0x2d94c026,0x38c845d3}},	//   molc, _thys, _арыс, واری_,
   {{0xba231902,0x7d041903,0x3958001f,0xeafa409d}},	//   удск, _ukis, rsrs_, ्त्त_,
   {{0x68e45904,0x2cab4070,0xfaff00fd,0xdbc7009d}},	// [12a0] riid, _dncd_, mrën_, _sööm,
   {{0x442d9905,0x60c9d906,0x6306461e,0xb05b5073}},	//   _age_, hkem, روال, _slät,
   {{0xdcffc047,0x7bc61907,0x2cab40b6,0x91fcc8c7}},	//   ívěs, lyku, _fncd_, lgār,
   {{0x20cac29a,0x68e44149,0x67289908,0x66e6c171}},	//   _cùil_, qiid, _sidj, _kékè,
   {{0x64565909,0x248dd90a,0x7053801c,0x03a3990b}},	//   mayi, deem_, انها, лицо,
   {{0x2360804f,0x2366813b,0x7c3b884f,0x3cff4123}},	//   šijo_, rroj_, _efur, čuve_,
   {{0x9c83961b,0x442d8018,0x7529805c,0x6f01d02f}},	//   ščar, _fge_, _fiez, dolc,
   {{0x2b400451,0x7ae18085,0x6d4e4157,0x248041ff}},	//   _otic_, _emlt, _iwba, nfim_,
   {{0xe3b2c182,0x68e60080,0x656e190c,0x629c04c9}},	//   ارع_, dikd, hubh, kdro,
   {{0x7c248077,0x98a80017,0xfaff013b,0x7529990d}},	//   žirs, _runā_, erën_, _ziez,
   {{0x28f9190e,0x63a2c0c3,0x20c2190f,0xdca6c119}},	//   день_, _wron, _nóis_, _пажи,
   {{0x93f48063,0x23c7402e,0x7ce80561,0xe0d7d910}},	//   _अशाच_, _jíjú_, dırs, _пвх_,
   {{0xdb008669,0x68e2c00d,0x64565911,0x629c00a8}},	//   _armé, _imod, dayi, fdro,
   {{0x2f97c093,0x629a8232,0x63a4054f,0x6d5c5912}},	//   _נכון_, _jato, _drin, _ovra,
   {{0x7d029913,0x7ae540e5,0x78abd914,0x69d88414}},	//   koos, viht, _yngv, nzve,
   {{0x776d4004,0x2f1600b0,0xfd13554f,0x29020024}},	//   tuax, væge_, اجس_, coka_,
   {{0x6d5c5915,0x7c84004c,0xc29948a9,0x2d9e1539}},	// [12b0] _avra, _суще, мках_, åter_,
   {{0x2bdb84fb,0x442d9916,0x248dd917,0x69c546a6}},	//   _मेगा, _sge_, zeem_, tyhe,
   {{0x2d875918,0xf653c052,0xeef7c052,0x628500f7}},	//   ïne_, רצע_, עמבר_, _ibho,
   {{0x291d9919,0x7d02991a,0x39918247,0x64564611}},	//   umwa_, goos, _ršs_, cayi,
   {{0xadfc0036,0x78ad191b,0x257a814b,0x6d4e591c}},	//   _एडऑन_, _mnav, eël_, _ewba,
   {{0x7529991d,0xda62820d,0xd0564561,0xaaa48062}},	//   _wiez, авши, diyə, _गोदक,
   {{0x2bd9cc6b,0x2902191e,0x8aa440c5,0xf8bf4396}},	//   _बेजा, yoka_, _сряд, _koé_,
   {{0x3991991f,0x20074080,0x629c0b75,0x628e0036}},	//   _všs_, ənir_, zdro, zebo,
   {{0x629a9920,0xa28381aa,0x248dd921,0x29021922}},	//   _fato, _میشو, reem_, voka_,
   {{0x236945c7,0xc3c8c1b4,0x63a41923,0xa3ce8045}},	//   iraj_, عظيم_, _rrin, शनर_,
   {{0xdd918567,0x186a1924,0x860281aa,0x0446059d}},	//   _خوا_, мани_, _پژوه, кенн,
   {{0x6d418085,0x7ae6c303,0x628500cb,0x32cf006a}},	//   _itla, éktr, _abho, _rüya_,
   {{0x7d0d5925,0x2d8c0283,0x628e1926,0xda0dcfd1}},	//   dlas, ħdem_, tebo, _हरकत_,
   {{0xa3dac758,0x2369405c,0x200c0017,0xdce3c0b4}},	//   _डेट_, draj_, ādi_, bună,
   {{0x29194303,0xfaff013b,0xa2840de9,0xe45f0fd0}},	//   _bhsa_, prën_, نیکو, rhör_,
   {{0x753c805f,0xdb02c303,0x98b88017,0x55f6c0c3}},	//   _érze, _aroè, _otrā_, _במצב_,
   {{0x7ae70077,0x68e41927,0xb4d25928,0x1d0750cd}},	// [12c0] bijt, _imid, _वती_, тети_,
   {{0x7d0d409d,0x2fc68022,0x6d419929,0x6f039496}},	//   alas, vyog_, _otla, jonc,
   {{0x2cbf814b,0x6d4540d1,0xbebcc017,0xc692c1f2}},	//   _boud_, gpha, smīg, שאב_,
   {{0x0b8a82e2,0xdb040078,0xceb8c036,0x938a87e3}},	//   дски_, _orië, zję_, дска_,
   {{0x6bd687c3,0x939381b4,0xa3c2009d,0x6d45592a}},	//   ختار, لجوا, ंहि_, apha,
   {{0xe283843e,0x68e2d92b,0x1ee6801c,0x212040e5}},	//   илчи, _smod, ضوعی_, lmih_,
   {{0x2fc6823b,0xdb1d0107,0xd91ac051,0xb05b00b2}},	//   syog_, nysá, мьи_, skäi,
   {{0xa3c21890,0x6d5ad92c,0x69c34051,0x237686b0}},	//   ंहा_, vsta, änee, _لائح,
   {{0x09cac891,0x6281c3ad,0x7cfd0004,0x6f038e7b}},	//   ान्य, fflo, mérx, bonc,
   {{0x7d0d592d,0x32d081c0,0x7d04592e,0x4ea6c376}},	//   zlas, _fàya_, hois, триа,
   {{0xddc88064,0x7d0d592f,0x290dc545,0x7658812c}},	//   _wedł, ylas, blea_, mavy,
   {{0x290dd930,0x7769c03c,0x61fa8070,0x77cac203}},	//   clea_, brex, _ixtl, _олег_,
   {{0xfbdf414d,0x60d64398,0x60c09931,0x6d5c1932}},	//   _leêr_, dhym, _momm, esra,
   {{0x9abc80f6,0x59b69933,0xd6d0c2f0,0xaa641934}},	//   _biċi, _अपार, _دقت_, итск,
   {{0x3cff5935,0xa9c405f1,0xe80f0314,0x66c4c0b6}},	//   लवले_, астк, _सरका_, _dòkt,
   {{0x656a8032,0x48bd8079,0x6f039936,0x8c3b40cb}},	//   irfh, _আগ্র, zonc, _maßg,
   {{0xe7bd8079,0x20c201b4,0x5c0741bc,0x76589387}},	// [12d0] _অধ্য, _tóir_, тява, kavy,
   {{0x6e454032,0x76589937,0x2904d938,0x6d454104}},	//   انضم, javy, homa_, tpha,
   {{0x69dad939,0x60c0993a,0x6e9441eb,0x212b593b}},	//   nzte, _bomm, риху, _tich_,
   {{0x63a64011,0xb87b593c,0xe791406a,0x2904d93d}},	//   _frkn, _zmín, _göğü, joma_,
   {{0xa3ad4a71,0x6281d93e,0x6d41993f,0xfbd08032}},	//   _कपट_, yflo, _stla, يته_,
   {{0x2cbf868e,0x6d454833,0xaca381c0,0xc879d940}},	//   _woud_, ppha, _ikọn, mişi_,
   {{0xf527860e,0x81e6802a,0xfce5d19f,0xb05b4025}},	//   _афан, _যুব_, локо, _yläp,
   {{0x2cad81f4,0x6ca49941,0x752d017b,0x26199942}},	//   _uned_, _круж, _niaz, येगी_,
   {{0x629c5943,0x76588150,0x60cd5944,0xa49b402e}},	//   _yaro, bavy, ikam, _akòk,
   {{0x7769d945,0xf09f0016,0x290dc0fc,0x0ccc1946}},	//   rrex, edà_, slea_, ास्म,
   {{0x69374011,0x7d04412c,0xd5e5caba,0xdc10425c}},	//   _oćem, yois, ужни, _ार्ड_,
   {{0x64599947,0xcb6a1948,0xaca380d1,0x27399949}},	//   nawi, наме_, _khốn, _kèn_,
   {{0x20f8994a,0x7d04594b,0x273983bc,0x6e29003a}},	//   nčia_, vois, _jèn_, əmbə,
   {{0x320c0064,0x6459994c,0xe689c032,0x5a47c5dd}},	//   żdym_, hawi, _أنثى_, _рэда,
   {{0x63a640b3,0x629c4e84,0x2d98c240,0x75354157}},	//   _srkn, _raro, æret_, _nuzz,
   {{0x7b1040fa,0x6d5c194d,0x629c594e,0x6908034d}},	//   räum, rsra, _saro, añer,
   {{0xb928c25d,0x10a34623,0x765540b6,0x93464f72}},	// [12e0] _akwụ_, щитн, _bezy, унзе,
   {{0x629c594f,0x60cd5950,0x3cff45c7,0x93b70093}},	//   _qaro, akam, čuva_, _עליו_,
   {{0x64a69951,0x4a7b0009,0x75354011,0x2904d952}},	//   лажа, _אריב, _cuzz, yoma_,
   {{0x3a3e8498,0x7d061953,0x22588158,0x443f9954}},	//   _sftp_, noks, _žrk_, _cfu_,
   {{0x76589955,0x212d8303,0x7d1b9956,0x2904d957}},	//   tavy, _dieh_, _dhus, voma_,
   {{0x64560083,0x443f8094,0x75355958,0x629c5959}},	//   _leyi, _efu_, _fuzz, _uaro,
   {{0x7535595a,0x7d060051,0x3f804016,0x69134138}},	//   _guzz, koks, ltiu_, kçel,
   {{0x69c8d95b,0x7658995c,0x63a4595d,0x212d80f6}},	//   vyde, savy, ovin, _gieh_,
   {{0x667680a3,0x249dc046,0x8fa3995e,0x3f80595f}},	//   _مدار, _dawm_, _лате, ntiu_,
   {{0xc3334087,0x7afcc06c,0xdb008089,0x63a45960}},	//   זוז_, črto, _krmí, ivin,
   {{0x64561961,0x7f441962,0x2904d963,0x7ae8c211}},	//   _beyi, _atiq, poma_, ridt,
   {{0x273985dc,0x672e41d6,0x2ca0421b,0x8556c08c}},	//   _yèn_, _libj, jdid_, پیکر_,
   {{0xd7f807d4,0x2d9a0053,0x9f350125,0x629e1964}},	//   гур_, _aspe_, регі, _bapo,
   {{0x64598036,0x249dc022,0x2d51c06c,0x53341965}},	//   zawi, _zawm_, bše_, серт,
   {{0x6d46c13f,0xd5afcc1b,0x02b1c048,0x56378052}},	//   ćkas, _ус_, जारभ, ראלע_,
   {{0x60cd4007,0x753540c4,0x2fc9581f,0x4432017b}},	//   ukam, _ruzz, tyag_, _ggy_,
   {{0x75354157,0x3e6b4bfc,0xbec78017,0x6d471966}},	// [12f0] _suzz, ешен_, ldīš, spja,
   {{0x7d1b9967,0x68e9c017,0x8883401c,0x629e0c66}},	//   _shus, zied, _گیرن, _gapo,
   {{0xdd91483b,0xe7ebce95,0xa29f854a,0x3f805968}},	//   توا_, _जेना_, _गोग्, atiu_,
   {{0x5c380052,0x60c2d969,0x5f75801c,0x2739996a}},	//   ָרגן_, _noom, لاتر, _pèn_,
   {{0x629e196b,0xeb99879c,0x68e9c166,0x0a6b596c}},	//   _yapo, тил_, vied, _први_,
   {{0xa96988d3,0x2169996d,0x6b8d0094,0xa3de4048}},	//   вика_, вики_, _mpag, _थेट_,
   {{0x08d5c376,0x69ca897e,0x6459996e,0xbd458359}},	//   иция, gyfe, pawi, جنبي,
   {{0x443f996f,0x7d1b84fd,0x693c0011,0x62888053}},	//   _ufu_, _uhus, _očen, _ebdo,
   {{0x26c34570,0xdddac066,0x799a9970,0x63b68051}},	//   _kojo_, latň, _estw, äynt,
   {{0xfaf39971,0x4585c072,0x2489005c,0xa6e5c5af}},	//   _اثر_, агов, _abam_, ржол,
   {{0x6b8d1972,0x2d815973,0x2d51d974,0x645603bc}},	//   _apag, nthe_, uše_, _peyi,
   {{0xb605c083,0x03a60a23,0xa3e70428,0xaad9cdb4}},	//   _aláà, аимо, _येह_, योजक,
   {{0x2d98c240,0x63a99975,0x629e1976,0x60dd00fd}},	//   ærer_, _jren, _papo, ërma,
   {{0x249f847a,0x6d5e5977,0x6da5d978,0x776d4004}},	//   _laum_, yspa, _вика, drax,
   {{0x672e404f,0x68eb8006,0x2d8c1979,0x6cecc25c}},	//   _ribj, kigd, ïde_, _जगमग_,
   {{0x629e012c,0x6d5e597a,0x645bc414,0x2d815573}},	//   _wapo, vspa, naui, dthe_,
   {{0xa01b0c24,0x4127447f,0x2b494018,0x442600d1}},	// [1300] nföl, рото_, gpac_, _ào_,
   {{0xf8d2c330,0x60c4197b,0x645bc43e,0x23664026}},	//   _तत्प, _hoim, haui, šojo_,
   {{0x2d814359,0xf09f4031,0x3cf28c4b,0x6d5e5173}},	//   gthe_, _faà_, ंचले_, uspa,
   {{0xb35840fb,0xa9674271,0x200c003a,0xdca653d0}},	//   _میرا_, рица_, ədir_, _тами,
   {{0xac078156,0x24078bf1,0xcc3b0052,0x35a7c25c}},	//   анца_, анци_, דענט, गिड़,
   {{0x4ed54768,0x6d5e597c,0x3f82021b,0xa01b197d}},	//   _люст, pspa, itku_, dföl,
   {{0x63a9997e,0xd5b24107,0x249f805e,0x8c3d914f}},	//   _eren, _ظفر_, _faum_, _başd,
   {{0x291dd24f,0x692ac0a0,0x63add97f,0x741682f0}},	//   _chwa_, _zřej, _šana, _نوزا,
   {{0x2486910f,0x9998004f,0x68f641f4,0x1eaac032}},	//   mfom_, jbrž_, inyd, نادي_,
   {{0x6e968032,0x4b7b9980,0xdce74062,0xb6c6c23f}},	//   _خلطا, _באמו, mują, рсий,
   {{0x60c41981,0x20f88039,0x60c2c54a,0x249f823b}},	//   _boim, nčio_, _toom, _yaum_,
   {{0xdb0080b4,0x236dcb81,0x0ea6c048,0xfc3f00a0}},	//   _urmâ, brej_, _कोरड, ucí_,
   {{0x6d450085,0x98bf0017,0xdce74036,0x2b494004}},	//   _stha, lstī_, nują, xpac_,
   {{0xa3d788c0,0x6d5cd982,0xdb240086,0x6ee9056e}},	//   ानत_, áras, ærðu, ržbo,
   {{0x39450b45,0x0dcac8b5,0x3866c04f,0x925812bf}},	//   ëls_, _јули_, _kdor_, раст_,
   {{0x6f08c04f,0x2ca00061,0x2f0bc0b0,0x693ac0f6}},	//   lodc, _gaid_, søgt_, _jċem,
   {{0x249f9983,0x61358039,0x7658c051,0x94194dbe}},	// [1310] _raum_, _išle, _kevy, ужат_,
   {{0xf64753f4,0xba9900d9,0x63a980fd,0x776d5984}},	//   рхан, _своє_, _rren, rrax,
   {{0x8c090079,0x20074036,0x29125985,0x68eb8b32}},	//   রেশন_, łni_, blya_, tigd,
   {{0x249f804d,0x73d99986,0x20d1c032,0x20c7409d}},	//   _qaum_, лдер_, _cáil_, _võis_,
   {{0x20d1c359,0x07a59987,0x57b0c84d,0x4fa59988}},	//   _dáil_, салн, जमोह, силв,
   {{0x61fb0a4a,0xc90fd527,0x98bc8017,0x2d8300a8}},	//   şulu, ात्म_, īvā_, otje_,
   {{0x249f823b,0x7013c079,0xf9940009,0x7158823d}},	//   _taum_, _হলেও_, ַרץ_, арыс_,
   {{0x7d0d1989,0x85f800c3,0x9479d8d5,0xe5f800c3}},	//   _nkas, יצוע_, уску_, יזור_,
   {{0x81e4c079,0xdce74064,0x6d41401e,0x2258421b}},	//   _ভুল_, cują, _élab, _yerk_,
   {{0x7b32c036,0x4ec5402a,0xbd6b80b4,0x2011c8c7}},	//   _słuc, _এগুল, _арде_, āzi_,
   {{0x2d83198a,0x212fd335,0x7658d98b,0x765c198c}},	//   jtje_, _tigh_, _devy, vary,
   {{0xf8dbc54a,0x2ca0005c,0x32d98053,0xf09f435d}},	//   _बतिय, _qaid_, _dèye_, _thày_,
   {{0x7d0d0033,0x3981998d,0x6aa1998e,0x2d8300a8}},	//   _dkas, lós_, _kalf, etje_,
   {{0x2cbfd98f,0x6459d990,0x7d09c1f4,0xc332c0c3}},	//   ljud_, _hewi, loes, _זוג_,
   {{0x68ed40de,0x98dbc9af,0x63abc033,0x765c1991}},	//   fiad, _बताए, _hrgn, rary,
   {{0xcd2a521c,0xfd1f40d1,0x290d8044,0x645d10b0}},	//   ужбе_, _chì_, _nkea_, casi,
   {{0x693c0043,0x212000c4,0xfc3f4263,0xdb04434d}},	// [1320] _ičem, _ihih_, _anís_, lvié,
   {{0xd05d003a,0x68e99992,0x66d01993,0x0508402a}},	//   disə, _amed, _mäkk, লগের_,
   {{0x68ed5994,0x1a9b0009,0x22585995,0x20f88b22}},	//   biad, _גייע, _verk_, učio_,
   {{0xdd8f4183,0x693ac0f6,0x69ce0007,0xd7fa8186}},	//   عون_, _bċej, mybe, лул_,
   {{0x20f88007,0x787b0009,0x60dbd996,0x68fb8396}},	//   sčio_, אָוו, dhum, _djud,
   {{0x2ca08639,0x39a780d1,0x2d9c40b0,0x6aa19997}},	//   žid_, _bđs_, æves_, _calf,
   {{0x27228015,0xddc18107,0xdce74036,0x7658c1e5}},	//   _lưng_, _belő, sują, _revy,
   {{0x60dbc105,0x160bc027,0x765e4007,0x854440eb}},	//   ghum, _सुधर_, lapy, _ịgwọ_,
   {{0x645d1998,0xdddd0062,0x3866c147,0x69ce01e2}},	//   vasi, _łyże, _vdor_, hybe,
   {{0x644400bc,0x798180eb,0x68e9804f,0x765e5999}},	//   _afii, _ịwet, _zmed, napy,
   {{0xc0e6c7ea,0x4c95079c,0xd9fa4047,0x39818060}},	//   _ложк, оинс, ्थित_, cós_,
   {{0x2ed54d91,0x693c0066,0xf79ac6b0,0x02174942}},	//   _धत्त, _včel, _منصب_, מחים_,
   {{0x7643c033,0x6b844127,0x2d8300a8,0x6f08c56e}},	//   _ffny, jtig, wtje_, podc,
   {{0x2eee805c,0x272280d1,0x644400bb,0x2f0f4414}},	//   niff_, _dưng_, _efii, nügt_,
   {{0x6ce7093d,0x60c644f5,0x7d0d199a,0x225a0303}},	//   _гіпе, _bokm, _tkas, _depk_,
   {{0x78a2c00c,0x6295199b,0x7d0d199c,0x98c443e1}},	//   _jaov, sezo, _ukas, псул,
   {{0x753a999d,0x799e03e2,0xdb098141,0xaad1025c}},	// [1330] _lutz, _espw, _freè, _सकपक,
   {{0xa49b4031,0x69ce199e,0x69c100d9,0x28a94d65}},	//   _akòt, bybe, øles, _चोरि,
   {{0x291f8046,0x26c5999f,0xa2bf4959,0x999952ff}},	//   _phua_, _rolo_, लॉग्, ркет_,
   {{0xd126c61e,0x78a2c6f0,0x481599a0,0x60dbc0f7}},	//   _زم_, _naov, омес, xhum,
   {{0x6c7a4009,0x91b68045,0x2f0f40cb,0x26c599a1}},	//   _דארפ, _अपॉइ, fügt_, _polo_,
   {{0x7f4d4070,0x29d38112,0x00000000,0x00000000}},	//   mpaq, ṭa_, --, --,
   {{0xddd50036,0x38690020,0x3cedc02d,0x9db98097}},	//   lazł, _odar_, tiev_, рылу_,
   {{0x20d1c032,0x00c9d9a2,0x68e999a3,0xdce20017}},	//   _táim_, рлик_, _umed, rtlī,
   {{0x2eee959a,0x76b98119,0x26c599a4,0x290b043e}},	//   biff_, _клар_, _tolo_, doca_,
   {{0xdb04034d,0x212019a5,0xdb02ca5e,0x765a81b0}},	//   _prií, _shih_, _croà, _gety,
   {{0xed59c6b1,0x290b0cc6,0x20cac29a,0x77f64036}},	//   јом_, foca_, _cùis_, _इश्क_,
   {{0xe80ac045,0x7b1040cb,0x69ce19a6,0xa3d94036}},	//   _हुवा_, läut, vybe, ़ना_,
   {{0x2b4900d2,0xe613c16a,0x63ad09a7,0x79504053}},	//   _ctac_, _کشش_, _cran, _kòwò,
   {{0x201dc0f7,0x60c659a7,0x6577400b,0x69ce0026}},	//   _izwi_, _sokm, kuxh, tybe,
   {{0xe5a31512,0xd62a13c7,0x3333017a,0x6aa3c05e}},	//   мири, рове_, _dixx_, _ianf,
   {{0x645b99a8,0xddc74036,0x2722800c,0x7aee0022}},	//   _neui, _wejś, _tưng_, sibt,
   {{0xa3e7008f,0x63a4d9a9,0x78a459aa,0x6b8459ab}},	// [1340] _येऊ_, _áint, rdiv, utig,
   {{0xaca441c0,0x6aa3d9ac,0x3ea34147,0x78a60ccb}},	//   _idọt, _janf, _cajt_, ldkv,
   {{0xfc3f0319,0xdb04001f,0xdb0bc0fd,0xe45f04c9}},	//   ldía_, _triâ, _argë, bjöd_,
   {{0x6d4e0b44,0x274a99ad,0xfbc7c1e3,0xa3a9c8b8}},	//   mpba, ачко_, _قت_, खटा_,
   {{0xb4ca8028,0x7cf34283,0x386059ae,0xa2c10045}},	//   _लकी_, għru, mair_, रॉक्,
   {{0x2d8506ed,0x7d1659af,0x753a99b0,0x6d4e075a}},	//   àleg_, llys, _putz, opba,
   {{0x63a9cc19,0x8c3b40fa,0x628e4085,0x60d9c99e}},	//   even, _maßn, _ibbo, _blwm,
   {{0x387f8032,0x0caad9b1,0x7d1647fb,0x94aacb54}},	//   _gcur_, ртки_, nlys, ртка_,
   {{0x2918c017,0x60f7c0d7,0xd6d0c032,0x6b6383e1}},	//   ēra_, ўныя_, فقة_, _окта,
   {{0x60c28170,0x8574c20d,0x78a2c12c,0x7d16402c}},	//   ljom, плох, _waov, hlys,
   {{0x26c7d9b2,0x2d9e8232,0xf8bf5357,0x6d488761}},	//   _dono_, _uste_, _miér_, _utda,
   {{0x60c299b3,0x629899b4,0xd90ec16a,0x40350c38}},	//   njom, levo, _جیب_, яемс,
   {{0x290b19b5,0xa3ae417e,0x68ef0080,0x78a419b6}},	//   roca_, किफ_, ricd, _daiv,
   {{0xe297c214,0xe7f2817e,0x64464b48,0x6aa3c02c}},	//   _мач_, _आइना_, _afki, _ganf,
   {{0x753c405c,0x518403d6,0x24800060,0xddc50138}},	//   _nurz, мута, _fcim_, _dehş,
   {{0x63a4c018,0x6d468077,0xdcee4017,0x69c3409d}},	//   _áins, _čkal, tubā, änem,
   {{0x26c7d9b7,0x62974089,0x6d4e03b3,0x6aa3c0bb}},	// [1350] _yono_, texo, apba, _yanf,
   {{0x645b801e,0x66d90031,0x628a80a8,0x387f99b8}},	//   _seui, _fìka, jffo, _scur_,
   {{0xd9ea8549,0x658a8080,0x78a40230,0xba9a00c3}},	//   _झेलत_, _səhn, _yaiv, _הסתי,
   {{0x672180b3,0x63a9ce8e,0x8f3559b9,0x249900b3}},	//   _shlj, yven, _немц, nesm_,
   {{0xa4f9408f,0x4439412c,0x66dd8756,0x212959ba}},	//   ्कीच_, _igs_, _lèke, mmah_,
   {{0x8c3d86e2,0x95cb47f1,0x63a9c5d4,0xe7f84fd1}},	//   _daşa, _куба_, vven, ंपरा_,
   {{0x395841f4,0x248d81ff,0xd65800c3,0x26c7d6f3}},	//   _gwrs_, _tbem_, חיות_, _rono_,
   {{0xb4d5c0b2,0x645d59bb,0xd5fc00c3,0x68ed0112}},	//   हसे_, _jesi, יפור, _nmad,
   {{0x78a419bc,0x290313ca,0xf3f9c0b4,0xa3ae4047}},	//   _raiv, čkal_, faţa_, किय_,
   {{0x2d85c3d4,0x212959bd,0x386059be,0x78a40051}},	//   ttle_, hmah_, zair_, _saiv,
   {{0xa0a60077,0x66dd8303,0x60c999bf,0x443959c0}},	//   панд, _cèke, _koem, _ogs_,
   {{0x2b4b4010,0x7d0d40b4,0x60c980b1,0x2d060045}},	//   _otcc_, joas, _joem, रवेल_,
   {{0x38604060,0x6aa3c107,0x7de24107,0x290dc053}},	//   vair_, _tanf, _kísé, moea_,
   {{0x673559c1,0xa3ac8cbb,0x68fbc2ea,0x78a419c2}},	//   _nizj, गित_, lnud, _waiv,
   {{0xceb284e0,0x7d0d40cc,0x412a05f5,0x957cc062}},	//   עיל_, foas, _локо_, rząc,
   {{0x93464541,0x2b5940f6,0x274800b4,0x673d40a8}},	//   знае, _bwsc_, _pînă_, _busj,
   {{0xb4ca0285,0x6d41c080,0x67354247,0xe73740b4}},	// [1360] ोसी_, lqla, _bizj, зеу_,
   {{0x6fb34032,0x7d1659c3,0x673d4125,0x2ca499c4}},	//   عملا, slys, _dusj, _samd_,
   {{0xbe3b00c3,0xa7fb0019,0xdb044018,0x2a6ac107}},	//   _לעית, maña, uxiñ, óbbi_,
   {{0x684387ad,0x6f0e0089,0x55bb00c3,0x238e48c7}},	//   енца, lobc, _המטו, tējā_,
   {{0x673d46f0,0x753c40cb,0xdb098580,0x3cdd8036}},	//   _gusj, _wurz, _creï, _खतरे_,
   {{0x59cbc48b,0xdb0bc016,0x7b1040cb,0xdea3c09c}},	//   ाहार, _urgè, räus, _tinƙ,
   {{0x60db99c5,0x8af0403a,0x673d415d,0xceb300c3}},	//   _flum, ssəs, _zusj, תיו_,
   {{0xa3cc054a,0x60d64efa,0x2912055e,0x68138036}},	//   लहा_, nkym, _nkya_, _będą,
   {{0xed35859d,0x2002c03a,0x225cc247,0x20050138}},	//   _цэрэ, çki_, _pevk_, ğlik_,
   {{0x7e7e4010,0x64460036,0x26ca4303,0x752419c6}},	//   ngpp, ecki, _jobo_, _ahiz,
   {{0x1bf281f9,0xb4e2c112,0x2606c9f6,0x75240073}},	//   _आइडल_, áàsh, _सुखी_, _bhiz,
   {{0x76454089,0x94208048,0x78a64026,0x55bb80c3}},	//   zchy, _बराच_, _nakv, _למבו,
   {{0xcce5c7bd,0x7d0d4c3f,0xdfd805f5,0x00000000}},	//   _تسلي, voas, пър_, --,
   {{0x691d01cb,0x6125c086,0x65950097,0x2ca6c05e}},	//   céen, gólf, магу, _haod_,
   {{0x6d4acd27,0x629ad9c7,0x44394104,0xb87b59c8}},	//   _utfa, meto, _pgs_, _omít,
   {{0x2a7ec018,0x7afcc04f,0x3d068036,0xfc3f450e}},	//   lgtb_, črtu, षकों_, _baía_,
   {{0x60c9911b,0xfc3f4344,0x47354039,0x68fd0041}},	// [1370] _roem, _caía_, днас, mnsd,
   {{0x60c999c9,0x692ac0a0,0x2d878066,0x291919ca}},	//   _soem, _křes, ytne_, llsa_,
   {{0xddcdc007,0x645f013b,0x60c999cb,0x7d0d59cc}},	//   _įkūr, _keqi, _poem, poas,
   {{0x60c440b3,0x764544c9,0xfaff013b,0x94198051}},	//   cjim, schy, prës_, ожет_,
   {{0x0b4480d9,0xa7fb40b9,0xd366c9ab,0xbea58e97}},	//   енін, _beñe, _جه_, далк,
   {{0x213e8321,0x7c39c1f4,0xe8224045,0x2d8799cd}},	//   _buth_, _sgwr, _मरता_, ttne_,
   {{0x90d5c0d1,0x60c9814b,0x7e61c407,0x3cff8c9f}},	//   _dùn, _toem, valp, _tjuv_,
   {{0x2ca959ce,0x9f5f805f,0x7f4d003a,0xddde0053}},	//   ndad_, áról_, _otaq, _depň,
   {{0xb05b0c62,0x2ca9446a,0x3ea599cf,0x68fbd9d0}},	//   tjän, idad_, _talt_, rnud,
   {{0xab5dc036,0x658a8080,0x657ac0f7,0x1e95cd29}},	//   wyżs, _zəhm, futh, фрир,
   {{0xf771c78a,0x7e61d9d1,0x691359d2,0x692ac047}},	//   راک_, ralp, nçes, _přet,
   {{0xe3e48079,0x66d00041,0xb4f9417e,0x386d8303}},	//   _ফুটব, _läkt, ्कोप_, _jder_,
   {{0xb9158031,0xa7fb0019,0x61e200e2,0x6b8b04c9}},	//   _bibẹ_, taña, _ƙolo, _äggl,
   {{0xed59c1bd,0x66d2410d,0xe8e0c00c,0x78a9d9d3}},	//   _док_, _tæki, ượt_, ldev,
   {{0x0446476b,0xaac4c16a,0x63ad59d4,0x3ce04022}},	//   дебн, _ستون, evan, thiv_,
   {{0x6ee05456,0x26ca59d5,0x1288001c,0x7f4d0085}},	//   _möbe, _sobo_, _کمدی_, _ftaq,
   {{0x59ba19d6,0x442001c6,0x60d64007,0x394d404f}},	// [1380] _उपकर, _uzi_, rkym, _česa_,
   {{0x645f00fd,0x23668158,0x7d09404f,0x6b89c0fc}},	//   _zeqi, vsoj_, česa, iteg,
   {{0x290f99d7,0x6283c070,0x63a9404f,0x2c0ac036}},	//   foga_, _mcno, _šent, _हुईं_,
   {{0x3ea7d9d8,0x3f9fc044,0xeaaf805f,0xdb02d9d9}},	//   _lant_, kwuu_, یٹن_, _troç,
   {{0x394c99da,0x2b7b0052,0x60dd013b,0x98a480a0}},	//   _stds_, ַטקײ, ërmi, _zimě_,
   {{0x7c3b80fc,0xdb09834d,0x3ea7c02c,0x657ac00b}},	//   _egur, _freí, _nant_, yuth,
   {{0x69d847a4,0xfa8ec0d1,0x7c3b81d6,0xdb040060}},	//   øved, _bừng_, _fgur, _eriç,
   {{0x66cf8125,0x6b89c253,0xa6db4086,0x3ea7c206}},	//   _søkt, fteg, _guðb, _aant_,
   {{0xe7ee0d60,0x63a94018,0x7e6380f6,0x6b89d9db}},	//   _चेला_, _áent, banp, gteg,
   {{0xdb0d0018,0x657ac00b,0x03238156,0x3ea7d9dc}},	//   _traé, tuth, _адун, _cant_,
   {{0x38600e89,0x6b960007,0x29190077,0xe3afc01c}},	//   _beir_, _apyg, tlsa_, هری_,
   {{0x386d821b,0xfa8ec0d1,0x6123809d,0x68e281ff}},	//   _xder_, _gừng_, põle, nhod,
   {{0x8c43c661,0x26cc99dd,0x3eba0033,0x0443cdfc}},	//   _рече, _kodo_, _bnpt_, _речн,
   {{0xfc3f4019,0x2cb959de,0x290f81c6,0xd5b0c107}},	//   _caín_, _snsd_, zoga_, _مفت_,
   {{0x20d8c1b4,0xb8e50079,0xfd13451b,0x8caa0285}},	//   _léim_, _এত_, نجر_, _जोको,
   {{0x386019df,0xe7ab8166,0x66dd8303,0x3ea7c0d2}},	//   _geir_, _ďaľš, _mèka, _zant_,
   {{0x44224066,0x2bb1c036,0xb87b0018,0x63ad59e0}},	// [1390] _czk_, जिया, chía, uvan,
   {{0x2126c42c,0x333f8057,0xbf1541b4,0xfc3f0047}},	//   _lhoh_, _ruux_, رواب, zdíl_,
   {{0x644980cb,0x8c9586bc,0x84e804e8,0xaaa80e95}},	//   _pfei, ерлі, _رفیق_, _छोटक,
   {{0x3f8940cc,0x2ca90d31,0x200f40b2,0x3218499e}},	//   ptau_, _jaad_, ügis_, _dyry_,
   {{0x60cd19e1,0x260f55be,0x69d519e2,0x2ca915d4}},	//   _moam, _तुरी_, lyze, _maad_,
   {{0xfa8ec0d1,0x6f020359,0x3cff4011,0xe8044062}},	//   _sừng_, _íoct, čuvu_, _रखता_,
   {{0x6d5c41f4,0x213940fd,0x6285012c,0xe0df4053}},	//   _gwra, _kish_, _mcho, _klò_,
   {{0x78a9c157,0x764ac329,0x4c85d9e3,0x7af500b9}},	//   udev, _affy, хлив, hizt,
   {{0x7d034004,0x58848097,0xa7fb19e4,0x92f5c589}},	//   _ínsu, _шыра, daño, ечні,
   {{0x6b8980f6,0x2bbe84ef,0x26cc99e5,0xa3ac8047}},	//   _iqeg, ्हरा, _godo_, गिर_,
   {{0x3ea7d9e6,0xc6924087,0x2ca901c8,0x78a9c580}},	//   _vant_, נאט_, _baad_, pdev,
   {{0xa7fb046a,0x6d4199e7,0xfc3f4004,0xf1b242a6}},	//   gaño, _iula, _saín_, אסט_,
   {{0x60cd0156,0x291e003f,0xb05b0051,0x26cc99e8}},	//   _doam, ēta_, nkäy, _yodo_,
   {{0x7af51256,0x7769c35d,0xa3ae40e9,0x6b8980f6}},	//   gizt, msex, किस_, _mqeg,
   {{0xf8d3c027,0x60cd19e9,0x628e01ff,0xf2d28052}},	//   _तवाय, _foam, rfbo, נעל_,
   {{0xa7fb0019,0x98a34f27,0x6449d9ea,0x657c002f}},	//   caño, лисе, ncei, rurh,
   {{0x683683a6,0x0326419b,0xfc3f4018,0x7d1bc051}},	// [13a0] _müdü, едан, _taín_, ilus,
   {{0xdb0bc34d,0x629c013b,0x7c240449,0x2ca919eb}},	//   _orgí, qero, _izir, _zaad_,
   {{0x68e28b2d,0x26cc99ec,0x443dc31c,0x7f40803a}},	//   thod, _rodo_, _ogw_, _sumq,
   {{0x68e28047,0x44224011,0x89168a2c,0x27e699ed}},	//   uhod, _tzk_, ربائ, tzon_,
   {{0xc1c880a0,0x7bdd8080,0xfd6500eb,0x68e2851d}},	//   िङ्ग, _üsul, kasị, rhod,
   {{0x63a640b3,0x61054039,0xd00f871d,0x29005243}},	//   _iskn, mėla, حله_, lnia_,
   {{0x6d4199ee,0xdb0bc01d,0x629e4d55,0x7c22d9ef}},	//   _cula, _orgâ, mepo, _szor,
   {{0x61e1409d,0x71f78182,0x7d1bd9f0,0xe876c567}},	//   _ülla, عروس_, glus, راعظ,
   {{0xb09b8093,0xa09b4323,0x657e40f7,0xd10d8371}},	//   _צימר, ליקט, luph, िकरण_,
   {{0x629e4820,0x026ac04c,0x6108c185,0xc66ac051}},	//   nepo, чший_, děle, чшие_,
   {{0x7c2419f1,0x7d02c2e9,0x8cc0c062,0xdd90c1e3}},	//   _azir, _tjos, वादो, جوج_,
   {{0xfbe04027,0x6449c580,0x2ca901c8,0x443dc0bb}},	//   फनाम, ccei, _qaad_, _ggw_,
   {{0x693c006c,0x68e459f2,0x4e161337,0xc7b80030}},	//   _očes, dhid, _दुबई_, нёр_,
   {{0x7c24003f,0x2ca90057,0x21395024,0x44248033}},	//   _dzir, _waad_, _sish_, _mzm_,
   {{0x673a99f3,0x60cd0156,0x62850066,0xf52759f4}},	//   _mitj, _toam, _vcho, ефан,
   {{0x68e459f5,0x62850036,0x5ba700d9,0xd7e74289}},	//   ghid, _wcho, _зроз, нізо,
   {{0xb87b59f6,0x7c24017a,0x317ec09c,0xa7fb59f7}},	// [13b0] _alíc, _gzir, lutz_, _beña,
   {{0x63a2911b,0x68e4412c,0x213940c3,0x9e074119}},	//   dwon, ahid, _wish_, нчел,
   {{0x26cec43e,0x66d24086,0xa49b00d2,0xf53981af}},	//   _mofo_, _rækt, cnòc, _piť_,
   {{0x6101c8c7,0xdb080025,0x63a28127,0x20d1c145}},	//   vēlo, älöi, fwon, _láir_,
   {{0xf77f006a,0x78a9809d,0x673a804f,0xc7a580c5}},	//   nuç_, _vaev, _bitj, тилк,
   {{0x6b8d59f8,0x629e59f9,0xbb528032,0x21290396}},	//   mtag, cepo, جنوب, _lhah_,
   {{0x6d418e2e,0x673a99fa,0xceb403bd,0x2486d9fb}},	//   _qula, _ditj, טיס_, _bcom_,
   {{0x7e6199fc,0xdb1bc018,0x81d4c02a,0x6d4199fd}},	//   _welp, rxuí, _সেভ_, _vula,
   {{0x6d4199fe,0x4794878a,0x6449d9ff,0xafe5da00}},	//   _wula, _مجلس, rcei, топл,
   {{0xccf8c047,0xda679a01,0x29005a02,0x59b30707}},	//   _svět_, _سائي, znia_, ुमार,
   {{0x27e94df5,0x29005a03,0xb895c032,0x417487d8}},	//   hzan_, ynia_, _للاع, _مانس,
   {{0xcb6a047f,0x693c006f,0xe45f0041,0xdb0d0359}},	//   маме_, _očer, sjön_, _draí,
   {{0x06b0c079,0x60dbc12c,0x3327c206,0x62839a04}},	//   _চকরি, mkum, _thnx_, ogno,
   {{0xa01b04d3,0x66d24065,0x249fda05,0x29004064}},	//   tför, _lækr, leum_, wnia_,
   {{0x29125a06,0xa7fb4070,0x45d2c217,0x644d01f4}},	//   toya_, _reña, _војс, _ffai,
   {{0x6d43c02f,0xb903410e,0x68e4421b,0x2eda4047}},	//   _iuna, азск, uhid, णस्त,
   {{0x29125a07,0x3f8dc6ed,0xaa4645bf,0xa7fb5a08}},	// [13c0] roya_, nteu_, везл, _peña,
   {{0x321a1a09,0x39460051,0x98a042bc,0xdfcf41b4}},	//   _typy_, _иног, kmić_, غيل_,
   {{0xa7fb403c,0x7e63c0fc,0x290201c8,0xdca68051}},	//   _veña, _menp, onka_, кажи,
   {{0x443f9a0a,0x385a405f,0x29020397,0x7e63c0b6}},	//   _cgu_, _تشدد_, nnka_, _lenp,
   {{0xa0679a0b,0x29021a0c,0xf8b302a6,0x3eab4051}},	//   тача_, inka_, ישא_, öitä_,
   {{0x98b88303,0x66dd8053,0xc178c007,0x2902009c}},	//   _bură_, _dèko, yrė_, hnka_,
   {{0x4420c039,0xb0e20028,0x673a84f5,0x3f804fc2}},	//   _ši_, _पतंग, _vitj, luiu_,
   {{0x2bb4809d,0x60dbc0ec,0x673c417b,0x661a856e}},	//   ूमदा, gkum, _hirj, _vytk,
   {{0x673a8283,0x7ce60032,0x78abda0d,0x7e63cccb}},	//   _titj, _mórd, _dagv, _benp,
   {{0xb87b0032,0x29021a0e,0x59d20384,0x673a8a26}},	//   thío, enka_, सहार, _uitj,
   {{0x24f9010e,0x27e95a0f,0xc27b421d,0x2ca05a10}},	//   енны_, zzan_, וריי, keid_,
   {{0x2900c007,0x26cec09c,0x9f64c107,0x7e63da11}},	//   čias_, _wofo_, ától_, _eenp,
   {{0x3f8dc016,0x7d0299a2,0x03c58031,0x99624047}},	//   cteu_, inos, _bóṣe, _níže_,
   {{0x78abc011,0x7d029a12,0x6d430396,0x00000000}},	//   _zagv, hnos, _énak, --,
   {{0x60cf4011,0x69c80415,0x661c4025,0x2b448206}},	//   _pocm, ødep, _nyrk, _lumc_,
   {{0x272404c9,0xa3ae425c,0x28c5c314,0x63a45a13}},	//   röna_, किं_, वायि, fwin,
   {{0x673c5a14,0x63b61a15,0x3d0f0027,0x98a04123}},	// [13d0] _birj, _gryn, सवीं_, zmić_,
   {{0x249fda16,0x78ad1845,0x60dd1263,0x439449d3}},	//   zeum_, _haav, lksm, рафс,
   {{0x78ad5a17,0x75298339,0x78ad0051,0x63ba0017}},	//   pdav, _phez, _kaav, ātne,
   {{0x98ad8064,0x63a441d4,0x60dd0039,0xc0ab805f}},	//   _mieć_, bwin, nksm, بائل_,
   {{0x2489021b,0x673c5a18,0xe2998d9a,0x753b8157}},	//   _mcam_, _firj, еал_, _viuz,
   {{0x78ad1a19,0x6135c007,0xd6db84df,0xf41400c3}},	//   _laav, _išli, ьте_, ספס_,
   {{0xfc3fc05b,0x443f821b,0xc33404e0,0xa8a797c9}},	//   žím_, _tgu_, בוס_, _ирак,
   {{0x6d43da1a,0x3ea14834,0x7e63da1b,0x3ce6805b}},	//   _runa, leht_, _senp, chov_,
   {{0x7e63da1c,0xb05b44c9,0x26d14147,0x753d5a1d}},	//   _penp, _knäb, _kozo_, _misz,
   {{0x60dbda1e,0xed59c43e,0xfff684e8,0x26d1591f}},	//   skum, ноо_, _حکمت_, _jozo_,
   {{0x41558217,0x644d4033,0xe8df80eb,0x90e041c0}},	//   _свес, kcai, _ndịa_, _bọ̀,
   {{0x455a80c3,0xdce7c017,0x28c40036,0xf487c217}},	//   _נכנס, ēlēj, षाधि, _јужн,
   {{0x2d8140fa,0x7e63c0fc,0x90e041c0,0x6d4501ff}},	//   huhe_, _tenp, _dọ̀, _auha,
   {{0x877ac052,0x68e2da1f,0x7ce60018,0x776d556e}},	//   _נאצי, _zlod, _sórd, dsax,
   {{0xf3f9c0b4,0x91e30acf,0xdb09801f,0x90e041c0}},	//   daţi_, боре, _ereç, _fọ̀,
   {{0x63a99a20,0x25d6c2a6,0x3ce6804d,0x63b618d5}},	//   _osen, _תוקן_, xhov_, _tryn,
   {{0x63a4415d,0x7981c18c,0x753d5a21,0x212b405e}},	// [13e0] uwin, lulw, _disz, _dhch_,
   {{0x644d492c,0xf3f9c0b4,0x8266401c,0x41aa01dc}},	//   acai, gaţi_, اهان, _звон_,
   {{0x2ca05a22,0x63a45a23,0x68e40047,0xccf9c036}},	//   peid_, swin, _klid, kiś_,
   {{0xf8bf4032,0x63a44127,0x59830289,0x6aa1da24}},	//   _gné_, pwin, _улюб, helf,
   {{0x6aa1da25,0x7981c00b,0x673c40e2,0x6b9b8085}},	//   kelf, hulw, _tirj, _cpug,
   {{0x7d045a26,0x236dc02d,0x7981c18c,0x1a66801c}},	//   lnis, dsej_, kulw, ایای_,
   {{0x236740b3,0x870740b4,0x3ce684c9,0x224ec0b9}},	//   ćnje_, _серв_, phov_, _rffk_,
   {{0x26d15a27,0xd90dc646,0x1c040045,0x3ce68046}},	//   _zozo_, ویل_, रपाल_, qhov_,
   {{0x78a29a28,0x09dcc063,0xe8d780c3,0x98ad8062}},	//   meov, मन्य, _עומר_, _sieć_,
   {{0x78a28043,0x6b80da29,0xb05b4041,0x3f821a2a}},	//   leov, rumg, _knäc, duku_,
   {{0x02d59a2b,0xa3ac8163,0xe3b2c16a,0x78ad1139}},	//   _тютю, गिक_, _گرا_, _paav,
   {{0x3f821955,0x28af0d6c,0x0446da2c,0x7d095a2d}},	//   fuku_, _जोखि, _седн, česk,
   {{0x6442c71c,0xf3ff01ff,0x6b828026,0x8c3d80cc}},	//   _igoi, raão_, nuog, _paşi,
   {{0xf1a6c299,0x79a6c0b4,0x78ad017b,0x7981d63e}},	//   _брин, _брие, _waav, bulw,
   {{0x63a2401e,0x26d15a2e,0x7d045a2f,0x6b8f0010}},	//   çonn, _rozo_, fnis, stcg,
   {{0xd90485d3,0x7d1641c8,0x69dacf37,0xdb044177}},	//   _ری_, goys, myte, bwië,
   {{0x6d450c29,0x3ea140fa,0x2ef550a1,0x78a29a30}},	// [13f0] _wuha, teht_, азар, deov,
   {{0xa3b38b26,0x26deda31,0xa3d883ae,0xc7d7c0c3}},	//   टिस_, nkto_, ाहन_, אומי_,
   {{0x63a9831c,0x62855a32,0xf3f9c119,0x6b9b9a33}},	//   _ssen, rgho, raţi_, _spug,
   {{0x6442da34,0x4c95801b,0xf3f9c0b4,0x62870041}},	//   _ngoi, ридс, saţi_, lgjo,
   {{0x2b46c00c,0xddd08047,0x08780009,0x7afada35}},	//   _nuoc_, _češt, רעדט_, kitt,
   {{0x81b980e2,0xe81ec09d,0x24898036,0x3869c147}},	//   _haɓɓ, _परजा_, żam_, _žar_,
   {{0x645bc820,0x3f821a36,0x6aa1cb44,0xc33401f2}},	//   tbui, zuku_, velf, זוס_,
   {{0x752d025d,0x6d5540fc,0x63a980b2,0x6d44c166}},	//   _nhaz, _itza, _tsen, _čiap,
   {{0xa7fb1a37,0x2b46c00c,0x7981c5bc,0x7afac193}},	//   bañi, _cuoc_, wulw, fitt,
   {{0x2b46c015,0x752d1a38,0x26d30004,0xf8de0185}},	//   _duoc_, _ahaz, _noxo_, मस्प,
   {{0xe4c61a39,0xa2c28707,0xe81c417e,0x98a900f6}},	//   айни, लार्, _भुना_, _ghaċ_,
   {{0xf530c032,0x26dec0f8,0xa49b40b6,0x3866c303}},	//   _فإن_, akto_, _djòk, _geor_,
   {{0x7d1b812c,0x6aa38b32,0x81bd402a,0x661e1a3a}},	//   _mkus, oenf, েনি_, _sypk,
   {{0x644f05f5,0x62871a3b,0x6aa39a3c,0x2d831a3d}},	//   acci, ggjo, nenf, fuje_,
   {{0xa2c440e6,0x27edda3e,0x254cc047,0xacf64217}},	//   रास्, lzen_, _těla_, ачај,
   {{0x68fbda3f,0x6aa380cb,0xdb0f40d2,0x7d09813b}},	//   niud, henf, _arcà, _njes,

   {{0x64440340,0x6d555a40,0x6aa39a41,0x16665123}},	// [1400] _igii, _atza, kenf, ивам,
   {{0x27edda42,0x63a903a6,0x7e565a43,0x9e3a41b4}},	//   izen_, çene, ртац, نساء_,
   {{0x7a7b0087,0x68e9c2a4,0xc8668dbe,0x546a8f77}},	//   _בריס, khed, атли, ваем_,
   {{0x6125c7c9,0x60cd4036,0x409652ff,0xdc34c02d}},	//   dólo, cjam, _трот, _súči,
   {{0xa3e60185,0x7d0980fd,0x33f6801b,0x6aa386bf}},	//   पनि_, _djes, јчес, fenf,
   {{0x212d8157,0x7c298017,0x81b980e2,0x39401789}},	//   _eheh_, _dzer, _zaɓɓ, _liis_,
   {{0x27edc1d4,0x5f090028,0x6b84405e,0x3a3a8041}},	//   ezen_, _सदस्_, luig, äpp_,
   {{0x7d099a44,0xa3b38578,0x78a440b3,0x7643da45}},	//   _gjes, टिश_, neiv, _agny,
   {{0x6440401f,0x6d4081c8,0x6563c085,0x256c81c0}},	//   _úmid, _iima, _awnh, _bólá_,
   {{0x645d0046,0xa3b393ea,0x7afc0149,0x44290561}},	//   wbsi, टिर_, jirt, _rza_,
   {{0x68e9c0f7,0x3866c3bb,0x62870854,0x2a67da46}},	//   bhed, _teor_, vgjo, _denb_,
   {{0x6f188b17,0x69dada47,0x44200f2d,0x6d48901e}},	//   lovc, ryte, _byi_, _iuda,
   {{0x799e0033,0x6d409a48,0x7afada49,0xaca480eb}},	//   _appw, _mima, pitt, _nzọp,
   {{0xa3da454a,0xd7f806fe,0x260f4048,0x6101c017}},	//   ़हन_, рую_, _तुझी_, vēli,
   {{0xaca48044,0x69d84240,0xc1054032,0x75229a4a}},	//   _azọp, øvel, موسي, kloz,
   {{0x9553c1aa,0x7afc024f,0x799e005c,0xdb0d010b}},	//   _بخوا, airt, _dppw, _oraç,
   {{0x692ac185,0x629a806c,0x3f84da4b,0x7e67406f}},	// [1410] _břez, _obto, numu_, _pejp,
   {{0x7afc1a4c,0x7d1b9a4d,0x7d098514,0x454541b4}},	//   cirt, _skus, _sjes, منطق,
   {{0x3f84da4e,0x254cc047,0x27edc107,0x68e9da4f}},	//   humu_, _mělo_, zzen_, yhed,
   {{0xdb0d1a50,0x6d475a51,0x78a44093,0x60c2da52}},	//   _braç, _vuja, ceiv, _nnom,
   {{0x8c3d8119,0x7d1b980a,0x6aa39a53,0x7e67541b}},	//   _naşt, _vkus, tenf, _tejp,
   {{0x63ad0150,0x6125c30d,0x98adc639,0xfaa59a54}},	//   _msan, tólo, rmeč_, сако,
   {{0x68fbda55,0xa3a903fc,0x98a6c02d,0xfa7804e0}},	//   tiud, _गैस_, _choď_, בעות_,
   {{0x7d099a56,0x8c3d806a,0x63ad1a57,0x6125c19d}},	//   _ujes, _başt, _osan, cóll,
   {{0x68fbc0da,0xdb0d001d,0x63ad0536,0xef19c0c5}},	//   riud, _graç, _nsan, лми_,
   {{0x68e9da58,0x06c9cc4e,0x6d409a59,0x6125c019}},	//   shed, угой_, _zima, pólo,
   {{0x27edc05f,0x6d409364,0xdc6a12bf,0xd46a1a5a}},	//   szen_, _yima, ланд_, лине_,
   {{0x03a60dd2,0x6d408d31,0xddc1da5b,0xc1b388b8}},	//   бимо, _xima, galš, ंटीग,
   {{0x3f84da5c,0x386dc36b,0x291dda5d,0x69c10b9a}},	//   cumu_, maer_, _ikwa_, ålen,
   {{0xdc36c009,0x3947c0b4,0xd6dbc143,0x7f4180f1}},	//   _פאסט_, _tuns_, _ште_, _jilq,
   {{0x41b5044a,0x248d80e0,0x09e312bf,0x9c82806c}},	//   остт, _ocem_, порн, ščic,
   {{0xa2da4045,0xe3b20425,0x225f4043,0x6f18856e}},	//   पॉन्, _فرخ_, _đuka_, zovc,
   {{0xa3ab41f9,0x3ce05a5e,0x44200073,0x69dc0e16}},	// [1420] _कैद_, rkiv_, _uyi_, syre,
   {{0x52aa06b1,0xdcfe8089,0x38690140,0xf8bf0e5d}},	//   _свом_, rupč, _zear_, rlée_,
   {{0x41a68036,0xf2df40d1,0x60d6006a,0xfad70052}},	//   _कैंस, _tuân_, _koym, _הויך_,
   {{0xe894811b,0x4fea92bf,0x6d4085d1,0x291dc25d}},	//   іаль, лмен_, _qima, _nkwa_,
   {{0x29069a5f,0x7f419a60,0xa7738589,0xbcb740c3}},	//   rnoa_, _bilq, зліч, _הפכו_,
   {{0xef1f03a6,0x6d5ada61,0x63a9da62,0x3f84da63}},	//   ltür_, ypta, dwen, vumu_,
   {{0x6d409a64,0x216781bd,0x75229a65,0x629c5a66}},	//   _tima, бији_, ploz, _ibro,
   {{0x9f54da67,0x98bc8017,0x386dda68,0x6d409a69}},	//   ович, īvē_, gaer_, _uima,
   {{0x63a9da6a,0x6f189a6b,0x7e6e0017,0x69b882ea}},	//   gwen, povc, kabp, ्मही,
   {{0x2ca69a6c,0x68e2805f,0xd36f81b4,0xd84f4044}},	//   leod_, lkod, _أهل_, _họta_,
   {{0x3991da6d,0x3f84da6e,0x658a8080,0x8c3dd58d}},	//   gás_, sumu_, _təhq, reşa,
   {{0x63a9c491,0x68e29a6f,0xa193c31e,0x39584070}},	//   bwen, nkod, чаюч, _mtrs_,
   {{0x254cc047,0x3f86850e,0x53a3cde7,0x657a0032}},	//   _tělo_, nuou_, _нацб, áthn,
   {{0x7afe40fd,0x3ea5c017,0x61054007,0x6d5ada70}},	//   jipt, celt_, mėli, ppta,
   {{0xf3f980b4,0x61054007,0x305640eb,0x9afbc0c3}},	//   _veţi_, lėli, _ọlụ_, _תפוח,
   {{0x2d73011f,0x24895a71,0x25e08374,0x25bf4011}},	//   rće_, ugam_, _कथनी_, _čul_,
   {{0xa49b0016,0x2ca6809d,0x6bda005f,0x09e14048}},	// [1430] riòd, deod_, _نوٹس_, पन्य,
   {{0xdb09da72,0xb87b0107,0x7c22c17b,0x7afe4359}},	//   rveç, ghív, _myor, gipt,
   {{0x69de468b,0xd5bb41dc,0x63a9c0f7,0x9603002a}},	//   gype, ыса_, zwen, _এরকম_,
   {{0x0cab4457,0xddc3806c,0x63a9da73,0x7f5d00c4}},	//   _стои_, janš, ywen, opsq,
   {{0xa2be0048,0x2d85c140,0xe0d0861e,0x3aeb8125}},	//   शाच्, zule_, عزم_, _løpe_,
   {{0x61054007,0xb5799702,0xb87b0cec,0x394a40c7}},	//   dėli, ащих_, chív, _fubs_,
   {{0x23608017,0x3ce9011b,0x290957b4,0x9987c570}},	//   ģija_, _olav_, onaa_, _žižu_,
   {{0x63a9da74,0x3ea5c0fa,0xfbdf010b,0x29095a75}},	//   twen, welt_, ncês_, nnaa_,
   {{0x63ad810b,0xdb23801c,0x98bec0b4,0xf549c0d1}},	//   çand, _فوری, _sută_, _cấn_,
   {{0x63a9da76,0x237fc056,0x518789bd,0x7c22cc05}},	//   rwen, rruj_, _гуда, _dyor,
   {{0x68fb807a,0x68ed5a77,0xa969c1bd,0xd629c823}},	//   _kmud, khad, јима_, роне_,
   {{0x291dc00d,0x2d85da78,0x6d42da79,0x60d6003a}},	//   _ukwa_, rule_, _gioa, _qoym,
   {{0x6d4ac018,0xfc3f5a7a,0x7d09da7b,0x290941c8}},	//   _eufa, _maís_, mnes, dnaa_,
   {{0x2d85da7c,0x7ce60036,0x442d812c,0x539ac4e0}},	//   pule_, _górn, _mze_, _כינו,
   {{0x3ce90010,0x2d8784c0,0xba39c052,0x98a48007}},	//   _flav_, nune_, _דײַט, _gimė_,
   {{0x3f805a7d,0xa3e99a7e,0xe4520dd8,0xdb041a7f}},	//   triu_, मना_, _غضب_, _prió,
   {{0x2d879a80,0x628a8ccb,0xa2cdcbfa,0x2545c8c7}},	// [1440] hune_, ygfo, ताप्, _vēlu_,
   {{0x2d879a81,0x752445c5,0x68fb9a82,0x3f804fc2}},	//   kune_, sliz, _amud, rriu_,
   {{0x7d1bda83,0x6f1c1a84,0x7d09da85,0x442242a4}},	//   kous, morc, knes, _wyk_,
   {{0x69de5a86,0x7f43da87,0xc7b9c107,0x319ac052}},	//   rype, _linq, kvő_, יבענ,
   {{0x5e588051,0x3ea79a88,0x7d09da89,0x68e98303}},	//   биля_, fent_, dnes, _dled,
   {{0x6f1c0861,0x394a5a8a,0x1c1dc834,0xa3bfc384}},	//   norc, _tubs_, _पड़ल_, ुमन_,
   {{0x2d879a8b,0xe8010036,0x7c22c0c9,0xab5b409d}},	//   gune_, _लेना_, _syor, _prüg,
   {{0x27e04057,0x6aa700b3,0x7c240044,0x3942cc28}},	//   oyin_, zejf, _oyir, öks_,
   {{0xb87b410d,0x68e45a8c,0x6d4ada8d,0xddc540b3}},	//   _slík, ikid, _sufa, mahš,
   {{0x6b8295ce,0x63ad9a8e,0xaefb41c0,0x6d44005e}},	//   mrog, çane, _awùj, _aiia,
   {{0xf6534093,0x7c241a8f,0x9405003a,0x6d44005e}},	//   וצת_, _ayir, ələ_, _biia,
   {{0x7c24084f,0x9c838574,0xa3ab409d,0x4424802d}},	//   _byir, _účtu, _कईल_, _kym_,
   {{0x7b1f801f,0x7f43c580,0x7c240449,0x6f1ac247}},	//   pêut, _finq, _cyir, potc,
   {{0xdb0080fa,0x7ce60ae1,0x050b0079,0x6b828004}},	//   _ermö, _fóro, রতের_, irog,
   {{0x273280b4,0xdb0d401f,0xb4db40d2,0x25478107}},	//   mând_, lvaç, _diàn, _tőle_,
   {{0x8b674032,0x9f6b06b1,0x68e440f8,0x2016001e}},	//   قائم, _кроз_, gkid, écié_,
   {{0x44248303,0x29094057,0x7c2d0449,0x6f1c1815}},	// [1450] _nym_, rnaa_, _uzar, borc,
   {{0x7d1bcad6,0xd25b4404,0x7d00c2a7,0x7d0dc166}},	//   zous, рца_, hims, časi,
   {{0xac588112,0x7649406a,0xa2b2c047,0x6d5a817b}},	//   _ịnụb, _şeys, _असन्, _ntta,
   {{0xd126c865,0xaac94163,0x7d1bc004,0xc237c0c3}},	//   _سم_, राहक, xous, קראו_,
   {{0xa3a7838b,0x61319a3b,0x3ea79802,0x8ccec036}},	//   تحان, jåle, tent_, थानो,
   {{0x059601aa,0x26e38079,0x7d1d1a90,0xb345c01f}},	//   _بایگ, কোনো_, hoss, _liçã,
   {{0x69dcc36b,0x68e9842c,0x7d09da91,0x394480b6}},	//   ørel, _tled, tnes, _fims_,
   {{0x54559a92,0x290b0077,0x442d9a93,0x63ad5a94}},	//   _хват, jnca_, _tze_, owan,
   {{0x63ad5a95,0x3ae9c070,0x629ac17b,0x3ea79a96}},	//   nwan, _aúpa_, ffto, pent_,
   {{0x2d879a97,0x386d8e1e,0x290b1a98,0x61318041}},	//   pune_, _heer_, enca_, såld,
   {{0xaca340eb,0x7d084066,0x3d18049d,0x4990c05f}},	//   _awọd, édsk, नवले_, نیور,
   {{0x7aeada99,0x7cf14ded,0x291d9a9a,0x39440041}},	//   _elft, _hårf, nowa_, öms_,
   {{0xa3ab45da,0x7ce340b2,0x2d831a9b,0xd7ab409d}},	//   _कैल_, _tõrj, erje_, _घैलच,
   {{0x442fc6f9,0x290b1a9c,0xfbd29980,0x399544a0}},	//   _izg_, anca_, עתם_, kås_,
   {{0x26c7cb9b,0x63bbc086,0x7ced001e,0x2ca94032}},	//   _inno_, lvun, _sûre, fead_,
   {{0x27328119,0xa3bd8185,0xf1b28009,0x63ad40cb}},	//   mâne_, ेमा_, עסן_, fwan,
   {{0x3b864026,0x23690085,0x07a347dc,0x7c24084f}},	// [1460] ялаг, _gwaj_, натн, _uyir,
   {{0x8b234051,0x1dbd96ca,0x2fc00077,0x7cea4086}},	//   едуе, ्मात, _irig_, _dýra,
   {{0x63ad40bc,0x6b89c070,0x24554112,0x6b82802c}},	//   awan, hueg, _ụme_, wrog,
   {{0x6125ce84,0x629c0f64,0x273280b4,0xed56c052}},	//   bóli, lfro, zând_, לבער_,
   {{0x26da1a9d,0x2d8a1a9e,0x21269a9f,0x63ad45bc}},	//   _kopo_, lube_, rloh_, cwan,
   {{0x7cfec039,0x99669aa0,0xe45f0041,0x63a416de}},	//   tūro, птил, njör_, _mpin,
   {{0x2d8a1aa1,0x61e1daa2,0x2ca00011,0x6f01c04f}},	//   nube_, jyll, _obid_, dilc,
   {{0x3f508015,0x29021aa3,0x2d981aa4,0x0caac179}},	//   _tàu_, jika_, itre_, стки_,
   {{0x3f6781bc,0x2fc0004d,0xddc19aa5,0x8c53c032}},	//   _нито_, _nrig_, _velš, رئيا,
   {{0xdb0d401d,0x6131836b,0x7c26405c,0x76488007}},	//   rvaç, råle, _mykr, _ugdy,
   {{0x6d4e5aa6,0x10a6c698,0xbc6ac1aa,0x27328119}},	//   _juba, _нижн, _همان_, rând_,
   {{0x9f4e0066,0x386d81c8,0x6e9f0185,0xdb0f4016}},	//   žným_, _xeer_, ख्नु, _escè,
   {{0x254cc185,0x2d78406c,0x6133406a,0x63a2daa7}},	//   _měli_, hče_, nçle, _upon,
   {{0x96d801e7,0x26da010b,0x7d029aa8,0x63bb4018}},	//   नॉलॉ, _copo_, hios, _áuni,
   {{0x4426d3e1,0x06fd8185,0x6b845aa9,0x76550036}},	//   _hyo_, _říká_, erig, rczy,
   {{0x29021aaa,0x63ad5aab,0x2fc01aac,0x79974046}},	//   cika_, twan, _frig_, vtxw,
   {{0x57c6808f,0x2ca95aad,0x9ed95109,0x6d4e5aae}},	// [1470] लमोह, read_, омат_, _auba,
   {{0x399540ac,0xf1b0cc5c,0x386d82a4,0xa2c4442f}},	//   tås_, _जनान, _seer_, राग्,
   {{0x7522daaf,0x6125c30d,0x7d029ab0,0x5faec036}},	//   _okoz, sóli, fios, _जैसल,
   {{0x4426dab1,0x6d465ab2,0x2eec8070,0x6fdcc036}},	//   _oyo_, _gika, _aldf_, यहां,
   {{0x3f8b03a6,0x39954673,0xab5b40fa,0x6b844016}},	//   nucu_, sås_, _drüc, crig,
   {{0xd246c1b4,0x68ed1ab3,0x7522dab4,0xea63405f}},	//   _لن_, _llad, _akoz, _سپری,
   {{0x672192b8,0x7522c0b3,0x29021ab5,0x3ce694db}},	//   _vklj, _bkoz, yika_, bkov_,
   {{0x60d9c149,0x61e1c025,0x8c3d8080,0x3ce681fd}},	//   _qowm, vyll, _abşe, ckov_,
   {{0x7bc080b3,0x78a9c1ae,0x442b800c,0x629c0b5e}},	//   _grmu, reev, _ác_, yfro,
   {{0x29021ab6,0x3f52c015,0xa91d0166,0x6b8b9ab7}},	//   wika_, _dâu_, buľk, mugg,
   {{0xf549c015,0x3dc10022,0x6b8b9ab8,0x4426dab1}},	//   _tấm_, _nrhw_, lugg, _eyo_,
   {{0xddc3c017,0x60db8141,0x63a4c0cc,0x69c19ab9}},	//   _cenš, _joum, _ţine, _irle,
   {{0x26da1aba,0x4426c1ae,0x753bdabb,0xf8bf0019}},	//   _popo_, _gyo_, mmuz, plén_,
   {{0x6d465abc,0x2d8a1abd,0x69c180e0,0x161f0027}},	//   _sika, tube_, _krle, _मुहर_,
   {{0x68ed1abe,0xbb430d29,0x6b845abf,0x6113c0b4}},	//   _flad, терк, wrig, călc,
   {{0x2d8a01c6,0x290dc521,0x6b8b9ac0,0x629c00b1}},	//   rube_, nnea_, kugg, sfro,
   {{0x63a404fd,0x75241ac1,0x2336011b,0x48fd4314}},	// [1480] _upin, _ikiz, _охор, रोधो_,
   {{0x44320459,0x6b8b8004,0x26da0157,0xddc8c089}},	//   _izy_, dugg, _uopo_, ladš,
   {{0x21294f7c,0x7c264036,0x6b845ac2,0x7d029ac3}},	//   blah_, _wykr, srig, tios,
   {{0xfce38495,0x644bc1aa,0x2b47c1f4,0x186786b1}},	//   кохо, _nggi, _linc_, даци_,
   {{0x7d044e04,0x25ad4570,0xa01b04c9,0xdb1b8016}},	//   miis, _ćele_, lgör, _cruï,
   {{0x6459dac4,0x4426c00d,0x3946dac5,0x7d0290df}},	//   _afwi, _ryo_, _sios_, sios,
   {{0x27360065,0x29000051,0x69ca0018,0x3ce69ac6}},	//   mænd_, _omia_, _áfed, pkov_,
   {{0xf9930093,0x60db83bc,0x7cf15ac7,0xdd8f4a1d}},	//   דרה_, _goum, _gård, _خوف_,
   {{0xb7bec079,0x032687bc,0x2d85dac8,0x98be4007}},	//   েন্ট, _ждан, erle_, ūtė_,
   {{0x65c681bc,0x644bd71c,0x98a3c03f,0x3eba421b}},	//   _обза, _eggi, ējā_, ndpt_,
   {{0xe8df800c,0x7529dac9,0xdb044018,0x7522c011}},	//   _hiền_, blez, nviñ, _tkoz,
   {{0x2129405c,0x6723c60f,0x6ba7c4c9,0xf503c0c5}},	//   xlah_, _eknj, örgå, _изхо,
   {{0x7ce3454a,0x4426d31d,0x69c806d5,0x69da01af}},	//   _kõrv, _uyo_, åden, äten,
   {{0x3f8b0165,0x61120017,0x7bc2c024,0xddd8c138}},	//   rucu_, rāla, _irou, _gevş,
   {{0x7d044057,0xdd9400d7,0xf2041aca,0x19941acb}},	//   fiis, кары, вято, каря,
   {{0x7bc2c047,0x403510a2,0x201e00b4,0x6ab8c7fb}},	//   _krou, _пейс, ştia_, _havf,
   {{0x6d5845e5,0x3eb8522b,0x6f039acc,0xb9074045}},	// [1490] ívan, _bart_, yinc, _बक_,
   {{0x39491acd,0x60db9ace,0x0dcb01bc,0x60c99acf}},	//   _hias_, _soum, _думи_, _snem,
   {{0xceb20009,0x60db9ad0,0x305c8044,0xfbd0801c}},	//   _גיי_, _poum, _ịlụ_, یته_,
   {{0xb87b4019,0x7aee5ad1,0x980d402a,0xdb1b80d2}},	//   _clít, _elbt, _শরীফ_, _pruï,
   {{0x60db8004,0xdbd6cc99,0xc7ab87c3,0xf0444051}},	//   _voum, _jääm, تدال_, _аэро,
   {{0x69c1804f,0x2d8cdad2,0x6d4a00c4,0x78ad5ad3}},	//   _prle, kude_, _èfac, leav,
   {{0xa3b38444,0x6b8b83b3,0x7529c206,0xdb0280cb}},	//   टिङ_, sugg, tlez, stoß,
   {{0x6f039ad4,0x3f869ad5,0xa6db4086,0x7cf145ce}},	//   sinc, brou_, _guðr, _hårb,
   {{0x68e48051,0x60dd413b,0x387f817a,0x0b45c1f0}},	//   öide, _mosm, _idur_, ннин,
   {{0x60dd4820,0x7c298dcc,0x78a2c0c7,0x301480b4}},	//   _losm, _iyer, _ebov, _рдур,
   {{0x26dcc498,0x2d8cc54a,0xead480c5,0xb8f5c02a}},	//   _dovo_, gude_, _шофь, _হত_,
   {{0xd756c0fe,0xa107c1aa,0x23cb0021,0x6eedc359}},	//   بلیت_, _غذاه, ामंद, _dúba,
   {{0x13a7c1aa,0x9986c158,0x6b8d434d,0x2cadc1c8}},	//   _آنتی_, čiše_, juag, meed_,
   {{0x2b5f805c,0x60dd4321,0x7ff4cde9,0x7e7501a8}},	//   _mtuc_, _aosm, _جسما, gazp,
   {{0x6da30760,0x3eb84240,0x44291ad6,0x13c84444}},	//   лира, _rart_, _eya_, रम्भ,
   {{0x395e003f,0x69c08b26,0x69dc86ed,0x78bbc09d}},	//   īts_, विती, _àree, nduv,
   {{0x6b8d40c4,0xbb4a44e8,0x290f8010,0x5eb2c02a}},	// [14a0] guag, سلان_, dnga_, জারে,
   {{0x8c1b0093,0xdbdb402e,0xa01b04c9,0x3f86814b}},	//   _מופי, _dààm, pgör, vrou_,
   {{0x2904dad7,0xc486853a,0x3eba405c,0xa3b80fb2}},	//   yima_, елек, rdpt_, छिक_,
   {{0xdb1b8018,0x39490046,0x80ca4079,0x6721c13f}},	//   _druí, _xias_, রসঙ্, holj,
   {{0x4429023b,0x3eb85ad8,0x0a94811e,0xf77243a9}},	//   _xya_, _tart_, валю, _حاج_,
   {{0xa82481aa,0x3f869ad9,0xdd90849f,0x3866979d}},	//   _یکشن, rrou_, لوت_, sbor_,
   {{0x77628018,0xe3d8802a,0x3998dada,0xa2cd4c13}},	//   spox, _দেখব, xés_, सार्,
   {{0x7c2980fd,0xc19b421d,0x7cf14240,0x63b604c9}},	//   _fyer, _משלי, _tåre, _osyn,
   {{0x3eacc095,0x3f8dc6ed,0x2d879adb,0xff06c039}},	//   tedt_, gueu_, arne_, еянн,
   {{0x13f3c051,0xdb974009,0x290680fc,0x877b84e0}},	//   узья, עדיט_, lioa_, _מאמי,
   {{0x69c3c077,0x61360066,0x236740b3,0x3eacc586}},	//   _crne, zále, ćnji_, redt_,
   {{0x26de8360,0x39490046,0x3eae9adc,0x6b8d4033}},	//   _hoto_, _qias_, left_, yuag,
   {{0x69c3dadd,0xe8df8015,0x6d5a0cec,0xf8b3c087}},	//   _erne, _hiển_, ítan, _תשנ_,
   {{0x24800561,0x2fc046bc,0x78a401ae,0x290242c0}},	//   _edim_, dvig_, _ebiv, _amka_,
   {{0x6d584089,0xda208045,0x6aba8d27,0xf1a3c119}},	//   íval, यथित_, _matf, _брын,
   {{0x644d1ade,0x248000f6,0x673e40a8,0x61360089}},	//   _ugai, _gdim_, empj, tále,
   {{0x27e683bc,0x7bc6806f,0x290680fc,0x69d81adf}},	// [14b0] jyon_, _škun, dioa_, _àven,
   {{0x3eae8077,0x3ce940e5,0x798e02c2,0xf09f405e}},	//   jeft_, skav_, bubw, _smàd_,
   {{0x657adae0,0x7b0b4017,0x6b8d5ae1,0x3d954119}},	//   nsth, kļuv, suag, тиер,
   {{0x62954036,0x7bcdc018,0x6c794009,0x2cb94070}},	//   _wczo, _áaug, _קאָפ, _uasd_,
   {{0x69d84af3,0x752d5ae2,0xe9ffc0d1,0x6b8d5ae3}},	//   øver, mlaz, _khải_, quag,
   {{0xfaa59ae4,0x2126c0f8,0x869880c5,0xd6db9ae5}},	//   тако, _akoh_, етът_, яте_,
   {{0x60cd000b,0x5b144748,0x27e68c47,0x2caddae6}},	//   _onam, _смрт, ayon_, teed_,
   {{0x9f52c066,0x27e680e2,0x657ac0b0,0xdbdfc031}},	//   ždým_, byon_, dsth, _fììm,
   {{0x1fcb0048,0xe80109d5,0xe7848448,0x78af00b4}},	//   ामोड, _लेला_, _бухо, decv,
   {{0x2caf81d4,0x7d07c303,0xa2e5c43e,0x2caddae7}},	//   legd_, _bèrè, тоод, seed_,
   {{0xdb098070,0xcc8a001c,0xe4e7c0d9,0x7bc40007}},	//   _ureñ, ونده_, _підн, _sriu,
   {{0xd7d14185,0xf1b24052,0x7d07c01c,0xd00a001d}},	//   समाच, בסט_, _dèrè, деме_,
   {{0x3f894022,0x38694df2,0x6c7a8052,0x69c1093b}},	//   jrau_, dbar_, וארפ, ælen,
   {{0x7d061ae8,0x63a98150,0x6b89dae0,0x6f0d8032}},	//   siks, _mpen, mreg, éach,
   {{0x7c9642b1,0x7cf5c018,0xc69282a6,0xd62706b1}},	//   крац, _cárg, יאם_, воре_,
   {{0x752d5ae9,0x645bdaea,0x442b4036,0x67239aeb}},	//   glaz, ncui, _byc_, honj,
   {{0x41275aec,0x7d041aed,0x3f895aee,0x399a80fd}},	// [14c0] тото_, _imis, grau_, zës_,
   {{0x6133406a,0x2ba9c09d,0x2bb88027,0x7d040085}},	//   rçla, _कहना, _इनबा, _hmis,
   {{0x212dc0c9,0xceb2c093,0x127b0009,0xaefb5aef}},	//   kleh_, שיב_, _קאטע, _awùs,
   {{0x13e60079,0xe8034045,0x216749d3,0x27e683e2}},	//   _পেয়, _रेवा_, тици_, tyon_,
   {{0x29068232,0x3f8f9af0,0x27e68006,0x60238051}},	//   rioa_, gugu_, uyon_, адца,
   {{0x29068232,0x27e69af1,0x7c224283,0x7d02c157}},	//   sioa_, ryon_, żors, _smos,
   {{0x39404007,0x66e3801b,0x290680fc,0x6b89c3b3}},	//   omis_, роја, pioa_, ereg,
   {{0x64a68dc8,0xb9e3811b,0x2d8e80cb,0x6d4bdaf2}},	//   _шаба, ріши, rufe_, _ciga,
   {{0x290481b7,0x0b468dfd,0x399a80da,0x78a28242}},	//   _imma_, _анан, sës_, mfov,
   {{0x672380b4,0x752d5af3,0x6ef4805e,0x6d4bd4bc}},	//   conj, zlaz, _bàbe, _eiga,
   {{0x6d4bdaf4,0x6d5a0086,0xddda8107,0x752441a8}},	//   _figa, ítal, _tető, koiz,
   {{0x3ea987ca,0x645bdaf5,0x7de88031,0x7d02c0f7}},	//   đate_, ccui, _eèsú, _umos,
   {{0x6d584066,0x63a9805c,0x394b4016,0xdb250107}},	//   ívaj, _xpen, _rics_, ősít,
   {{0xd00fc01c,0x6594d3f4,0x39405af6,0x2d588031}},	//   _بله_, _баку, emis_, _kée_,
   {{0x35e40039,0x6d4bdaf7,0x2c585228,0x6f070ee2}},	//   ацтв, _yiga, _ọda_, rijc,
   {{0x8c644156,0x6d4bdaf8,0x6d4e801e,0x3ebcc6bc}},	//   итуд, _xiga, _ébau, _havt_,
   {{0xf54a0015,0xab5d80f6,0xdddc406a,0x752d40b9}},	// [14d0] _cấu_, _arżn, _perş, rlaz,
   {{0x752d5af9,0x7cf5c05f,0x6abc5afa,0x399c4032}},	//   slaz, _tárg, _carf, fís_,
   {{0x6136005f,0x78bb8669,0x8c3dd58f,0x2d58801e}},	//   lála, _pauv, leşt, _née_,
   {{0x5064411b,0x3ebccaf3,0xdb16196a,0x2d911afb}},	//   _втра, _lavt_, _asyè, muze_,
   {{0x6136005f,0x78bb9afc,0x07a58495,0x67239afd}},	//   nála, _vauv, уалн, tonj,
   {{0x3f8f9afe,0xa3c04959,0x8c3dc119,0x2d589aff}},	//   rugu_, ंटर_, ieşt, _bée_,
   {{0x27e95b00,0x10a5c0c5,0x212900e2,0xd49b800a}},	//   lyan_, гийн, _okah_, _ора_,
   {{0x3d02017e,0x7ceec061,0x7cfec026,0x24995b01}},	//   _लगें_, _dùro, kūru, _jcsm_,
   {{0x2d9edb02,0xf771c183,0x6abc409c,0x74c5402a}},	//   ette_, حاب_, _yarf, _একাউ,
   {{0x6d4bc1aa,0xe9d9c299,0x29124853,0x2d911b03}},	//   _wiga, еко_, znya_, kuze_,
   {{0x6605db04,0x6d555b05,0x68ed5b06,0x613880a0}},	//   упна, _juza, kkad, síle,
   {{0x442d9415,0x29124450,0x68ed5b07,0xa879c009}},	//   _kye_, xnya_, jkad, _װאַר,
   {{0x61360d6b,0x7ae1806a,0x7c2d000d,0x69c1c2a4}},	//   gála, _kolt, _cyar, svle,
   {{0xe8d08b26,0x2cbfc54a,0x68ed41c8,0x7c2d1b08}},	//   _सच्च, ldud_, ekad, _dyar,
   {{0x75298b0e,0x68ed4077,0x7d04017a,0x2739c01e}},	//   _okez, fkad, _tmis, gène_,
   {{0xa3b7c275,0xf992c087,0xf54a000c,0x68ed42d7}},	//   _चना_, _הרה_, _cất_, gkad,
   {{0x7c2d1b09,0x3f9fc04c,0x69c75b0a,0xb3480283}},	// [14e0] _gyar, ntuu_, _arje, _agħż,
   {{0x2d911b0b,0x7cf144d3,0x7bcb010b,0x7d09db0c}},	//   buze_, _våra, _água, hies,
   {{0x3f9fc04c,0xdb0d04f2,0xea76c009,0x91e604c5}},	//   htuu_, _grañ, רגער_, _соне,
   {{0x6d5542a3,0x29124056,0x27e95185,0x3cedc04d}},	//   _duza, qnya_, byan_, jkev_,
   {{0x66e6943c,0x7bc65b0d,0xf487805f,0x78a2856e}},	//   лода, _urku, طانی, rfov,
   {{0x29e100e2,0x80a1ce1a,0x7ae19b0e,0x28a6cbc0}},	//   iɗan_, क्से, _colt, क्नि,
   {{0x63b65b0f,0x6f08d48d,0x442d80c3,0x91e35511}},	//   lwyn, vidc, _eye_, _лоре,
   {{0xc448c1aa,0x28ab8028,0x3cedc022,0x61e10176}},	//   نیان_, _टॉपि, gkev_, ølli,
   {{0x7cf5db10,0x3f92406a,0x2126807a,0x9cd740c3}},	//   _bárb, nuyu_, mooh_, רופה_,
   {{0x8c3dc119,0x2126807a,0x3f8b00b3,0x98a04b1b}},	//   veşt, looh_, vrcu_, blić_,
   {{0x23608017,0x97d7c107,0x63b6402c,0x7cf840d2}},	//   ģiju_, نظیر_, hwyn, _gírg,
   {{0x2ca6db11,0x61e580fa,0x212680b3,0x61361b12}},	//   _ubod_, ähle, nooh_, tála,
   {{0x6abe000d,0x0906c05f,0x41b0c314,0xe47bc052}},	//   _bapf, _لڑکی_, _जनकस, _טראכ,
   {{0x272f4107,0x6abe0060,0x38601b13,0xbb83c032}},	//   rünk_, _capf, _efir_, _الوي,
   {{0x5186c23d,0xd13b5b14,0x7e5782a6,0xe801054a}},	//   _сула, еха_, רסלב_, _लइका_,
   {{0x55778009,0x61360107,0xa3c24a7c,0x8c3ddb15}},	//   טעלן_, láln, ्मं_, peşt,
   {{0x98a04b22,0x7ce60070,0xd79540c5,0xf54a00d1}},	// [14f0] zlić_, _vórt, ризъ, _vất_,
   {{0x63ad1b16,0x68e2c834,0x27e95b17,0x442d9b18}},	//   _ipan, _lood, ryan_, _rye_,
   {{0x2bc3008f,0x62850396,0x66280089,0x78bd47ba}},	//   शिवा, _idho, čské, _tasv,
   {{0xd5b8423d,0x43954026,0x2d8cc032,0x7e7ac498}},	//   ысу_, _камс, irde_, hatp,
   {{0xc879c530,0x960d8285,0x67254051,0x3cedc022}},	//   vaş_, िप्ट_, pohj, vkev_,
   {{0x69c38033,0x6b8d47a4,0x2bc786ff,0x6d4f52f8}},	//   tvne, mrag, लिबा, _hica,
   {{0x3ebe8ae6,0x25ac8010,0xd2294032,0x7e77034d}},	//   _datt_, _cpdl_, _شكره_, _mexp,
   {{0x2d934018,0x7ae19b19,0xb385d35b,0xef85c65e}},	//   muxe_, _wolt, алил, алип,
   {{0x98a05b1a,0x62850e81,0x7ae19b1b,0xe0d6c10e}},	//   slić_, _odho, _tolt, рвы_,
   {{0x61360a6e,0xe8df800c,0x3ebe817a,0x2cbf8631}},	//   gáln, _biện_, _gatt_, _haud_,
   {{0x6da5cb8e,0xe80c49cb,0xe5a5cb2c,0x7d09db1c}},	//   шина, _सेना_, шини, pies,
   {{0x6b8d5b1d,0x3325c21b,0xdb09c03c,0x2fc91b1e}},	//   krag, solx_, rveñ, _brag_,
   {{0x3ebe821b,0x61120017,0x2fc9005e,0x5fc940e9}},	//   _yatt_, nāli, _crag_, रिफल,
   {{0x80a1d09f,0x7a40005f,0x394fc06f,0xcb128009}},	//   क्रे, játé, _higs_, ַלן_,
   {{0xd62a1b1f,0x6d57003c,0x6b8d5b20,0xa5464032}},	//   тове_, _cuxa, erag, لضرو,
   {{0x7ae3db21,0xb4665b22,0x2fc91b23,0x386dc397}},	//   _hont, ркал, _frag_, nber_,
   {{0xec4a5b24,0x7cf14ded,0x7d0b814d,0x7306418d}},	// [1500] тзал_, _tårn, digs, апаз,
   {{0x577b0009,0x7bc440b4,0x4439460f,0x7ae3c521}},	//   _שטיצ, rviu, _dzs_, _jont,
   {{0x63ad0077,0x7d0b80cb,0xdcff8047,0x1ea94032}},	//   _zpan, figs, _úvěr, طالي_,
   {{0xa3ba0794,0x7b668026,0x26d15b25,0x2bb6c260}},	//   _घना_, атке, _enzo_, _अनला,
   {{0xe3b2883b,0x3f5bc00c,0x69c89b26,0x6d429b27}},	//   ترا_, _nêu_, _srde, rmoa,
   {{0x7e7c05e7,0x6d445b28,0x68e4068a,0x6d428232}},	//   narp, lmia, _loid, smoa,
   {{0x257c4031,0xf9e9802a,0xf2890052,0xb33b01cb}},	//   _dálá_, _কেবল_, אָפֿ, ntça,
   {{0x1fa6d045,0x3f8dc43d,0x3ebe9b29,0x80a1c4d8}},	//   арог, freu_, _watt_, क्ले,
   {{0x7ae3db2a,0xdfd0c1b4,0x7e7ac580,0xfbc940a0}},	//   _bont, سيد_, tatp, रियम,
   {{0xa2cdc0e9,0x8f9b84e0,0x68e2db2b,0x69c880e5}},	//   ताग्, _בימי, _wood, _trde,
   {{0x80b8cd91,0xd6d7cc4e,0x2d8cc4e1,0x7e7adb2c}},	//   ्यदे, рты_, urde_, ratp,
   {{0xab5b4600,0xe8df8082,0x68f61b2d,0x2ca681f4}},	//   _früh, _viện_, _clyd, nfod_,
   {{0x7e7ac123,0x81c78017,0x4bd7c01c,0x8af98080}},	//   patp, rtēš, _نبود_, bləğ,
   {{0x7e7c1b2e,0x2fc91b2f,0x61360107,0x6d444b35}},	//   garp, _vrag_, láll, emia,
   {{0xbbb6c575,0x60c29b30,0x39584061,0x68f61b31}},	//   _अनुक, kdom, _nurs_, _flyd,
   {{0x629c5b32,0x7ae3db33,0x61360107,0x81ac402a}},	//   _acro, _zont, náll, কটা_,
   {{0x63a29b34,0x6d58c230,0x8af98080,0x2cbf9b35}},	// [1510] jton, _huva, lləş, _raud_,
   {{0xf54a0015,0x63a282a7,0xf8bf41aa,0x443b034d}},	//   _hấp_, dton, _waé_, _izq_,
   {{0x2455821a,0x8af9803a,0x651945d3,0x6d5a401e}},	//   مناس, nləş, _مقدس_, _étal,
   {{0x63bb8033,0x6728c570,0x629c5b36,0xf4879941}},	//   _psun, hodj, _ecro, ружн,
   {{0x63a28aee,0x6d58db37,0x752d0150,0xf8bf1b38}},	//   gton, _luva, _mkaz, llés_,
   {{0x7d0b9b39,0x7cf84359,0x629c4359,0x752d017b}},	//   sigs, _víre, _gcro, _lkaz,
   {{0x7db441b4,0x6728c1be,0x60c0823f,0x60c29b3a}},	//   _وصفا, dodj, _famm, bdom,
   {{0x2d815b3b,0xac94809b,0x7ae3db3c,0x7cf5c55d}},	//   mshe_, _масш, _sont, _bára,
   {{0x6f0d8359,0x69de8125,0x4439cc9f,0xd371801c}},	//   éacs, øper, ås_, _رها_,
   {{0x5ea5cdd8,0x6d444064,0x799503cb,0x26c1091f}},	//   حمدل, zmia, kuzw, _naho_,
   {{0x6d4441f4,0x7e78c077,0x2ba9c54a,0xdbdc402d}},	//   ymia, _devp, _कहवा, všíc,
   {{0x61360443,0x387d81f4,0x3f8dd83f,0x7e7c021b}},	//   rálo, nawr_, preu_, warp,
   {{0x26c11b3d,0x320bc036,0x442fc611,0x21c7835d}},	//   _baho_, ńcy_, _uyg_, _hđh_,
   {{0x6113c0b4,0x6d55c004,0x7529c0a8,0x62874396}},	//   dăli, ízas, loez, _ndjo,
   {{0xd9461b3e,0x68e4054a,0xdbdc405b,0xb995cce1}},	//   _леки, _toid, ršíc, _العب,
   {{0x7d0d5b3f,0x2a785b40,0x4bda4051,0xf8c60066}},	//   gias, _serb_, льзя_, _šéfa_,
   {{0x78b640b3,0x0686473c,0x66eec7f6,0x4aaa56a8}},	// [1520] _čavč, йган, _चकमक_, лкан_,
   {{0xdfcf41b4,0x61360107,0xaad24444,0x7a428107}},	//   عيل_, záll, साइक, níté,
   {{0x0b62c112,0x2a5700c3,0xe3b2401c,0xb4db4016}},	//   _mụọr, _לבין_, _کرج_, _viàr,
   {{0x2fc680e0,0x53a645e4,0x26c11b41,0x2b5940c4}},	//   tvog_, _ламб, _zaho_, _fusc_,
   {{0x09e04079,0x61360fc1,0x213f888b,0x60c09b42}},	//   _যেখা, váll, _dhuh_, _vamm,
   {{0x60c0811c,0xf8bf401c,0xe762db43,0x2ee580c4}},	//   _wamm, _akéh_, _nọọs, _colf_,
   {{0x81e64079,0xceb30093,0xdbf1c047,0x63a45b44}},	//   _বের_, פיה_, _dřív, ltin,
   {{0x92d88079,0x7bcbc011,0x68fbdb45,0xa3bc5b46}},	//   াসে_, _brgu, ghud, _आना_,
   {{0x69c70514,0x20004119,0x60c45b47,0xac18c740}},	//   zvje, nzii_, idim, ропу_,
   {{0x2bc9442f,0x7d09802d,0x7cf5c107,0x2ee5904f}},	//   रिता, _zmes, _vára, _golf_,
   {{0x7d09802c,0x628896fa,0x7ae50d98,0x19f980b4}},	//   _ymes, _iddo, _roht, _кэць_,
   {{0x39400061,0x629e005e,0x79951b48,0x61360107}},	//   _chis_, _acpo, vuzw, lálj,
   {{0x7ae50025,0x69c80329,0x39400d31,0xd7f81b49}},	//   _poht, æden, _dhis_, бур_,
   {{0x6d461b4a,0xd6d70079,0xd765c01c,0x2be5c185}},	//   amka, হস্প, _بنوی, टहरू_,
   {{0x26c31b4b,0x7d0d5b4c,0x60c2c398,0xf54a035d}},	//   rdjo_, tias, _kaom, _tấp_,
   {{0x7cf5c032,0x69c70fc0,0xf8bf0107,0x6eedc0d2}},	//   _lárn, rvje, rlés_, _rúbi,
   {{0x7ae50038,0x60c2c4fd,0x2d8342bc,0x6eeddb4d}},	// [1530] _toht, _maom, _svje_, _súbi,
   {{0x7529c150,0x212b1b4e,0x4e78461e,0x09b24079}},	//   zoez, loch_, محمد_, ঘটনা,
   {{0x80ca83b0,0x7d0d5b4f,0x63a440c3,0x29191b50}},	//   _सोहे, pias, atin, onsa_,
   {{0x24890010,0xfc3f030d,0x63a45b51,0xdce200cc}},	//   _jdam_, nfío_, btin, mplă,
   {{0xdbf1c047,0x29191b52,0x3e4ec03a,0x3f8f9b53}},	//   _přív, insa_, hət_, urgu_,
   {{0x3e4ec080,0x4b7c0052,0x27eddb54,0xa8a7c50c}},	//   kət_, נאוו, vyen_, şmüş_,
   {{0x6d584038,0x6a9c0093,0x7bc7c03f,0x057981b4}},	//   ívat, אשונ, ājum, جمعة_,
   {{0xab65db55,0x6f65db56,0x98a00011,0x29191b57}},	//   овил, овиз, _ikić_, jnsa_,
   {{0x7ae74022,0x7c3b9b58,0xd7fb88b7,0x7b090066}},	//   _kojt, _uzur, _сув_, ržuj,
   {{0xd709c04c,0xe45081b4,0x1309c04c,0x7bdbc057}},	//   рное_, _أضف_, рной_, rxuu,
   {{0x3940004d,0x6b841b59,0x44320051,0x1dd948b8}},	//   _phis_, _svig, _syy_, णमित,
   {{0x7ae740fd,0x2bba4185,0x7e7e4c10,0xb4e84314}},	//   _lojt, _उनला, zapp, _भवे_,
   {{0x63a45b5a,0x386d1b5b,0x6d5a9939,0x6136005f}},	//   xtin, ñera_, _zuta, lálk,
   {{0x29191b5c,0x3ce6c04d,0x68f88017,0x7cfcca5d}},	//   ansa_, _zoov_, īvdi, _pérg,
   {{0xddc3000a,0x3ce6c046,0x6916006c,0x7f5b81c8}},	//   мбри, _yoov_, jšeg, _luuq,
   {{0x463ac009,0x7bcd1519,0x7e7e5b5d,0x61120017}},	//   _דעצע, _frau, wapp, tālu,
   {{0x63bbdb5e,0x2d8300a8,0x7ae74043,0x443200f8}},	// [1540] nwun, asje_, _bojt, _uyy_,
   {{0x80d8008f,0xeb910009,0x60c41b5f,0x20005b60}},	//   यावे, _אָט_, _haim, rzii_,
   {{0x3eb81b61,0x409301aa,0x290f9b62,0x26c35b63}},	//   mert_, _علیر, figa_, _dajo_,
   {{0x2d981b64,0x7cfcc05f,0x290f9b65,0x3eb803b1}},	//   mure_, _kére, giga_, lert_,
   {{0x44209b66,0x3940803f,0x387fdb67,0x87ba8051}},	//   çi_, ķis_, daur_, рует_,
   {{0x7cfcc05f,0x6b845b68,0x3eb81b69,0x141b4093}},	//   _mére, msig, nert_, _כוכב,
   {{0x77699b6a,0xc8ca1928,0x20dd008f,0xbbba454a}},	//   _etex, ियाट, यामध, _उनुक,
   {{0x3e4ec080,0x2480426b,0x7e7a9b6b,0xc0cac6b1}},	//   vət_, naim_, _wetp, руке_,
   {{0xd01284a4,0x69cc008f,0x6d5a8067,0x629c0078}},	//   _غلط_, हिडी, _wuta, kgro,
   {{0xe73a95d5,0x28dd03a8,0x78ad00c4,0x6b845b6c}},	//   _тез_, याभि, _sbav, isig,
   {{0x60c41b6d,0xa01b40cb,0x629ac713,0x212b0166}},	//   _baim, _geöf, rgto, toch_,
   {{0xdb1d4016,0xa3ca49fd,0x2d981b6e,0x7e7c402c}},	//   _essè, लटा_, dure_, _lerp,
   {{0x3eb81b6f,0xdcfb003f,0x212b1b70,0x3e4ec03a}},	//   fert_, gstā, roch_, sət_,
   {{0x7c22c21b,0x212b1b71,0xfbc94281,0x6ef90031}},	//   _ixor, soch_, रिसम, _bìba,
   {{0x41e6d13b,0x2d851b72,0xa8eec185,0x67f1002e}},	//   _філа, éle_, _जवाफ_, _bójú,
   {{0x7ae880b0,0x290f04c9,0x6f00c031,0x2480403e}},	//   _lodt, _öga_, _fábù, gaim_,
   {{0x7d0d1b73,0x31b78275,0x6b845b74,0x2bcdc3fc}},	// [1550] _imas, _आन्ध, gsig, ़िया,
   {{0x629c0321,0xfe7043a9,0x80a704fb,0x387fdb75}},	//   cgro, ندم_, ट्रे, zaur_,
   {{0x7f5b8057,0x6cd54d72,0x3f991b76,0x116a41aa}},	//   _suuq, _فقدا, lusu_, مللی_,
   {{0x60c4003c,0x6367c166,0x6fcdc0aa,0x7afa9b77}},	//   _xaim, nčný, तिमू, _altt,
   {{0x9f35811b,0x7c22c13b,0x628ac02d,0x60da40c3}},	//   педі, _nxor, _odfo, _הקרנ,
   {{0x1fd0c079,0x7d0d1b78,0x6916004f,0x7bc08303}},	//   িহাস, _lmas, pšeg, _dsmu,
   {{0x3f84c017,0xd49b801b,0x7cf84047,0xdcfb0017}},	//   esmu_, _врз_, _mírn, zstā,
   {{0x3f991b79,0x2fcd9b7a,0x8b95c2d5,0x9f4409ac}},	//   kusu_, _treg_, проч, ámú_,
   {{0x3cdf0048,0x3f99006f,0xdcfb0007,0x3ea10032}},	//   गाने_, jusu_, lutė, _ocht_,
   {{0xb87b4018,0x3f86c185,0x7ae8811b,0x68e997fe}},	//   _elíx, _dvou_, _godt, _hoed,
   {{0x80d80185,0x68fb9b7b,0x7cfcc410,0xe8df80d1}},	//   याले, _klud, _sére, _nhịn_,
   {{0x69acc81d,0x443dc036,0x2d981b7c,0xcb0904e0}},	//   _जहरी, _tzw_, vure_, _גל_,
   {{0x60c4117f,0x61361b7d,0x7cf5c107,0x6d49db7e}},	//   _vaim, náli, _járm, mmea,
   {{0x7a210112,0x6d49db7f,0x6113c0b4,0x3eb800cb}},	//   _ịtal, lmea, rălu, uert_,
   {{0x27328156,0x68fb9b80,0x3eb8011b,0x7bcf5b81}},	//   mânt_, _olud, rert_, _arcu,
   {{0x26c59b82,0x613d0857,0x2d981b83,0xc0e35b84}},	//   _lalo_, péla, rure_, носк,
   {{0x2fc01b85,0x3f990189,0x443f9b86,0xaad0c048}},	// [1560] _usig_, cusu_, _nzu_, _थोडक,
   {{0x69cc054a,0x6eeddb87,0x39494007,0xfd1f41c0}},	//   हिदी, _túbu, amas_, _ejì_,
   {{0x6d44024c,0x6d561b88,0xf8bdd077,0xa2d90191}},	//   _khia, _kiya, ्याय, मार्,
   {{0x4fc6839d,0x68e99b89,0x2cafc077,0x40964051}},	//   зска, _coed, _nbgd_, _эрот,
   {{0x92e90646,0x7bcf8018,0x60c645bb,0x6d5e1595}},	//   _طریق_, _ácul, _iakm, _hupa,
   {{0x26c59b8a,0x7e7e1b8b,0x3866c570,0x6459cca0}},	//   _calo_, _jepp, _sfor_, _agwi,
   {{0x7e7e1b8c,0x68e996dc,0x2bb88036,0x6d4401a8}},	//   _mepp, _foed, _इनका, _ohia,
   {{0x361b4093,0x61e11b8d,0x6d5e1b8e,0x7ae38022}},	//   _הולד, älli, _mupa, ajnt,
   {{0xa49b40ce,0x3f991b8f,0xdb0447b0,0xdd908567}},	//   _imòt, xusu_, ttiè, روک_,
   {{0x8626d0f2,0x98b88039,0xfee981b4,0x6d561b90}},	//   зьме, _kurį_, _وعلى_, _aiya,
   {{0xb5ca861e,0x6d42c015,0xdceb491c,0xa50acfd6}},	//   _دوام_, _thoa, _žiča, _лежа_,
   {{0x6d49db91,0x63a4c0b4,0x38669b92,0x7c22c0fc}},	//   cmea, _ţinu, ncor_, _txor,
   {{0x703ac200,0x68e442bc,0x2d87c240,0xe505c3a9}},	//   _اساس_, djid, _evne_, _تبلي,
   {{0x3f82c007,0x6d55c03c,0x7e7e1b93,0x2d9a5b94}},	//   škus_, _ézar, _cepp, kupe_,
   {{0x7f554b0e,0x2561ca6e,0x60c6406a,0xb4bc8048}},	//   _rizq, _gól_, _bakm, _असू_,
   {{0x6d561b95,0x26d840b6,0x7aeac240,0x6d5e08f1}},	//   _giya, _anro_, _hoft, _dupa,
   {{0x6eef8065,0xd00801bd,0x69c5c10d,0xd064803a}},	// [1570] _købt, _неће_, _áher, _ürəy,
   {{0xd7fc00c3,0x7e7e0157,0xd25b40d7,0x68e99b96}},	//   _להחל, _gepp, сца_, _soed,
   {{0x2d875b97,0x6d5e1b98,0x26c581ff,0x2d5400cc}},	//   éne_, _gupa, _ralo_, _oţel_,
   {{0x79854396,0x291901aa,0xa2db4314,0x6ef4805e}},	//   rshw, érah_, नाह्, _hàbh,
   {{0x6d5e1b99,0x3ce0c389,0x6281db9a,0x03a58abe}},	//   _zupa, काने_, yalo, фило,
   {{0x2d51c047,0x61361b9b,0x799ad7b8,0xa49b4321}},	//   _všem_, ráli, kutw, _blòg,
   {{0x6d49db9c,0x61361b9d,0x26c59b9e,0x7ae35b9f}},	//   tmea, sáli, _valo_, öntu,
   {{0x61360c1e,0x6d4a40c4,0x26c59ba0,0x290d81a8}},	//   páli, _èfat, _walo_, _umea_,
   {{0x752f0036,0x6d441ba1,0x7f5f0283,0x25a7815d}},	//   docz, _rhia, _nuqq, stnl_,
   {{0x799ac150,0xca4881aa,0xa49b4053,0x5589c86c}},	//   futw, _کلمه_, _flòg, обом_,
   {{0x112bd2b0,0xddd3c02d,0x6843802e,0x63a4c0cc}},	//   _люди_, ňaže, _fìdí, _ţint,
   {{0x6d440046,0x3eba40fa,0x6eedc019,0x7cf5c107}},	//   _qhia, zept_, _cúbr, _márk,
   {{0xe9dbc01c,0xe8df80d1,0x73e4c0d9,0x99d5c01c}},	//   _گذشت_, _nhọn_, _поїз, ستگا,
   {{0x60c6401c,0x2cadc3ac,0x78bbdba2,0x29125ba3}},	//   _sakm, lfed_, leuv, wiya_,
   {{0x78ad5ba4,0x29125ba5,0x6da31027,0xe9a3011b}},	//   ffav, tiya_, кира, карп,
   {{0x7c240232,0x672e0b61,0x3ce0c17e,0x248d8303}},	//   _txir, sobj, काये_, _ndem_,
   {{0x3eba4119,0xaec65657,0x46ea55a2,0x03260698}},	// [1580] tept_, мбал, одан_, _один,
   {{0xddc89ba6,0x6d5e1ba7,0x68e45ba8,0x7cff00fd}},	//   _redž, _tupa, sjid, _vëre,
   {{0x80a656c0,0x6b899ba9,0x7cf5c05f,0xddc88639}},	//   _छापे, _aveg, _várj, _sedž,
   {{0x31be4047,0x6b838044,0x2d9a5baa,0x3eba5bab}},	//   _vůz_, _ọgar, rupe_, sept_,
   {{0x2ca04010,0x61e104c9,0xb4db4061,0x7a4707b0}},	//   mgid_, ällv, _mhàl, pété,
   {{0x248d9bac,0x78a2d95a,0xdcfc4007,0x416a86b1}},	//   _edem_, _scov, turė, ојим_,
   {{0x3f869bad,0x28cf8028,0xa2db422d,0x387f829a}},	//   ssou_, _सोवि, नार्, _feur_,
   {{0x63a9dbae,0xddc880b3,0x6934c2f0,0x2d8ac077}},	//   ften, _tedž, رکار, šbek_,
   {{0x2004c91c,0x61fd8080,0x7791816a,0x394b0018}},	//   uzmi_, _əsli, _مینا, vmcs_,
   {{0x7cf14730,0x273280cc,0x395e9baf,0x0b438119}},	//   _hårt, râns_, _tuts_, _анун,
   {{0x8e9740c3,0x61151bb0,0x2b585bb1,0xd12fdbb2}},	//   ודיו_, едну, _mirc_, _ах_,
   {{0x799c1bb3,0x3869013b,0x16078db4,0x38cbca87}},	//   durw, _qfar_, _वेटर_, _وانی_,
   {{0x61388f9c,0xa294c93d,0x7cf14041,0x7aeac1e5}},	//   gíli, _залі, _mårt, _toft,
   {{0x6abc1bb4,0xe60fd971,0x06acc02a,0xdbdc0086}},	//   gerf, اشی_, _কোরি, ráðg,
   {{0x799c000d,0x5757c0c3,0xc7c8c0d1,0x518401d5}},	//   gurw, _קבוע_, _hố_, кута,
   {{0xa2d6c027,0x66250017,0xd2580589,0x2ca042c0}},	//   बाक्, _ārkā, ьця_, ggid_,
   {{0x69dc8018,0xf54a00d1,0x62839bb5,0x74150ec0}},	// [1590] _áref, _nấy_, yano, _سودا,
   {{0x8afd80a0,0xddd880ab,0x569447be,0x60c9dbb6}},	//   _kuře, zavš, каут, zdem,
   {{0x6b9d1bb7,0x6ef48060,0x60c9dbb8,0x6edd8048}},	//   lusg, _gàbi, ydem, पासु,
   {{0x2b584010,0x6f15006a,0x628e40f8,0x6b96451f}},	//   _eirc_, lizc, _edbo, bryg,
   {{0x387f8127,0x6b9d197a,0x3f8987b0,0xa2a748bc}},	//   _veur_, nusg, éau_, _चाप्,
   {{0x39595bb9,0x68ebdbba,0xdb1b8032,0x539c0323}},	//   _hiss_, _sogd, _tsuí, קסוא,
   {{0x78bd0588,0x613ec13b,0x6d4d5bbb,0x6ef48060}},	//   kesv, gëlo, omaa, _xàbi,
   {{0x6b899bbc,0x6b9d1bbd,0x61f8436b,0x673ad11b}},	//   _tveg, kusg, øvle, eltj,
   {{0x78bbc669,0x613883bb,0x39595bbe,0x7cf15127}},	//   reuv, xíli, _miss_, _hårs,
   {{0x78a405f5,0x8af0403a,0xddd88158,0x6d4d41c8}},	//   _sciv, qqət, savš, hmaa,
   {{0x68ed0263,0xb4db5aef,0x24800018,0x6d4d4a26}},	//   _boad, _ahàm, _peim_, kmaa,
   {{0x3ce0c08f,0x6abc0378,0x6ef48580,0x62855bbf}},	//   काणे_, werf, _ràbi, haho,
   {{0x6d4d5bc0,0x6abc180e,0xb4db4061,0x6136003e}},	//   dmaa, terf, _chàm, dált,
   {{0x61388fb4,0xb4bc8028,0x62855bc1,0x6d4d4fd7}},	//   ríli, _अस्_, jaho, emaa,
   {{0xe8168064,0x61280530,0x75294158,0x62855bc2}},	//   _देना_, tıld, čezn, daho,
   {{0x07a60e9d,0x6abc1bc3,0x386b405e,0x44395bc4}},	//   _заин, serf, _cfcr_, _bys_,
   {{0x28dd16c0,0x2ca05bc5,0x2bd2c8c0,0x6d59dbc6}},	// [15a0] यारि, rgid_, तिया, _miwa,
   {{0x6d4d5bc7,0x62855bc8,0x7cf5c02e,0x6b964329}},	//   amaa, gaho, _dári, rryg,
   {{0x499a4768,0x2fc04cb8,0x61e104c9,0xe3b20de9}},	//   ятая_, swig_, ällt, _شرک_,
   {{0x2bd2cd22,0xfd6640d1,0xf1c9c0d1,0x3ea140b9}},	//   तिमा, _khuấ, _mạ_, aght_,
   {{0x753bdbc9,0x69c340b0,0xc9530323,0x7cf14854}},	//   dluz, æner, אמא_, _vårt,
   {{0x65619bca,0x2d9c9bcb,0x66e38768,0x7d045bcc}},	//   _bulh, tuve_, лоча, lhis,
   {{0x7cf15bcd,0xfc3f4018,0xb87b0166,0xa2c94045}},	//   _tårt, _icía_, rkíz, _होट्,
   {{0x81b6402a,0x65618396,0xe8b58189,0x273b80d1}},	//   জিদ_, _dulh, mışı, hênh_,
   {{0xd11782a6,0x03268051,0x69dc8077,0x925a801c}},	//   _נקמה_, _здан, _šred, _فشار_,
   {{0x55e680d9,0xe8168314,0x78a29498,0xfaff013b}},	//   _позб, _देया_, lgov, hpër_,
   {{0x7aee4590,0x61361bce,0x29000321,0x644400bc}},	//   _mobt, jáls, _blia_, _azii,
   {{0x62855bcf,0xf1c9c00c,0x6d4d4057,0x7bc65bd0}},	//   zaho, _dạ_, xmaa, _osku,
   {{0x040b4015,0x65619bd1,0x7cfcdbd2,0x78bd1bd3}},	//   _dưỡn, _zulh, _héro, resv,
   {{0x443f4283,0xe8b5806a,0xa2d04185,0xb909c0eb}},	//   _ġu_, kışı, _डोल्, kchọ_,
   {{0x945d8053,0x46ce409d,0x68ed1bd4,0xd5b813a4}},	//   _dańj, _होइह, _toad, нст_,
   {{0x98a50017,0x6d4d5bd5,0xd904801c,0x2eeedbd6}},	//   ēlē_, umaa, _طی_, _hoff_,
   {{0x395949e6,0x101741aa,0x62855bd7,0x2739c5dc}},	// [15b0] _viss_, ربرد, taho, wèni_,
   {{0x3ea14093,0xbebcc03f,0x3ebedbd8,0x8e274de0}},	//   ught_, lnīb, nett_, нфед,
   {{0xa2d0408f,0x60db8018,0xf1c9c00c,0x6d4d40bf}},	//   _डोळ्, _pnum, _xạ_, pmaa,
   {{0xe4e4811e,0xdbe40171,0x6d4d41c8,0x3f7dc02d}},	//   лічн, _béèr, qmaa, yňu_,
   {{0xbea59bd9,0xa2a1c4eb,0xa2dd8185,0x2d9edbda}},	//   валк, _खाल्, पाल्, hute_,
   {{0x26ca5bdb,0x3ebec0d9,0x6b8d0024,0x3f7dc02d}},	//   _gabo_, jett_, _mvag, vňu_,
   {{0xa928180a,0xf2d40052,0x442901ff,0x6d59dbdc}},	//   nažé, טעס_, _lxa_, _piwa,
   {{0x78a280b3,0x62871473,0x2904dbdd,0xed63c5e5}},	//   cgov, hajo, ghma_, _leží_,
   {{0x20095bde,0x26ca5bdf,0x13b48d72,0x62871be0}},	//   nzai_, _yabo_, _مصلح, kajo,
   {{0x7790805f,0x39490c47,0x9e079201,0xdcfc4017}},	//   _ایوا, _ahas_, _пчел, turī,
   {{0x2d9edbe1,0x60cd4007,0x3f8b1be2,0x7d045be3}},	//   gute_, kdam, escu_, yhis,
   {{0xdb1b80fc,0x23dd0045,0xb815c217,0xa3c15be4}},	//   _iruñ, ममंद, _идеј, ंबा_,
   {{0x39490321,0x6608c036,0xdddac089,0x3ebedbe5}},	//   _dhas_, azdk, ratš, bett_,
   {{0x2eeec0f6,0xf1c9c00c,0x62871be6,0xdbdd01c0}},	//   _goff_, _tạ_, gajo, _dáàr,
   {{0x6b8d0085,0x98ad8085,0x63ad5be7,0x3949029a}},	//   _evag, _gieħ_, etan, _fhas_,
   {{0x2eeedbe8,0xa3e18185,0x7fd64176,0x752406df}},	//   _zoff_, धमा_, кізі, _ujiz,
   {{0x6563dbe9,0xccf30093,0xb4db06ed,0xdceac7ca}},	// [15c0] _hunh, _ככה_, rmàt, žiće,
   {{0x60cd5bea,0x26ca4057,0xc7d700c3,0x799e412c}},	//   adam, _qabo_, _יופי_, tupw,
   {{0xa50a43c6,0x1d0a5aec,0xdb0f4018,0x68fbc54a}},	//   _жена_, _жени_, _ascó, kkud,
   {{0x6563dbeb,0x61e10041,0x318c8047,0x6d5b8061}},	//   _munh, ålle, věz_, _ciua,
   {{0x64a39170,0x6d5b812d,0x26ca5bec,0x2d9edbed}},	//   рача, _diua, _tabo_, zute_,
   {{0x09c8c079,0xdd908ec0,0x799e4398,0x7bc28a26}},	//   ষমতা, موت_, pupw, rwou,
   {{0xcec34185,0xdb1b8018,0x69d54064,0x7c298e6e}},	//   ářů_, _cruñ, _grze, _exer,
   {{0xddd8dbee,0xeaff0045,0x6d5b805e,0x68ef4060}},	//   _nevš, _उत्त_, _giua, _xocd,
   {{0x7d034119,0xff06c051,0x3cefc0d2,0xbebcc017}},	//   _înse, вянн, _dogv_, jnīc,
   {{0x2904c46b,0x9af04020,0x69160047,0x6d5b80b4}},	//   shma_, _ƙaƙa_, ušen, _ziua,
   {{0x6b8d1bef,0x5d5501bc,0x248481b7,0x42078f34}},	//   _svag, лкот, _kemm_, _инфо_,
   {{0x26cad2b8,0x2d9edbf0,0x60cbc71c,0x68e9c514}},	//   žbo_, rute_, _gagm, cjed,
   {{0x69d7c018,0x6d4f0060,0x2d9ec0cc,0xd706c2fd}},	//   _áxen, rmca, sute_, _изди,
   {{0xd5b0c1aa,0x6f188066,0x9b45001c,0x2d9a4077}},	//   _هفت_, nivc, انسو, krpe_,
   {{0x3949023b,0x80d88185,0xb909002a,0x6d4ec157}},	//   _thas_, _नोभे, _যত_, _èbas,
   {{0x78a44157,0x6d584157,0x60cd4097,0xdbca82ea}},	//   ggiv, _èval, udam, _hõõr,
   {{0x7c845bf1,0x2b4a44ff,0x7bcdc018,0x62871bf2}},	// [15d0] русе, _bhbc_, _áaut, pajo,
   {{0x26cc848e,0x613d0669,0x6443403a,0x60cd5bf3}},	//   _nado_, déli, ənil, sdam,
   {{0x61280676,0x60cd1bf4,0x63a0c1be,0x14ab408f}},	//   lıla, _kaam, humn, _छापण,
   {{0xf1b3c009,0x28a7c09d,0x7cf5c107,0x69160013}},	//   יסע_, _गाधि, _járt, jšel,
   {{0x61280bd6,0x6d5d5bf5,0x69d54064,0x25f3408f}},	//   nıla, _iisa, _wrze, ूनही_,
   {{0x6d5d5bf6,0xdb00c4d3,0x7cfcc018,0x7d02c141}},	//   _hisa, ntmä, _dérm, _alos,
   {{0x68e9c514,0x60c0dbf7,0xbebcc03f,0x2ca90070}},	//   tjed, femm, znīc, _ocad_,
   {{0x6283dbf8,0xbcfb403c,0x6d5d4150,0x612800b5}},	//   _seno, _diég, _jisa, kıla,
   {{0x26cc9bf9,0x3f42c10d,0x7cff1bfa,0x69dccaf3}},	//   _fado_, rðun_, _përn, åren,
   {{0x63bb9bfb,0x68fbdbfc,0xf1c00066,0xdb1b8070}},	//   _ipun, skud, ášku_, _truñ,
   {{0x7c3d45ce,0x5ed2002a,0x20108026,0x7cf5cc1e}},	//   _lysr, _সকলে, ėlių_, _bárt,
   {{0x5a0c8009,0x60c0c01e,0x63a0c00b,0x60cd1bfd}},	//   _קלאַ, cemm, bumn, _caam,
   {{0x26c14038,0x78a456a9,0x48e0c036,0x7cfcc018}},	//   keho_, vgiv, कारो_, _xérm,
   {{0x6da6000a,0x673501b7,0x3392c1b4,0xa3d24371}},	//   лига, gozj, _الوز, विस_,
   {{0xd6270445,0x62851bfe,0xb176c00c,0x66094047}},	//   горе_, _deho, _trượ, _řekn,
   {{0x60cd0b28,0xbebcc017,0xd5b1435d,0x61280526}},	//   _gaam, pnīc, _ấy_, bıla,
   {{0x6b8d5bff,0xeb974670,0x3ce00053,0x27e6013b}},	// [15e0] gsag, лит_, _iniv_, _çon_,
   {{0x6b9bdc00,0x91e65c01,0x2bc94e18,0x4e36161e}},	//   irug, лозе, रिजा, _معجز,
   {{0x78a444c9,0x7deac080,0x5efac052,0x6d5ec7b0}},	//   pgiv, vəsk, עפעד, _épat,
   {{0xfce64640,0x26cc9c02,0x104a85b4,0x647540b4}},	//   _сомо, _sado_, няли_, _вырф,
   {{0xd12f8032,0xaff5405f,0x75229c03,0xbcfb5c04}},	//   أمن_, _پہلا_, rnoz, _diéd,
   {{0x613d1c05,0x6d5d47cf,0xbb838032,0x51864a1d}},	//   réli, _zisa, حلوي, _مشرق,
   {{0x3ce0c705,0x26cc842d,0x443dcc05,0x29191c06}},	//   काले_, _vado_, _ayw_, yisa_,
   {{0x443dc0de,0x6b9bdc07,0x6d5d4057,0x3fa6838b}},	//   _byw_, frug, _xisa, _مصطف,
   {{0x28e19c08,0x6b9bdc09,0x2aaacaba,0x443dc15a}},	//   फारि, grug, нтно_, _cyw_,
   {{0x63a28150,0x3f14cb8e,0x35b4dc0a,0x2ca913f3}},	//   muon, рдос, абор, _scad_,
   {{0x60cd01b9,0x386984f9,0x6ef486ed,0x0737421d}},	//   _paam, žare_, _fàbr, ראים_,
   {{0x26c1400d,0x7d041c0b,0x443dc1f4,0x7cf5c30d}},	//   zeho_, _clis, _fyw_, _dárs,
   {{0x33f6d2c0,0x8ff7dc0c,0x6b4b4414,0x7cf5c5ca}},	//   _حساس, _مرور_, lüge, _várt,
   {{0xc6bf4079,0xf53f0ded,0x27ff0283,0x59b880ba}},	//   _উচ্চ, slå_, ġun_, _आहार,
   {{0x6b4b40fa,0x290480b5,0x1efbc052,0x7f3bc052}},	//   nüge, _olma_, _אלגע, _רעוו,
   {{0x442b4016,0x6d5d5c0d,0xa3b8c048,0x39405c0e}},	//   _pxc_, _qisa, _चहा_, glis_,
   {{0x24895c0f,0x443dc022,0xd37145a7,0x351c021d}},	// [15f0] raam_, _xyw_, زها_, _רוחנ,
   {{0x75245c10,0x1da8c027,0x2d9c82a3,0x24895c11}},	//   aniz, _कमात, krve_, saam_,
   {{0xfe1ac028,0xf647411e,0x6d4d01c8,0x7deac03a}},	//   _फेमस_, ухан, _khaa, fəsi,
   {{0xba74001c,0x6b8d5c12,0xd7d5801d,0x4fd59148}},	//   _پایت, psag, ижењ, ижет,
   {{0x2b5e805e,0xe28581f0,0x6f1ac6e2,0x4c848589}},	//   _bitc_, алли, kitc, слів,
   {{0x6d4bc09c,0x7cf5c018,0xdb02c03c,0x2d958ff8}},	//   _shga, _nárr, _opoñ, арис,
   {{0x7cff00fd,0xf075c05f,0x3b0680c5,0x256a85ef}},	//   _përl, لیاں_, рещо_, _cùl_,
   {{0x2fd940b3,0x1c169c13,0x386dc061,0x6d5f1c14}},	//   _krsg_, _देवल_, ucer_, _niqa,
   {{0x628a800b,0x63bb8150,0xab5b409d,0x26cedc15}},	//   bafo, _upun, _psüh, _bafo_,
   {{0x28a7c185,0x82f5c1a9,0x7d160047,0x628a8060}},	//   _गावि, рчиц, _smys, cafo,
   {{0x6d4d005e,0xf8c984fb,0x2fcb4451,0x3f8dc580}},	//   _bhaa, _रसाय, _lscg_, sseu_,
   {{0x33d5c12b,0xcb6a11af,0x68ed42d9,0x7cf5ca2c}},	//   _вікт, каме_, jjad, _várs,
   {{0x68ed5c16,0xdee5caf9,0x7d041c17,0x66094047}},	//   djad, _воли, _vlis, _řekl,
   {{0xa8568093,0x394d83bb,0xd6260032,0x0502402a}},	//   יירה_, _lhes_, لعزي, _এদের_,
   {{0x7deac080,0x6d4d005e,0x63a282c0,0x764e8089}},	//   yəsi, _fhaa, zuon, _úbyt,
   {{0x753b8094,0x06cf402a,0x613ec0fd,0x60265c18}},	//   _nkuz, রাফি, tëli, адба,
   {{0x7deac03a,0x06865c19,0x81ccc079,0x1e865702}},	// [1600] vəsi, иган, রমণ_, илам,
   {{0xd910401c,0x96960f27,0x0d861c1a,0x26c30147}},	//   _کیر_, _триш, _клон, cejo_,
   {{0x6f1c1c1b,0x75298451,0x6449810b,0x4a9b0087}},	//   mirc, _bjez, _azei, _בייג,
   {{0x63a283fb,0x60cf41c8,0x443f9c1c,0x07a646fe}},	//   tuon, _gacm, _byu_, _камн,
   {{0xe3b2438b,0x7d1bdc1d,0x60c29c1e,0x2900412c}},	//   _برج_, dius, reom, mkia_,
   {{0xc7d700c3,0x9ea786b1,0x9713831e,0x7cf85c1f}},	//   יוני_, авља_, оміц, _víru,
   {{0x7cfcc694,0x395f9c20,0x95ca9c21,0x63a29c22}},	//   _héri, _fius_, тула_, suon,
   {{0x29005c23,0xdddc4077,0xdca38d32,0x7deac080}},	//   nkia_, _gerš, _маси, qəsi,
   {{0xa2db4048,0x63a45433,0x63a29c24,0xdb00c7b0}},	//   नाच्, nuin, quon, lumé,
   {{0x6d5f1c25,0x3eb8c086,0x65608085,0x29e586df}},	//   _siqa, ýrt_, _himh, rɓar_,
   {{0x3cffc022,0x7cfcc070,0x8ad94052,0x7bcbdc26}},	//   bkuv_, _léri, אַרפ, _esgu,
   {{0x67389b53,0xfce3dc27,0x6f1ac43e,0x25be82c0}},	//   lovj, _мохо, sitc, _iptl_,
   {{0xe6671c28,0x68ed404f,0x6f1c06df,0x60c45c29}},	//   итво, vjad, firc, deim,
   {{0x64409c2a,0x65609c2b,0x28b4c036,0x6566c6b1}},	//   _mymi, _limh, ंभवि, _књиж,
   {{0xfa77c3bd,0x68ed5c2c,0x7cfcc669,0x06cf4079}},	//   _דעות_, tjad, _aéri, রামি,
   {{0x62875c2d,0x3cf5809d,0x69da8142,0x3eac805e}},	//   _sejo, _आवें_, _mrte, _lcdt_,
   {{0x395f8016,0x65688061,0x76b95c2e,0x67389c2f}},	// [1610] _rius_, _ludh, ллар_, kovj,
   {{0x65608e89,0xa857c0c3,0x291b4573,0x752980a0}},	//   _aimh, שימה_, siqa_, _sjez,
   {{0x31354d9b,0xdddc5c30,0x68e2c25d,0x59f900b4}},	//   _генр, _perš, _onod, _сеня_,
   {{0xbcfb4303,0x63a45c31,0x7d1bc004,0x2139013b}},	//   _diéc, buin, xius, nosh_,
   {{0xee87404c,0x75299c32,0x7cff00da,0x24890060}},	//   _выбо, _vjez, _përj, _meam_,
   {{0x2489068a,0x628880c4,0x1dd3809d,0x65609c33}},	//   _leam_, _cedo, थिलत, _eimh,
   {{0x6ef34185,0x32018066,0x7dd04107,0xf4268051}},	//   _výbě, áhy_, rósá, _ääni_,
   {{0x945d81c0,0x7785dc34,0xb4c553ea,0x7af55c35}},	//   _bańt, близ, _एसो_, _hozt,
   {{0x26d15c36,0xdb09c480,0x26178047,0x21391c37}},	//   _kazo_, steí, _भेरी_, dosh_,
   {{0x7d09dc38,0x65688056,0x3cffc64d,0x26d15c39}},	//   shes, _fudh, skuv_, _jazo_,
   {{0x63a4415d,0x7af55c3a,0x2d910036,0x6efd8141}},	//   zuin, _mozt, jsze_, _nèbi,
   {{0x2a730f2d,0xeb9f07fb,0xb0d64d22,0x2fc9414d}},	//   _afxb_, frø_, _ढोंग, kwag_,
   {{0x61e104d3,0x8fc7c301,0x38c8478a,0x78a9d11b}},	//   ålln, _خزان, یاری_, mgev,
   {{0x78a9dc3b,0xa2ad008f,0x84e5c027,0x777bc03c}},	//   lgev, _जाण्, कावट_, mpux,
   {{0x78bb9c3c,0x7d06403f,0x236dc0da,0x76071512}},	//   _obuv, _plks, lqej_, берг_,
   {{0x63a45c3d,0x3c6640d7,0x78665c3e,0x248918bd}},	//   tuin, скаг, сказ, _geam_,
   {{0x26d15c3f,0x6d4f5c40,0x21268011,0xa49b4061}},	// [1620] _bazo_, _dhca, vnoh_, _glòm,
   {{0x2bd5008f,0x26d1434d,0x2619439a,0x29020051}},	//   दिरा, _cazo_, _येही_, lkka_,
   {{0x23690046,0x387fc21b,0xa2ad0e18,0x613d0070}},	//   _zuaj_, kbur_, _जात्, céls,
   {{0x23690046,0x2fc94006,0x78a9c15d,0x2bef002a}},	//   _yuaj_, bwag_, jgev, _চেয়ে_,
   {{0x6d445c41,0x78a9c078,0x24805c42,0xf74695a2}},	//   mlia, dgev, mbim_, бедо,
   {{0x31624033,0x68e2dc43,0x7d1d1c44,0x05d38048}},	//   _hikz_, _snod, ziss, थिंब,
   {{0x68e40171,0xa49b402e,0xfb1b40c3,0x656881c8}},	//   _onid, _amòy, _עולמ, _qudh,
   {{0x656084f8,0x6288801c,0x69da806c,0x60f8c0c5}},	//   _uimh, _wedo, _vrte, рния_,
   {{0x6d445c45,0xe8df800c,0xc00684df,0xe81f8374}},	//   ilia, _nhộn_, _упак, _मइया_,
   {{0x26c5dc46,0x25a5dc47,0x7d029c48,0x628e1c49}},	//   gelo_, full_, lkos, jabo,
   {{0x628e1c4a,0x69da406c,0xfd4d825d,0x21390947}},	//   dabo, _štej, _nchọ, tosh_,
   {{0x07a6d988,0x7f83cc31,0x2d9eca31,0x387fc696}},	//   _гадн, _کلون, rrte_, cbur_,
   {{0x14aa06c1,0xfd4d8094,0xd0e5c914,0xf09f405e}},	//   _कारण, _achọ, कारण_, _blàn_,
   {{0x7d029c4b,0xde58c5dd,0x8ca50045,0xf1c84021}},	//   hkos, _калі_, _काको, रबान,
   {{0x7d1d1c4c,0x7afa04c9,0x41e40e99,0x6442c303}},	//   piss, ötta, піта, _hyoi,
   {{0x63a61c4d,0x628e1b85,0xa2d904fb,0xe81dc314}},	//   bukn, aabo, _फोर्, _बेडा_,
   {{0xc1b58047,0x63a6005c,0x7bcd1959,0xb4db429a}},	// [1630] _अङ्ग, cukn, _usau, _bhàr,
   {{0x69dc5c4e,0x2f0b80b0,0xb4db45ef,0x442740d1}},	//   _brre, _køge_, _chàr, ăn_,
   {{0xd8798032,0x2bcfc8c1,0x24805c4f,0x611580d9}},	//   لمات_, _तैना, bbim_, оджу,
   {{0x26d15c50,0x3ce48019,0x7bdb809d,0xb87b4032}},	//   _wazo_, _cnmv_, _pruu, _inío,
   {{0x7d0d5c51,0xff518de9,0x60c4809d,0x61280080}},	//   mhas, وخت_, õima, xılm,
   {{0xdb0d4032,0x13ba4052,0x26c5dc52,0xaad7c25c}},	//   otaí, _דזשע, xelo_, _भोंक,
   {{0x198680c5,0x442fc03c,0x3f86c053,0xdb0d4032}},	//   общи_, _sxg_, _awou_, ntaí,
   {{0x14d9008f,0x6728c15d,0x8b95dc53,0x27e0c054}},	//   _बोलण, endj, ороч, _šina_,
   {{0x656ac0fa,0x628e1c54,0x212d8303,0x7bdb81c8}},	//   _aufh, yabo, _ijeh_, _uruu,
   {{0x25a5c0fd,0x777bc018,0xef19cacf,0xe299c244}},	//   tull_, rpux, рмо_, јан_,
   {{0x3ce616c0,0x628e1c55,0x26c5dc56,0x6cc61c57}},	//   टाले_, vabo, relo_, ойна,
   {{0x320bc064,0x7bdd4011,0x8afec09c,0x68f60080}},	//   ący_, _orsu, _riƙe, _qoyd,
   {{0x60c6006a,0x752d03e2,0x7af70206,0x20041c58}},	//   rekm, _djaz, _boxt, ámi_,
   {{0x753bdc59,0xb4c9c945,0x6d4441f4,0x7ae3dc5a}},	//   louz, _लघु_, wlia, _unnt,
   {{0x27ffdc5b,0xab19031e,0x39ae803a,0x6d445c5c}},	//   lyun_, сцях_, _həsr_, tlia,
   {{0x26c7935f,0x6d445c5d,0x212d80fd,0x7529c157}},	//   heno_, ulia, _njeh_, nnez,
   {{0xd7ef0032,0x6d5658ec,0x2d87c05e,0x6d445c5e}},	// [1640] _لكي_, rmya, _hwne_, rlia,
   {{0x7643c07a,0xb87b4004,0x752d0881,0x7bcf4070}},	//   _kyny, _unín, _zjaz, _dscu,
   {{0x69c1823b,0x7cff00fd,0x7d029c5f,0xe61a4afa}},	//   _nple, _sëri, tkos, јде_,
   {{0x7643c1f4,0x69de023f,0x7763dc60,0x291fc12c}},	//   _myny, _irpe, _linx, jiua_,
   {{0x7cfcc107,0x7643dc61,0x69de060f,0x6281dc62}},	//   _mért, _lyny, _hrpe, kblo,
   {{0xda1ac09d,0x7c24c11a,0x2ae30036,0x7529dc63}},	//   _फइलत_, _žiro, खाएँ_, enez,
   {{0xf98f854c,0xaa435b49,0x20aa0384,0x80aa0314}},	//   نبي_, _жерл, _कांध, कलाइ,
   {{0x90c39c64,0x673c004f,0x7d0983ad,0x65640051}},	//   _обсе, horj, _gles, _niih,
   {{0x27ffc0f8,0x26c79c65,0x69c18125,0xe4d783be}},	//   gyun_, beno_, _eple, _بوقت_,
   {{0x20d700d1,0x7deac080,0x8af7c080,0xb2b7cda4}},	//   _ủi_, xəss, _şəri, ольф_,
   {{0x64441c66,0x6564017b,0x6728c13b,0x7cfcdc67}},	//   _ayii, _biih, rndj, _séru,
   {{0xa2ad0045,0x7d0d400b,0x38608242,0x6575c107}},	//   _जाह्, xhas, žiru_, ízha,
   {{0x64441c68,0x6800c02e,0xdcf8c017,0x673c1c69}},	//   _cyii, _dájú, ssvē, forj,
   {{0xbcfb4019,0x6281dc6a,0xdb044694,0x7643c02c}},	//   _cién, cblo, quiè, _fyny,
   {{0x2bd2c758,0x7643dc6b,0x69de0077,0x6b448016}},	//   तिका, _gyny, _crpe, gògi,
   {{0x3375474a,0x7bdd46f0,0x92a94036,0xd9049755}},	//   згар, _prsu, kułó, _شی_,
   {{0x3f8740b3,0x629a9c6c,0xdcf3c077,0x673c1c6d}},	// [1650] ćnuo_, _odto, žaće, borj,
   {{0x7945c036,0x7d04417b,0x26c70047,0x61360107}},	//   tówk, akis, _úno_, dály,
   {{0xf0788112,0x9c131228,0x80bcc1f9,0x7d0d5c6e}},	//   _ịgụn, kọka, ्जाइ, phas,
   {{0x27ffdc6f,0x753d1243,0xcdda0009,0x657a0a1d}},	//   yyun_, nosz, _פֿיר, íthe,
   {{0x6281dc70,0x69dec04f,0xf8bf4031,0x69d843db}},	//   yblo, _špel, _ibé_, åver,
   {{0xff7c0052,0xeb969c71,0xa9698b6f,0x7cff06a6}},	//   סטומ, чиш_, бика_, _gërv,
   {{0xf8bf0107,0x3ce7c314,0x753d1a1d,0x7bcd5c72}},	//   tnél_, झाले_, kosz, lwau,
   {{0x25dec1f9,0x9943c06a,0x63a29c73,0x69161c74}},	//   गिनी_, _dış_, bron, nšet,
   {{0xdb09c01f,0x753bc018,0xa49b4321,0x6b504136}},	//   nteç, rouz, _clòi, säge,
   {{0x2904c02f,0x290dc12c,0x05cb00ba,0xf8bf05ca}},	//   akma_, shea_, ाबाब, snél_,
   {{0x7cfcc019,0xbcfb4070,0x7c2dc077,0x27ffc0f8}},	//   _pért, _rién, _žard, syun_,
   {{0x7bcd409c,0xa3cb42ea,0x6444017b,0xd886c231}},	//   kwau, लबा_, _pyii, _فهمی,
   {{0x69de0047,0x60c9c11c,0xbcfb4070,0x14cac01c}},	//   _srpe, meem, _pién, _دهنی_,
   {{0xe7f3861a,0xbb78c107,0x63a9c2c0,0xe689c032}},	//   _आपना_, _بلوچ_, muen, _انثى_,
   {{0xbcfb434d,0x6f18c107,0xcaf48048,0xc27ac4e0}},	//   _vién, _بزنس_, _अवघड_, _פרקי,
   {{0x141a4032,0x2caddc75,0x41b2c032,0xcc8a0ed5}},	//   ميزة_, nged_, _أمير, _убие_,
   {{0x2fcddc76,0x6d408011,0x4426001f,0x68f9c149}},	// [1660] nweg_, _rkma, _ão_, _mowd,
   {{0x63b65c77,0x7af8c04d,0xe8168036,0xae1c854a}},	//   rtyn, _xovt, _देगा_, _भइलन_,
   {{0x63a9c112,0x60c9dc78,0xa3d2c047,0x39468cb8}},	//   huen, keem, _हैन_, tlos_,
   {{0xc8dadc79,0x656ec032,0x8afec0e2,0x6b898536}},	//   _मोंट, íbhi, _miƙa, _bweg,
   {{0xdcf740b4,0x61e14107,0x6721dc7a,0x5f43816a}},	//   şcăr, _álln, kilj, کنول,
   {{0x65665c7b,0x63a446a1,0x61360107,0x2fdf9c7c}},	//   _hikh, mrin, rály, _drug_,
   {{0x8afec0e2,0xe814c045,0x26d80017,0xf8bf01cb}},	//   _niƙa, _तेजा_, idro_, liée_,
   {{0x2caddc7d,0xe01dc036,0xf8bf1b72,0x290780fd}},	//   gged_, _बेहद_, tném_, ënat_,
   {{0x8fa38d00,0x65664bd3,0x7af8c046,0x2a6a4033}},	//   _пате, _mikh, _povt, _kgbb_,
   {{0x69060018,0x65665c7e,0x656e400b,0xe2978119}},	//   _dóem, _likh, _kubh, _нау_,
   {{0xb87b4d04,0x127b8009,0x8afec09c,0xe947c05f}},	//   _sním, _האבע, _ciƙa, _کرلی,
   {{0x628e5c7f,0x656640c2,0x97478011,0x7c2dc9b7}},	//   _lebo, _nikh, rićš, _žare,
   {{0xb90980eb,0x60c0805c,0x60d61c80,0x69160166}},	//   _aghọ_, _mbmm, _daym, všet,
   {{0xa2bf88b8,0x752280c4,0x23650d88,0x6601c56e}},	//   ल्प्, hioz, ölj_, bylk,
   {{0x76bbc093,0x78ad5c81,0xa3d24048,0xb2bbc0c3}},	//   _המופ, tgav, विझ_, _המור,
   {{0x0f0981f9,0x26d80157,0x7cff013b,0x76a2c031}},	//   _वत्स_, adro_, _përu, _fíyà,
   {{0x65665c82,0x6d42c4fd,0x7522990d,0x88bdc036}},	// [1670] _dikh, _mkoa, dioz, liśc,
   {{0x04f98079,0x42751c83,0x78ad5c84,0xdce78123}},	//   _আগের_, _югос, sgav, _vujč,
   {{0xd5b8c03f,0xb9554a23,0x3f8080b4,0x656e4321}},	//   ntā_, _овощ, ţiul_, _cubh,
   {{0x6d42dc85,0xf6504359,0xdb00c0d2,0xdbcc4031}},	//   _nkoa, ائك_, humà, _kòìp,
   {{0x2d985c86,0x335940b4,0xbfa840b4,0x3fc98231}},	//   _evre_, _мамэ_, _нтре_, تدای_,
   {{0x4dc38079,0x69240054,0x656640f7,0x61e14107}},	//   ্মসং, nđer, _zikh, _állo,
   {{0x60c9dc87,0x7d0d1c88,0x62855c89,0x22a341c0}},	//   teem, _olas, mbho, _eékà_,
   {{0x48e80079,0x752d5c8a,0xb4d7c474,0x6b899c8b}},	//   _পত্র, nnaz, ाये_, _tweg,
   {{0x3cf08066,0xb0aec028,0x2d815c8c,0x29078007}},	//   ťové_, _टारग, lphe_, ūnas_,
   {{0xe3ca846a,0x6673c1aa,0x69ce01f4,0x2122021b}},	//   señó_, رگتر, ywbe, wikh_,
   {{0xe81dc09d,0x7bc400fd,0x3cca0c21,0x68e99c8d}},	//   _बेरा_, _spiu, олно_, _kned,
   {{0x68fb9c8e,0x63a9c070,0x26ca075d,0x291dc024}},	//   _joud, puen, webo_, _umwa_,
   {{0xe299c662,0xb8f60021,0x26ca1c8f,0x68fb9c90}},	//   _дал_, _हस_, tebo_, _moud,
   {{0x63a45c91,0xdb23c051,0x6d5bdc92,0x752d5c93}},	//   vrin, äräi, lmua, enaz,
   {{0x2492402f,0x68e99c94,0x60d61c95,0xc7b9c107}},	//   taym_, _oned, _taym, ltő_,
   {{0x26ca1366,0xdb0d40fa,0x68fb9c96,0xdce400b4}},	//   sebo_, traß, _noud, _dună,
   {{0xc7b9c05f,0x224c406f,0x6d440fb5,0x4aae8048}},	// [1680] ntő_, _šdk_, _ikia, _घालव,
   {{0x68e99c97,0x672381ae,0x6d5bc0fd,0x68fb8085}},	//   _aned, jinj, hmua, _aoud,
   {{0x8236005f,0x75d64032,0x3ebe00b2,0x6917c0cc}},	//   _زردا, بيضا, õttu_, nţes,
   {{0x4fc69c98,0x66038064,0x63a45c99,0x68fb801e}},	//   дска, dynk, prin, _coud,
   {{0xe81dd283,0x63ab9c9a,0x39405c9b,0x7afa9c9c}},	//   _बेला_, gugn, mois_, _pott,
   {{0xdee38173,0xdddc0062,0x6b8940b9,0x6603814d}},	//   кочи, karż, _çega, fynk,
   {{0x03675575,0xa50a83e1,0xb4db0060,0x657c5c9d}},	//   _цирк_, _дева_, noàc, _utrh,
   {{0x399b0093,0x63ab9b85,0x6d5bc022,0xe8e000d1}},	//   קיפד, bugn, gmua, _trội_,
   {{0x8fa3cd95,0x6e94c2f1,0x88bdc064,0x99928036}},	//   вање, нипу, wiśc, ódło_,
   {{0x7bc64112,0x6d441c9e,0x7d0d035b,0x6d49c545}},	//   _mpku, _akia, _slas, alea,
   {{0x2d9e00a0,0x1becdc9f,0x2aeb8db4,0x75245ca0}},	//   átel_, जमहल_, चारु_, kiiz,
   {{0x3f42c086,0xa806c448,0x249dc398,0x2eea443e}},	//   gður_, _озел, _gdwm_, _lnbf_,
   {{0x60c2c02e,0x394047b0,0x69c51ca1,0x0cbcc0e9}},	//   _ibom, dois_, _sphe, ्जीम,
   {{0xd703c0c5,0x2124c032,0x6b82841b,0x05c28045}},	//   _изчи, limh_, ipog, _शहाब,
   {{0x3eb9c080,0x2caf90e8,0xdb0d41ff,0x3d0ac031}},	//   əst_, yggd_, ltaç, _jùwo_,
   {{0x657a0107,0x2124c311,0x6ca45ca2,0x6d44005e}},	//   ítha, nimh_, круж, _gkia,
   {{0x6b82806c,0x26d85ca3,0x439455d3,0xf66b0032}},	// [1690] jpog, _baro_, катс, _وحده_,
   {{0x6b8d00f8,0x6d49c0fc,0x68e984aa,0x3ed54032}},	//   _iwag, zlea, _sned, عقار,
   {{0xa3ab44ef,0x70954c85,0x7cf5c1ff,0x9f55c107}},	//   _गमक_, _панф, _várz, égén_,
   {{0x25f44428,0x26ccc044,0x2004c02d,0x98a04062}},	//   ंहजी_, hedo_, kymi_, tnią_,
   {{0xc3cb8a1d,0x60cd5ca4,0x31b8c107,0x2f0b8240}},	//   تظام_, meam, héz_, _døgn_,
   {{0x6b8d0536,0x26ccdca5,0x26d85ca6,0x6b5044c9}},	//   _mwag, jedo_, _garo_, lägn,
   {{0x200992ae,0x2367c0fd,0x68fb8141,0x69dcc240}},	//   šai_, _rinj_, _toud, ærel,
   {{0x68e981f4,0xfd64c0eb,0x7afc4232,0x2367cf26}},	//   _uned, _ikwụ, _zort, _sinj_,
   {{0x349487ad,0x6b8d1ca7,0x249f817a,0xafe5c289}},	//   _шатр, _nwag, _idum_, хопл,
   {{0xfbd24093,0x2120005c,0xfaf1c032,0x6b9b800d}},	//   נתי_, _smih_, اثة_, _ivug,
   {{0xe126024b,0x69261ca8,0x7c294077,0x64dac048}},	//   емни, емна, _žerl, _मोकळ,
   {{0x63ad5ca9,0x70aa1543,0xbcfb4396,0x6b8d018b}},	//   kuan, कलेल, _diék, _bwag,
   {{0x60cd5caa,0x26ccc019,0x60dbdcab,0xe3b20446}},	//   deam, bedo_, mdum, درج_,
   {{0xfd64c112,0x63bbdcac,0x6ec141ac,0x6b9b81c6}},	//   _okwụ, mtun, र्मु, _mvug,
   {{0xf2d28009,0x75d3803a,0x2bde025c,0xfd64c044}},	//   װען_, _bəzə, मिहा, _nkwụ,
   {{0x644100fa,0x60cd5cad,0x6d44012c,0x68fd4061}},	//   ßlic, geam, _ukia, _cosd,
   {{0xb4cc008f,0x4fa34def,0x6b8d1cae,0xa6e64030}},	// [16a0] रजी_, литв, _gwag, нжал,
   {{0xdbc6c54a,0x2cbfcb0e,0x386d9caf,0x249f8085}},	//   _tööa, hfud_, _ager_, _adum_,
   {{0x248680b3,0x7bde8017,0x6449802e,0xfbdf40d1}},	//   tbom_, āpum, _ayei, _uyên_,
   {{0x397ac052,0xe4dfc0b2,0xa2c14ebe,0x22a6c171}},	//   לטענ, _खोलि_, र्ब्, _kíkà_,
   {{0x60c41989,0x26da1cb0,0xd12f9438,0xe8df80d1}},	//   _mbim, _kapo_, حمن_, _chốn_,
   {{0x8afec020,0x6d4b9cb1,0x26da1cb2,0x7afa04c9}},	//   _riƙo, alga, _japo_, ötth,
   {{0x2fc6c14b,0x6b9b80bb,0x7d09c09c,0x13c9002a}},	//   _spog_, _evug, fkes, শিয়,
   {{0x60dbc2a7,0x91bb40c3,0x290fc061,0x8d738107}},	//   gdum, _ממלי, _clga_, داوا,
   {{0xef1a83d5,0x5ce3c051,0x27e052e2,0x25af4036}},	//   _ема_, ующа, nvin_, ągle_,
   {{0xb4db4031,0x6d5d0022,0x6b8d01c6,0x0bb740c3}},	//   _akàl, wmsa, _rwag, עלים_,
   {{0x62951cb3,0x63bbdcb4,0x6d40dcb5,0x60cd412c}},	//   vazo, atun, poma, yeam,
   {{0x26ce9bac,0x6d4640f8,0x7c29406f,0x386d0240}},	//   lefo_, _nkka, _žerm, øer_,
   {{0x26da0140,0xdb0b8588,0xd4981cb6,0x6d5d1cb7}},	//   _bapo_, stgå, эрэ_, rmsa,
   {{0xe6671198,0x60c4011c,0x3205c0a0,0x25750125}},	//   етбо, _ebim, byly_, _pål_,
   {{0x68fd5cb8,0xb9254032,0xa2a9809d,0x692b00a0}},	//   _posd, نفسي, _घाघ्, třed,
   {{0x2d8300a8,0x2ca001d6,0x60c401c0,0xa4d440d9}},	//   rpje_, _gdid_, _gbim, лосі,
   {{0x60cd5699,0x070945a7,0x27e048f2,0xb0aec17e}},	// [16b0] ream, ويري_, gvin_, _टाईग,
   {{0x63af01be,0x290957b4,0x6b520065,0xdddc4011}},	//   mucn, skaa_, lægn, _derž,
   {{0x27e48303,0x692b0047,0x7dc4005f,0xfb1c00c3}},	//   _armn_, před, _یقین, _מוזמ,
   {{0x237f9cb9,0x63bbdcba,0xc0ab4032,0x68ed0085}},	//   _ptuj_, ytun, _عاجل_, _jnad,
   {{0x60dd1cbb,0x24895cbc,0x26da012c,0x68ed1cbd}},	//   idsm, mbam_, _yapo_, _mnad,
   {{0x7d09dcbe,0xf7740087,0x2f140041,0xa49b5cbf}},	//   wkes, אקס_, _vägg_, _glòr,
   {{0x6b448016,0x8f34411b,0x6d464086,0x98c789f8}},	//   tògr, _серц, _ykka, _псал,
   {{0x672700b3,0x68ed1ca7,0x6d4d5cc0,0x62975cc1}},	//   hijj, _nnad, nlaa, laxo,
   {{0x1fbdcfb2,0x6b9b800d,0x7d0340b4,0x98a040ab}},	//   ्बेड, _uvug, _însu, snić_,
   {{0x7522dcc2,0xf8aa06c1,0x2d9e0047,0x6d4d5cc3}},	//   _emoz, कल्प, átek_, hlaa,
   {{0x68ed01d6,0x764ac1f4,0x2701c027,0x39421cc4}},	//   _bnad, _cyfy, _लकीर_, toks_,
   {{0xeb9a1cc5,0xbcfb401f,0xa2c14a89,0x2d478fc2}},	//   мим_, _fiéi, र्त्, mões_,
   {{0x7d06c04c,0x672700b3,0x6d4d41c8,0x395fdcc6}},	//   ökse, fijj, dlaa, mmus_,
   {{0x656bdcc7,0x63a9c6a1,0x60db9cc8,0x2be04794}},	//   _high, mren, _laum, निसा,
   {{0x6b9bdcc9,0x60c4005e,0xd62a1cca,0x6d4d5ccb}},	//   lsug, _tbim, фове_, flaa,
   {{0x394dcad6,0x44394060,0x63af00b4,0x657c8107}},	//   nles_, _bxs_, bucn, _érhe,
   {{0x2d47801f,0x26c58157,0xe3ba46fe,0x63a9dccc}},	// [16c0] hões_, _oblo_, ьба_, nren,
   {{0x6b845ccd,0x63a9dcce,0xdb00c080,0x7d1ec107}},	//   rpig, iren, rumç, épsz,
   {{0x656bc92c,0x6d4d5ccf,0xdb1d40b0,0x6b844ccb}},	//   _oigh, blaa, _opsæ, spig,
   {{0x6b8458c1,0xdcfec03f,0x2d47801f,0x6d4d41c8}},	//   ppig, īvīb, dões_, claa,
   {{0x60db9cd0,0xd4679cd1,0x752400bb,0x20565281}},	//   _daum, вице_, _mmiz, _штор,
   {{0xde58811e,0xa2c148c4,0x62974018,0x6d59cf2d}},	//   налі_, र्द्, caxo, _ahwa,
   {{0x26c580b9,0x2a354156,0x2912040d,0xe8df835d}},	//   _dblo_, _бэтр, _olya_, _chồn_,
   {{0x31604053,0x3ced806f,0xa2a20759,0x66035cd2}},	//   nmiz_, _gnev_, कृत्, änke,
   {{0xdb044018,0x31bc4070,0x50469702,0x44394253}},	//   ltiñ, líz_, _реаб, _xxs_,
   {{0x86ea8032,0xed598123,0x9bb78323,0x14aec048}},	//   _تعرف_, _zhž_, _בהמה_, _टाकण,
   {{0x4c9514cf,0x395fc022,0x656bc0c3,0x60cf0018}},	//   линс, bmus_, _figh, tecm,
   {{0x29000160,0xd026c0c5,0x75240011,0xdb044018}},	//   _coia_, _имей, _cmiz, itiñ,
   {{0x7ff3c6b0,0x3944c007,0x290000b9,0xeb97c156}},	//   _نسوا, moms_, _doia_, _аич_,
   {{0x63bd1cd3,0x629a10ec,0x27e6dcd4,0x7d009cd5}},	//   rtsn, ótop, _iron_, _loms,
   {{0x6e9412e5,0x9f4480fd,0x24784efc,0x6b5200b0}},	//   рису, _armë_, _ọma_, mægl,
   {{0x0dc7cb7d,0x62989cd6,0x2bf38048,0x6d4447f3}},	//   _руши_, havo, _आपलं_, goia,
   {{0xe8d90015,0x2d7800b3,0x69da5cd7,0x257180ab}},	// [16d0] _nhỉ_, _učen_, _štep, _išle_,
   {{0x395fccec,0x59ce0c63,0x61e10041,0x752405e5}},	//   zmus_, _हैकर, ålls, _zmiz,
   {{0x63a481b4,0x2d810339,0x78a2c166,0x395fdcd8}},	//   áinn, _uthe_, _odov, ymus_,
   {{0x2900003c,0x26dcdcd9,0x7d164066,0xa3d2c54a}},	//   _xoia_, _lavo_, chys, _हईं_,
   {{0x7d0085ce,0xfd565cda,0x443f4015,0x351c0087}},	//   _doms, _תשרי_, _âu_, וואנ,
   {{0xf1c7008f,0x69cac0cb,0x78a2c0d2,0x7c2dc147}},	//   _लहान, _opfe, _adov, _žaro,
   {{0x2d948039,0x656bc728,0x6b82dcdb,0xbcfb4396}},	//   арыс, _pigh, _atog, _diév,
   {{0x693c98ca,0x3ea99cdc,0x394ddcdd,0xdb028086}},	//   včeg, şat_, ules_, stoð,
   {{0x62989cde,0x395fdcdf,0xb87b4018,0x7cd48036}},	//   bavo, rmus_, _uníu, _wśró,
   {{0x6b9bdce0,0x6d4457f2,0x394ddce1,0x29001ce2}},	//   rsug, zoia, sles_, _soia_,
   {{0x2129421b,0x2bd8c027,0xaaab4285,0x31604e05}},	//   kiah_, _बैठा, _चयनक, ymiz_,
   {{0x62955ce3,0x6f019ce4,0x6d5cc157,0x81cc002a}},	//   _lezo, _holc, _èrap, লিম_,
   {{0xef2842d6,0x3cefc0c4,0x290000b4,0x6f018062}},	//   lmüş_, _ingv_, _voia_, _kolc,
   {{0x26dcc007,0x6723c123,0x6b4d81ff,0x63ab8359}},	//   _gavo_, _umnj, fúgi, irgn,
   {{0xdb26c018,0xdb04410b,0xf8bf001e,0x6f018ad3}},	//   _ápáx, luiç, gnés_, _molc,
   {{0x60dd5ce5,0x9f4000d2,0x53b7c1f9,0xfbd8c062}},	//   _casm, _triï_, _आमाश, _बैडम,
   {{0x2d8340da,0x2f164065,0x7d0084f5,0x60dd40fd}},	// [16e0] _atje_, _læge_, _roms, _dasm,
   {{0x7d009ce6,0xf063521f,0x8a3a4051,0x945dc036}},	//   _soms, скуп, няет_, leńs,
   {{0xa3b6808f,0x2fcb4570,0x290dc051,0x7e564156}},	//   चून_, _epcg_, kkea_, утац,
   {{0x19b6c052,0xc955859d,0x2bac44ef,0x6728dce7}},	//   טפער_, атчы, _चिपा, zidj,
   {{0x25788396,0xdcfc841b,0xda7a8007,0xac979546}},	//   _sél_, _utrč, няй_, انها_,
   {{0xdd1d4047,0x53349025,0xe4570323,0xf8bf0211}},	//   dářs, јект, ניסט_, nnér_,
   {{0x6d5b84ff,0x2fc05456,0x2b07c185,0xdb1bc01e}},	//   _fhua, ltig_, ाउनु_, ctué,
   {{0x6d461ce8,0x60c44141,0x629540c2,0xdb09c14b}},	//   joka, nfim, _zezo, breë,
   {{0x46b6883b,0x29025ce9,0x2578815d,0xa2c14db4}},	//   _محاس, _moka_, _wél_, र्व्,
   {{0x59dc8185,0xfc4ac031,0xf77fc10b,0x2480001f}},	//   _मनपर, _akíó_, íça_, _afim_,
   {{0x6b840449,0x290dc654,0x72068032,0x2fc051e6}},	//   _atig, bkea_, _حوام, htig_,
   {{0x78a2dcea,0xa84ac1b4,0x290dc070,0x6d461ceb}},	//   _udov, _كلام_, ckea_, goka,
   {{0x6d44c039,0x31d14047,0x7d0d5cec,0x6f01806a}},	//   čiad, _सन्ध, vkas, _yolc,
   {{0x59b88742,0x3dc64036,0xdb1ec041,0xe0df4053}},	//   _इमार, łowy_, övän, _ekòl_,
   {{0x7d0d5ced,0x290244e6,0x627bc3bd,0x65951b04}},	//   tkas, _boka_, _אנונ, рабу,
   {{0x257182a3,0xfd4cc02e,0x7d02dcee,0xa7750179}},	//   _ušle_, _ailẹ, _joos, _клич,
   {{0x2d9ece9c,0x6d5b804d,0xf09f45ef,0x29190510}},	// [16f0] lste_, _rhua, _blàr_, mhsa_,
   {{0xf09f44ff,0x7bcd181f,0xeb9f0af3,0x61e89cef}},	//   _clàr_, _ipau, msø_, _ordl,
   {{0x69da8085,0x6d5b823b,0xdc438047,0x764e42cd}},	//   _nste, _phua, _véčk, _cyby,
   {{0x6d5b824c,0xd0118032,0x19b7c009,0x2129421b}},	//   _qhua, يلا_, רפאר_, qiah_,
   {{0xbcfb5cf0,0x7529dcf1,0xab5b4060,0x6d5d5cf2}},	//   _diét, viez, _aqüe, _ihsa,
   {{0x212b1cf3,0xde058aba,0x945dc064,0x8afec09c}},	//   hich_, ипли, zeńs, _fiƙi,
   {{0xe8d90082,0x629adcf4,0x41e45cf5,0xbcfb403c}},	//   _chị_, dato, _літа, _chég,
   {{0x26d34c5a,0x2be28428,0x656f412c,0x7c3b81a8}},	//   lexo_, पिशा, _jich, _txur,
   {{0x7bcd024c,0x80de0079,0x7529dcf6,0x7d02dcf7}},	//   _npau, যাম্, riez, _doos,
   {{0xd709c051,0x2d9ed69b,0xdb044fc2,0xa1c5c0d7}},	//   тное_, fste_, ruiç, абод,
   {{0xe8d90112,0x7d02c1c8,0x6937406f,0x2d91c1cb}},	//   _ghị_, _foos, vćen, èze_,
   {{0xf8661cf8,0x7d02dcf9,0xd9461cc5,0x61460949}},	//   ивно, _goos, реми, рема,
   {{0xd45601bc,0x9cd68093,0x2fdb0085,0x4ac65cfa}},	//   ртнь, בורה_, _csqg_, र्डव,
   {{0x657700fd,0x629adcfb,0x26de80d2,0xb05b0d42}},	//   _buxh, cato, _xato_, pfän,
   {{0xc89644ee,0x395dc23b,0x6f03c1b4,0x78bb8a18}},	//   ирањ, _khws_, _ionc, _ocuv,
   {{0xac864d37,0xbcfb0107,0x2a3ac0c3,0x7bdb9cfc}},	//   ргал, lmén, _בעצמ, _osuu,
   {{0x8b26410e,0x216748ce,0x60c45cfd,0xd0074897}},	// [1700] адае, рити_, rfim, аете_,
   {{0xdb0603a6,0x6f03c7b0,0x6297014d,0xdb044025}},	//   dukç, _jonc, _gexo, htiö,
   {{0x2bde0ebe,0xbcfb41cb,0x69c1dcfe,0x690340b2}},	//   मिका, _piét, ntle, _tõep,
   {{0xbcfb5cff,0x49734039,0x3fe68217,0x6982025d}},	//   _diés, іліс, ижев, _ọgwụ,
   {{0x69c1c09d,0x629ad42a,0x39469d00,0xbcfb4303}},	//   htle, yato, roos_, _dhéd,
   {{0x2d9edd01,0x3ce0023b,0xdb1d005f,0x0cd31d02}},	//   yste_, _laiv_, ttsé, _तस्म,
   {{0x6da35d03,0x6028c017,0x629c0004,0x26de8147}},	//   _мира, zīmī, iaro, _vato_,
   {{0x5bb8dd04,0xbcfb5d05,0xd9439d06,0x9ccac0d7}},	//   глия_, _hiér, _деси, тыка_,
   {{0xaac644fb,0x02c64314,0xe0df40b6,0x6f03dd07}},	//   र्थक, र्थभ, _chòy_, _bonc,
   {{0x7bc0dd08,0xada6811b,0x69c1dd09,0x68e296e6}},	//   rtmu, _важл, ftle, ldod,
   {{0xbca6c1aa,0x0f574093,0x68e08daa,0x212b1d0a}},	//   _نماي, שיים_, _kamd, tich_,
   {{0xf8bf5d0b,0xd7e6c0d9,0x63ad9d0c,0x7d1602cd}},	//   _amén_, _віко, šane, _clys,
   {{0x3ce00022,0xdc54c0fb,0x62970004,0xa3dcc891}},	//   _daiv_, _اراک, _pexo, डिओ_,
   {{0x2d9edd0d,0xa3ae8260,0x28df4285,0x8afec09c}},	//   pste_, _किन_, _पोजि, _riƙw,
   {{0x7cff013b,0x257c00a0,0xf527423d,0xe8d9035d}},	//   _mërz, _cíl_, афан, _giở_,
   {{0x79690064,0x257c0047,0x6298c051,0xf993c0c3}},	//   _oświ, _díl_, _hevo, _ורק_,
   {{0xd371400f,0x69dc5d0e,0x645cc080,0x26d34004}},	// [1710] سها_, _asre, əric, texo_,
   {{0x67ca403f,0x1ddac036,0x8aa70ecc,0xceb8c007}},	//   dējā, _बनात, _трид, ngę_,
   {{0x29049d0f,0x3ce00022,0x25718011,0x26d3403c}},	//   _boma_, _yaiv_, _ošla_, rexo_,
   {{0x7de0805f,0xdb16405f,0x3ce0024c,0xa3ce0374}},	//   zásá, rtyá, _xaiv_, _रहम_,
   {{0x3949403c,0x3ea580d2,0x6d4d02c0,0xe0df0580}},	//   moas_, _pdlt_, _mkaa, llòs_,
   {{0xc72480d9,0x2bac46fc,0x43944dc8,0x11678231}},	//   одій, _चिता, _фарс, _چلسی_,
   {{0x212901aa,0x51845d10,0xdb044051,0x7de08107}},	//   _omah_, _мута, ttiö, vásá,
   {{0x657a0032,0xba3800c3,0xd5b88027,0x394941ff}},	//   íthi, יטוח_, _इमरज, noas_,
   {{0xa3d2ca3c,0x692b0185,0xe8d90044,0x2ca6c1f4}},	//   हौल_, třen, _chọ_, _ddod_,
   {{0xe9d9c698,0x6298c79b,0x63a2c944,0x249d8046}},	//   гко_, _cevo, _dvon, lawm_,
   {{0x3946009b,0x7d160b44,0xb05b0455,0xb6da4052}},	//   йног, _plys, sfäl, אַכט,
   {{0x753b80bb,0xd25680c3,0x6b89dd11,0x69c1dd12}},	//   _jjuz, _השעה_, ppeg, rtle,
   {{0x753b9d13,0x853a8052,0x291e0039,0x63af00b3}},	//   _mjuz, רגרי, ėta_, grcn,
   {{0x2bfa8048,0x81bc802a,0x6d4d1d14,0x645b8398}},	//   ्हतं_, েটর_, _ekaa, _mzui,
   {{0x75298185,0x249d8022,0xa3b3cfa8,0x2c854112}},	//   _omez, kawm_, जूर_, _ụmị_,
   {{0x39494c5a,0xe6d04285,0x753b9d15,0xdb044004}},	//   goas_, सज्ज, _njuz, driá,
   {{0xf8bf4303,0x3f5600b0,0x75ca8080,0x13ea4026}},	// [1720] _imél_, læum_, _məza, ымай_,
   {{0x68e09d16,0x57fb04e0,0x93fb04e0,0xd83f00a0}},	//   _samd, _עליו, _עליי, áček_,
   {{0x7d1bdd17,0x9d464d9b,0x8b56c009,0x29049d18}},	//   khus, _генд, ציעס_, _poma_,
   {{0xd83f004f,0x443f80f6,0xc8b80428,0x7ae19d19}},	//   šček_, _bxu_, अलिट, _aalt,
   {{0x69c180f6,0x68e4406a,0x2d088fa8,0x5c9780d7}},	//   _aqle, mdid, _वकील_, скія_,
   {{0x753b8112,0x5f065d1a,0x67ca4017,0x3ce087ca}},	//   _ejuz, _узга, rējā, živ_,
   {{0x3ce241be,0x2be04945,0x99984007,0x2c754112}},	//   _kakv_, निका, _vyrų_, _ụdi_,
   {{0x44205d1b,0xa06a84b6,0x7644806a,0x443f817a}},	//   ozi_, _баба_, şiyo, _fxu_,
   {{0x3dcec1ff,0x68e45d1c,0x63a400bb,0xc600402a}},	//   _spfw_, idid, _nvin, _এইটা_,
   {{0x7d065d1d,0xfc3f4019,0x7ae19d1e,0xaab34185}},	//   _loks, _odín_, _galt, ुभएक,
   {{0x7d1bdd1f,0xaa58d892,0xceb8cf86,0x2d9e01cb}},	//   bhus, рину_, rgę_, âtel_,
   {{0xec7add20,0x7d065d21,0xceba809c,0x657a8061}},	//   _спд_, _noks, riƙu_, _iuth,
   {{0x321ec036,0x752d5d22,0x4ad84374,0x443f1d23}},	//   szty_, viaz, ड़ाव, çu_,
   {{0xdd90c425,0x443f01b7,0x63a29d24,0x69dccaf3}},	//   _قوت_, ħu_, ison, æres,
   {{0x3ce2414d,0xdb00c4c9,0x37be802a,0x98bd8062}},	//   _bakv_, rrmä, _ইনফর, lową_,
   {{0x249d804d,0x6d4d02c0,0x115544c5,0x25ac05e5}},	//   xawm_, _ukaa, ікаю, ádla_,
   {{0xa1584c9d,0xba9940d9,0xc29944df,0x629a8469}},	// [1730] сату_, иває_, иках_, _oeto,
   {{0xa3ce054a,0x69c38089,0x657a8402,0x27e9c3aa}},	//   _रहत_, ytne, _outh, _šank_,
   {{0x2d9e161b,0x2d875d25,0x249d8046,0x247e825d}},	//   šter_, ëne_, tawm_, _ịma_,
   {{0xa3b982f0,0x629a80b1,0x2d874017,0x24ab002a}},	//   لاتر_, _aeto, īne_, গ্রহ,
   {{0x26cc8070,0x5ee14079,0x6281dd26,0x7d1bc730}},	//   _bbdo_, নাবে, yclo, vhus,
   {{0x249d8022,0x657a9d27,0x3d9543b2,0xdb06141b}},	//   sawm_, _buth, _мигр, stkö,
   {{0x657a9bea,0x6ebf85a3,0x395f9d28,0x6d49c0a8}},	//   _cuth, ल्गु, _thus_, toea,
   {{0x75299d29,0xb385dd2a,0x2bd982cf,0x657a85ef}},	//   _umez, олил, _پارک_, _duth,
   {{0x63a2805f,0x4ac64eec,0x69c55d2b,0x7f94811e}},	//   cson, र्वव, lthe, _натх,
   {{0x69c55d2c,0x6b8d470e,0xf1c3c185,0x316002bc}},	//   othe, ipag, _naší_, _shiz_,
   {{0x68e2c4ff,0x69c55d2d,0xc5d98e40,0x6f07404f}},	//   _faod, nthe, _خواص_, _mojc,
   {{0x212f81b4,0xdb09c2b0,0x27ed9d2e,0x671dc1ac}},	//   nigh_, rteñ, _kren_, योजक_,
   {{0x317a0011,0x505a05bf,0xdb09c30d,0x629e5d2f}},	//   _supz_, ршня_, steñ, yapo,
   {{0x9f44810b,0x693c8194,0x3f8ddd30,0x249fdd31}},	//   _irmã_, jčen, mpeu_, laum_,
   {{0x6d4b9d32,0xe7370007,0x39a58017,0xec9a416f}},	//   koga, цер_, nēs_, итај_,
   {{0x27ed9d33,0x448a41cc,0x629e4150,0x78bbdd34}},	//   _oren_, рбан_, wapo, nguv,
   {{0x6b8d4aee,0x60d65d35,0xa3ce054a,0x44205d36}},	// [1740] gpag, reym, _रहि_, uzi_,
   {{0x27e01d37,0x6b84c032,0xab5b40cb,0xdce8c047}},	//   _isin_, _éige, _spür, _budě,
   {{0x6b899d38,0x7ae3c129,0xed5a5d39,0x8c3b00fa}},	//   _ateg, _mant, _вон_, raße,
   {{0x92b611be,0x938a8687,0x260ac045,0xa2ca4036}},	//   _احکا, аска_, ाहती_, _सॉर्,
   {{0x3f8900c9,0x07a38bac,0x68e41aad,0x7bc6014d}},	//   _xtau_, дачн, _maid, ntku,
   {{0x68e41d3a,0x940b4435,0x212f92e4,0x63a45d3b}},	//   _laid, _necə_, aigh_, msin,
   {{0x657a9d3c,0x66dfc007,0xdb09c070,0x2919109c}},	//   _quth, iškė, greí, ūrai_,
   {{0x26d81d3d,0x4ac64064,0x2ca05d3e,0x629c5d3f}},	//   hero_, र्रव, naid_, _hero,
   {{0x26d81d40,0x27ed9d41,0xa2c141ac,0x29c3c34d}},	//   kero_, _gren_, र्क्, eña_,
   {{0xcff740c3,0x15eac0d9,0x68f61573,0xddc980cc}},	//   קציה_, аємо_, _anyd, înţe,
   {{0xdb09c815,0x3f890119,0x27e95d42,0x68e41d43}},	//   creí, _stau_, zvan_, _baid,
   {{0x25b80303,0xdce40011,0x3ce69d44,0xdb1d13ab}},	//   durl_, _bunđ, ndov_, rtsí,
   {{0x68e40813,0x2fc69092,0x60c0805c,0xdb04410b}},	//   _daid, ntog_, _mcmm, criç,
   {{0x940b403a,0xe8d900d1,0x3949c0a0,0xc444d006}},	//   _gecə_, _thỏ_, čase_, _ویژن_,
   {{0xc1c94064,0x63a45d45,0x6d4b9d46,0x69c54321}},	//   _रहेग, esin, yoga, xthe,
   {{0x692b0185,0xbcfb41b4,0x2fc69d47,0x98a20007}},	//   zřej, _bhéa, ktog_, tiką_,
   {{0x7c3b40ab,0x61ee417a,0x0ca840c5,0x673aca26}},	// [1750] _žurb, _arbl, ютри_, ontj,
   {{0x26d81d48,0x61ee44f9,0x81cdc079,0x249fdd49}},	//   cero_, _brbl, রির_, zaum_,
   {{0x13d3c079,0x6b8d4fdb,0xdb1bdd4a,0xab5b00cb}},	//   ়িয়, spag, ntuá, ntüm,
   {{0x6f1a8119,0x27ed9d4b,0x249fc022,0x63a45d4c}},	//   _altc, _pren_, xaum_, bsin,
   {{0xdb09c10b,0xbbd9c185,0xd7fb48b7,0x78fa40c3}},	//   queç, _भनेक, _тун_, _הפרו,
   {{0x2d9598ed,0xdb1bcc1e,0x6562cf2d,0x39a58017}},	//   прис, ktuá, _ahoh, tēs_,
   {{0x693740b3,0x9445805f,0xb05b00cb,0x62855d4d}},	//   tćeh, _کھان, sfäh, mcho,
   {{0x26d81d4e,0x212bc3bc,0x6562c05e,0x2fdf8022}},	//   zero_, òch_, _choh, _tsug_,
   {{0x249fd064,0xe3b1c032,0x7c228036,0x66188570}},	//   raum_, ررة_, czor, _čakš,
   {{0x68f61d4f,0x7d099d50,0x291b009c,0x249fc046}},	//   _snyd, _hoes, _alqa_, saum_,
   {{0xb87b5d51,0x6448003a,0x7d099d52,0xdce40054}},	//   _raín, ədiy, _koes, _sunđ,
   {{0x7ae3dd53,0x2ee59d54,0x2484c018,0xef198036}},	//   _want, _half_, ccmm_, _duże_,
   {{0x2ee5868e,0x6569c7fb,0x8c468080,0x27e9c359}},	//   _kalf_, mmeh, _peşə, _éan_,
   {{0x63a44655,0x6562c05c,0xe796c01c,0x6569dd55}},	//   vsin, _zhoh, _راهک, lmeh,
   {{0x551fc5de,0x629c4396,0xdb1bc018,0xa96a1807}},	//   _बताए_, _rero, ctuá, _лика_,
   {{0x6386443e,0xec7a4e32,0xd83f1d56,0x62855d57}},	//   згаа, спа_, ščak_, echo,
   {{0x69c701d4,0x65641c9a,0xa0674b24,0x63a44097}},	// [1760] atje, _ihih, зата_, usin,
   {{0x213f8303,0x212d888b,0x7c3b57ff,0xe29a4657}},	//   _ajuh_, _ameh_, _žurc, саж_,
   {{0x6d5640f8,0x41b64887,0x7d06c4c9,0x98a4c026}},	//   plya, ясат, öksk, limą_,
   {{0x7d099d58,0xdb1b8016,0xd9464244,0x7d028026}},	//   _coes, _aquà, _хеми, ujos,
   {{0x2d98c319,0xdb0442a4,0x6f089d59,0x7d098093}},	//   árez_, nsië, _podc, _does,
   {{0xa9a6407b,0x39400077,0xb87b0107,0xdbc7409d}},	//   _нигд, _ljis_, gdíj, tööt,
   {{0xf41f0fd0,0x52d8409d,0x672e4085,0x6f089d5a}},	//   nbär_, ड़ीस, _imbj, _vodc,
   {{0x98a4c039,0x3983803a,0x7d164007,0xa37b009d}},	//   kimą_, _qısa_, nkys, svõi,
   {{0xa2c48185,0x2486914e,0x657e00c2,0x2ee582cd}},	//   _राप्, mcom_, _luph, _falf_,
   {{0x3981dd5b,0x752d0047,0x98a4c007,0x291fc1ff}},	//   _bós_, _smaz, dimą_, ahua_,
   {{0x3981dd5c,0xbcfb1d5d,0x8cc1017e,0x62834043}},	//   _cós_, lméi, _वादो, žnog,
   {{0x78a282c0,0xe995801c,0x14ce562f,0x26c10414}},	//   naov, _آهنگ, ह्मण, _scho_,
   {{0x78bd0adc,0xc8641d5e,0x2720c35d,0x98a4c026}},	//   rgsv, етри, _nòng_, gimą_,
   {{0x707704e8,0x2c09c185,0x81cf802a,0x69c71d5f}},	//   _کاغذ, िहरू_, শির_, ttje,
   {{0xb87b4018,0x7ae50c99,0x24868b0e,0x48ab41dc}},	//   _faíl, _vaht, kcom_, йтам_,
   {{0x76554036,0x25d7c052,0xb87b5d60,0x248690a9}},	//   _ryzy, _זוהן_, _hníz, jcom_,
   {{0x224d0036,0xdb0d401f,0x2486802d,0x6b5200b0}},	// [1770] łek_, nuaç, dcom_, tægt,
   {{0x6b8d1d61,0x7d09919e,0xd43800c3,0x656400e2}},	//   _itag, _soes, _מרחק_, _zhih,
   {{0xdb044669,0x2ee59d62,0x99d94280,0x657e0024}},	//   isiè, _ralf_, تواء_, _guph,
   {{0xa3acc048,0xdb0d4359,0x32cf8138,0x31148589}},	//   गळा_, mraí, zıyı_, нфіс,
   {{0x2a610011,0xed58811b,0xaf37401c,0xdee581cc}},	//   _hzhb_, чої_, _فرست, доли,
   {{0x3ce9409d,0x290b406a,0x6b8d02c0,0xdb09c39e}},	//   ldav_, _hoca_, _mtag, kreá,
   {{0x2d860043,0x399a99b6,0x7d1b80a0,0x6d4f1d63}},	//   _čoek_, gūs_, _tlus, koca,
   {{0x24869d64,0xdef88085,0x60cd5d65,0xa2cacabd}},	//   ccom_, _enċ_, nfam, त्स्,
   {{0xd0a8c1b4,0x69c8dd66,0xb4b98743,0xdb0d5d67}},	//   سطين_, etde, चली_, hraí,
   {{0x2fc940fa,0x98a4c039,0x7c2484ff,0x399a90aa}},	//   itag_, vimą_, ùire, būs_,
   {{0xa96a1d68,0x6aa1c1e5,0x9d460802,0x6b8d1d69}},	//   жина_, ralf, денд, _atag,
   {{0x8fa613fd,0xdbd78051,0x3015c22b,0x6fb20027}},	//   маме, päät, _одер, _जिदं,
   {{0x6d5980d2,0x2cbfd3f6,0x20004018,0x25a080ab}},	//   ilwa, mgud_, xxii_, ćile_,
   {{0x2fc94065,0x6b8d0032,0x98a4c039,0xdb1d005f}},	//   dtag_, _dtag, rimą_, ttsá,
   {{0x28c60027,0x69c8cc2a,0x9f4d8070,0xdce44ee2}},	//   _वापि, ctde, _creé_, smič,
   {{0x6d4f0580,0x7c2440fc,0x629e0073,0xb7f1c047}},	//   coca, tzir, _wepo, _अछाम_,
   {{0x31648077,0x7d16456e,0xb4da00b2,0x2486802d}},	// [1780] _rhmz_, rkys, ठजी_, vcom_,
   {{0xfe724865,0x27eddd6a,0x7bc9c37a,0xcecec0d1}},	//   ندا_, iven_, iteu, _lộng_,
   {{0x6e460ce0,0xf8bf1d6b,0x7d0bd26b,0x249f8061}},	//   _ценз, ciés_, _oogs, _beum_,
   {{0x7d0bc68e,0x63bbdd6c,0xd91082cf,0xf8bf0089}},	//   _nogs, kuun, دیر_, liér_,
   {{0x60dbcad6,0xdb0441b4,0x97da9094,0x2ca00d35}},	//   deum, iriú, تظار_, _meid_,
   {{0x317e9d6d,0x6d4f1d6e,0x2ca01d6f,0x399a8007}},	//   _putz_, zoca, _leid_, tūs_,
   {{0x7b1000fa,0xda0e059c,0x1dd25d70,0x693c802d}},	//   _häus, सहित_, _सहित, nček,
   {{0x68e9dd71,0x27edc4c9,0x399a8007,0xa967c169}},	//   gded, fven_, rūs_, мија_,
   {{0x63bbdd72,0xb0188112,0x3374d9ad,0xc302c02a}},	//   guun, ọọvụ_, нгир, এসসি_,
   {{0x93fb42a6,0x98a00064,0x78a08041,0xdb09c004}},	//   קליי, _imię_, _hemv, treá,
   {{0x27edc060,0x7bd60303,0x63a98ac0,0x6935109b}},	//   aven_, _apyu, _zven, енну,
   {{0x92bec079,0x63bbcb28,0x249f0086,0x2ca0032a}},	//   ঁজে_, buun, úum_, _ceid_,
   {{0x7ae88a92,0xc178c007,0xdb0d401f,0x2ca00061}},	//   _kadt, tvės_, quaç, _deid_,
   {{0x92c2402a,0x78a09d73,0x2d5c8580,0x2d558329}},	//   ্যু_, _lemv, díem_, lået_,
   {{0xa4d5411e,0x8c3dc080,0xf77f406a,0xdb00d9a9}},	//   нові, maşa, _suç_, nsmí,
   {{0x78ad00f7,0x63b641f4,0x6ecac185,0x78a09d74}},	//   _udav, fryn, त्रु, _nemv,
   {{0x58844026,0xe7bcc079,0x6b8d1d75,0x7afa88f6}},	// [1790] тыса, _অনুয, _utag, _ontt,
   {{0x2fc95d76,0x69cf817e,0x067bc052,0x60cd435a}},	//   rtag_, _दहली, ַנדל, sfam,
   {{0x7cd9923a,0x2fc95d77,0x28c6009d,0x200f409d}},	//   змер_, stag_, _वामि, ägib_,
   {{0x2d5c8060,0xc61b1cfa,0x27edcdf2,0x7ae88573}},	//   bíem_, ननीय_, yven_, _aadt,
   {{0x3ce90033,0xeb9982db,0x656d5d78,0x9f3580d9}},	//   _maav_, чил_, mmah, неді,
   {{0xdb1d00b0,0xe7b20027,0xa3d713c4,0x80db8047}},	//   stsæ, _जिसप, _सहन_, _नसके,
   {{0xd3788011,0x2d811d79,0xc3324323,0x63601d7a}},	//   _dić_, _juhe_, _עול_, könn,
   {{0x75229d7b,0xfba34f76,0x63a994a7,0x6aa5405c}},	//   choz, _ओबाम, _tven, lahf,
   {{0x60dbc755,0x919f8b35,0xe45480d7,0xfaa5dd7c}},	//   reum, _गौरै, _акты, напо,
   {{0x60c41d7d,0xa205d43d,0x68e9815a,0x9f400321}},	//   _scim, епод, _haed, _friù_,
   {{0x7778dd7e,0x63bbdd7f,0x3eaec061,0x8c3d80b4}},	//   _divx, suun, _ddft_, _deşe,
   {{0x9f4901c0,0x290d8011,0x2d53cfc2,0x628add80}},	//   _araà_, _joea_, rães_, _effo,
   {{0xdb1d0041,0x7981802f,0x741605a7,0xe708c1aa}},	//   ktsä, _hulw, روسا, ستین_,
   {{0x7981963e,0x2d5c8016,0xfd1f4157,0x2d811d81}},	//   _kulw, víem_, _alì_, _buhe_,
   {{0x7658c007,0x5239c052,0x2ca01d82,0x6aa19d58}},	//   _gyvy, _מײַנ, _teid_, _melf,
   {{0x656d4f74,0x2d810003,0xe8e08112,0xb4b980ba}},	//   gmah, _duhe_, raịt_, चलो_,
   {{0x78a45d83,0x7f8cc052,0xc5691546,0xc2b646b1}},	// [17a0] raiv, ַנאַ, _تحول_, ељењ,
   {{0x3ea5dd84,0x2d5c86ed,0x63b642cd,0x7a0ac080}},	//   nalt_, ríem_, rryn, kətl,
   {{0x69ca8095,0xdb060066,0x429b03bd,0x2571c077}},	//   xtfe, jské, _מסיב, _ešli_,
   {{0x80de0079,0x98ab00b4,0x2ca08032,0x291f80d2}},	//   যাক্, mică_, úid_, _clua_,
   {{0x69374054,0x2d5580d9,0x63a9dd85,0x9f4d80d2}},	//   rćet, vået_, jsen, _creï_,
   {{0x3ea5c54a,0x39405d86,0x6aa181f4,0x69ca80d9}},	//   jalt_, lnis_, _celf, ttfe,
   {{0x26dc98ca,0x68e99d87,0x98ab0156,0x39405d88}},	//   revo_, _faed, nică_, onis_,
   {{0xdb044018,0x6d44012c,0x20118080,0xdb09c051}},	//   muiñ, _njia, _əziz_, hreä,
   {{0x93c880fb,0x6aa1805f,0x7ae8802f,0xbcfb1d89}},	//   _تازہ_, _felf, _tadt, llég,
   {{0x394040fa,0x6d561d8a,0x6f0e5d8b,0x8017c1b4}},	//   hnis_, _akya, _jobc, عزيز_,
   {{0x3f825d8c,0x7d0d013b,0x073740c3,0x4c9506dc}},	//   _luku_, _poas, תאים_, кинс,
   {{0x2d811d8d,0x39a6c031,0x6d5bc01e,0xb05b04c9}},	//   _ruhe_, _aísá_, clua, dfär,
   {{0x27e0c5f5,0x6d440053,0x0b8b00c5,0x39405d8e}},	//   _èin_, _djia, ясни_, dnis_,
   {{0x613b4025,0x27e6dd8f,0xa3c0025c,0x628a9d90}},	//   kälä, _ison_, ँढ़_, ncfo,
   {{0xcf57c093,0x26decba7,0x98ab00b4,0x99675d91}},	//   _רבות_, meto_, gică_, етал,
   {{0xbcfb4669,0x39405d92,0x6b82c150,0x2120004f}},	//   _thém, gnis_, _kuog, _glih_,
   {{0xa3ce009d,0x80de002a,0x2d810024,0x5c7545f5}},	// [17b0] _रहए_, যাখ্, _wuhe_, тлат,
   {{0xce6b5d93,0x3f8f403f,0x7a0ac03a,0x394040b2}},	//   пред_, īgu_, yətl, anis_,
   {{0x291f8046,0x290d8340,0xdb045d94,0x348e8094}},	//   _plua_, _poea_, guiñ, _ịdị_,
   {{0x777a8140,0xa2cd0c13,0x6d40c206,0xdc34056e}},	//   _aitx, द्र्, jnma, zúča,
   {{0x777a8232,0x6b82c007,0x6d5bc022,0x7afc405e}},	//   _bitx, _nuog, vlua, _fnrt,
   {{0x29095d95,0x63ad1d96,0x45d58ed5,0x61260086}},	//   ljaa_, _mvan, вцит, _gólf,
   {{0x9412003a,0x78a2dd97,0x9f4bd93c,0x316dc06a}},	//   _deyə_, _beov, ící_, tmez_,
   {{0x13f580c5,0x68fb8080,0x7d0f5d98,0x66035d99}},	//   _избя, _unud, _jocs, änku,
   {{0x3ea35d9a,0xb4dd809d,0x26dedd9b,0x316ddd9c}},	//   _kejt_, तजी_, feto_, rmez_,
   {{0xbcfb0047,0xdb0600a0,0x7981840d,0x6d5bdd9d}},	//   hléd, pské, _tulw, slua,
   {{0x3ea5dbfc,0xd629cc38,0xb4dd15a8,0x6e45cc86}},	//   ralt_, фоне_, ड़ू_, тенз,
   {{0x4087c0c5,0x333315dc,0xe8044185,0x6aca0036}},	//   _чужб, _amxx_, रममा_, िभ्र,
   {{0x61e1c1f4,0x290fdd9e,0xfd598171,0x6b54c016}},	//   swll, _ioga_, _bibẹ, ràgr,
   {{0x2726000c,0x68fd4053,0x81bcc017,0xb464c0d9}},	//   _mông_, _ansd, izēj, _скіл,
   {{0x39405d9f,0x27260015,0x693c8f26,0x2d9e1da0}},	//   tnis_, _lông_, mčev, ète_,
   {{0x44295da1,0xb05b137b,0x78a2c004,0xdcf9003f}},	//   fza_, rfär, _xeov, _tuvā,
   {{0x7d1bdda2,0xb05b0136,0x7bcd5da3,0xfc3f0032}},	// [17c0] ikus, sfär, gtau, laín_,
   {{0x7d1bcf4c,0x656987b6,0x68ed5da4,0x7983cc47}},	//   hkus, _aheh, adad, _kunw,
   {{0x18a69da5,0x321c4066,0x9f4d834d,0x60c2805c}},	//   ваем, ávy_, _creí_, tgom,
   {{0xe9ff8015,0x6123454a,0x2d834123,0x62880066}},	//   _nhằm_, _põle, _duje_, ždod,
   {{0x7c29dda6,0x693c8077,0x3ea78dc5,0xdb044018}},	//   jzer, kčev, fant_, suiñ,
   {{0x78a41175,0x7c29dda7,0x3ea340f6,0x387f8545}},	//   _leiv, dzer, _gejt_, _egur_,
   {{0x6da35da8,0x2d834360,0x66035da9,0x19b94051}},	//   _виса, _guje_, änkt, _путь_,
   {{0xa06a9daa,0x291c8017,0xaa435dab,0x80d0802a}},	//   _жаба_, īvas_, _тесл, _সোর্,
   {{0xb87b0107,0xc8f2c17e,0xf366c41a,0x98ab0062}},	//   ndít, _अफीम_, ктон, nicą_,
   {{0xf8eb0027,0x69ce10ff,0xd6daddac,0x6d42806f}},	//   _जोड़ा_, ktbe, фти_, lnoa,
   {{0x3f848150,0x6d4646f0,0xdb00c086,0x5ebb40c3}},	//   _humu_, _ojka, gsmá, וזיק,
   {{0x2002c09d,0x7aeac1c8,0x7983c99e,0x6569813b}},	//   äkis_, _waft, _dunw, _xheh,
   {{0xaed4c156,0x272600d1,0x6b840755,0x69c44045}},	//   _болш, _xông_, _cuig, ांडी,
   {{0x8233c4e8,0x6aa3ddad,0xdb23406a,0x81cdc02a}},	//   اریا, _genf, örün, রিজ_,
   {{0x4ad20ebe,0x290fddae,0xaa5806b1,0x7522ddaf}},	//   द्धव, _yoga_, виру_, _kloz,
   {{0x63ad9db0,0x63ad036b,0x68e0c8bf,0x628e5db1}},	//   šani, _tvan, nemd, _afbo,
   {{0x21391db2,0x19584c4e,0x2126807a,0xaacfc185}},	// [17d0] mish_, таты_, dhoh_, त्वक,
   {{0x3ea79db3,0xdd11403f,0x68ed01ef,0xbcfb4032}},	//   xant_, _kļūd, _haad, _mhéi,
   {{0x7c29ddb4,0x7bcd545e,0x27260015,0x7bc0ddb5}},	//   zzer, stau, _sông_, humu,
   {{0x3f8481ae,0x9f490580,0x765c56d7,0xa3c71057}},	//   _bumu_, _braç_, _dyry, _उमा_,
   {{0x14d642a6,0x777c5db6,0x62800047,0x68e0ddb7}},	//   _גורל_, _firx, ěmov, demd,
   {{0x6b6580d7,0x3946c34d,0x3f849db8,0xd246c182}},	//   ыкла, _ajos_, _dumu_, _هن_,
   {{0xa493c4fc,0x6aa3ddb9,0x39aec039,0x4429c166}},	//   لیات, _renf, jęs_, _ťa_,
   {{0x29f3406f,0x63ad5dba,0x68ed1dbb,0x7bc0c0f7}},	//   _ića_, osan, _naad, fumu,
   {{0x3ea784e2,0x7983c083,0x78a40714,0xa2ca4e18}},	//   pant_, _sunw, _reiv, स्क्,
   {{0x2fcdc5b2,0x7d09ddbc,0x213900f8,0xdcfe4013}},	//   rteg_, sjes, eish_, _rupč,
   {{0x7d09ddbd,0x645d5dbe,0x693c8618,0xbbd04185}},	//   pjes, _lysi, rčev, _सङ्क,
   {{0xbcfb41b4,0x68ed0057,0xa3e44834,0xa2d3c028}},	//   _fhéi, _caad, _भईल_, _बॉर्,
   {{0x2ca94057,0xb4dfc9fd,0x6aa3c0f6,0xb05b1073}},	//   daad_, दजी_, _tenf, sgän,
   {{0x8afcc064,0x636b40b5,0x70e08036,0x7522ddbf}},	//   ględ, nünd, _नस्ल, _zloz,
   {{0x2f140041,0x60c98077,0x657d5dc0,0x645d5dc1}},	//   _sägs_, _ocem, _bish, _aysi,
   {{0x63ad5dc2,0x248dddc3,0x657d5dc4,0x67388514}},	//   fsan, ncem_, _cish, zivj,
   {{0xa2cac8b8,0x61260344,0x0b465dc5,0x96964fc8}},	// [17e0] त्क्, _cóle, гнан, греш,
   {{0x68ed1642,0x139b021d,0x479b0323,0xa2e6001d}},	//   _zaad, _רביע, _רייס, _соод,
   {{0x29120360,0x2ca94057,0x6d59ddc6,0x3f849dc7}},	//   _koya_, baad_, _okwa, _sumu_,
   {{0x63ad41c8,0xf539c166,0x0cbec02a,0xb95a8032}},	//   bsan, jiť_, _আস্ত, رجاء_,
   {{0x6d445dc8,0xb8dc8a89,0x29121dc9,0x60c99dca}},	//   mnia, _आय_, _moya_, _dcem,
   {{0x2912021b,0xfc3f4004,0x657d5dcb,0x63bbddcc}},	//   _loya_, _edís_, _zish, drun,
   {{0x7ae1ddcd,0x69c1ddce,0x6ed60028,0x3ea5927d}},	//   delt, jule, म्यु, _delt_,
   {{0x291202e3,0xdb0d410b,0x7aee5876,0x7ae1c051}},	//   _noya_, traç, _habt, eelt,
   {{0x7aee5dcf,0x7a0ac03a,0x779281aa,0xdb0d401f}},	//   _kabt, məti, _ایتا, uraç,
   {{0x7c3b5dd0,0x6d445d87,0xdb0d410b,0x636b5dd1}},	//   _žurk, hnia, rraç, rüng,
   {{0xf539c038,0x6d565dd2,0x2d9808c9,0x2d859dd3}},	//   biť_, koya, jpre_, _gule_,
   {{0xac190842,0x92e04079,0x2d590669,0x7aee5dd4}},	//   вому_, থায়_, vées_, _labt,
   {{0x213918de,0x6d445dd5,0xddcbddd6,0xfc3f0018}},	//   rish_, dnia, čišt, raío_,
   {{0x7aee4046,0xce94c1bc,0x657d400b,0x2ca94057}},	//   _nabt, _такъ, _sish, waad_,
   {{0x645d5dd7,0x657d5dd8,0x6d4441f4,0x6560c032}},	//   _sysi, _pish, fnia, olmh,
   {{0x63a2ddd9,0x5c0740c5,0x6ed60047,0xc9840156}},	//   _kwon, ляза, म्बु, сури,
   {{0x629c1dda,0x69ce40f1,0xb97c0052,0x63ad5ddb}},	// [17f0] bbro, _aqbe, _אנהי, usan,
   {{0x2ca9489d,0x645d4166,0x6d445ddc,0x60c9823f}},	//   saad_, _vysi, ania, _scem,
   {{0x657d5ddd,0x6d565dde,0xdc560a87,0x7a0ac080}},	//   _tish, boya, _مریک, fəti,
   {{0x63ad5ddf,0x7ae1dde0,0x9f400070,0xdb00c041}},	//   psan, zelt, _frió_, lsmä,
   {{0x636b41df,0x6b864303,0x661adc4b,0x63ad414e}},	//   tünd, _gukg, hytk, qsan,
   {{0x6d59d3a7,0x9f4d8032,0x4ea780b4,0x398a81c0}},	//   _skwa, _breá_, урда, _bùs_,
   {{0xdb029de1,0xab5b00fa,0x636b5de2,0x9f4d8070}},	//   groñ, prüf, ründ, _creá_,
   {{0x2d8593df,0x63a2d1a4,0x7ae1c0fa,0x7d0d5de3}},	//   _vule_, _bwon, welt, njas,
   {{0xf576c1b4,0x3ea59ae9,0xb4db4031,0x69c1dde4}},	//   جميع_, _telt_, _ajàk, wule,
   {{0x6d445de5,0xc6a4801b,0x248dc1ff,0xf539c02d}},	//   znia, _грци, scem_, siť_,
   {{0x248ddde6,0x6d564987,0xaca341c0,0xf5060687}},	//   pcem_, yoya, _ajọb, азно,
   {{0x6d59dde7,0x2b5a00b3,0x2b89c00c,0x1bd5c6d8}},	//   _ukwa, _skpc_, _túc_, _водя,
   {{0x74040079,0x8fa5dc0a,0x69c1dde8,0x6d565de9}},	//   উন্ট_, _тале, sule, voya,
   {{0x26c79dea,0x98ab003f,0x8235c1aa,0x291fc85c}},	//   ngno_, ējās_, _پرتا, lkua_,
   {{0x29121deb,0x7a0ac03a,0xfc3f4070,0x7bdd5dec}},	//   _toya_, yəti, _reía_, _apsu,
   {{0x21295ded,0x3ea7db59,0x6ed84185,0x75241dee}},	//   ghah_, _hent_, न्नु, _uliz,

   {{0x442dcddb,0xdb09ddef,0xe2ca5df0,0xeab2401c}},	// [1800] nze_, queó, клад_, قعا_,
   {{0x69dc5df1,0x21294022,0x1303411b,0xf7725438}},	//   _ppre, ahah_, озум, زاء_,
   {{0x2d850047,0x69c3809d,0x673c04c6,0x291fc051}},	//   ílet_, june, mirj, kkua_,
   {{0xeb9a8bfc,0xaad20e18,0xe3a7c865,0x753bc150}},	//   вид_, द्रक, _ور_, jiuz,
   {{0x6aaa811c,0x4420800c,0x26e5c25c,0xeb069df2}},	//   taff, ái_, _कसूर_, ичко,
   {{0x69c39df3,0x6d5b9df4,0x60cbc05e,0x2120404f}},	//   fune, _ekua, _acgm, lkih_,
   {{0xdcc60028,0x8884c08c,0x2d87ddf5,0x693c80b3}},	//   _वांछ, میان, _nune_, učes,
   {{0x7d008070,0xa96a8477,0x212040e5,0x673c00fd}},	//   _unms, _риба_, nkih_, hirj,
   {{0xeb06ddf6,0x42ea86b1,0x4306c0d9,0xff06c007}},	//   ачно, _имао_, аїна, аянн,
   {{0x69de13c1,0x6d461df7,0x656280da,0x11d6811b}},	//   _oppe, enka, lloh, _відр,
   {{0x9813c1aa,0x6d22046d,0x61e70046,0xd5b100d1}},	//   مبیا, मसंग_, xwjl, ới_,
   {{0xdb044004,0x6283c17a,0x442dc06a,0xd257cae8}},	//   iriñ, _egno, bze_, рць_,
   {{0x50671df8,0xab94c1b4,0x6ecd8371,0x2d5c83c1}},	//   ртна, _التغ, _सामु, líes_,
   {{0x673ac0fd,0x3d04d543,0x2d87c0c4,0x6d485df9}},	//   qitj, वावे_, _fune_, édan,
   {{0x212945dc,0x2d87c0fc,0x6d460022,0x29881dfa}},	//   thah_, _gune_, bnka, исто_,
   {{0xc27bc009,0x8a7bc093,0x427bc3bd,0xdb1983bc}},	//   _ברוי, _באות, _באוג, ntwò,
   {{0xbcfb1dfb,0x79889dfc,0x2129405c,0x115440d9}},	// [1810] cléa, _ludw, rhah_, ікую,
   {{0x2ca91dfd,0x3949c06c,0x64a70027,0xf8ef8374}},	//   _head_, časi_, _ख़ुश, _घोड़ा_,
   {{0x628500eb,0x2d8ac166,0x7d02c0bb,0x63a41dfe}},	//   _igho, íbeh_, _onos, _zwin,
   {{0x5c7591cd,0xbd689dff,0x0d844007,0x2729c0d1}},	//   блет, арче_, ілін, _túng_,
   {{0x798080b6,0x80cf01f9,0x75f04107,0x2f1980d9}},	//   _dimw, _थाने, tózá, лодь_,
   {{0x6d5d4010,0xdb04403c,0x39591e00,0xd5434031}},	//   _hksa, briñ, hoss_, _fẹ́n,
   {{0x3ea7c0c3,0x6aa8815a,0x8c3dde01,0x291fc025}},	//   _rent_, _dedf, maşi, tkua_,
   {{0x0905d229,0x6d5b812c,0x2249c123,0xdce44011}},	//   спин, _ukua, _ćak_, rmić,
   {{0x2bda84e8,0xe8f6c1dc,0x39591e02,0x3ea7de03}},	//   _مالک_, слы_, doss_, _pent_,
   {{0x27ed851f,0x798081c6,0x27e95e04,0x62851e05}},	//   _isen_, _zimw, iwan_, _ngho,
   {{0x6d44c166,0x568c8009,0x6b961e06,0x38660077}},	//   čiar, _סטאַ, _styg, _šor_,
   {{0x62851e07,0xa3bb8027,0x27e95e08,0x673c0033}},	//   _agho, _आटा_, kwan_, wirj,
   {{0x27e95e09,0x6b819e0a,0x6d461e0b,0x2ca91e0c}},	//   jwan_, _kilg, rnka, _dead_,
   {{0x661c1e0d,0x6370454a,0x68e45e0e,0x7e618051}},	//   tyrk, mäng, weid, _kylp,
   {{0x60db820e,0x412a4f34,0xe297043e,0x6562871c}},	//   _obum, гово_, сас_, yloh,
   {{0x6362401d,0xdb00de0f,0x6136109c,0x61fcde10}},	//   môni, rsmå, kšli, ærle,
   {{0x394682bc,0x3f891e11,0xf388c00c,0xdb044fc2}},	// [1820] vnos_, _guau_, _lợn_, nsiç,
   {{0x2fd24041,0xdb04443d,0xed59c047,0x60db99f1}},	//   rtyg_, isiç, hož_, _abum,
   {{0xc3330009,0x27e945b2,0x6362401f,0x644f5e12}},	//   _מוז_, awan_, nôni, _exci,
   {{0x984a85bf,0xb4c28260,0x2d5c83e9,0xf38a8083}},	//   ляла_, ंले_, víes_, _aṣa_,
   {{0x65629e13,0x2ca040b2,0x80c108b8,0x7988814d}},	//   rloh, mbid_, _वाघे, _sudw,
   {{0x60db825d,0x26d801f4,0x96f88156,0xe9aa401c}},	//   _ebum, nfro_, рект_, _مدرن_,
   {{0x3eaa4018,0xdb1d010b,0x7988821b,0x3ce90185}},	//   _iebt_, lusã, _qudw, _जसले_,
   {{0xa49191be,0x6d598064,0x1ae40079,0x5bb8c844}},	//   _قیمت, cowa, মায়া, алия_,
   {{0x6b8180f1,0x3eb84033,0x2fc05e14,0x6b9bc71c}},	//   _filg, _kdrt_, nrig_, gpug,
   {{0x95d8c01b,0x8afc8036,0x96d3c46d,0x35b4c505}},	//   адот_, _chęt, ब्लॉ, обор,
   {{0x2ca9054a,0x3eacc05f,0xe8d9000c,0x27e00031}},	//   _pead_, radt_, _chở_, _apin_,
   {{0x81bcc279,0xc27b4087,0x6c86c1b4,0x19590039}},	//   dzēt, טריי, _الإم, рамы_,
   {{0x7d1dc0cb,0xd8d78052,0x2ca900b2,0x78ad5e15}},	//   össe, זוכט_, _vead_, vaav,
   {{0x87b7c4e0,0x2d6840cb,0x81df402a,0xdb044521}},	//   _פלוס_, ußen_, তিত_, nsiä,
   {{0x2fc05e16,0x6f154750,0xc33980a0,0x753d1e17}},	//   erig_, _rozc, _říká, pisz,
   {{0xbcfb4031,0x6564471c,0xdb1d001f,0x2fc04c1c}},	//   _ahér, glih, fusã, frig_,
   {{0x7bc61e18,0x69d804d3,0x6aaacc29,0x7ae55e19}},	// [1830] cuku, _även, _keff, teht,
   {{0xa2cd8e1a,0x7d040036,0x78a99e1a,0x7a0ac080}},	//   _साध्, _znis, _seev, bətt,
   {{0x2ba94a3c,0x65645e1b,0xa2ce0891,0x27e9409c}},	//   _चौरा, blih, _तात्, swan_,
   {{0x2486c09c,0xf388c0d1,0x2d824f2d,0x2fc0499e}},	//   _ngom_, _rợn_, _gike_, brig_,
   {{0xa2c48260,0xdfc6c182,0x6b8985f5,0x6b9bc49a}},	//   _राख्, _تي_, _queg, xpug,
   {{0xd5dd0027,0xdd86c226,0x69c54051,0x636d8018}},	//   _पहाड़, _يو_, puhe, dúnc,
   {{0x6d599e1c,0x3495909d,0x9f448070,0x69c71815}},	//   powa, _мавр, _armó_, nuje,
   {{0x254cc047,0x7ae70047,0xe3b9c4b6,0x321ec036}},	//   těla_, hejt, аби_, dyty_,
   {{0x27ed9353,0xe0df4053,0x69d500cb,0x7982c1aa}},	//   _usen_, _ajòk_, htze, _diow,
   {{0xe8d900d1,0x1c42c5f1,0x2d9840d9,0x6d4d1e1d}},	//   _phở_, ьным, _ytre_, _ajaa,
   {{0x3669cc86,0x7ae70185,0x7bc61e1e,0x6123454a}},	//   рано_, dejt, wuku, _põll,
   {{0x27e0c119,0x3f834077,0x2ee5de1f,0x26dcc17b}},	//   _ţine_, _liju_, self_, _ebvo_,
   {{0x68e61e20,0x394d8f95,0x28d180e6,0x290400b5}},	//   rekd, _mjes_, _हानि, ıma_,
   {{0x6d4d1e21,0x394954dc,0x21290033,0xe8d9000c}},	//   _ejaa, enas_, _elah_, _thở_,
   {{0x6d471e22,0x798ac024,0x7d161e23,0x2ca04b87}},	//   čkar, _gufw, _toys, tbid_,
   {{0x4d66411e,0x752d52cf,0x6295415d,0xc5f280c3}},	//   ікав, ghaz, _afzo, ודל_,
   {{0xe8c6129c,0x25a08068,0x27e01e24,0x69d50232}},	// [1840] वलीच, ćili_, _upin_, atze,
   {{0x3f834158,0xfe4652bf,0x753b9e25,0x5ec10079}},	//   _ciju_, онзо, _amuz, শ্বে,
   {{0xe2974efa,0x80b10064,0x798400eb,0x2d825e26}},	//   цах_, _अजमे, _kiiw, _tike_,
   {{0x6d41401e,0x7f5c0157,0x69cb44ef,0xd57680d9}},	//   élat, lorq, _हमरी, цузь,
   {{0x7b39c066,0x48dc0185,0x6d5bde27,0x6b83c140}},	//   rňuj, ग्यो_, doua, _oing,
   {{0x27e98016,0x4420400d,0xab2a41bd,0x3d084048}},	//   çana_, myi_, _тога_, हावे_,
   {{0x272f00fa,0x76a9811b,0x7f5c0018,0x6aaac15a}},	//   _fünf_, стів_, iorq, _reff,
   {{0x628740fd,0x752440fc,0x6f008166,0x637200b0}},	//   _zgjo, nkiz, _bábä, lænd,
   {{0x0ed2808f,0x78a29e28,0x6b8bc157,0x7bd65985}},	//   _सापड, mbov, _cugg, ntyu,
   {{0x1fd0002a,0x39404149,0x75298ee2,0x63bdc107}},	//   িবাস, hiis_, _zlez, ásna,
   {{0x636000fa,0x39495e29,0x6020c031,0x6b83de2a}},	//   höns, ynas_, _bámú, _ding,
   {{0x6d49d335,0xf41f0051,0x69c3404f,0xcbf2c384}},	//   cnea, tyä_, šneg, _अनपढ_,
   {{0x6d40de2b,0x798401c8,0xf8b384e0,0x6b83de2c}},	//   mima, _diiw, ושר_, _fing,
   {{0x2d8c9e2d,0x321ec02d,0x6b83de2e,0x7e63c0b1}},	//   _kude_, pyty_, _ging, _fynp,
   {{0x636d8032,0xdb060041,0x3f83406f,0x69d500fc}},	//   núna, dskä, _riju_, utze,
   {{0xbdfb41aa,0x2d8c9e2f,0x39404149,0x7bc29e30}},	//   یرضا_, _mude_, giis_, krou,
   {{0x6f18c0b3,0x368b4a66,0x69d51e31,0xcd2b01aa}},	// [1850] _kovc, асен_, stze, _مسکن_,
   {{0x6e675828,0x752d5e32,0x6f051e33,0x78ad00c3}},	//   отеж, shaz, _unhc, _heav,
   {{0x39495e34,0x6b8d1e35,0x8c3dc06a,0x0c988112}},	//   pnas_, _huag, laşt, _ịhụl,
   {{0x636d8032,0xdb0d4032,0x6b8d0b29,0x62950062}},	//   dúna, msaí, _kuag, lczo,
   {{0x60cd4150,0x799a8283,0x78abc2a4,0x3eac8240}},	//   mgam, _attw, _regv, _bedt_,
   {{0xe7e00374,0x2fc94022,0x3cddc185,0x637200b0}},	//   खौटा_, muag_, क्ने_, ræng,
   {{0xf628411b,0x2d8c80e2,0x3869c570,0x6d5bcd4a}},	//   _діти_, _cude_, _šar_, toua,
   {{0x6d40de36,0xdb1bc6ed,0x7af548fd,0x69c8d6fb}},	//   gima, truï, _hazt, dude,
   {{0x7e63c4d3,0x6b8d0669,0x425584e8,0x2729c019}},	//   _synp, _nuag, _کنار, _aúna_,
   {{0xfbd243bd,0xe80f0e98,0x78abc078,0x752440fc}},	//   עתי_, ामना_, _wegv, zkiz,
   {{0x69c8de37,0x2fc94046,0x68f641f4,0xa49b40d2}},	//   gude, huag_, ydyd, _anòm,
   {{0x3f858654,0x442055ca,0x6b8bde38,0xb7d5802e}},	//   _hilu_, yyi_, _tugg, _aṣiw,
   {{0x6b8d0061,0x60dbcdc0,0x93c600cc,0x9d1a8052}},	//   _cuag, mfum, _orăş, צושט,
   {{0xe7e384ae,0x3b0a004c,0xb113c094,0xdb09c5b1}},	//   _गहना_, щего_, _bụgh, rreó,
   {{0xd0044919,0x78a28089,0x8c3dc0cc,0x613144f5}},	//   रम्भ_, ybov, raşu, _målf,
   {{0x636499f3,0x2cad9e39,0x63a99e3a,0x5fc2cef0}},	//   ròni, _need_, _owen, _शिमल,
   {{0x63a9817b,0x1aeec079,0x39421e3b,0xe8df800c}},	// [1860] _nwen, জারে_, miks_, _ngựa_,
   {{0x44205e3c,0x68f61e3d,0x752440fc,0x39405e3e}},	//   ryi_, _hayd, skiz, siis_,
   {{0x27ff8171,0x44264f56,0x6b9b9e3f,0x6d40dd75}},	//   _arun_, šo_, _atug, yima,
   {{0x6d4b82d7,0x29195e40,0x6e3cc01f,0xa91d9e41}},	//   gnga, _gosa_, úrbi, _piža,
   {{0x27ff8321,0xf3ff401f,0xdb044359,0xa09b0323}},	//   _crun_, _grã_, isiú, ציסט,
   {{0x399181b4,0xf767c05f,0x1fc3c079,0x63a980f8}},	//   _bás_, _سا_, ্বাস, _dwen,
   {{0x79865e42,0x63b65e43,0x6d5d1e44,0x27308015}},	//   _kikw, lsyn, yosa, _làng_,
   {{0x7bc29e45,0x2cad81c8,0x39919e46,0x62950036}},	//   prou, _geed_, _dás_, zczo,
   {{0x79865e47,0x5f76805f,0x636d8032,0xb4b88048}},	//   _mikw, _فائر, súna, चणी_,
   {{0x81df4879,0x96668583,0x2cb24057,0x39918032}},	//   তির_, _екзе, hayd_, _fás_,
   {{0xba9b80c3,0x69c38077,0x20001a71,0x7ae8de48}},	//   _הסבי, crne, _arii_, redt,
   {{0x798e49dc,0x3942009d,0x63b65e49,0x2d9ede4a}},	//   _mubw, giks_, ksyn, rpte_,
   {{0xbcfb005f,0x6b8d1e4b,0x68f601c8,0xb113c044}},	//   llék, _quag, _dayd, _sụgh,
   {{0x6123409d,0x48e90047,0x636b450c,0x63b65bd6}},	//   _tõlk, _जसको_, günl, dsyn,
   {{0x7af5406c,0x6d5d1e4c,0x798e400d,0x6d4b81f4}},	//   _razt, posa, _nubw, ynga,
   {{0x60cd4026,0x25bf01af,0xf3ff443e,0x46d8cabd}},	//   ugam, čul_, _prã_, ब्रह,
   {{0x705501aa,0x29090149,0x273080d1,0x88bc00c3}},	// [1870] _زندا, _inaa_, _gàng_, _המחז,
   {{0x51871e4d,0x6d4b8c47,0x69d889be,0x25720089}},	//   _нума, wnga, ktve, rále_,
   {{0x6d4b9e4e,0x9f4053ab,0x2fc9404d,0x68e9c1c8}},	//   tnga, rvið_, suag_, yeed,
   {{0x63720065,0x6d4b9e4f,0x79865e50,0x69c38084}},	//   ræne, unga, _gikw, vrne,
   {{0x752d00e0,0xfc3f0018,0xa3e1449d,0x2ca08019}},	//   _mlaz, maís_, _दहि_, ñida_,
   {{0x68e9de51,0xf1b109fd,0x6d4b8986,0x6d4d5e52}},	//   weed, _जबान, snga, lnaa,
   {{0x2cad809d,0x25480107,0x2d8ec0e2,0x25aa41f4}},	//   _teed_, lőle_, _nufe_, _gwbl_,
   {{0x2d86cbfd,0x29091ca7,0x63bdc066,0x6298de53}},	//   _cioe_, _nnaa_, ásno, _afvo,
   {{0x27ff9e54,0x316943d2,0xf0944009,0xab5b0080}},	//   _urun_, ilaz_, ענץ_, vrün,
   {{0xa3d7115e,0x69ca9e55,0x68f61e56,0x7bcb9e57}},	//   _सहज_, bufe, _sayd, mugu,
   {{0x68e9c09d,0x69c541f4,0x60dbc449,0x44221e58}},	//   peed, nrhe, pfum, wyk_,
   {{0xdb09dde1,0x68eb80ab,0x7bc44007,0x63b65e59}},	//   rreñ, negd, yriu, ysyn,
   {{0x395fde5a,0x6d4d41c8,0xa936c4e0,0x9f4dc14b}},	//   mous_, dnaa, _קטנה_, nweë_,
   {{0x09e60495,0x1dc5c384,0x7af70018,0x59c5c85a}},	//   могн, _विपत, _caxt, _विपर,
   {{0x3f8fde5b,0xd62a00c5,0xd84f0112,0xa3a9d337}},	//   _hugu_, цове_, wọta_, गीर_,
   {{0xb4bc8103,0x7bcb9e5c,0x3f87c086,0xc0e340a7}},	//   _आये_, kugu, _hinu_, коск,
   {{0x18675e5d,0xb928c094,0x8c435dff,0x61e9438f}},	// [1880] дати_, _anwụ_, вете, _ćela,
   {{0x8c4300fa,0x9f4b40c4,0xe9ff80d1,0x6569c00b}},	//   ößer, _uscì_, _nhắm_, hleh,
   {{0x394dde5e,0x68eb8077,0x6d429e5f,0xf1e2009d}},	//   knes_, fegd, tioa, _पहिन,
   {{0x2d9c4017,0x1dc5c17e,0xe5a344b6,0xd7d2017e}},	//   īve_, _विनत, тици, _तमाच,
   {{0x394d5e60,0xa3ab8b35,0xf8b344e0,0x7d099e61}},	//   čest_, _कौआ_, _בשר_, _dnes,
   {{0x69d880d9,0x6d43801e,0x6aae413b,0x81e4c02a}},	//   ttve, énar, _uebf, নিত_,
   {{0x3866c0c9,0x6d4297f2,0x3f8fde62,0x2019c051}},	//   _syor_, pioa, _augu_, äsin_,
   {{0x92ae8079,0x2d9cc3c1,0x3f8fc360,0xa2be0945}},	//   কলে_, _rtve_, _bugu_, वृत्,
   {{0x3f87de63,0x61438da3,0x98b900b4,0x6f1a80d2}},	//   _binu_, _рета, hisă_, _totc,
   {{0x65641e64,0x692c406a,0x69d89e65,0xb87b0070}},	//   _akih, rşey, ptve, nfíe,
   {{0x7c24400d,0xbcfb1e66,0x6d4d41c8,0x3f87c0b4}},	//   hyir, lléi, ynaa, _dinu_,
   {{0x6b888010,0xc7a6cbba,0x7af70080,0xb4bc8047}},	//   _hidg, _жидк, _saxt, _आयो_,
   {{0x752d04f9,0x63a28232,0x3f87c0ab,0x3f8fde67}},	//   _vlaz, npon, _finu_, _gugu_,
   {{0x27e6de68,0x3f87c0e2,0x39401e69,0x6f1c5e6a}},	//   _ipon_, _ginu_, _emis_, _norc,
   {{0x200d0119,0x6d87c107,0x386d406f,0x7bcb9e6b}},	//   ţei_, _műan, _šer_, zugu,
   {{0x636b4676,0x3f87c017,0xa3f2c374,0x765b006a}},	//   rünm, _zinu_, _अनाप_, şuyo,
   {{0xb345801d,0x7d1b9e6c,0x69dad6d9,0xa2d70048}},	// [1890] niçã, _rous, ltte, _बाप्,
   {{0x7d1b9e6d,0x613144d3,0x63ad1e6e,0x25721e6f}},	//   _sous, _såld, _iwan, mála_,
   {{0x2ef84600,0x2572082f,0x6d4f1e70,0x395fde71}},	//   _darf_, lála_, onca, yous_,
   {{0x636fc11b,0x4424d80a,0x63704041,0x6b9d4010}},	//   jønn, kym_, räna, _ttsg,
   {{0xbbeb90da,0x613144d3,0x63a29e72,0x7d0992b8}},	//   ترام_, _våld, gpon, _vnes,
   {{0x7bcb9e73,0xb345801d,0x6f1c41f4,0x394dc100}},	//   rugu, diçã, _gorc, wnes_,
   {{0xa2d715be,0x7bcb854a,0x63ad1e74,0x3f8fde75}},	//   _बान्, sugu, _lwan, _sugu_,
   {{0xa2d74079,0x2bd3c028,0x636d846a,0x6d4f034d}},	//   _সফটও, _दमदा, múnm, ébal,
   {{0x657bc21b,0xa3c1c56c,0x3f87de76,0x39951e77}},	//   rmuh, ौंध_, _pinu_, _lås_,
   {{0x21295e78,0xee39d25a,0x809fc945,0xb113c0eb}},	//   hkah_, зно_, _ग्रे, _bụch,
   {{0x216a1e79,0x27340851,0xb062873b,0x39950588}},	//   зини_, _häng_, _ääri, _nås_,
   {{0xb345810b,0x7bc600b3,0xf7690323,0x661cde7a}},	//   biçã, trku, _הק_, ärka,
   {{0xdb0bc300,0x69dade7b,0x394f9e7c,0x25720032}},	//   _avgå, atte, ings_, gála_,
   {{0x3d069e7d,0x6d4f1e7e,0x290b5e7f,0x68f9c1f4}},	//   _सोने_, anca, _anca_, _hawd,
   {{0xc0e652b0,0x2ca680de,0x63a2805f,0xb113c044}},	//   новк, ybod_, zpon, _gụch,
   {{0x63bb9e80,0x248d80f8,0x2d9e0017,0x98b900b4}},	//   _ovun, _ngem_, īte_, risă_,
   {{0xf388c00c,0x7d1640b0,0x7ff60032,0x9b8a5546}},	// [18a0] _sợi_, rjys, _أسبا, سنال_,
   {{0x6292002d,0xf8bf402e,0xe8dfc0eb,0x68fbc080}},	//   ékoľ, _edé_, diọn_, hdud,
   {{0x61315060,0x63bb9e81,0x7c245e82,0x4424c064}},	//   _såle, _avun, syir, zym_,
   {{0x809fc028,0x6135c10d,0x0b8a820f,0xe9ff800c}},	//   _ग्ले, _hálf, пски_, _chậm_,
   {{0x4af8804c,0x6123454a,0x6f1e1e83,0xa2d700df}},	//   делю_, _põlv, _kopc, _बाम्,
   {{0x69dc0177,0x254cc0a0,0xdd9247ce,0x798980b1}},	//   otre, měli_, _موس_, _eiew,
   {{0x69ce0396,0x291dc031,0x27f25b0f,0xae944171}},	//   nube, _bowa_, lwyn_, _fẹra,
   {{0xb345801d,0x68fbcaee,0x31ba803f,0x8c3d80b4}},	//   tiçã, gdud, rīz_, _peşt,
   {{0xdef88283,0x65628033,0x2002c086,0x6d4f0046}},	//   _taċ_, mooh, íki_, vnca,
   {{0xa91d92b8,0x3944de84,0x69ce1181,0x2eaa008f}},	//   _nižj, sims_, kube, करोत,
   {{0x38690cff,0x6603d813,0x2d44005f,0x041ec079}},	//   _syar_, _crnk, rűen_, _বেশী_,
   {{0x68e2c0ab,0x68ed5def,0x63ad0150,0x69c70514}},	//   _ubod, xead, _pwan, vrje,
   {{0x63705478,0xd05b809c,0xb8039e85,0x399513f6}},	//   vänn, _dauɗ, लियम_, _sås_,
   {{0x539bc087,0x442681c8,0x69dc0cb8,0x628e5b43}},	//   _ציוו, iyo_, ftre, _ngbo,
   {{0x0697c093,0x7afa9e86,0x99854047,0xd90f408c}},	//   _אדום_, _matt, álů_, مید_,
   {{0x2d914242,0x63ad1e87,0x3f8a5e88,0x3f9200e2}},	//   _ruze_, _twan, _aibu_, _fuyu_,
   {{0x6d9341b7,0x7d0d1e89,0x68ed5699,0x70bf025c}},	// [18b0] _għaj, _inas, read, ्लील,
   {{0x69dc0015,0x69c70283,0x3f9bcc5a,0x27e900f8}},	//   btre, prje, _éque_, _ipan_,
   {{0x7d0d064b,0x7df3803a,0x27340041,0x7bdd1e8a}},	//   _knas, _təsə, _säng_, ltsu,
   {{0x629c5e8b,0x27e9007a,0x61260086,0x3f921e8c}},	//   _efro, _kpan_, _póli, _yuyu_,
   {{0x7bcf1e8d,0x2556003f,0x291dc738,0x68fd0b32}},	//   nucu, nāla_, _rowa_, idsd,
   {{0x02c2811e,0x3166c3e2,0x2fc94010,0x81ea802a}},	//   айшо, _akoz_, mrag_, মিন_,
   {{0xbe65479e,0x7bdd009d,0x1a9c0009,0x0dc84051}},	//   _شهري, htsu, ליגע, _пути_,
   {{0xdb0b84c9,0x7bdd1e8e,0xe80542ea,0xafe5cd29}},	//   dsgå, ktsu, रिपा_, воил,
   {{0x7f9581bc,0x442bde8f,0x68fbde90,0x8ca2050b}},	//   _разх, ác_, rdud, _क्षो,
   {{0x656d400b,0x6376801f,0x23658011,0xdce54085}},	//   hlah, tâne, _uklj_, _fuhħ,
   {{0x6f1e1e91,0x2d8b5e92,0x3f9200b5,0xa0a6092f}},	//   _ropc, _oice_, _suyu_, канд,
   {{0x26c100f8,0x3f92021b,0x68fb95c5,0x236cde93}},	//   _adho_, _puyu_, _jaud, aldj_,
   {{0x291f8022,0x2d931c00,0xf8bf0047,0x2ca95e94}},	//   _moua_, _auxe_, ckém_, dbad_,
   {{0x7bdcc0b4,0x6374c016,0x7d0d182e,0x637680b4}},	//   ărut, rànc, _enas, mânc,
   {{0x6376810b,0x21fc8047,0x9a69c032,0x63bbde95}},	//   lânc, máhá_, _تمثل_, lsun,
   {{0x57d19087,0x4426809c,0x656d5e96,0x2d8b4199}},	//   _समूह, yyo_, glah, _cice_,
   {{0xac864097,0x6f1e1e97,0x63a45e98,0x7bc9d8d9}},	// [18c0] тгал, _topc, upin, nreu,
   {{0x2d930018,0x63bbde99,0x657f4022,0x27f2402c}},	//   _fuxe_, isun, amqh, rwyn_,
   {{0x2ca95e9a,0x656d545c,0xba3c8007,0x273404c9}},	//   bbad_, blah, _neįp, _vänd_,
   {{0x1e5700c3,0x03a69e9b,0x4fc6879c,0x621ac052}},	//   _ישיר_, видо, вска, וועק,
   {{0xb4c041e7,0xb4ce4389,0xa3ba48a7,0x81e84079}},	//   ीली_, रली_, _تاجر_, বিধ_,
   {{0xb87b030d,0x290d9e9c,0x6d42d1f9,0x628e4094}},	//   nfía, _enea_, _smoa, _ugbo,
   {{0xe45f1e9d,0x798bde9e,0x48fd8045,0xe1f74051}},	//   ngör_, _bigw, _रोको_, _игр_,
   {{0xed57de9f,0x63bbdea0,0x7bc9c0fa,0xf486d8ed}},	//   кој_, fsun, freu, купн,
   {{0x9f4d85b1,0x05559041,0xb3868119,0x1c054b26}},	//   _creó_, _стря, _алал, रियल_,
   {{0xbcfb001e,0x7bdd0046,0xaf06cdca,0x6d5601c6}},	//   hlét, vtsu, тчик, _ajya,
   {{0xdb044319,0x656d5e1b,0x69de546e,0x68fb9421}},	//   lsió, ylah, ntpe, _yaud,
   {{0x7bc9dea1,0x3f8c805c,0x2d930004,0x68e28cbf}},	//   breu, _hidu_, _ruxe_, nfod,
   {{0x7bc9dea2,0x3eb80098,0x4fc700c5,0x9abc8085}},	//   creu, fart_, ъсна, _eoċe,
   {{0x45d4d198,0x2d8b4185,0x656d4057,0x5693c039}},	//   _бокс, _sice_, wlah, _кашт,
   {{0x2ca94206,0xb87b0018,0xe45f04c9,0x5224059d}},	//   tbad_, teís, ggör_, афта,
   {{0x850d4028,0x69ca8032,0x6135c070,0x30a44802}},	//   हाइट_, irfe, _gáld, ирув,
   {{0x25a98aa2,0x2ca95ea3,0x68fb9ea4,0xd2d2839a}},	// [18d0] ćali_, rbad_, _raud, _सांझ,
   {{0x656d5ea5,0x2ca945ef,0x7e470acf,0x1fa401bc}},	//   slah, sbad_, _ахме, _тръг,
   {{0x612613af,0x68e2802c,0x67280041,0xb87b0004}},	//   _vólv, ffod, ödje, peís,
   {{0x63bbdea6,0xe8599ea7,0x7bc9c2ad,0xe7954c31}},	//   ysun, наеш_, yreu, _ماسک,
   {{0x68fb9ea8,0x7afc4129,0x291f80cc,0xf09f4031}},	//   _vaud, _fart, _voua_, _ifà_,
   {{0x7bc9dea9,0x2abc40a0,0x27f9505f,0x68fd5e01}},	//   vreu, rábí_, _issn_, _hasd,
   {{0xdb060066,0xdb044019,0x69de40a8,0x3f8c8303}},	//   jský, asió, ctpe, _didu_,
   {{0x3998801e,0x9f4d80c4,0x394480f6,0x8d748107}},	//   _dés_, _creò_, _gmms_, _ناقا,
   {{0x54559988,0x25be80fa,0xfd44823d,0x657b9eaa}},	//   _сват, _evtl_, _тэрн, _ihuh,
   {{0x63769eab,0xa3d44028,0x98ad8077,0x46f5d941}},	//   rânc, संत_, _mleč_, учит,
   {{0x798d012d,0x394a1eac,0x5cd5c54c,0xe8df800c}},	//   _biaw, езно_, _مقاط, _ngừa_,
   {{0x8fa60ae8,0x3495c1bd,0x89360032,0x67218011}},	//   ламе, _садр, اعدا, _holj,
   {{0x798d1ead,0x6135c018,0x5184c0b4,0xb1430ff9}},	//   _diaw, _cále, _туфа, снял,
   {{0x2d91deae,0xdc3a8052,0xdbd140cb,0x68fd414d}},	//   ízes_, געשר, _süße, _aasd,
   {{0xe8df8112,0x62814194,0xe4f9deaf,0x442941c8}},	//   _amọn_, _úloh, ्यपि_, eya_,
   {{0x5c16404c,0x44295eb0,0xfc3f43e9,0x798d0010}},	//   льзу, fya_, _reír_, _giaw,
   {{0x6b8dcf35,0x386d9eb1,0x2d805eb2,0x07a64da4}},	// [18e0] _éags, _nyer_, rmie_, уазн,
   {{0x29dc4319,0xe8d0c260,0xbf9b410b,0x81ea8079}},	//   tía_, _सञ्च, _grêm, মিত_,
   {{0x637044d3,0x44294b1f,0xaca3c25d,0x645b8018}},	//   länk, aya_, _asọm, _axui,
   {{0x61fcc58a,0x27e65eb3,0x386d8240,0x290fc006}},	//   ærli, çons_, _byer_, _nnga_,
   {{0x9cd70093,0x7d1bdeb4,0xbef3c08f,0x657b9eb5}},	//   רונה_, djus, _असून_, _dhuh,
   {{0x29004e07,0x39988c5a,0x68e45eb6,0x81e70079}},	//   ldia_, _pés_, lfid, পির_,
   {{0x656f01f4,0x61314041,0x60c40112,0xa2d704d8}},	//   ylch, _måln, _odim, _बास्,
   {{0x399886ed,0x425344a4,0x63a4015d,0x7afe1eb7}},	//   _vés_, _انفر, _otin, _lapt,
   {{0xdce2c7ca,0x29004150,0xb7f1809d,0xa3e889d5}},	//   _ukoč, idia_, _आईएम_, _बहि_,
   {{0xe8054578,0x39495eb8,0x5837c051,0x70bf0c4b}},	//   रिता_, zias_, узья_, ्ल्ल,
   {{0x7e569eb9,0x798d1eba,0xd915010e,0xaa58ce1f}},	//   _стац, _piaw, адны, тину_,
   {{0x60c2c7ef,0x40a8c1aa,0x2006debb,0xa2d706c1}},	//   _udom, _شخصی_, _troi_, _बाह्,
   {{0x60c4103b,0x5f174033,0x27e05ebc,0x2ca00f2d}},	//   _ddim, नाम्_, jtin_, _dfid_,
   {{0x3cfdc022,0xdb060047,0x2fc0004f,0x6d934283}},	//   _zawv_, pský, _dvig_, _għaw,
   {{0xe3d18260,0x3949505e,0x7afe0396,0x68e45ebd}},	//   _सम्झ, tias_, _dapt, ffid,
   {{0x63704851,0x06cc402a,0x316904f7,0x79954f2d}},	//   bänk, র্মি, _ukaz_, _ruzw,
   {{0x29270036,0xbf9b443e,0x68fd40b1,0xb8df48b8}},	// [18f0] ętać_, _trêm, _vasd, _ीय_,
   {{0x68ff003a,0x52af4959,0xf09f0016,0xdce9c272}},	//   _haqd, टरेस, lcà_, vleč,
   {{0x386d821b,0xdce9c158,0x62880066,0xbbc1c8b8}},	//   _syer_, zmeđ, ždor, _षट्क,
   {{0xdce9de41,0x80dc425c,0x68ff01d6,0x7afe1ebe}},	//   tleč, _फाये, _jaqd, _zapt,
   {{0xa295411b,0xa3d44045,0x6abac51f,0x0ed4d4e8}},	//   _вагі, सूद_, katf, _दांड,
   {{0x5694484e,0x6566000b,0x06cc402a,0x9f3544f5}},	//   _гарт, zokh, র্বি, _тегі,
   {{0xf20440c5,0x389e825d,0x6d49debf,0x6566000b}},	//   _лято, _ịre_, tiea, yokh,
   {{0x68ff1ec0,0x2e3bc1c0,0x7c36c062,0x00000000}},	//   _naqd, _láfé_, _żyra, --,
   {{0xa3b0ca1b,0xe3b6c10e,0x60db800d,0x7bcd5ec1}},	//   टील_, абы_, _icum, nrau,
   {{0x27ed9ec2,0xeaf8816a,0x7bcd5ec3,0x2732c0cc}},	//   _ipen_, _مرمت_, irau, _pâna_,
   {{0x438481b4,0x6135ca4d,0x3cfdc24c,0x2ca00018}},	//   _اللق, _cálc, _tawv_, _pfid_,
   {{0x7afe1ec4,0x399a82a6,0x6933c1aa,0x008609d3}},	//   _sapt, _סינד, _دکتر, илно,
   {{0x98a044d6,0x2d821ec5,0x2e3bc1c0,0x20091ec6}},	//   lkić_, rmke_, _báfé_, _crai_,
   {{0x56b58009,0x46a5c748,0x79828064,0x2d5207ca}},	//   יפֿן_, _такв, zmow, kšeg_,
   {{0x60db8070,0x63705368,0x69265ec7,0x798f5ec8}},	//   _ocum, sänk, амва, _bicw,
   {{0x200900b9,0xa0a64026,0x63705ec9,0x8c670094}},	//   _frai_, раад, mäni, ụmọd,
   {{0x0b46459d,0xdfa54032,0x60d65eca,0x4d6340d9}},	// [1900] анан, محلي, rgym, ікув,
   {{0x63a9decb,0x09e646e4,0x29001ecc,0x4a460025}},	//   ipen, иозн, _haia_, _внов,
   {{0x4addd05d,0xaca440eb,0x98a04a18,0x613840e1}},	//   _मानव, _agụt, jkić_, _píld,
   {{0x84e6893d,0x27e05ecd,0x6abc1ece,0x290000fc}},	//   родж, ptin_, larf, _jaia_,
   {{0x6d5640f7,0x69c186d5,0x63a9c15d,0xa3ea4314}},	//   mnya, _avle, jpen, _महि_,
   {{0x6abc010d,0x6723decf,0x6d564033,0x9f424053}},	//   narf, _nonj, lnya, _eskò_,
   {{0x29121ed0,0x63a9ded1,0x60db8061,0x2fc05ed2}},	//   _onya_, epen, _fcum, lsig_,
   {{0x2d989ed3,0xa91d8d0e,0x60db8032,0x6ed29687}},	//   _érem_, _bižu, _gcum, _ठाकु,
   {{0x6abc1ed4,0x8cd7c028,0x2aaacdfc,0x2fcdc303}},	//   karf, _यारो, ктно_, greg_,
   {{0xf1bf0038,0x4734d08b,0x3cff8046,0xdcfc8017}},	//   žšie_, снос, _zauv_, _turē,
   {{0x2d8fc60f,0x394b1ed5,0xfa9742a6,0x3cff823b}},	//   _fige_, tics_, ידיש_, _yauv_,
   {{0x35471ed6,0x3cff823b,0x6135c0a0,0x2d8fc02e}},	//   рхов, _xauv_, _válc, _gige_,
   {{0x394b1ed7,0x25a6006f,0x27ed1ed8,0x290500a0}},	//   rics_, _čola_, ïen_, ěla_,
   {{0x29021ed9,0x61ee5eda,0x7d028051,0x6abc0c8e}},	//   adka_, _opbl, hdos, garf,
   {{0x394b1edb,0xa3d450de,0x937bc2a6,0x9f4040a8}},	//   pics_, सूस_, _שטות, atië_,
   {{0x6d564534,0xef198036,0x6d4b9edc,0x4906884d}},	//   gnya, _duży_, xiga, _सोलो_,
   {{0xe9ff800c,0xdb04010b,0x588745f1,0xdce2897c}},	// [1910] _thầm_, _aviõ, рыва, gooč,
   {{0x9f4043bc,0x7bcd5edd,0x6d4b9ede,0x48e304e3}},	//   ntiè_, rrau, wiga, ट्रो_,
   {{0xceb20087,0x636b40fa,0x04958032,0x93885edf}},	//   _מיי_, wüns, ملاح, рста_,
   {{0x2d8c8157,0x69d50d68,0xdce98085,0x7bc0c097}},	//   _èdel_, muze, _ikeċ, ksmu,
   {{0xfc058f34,0x2d985ee0,0xf0924093,0xfaa58d9b}},	//   спло, _eure_, _מנכ_, бало,
   {{0x257c8066,0xf3679ee1,0x61314ded,0x7af51256}},	//   víle_, штен, _målm, nezt,
   {{0x7c2d459a,0x7bc2c01e,0x656d1ee2,0x290201c8}},	//   lyar, _avou, _okah, ydka_,
   {{0x91cc409d,0x78bd0166,0x98a040ab,0x63a9dee3}},	//   _हितै, jasv, rkić_, tpen,
   {{0x290004fd,0xdee5c95c,0x7bc0dee4,0x63a9dee5}},	//   _raia_, бопи, gsmu, upen,
   {{0x7bc2c185,0x06ad0079,0x656d1ee6,0x2d84c051}},	//   _dvou, কৃতি, _akah, amme_,
   {{0x29001ee7,0x2d8fdee8,0xaa49dee9,0x6ed8c3ae}},	//   _paia_, _tige_, упна_, _मारु,
   {{0x6135d3af,0x200b5eea,0x2fc040de,0xe9ff8015}},	//   _fála, _orci_, ysig_, _chấm_,
   {{0x3085c032,0x6723deeb,0xc448001c,0x613144c9}},	//   _الشف, _tonj, شیدن_, _våll,
   {{0x6d93417a,0x656d075d,0x69d510c7,0x81ea802a}},	//   _jħas, _ekah, fuze, মির_,
   {{0x6d564056,0x637dd397,0x443fdeec,0xeb9f4240}},	//   tnya, rènd, lzu_, _drøm_,
   {{0x3f4f4017,0x6abc1eed,0x2fc05eee,0x69c1c595}},	//   kļus_, sarf, tsig_, msle,
   {{0x6d565eef,0x69c1def0,0x28d182c8,0xb4b41ef1}},	// [1920] rnya, lsle, _हाजि, टरी_,
   {{0x2d92009c,0x2fc05ef2,0xf7724032,0x2bd18048}},	//   _hiye_, rsig_, ساء_, _समजा,
   {{0xf3ec8079,0x2fc0456d,0xceb2c2a6,0x30f9c1f9}},	//   ওয়ার_, ssig_, פיא_, ्याः_,
   {{0x3eb8534d,0xecba8f4d,0x93aa8032,0x661cc0b2}},	//   _wert_, اطات_, هاتف_, ärki,
   {{0x6d5b807a,0x28db0e95,0x60189612,0x3eb85ef3}},	//   _djua, _भासि, роля_, _tert_,
   {{0x6f019ef4,0xe29749bd,0x69c1def5,0xdce0c03f}},	//   _calc, _гар_, ksle, domā,
   {{0x7bd65ef6,0xdce44158,0x442dc1c8,0x2d9a1ef7}},	//   luyu, glić, eye_, _jupe_,
   {{0x69c1d020,0xdb19c053,0xdce4406f,0x6abe4077}},	//   dsle, _avwà, koič, lapf,
   {{0x69d51ef8,0x88b7002a,0x2c1ec02a,0xfc4a40a0}},	//   zuze, _ঝালক, _বেড়ে_, blíž_,
   {{0x7bc280b6,0x6023810e,0xfe6f405f,0xc8d88374}},	//   msou, _эдуа, _آگے_, _डाँट,
   {{0x2d98c2a4,0x2d921ef9,0x6146defa,0x27efc0b9}},	//   êre_, _biye_, _лежа, _epgn_,
   {{0xdced5efb,0x69d51efc,0x63a48119,0x394dded5}},	//   tlač, vuze, ţinu, cies_,
   {{0x443fc064,0x21204570,0x69c3c240,0x7af51efd}},	//   czu_, djih_, _evne, tezt,
   {{0x2d920031,0xdce9006a,0x3f995efe,0x61fe1eff}},	//   _eiye_, ılıy, _rusu_, _bspl,
   {{0x61fe0018,0x6135d608,0xe9ff800c,0x417745a7}},	//   _cspl, _máln, _thấm_, مارس,
   {{0x3ebedf00,0x6d589f01,0xe8d900d1,0x61314ded}},	//   latt_, éval, _khử_, _tålm,
   {{0x29025f02,0x7bd65f03,0x29074185,0x7d02df04}},	// [1930] _daka_, guyu, ěna_, _maos,
   {{0x2126c42c,0x6440df05,0x1cf10094,0xfb844c38}},	//   _looh_, izmi, _ọjọọ_, пыхн,
   {{0x2cbd8022,0x6d934085,0x7c2f1f06,0x7bc2814d}},	//   tawd_, _aħar, lycr, esou,
   {{0xcebc003a,0x443fc089,0x29024053,0xdce446f0}},	//   _şəxs_, yzu_, _gaka_, vlić,
   {{0x637dc016,0xab5d817a,0xb901817e,0xeab99f07}},	//   nènc, _avża, _दा_, айл_,
   {{0xc7d80093,0x443fc03a,0x69c1df08,0x4addc5a3}},	//   מודי_, vzu_, ysle, _माधव,
   {{0x7d02df09,0xb4db405e,0xf2d40052,0xa20641c0}},	//   _baos, _amài, לעס_, _bọ́ọ,
   {{0x6f018036,0xdce45f0a,0xdce0c017,0xb3c9ca23}},	//   _walc, rlić, tomā, ализ_,
   {{0x442dd593,0x7dea803a,0x69c1df0b,0xdce4411f}},	//   uye_, _vəsa, wsle, slić,
   {{0x637dc315,0x69c1c51f,0x776a834d,0x78bb815d}},	//   dènc, tsle, cofx, _heuv,
   {{0xe7849c27,0xf2d2421d,0x8d74c2f0,0x753bc0f7}},	//   _хуто, ועי_, _کالا, phuz,
   {{0xa96a1f0c,0x442dc3bc,0x6d4f1f0d,0xa3aa408f}},	//   рима_, pye_, gica, _गझल_,
   {{0x69c504f5,0x28db07f6,0x69c381a7,0x25560017}},	//   _avhe, _भारि, lsne, nāli_,
   {{0x69c1c54e,0x656f4053,0x68ed17e0,0x78bb8c2a}},	//   psle, _akch, _ebad, _leuv,
   {{0x320c0047,0x6f03c0b4,0x2120404f,0x656b9f0e}},	//   ídy_, _ianc, tjih_, kogh,
   {{0x68ed1f0f,0x69c39f10,0x2cbfcd4a,0x6a8001c0}},	//   _gbad, isne, naud_, _aáfí,
   {{0x032645ac,0x63a9809a,0x67274085,0x6abe5f11}},	// [1940] одан, _nten, _bojj, tapf,
   {{0x2d9a0e4b,0xe3b7431e,0x7d041f12,0x63a4c359}},	//   _tupe_, юбу_, _hais, _éine,
   {{0x6abe41c6,0xbd06c004,0xdb09c30d,0x7d161f13}},	//   rapf, ntéñ, nseñ, _knys,
   {{0x63ad4010,0x6ed78185,0x7d0401a8,0xbfaa8bb4}},	//   bpan, _ठाउँ, _jais, атке_,
   {{0x613841c0,0x6b834112,0x7d02c231,0xaae24db4}},	//   _gíla, ọgar, _raos, _पापक,
   {{0x63a98033,0xf1a6935b,0x73f94052,0x39a68051}},	//   _dten, орин, _פּרו, ошив,
   {{0x6d4f0d08,0x656b80eb,0x78a28c81,0xae0d00aa}},	//   yica, bogh, pcov, हियन_,
   {{0x63a90119,0x60dbdf14,0x20074036,0x6d4f1f15}},	//   ţeni, ggum, łnie_, xica,
   {{0x6abc4086,0x3ebec0d9,0x5454ce03,0x200d9f16}},	//   _kerf, tatt_, явит, _grei_,
   {{0x75228639,0xf72ac186,0x68ed1f17,0xba0ac0c5}},	//   ljoz, рций_, _sbad, ахме_,
   {{0x28abc191,0x9f52df18,0x5ec74079,0x6f03df19}},	//   _ट्वि, _èyí_, র্কে, _danc,
   {{0x637dc315,0x2730800c,0x799c41c6,0x63ad5f1a}},	//   tènc, _sành_, _murw, ypan,
   {{0x2bd29c08,0x69d89f1b,0x3ebedf1c,0xe133c5dd}},	//   _सिफा, luve, patt_, _іншы,
   {{0x6d958085,0x27e68025,0xe8d901c0,0xfe7900a0}},	//   _iġar, iton_, _ijọ_, řům_,
   {{0x637f801d,0x69d89f1d,0x9e66c78a,0xda6fc11b}},	//   lênc, nuve, _باشن, _ця_,
   {{0x63704041,0x6e280041,0x9f5dc3e2,0x6abc4032}},	//   käns, ädba, _aswè_, _aerf,
   {{0x27e680fd,0x442f0065,0x7bc44c05,0x4fd54f93}},	// [1950] jton_, _æg_, gsiu, яжат,
   {{0x6abc5f1e,0x8c1bc0c3,0x60dd1f1f,0x6e2a013b}},	//   _cerf, בומי, lgsm, ëmbë,
   {{0x6374c6ed,0x7bc4409d,0x7af75f20,0x63ad5372}},	//   gàni, asiu, rext, span,
   {{0x69d75f21,0x27e69f22,0x673a8c4b,0x26080185}},	//   ruxe, fton_, _altj, हिरी_,
   {{0x2d895f23,0x3d1c0c4b,0xe8d9025d,0xdb061f24}},	//   mmae_, याते_, _njọ_, rskö,
   {{0x442f9f25,0x69c39f26,0xa85800c3,0x25720107}},	//   ryg_, tsne, חידה_, lált_,
   {{0x43944fd2,0xe8d9025d,0x6b9d5f27,0x6374c016}},	//   _царс, _ajọ_, _husg, càni,
   {{0x6441403a,0x27e68010,0xda5c00c3,0x6b9b9f28}},	//   _əlin, bton_, יכול, _tuug,
   {{0xe80e425c,0xaadc0430,0x637f801d,0x1bd5804c}},	//   सिया_, _बालक, gênc, _хозя,
   {{0xb4bb8834,0x28abd527,0xfe45c76b,0x78bd4070}},	//   _आजु_, _ट्रि, зноо, _lesv,
   {{0x1d0a1d93,0xab5b005f,0x2ef81f29,0xa50a02fd}},	//   бени_, tsün, verf_, бена_,
   {{0xc104c1b4,0x7d04005c,0x9c13c0eb,0xa3df8027}},	//   _يولي, _qais, _nọgi, _थमा_,
   {{0x637f801f,0x317ac323,0x889ac0c3,0xab5b1f2a}},	//   cênc, _פאנד, _הבני, rsün,
   {{0x2d9c0107,0x69c55f2b,0xa3b0c045,0x539ac0c3}},	//   _évek_, kshe, टीओ_, _פיצו,
   {{0x61384047,0xb4bb80aa,0x2d9cc0bb,0x644299a2}},	//   _díln, _आजू_, _guve_, zzoi,
   {{0x6b9d5f2c,0x6b954017,0x25720089,0x799c4f2d}},	//   _busg, _aizg, tálu_, _rurw,
   {{0x6b954247,0x79840340,0x6b9d409c,0x27e6922b}},	// [1960] _bizg, _ihiw, _cusg, xton_,
   {{0x7bc61f2d,0xe8d9000c,0x753b9f2e,0x2b1d09cb}},	//   msku, _thợ_, _aluz, माणु_,
   {{0x27340c62,0x69c75f2f,0xe2974fe8,0x60cbc0b3}},	//   _länk_, _cvje, чах_, _odgm,
   {{0xaadc0185,0x6374c016,0x6abc5f30,0x673e413b}},	//   _बाँक, ràni, _werf, shpj,
   {{0x6b9d5f31,0x6b9540e2,0x62830047,0x69c543c3}},	//   _gusg, _fizg, _únor, ashe,
   {{0x637f810b,0xf48784e8,0x273f40b4,0x28d8884d}},	//   vênc, سانی, _cînd_, _डाकि,
   {{0x7d7a81aa,0x395f80f6,0x5f1d0a94,0xde9386b1}},	//   _همسر_, _fjus_, मात्_, нашњ,
   {{0x273404c9,0xb0c6cd6c,0xda5b44e0,0xf8db0062}},	//   _bänk_, रृंग, _הכלל, _भाइय,
   {{0x44205f32,0xa4f1891a,0x394040e2,0xb4db40d2}},	//   nxi_, lışı_, ihis_, _imàt,
   {{0xb8d3d1f1,0x200d48c9,0x637dc3bc,0x75298150}},	//   _ज्_, _šeik_, tèna, _zoez,
   {{0x3d118048,0x7bc60166,0xbfa5c0d1,0xa3b0c8c1}},	//   णाचे_, esku, _hiệ, टीज_,
   {{0x26c156b4,0xdb19c053,0x867b8052,0x2bd4cae7}},	//   zaho_, _avwä, _פראו, _दिपा,
   {{0x3ae5c0b6,0x60dd1f33,0x25720107,0x39405f34}},	//   _bňpč_, rgsm, vált_, dhis_,
   {{0x78bd5f35,0x6ffbc093,0xaae6c01c,0x69c55f36}},	//   _sesv, _להדפ, _رستو, yshe,
   {{0xde57c11b,0x20025f37,0x60c28230,0x2480017b}},	//   _наші_, _aski_, kaom, _ezim_,
   {{0xda5bc093,0x3f9dc0e2,0x225f46f0,0xdff3df38}},	//   _לכול, _yuwu_, _ćuk_, _अहमद_,
   {{0x2d9e9f39,0x7d065f3a,0xa3d44185,0x25ac805c}},	// [1970] _lute_, _daks, संग_, _ltdl_,
   {{0x3ebe9f3b,0x629a8010,0x6abe00cb,0x23d4c4eb}},	//   _nett_, _ngto, _gepf, _दिनद,
   {{0x6376801d,0x651540fb,0xdce98283,0xa3dcc045}},	//   câni, _ہوگئ, _jieħ, तूत_,
   {{0x63ad0033,0x6135d608,0x7bd99f3c,0x853000e2}},	//   _ktan, _pálm, tuwu, _kiɗa,
   {{0x3ebe9da9,0x2d9e9f3d,0x22070047,0x394d804f}},	//   _bett_, _aute_, bíhá_, _vmes_,
   {{0x27e95f3e,0x69c71f3f,0x656f1f40,0xe29ac00c}},	//   mtan_, osje, hoch, _ngư_,
   {{0xba7751be,0x7d065f41,0xb4d74027,0x60cd0eeb}},	//   _راست, _yaks, _साफ़_, _odam,
   {{0x20d5c31e,0x68ed4359,0x26dedf42,0x69c700a8}},	//   фікс, nfad, egto_, isje,
   {{0x3ebe9f43,0x6f6581aa,0x26c3006c,0x3d1c017e}},	//   _fett_, _قهرم, kajo_, यासे_,
   {{0x3ebe84d3,0x2bd28064,0x69dadf44,0x68e2df45}},	//   _gett_, _सिता, fute, _ecod,
   {{0xd6e30079,0xb4d909fd,0x61e8c010,0x6ed704eb}},	//   য়ায, ालू_, gtdl, _बाजु,
   {{0x656f1c17,0x69d50036,0x39404022,0xdce981d6}},	//   goch, drze, xhis_, _dieħ,
   {{0x2d9e8242,0x60cd1f46,0x290941c8,0x69ce8673}},	//   _zute_, _ddam, ddaa_, _åber,
   {{0x6376810b,0x63ad0033,0x9f84c11b,0x799e00f8}},	//   tâni, _dtan, _згід, _pupw,
   {{0x27e94e07,0xfd648015,0x68ed5f47,0x1b064079}},	//   etan_, _chuộ, ffad, রামে_,
   {{0x395d8022,0x6b405da9,0x212b402c,0x637681ff}},	//   jnws_, _möge, _coch_, râni,
   {{0x5ed30079,0x63bb825d,0xb87b4047,0xed57410b}},	// [1980] দ্ধে, _nwun, _sbír, фот_,
   {{0xa4f180b5,0xf7720280,0x32114047,0x03d70052}},	//   tışı_, _جاب_, _brzy_, _קוים_,
   {{0x614647c2,0x831b0009,0x7afc1f48,0x6374c016}},	//   _жена, _וויז, mert, mànt,
   {{0x70d88048,0x395d8022,0x6135df49,0xa4f18189}},	//   डलेल, gnws_, _dálk, rışı_,
   {{0xe4e60314,0x0b8a86e4,0xc7a39637,0x938a86e4}},	//   _कानि_, оски_, вичк, оска_,
   {{0x2d9e9f4a,0x644601a8,0xf1c0c02d,0x7d09df4b}},	//   _pute_, izki, úšky_, edes,
   {{0x395d8046,0x68e40fc2,0x3ebe9f4c,0x90c685ac}},	//   bnws_, _ocid, _vett_, _обве,
   {{0x64404086,0x6f074147,0x26c3004f,0x6fbfcd91}},	//   _ýmis, _zajc, zajo_, लीभू,
   {{0xe2ca9027,0x3f9840e2,0x656f0c87,0x613cc303}},	//   _млад_, _kiru_, voch, _céla,
   {{0x2d9e9f4d,0xb38380b4,0x2004806a,0x7afadf4e}},	//   _tute_, _алул, _ismi_, uett,
   {{0x2fc9156e,0x2d9e854a,0x27e941a8,0x7dea8080}},	//   _svag_, _uute_, ztan_, _məsk,
   {{0x27e95f4f,0x69dc054f,0xdb0284c9,0xae0d009d}},	//   ytan_, dure, spoä, हिसन_,
   {{0xdce981b7,0x212b576b,0x60c45f50,0x61315060}},	//   _wieħ, _roch_, daim, _målt,
   {{0x69c704a9,0xc4c480fb,0x629c53d8,0x69dc156d}},	//   tsje, _ھے_, _ngro, fure,
   {{0x60c0807a,0x212b5f51,0xc808c00c,0x6f075f52}},	//   _oemm, _poch_, _hở_, _rajc,
   {{0x26c31f53,0x8afe8020,0x2c0b4048,0x20049dd6}},	//   sajo_, moƙu, हटलं_, _osmi_,
   {{0xbcfb001e,0x26c3004f,0x395d8022,0x69c71f54}},	// [1990] gnée, pajo_, vnws_, ssje,
   {{0x9f9adafc,0xfd648082,0x7bdd1f55,0x69dc1f56}},	//   mään_, _thuộ, musu, bure,
   {{0x69dc1f57,0x3f984232,0xd2514a10,0x69c8df58}},	//   cure, _diru_, دنا_, nsde,
   {{0x8ccb409d,0xdce4406a,0xd9f88048,0x60c4529a}},	//   तृशो, mliğ, ंबईत_, caim,
   {{0x62818107,0x69c80004,0x798d4360,0x7d09df59}},	//   _szlo, ádev, mmaw, vdes,
   {{0x32114036,0x395d8022,0x5de59657,0x60c08053}},	//   _trzy_, snws_, ежка, _eemm,
   {{0xdce443a6,0x26c11f5a,0x7d09c147,0x2ca082bc}},	//   nliğ, _meho_, tdes, žida_,
   {{0xb4d91f5b,0x645a81fc,0xd5b100d1,0x6b4040cb}},	//   ालो_, áciá, ấy_, _vöge,
   {{0x6562c07a,0x4439df5c,0x2fc95f5d,0x9f9ac051}},	//   _djoh, ás_, nsag_, jään_,
   {{0x7d098303,0x7c849f5e,0x798d4b0e,0xc808c00c}},	//   _haes, _русе, hmaw, _dở_,
   {{0x2d99401e,0x798d4033,0x7d1b86a9,0x752d1f5f}},	//   _oise_, kmaw, _knus, _boaz,
   {{0x25560017,0x69dc1f60,0x463a4052,0x777ac0b9}},	//   vāls_, vure, פערע, altx,
   {{0x60c45f61,0x7bdd1f62,0xa2d7c045,0x69dc0efc}},	//   vaim, gusu, _मयप्, wure,
   {{0x25560017,0x395fd9b6,0x7afc0c3e,0xdbd200b2}},	//   tāls_, lnus_, uert, müüj,
   {{0x26c100b6,0x2cab0359,0xd62a00c5,0x7bc9df63}},	//   _deho_, éidí_, чове_, lseu,
   {{0x69dc1f64,0x7afc0129,0xeaa00031,0x273640b0}},	//   rure, sert, _biṣu_, _tænk_,
   {{0x03961585,0x01635000,0x39400105,0xddd8c077}},	// [19a0] _проя, укто, _ilis_, _izvš,
   {{0x2d99414b,0x63a44947,0x2d8dc05c,0x2d9e010b}},	//   _eise_, rqin, hmee_, ítes_,
   {{0xaaddc874,0x7d09817b,0xf772005f,0x2bd28c4b}},	//   _माईक, _baes, _لاگ_, _सिहा,
   {{0x0ee248c5,0xdb1d44c9,0x7d1b805e,0xfd1f40d1}},	//   _पावड, _avsä, _cnus, _thìa_,
   {{0x3ce10027,0x62810166,0x2d52004f,0x26c100f8}},	//   कलते_, ýlov, jšem_, _yeho_,
   {{0x23a60038,0xae1fc281,0xa5a48036,0x69a48045}},	//   _môj_, यमान_, _चंदौ, _चंदी,
   {{0x7a46c669,0x6b634dc8,0x39401f65,0x7dea803a}},	//   _mété, _скра, _olis_, _kəsi,
   {{0x213f9361,0x657bc986,0x59768007,0x3f9a1f66}},	//   _gluh_, gluh, _чыгу, _lipu_,
   {{0xe813508d,0xab6690f3,0x1be7c6b1,0x7c244004}},	//   ठिया_, _звал, едњи_, nxir,
   {{0xc808c0d1,0x798d4036,0x8fa39654,0x68e29f67}},	//   _vở_, zmaw, _сафе, lgod,
   {{0x2bd30d6c,0xb1e58032,0x0ae98a87,0xf41fc0b2}},	//   _तिहा, _لأنه, _ترقي_, äär_,
   {{0xbcfb402e,0x7dea803a,0xdced42a3,0x2245406a}},	//   _ajén, _nəsi, mlać, _ülke_,
   {{0x6d44434c,0x68e28112,0xb4db40d2,0x7afe5f68}},	//   dhia, igod, _llàc, kept,
   {{0xf53f5060,0x69de5f69,0x8c1bc3bd,0x39520033}},	//   _slå_, kupe, _מודי, _emys_,
   {{0x7bdd1f6a,0x798d4b64,0x92680ceb,0xbb83c1b4}},	//   susu, tmaw, ерта_, _حلوي,
   {{0x28db0027,0x613cdd05,0x4a7bc0c3,0x25ac07cb}},	//   _भाटि, _mélo, _מרוב, ídla_,
   {{0x9f9ac025,0x7d1d8060,0x68e29f6b,0xdce44138}},	// [19b0] pään_, _òssi, dgod, sliğ,
   {{0xade4df6c,0x65c7405f,0x78a24038,0x7d099f6d}},	//   _कमान_, _néhá, ľova, _saes,
   {{0x2d520166,0x69ca8077,0x6d444311,0xb6064017}},	//   dšej_, jsfe, bhia, jušā,
   {{0x3ce6c046,0xacbb4669,0x69ca8655,0x3f9a1f6e}},	//   _ncov_, _coût, dsfe, _zipu_,
   {{0x66e59065,0x6568403e,0x7d09809d,0xb4cd4e1a}},	//   вола, édhe, _vaes, रणी_,
   {{0xe0df429a,0x613cc303,0x6b9a9f6f,0x26c5c03c}},	//   _blòg_, _bélo, _citg, xalo_,
   {{0x69ca8d2f,0x657bc5bb,0x7a3c0051,0x6135c086}},	//   gsfe, tluh, mätö, _málv,
   {{0xc1790007,0x26c34024,0x6d589f70,0x3e8680a0}},	//   itės_, _hejo_, évat, _sítí_,
   {{0x63b48066,0x60c2c061,0x78a9df71,0x6c57c031}},	//   čený, _deom, rcev, _bálẹ,
   {{0xc6bc0079,0x88bd8036,0x7d0d4051,0x395fdf72}},	//   _অঞ্চ, _pośw, hdas, snus_,
   {{0x39400da9,0x61460b24,0x26c35f73,0x7d1d414b}},	//   _plis_, вена, _mejo_, _onss,
   {{0x26c35f74,0xaca3c044,0x3f9a005c,0xd14bc032}},	//   _lejo_, _kpọm, _sipu_, _عشان_,
   {{0x60c6006a,0x6d565f75,0x69dec0d9,0xaae24048}},	//   rakm, viya, _åpen, _पालक,
   {{0x27eddf76,0x7d0bc10d,0x78ad0053,0x60c61f77}},	//   mten_, _hags, _efav, sakm,
   {{0x7d0bc010,0xe5a601cc,0x50b61534,0x26c79f78}},	//   _kags, тиби, _испу, iano_,
   {{0x7529df79,0x26129077,0xc5635f7a,0x7c2441a8}},	//   njez, थिती_, акск, txir,
   {{0x6d4447c5,0x7a46df7b,0xc2e8c079,0x26c35f7c}},	// [19c0] rhia, _tété, _কোটি_, _bejo_,
   {{0x69de456e,0x26c79f7d,0x98a000b3,0x7d0d5f7e}},	//   tupe, jano_, _boić_, adas,
   {{0x200d403f,0x333b03bd,0x6449c0fa,0xa3e4808f}},	//   _šeit_, _חתימ, hzei, पून_,
   {{0xe8d90015,0x69de5f7f,0x64a65d10,0x6c864032}},	//   _thụ_, rupe, _шама, _للجم,
   {{0x6d5d001e,0xc0e384df,0x799b888b,0xead487fe}},	//   érai, рочк, _diuw, голь,
   {{0x27edc36b,0x6135c086,0x2734009d,0x68e29f80}},	//   dten_, _málu, _tänu_, sgod,
   {{0x5fd4c834,0x63a41f81,0x212fc05e,0x27e041b1}},	//   _दिहल, _luin, _bogh_, luin_,
   {{0x61385f82,0xfbd30384,0x613cc01e,0x6b9a8a26}},	//   _bíli, _तिलम, _vélo, _witg,
   {{0xed57943c,0x27e05f83,0x6135c05f,0x3cea49fd}},	//   _рот_, nuin_, _nálu, _छाने_,
   {{0x6b9c4067,0xbcfb4031,0x87b780c3,0x81abc079}},	//   _jirg, _ajél, _סלבס_, গঠন_,
   {{0x60c41f84,0x273404c9,0xceb8d286,0x2cad802c}},	//   _beim, _läns_, rbę_, _yfed_,
   {{0x2924c066,0x291dc0f8,0x27eddf85,0x518706b1}},	//   ávač_, _gnwa_, bten_, ђуна,
   {{0x60c41f86,0x1bd4df87,0x29005f88,0x67d4dedf}},	//   _deim, _соля, deia_, _солу,
   {{0x27e05f89,0x752f4062,0x9f404025,0x260f04ef}},	//   duin_, _socz, ntiä_, डिली_,
   {{0x78a24166,0x6d42c240,0x290b5f8a,0x629c8089}},	//   ľovn, _kloa, _paca_, _úrod,
   {{0x6d461f8b,0x290041ff,0xc1790007,0x6d87005f}},	//   chka, geia_, rtės_, _جمعہ_,
   {{0x2bda4b6d,0x39591f8c,0x26c79f8d,0xc1790039}},	// [19d0] यंगा, miss_, yano_, stės_,
   {{0x69dadf8e,0x7d00c4c9,0x46a70b35,0x3d19c549}},	//   orte, hems, _खलिह, _मोने_,
   {{0x44269f8f,0xb05b40fa,0x26c35f90,0x63a4015d}},	//   exo_, _geän, _vejo_, _zuin,
   {{0xdce2c1d6,0x39591f91,0xb33c8085,0x7bcb8838}},	//   _djoċ, niss_, _jiħf, tsgu,
   {{0x7dea803a,0xc6a74687,0xd25040fb,0x63a241b4}},	//   _məsu, _арби, منے_, íont,
   {{0xf77f0696,0x39468011,0xdce0c0a0,0xaed286b1}},	//   ftçi_, ahos_, pomě, бољш,
   {{0xb0628051,0xdb064047,0x4999cdd2,0xa3e5c048}},	//   _ääni, _utká, нтия_, बून_,
   {{0x2409dafc,0x26c79f92,0x6b9c5f93,0x6009df94}},	//   ении_, sano_, _zirg, еним_,
   {{0xf8ae805f,0xc95282a6,0x9f400086,0x753bc077}},	//   _رکن_, _המן_, _opið_, rkuz,
   {{0x2b1c4036,0x26c3cfc2,0x48164052,0x6b4050e8}},	//   नाएँ_, újo_, אַטן_, _lögn,
   {{0x7ae54269,0x27e05f95,0x60e8c041,0x28dcc46d}},	//   ight, zuin_, ärmö, _याचि,
   {{0x7d0d0057,0x6e2146ed,0x6d124045,0x27e04340}},	//   _caas, _àlbu, _ढोंग_, yuin_,
   {{0x25a59f96,0x9f59801f,0x68e9809c,0x6ee08112}},	//   _hull_, _ésó_, _mced, _ịbid,
   {{0x60c41f97,0x257c9f98,0x91e612ff,0x3ea1099e}},	//   _weim, ríli_, логе, _cght_,
   {{0x7d0d1f99,0x39591f9a,0x29005f9b,0x63a9c13b}},	//   _faas, biss_, teia_, lqen,
   {{0x3f9cc158,0x61ee1f9c,0x2d9503d0,0x6b9c595d}},	//   _zivu_, rtbl, _крыс, _sirg,
   {{0x61ee1f9d,0x21201f9e,0xf2da46b0,0x6d599f9f}},	// [19e0] stbl, _inih_, فظات_, diwa,
   {{0x7bdbc05c,0x61e1c018,0x68e45fa0,0x273404c9}},	//   iruu, oull, sgid, _väns_,
   {{0x637dcacd,0x3a250041,0x21200047,0x26ca1fa1}},	//   gèni, älpt_, _knih_, mabo_,
   {{0x2bd4cb26,0x4426824d,0x2d9dc43a,0x106a8156}},	//   _दिला, txo_, _niwe_, нией_,
   {{0x65629fa2,0x65644044,0xa2ba0ebe,0x7d00c125}},	//   rnoh, mnih, ्रप्, vems,
   {{0xfaa35fa3,0x6b9c4061,0x29021fa4,0x2d804361}},	//   _гаро, _uirg, heka_, llie_,
   {{0x6d42c119,0x290214a4,0x637dc016,0x2d9dd24b}},	//   _ploa, keka_, cèni, _biwe_,
   {{0x9f40404c,0x26ca0057,0xaea142d6,0x237a0033}},	//   stiä_, habo_, ğışl, _lkpj_,
   {{0x7d0d1fa5,0xbc6681bd,0x69c181b7,0x6b46810d}},	//   _raas, _свак, _ewle, _aðge,
   {{0x3706dfa6,0x7d0d1fa7,0x8ff7c1b4,0x6135ca5d}},	//   учив, _saas, ارير_, _báls,
   {{0x7d0d1fa8,0x3f82c279,0xa2ba16c0,0x60c9c17b}},	//   _paas, ēku_, ्रन्, baem,
   {{0x64a6dfa9,0x637040fa,0x98a6ca23,0x3f9cc12c}},	//   _сада, gänz, _сиде, _wivu_,
   {{0xb9540051,0x6d440061,0x3f9cc157,0x2d805faa}},	//   свящ, _dlia, _tivu_, dlie_,
   {{0x6d56031c,0x2d805fab,0x160443a8,0x237a00f6}},	//   _emya, elie_, रबार_, _ckpj_,
   {{0x69ce1fac,0x25a58018,0xa5f80594,0xae17809d}},	//   gsbe, _xull_, леру_, थियन_,
   {{0x99d3c05f,0xb33b4060,0x7bc2c0b6,0x6ee24047}},	//   _اتوا, _puço, _kwou, _पाउँ,
   {{0x69dc1fad,0x2bc68185,0x909940c5,0x9f554b69}},	// [19f0] arre, रीमा, тват_, авач,
   {{0x6d44002d,0xb4db4060,0x63a65fae,0x7ae540c3}},	//   _zlia, _glàn, _dukn, ught,
   {{0x05794032,0x26c580ec,0xa3e14045,0xdb09c01f}},	//   _لمدة_, _relo_, _धमक_, speç,
   {{0x78a49bee,0xdef8817a,0x6b404041,0x112880c5}},	//   živn, _abċ_, _högl, лючи_,
   {{0x3949424f,0x02c59041,0x752d5faf,0x61e1dfb0}},	//   mhas_, айло, mjaz, zull,
   {{0x7bda40c3,0x9732449b,0xaae24185,0x2d9ddfb1}},	//   _בקשו, _وکلا, _पाएक, _siwe_,
   {{0xddc2923a,0x7d0f5606,0xb0b50028,0x65c28623}},	//   общи, _kacs, ंडाग, обща,
   {{0x25a58315,0x8cc8871d,0x6f01c0cb,0x2fcddfb2}},	//   _vull_, _موفق_, welc, tseg_,
   {{0x44294339,0x2d53c156,0x613f00da,0x29021fb3}},	//   nxa_, nţei_, _vëll, veka_,
   {{0x60cb871c,0xefb281aa,0x7bdbc057,0x78a2c157}},	//   lagm, _بیوگ, rruu, _egov,
   {{0x24891fb4,0x2d8d8022,0xa3e80e80,0x7bdd1b39}},	//   _azam_, _khee_, मून_, ersu,
   {{0xa3e5c028,0x6f038e6e,0x2bddc08f,0x26ca1fb5}},	//   बंद_, lenc, _मिपा, wabo_,
   {{0x752d5fb6,0x7bc2c565,0xc60e009d,0xb4db5cbf}},	//   djaz, _gwou, ाट्य_, _plàn,
   {{0x6d49dfb7,0x3f9e1fb8,0x6d5bc12c,0x37760097}},	//   lhea, ötu_, liua, рымс,
   {{0x4279c009,0x24891fb9,0xed5a4dd2,0xf679c009}},	//   _באַג, _ezam_, вов_, _באַמ,
   {{0x6d440150,0x65699fba,0x26c7c02c,0x798d01d6}},	//   _ulia, _njeh, _heno_, _ghaw,
   {{0xe4f8c2ea,0x0c264f34,0xf99f5fbb,0x60cb9fbc}},	// [1a00] ्जति_, шман, _diè_, dagm,
   {{0xe6c54032,0x200b405e,0x657b9fbd,0x20194147}},	//   متمي, _dsci_, _akuh, _drsi_,
   {{0xaadb0093,0x32db03bd,0x200b423f,0x7d029664}},	//   _בחיר, _בחינ, _esci_, teos,
   {{0x60cb8010,0x387f8303,0xc05a84f5,0xd94686b1}},	//   gagm, _byur_, кіл_, једи,
   {{0x3f9e9fbe,0xfaa64b54,0x5f068abe,0x212dc514}},	//   _pitu_, _ваго, изда, djeh_,
   {{0x9f53913b,0x657b800b,0xb87b42cd,0x06d8002a}},	//   овіч, _ekuh, _acíw, দ্রি,
   {{0xe607c425,0x6ce60027,0x2bd28185,0x84e609fd}},	//   _بش_, _कांग_, _सिका, _कांट_,
   {{0x291240bb,0x62888c90,0x23ab80b0,0x290fc5d1}},	//   ndya_, _vzdo, _føj_, _caga_,
   {{0xa2e69fbf,0xb8feceb4,0xdcf181b7,0x27f241f4}},	//   _возд, _तय_, _żgħa, ntyn_,
   {{0x752d5fc0,0x6370404c,0x6da3841b,0x78a41fc1}},	//   zjaz, täny, _rđav, _agiv,
   {{0x63b61fc2,0x39405fc3,0x24800396,0x764dc020}},	//   _atyn, kkis_, _ayim_, _ƙaya,
   {{0x9257c025,0xdb06413b,0x7d044025,0xd5b8c8c7}},	//   рают_, _bukë, jeis, rpā_,
   {{0x661a8077,0x26c7c43e,0x7416d006,0x386d006a}},	//   _hrtk, _feno_, _خوشا, çer_,
   {{0x79a6c47f,0x78a400bc,0x6b44c321,0x637f81ff}},	//   _крие, _egiv, _fòga, têni,
   {{0x7aefc066,0xf99f4c98,0x290fdfc4,0xd90f0de9}},	//   žitý, _piè_, _yaga_, _قید_,
   {{0x6f039fc5,0x6d40dfc6,0x9f494032,0x290fc1c8}},	//   zenc, nkma, rtaí_, _xaga_,
   {{0x63a4c0c4,0x7d0f5fc7,0x7522c224,0x6d40c206}},	// [1a10] _èind, _vacs, _mnoz, ikma,
   {{0xec71c81b,0x2904dfc8,0xf7704b3f,0x3946c018}},	//   פֿן_, hema_, وال_, _llos_,
   {{0x55594844,0x6d40dfc9,0x3940423b,0x2d52004f}},	//   _баня_, kkma, bkis_, ršev_,
   {{0x2bd282f6,0xfcab416a,0x61384359,0x79829fca}},	//   _सिखा, _جادو_, _díls, glow,
   {{0x60cd5fcb,0x395943e9,0xed58811b,0x6569813b}},	//   maam, _imss_, шої_, _vjeh,
   {{0x7db748a7,0x3946dfcc,0xa3e80a1b,0xbcfb0066}},	//   _نصرا, _alos_, मंत_, dném,
   {{0xdd9b8156,0x6eba08b8,0x69de4077,0x48e80048}},	//   _аша_, ्रतु, crpe, _झालो_,
   {{0x657b8339,0x6d5d1fcd,0x2904dfce,0x6f0540c9}},	//   _ukuh, jisa, gema_, lehc,
   {{0x26ccd328,0x26c7dfcf,0x613cc018,0x67355fd0}},	//   fado_, _peno_, _xéli, _kozj,
   {{0x7c29c03c,0x43858032,0x2bddc17e,0x27ff8231}},	//   rxer, _الطق, _मिठा, _ipun_,
   {{0x61e54056,0x7c3bd367,0xb4db41c0,0x78acc011}},	//   nuhl, syur, _alàm, _šovš,
   {{0x200bc065,0x26c7de11,0x5187d0a1,0x6aa50085}},	//   æcis_, _weno_, _туза, _aghf,
   {{0x4174c1b4,0xa3df03b0,0x6d59dfd1,0xd3a7c42e}},	//   _بالس, दंग_, _imwa, _треп,
   {{0x61e54339,0x59a74021,0x3959406f,0x9f404032}},	//   kuhl, गदार, _amss_, stiú_,
   {{0x63bbdfd2,0x6ade4079,0xe643011b,0x68ed005e}},	//   lpun, ন্ডো, перп, _fcad,
   {{0xccc6076b,0xfd120d72,0x661cc065,0x420580e9}},	//   _убий, _رجب_, ærke, _शनैः_,
   {{0xa2ba008f,0x63a99fd3,0x29125b85,0x65798157}},	// [1a20] ्रद्, _nuen, rdya_, dowh,
   {{0x39405fd4,0xaa46135b,0x613cdfd5,0x27f242cd}},	//   skis_, _геол, _véli, rtyn_,
   {{0x61e55d3c,0x7d04480a,0x6d59d415,0xe9da4bb4}},	//   guhl, peis, _omwa, уке_,
   {{0x0c268e99,0x2904c018,0x68e9c0a8,0x60cd4149}},	//   ймен, xema_, jged, caam,
   {{0x69d5c047,0x68e9cb32,0x7982814d,0x9c13c1c0}},	//   ázej, dged, rlow, _dọki,
   {{0x6d5d1fd6,0x7d060f4c,0x62818007,0x25720804}},	//   zisa, heks, _bylo, rály_,
   {{0x26d85fd7,0x3d19c045,0x63a981ff,0x63a19fd8}},	//   _idro_, _मोहे_, _euen, _diln,
   {{0x26ccc094,0x463b481b,0x26ca42bc,0x57b4dfd9}},	//   wado_, _געלע, _hebo_, обит,
   {{0x26ca5fda,0x63a19fdb,0xdb0181ff,0x6fd8c048}},	//   _kebo_, _filn, _milê, _मिळू,
   {{0x6d5d1fdc,0xeb9a93f4,0x75241fdd,0x9df8c01b}},	//   wisa, _сиз_, _aniz, анот_,
   {{0xdd950efa,0x528681b4,0x2904c4fd,0xa016c1aa}},	//   жаны, _الاك, pema_, _گذاش,
   {{0x63a18156,0x2b5a0018,0x2fdfdfde,0x2600454a}},	//   _ziln, _ampc_, brug_, _रहनी_,
   {{0x69da0166,0x79845a9a,0x317bc323,0x4aac809d}},	//   áten, dliw, _גראמ, _चलाव,
   {{0x7c220054,0x6b810112,0x1659c01c,0xdb0b8377}},	//   _šorc, _ịgbo, اسیک_, ppgå,
   {{0x67355fdf,0x644f1243,0x20000053,0xdce98017}},	//   _rozj, szci, _epii_, _pieļ,
   {{0x9f5dc0ce,0x2d520047,0xdd910032,0x6d5d1fe0}},	//   _apwè_, ušet_, _توب_, qisa,
   {{0x29068232,0x394900f8,0x2ca6c35d,0xe5344125}},	// [1a30] deoa_, _ilas_, _mgod_, четь,
   {{0x21248053,0x200956ce,0xdb008060,0x26ca4073}},	//   _anmh_, rwai_, _numà, _cebo_,
   {{0xe535404c,0x60cd4051,0x51878039,0x8afcc036}},	//   _день, paam, буда, międ,
   {{0x25aa5fe1,0xa301849d,0x60cd4d31,0x443d8062}},	//   _dubl_, लज्ज_, qaam, tyw_,
   {{0xbcfb001e,0x26ca4bc2,0x777ac1a8,0x6d4d4820}},	//   ciée, _febo_, kotx, mhaa,
   {{0x8afcc036,0xdced4451,0xfbdc02ea,0x443d802c}},	//   nięd, mlađ, _बिसम, ryw_,
   {{0x63bc80e5,0x260f08b8,0x7d061fe2,0xc5d580d9}},	//   _črne, डिटी_, yeks, ціль,
   {{0x261a854a,0xdb1600b6,0x9c134044,0x0524002a}},	//   _मछरी_, _etyè, họmm, _পত্র_,
   {{0x7d0618be,0x98a94038,0x2ba50a89,0x200d810b}},	//   veks, kiaľ_, _गंगा, _usei_,
   {{0x39490b0e,0x6d5ec2cb,0x3d19dfe3,0xe1f9dd91}},	//   _alas_, épar, _मोरे_, аго_,
   {{0xdced491c,0x6d4d5fe4,0x6f070047,0x6d484017}},	//   hlađ, khaa, dejc, ūdai,
   {{0xdced5f2f,0x78a2406f,0x69dcc319,0x6d5d0669}},	//   klađ, žovi, área, érap,
   {{0x31c64ca7,0x60cbc0c7,0x777ac0b9,0x06ee0063}},	//   _लब्ध, _iegm, botx, _जादव_,
   {{0x6d428e07,0x63abc02f,0xdb01810b,0x29121fe5}},	//   zkoa, _iugn, _silê, _waya_,
   {{0x417604fc,0x6d5f4aef,0x26ca45b2,0x3392c1aa}},	//   _وابس, fiqa, _rebo_, _تلوز,
   {{0xbcfb05e5,0x973c8077,0x395fdfe6,0xd012405f}},	//   jnéh, _mića, nius_, ولز_,
   {{0xfd1f400c,0x27e05fe7,0x3ce60374,0x6283c02c}},	// [1a40] _nhìu_, urin_, कलीं_, _hyno,
   {{0x6283dfe8,0x23e082ea,0xdee344c4,0x63abc0c4}},	//   _kyno, _निबद, дофи, _mugn,
   {{0x316d80b3,0x9a6a41b4,0xdce45fe9,0x2aeb4314}},	//   _bjez_, جمال_, lnič, _चारु_,
   {{0x98a6819b,0x27e6829e,0x6283c0b1,0x7c2d40d2}},	//   циде, tuon_, _myno, bxar,
   {{0x6d4281a8,0xe5a38d37,0x6569c02d,0x34a740d9}},	//   rkoa, фици, dneh, _євро_,
   {{0xadc30171,0x6d445fea,0x6d5b817b,0x27e6802f}},	//   _afẹd, lkia, _emua, ruon_,
   {{0xb53a0031,0x6569c0cb,0x56939feb,0x63abc6eb}},	//   _akọ́, fneh, машт, _augn,
   {{0x387f0283,0x63a3c510,0xbcfb0066,0xad268301}},	//   żuri_, _ainn, cnéh, _برسو,
   {{0xfd4f4015,0xa3e5c045,0x61e1c018,0x46bf0047}},	//   _phiế, बूल_, erll, ्रमह,
   {{0x60c29fec,0x321ccc81,0x7d165fed,0x2cb1c0a0}},	//   lbom, _prvy_, hdys, ězda_,
   {{0xd013402a,0x63a3c28f,0xa2ad5fee,0x171b4052}},	//   সময়_, _dinn, _जलस्, בויע,
   {{0x2d92005c,0x8fa6c445,0xe9b780fb,0xda658032}},	//   _chye_, _даде, _بچوں_, _عالي,
   {{0x4f65c05f,0x06d54079,0x6840c031,0x63abc157}},	//   _کانف, স্টি, _dádú, _gugn,
   {{0x26cc9fef,0x9377c032,0x6283c14d,0xb4db0060}},	//   _jedo_, _وصور_, _fyno, ckàn,
   {{0x6283c02c,0x28c80045,0x68eb84c9,0x6d9341cb}},	//   _gyno, लरशि, yggd, nçag,
   {{0x61e8c105,0x7c2d40fc,0x26cc9ff0,0x2afd4047}},	//   mudl, txar, _ledo_, र्नु_,
   {{0x61e8dff1,0xdce4456e,0xb2ab4800,0x545543dc}},	// [1a50] ludl, cnič, атеж_, чват,
   {{0x6d5b85ef,0x6e234041,0x6d5f400b,0x65b340f6}},	//   _smua, ånbo, siqa, _aħha,
   {{0xab9801b4,0x26d100b6,0x20024011,0x61e8c71c}},	//   _بخير_, mazo_, _epki_, nudl,
   {{0x6d444145,0x443fdff2,0x394dc13b,0xaba8001c}},	//   ckia, yyu_, xhes_, _دهیم_,
   {{0xe8d90044,0x6fc68578,0x6569c166,0x2bc68185}},	//   _amị_, रीलं, vneh, रीला,
   {{0x2126c02f,0x657d1c54,0x63ad1ff3,0x973c8011}},	//   _anoh_, hosh, _muan, _pića,
   {{0xeaf881b4,0xe5738865,0x61e8cdf5,0x69d51ff4}},	//   ترنت_, _قطر_, judl, nsze,
   {{0x657d1ff5,0xb4db4321,0x63a3c35b,0x2bff454a}},	//   josh, _blài, _sinn, _उहां_,
   {{0x442dc10b,0x26d11ff6,0x69dcc17c,0xb4db4321}},	//   uxe_, kazo_, áren, _clài,
   {{0x6d444232,0x657bc047,0x26cc81c8,0x394ddff7}},	//   zkia, souh, _gedo_, shes_,
   {{0x26d11ff8,0x443fdff9,0x394dc01e,0x69d50036}},	//   dazo_, syu_, phes_, jsze,
   {{0x657d1ffa,0x63a3dffb,0xa96a1ffc,0xdcfb8123}},	//   gosh, _winn, сима_, _okuč,
   {{0x63a51ffd,0xdb019ffe,0x81ad8079,0x4acb44ef}},	//   _bihn, _ailé, _কবি_, िराव,
   {{0x63a3c5ef,0x26d10019,0x7bc9812c,0x63a50303}},	//   _uinn, gazo_, _mweu, _cihn,
   {{0x69d5005f,0x21394b39,0x63ad005e,0x29d70283}},	//   gsze, _bosh_, _euan, għa_,
   {{0x20024056,0x63bb9fff,0xb33b401f,0x60dba000}},	//   _ppki_, _otun, _muçu, _ndum,
   {{0xa3d61f38,0x945f80e2,0x21396001,0x63bb9e3f}},	// [1a60] _हिट_, _fāɗ, _dosh_, _ntun,
   {{0x6d46004c,0x629a4066,0x6d5d6002,0x26d12003}},	//   lkka, _útok, _emsa, cazo_,
   {{0xdb018396,0x63ad2004,0x42564376,0x6440d191}},	//   _gilé, _zuan, чтат, zymi,
   {{0x63ad0020,0x44202005,0x68fbc0b3,0x2be08945}},	//   _yuan, _kri_, jfud, _निदा,
   {{0x25bf41be,0xb4db402e,0x7d161700,0x2608417e}},	//   _čule_, _alàw, _mays, _सनकी_,
   {{0x7d160057,0x657d2006,0x69c880f8,0x2fc0413a}},	//   _lays, zosh, _pwde, mpig_,
   {{0xdb0f4107,0x290000eb,0x945dc036,0x63bba007}},	//   _utcá, _obia_, kańs, _etun,
   {{0x23dc2008,0x26d10019,0x6da3c169,0x3869c247}},	//   _बिंद, zazo_, нија, _žara_,
   {{0xebe3820f,0x69d51243,0xdb0080b0,0xb4ca05da}},	//   _потп, zsze, _rumæ, _लड़े_,
   {{0x68ed6009,0xd7ddc08f,0x6562a00a,0x61e8c71c}},	//   zgad, _मिरच, lioh, tudl,
   {{0x7d09e00b,0x67288283,0x69da200c,0x20120024}},	//   bees, _indj, štej, _asyi_,
   {{0xe0df4053,0x9c870089,0x14cca00d,0xdb03c0ce}},	//   _elòj_, _ničí, ारिण, _linè,
   {{0x69d50064,0x7d160d31,0x7c83cf8d,0xa3cf8298}},	//   wsze, _days, _пуше, वीप_,
   {{0x657d200e,0x8fa3c7e1,0x63a20157,0x63ad013b}},	//   sosh, _заче, _èonl, _vuan,
   {{0x6fd9008f,0xb604011e,0xd90f41aa,0x69170018}},	//   _भटकं, нятк, هید_, güeñ,
   {{0x7d160057,0x657d1dc4,0x39920018,0x26d1200f}},	//   _gays, qosh, táse_, sazo_,
   {{0x21290070,0x84eac021,0xdb03e010,0xdb0bc303}},	// [1a70] _inah_, _टाईट_, _binè, _bugè,
   {{0x69d52011,0xfbd20093,0x76ab6012,0x4de0c027}},	//   psze, _שתי_, став_, _खटाई_,
   {{0x213942cd,0x7d09d238,0x442bc0d1,0x29094051}},	//   _tosh_, yees, ̣c_, peaa_,
   {{0x290b10d0,0x2bddc07a,0xdb0bc4e2,0xf41f4041}},	//   neca_, _मिला, _eugè, _trä_,
   {{0x6843402e,0x6dac40b4,0xdb03e013,0x2ba74048}},	//   _dídú, _aşad, _finè, _कंटा,
   {{0x290b2014,0x2be24a94,0xd040c03a,0xa49b43bc}},	//   heca_, _पिता, qamə, _ebòc,
   {{0xe8d901c0,0x2486c303,0xe51ed3a2,0xf8ae805f}},	//   _amọ_, _ayom_, _मोहि_, اکہ_,
   {{0x290b1295,0xf9938646,0x6b40410d,0x0c25e015}},	//   jeca_, _سبز_, _dögu, дмин,
   {{0x395fa016,0x25a6e017,0x46bf04fb,0x7529a018}},	//   _imus_, _diol_, ्राह, _inez,
   {{0xb4e60191,0x7d162019,0x673a8570,0x63af47ca}},	//   कल्प_, _says, _gotj, _mucn,
   {{0x7d160669,0x6d4bc02f,0x753ba01a,0x69d74018}},	//   _pays, _tlga, _kouz, nsxe,
   {{0x63a741d4,0x7d16201b,0xdb03e01c,0x77638018}},	//   _lijn, _qays, _miné, linx,
   {{0xdde0c0a0,0x78abc085,0x799be01d,0x316dc379}},	//   ětši, _iggv, mmuw, mnez_,
   {{0x2f18c051,0x9f40401e,0x6d46201e,0x7d160149}},	//   _ночь_, prié_, skka, _ways,
   {{0x6b500969,0x316dc0b4,0x7989c2c0,0x7d16201f}},	//   _näge, onez_, olew, _tays,
   {{0xa01b4051,0x799bc6df,0x656d6020,0x290002c0}},	//   _työl, nmuw, gnah, _ubia_,
   {{0xa01b4107,0xdb03e021,0x316de022,0xd7f94125}},	// [1a80] _ször, _ainé, inez_, зує_,
   {{0x49ba0d9e,0x6442812c,0xa3e5c5da,0xdb040060}},	//   _واجد_, vyoi, _फिन_, _etiò,
   {{0x973c8077,0x6562a023,0x5f188045,0xb7d4c031}},	//   _sićo, tioh, _योग्_, _iṣeb,
   {{0x273f40b4,0x9c82c5e5,0x6b44c29a,0x9cb6401c}},	//   _sînt_, íčko, _eògh, _زمست,
   {{0xdca3a024,0xb4db4016,0x798402c0,0x6b44c29a}},	//   ваци, _clàu, _mkiw, _fògh,
   {{0x290b0054,0x25a6e025,0x56948157,0xe4570052}},	//   zeca_, _siol_, налт, וינט_,
   {{0x63af441b,0x7bcbc17a,0xfbb0402a,0xfaa3423d}},	//   _zucn, _awgu, _ছবিত, _ааро,
   {{0x61eaa026,0xb814c217,0x61f88b32,0x75298d75}},	//   rufl, едиј, rtvl, _gnez,
   {{0xd007c01b,0xa91dc6f0,0x2afb809d,0x00838156}},	//   дење_, dožd, ल्हु_, _алто,
   {{0x753b976b,0xc43b80c3,0x7bc2a027,0x76438977}},	//   _zouz, _ותמי, mpou, byny,
   {{0x25a6c018,0x69c1e028,0x3d19c25c,0xdb03c0d2}},	//   _tiol_, gple, _मोके_, _xiné,
   {{0xa01b4051,0xb7d4c1c0,0x2bd000aa,0xdfcfc534}},	//   _syöm, _aṣeb, तीभा, _چين_,
   {{0x24920064,0x4422411b,0xbcfb00e1,0x6b44c016}},	//   _czym_, _nrk_, bién, _lògi,
   {{0x70ab817e,0x7984031c,0xb4db4060,0xfc67c16a}},	//   _छल्ल, _ekiw, _llàt, _تخمی,
   {{0x63a7415d,0xf1a76029,0x672ac17a,0x656d5d62}},	//   _rijn, дран, _infj, tnah,
   {{0x2129005c,0x98a480b6,0xac950007,0x61e54089}},	//   _unah_, _anmč_, _пайш, vrhl,
   {{0x1eab0032,0xa01b4051,0x78ad009d,0x60cf4017}},	// [1a90] _وادي_, _työm, _igav, _vecm,
   {{0xadf2c632,0xa01b4051,0x69d88a9f,0x6ec00048}},	//   _अमान_, _hyök, ksve, वडणु,
   {{0x69d881d4,0x58d5602a,0x63a740fd,0x27e081b4}},	//   jsve, _понт, _vijn, áinn_,
   {{0xa83541bd,0x69d8a02b,0x7bcd202c,0x24890020}},	//   _земљ, dsve, _kwau, _kyam_,
   {{0xf210c027,0x6d4f40c4,0x69da8147,0x03b60112}},	//   ़बड़_, _ilca, _avte, _ịṅụr,
   {{0x673c602d,0x3949453e,0x7643804c,0xdb0740fd}},	//   _gorj, lkas_, tyny, _mijë,
   {{0x69d8a02e,0x53380009,0x7c22d7bd,0x78ad06f0}},	//   gsve, ונגן_, _aror, _ogav,
   {{0x6e944ba6,0x3f814066,0x69da010b,0x63ad803c}},	//   _рису, lohu_, átei, íans,
   {{0x2d9d9415,0x7989e02f,0x6006c39d,0x39496030}},	//   mmwe_, rlew, еным_, ikas_,
   {{0x7d02c427,0x6b5240b0,0x920f0428,0xe731c032}},	//   _ebos, _vægg, ाबाज_, اصة_,
   {{0xbcfb00e1,0x3949409d,0x25a92031,0xdcfbc0a0}},	//   rién, kkas_, _bial_, louč,
   {{0x2b898166,0x26118011,0x26d16032,0x917ac0d1}},	//   dúci_, _išo_, _lezo_, _vậy_,
   {{0x7d0d5c0b,0xab5d817a,0x92c3802a,0xab644189}},	//   deas, _awżi, ্লী_, lmüş,
   {{0x79460064,0x21f8c88b,0x7d19c057,0x3eac07a4}},	//   _mówi, béh_, _haws, ødt_,
   {{0x7d19c573,0x6b5247a4,0xa3cf8048,0xf8bf4396}},	//   _kaws, _jæge, वीत_, _eném_,
   {{0x41e107f6,0xe3ba46e4,0x39496033,0x6fe0846d}},	//   _फिरस, зба_, gkas_, _निलं,
   {{0x7d04091f,0x6b5004d3,0x29196034,0x2d822035}},	// [1aa0] _ibis, _vägb, _dasa_, moke_,
   {{0x7c240083,0xa01b404c,0x06e34079,0x69d8a036}},	//   _irir, _myöh, ন্সি, ysve,
   {{0x7bdb80bc,0xeef700c3,0x7980e037,0xdb074303}},	//   _avuu, _אמיר_, yomw, _mijè,
   {{0xfd4d8112,0x27ede038,0x96954717,0x656600c2}},	//   _ighọ, kuen_, труш, nikh,
   {{0xd0408080,0x6288826c,0xb4db4060,0x44226039}},	//   _yemə, _sydo, _elàs, _urk_,
   {{0x9944059a,0x44204150,0x27e0a03a,0x8fa38051}},	//   yış_, mvi_, šino_, гаче,
   {{0x7bc2a03b,0x6ed6e03c,0x27e6a03d,0x3facc079}},	//   spou, _मजबु, sron_, _গবেষ,
   {{0x2900603e,0x9f4dc051,0x442048a1,0x7d0400eb}},	//   nfia_, hteä_, ovi_, _nbis,
   {{0xb603803f,0x888181aa,0x213dc05c,0x69d89e95}},	//   āšan, _پیون, _dowh_, ssve,
   {{0x25a91529,0x61ee203f,0x7980e040,0x26de8010}},	//   _sial_, kubl, somw, _udto_,
   {{0x7980d8e2,0x7986417b,0x7bcd0230,0x290dc17b}},	//   pomw, _okkw, _swau, beea_,
   {{0x6d49e041,0x290284d3,0x7d02e042,0x6c86c032}},	//   ckea, _ökad_, _ubos, _كلام,
   {{0x9f404086,0x39496043,0xe53bc0c3,0x7c22c360}},	//   ytið_, vkas_, _מתאר, _uror,
   {{0x6b81c0c4,0x4ea72044,0xc6a700b4,0x75280017}},	//   colg, ерба, ерби, ēdza,
   {{0x44206045,0x26d143e2,0x41e4011e,0xe610005f}},	//   evi_, _rezo_, літа, یشہ_,
   {{0x69da0669,0x26d140b3,0x39494039,0x6ab940e4}},	//   âtea, _sezo_, ukas_, इड्र,
   {{0x23cf906a,0xb4bf0191,0x26d14570,0x3f816046}},	// [1ab0] _सौंद, ेरी_, _pezo_, tohu_,
   {{0x2aee0064,0xa8a45948,0xb4db6047,0x7d0d6048}},	//   _जाएँ_, урск, _plàs, seas,
   {{0x16bf11c8,0xb8f7402a,0x26c7804f,0x9f404397}},	//   ्रीब, _সা_, vbno_, rtið_,
   {{0xf42a002d,0x9f404086,0x02bb8045,0x64c4dd0c}},	//   späť_, stið_, ॉर्न, nčič,
   {{0x798d6049,0xe3b886bc,0xdbe2c031,0x69dac455}},	//   mlaw, ебі_, _féég, hste,
   {{0x7d19e04a,0x2d680570,0xe8220163,0x27e951a5}},	//   _saws, nđer_, मिता_, mran_,
   {{0xf7708a10,0xc447c08c,0x66154036,0x26c7804f}},	//   حان_, کیشن_, _uszk, rbno_,
   {{0xdb088141,0x6295604b,0xdb0f4303,0x7d1be04c}},	//   _lidè, _izzo, _sucè, udus,
   {{0x7d1bc25c,0x3f83204d,0x798d40f8,0x2365c242}},	//   rdus, koju_, ilaw, tilj_,
   {{0x4f22c051,0x6d4b8018,0x7c849151,0x6d49e04e}},	//   адьб, lkga, _сусе, skea,
   {{0x2d82204f,0x798d5bba,0x1be40c63,0x6d988018}},	//   toke_, klaw, _कटहल_, bíad,
   {{0x8afcc064,0x628ac1f4,0x6b81e050,0x27e96051}},	//   wnęt, _dyfo, solg, kran_,
   {{0x65662052,0x44240359,0x212d8303,0x6594c59d}},	//   rikh, ím_, _mneh_, _сацу,
   {{0x65661a56,0x9f4dc4d3,0x9ad4025d,0x0056c093}},	//   sikh, fteå_, _bịar, _בשנת_,
   {{0x764dc09c,0x64462053,0x2d788123,0x20090545}},	//   _ƙayu, syki, nčec_, _epai_,
   {{0x7d1ba054,0x09d20027,0xa2c1962f,0x2367a055}},	//   _naus, _तबीय, रुत्, hinj_,
   {{0x629ca056,0x7bdbe057,0xe5a36058,0xef1a404c}},	// [1ac0] _úrov, nsuu, рити, мма_,
   {{0xdfcf4032,0xdb088053,0x3eae47fb,0x798d417b}},	//   تيك_, _gidè, øft_, alaw,
   {{0xd5b940d9,0x7c22006f,0xa9a680c5,0x798d40e2}},	//   есі_, _šorh, вижд, blaw,
   {{0x80cc8028,0x69dc0098,0xb7bb401f,0x291b01c8}},	//   ारें, msre, _grão, _xaqa_,
   {{0x6fb38b92,0x798281c8,0x6f1aa059,0x6295417b}},	//   لمنا, roow, _patc, _ezzo,
   {{0x69d86056,0xe8d90112,0x69c54046,0x69dcc017}},	//   áves, _ikụ_, bphe, šrei,
   {{0x2dd781b4,0x290fa05a,0x3999005f,0x69c545ef}},	//   نبية_, bega_, lése_, cphe,
   {{0x3940205b,0xdce60039,0x1514c119,0x26d80545}},	//   _nois_, mokė, удия, haro_,
   {{0x3d17808f,0x5d678ab2,0xdb0f4004,0x26d8205c}},	//   _नसते_, _ритм_, _sucé, karo_,
   {{0x6f1c441b,0xaca400eb,0x2bb54027,0x6d40a05d}},	//   _jarc, _chọw, _अंसा, _homa,
   {{0x28f9190e,0x2bd0008f,0x26d30018,0x7d1b8360}},	//   нень_, तीसा, _rexo_, _yaus,
   {{0x27e984c6,0xfd1f4031,0x39401440,0x7d02a05e}},	//   šane_, _akìn_, _cois_, nfos,
   {{0xdb03c10b,0x6d56605f,0x26d82060,0x2d84c043}},	//   _dinâ, dhya, faro_, mome_,
   {{0x7bc2d29a,0x39990107,0x656400f7,0x61fe4402}},	//   _itou, dése_, _emih, ktpl,
   {{0x1df803d0,0xa49b4031,0x98c70169,0x6b5481c0}},	//   керы_, _ebòl, _испл, _kàgb,
   {{0x2bdc2061,0xdb01856e,0xdef8c283,0xf8d2cb35}},	//   _बिचा, _milá, diċi_, सरिय,
   {{0xa91dc351,0x27e96062,0x7d1ba063,0x58874c4e}},	// [1ad0] noža, uran_, _raus, тыва,
   {{0xdb08801e,0x6d408321,0xdef8c283,0x69c56064}},	//   _fidé, _aoma, fiċi_, tphe,
   {{0x99520066,0x6f1c6065,0x27e95ef6,0x7c2640cb}},	//   láš_, _darc, sran_, _erkr,
   {{0x27e96066,0xfd1f002e,0xbd18811b,0x6f1c6067}},	//   pran_, ndì_, кції_, _earc,
   {{0x2d84cb68,0x6b83a068,0x69da0795,0x2006401e}},	//   dome_, tong, štet, çoit_,
   {{0xdced47ca,0x5ed3802a,0x6459a069,0x26d38004}},	//   inač, _সাহে, rzwi, úxo_,
   {{0x45d4404c,0x2d87801e,0xb5a7859d,0x290f9819}},	//   _восс, înes_, _арай, pega_,
   {{0x2ee9803a,0x99520066,0x2fc68022,0xdb03e06a}},	//   şaf_, káš_, bpog_, _viní,
   {{0xfc31c1b4,0x798980eb,0x38608032,0x7d1b4018}},	//   صحة_, _ikew, úirt_, _óusu,
   {{0x4426e06b,0x25ad8206,0x99520066,0x39401496}},	//   _dro_, _hiel_, dáš_, _sois_,
   {{0x25ad9d92,0x3999005f,0x69c180d9,0x98a00077}},	//   _kiel_, zése_, _utle, _knić_,
   {{0x26d8206c,0x7f41817a,0xab5b00cb,0x6b548580}},	//   waro_, _holq, spül, _vàge,
   {{0x2bddca3c,0x6d4d4057,0x6569c04c,0x79898150}},	//   _मिटा, dkaa, mieh, _mkew,
   {{0x645bc12c,0x6d5a8007,0x6dbac085,0x7f4181d6}},	//   mzui, _įtam, _iċan, _jolq,
   {{0x6d93606d,0x2d788077,0xb063009d,0x8db500d9}},	//   rçan, hčea_, äärs, исті,
   {{0x6f1c606e,0x250804fc,0x26d8206f,0x69dc2070}},	//   _sarc, _شرعی_, saro_, rsre,
   {{0xd0264097,0xe0df6071,0xb4e44036,0xdce0c017}},	// [1ae0] ымай, _alòs_, _नयी_, nimā,
   {{0x7989a072,0x799b86df,0xb8eb6073,0x79862074}},	//   _akew, _ahuw, _र्_, lokw,
   {{0x6f1c6075,0x8afb02a6,0x63b6000c,0x248da076}},	//   _varc, _אפיק, _huyn, _ayem_,
   {{0x291de077,0xed579d5e,0x61fc8041,0xdb09c10b}},	//   _nawa_, лох_, _ärli, mpeõ,
   {{0x23cf8028,0x7f46a078,0x27ffc0f1,0x399ac0fd}},	//   सीलद, ледж, jtun_, nëse_,
   {{0x7d1d6079,0x798609f3,0x7f41805e,0x2d87801e}},	//   _zass, hokw, _colq, îner_,
   {{0x68e4207a,0x7c22a07b,0x26da607c,0xfbe08384}},	//   _odid, svor, mapo_, _निकम,
   {{0x645bc15d,0x27e00011,0x7d1d4c64,0x98a68eb1}},	//   fzui, _ovin_, _xass, _бибе,
   {{0xed578348,0x06f68c59,0x9c12c044,0x385680c5}},	//   _сот_, _مساج, _gọlf, _съвс,
   {{0xdd04c06a,0xa01b4051,0x2d84e07d,0x316941a8}},	//   ırıy, _työv, some_, ziaz_,
   {{0x497512b0,0x55750dae,0x9294d201,0xa294c11e}},	//   илос, игот, ранц, рані,
   {{0x6569c166,0x23af017a,0x5187001b,0x394dd0ff}},	//   cieh, _ażja_, ѓуна, ckes_,
   {{0x071455a8,0x26da4150,0x248d8046,0x765ae07e}},	//   ड़ाव_, kapo_, _xyem_, szty,
   {{0x7c245b59,0x7c2f8018,0x6d42c09d,0xa01b4051}},	//   dvir, _ácre, _hooa, _myöt,
   {{0x26da607f,0x628e4adb,0xf3ff001f,0x200040b4}},	//   dapo_, _nybo, stã_, etii_,
   {{0x63ae4df5,0x69c8c016,0x9d1847e3,0x60d60086}},	//   _aibn, mpde, лост_, _geym,
   {{0x7d1d6080,0x69de6081,0x5ed40079,0xd7e08314}},	// [1af0] _vass, espe, _তারে, _निगच,
   {{0x2b99c01e,0x69c72082,0x799b86df,0x656640f7}},	//   pèce_, ppje, _shuw, _emkh,
   {{0x44290531,0x39425fe1,0x6b8700b3,0xc208005f}},	//   _hra_, _foks_, mojg, _یقین_,
   {{0xe0e7002a,0xdce44036,0xdd86c032,0x7d1f0283}},	//   গ্রহ_, knię, _ذو_, _jaqs,
   {{0x9fdfc079,0x60cd4dc0,0x20004119,0xa3cf8ef0}},	//   _বঙ্গ, mbam, ctii_, वीं_,
   {{0x25ad8101,0x60cd6083,0x26da4bf5,0x2fc96084}},	//   _wiel_, lbam, capo_, mpag_,
   {{0x79862085,0x93c640cc,0x27ffc09c,0x394de086}},	//   yokw, rtăş, wtun_, tkes_,
   {{0x3fe5e087,0x7d1f0aae,0x79a4801b,0x69c52088}},	//   ажив, _naqs, _груе, _mthe,
   {{0xdb16000c,0x44292089,0x67024281,0x9477816a}},	//   _duyê, _nra_, र्वक_, _صدرا,
   {{0x20d3c00c,0x613cc05f,0xab879cb6,0x645bc15d}},	//   ải_, _mély, _субк, rzui,
   {{0x291de08a,0xed5a0030,0x394dc033,0x7d04608b}},	//   _tawa_, вон_, pkes_, yfis,
   {{0xa96a208c,0x399ac0fd,0x6d5a8007,0x6d598033}},	//   тима_, tëse_, _įtak, nhwa,
   {{0x06f7450b,0x60dbc12c,0xa01b4051,0x7d1f00f1}},	//   ुभाव_, maum, _myös, _daqs,
   {{0x39424011,0xb3d78079,0x442c5c59,0x69de608d}},	//   _soks_, _সমাজ, _čd_, yspe,
   {{0x6d9d01b4,0x63ae40e5,0xdb03c10b,0x656b8105}},	//   féad, _ribn, _giná, kigh,
   {{0x60dbc4fd,0xdb160015,0x26da44fd,0x63ae608e}},	//   naum, _xuyê, wapo_, _sibn,
   {{0x1f665aca,0x66e6041a,0xad1b0093,0x27ede08f}},	// [1b00] акам, _копа, _יוקר, nren_,
   {{0x6d44054a,0xd00f02cf,0x9e6604df,0x0e6607ea}},	//   _hoia, _کلی_, _ввод, _вкон,
   {{0x39424039,0xa01b404c,0xa2d98a3c,0x8afcc064}},	//   _toks_, _syöt, _नज़्, więk,
   {{0x1426961d,0x6d441112,0x7c2980c4,0x65664339}},	//   идем, _joia, _brer, _umkh,
   {{0xa91ddbee,0x27ede090,0x6d440060,0x7d098247}},	//   tožn, jren_, _moia, _dbes,
   {{0x6d442091,0x6721c0e5,0x67024891,0x1615c047}},	//   _loia, jdlj, र्शक_, तबार_,
   {{0xa91de092,0x12e90009,0xdbcfc089,0x656ba093}},	//   rožn, אַפּ, _džín, bigh,
   {{0x224740cb,0x7c29a094,0x2d9dc02c,0x291f81a8}},	//   änke_, _frer, _chwe_, _gaua_,
   {{0xdb03c004,0x26d8412c,0xdcfb8077,0xd497c156}},	//   _siná, _kero_, _skuć, ирь_,
   {{0x9abc80f6,0xda26c0d9,0xa91dc04f,0xf2d34052}},	//   _baċe, аємо, ložl, ֿער_,
   {{0xb87b41c0,0x660e405c,0x6b500041,0x6d442095}},	//   _adíl, _jpbk, _vägl, _boia,
   {{0x26d86096,0x7a0a803a,0xb4d54c63,0x8c4841df}},	//   _lero_, _tətb, _सजे_, _kağı,
   {{0x75c1c017,0x7f43c085,0xdcfbc696,0x65764621}},	//   _rēze, _fonq, lluğ, dnyh,
   {{0x26d86097,0x6d562098,0x27e06099,0xfb87059d}},	//   _nero_, _elya, dsin_, рымн,
   {{0x613cc03c,0xf9c4c4e8,0xe8194027,0xdcfbc1df}},	//   _bélx, _احتی, नौना_, nluğ,
   {{0x75208398,0x74f9010b,0x00000000,0x00000000}},	//   _namz, _сеир_, --, --,
   {{0x60dd00f8,0x9627003f,0x442680b3,0x656ba09a}},	// [1b10] masm, _saņē, jvo_, vigh,
   {{0x2ef5142f,0xdb0f5445,0x629a80fc,0xdcfbc06a}},	//   _узор, _tucí, _ozto, kluğ,
   {{0x60dbd18e,0x644b81f4,0xf2d202a6,0x27ede09b}},	//   yaum, wygi, _מעי_, zren_,
   {{0xaca340eb,0x38bd4031,0xe61005d3,0x6f15209c}},	//   _anụb, _dáró_, _کشی_, lezc,
   {{0xf1a44523,0x629aa09d,0x798d1919,0x27ff87b0}},	//   _фрэн, _azto, _mkaw, _qqun_,
   {{0x6b74843e,0x60c2c031,0x6b88db1a,0x27ede09e}},	//   олчу, _afom, jodg, vren_,
   {{0x656b8c47,0x4426a09f,0xcf5804e0,0x798d00bb}},	//   pigh, avo_, שבות_, _okaw,
   {{0xe6780093,0xf8bf4559,0x7415c1b4,0x387e00b4}},	//   יתוח_, _inés_, موعا, ştri_,
   {{0x3f87a0a0,0xb345c10b,0x7f43c070,0xe81e8374}},	//   ponu_, _noçã, _ponq, _मईया_,
   {{0x6d988018,0x4374c0d9,0xaca3c112,0xf20780d7}},	//   nían, жуют, lfịn, _вядо,
   {{0x5e9581b4,0x63a552e4,0x60dbc12c,0xdb0e4303}},	//   _الاط, imhn, paum, _dibè,
   {{0xe8f707fe,0x2d78806f,0x04c9d546,0x6e3640c3}},	//   блю_, jčel_, _صوتي_, צטרף_,
   {{0x69c10047,0x798d0303,0x6d4400b4,0xa3d30048}},	//   ílen, _dkaw, _voia, हील_,
   {{0x644d4f4f,0x798d017b,0xaa4620a1,0x290b4176}},	//   dyai, _ekaw, бегл, _abca_,
   {{0x6d9899a9,0xe81fc045,0x6b6f4007,0xf99f40c4}},	//   dían, बिका_, _mėgė, _bhè_,
   {{0x65698112,0x213fc451,0xe8f740c4,0x60dd0cc6}},	//   _nmeh, njuh_, йлс_, casm,
   {{0x98a360a2,0x7d018107,0xcebac09c,0xaca480eb}},	// [1b20] зите, záró, _haƙa_, _prọp,
   {{0xef1a01bd,0x442b60a3,0x39920107,0x6d5be0a4}},	//   _смо_, _drc_, dási_, hhua,
   {{0x3f8a20a5,0xdce2c123,0x6b590031,0x216a40b4}},	//   mobu_, _smoč, _fìgb, _бини_,
   {{0x10a6a0a6,0x63a54032,0xb4c3da7e,0x69c34032}},	//   биен, amhn, ्रो_, ínea,
   {{0xfecf8079,0xb87b0344,0x26da20a7,0x9f404051}},	//   _রাজধ, caíd, _kepo_, triä_,
   {{0x7afc40ab,0x934640b4,0x33330104,0x6d5bc1ff}},	//   _ucrt, _унге, _xnxx_, ehua,
   {{0xdb03c051,0x0f574052,0x6dbc002d,0xb05b04c9}},	//   _minä, _פילם_, _očam, nbär,
   {{0x26da20a8,0x7d1660a9,0x629c60aa,0xdcfbc2d6}},	//   _lepo_, neys, _izro, rluğ,
   {{0x60ddc086,0xec7a8e97,0x37aac563,0x2d788077}},	//   ðsma, _спа_, лтон_, nčem_,
   {{0x25a00077,0x501b4093,0x60c28093,0x7d1641c8}},	//   _ahil_, נויו, lcom, heys,
   {{0x7179007b,0x6d4660ab,0x3f8a0066,0x7d1641c8}},	//   ибор_, _ooka, dobu_, keys,
   {{0xb4c74048,0xdb0e4231,0xd10a4045,0x6d4660ac}},	//   _उभे_, _dibé, ह्मण_, _noka,
   {{0xd467cf8d,0x7d1660ad,0x752460ae,0x286b0aba}},	//   _лице_, deys, ddiz, урно_,
   {{0x61f500b3,0x96bae0af,0x6d988018,0x6b5480d2}},	//   tuzl, _суду_, xían, _màgo,
   {{0x6d9d0669,0xa3e50185,0x2c048079,0xdb0e4303}},	//   réab, _पटक_, লিয়ে_, _gibé,
   {{0x6d4640e2,0x2b945073,0xdb03e0b0,0x798d0e1d}},	//   _coka, bäck_, _pinç, _ukaw,
   {{0x629c405c,0x661e005c,0x7ff70032,0x7522c011}},	// [1b30] _azro, _espk, _اسعا, _maoz,
   {{0x65698d75,0x7c2d1776,0x25720077,0x657b84c9}},	//   _smeh, _irar, ršle_, _sjuh,
   {{0x50b58179,0x2bb54048,0x26018018,0x0c780de9}},	//   ослу, _अंका, xóo_, _نصیب_,
   {{0x26c160b1,0x26dee0b2,0x6d46c051,0xdb0bc0fa}},	//   scho_, hato_, ökal, _zugä,
   {{0x316dc753,0x0708d4f7,0xdb1d1e7a,0x99714062}},	//   viez_, वभाव_, ppsä, _mąż_,
   {{0xdb074070,0x27e9811a,0x7bcd60b3,0x23299d5e}},	//   _fijá, šano_, mpau, роки_,
   {{0x6d46411c,0x7c2942bc,0xdb088016,0x2d9f800c}},	//   _yoka, _šerh, _didà, _thue_,
   {{0x22aec03a,0x47c5c477,0x6569a0b4,0xfbc5c1cc}},	//   dək_, обив, _umeh, обио,
   {{0x442960b5,0x2fc9004d,0x316de0b6,0x25e58027}},	//   nva_, _ntag_, riez_, _टिकी_,
   {{0x0609c5bd,0x63bb80f8,0x7b778e5f,0x25a020b7}},	//   анок_, _iuun, _اطرا, _shil_,
   {{0x7c2d20b8,0xf8bfe0b9,0x3946c23b,0xdce9e0ba}},	//   _arar, ñés_, _foos_, lieč,
   {{0x6d5d0032,0x4ca80079,0x2d8b20bb,0xdce9c077}},	//   ghsa, _ক্ষু, goce_, dneć,
   {{0xdee5e0bc,0x7c2d0004,0x1b230079,0x6d988018}},	//   _доли, _crar, মানে_, díal,
   {{0xa91dc05b,0x7a0a803a,0x60db829a,0x2b944041}},	//   kožk, _mətn, _leum, räck_,
   {{0x442960bd,0x7c2d20be,0xa3aec048,0xe8d94094}},	//   eva_, _erar, _कळत_, chị_,
   {{0x7d0d0efc,0x2d8b0fb8,0x2480024c,0x6723e0bf}},	//   _gbas, coce_, _txim_, _hanj,
   {{0x6ab24045,0xfe41c05f,0x2bd000b2,0x442960c0}},	// [1b40] जश्र, _رکھی, तीखा, gva_,
   {{0xbcfb0070,0x63694080,0x9696401b,0xdce9d7d3}},	//   biés, _yönə, ореш, dieč,
   {{0x3205c3d4,0x6d4660c1,0x46d00260,0x44200498}},	//   ntly_, _toka, _त्यह, _hsi_,
   {{0x9f49410d,0xa50a8bf8,0x1d0a89d3,0x26dec23f}},	//   stað_, реда_, реди_, zato_,
   {{0x44200185,0x629c4064,0x6dbc0166,0x26dee0c2}},	//   _jsi_, _wzro, _očak, yato_,
   {{0x6723e0c3,0x7c29cae6,0x6d59e0c4,0x7d09e0c5}},	//   _nanj, dver, _alwa, efes,
   {{0x7d09e0c6,0x7c29e0c7,0x66035201,0x644f0064}},	//   ffes, ever, _опра, zyci,
   {{0x752420c8,0x3946d2ef,0x799660c9,0xf8b844ef}},	//   _naiz, _qoos_, nlyw, _अलोप,
   {{0x44201415,0x6d9885b1,0x2d8b08e5,0x3946e0ca}},	//   _nsi_, níam, voce_, _voos_,
   {{0x59d78185,0x3a3a8041,0x8c1b8093,0xc7b98107}},	//   णीहर, äpps_, _דומי, _erős_,
   {{0x2004e0cb,0xb4ab810d,0x2d7893ca,0x75240232}},	//   stmi_, _íþró, jček_, _baiz,
   {{0xa9c3c11b,0x6dbc0123,0x6b60c1c0,0x6f188077}},	//   ьськ, _ečak, _bágù, levc,
   {{0x98b3403f,0x2603c004,0x6369004f,0x2bdd9890}},	//   ādīt_, año_, lžni, नीपा,
   {{0x60c4410b,0xdb018018,0x7053c01c,0x2d8b0047}},	//   ecim, _silú, _تنها, soce_,
   {{0x80ddc079,0xcebac0e2,0x9f404032,0x777ac046}},	//   _যাত্, _haƙo_, briú_, mntx,
   {{0x6723e0cc,0x752400fc,0x3f8cc017,0x7d0d20cd}},	//   _zanj, _gaiz, lodu_, _ubas,
   {{0xbcfb034d,0x60c641c8,0x6d989a7a,0x9f494359}},	// [1b50] biér, _dfkm, ríal, sraí_,
   {{0x3f8cc0f1,0xbcfb0070,0xdb19c88b,0x63bba0ce}},	//   nodu_, ciér, _cuwè, _ruun,
   {{0x5595401b,0x8ed8802a,0xb1158007,0xdb19c231}},	//   _наоѓ, _সাংগ, змеш, _duwè,
   {{0x200680fd,0x7c29c70d,0x621a00c3,0x395940c4}},	//   ftoi_, yver, _פורק, _ulss_,
   {{0x656d0010,0x21248e89,0x3f8ce0cf,0xc9540052}},	//   _mmah, _damh_, kodu_, ומף_,
   {{0x3992005f,0x672520d0,0x21248061,0x77ba40c3}},	//   lást_, _jahj, _eamh_, _למשח,
   {{0xa3cf8045,0x63bd60d1,0x60dd406a,0x7d09e0d2}},	//   वीज_, _husn, _kesm, tfes,
   {{0x63bd444e,0xceb240c3,0x63bba0d3,0x777ac0fc}},	//   _kusn, _טים_, _tuun, entx,
   {{0x7bc98150,0xb7d5801c,0x68fbde3e,0xea0040d1}},	//   _uteu, _رقاب, rgud, _kiếp_,
   {{0x2900023f,0x3f8ce0d4,0x0cb84d20,0x70b841f9}},	//   _scia_, godu_, _अल्म, _अल्ल,
   {{0x227791be,0xc7b440c3,0x63b55560,0xf53f04c9}},	//   _بلاگ_, ובץ_, _mizn, rmån_,
   {{0x6723de87,0x6d59c0f7,0x68e0c658,0xf8cb81f9}},	//   _wanj, _ulwa, camd, ाडिय,
   {{0x6d5b8022,0x395fe0d5,0x659ac2a6,0x39490018}},	//   _mlua, mhus_, _פינק, _doas_,
   {{0x395fc1e5,0xa91dcc90,0x2bdd81ac,0x6d9885c5}},	//   lhus_, doži, नीया, víam,
   {{0x7ae1e0d6,0xd24ec71d,0x291920d7,0x63bd40fa}},	//   malt, _منو_, besa_, _ausn,
   {{0x27e6e0d8,0x442fc450,0xf8b9800c,0x317f98ca}},	//   _yvon_, _krg_, _ngũ_, _njuz_,
   {{0x55770009,0xf3f9c0b4,0xe8d9425d,0x81a507ce}},	// [1b60] _מעקן_, nuţ_, chọ_, _تحول,
   {{0x6d98a0d9,0x60dd454a,0x6d5ba0da,0xdb008041}},	//   ríam, _eesm, _alua, _humö,
   {{0x98a24007,0xf53f04f5,0x14ca8051,0x63604086}},	//   _tokį_, kmål_, были_, _löng,
   {{0x9f420347,0x6d9d1dfb,0xdb0dc086,0xdb19c231}},	//   dské_, héan, _ákær, _duwé,
   {{0x999e4026,0x6d498290,0x32078062,0xdb19c303}},	//   štų_, _doea, etny_, _tuwè,
   {{0x7ae1c051,0x6d5640e2,0x6ab0002a,0x59d306fc}},	//   jalt, lkya, _জ্যো, धीकर,
   {{0x03a354e9,0x2006a0db,0x68e0c06a,0x6d5ba0dc}},	//   _чиро, stoi_, tamd, _flua,
   {{0x442240f6,0x7ae1c05e,0x63bd4056,0xceb303bd}},	//   _ksk_, ealt, _yusn, עיה_,
   {{0x6b5d8303,0x1b23002a,0x7ff6c359,0x68e2843e}},	//   _sège, মাতে_, أسعا, maod,
   {{0x68e2a0dd,0xdb1d410b,0x3992005f,0x394920de}},	//   laod, _ausê, zást_, _soas_,
   {{0x27e6a0df,0x442740d1,0x442246bc,0x98bf8085}},	//   lson_, ̉n_, _lsk_, _qmuħ_,
   {{0x63604086,0x55bb84e0,0xa2ccc8b8,0xbcfb4031}},	//   _hönd, _המאו, _द्र्, _ilég,
   {{0x6283c34d,0xc7c71585,0x7d02df2e,0xdc54c2cf}},	//   _exno, ясни, _icos, _تراک,
   {{0x291920e0,0xbb43ca66,0xbf9b001e,0x2d9200bc}},	//   sesa_, _печк, ptêm, _ekye_,
   {{0x27e6809c,0x80dc0079,0x44224093,0x5ee18079}},	//   hson_, _ভার্, _ask_, _নামে,
   {{0xa91dceae,0x63604086,0x2d80014d,0x6d4446a6}},	//   toži, _lönd, _gjie_, gjia,
   {{0x25a95433,0x3f8e97b8,0x6725005c,0x7bc041cb}},	// [1b70] rmal_, kofu_, _tahj, _émul,
   {{0xa91de0e1,0x2d99068a,0x7bcd20e2,0xb87b4070}},	//   roži, llse_, _itau, _reíd,
   {{0x29c1c015,0x63b54054,0x657bc057,0x7a0a803a}},	//   _xóa_, _vizn, ynuh, _qətl,
   {{0x7ae1e0e3,0xdb0660e4,0x0dba005f,0x27e69eed}},	//   zalt, _zukü, _گئیں_, fson_,
   {{0x443fc283,0x636050e8,0x27e6a0e5,0x7b024025}},	//   xxu_, _bönd, gson_, äytö,
   {{0xe7368d00,0x75264360,0x61fae0e6,0x49bb43a9}},	//   деш_, _zakz, kutl, _هارد_,
   {{0x636060e7,0xf4130079,0x442fe0e8,0x200960e9}},	//   _dönd, িটির_, _srg_, ltai_,
   {{0xe7ee0474,0xd4d9c12b,0x53c9cbb4,0x443fc232}},	//   _जिला_, цькі_, огим_, txu_,
   {{0x672760ea,0x7c2d60eb,0x98bdc036,0x657be0ec}},	//   _kajj, nvar, _nową_, rnuh,
   {{0x672760ed,0x212960ee,0xbebcc03f,0x20094039}},	//   _jajj, hdah_, ldīj, itai_,
   {{0x61fada04,0x7c2d60ef,0xbcfb4303,0x23a404c9}},	//   gutl, hvar, _kléd, nöje_,
   {{0x6560c510,0xed5700d9,0x7d02c359,0x7cf6c50c}},	//   chmh, дою_, _gcos, rürü,
   {{0xb8d60048,0x68ed002c,0x7d0d60f0,0x6360491a}},	//   _जण_, _ddad, dfas, _yönd,
   {{0x68ed20f1,0x6d5d60f2,0x7d1be0f3,0x636044c9}},	//   _edad, _alsa, leus, _köne,
   {{0x2bdd86ff,0x6b4f84f5,0x3d0ea0f4,0x9f4dc070}},	//   नीता, _høgs, ण्डे_, nreí_,
   {{0x7d1be0f5,0x6d9d20f6,0x6da3561d,0xe0df4321}},	//   neus, néal, виса, _ceò_,
   {{0x6d44405c,0xb87b0032,0x60ddc10d,0x291201c6}},	// [1b80] rjia, laín, ósmy, _ibya_,
   {{0xef174051,0x995c8066,0xda664032,0x212960f7}},	//   мму_, díš_, واضي, adah_,
   {{0x442de0f8,0x6d4be0f9,0x7c2d60fa,0x7bdb840d}},	//   hve_, _ooga, avar, _awuu,
   {{0x6d460618,0xdcfb8077,0x60c24166,0x61fc20fb}},	//   njka, _fjuč, žomb, murl,
   {{0x8b6644e8,0x3f8e841c,0x5edec079,0x9abc8283}},	//   _قاسم, tofu_, _মাসে, _faċl,
   {{0x3eba811b,0x6d4bc321,0x6446c09d,0x442de0fc}},	//   øpt_, _aoga, äkim, dve_,
   {{0x60c9a0fd,0x442060fe,0x3f8ea0ff,0x16de88b8}},	//   _ffem, lwi_, rofu_, _नजीब,
   {{0x6b5486ed,0xf70ec0d1,0xbcfb4303,0x64a68271}},	//   _màgi, _củng_, _gléd, _жаба,
   {{0x3f8ea100,0x15ea88c5,0x442de101,0xaf069a67}},	//   pofu_, _टिकर_, gve_, _опал,
   {{0x2900405c,0xbcfb0032,0x795cc231,0x2902c036}},	//   hgia_, dhéa, _déwa, żka_,
   {{0x68e093e1,0x6b500041,0x61fc021b,0xdd8fc119}},	//   _kemd, _lägs, jurl, _аш_,
   {{0x6d4be102,0x3946a103,0xf8de8384,0x9f400060}},	//   _goga, njos_, मरिय, _avià_,
   {{0x21296104,0xed5f8166,0xa3674031,0x3946801f}},	//   vdah_, úžia_, _bọ̀r, ijos_,
   {{0xd04f4080,0x6b4f84f5,0xe1f1805f,0x2912031c}},	//   _gecə, _høgr, _جسے_, _ebya_,
   {{0x44248b64,0x394b46ed,0xa2cb0419,0xa294011b}},	//   _lsm_, _pocs_, तुष्, варі,
   {{0x67276105,0x6728a106,0x442480a0,0x2fc00580}},	//   _sajj, _ladj, _osm_, _fuig_,
   {{0x67276107,0x7bc0a108,0x5ee34079,0x21294a28}},	// [1b90] _pajj, _numu, _পাবে, rdah_,
   {{0x250951be,0x7d0d6109,0x5f008064,0x1f740d9b}},	//   _کردی_, sfas, _राष्_, _алья,
   {{0x68e4610a,0x394b4580,0x7d1be10b,0x442041c8}},	//   baid, _tocs_, yeus, awi_,
   {{0xdb1d610c,0x2b0ec0aa,0xbcfb47c9,0x442de10d}},	//   _musé, त्तु_, _emér, yve_,
   {{0x06e20079,0x27e9a10e,0x69dc610f,0x63606110}},	//   _বাতি, éan_, _ewre, _söne,
   {{0x7982c031,0xf8bf4004,0x39b84011,0xdce98011}},	//   _ajow, _xaén_, _hčsp_, _vjeđ,
   {{0xe6118646,0x69dc41f4,0x3eb38041,0x25a6c05e}},	//   اشت_, _gwre, äxt_, _bhol_,
   {{0x693481a9,0x56b80093,0x995c8066,0x0c25c2d2}},	//   _инсу, ופון_, píš_, емин,
   {{0x7529c05f,0x96ca81e7,0xdb0e405f,0xb87b01b4}},	//   rdez, _स्कॉ, _hibá, daío,
   {{0x6728a111,0x1309e112,0xb6c980fb,0x2fc02113}},	//   _gadj, чной_, _رائے_, _ruig_,
   {{0xa3e649af,0xf1b982a3,0x99520066,0x6f1c2114}},	//   _यौन_, _kiš_, ráž_, verc,
   {{0x7bc0a115,0x6d4d0004,0x6f05005e,0x7d1d2116}},	//   _yumu, _coaa, _achc, gess,
   {{0x27e94041,0x69c1a117,0x442dc13b,0xb87b0004}},	//   jsan_, _hule, qve_, saín,
   {{0x27e96118,0x69c1a119,0x443202a4,0x7ae1a11a}},	//   dsan_, _kule, _vry_, _jelt,
   {{0x3999005f,0xf679c009,0x7d1d211b,0x7bdd4bc2}},	//   zési_, _מאַמ, bess, _awsu,
   {{0x4420611c,0x7c24211d,0x2fc002a7,0x44320093}},	//   twi_, _tsir, _tuig_, _try_,
   {{0xa802803a,0xbcfb4396,0x61fc142b,0x44204c47}},	// [1ba0] _çıxd, _bléb, surl, uwi_,
   {{0x78a4000b,0x31720089,0x753b80b9,0x6dbac085}},	//   _iziv, _hmyz_, _anuz, _iċar,
   {{0x68e095ce,0xfce64661,0x2129211e,0x68e4611f}},	//   _pemd, _поно, _yaah_, paid,
   {{0x4424a120,0x6d5988a5,0xdce2c123,0x68e60274}},	//   _psm_, gkwa, _imoć, nakd,
   {{0x7ae1a121,0x69c1a122,0x6562a123,0x27e941c8}},	//   _belt, _aule, rhoh, csan_,
   {{0x08774009,0x8a18a124,0x6d5980bc,0x80d08fa8}},	//   _װעלט_, докс_, akwa, _ड्रे,
   {{0x2d806125,0xf1b98013,0x9f524070,0x69ce4377}},	//   onie_, _fiš_, cuyá_, _utbe,
   {{0x799be126,0x6f1e40b4,0x2d806127,0x394da128}},	//   gluw, lepc, nnie_, _goes_,
   {{0xd90dc646,0x69c1a129,0xcebac09c,0xd007c01b}},	//   تین_, _eule, _haƙi_, еење_,
   {{0x3f85041b,0x69c18bab,0x31a1cc1e,0x79840398}},	//   čluk_, _fule, róza_, _ajiw,
   {{0x63b8c046,0x2d92612a,0x2d5c4070,0xd257cc35}},	//   _vivn, koye_, _ríen_, еця_,
   {{0xdb01a12b,0x7ae1a12c,0x6298c531,0x2d804064}},	//   _filó, _zelt, _vyvo, jnie_,
   {{0x2bb2c56c,0x6564612d,0x69de0031,0xe73acd32}},	//   ीददा, dhih, _awpe, _нед_,
   {{0x48ed0260,0x2129212e,0x291da12f,0x200b0011}},	//   _आएको_, _waah_, zewa_, rtci_,
   {{0x22580047,0x3da74c21,0xb907002a,0x61eaa130}},	//   _čeká_, ераб, _পা_, nsfl,
   {{0x2d924536,0x0e9bc21d,0xdb170089,0xf8e0c25c}},	//   goye_, _משול, _mixé, नरिय,
   {{0x27e96131,0x24184523,0xab644138,0x394da132}},	// [1bb0] usan_, ноты_, klüğ, _roes_,
   {{0x68e2e133,0x7c2f8018,0x63ba8170,0xae21009d}},	//   _leod, _ácri, _nitn, मबदन_,
   {{0xdbd74051,0x2d804036,0x78a40077,0x394da134}},	//   _säät, bnie_, _zziv, _poes_,
   {{0x69c1a135,0x63a88043,0x7ae72136,0xd87980b8}},	//   _rule, _ahdn, lajt, ومات_,
   {{0x291d8067,0x7ae18051,0x212b41f4,0x27e94c64}},	//   rewa_, _pelt, _iach_, qsan_,
   {{0x6d59a137,0x39496138,0x442f8123,0xc47641f2}},	//   skwa, ljas_, rvg_, _יתרו_,
   {{0xda62820d,0x869880c5,0x61fe4bb2,0x629aa139}},	//   ивши, нтът_, cupl, _cyto,
   {{0x2019407a,0x7ae7213a,0x77774283,0x9915c11b}},	//   _kpsi_, hajt, lixx, тькі,
   {{0x7ed5c11b,0xd0564080,0x6006c051,0xeb9f00b0}},	//   кінч, fayə, вным_, rtøj_,
   {{0x60c9e13b,0xdb1708ef,0x60cd213c,0xcebac09c}},	//   scem, _fixé, _afam, _zaƙi_,
   {{0x316011ae,0x2d804036,0x78a40107,0x25a900f1}},	//   _pliz_, ynie_, _sziv, _bhal_,
   {{0x6aba4410,0x27ed84f5,0x999f0026,0x399c8c57}},	//   _útfe, _kven_, dytų_, vísk_,
   {{0x64444018,0x8477c02e,0x4426c147,0x636044c9}},	//   xxii, _fáwẹ, _gso_, _löna,
   {{0x2d8045d9,0x29050107,0x6d49e13d,0x6364c0d2}},	//   wnie_, őlap_, ljea, _cònd,
   {{0xf796c38b,0xdee30dd2,0x26d80730,0xb87b4070}},	//   _جنوب_, роси, rbro_, _reía,
   {{0xc5f28009,0x7c22a13e,0xdb1bc018,0x6d49e13f}},	//   ידל_, ywor, mpuñ, njea,
   {{0x212b6140,0xcc8a01aa,0x27ffce04,0xe3ba45a4}},	// [1bc0] _dach_, _زنده_, nuun_, дба_,
   {{0xd36f01b4,0x2ee342bc,0x399ac0fd,0x7ae72141}},	//   _وهي_, _cejf_, rësi_, cajt,
   {{0x2d820590,0xd245801c,0x7c228127,0x2cb1c0a0}},	//   onke_, _اچ_, wwor, ězdy_,
   {{0xd9104973,0x20274051,0x6d4f50bc,0x2d82006f}},	//   _دیر_, äviä_, _goca, nnke_,
   {{0x68e42142,0x63ba9bee,0x7d02a143,0x399ac0fd}},	//   _meid, _pitn, rgos, qësi_,
   {{0x3999005f,0x6d4f6144,0x7d029138,0xe3b25546}},	//   lést_, _zoca, sgos, _خرج_,
   {{0xab6443a6,0x2ca0c654,0x35c6c027,0xcebac09c}},	//   rlüğ, _šid_, _रूढ़, _taƙi_,
   {{0x6da6a145,0xc05ac0d9,0x629a8089,0xdce9c06a}},	//   _риба, діо_, _vyto, rneğ,
   {{0x7bd64010,0x5963c0c5,0x31668107,0xe7bd002a}},	//   npyu, ръща, mhoz_, _অব্য,
   {{0x63bc6146,0x35b44036,0xda7ac698,0x60cd00c4}},	//   _jirn, ंगड़, дям_, _sfam,
   {{0x2179010e,0x7c2dc2bc,0xd5afc051,0x27e00083}},	//   ейны_, _šart, _вс_, _awin_,
   {{0x9257c051,0xd5e98032,0xd7facd4c,0x68e4002c}},	//   тают_, _أعلن_, _жук_, _ceid,
   {{0x69c3c077,0x27ed2147,0x6d9d01cb,0x39990107}},	//   _eune, éen_, néai, dést_,
   {{0x6562c02d,0x69c140c4,0x69cac1f9,0x69c3e148}},	//   _hloh, _èleg, _संपी, _fune,
   {{0xf1a7112e,0x69c3e149,0x661b4077,0xe919411b}},	//   _ирин, _gune, _ćuko, нові_,
   {{0x2ee3614a,0x8ab7c093,0x24890046,0x6f0d82a3}},	//   _sejf_, _בלוג_, _txam_, đaci,
   {{0x7c2449dc,0xe4544039,0x6562c043,0x7ae3e14b}},	// [1bd0] gwir, акты, _mloh, _yent,
   {{0x6d5d213d,0x7ae8c036,0x1616c09d,0x2ee3413b}},	//   lksa, nadt, _तहार_, _qejf_,
   {{0x35f5614c,0x777740f1,0x9abc8283,0x4424c24c}},	//   упер, rixx, _faċi, hwm_,
   {{0xdb18c303,0x79828036,0xf8c1017e,0x31791a1d}},	//   _divé, gnow, _एलोप, nisz_,
   {{0x2489801d,0x201940c9,0xdcfbc0b3,0xbcfb4032}},	//   çam_, _upsi_, unuč, _gléa,
   {{0x63bc614d,0xdb03c0d2,0x7ae5017a,0x628adb32}},	//   _girn, _linò, _jeht, _oxfo,
   {{0x6d5be14e,0xdb0fe14f,0x7ae3e150,0xa3c94036}},	//   tkua, _àdép, _rent, _लंड_,
   {{0xa925e151,0x224987ef,0xa0a5d136,0x3f830011}},	//   удил, ćak_, лайд, hnju_,
   {{0x63604086,0xcc35c032,0x6d49e152,0x6e9f88b8}},	//   _mönn, اربع, rjea, _ओरकु,
   {{0x69c4c038,0x6d5be153,0x3999005f,0xe9e9c166}},	//   _čier, skua, zést_, hnúť_,
   {{0x7dc783a6,0x9f42180a,0x1eea81aa,0x44324066}},	//   _kısm, jská_, _سونی_, zvy_,
   {{0xf99f03bc,0x7ae3e154,0xd435ce5f,0xdb03e155}},	//   glè_, _went, _معتب, _pinó,
   {{0x7d044189,0x39990047,0x4424c02c,0xdb1bc004}},	//   vgis, vést_, cwm_, spuñ,
   {{0x98a040b3,0x2d8200b3,0x21206156,0xa8750051}},	//   ldić_, snke_, weih_, рующ,
   {{0xa3dfe157,0xdb01c4c9,0xdb1a8396,0x79828036}},	//   धीर_, rmlä, _ditè, ynow,
   {{0x68e9cdff,0xc879c119,0x7c29a158,0x09062159}},	//   naed, eaşi_, _oser, _спин,
   {{0x7a0a803a,0x7c29a15a,0xd4674897,0x3940215b}},	// [1be0] _hətt, _nser, гите_, _inis_,
   {{0xdd9980ce,0x7ae5215c,0x2002215d,0xdb1d4fc2}},	//   _akň_, _geht, muki_, _fusí,
   {{0x9bb70093,0x69c5000d,0x75d34032,0x6d988018}},	//   _תהיה_, _guhe, ميلا, xías,
   {{0x6146615e,0x60cd615f,0x7c298123,0x6d988018}},	//   _сема, ccam, _bser, vías,
   {{0x6721e160,0x06e84079,0x27ede161,0xdb0185ef}},	//   kelj, _পাঠি, jsen_, _bhlà,
   {{0xe8d90112,0xed598514,0xaca40094,0x8f34a145}},	//   _ijụ_, _riže_, _nkọw, рекц,
   {{0xb90a8879,0xd5bacd00,0xa3b50742,0x6562d361}},	//   _মা_, нси_, जगत_, _ploh,
   {{0x4154e162,0x41c381b4,0xbcfb001e,0x6374003a}},	//   рвис, حقيق, thém, _dünə,
   {{0x6721e163,0x21678b8e,0xa3dfc08f,0x7b098051}},	//   felj, _сити_, धील_, ästö,
   {{0x6fdd881d,0x25a06164,0x60cd6165,0x4424c1f4}},	//   _नौटं, hlil_, zcam, rwm_,
   {{0x44292166,0xc7c8c00c,0x6fb382cf,0x59b4422d}},	//   _ssa_, _bốc_, _املا, ंगार,
   {{0x4035010e,0x29068232,0x2b14532e,0xc5f8c03f}},	//   аемс, ngoa_, न्तु_, dzēt_,
   {{0xd378c835,0xf593c1b4,0x9c57c1aa,0x69c52167}},	//   pić_, _النج, _مجوز_, _suhe,
   {{0x6601c224,0x6721c077,0xaca480eb,0x656400f7}},	//   bulk, celj, _nsọp, _elih,
   {{0x7bc66168,0x6601e169,0xa3e48036,0xab5b001f}},	//   _auku, culk, भीत_, nqüi,
   {{0xc7c8c015,0xaca48044,0x6d40802f,0xc5f3c2a6}},	//   _gốc_, _asọp, _nnma, _הדק_,
   {{0xb60645c7,0x60c2d39a,0x765ac051,0xa9bc00c3}},	// [1bf0] _lišć, _mgom, lyty, _אזהר,
   {{0x63be0010,0x7d09823f,0xdb018066,0x98a04158}},	//   _gipn, _sces, _ohlá, zdić_,
   {{0x7a0a8080,0xab5d80f6,0x2b144fb2,0xc879c0b4}},	//   _xətt, _bużn, न्धु_, raşi_,
   {{0x2d9940b2,0x32014089,0xa3abc5da,0xa49b405e}},	//   _ukse_, ruhy_, _कीन_, _lcòi,
   {{0x38ab4031,0x3b099324,0x2d7886f0,0xbcfb07b0}},	//   _dòrí_, вело_, rčep_, ckée,
   {{0x1b230079,0x92190027,0xc88640cb,0x29ca80d1}},	//   মাকে_, _पहाड़_, üßen_, _bùa_,
   {{0xcf580093,0x752f5a03,0x0f5804e0,0xff580d89}},	//   רבות_, _kacz, ריום_, רבוך_,
   {{0x672e4570,0xdb1d401f,0x69d541a8,0x4439616a}},	//   _zabj, _fusã, _itze, _krs_,
   {{0x6fb98157,0x68eba16b,0x7ae74590,0x5067a16c}},	//   _агар_, magd, _kejt, _ства,
   {{0xb8fccbc0,0xc7c8c00c,0xdced4165,0x443c0011}},	//   _त्_, _sốc_, ynağ, _čv_,
   {{0x4439616d,0x7ae7616e,0x8d7607c3,0x75d1803f}},	//   _lrs_, _mejt, لاحا, _bāze,
   {{0x68eb8871,0x7c3b4283,0x27e08119,0x6d4d41ae}},	//   nagd, _ġurn, ţine_, jjaa,
   {{0x7db4d971,0x8d5ac2a6,0x26d141d4,0xb4d1c08f}},	//   _اصلا, _שכני, _ofzo_, वडी_,
   {{0xdee30156,0x60c2c0b4,0x98a24036,0x68eb802f}},	//   жори, _zgom, _jaką_, hagd,
   {{0x0f7ac087,0xe29a0def,0x63be216f,0x672e566c}},	//   _ברסל, тав_, _vipn, _rabj,
   {{0xbdfa802a,0x75d18017,0xdb1d4060,0x65641ae2}},	//   _আহমদ_, _gāze, _ausà, _ulih,

   {{0x212fc4e7,0xa3e48f4a,0x98a480b4,0x69c74140}},	// [1c00] _magh_, _भौं_, _mamă_, _auje,
   {{0x7bc66170,0x79898031,0x69c76171,0x0b434119}},	//   _vuku, _ajew, _buje, онун,
   {{0x6da65e79,0x7bc66172,0xb2264156,0xe5a656ad}},	//   _вина, _wuku, рмел, _вини,
   {{0xd9108646,0xd7fa8039,0x2607409d,0x25bf805e}},	//   ثیر_, вук_, _हमरी_, _ciul_,
   {{0x765ac064,0xead486fe,0x7522a173,0x44396174}},	//   zyty, боль, reoz, _grs_,
   {{0x3f982175,0x799ba176,0x7ae76177,0xdce68526}},	//   noru_, _ekuw, _gejt, ımın,
   {{0xb4d1c048,0x394de178,0x22475da9,0xca4881aa}},	//   वडू_, fjes_, änkt_, العه_,
   {{0x75244019,0x7414c1b4,0xb4c2c8c1,0x6713ca94}},	//   neiz, موبا, ्डे_, त्सक_,
   {{0x69c740b3,0x661e021b,0x8afec360,0xe3c8c00c}},	//   _zuje, _lppk, _alƙa, _bựa_,
   {{0xab5c803f,0x60c42179,0xdb154107,0xaaaa4027}},	//   _biļe, _agim, _kizá, _कराक,
   {{0x7c2bc616,0x201dc141,0xaacf809d,0xdced40ab}},	//   _esgr, _epwi_, _स्टक, znađ,
   {{0xdb1c617a,0x98a480cc,0x6446cd98,0x1543e17b}},	//   _diré, _gamă_, äkis, _мехм,
   {{0x9f474038,0x69c0a17c,0x752f4064,0x26084021}},	//   čnú_, _mime, _racz, ांडी_,
   {{0x6d4d41d4,0x60c400bc,0x23650107,0x6364c321}},	//   wjaa, _egim, ólj_, _fòna,
   {{0x26d14654,0x75d3c0cc,0x99420062,0xa92441af}},	//   _rfzo_, _răzg, _dół_, _žľaz,
   {{0x7c2bc0de,0x661e0056,0x99d3c71d,0x636040b5}},	//   _ysgr, _dppk, _بتوا, _dönm,
   {{0xed5985c7,0x672381ae,0x66039256,0x69dae17d}},	// [1c10] _niža_, yenj, zunk, lpte,
   {{0x241843d0,0x7ae88ded,0x6d4d5331,0x60c480b3}},	//   рофы_, _nedt, sjaa, žiml,
   {{0x69c8a17e,0xdb0f40d2,0x75d3c0b4,0x7c2d017a}},	//   _nude, _bucò, _găzd, _hsar,
   {{0x6d9d0018,0x69c74011,0x91ac80d1,0x394d41ff}},	//   méas, _vuje, _đọc_, _ões_,
   {{0x68eb8871,0xf484617f,0xf77001aa,0xac27a180}},	//   ragd, _дурн, _رای_, рфек,
   {{0x69c76181,0x7dd341d6,0x68eb8010,0xf8bf2182}},	//   _tuje, _aħse, sagd, ldés_,
   {{0xdb1e2183,0x61fe40e0,0x69c08141,0x68eba16b}},	//   _sipë, crpl, _fime, pagd,
   {{0x2004c5f5,0x248d0064,0x201dc033,0x2d990007}},	//   fumi_, żemy_, _ppwi_, jose_,
   {{0x2004e184,0x66054b64,0x7d1ba185,0x6603a186}},	//   gumi_, luhk, _ibus, sunk,
   {{0x386dc0fa,0x68ed4057,0x25622187,0x1f65e188}},	//   rzer_, haad, _pólo_, ском,
   {{0x657d2189,0x6605618a,0xe6a54c63,0x69d7004d}},	//   fish, nuhk, _करोड़, _ntxe,
   {{0x442d802f,0x394dc0fd,0x3a3a0070,0x63668086}},	//   _kse_, qjes_, _rrpp_, _iðna,
   {{0x4429618b,0x7d09e18c,0x2d9dc044,0xe3c8c00c}},	//   jwa_, mges, _ikwe_, _tựa_,
   {{0x7d09e18d,0x98a08812,0x7c29e18e,0x443e4185}},	//   lges, žić_, mwer, _čt_,
   {{0xf1b988b8,0xcb058045,0xbcfb0019,0xfaa60e5a}},	//   ेदान, _राईड_, zhéi, саво,
   {{0x16a81f38,0xc6928052,0x657d1dcb,0x9c13c112}},	//   _गरीब, פאן_, cish, _nọkw,
   {{0x26c580b3,0x9f404032,0x80aa618f,0x7fd6459d}},	// [1c20] _oglo_, msiú_, ував_, сібі,
   {{0x7d1ba190,0x44202191,0x752600fc,0x2b434060}},	//   _abus, _ipi_, lekz, _cnjc_,
   {{0x69c0a192,0x7c29c600,0xb9c10676,0x68ed4057}},	//   _pime, hwer, _üçün, baad,
   {{0xdb1e03bc,0x2fc9023b,0x106a8441,0x7d09c15d}},	//   _sipè, _yuag_, лией_, jges,
   {{0x7c29c1d4,0x44296193,0x442002c0,0x674505ca}},	//   jwer, cwa_, _jpi_, _útjá,
   {{0x7bc18033,0xc7c8c00c,0x69c3023f,0x27ffe194}},	//   _cilu, _bốn_, _ènec, drun_,
   {{0x1b7b4009,0x7d09c0fa,0x6605407a,0x27f26195}},	//   _עטלע, fges, cuhk, lsyn_,
   {{0x442da196,0xdd90ce5f,0x4fd4e197,0x7d09e198}},	//   _fse_, بوب_, ожит, gges,
   {{0x27f2498b,0x7bc9801e,0x442d8157,0x7c29406f}},	//   nsyn_, _gueu, _gse_, _šerz,
   {{0x657d11ea,0x69c8a199,0x2d9dc25d,0x6d44219a}},	//   wish, _tude, _ekwe_, _ania,
   {{0xeb9f219b,0x69dc219c,0xa3be09af,0x2d99219d}},	//   ktør_, jpre, ेदन_, tose_,
   {{0x68ed4057,0x6562a19e,0xe572c425,0x99671b22}},	//   xaad, nkoh, _عطا_, стол,
   {{0x68ed409d,0x6d440036,0x69dc0201,0x9036c107}},	//   vaad, _dnia, epre, _دراص,
   {{0x2d99219f,0xb87b0359,0x995c80a0,0x25ef8048}},	//   sose_, daít, jíž_, ींची_,
   {{0xdce9823e,0x200040b4,0x68ed61a0,0x2cd640eb}},	//   _umeć, erii_, taad, _ọhụ_,
   {{0x9f4941b4,0x6d9d0032,0x2b1a0185,0x20ba8045}},	//   rsaí_, réas, म्बु_, ेशाध,
   {{0x44200303,0x47d54032,0x9f5561a1,0x5b270523}},	// [1c30] _gpi_, زيار, овач, _льна,
   {{0x7bdd21a2,0x7cff402e,0xe2f9411b,0x9c13c0eb}},	//   mpsu, _bàrà, режі_, _sọkw,
   {{0x7bc1a1a3,0x6aba4397,0xab5d81d6,0xd91940b4}},	//   _rilu, _útfl, _fużj, _конц_,
   {{0x66054cff,0x6f1c4077,0x02b50045,0x68ed41c8}},	//   ruhk, _ebrc, ंधीन, qaad,
   {{0x06e84079,0x31690199,0xb4e6c3fc,0xd006d2c0}},	//   _পারি, _mlaz_, _बड़े_, _تل_,
   {{0x7645c086,0xaded0027,0x660540b2,0x55524107}},	//   _áhyg, _जबान_, puhk, _ٹھہر,
   {{0x68e996fb,0x78a2c75d,0x27e08017,0x67350127}},	//   _teed, _ayov, ģina_, idzj,
   {{0x7bc1801c,0xf1cfc185,0x160b8036,0x7c3b80fd}},	//   _wilu, _संबन, संबर_, _trur,
   {{0x69cadee0,0xf1c9c0d1,0x5f75c107,0x6d5621a4}},	//   _aufe, _cạn_, قادر, _roya,
   {{0x27ffe1a5,0xe619c42e,0x75d3c119,0xc7c8c00c}},	//   rrun_, адо_, _răzb, _tốn_,
   {{0x692621a6,0xe12610cd,0x7c29e1a7,0x7aeae1a8}},	//   омна, омни, swer, _deft,
   {{0x7bdbe1a9,0x66070077,0x2d9de1aa,0xac19e1ab}},	//   ppuu, dujk, _ukwe_, _воду_,
   {{0x4429d02f,0x798d05b2,0xbcfb41c0,0x06c5002a}},	//   _èa_, _djaw, _elék, ্রনি,
   {{0xe73a06b1,0xdce40247,0x672700bc,0x443dc2ea}},	//   шег_, _ilič, gejj, _irw_,
   {{0x7aee01c8,0x7bc3c02f,0x3e4ec03a,0x6b848032}},	//   rabt, _iinu, yəti_, éigi,
   {{0x7989e1ac,0xb4e88027,0xdce421ad,0x3dd84033}},	//   nnew, _मजे_, _klič, _rtrw_,
   {{0xd00a4156,0x2613810b,0x291dcd41,0x2d51c34d}},	// [1c40] резе_, hão_, _mbwa_, _báez_,
   {{0xbcfb005f,0x27f246a9,0x6daac020,0x7989c05e}},	//   nkén, rsyn_, _aƙal, hnew,
   {{0xf1c9c00c,0x27f261ae,0x14c8801c,0x562a4119}},	//   _mạo_, ssyn_, مهای_, ржем_,
   {{0x20004119,0x3f9e805c,0xdb1a8004,0xafdb4af3}},	//   prii_, _sktu_, _vití, _brød,
   {{0x6e294570,0x4e084036,0x7bcbd56d,0xeb9f0240}},	//   _ćebe, ांहै_, _nugu, brød_,
   {{0x6234893f,0x636b21af,0x291de1b0,0x7989c75a}},	//   зеку, _tüne, _abwa_, enew,
   {{0xdbd1c10b,0xc2e8c02a,0x7989c02c,0x7bd9c024}},	//   qüên, _খালি_, fnew, _atwu,
   {{0x7aeae1b1,0x3f9e8dff,0xa37b001f,0x69cae1b2}},	//   _seft, _wktu_, mpõe, _rufe,
   {{0x69cae1b3,0x274ac179,0x442261b4,0xf1c9c00c}},	//   _sufe, ачно_, _jpk_, _bạo_,
   {{0x2613810b,0xf1c9c0d1,0x6564405c,0x656d4033}},	//   bão_, _vạn_, hkih, zhah,
   {{0x29d74283,0x31690487,0xf1c9c00c,0x8b034047}},	//   _għad_, _plaz_, _dạo_, _úřed,
   {{0x68e2a1b5,0x443dc00d,0xdb03c01f,0xb87b034d}},	//   nbod, _frw_, _sinô, daír,
   {{0x69c4005e,0x78a40f2d,0x442261b6,0xf8bf4303}},	//   _diie, _cyiv, _npk_, _laér_,
   {{0xf1c9c00c,0x5334c747,0x59ca4314,0x96da4743}},	//   _gạo_, _хект, िदार, _प्लॉ,
   {{0x95cb21b7,0x1634099b,0x9e340156,0x63bb4157}},	//   руга_, меря, мерч, _èuni,
   {{0xdb1c4319,0x3201405b,0x7bcbd3e7,0x200202bc}},	//   _dirí, vrhy_, _yugu, brki_,
   {{0x20040016,0x2d51c0e1,0x2d894145,0xdb1c4086}},	// [1c50] àmit_, _páez_, rnae_, _eirí,
   {{0x68ed21b8,0x4422405c,0x628bc7ca,0x8aa756a8}},	//   _head, _dpk_, šloš, оред,
   {{0x2d5c403c,0x69cec166,0xb4d8825d,0x68e2809c}},	//   _cíes_, íbeh, _ịzụt, fbod,
   {{0x2613801f,0x2d5c4060,0xdeb600c3,0x656f035d}},	//   vão_, _díes_, _מפתח_, nhch,
   {{0x7bc521b9,0x60d64009,0xdea3c020,0xd7f8615e}},	//   _kihu, _מורא_, _danƙ, _мур_,
   {{0x68ed21ba,0x212943f3,0x7bcbe1bb,0x20094033}},	//   _lead, leah_, _rugu, muai_,
   {{0x7989e1bc,0x7bcbc09d,0xf1c6c045,0x3c2d4011}},	//   tnew, _sugu, _रंगन, _hžv_,
   {{0x7bc3e1bd,0xab5d8283,0x645c8080,0x2ba94314}},	//   _sinu, _mużi, _əriz, कतवा,
   {{0x6ed88260,0x656f21be,0x799bcef1,0x200961bf}},	//   नुहु, dhch, rouw, nuai_,
   {{0x2d8b21c0,0x2d9da1c1,0x7bdb8033,0x7c22cf26}},	//   ence_, lowe_, _ituu, _dpor,
   {{0x7c22c073,0x31ae8066,0x636dc032,0x68ed21c2}},	//   _epor, lýza_, _rúnd, _bead,
   {{0x50cb906a,0x7bcbe1c3,0x27e920f7,0x637021c4}},	//   िशिष, _tugu, _bwan_, _käng,
   {{0x7bcd03e9,0x6728e1c5,0xed59a1c6,0x5552c107}},	//   _cuau, bedj, _mož_, _سپور,
   {{0xd00ec1b4,0x3ced8022,0x7bc508d4,0x7529e1c7}},	//   _صلى_, _leev_, _cihu, leez,
   {{0xf2d2c009,0x27e905bb,0x324321c8,0xd2aa14d8}},	//   _טעג_, _ewan_, нерг, скве_,
   {{0x6b9c21c9,0x290de1ca,0x88ca41ce,0x3ced8022}},	//   sorg, ngea_, слав_, _neev_,
   {{0x7bcd0070,0xed57401b,0x25e80384,0x291201c6}},	// [1c60] _guau, чот_, _जबकी_, _icya_,
   {{0x6d59d32b,0x60c9a1cb,0x636dc49a,0xf1c9c0d1}},	//   _lowa, _agem, _fúne, _lạm_,
   {{0xdb1c401f,0x673541d6,0x68e2831d,0x395961cc}},	//   _pirâ, _dazj, tbod, _foss_,
   {{0xc7c68217,0x31b20531,0x7c2d43ab,0x1d0a81cc}},	//   пски, báze_, bwar, седи_,
   {{0x27ee4185,0xdbd1c6ed,0x7536005c,0x443f8fda}},	//   álně_, qüèn, _mayz, _cru_,
   {{0x7c240150,0x656be1cd,0x29d181c0,0x442de1ce}},	//   _mpir, _algh, _báa_, dwe_,
   {{0x7bdba1cf,0x32180093,0xdb1a8066,0x7f58c022}},	//   _etuu, ntry_, _citá, _rovq,
   {{0x59be4705,0x7529c31c,0x29d1802e,0xbcfb4359}},	//   ्दिर, geez, _dáa_, _pléi,
   {{0x27e061d0,0x6728c451,0x3946c06c,0xdcfbc2bc}},	//   npin_, tedj, _vnos_, znuć,
   {{0x212021d1,0x7982a1d2,0x2fc580b3,0xb4bcc08f}},	//   _abih_, liow, _gilg_, _आणी_,
   {{0xdd950007,0x656f21be,0x44320782,0x7c240232}},	//   даны, thch, _asy_, _apir,
   {{0x69c661d3,0x442484a7,0xa91dc0e0,0x3ced804d}},	//   _nike, _kpm_, tiže, _xeev_,
   {{0x260f0c5c,0x6608c089,0x443f0ad6,0x69b044ef}},	//   तूनी_, sudk, íu_, ंतनी,
   {{0xe085c032,0xa91dc04f,0x2d9d8036,0x2b5a00d2}},	//   _تجمي, riže, zowe_, _copc_,
   {{0x356b4b8e,0x798b81f4,0x7c2d61d4,0x9f400016}},	//   бран_, yngw, wwar, _avió_,
   {{0xf2df800c,0x2d8221d5,0x6da40267,0xfc4a0047}},	//   _đâm_, cike_, _пија, _spíš_,
   {{0x7c2d415d,0x69ce4daf,0xdcfbc9fa,0xdb1c4031}},	// [1c70] uwar, _aube, snuć, _birà,
   {{0x65a5c107,0x20190546,0x656d1428,0x23c30031}},	//   róhi, mtsi_, _hlah, _déjì_,
   {{0x636b0bde,0x7c2d61d6,0x2d9da1d7,0x80a2408f}},	//   _güna, swar, towe_, _कुठे,
   {{0x442de1d8,0x69dc4032,0x657d40f7,0x69c64449}},	//   ywe_, _dtre, _umsh, _gike,
   {{0xac09811b,0x69ca4019,0xca6b823d,0x3f8147ef}},	//   інка_, ífer, _бiлi, pihu_,
   {{0x9618005f,0xbea5801b,0x628e0158,0x64408011}},	//   _بغیر_, малк, šnoš, _drmi,
   {{0x261721d9,0x6d59c036,0x69dc4070,0x212b21da}},	//   nço_, _powa, _gtre, kech_,
   {{0x5f77805f,0x60c98303,0x68fba1db,0x1c45c698}},	//   _کارر, _ugem, _udud, дним,
   {{0x21201ffd,0x69ce61dc,0xf1c70c6b,0x7529c1ae}},	//   _rbih_, _zube, _रंजन, reez,
   {{0x21200c82,0x0667805f,0x7d03c1c0,0x7c3bc253}},	//   _sbih_, _ٹائپ, _bìrà, rvur,
   {{0x6d59e1dd,0xdb074041,0x6d5ba1de,0x7d1bc449}},	//   _towa, _ihjä, _koua, pfus,
   {{0x6b81cd80,0x5ec5002a,0x442de1df,0xf53f0588}},	//   silg, ্রাই, pwe_, slån_,
   {{0xbf9b001d,0x637004d3,0xbcfb21e0,0x7bcf61e1}},	//   rrên, _läne, ckém, _nucu,
   {{0xb87b4070,0x6d5b8d4a,0xa3c28045,0x3ea080cc}},	//   _leís, _loua, ृदय_, şite_,
   {{0xc7b2c093,0xc33280c3,0x6d4981a8,0x637021e2}},	//   _שבו_, כום_, _onea, _ränd,
   {{0xb4c98e80,0xc6928052,0x2019004d,0x29f8402d}},	//   ोडो_, דאל_, btsi_, vča_,
   {{0x7aee4022,0x6da34b7d,0xfc4ac086,0x2fc7c0c3}},	// [1c80] _pebt, тита, mtíð_, _king_,
   {{0x7bcf556d,0x91e64a23,0x2d9fe1e3,0x2d8dc0cb}},	//   _ducu, доже, houe_, hnee_,
   {{0x6d5ba1e4,0x7afa0086,0x217693f4,0x7afc4247}},	//   _boua, óttu, мудр, _vdrt,
   {{0x290f0041,0xbc6a8182,0x6b9e40b0,0xdb1e00d2}},	//   _ögat_, يمان_, sopg, _hipà,
   {{0x6faf4028,0x2fddc022,0x6d5ba1e5,0x7bcf400d}},	//   _जीवं, _ntwg_, _doua, _gucu,
   {{0xf767c49f,0x26ca5f0f,0x6d498140,0x9f52434d}},	//   _شا_, _ugbo_, _enea, ruyó_,
   {{0x8b034185,0xa96aa1e6,0x79828036,0xfb198107}},	//   _úřad, _дива_, piow, سروں_,
   {{0xa3b50027,0xc7c8c00c,0x2d92000d,0xf0d2c0eb}},	//   _छीन_, _hối_, _njye_, _rịsọ,
   {{0x3f9ee1e7,0xf2028374,0x8706c9db,0x3ce680e5}},	//   totu_, रूज़_, мяне, mbov_,
   {{0x7f5c61e8,0x2d80001e,0x2fcfe1e9,0xe0df4053}},	//   _jorq, _amie_, _dugg_, _anòl_,
   {{0xc7c8c015,0x69c88107,0xdb18c383,0x63a8e1ea}},	//   _mối_, _édes, _nivå, rldn,
   {{0x6364c016,0x7c2657ab,0x7d1d0414,0x8f0e87a5}},	//   _mòni, _opkr, ufss, _साँझ_,
   {{0x9cc8023d,0xe7edc374,0x636b00cb,0x290500b5}},	//   дыра_, चीदा_, _dünn, ğla_,
   {{0x212b21eb,0xf487c01c,0x290501df,0x201921ec}},	//   sech_, _تامی, şla_, rtsi_,
   {{0x61f88b32,0x3ea7e1ed,0x13e3c02a,0x637240b0}},	//   nsvl, _gynt_, _মিয়, _mænd,
   {{0x656d1cab,0x7bc744fd,0x4426c044,0x442f804d}},	//   _ulah, _siju, _kpo_, ywg_,
   {{0x7bc761ee,0x8afec0e2,0x8f0e8285,0xfc3f402e}},	// [1c90] _piju, _alƙi, _सांझ_, _eyín_,
   {{0x2ca921ef,0xb87b61f0,0x79809ca0,0x7bc8a1f1}},	//   _iyad_, _seís, _ammw, _nidu,
   {{0xb4af008f,0x2cdc8094,0x2d854107,0x68ef5564}},	//   _करु_, _ịhụ_, éles_, _tecd,
   {{0x37e20079,0x63700041,0x7bcf4fb4,0x6442c0fc}},	//   _বিতর, _väne, _tucu, _oroi,
   {{0xba74478a,0x2d84e1f2,0x7bc761f3,0xa3c846ca}},	//   _یافت, dime_, _tiju, _ऊंच_,
   {{0x7522e1f4,0x636061f5,0x6364c0ce,0x6d5d61f6}},	//   _aboz, _döns, _fòni, _hosa,
   {{0x9f420066,0x60cd163e,0xc7c8c00c,0x2b1202ea}},	//   jský_, _ogam, _gối_, _तासु_,
   {{0x7bc8a1f7,0x7af50232,0x3dde8010,0x69d5c066}},	//   _eidu, hazt, _dttw_, ízem,
   {{0x7e9981aa,0x63a3c05c,0x2d9fc2a4,0xb4db4321}},	//   _کنار_, _pknn, roue_, _cnài,
   {{0xdce990b4,0xdbdcc10d,0x3ea7c240,0xbbcb8185}},	//   _mleč, ráðh, _pynt_, ादीक,
   {{0x6442e1f8,0xdb054032,0xd91002cf,0xdea1805f}},	//   _eroi, lmhó, لیغ_, _حیثی,
   {{0x25a0405c,0x7bc8a1f9,0xbf1b8045,0x78a9817b}},	//   xoil_, _zidu, प्रभ_, _kyev,
   {{0x60db84fd,0x27ed83bc,0x752d40b4,0x26cc0166}},	//   _mfum, _jwen_, deaz, ždom_,
   {{0x2571c185,0x60cd1030,0x7539c0e2,0x99718036}},	//   _dále_, _egam, _hawz, nął_,
   {{0x27ed83bc,0x63a1cd88,0x60db8a15,0x25a061fa}},	//   _lwen_, moln, _ofum, toil_,
   {{0x6d4bc07a,0x7dc7c05f,0x6569e1fb,0xb87b434d}},	//   _jnga, _műso, nkeh, _reír,
   {{0xf1ca00d1,0x8c14002a,0x656f405e,0x6d4bcfee}},	// [1ca0] _nại_, িবহন_, _dlch, _mnga,
   {{0x138a4032,0x5ba74156,0x98a0017a,0x99718062}},	//   أخرى_, екум_, _lbiċ_, jął_,
   {{0xdce440b3,0x69c98070,0xbcfb5305,0x37098027}},	//   lkič, _biee, _boéd, _साड़ी_,
   {{0x69c98033,0xf1ca000c,0xebe661fc,0x6d5d61fd}},	//   _ciee, _bại_, _помп, _gosa,
   {{0xdce98077,0x7bc8809d,0xbcfb402e,0x752421fe}},	//   _gleč, _pidu, _elés, _mbiz,
   {{0xf8af405f,0x81be4112,0x29be4112,0x27ed8053}},	//   _چکے_, _ọchọ_, _ọchụ_, _dwen_,
   {{0x290021ff,0x4426e200,0x6d5d6201,0xa3c96202}},	//   _odia_, _spo_, _yosa, _लूट_,
   {{0x5bc8c371,0x6da3d025,0x636de203,0xa3cb8027}},	//   रद्व, лија, _rúna, _रूक_,
   {{0x200dc01b,0x443241f4,0x27e0002f,0x7643c02c}},	//   guei_, nwy_, _ntin_, _arny,
   {{0x9f42005b,0xbf9b0669,0x60cd2204,0x6d4be205}},	//   tský_, trêm, _sgam, _enga,
   {{0x661c004f,0x66e3823d,0x28a745a8,0x673ac4c9}},	//   jtrk, _соха, _कुनि, rdtj,
   {{0x752d40b4,0x6569e206,0xe0df4053,0xdb01c1ff}},	//   xeaz, ckeh, _pnòm_, nolê,
   {{0x38c9016a,0xb87b0c81,0x7165c032,0x6442c0b9}},	//   بادی_, mbík, _جالك, _uroi,
   {{0xbf9b01cb,0xb11380eb,0xdb580466,0x9f4202f4}},	//   prêm, pụgh, нюс_, pský_,
   {{0xf2040698,0xa5d7c1b4,0x1c03409d,0xdce99bee}},	//   лято, _كبير_, _लिहल_, _sleč,
   {{0x5ba94430,0x555840c5,0x3169402d,0x7bcac84f}},	//   कत्व, нася_, ukaz_, _hifu,
   {{0x6aaac0de,0xa2be43ae,0x7ae7c107,0xc05b40d9}},	// [1cb0] _hyff, वेस्, űjte, чів_,
   {{0xdce993ca,0xf1bf0018,0x752f0036,0xe1cfc5da}},	//   _vleč, lmá_, lecz, _सूँघ,
   {{0x443fc531,0x7bcac4fd,0x27ed83bc,0x61fc4570}},	//   zvu_, _mifu, _swen_, _cvrl,
   {{0x752f0036,0x3eaa40b0,0x25874031,0x7bcae207}},	//   necz, _dybt_, _dìlè_, _lifu,
   {{0x5bcba208,0xa3d4817e,0x673a8379,0x6d4d1dc7}},	//   ादेव, _सूद_, _batj, _mnaa,
   {{0x7bcae209,0xdb038089,0x61fae20a,0x15e808b8}},	//   _nifu, plní, kstl, टीकर_,
   {{0x6995c0c5,0x61ed8013,0x21040026,0x673a8820}},	//   крих, ćalo, lčių_, _datj,
   {{0x60db8150,0x67248054,0x7af7620b,0x7bcac398}},	//   _ufum, đija, laxt, _aifu,
   {{0xe894811b,0x7bcac18b,0x67d5a20c,0x5bb5d213}},	//   _бать, _bifu, _розу, ксоф,
   {{0x0b42c0d7,0x21040007,0xb4bf842f,0x26c745e5}},	//   аньн, ičių_, ुखी_, žnou_,
   {{0x1d0a0d44,0x3f85e20d,0x753ba20e,0xa50a220f}},	//   мени_, rilu_, _kauz, мена_,
   {{0x7c298044,0x212dc21b,0x2903c007,0x753b80fc}},	//   _kper, qeeh_, ėjas_, _jauz,
   {{0x61e4c7ca,0x2d82405c,0x8afec360,0x3f85e210}},	//   _čile, _rmke_, _alƙu, pilu_,
   {{0x753ba211,0x6d4d074e,0x7bcac4db,0x6aaac061}},	//   _lauz, _enaa, _gifu, _fyff,
   {{0xfaa60417,0xdce44158,0x21040007,0x394d80c3}},	//   таво, skič, ečių_, _ones_,
   {{0x29000112,0x753b885f,0x41b6005f,0x27e080b4}},	//   _udia_, _nauz, _جمعر, ţini_,
   {{0x7bcacd08,0x68e90018,0x80c4c5da,0x08c64c85}},	// [1cc0] _yifu, ñede, ाइये, тбан,
   {{0x395f805e,0x3cde049d,0x1bba0865,0x0e661d7c}},	//   _aous_, कुरे_, _تابع_, _акон,
   {{0x5a9604ce,0x60cf4018,0x395fa212,0x8e4a4032}},	//   _шриф, _fgcm, _bous_, بلاك_,
   {{0x395f9136,0xafe680d7,0x27228047,0xafdb47fb}},	//   _cous_, водл, _oční_, _krøl,
   {{0x673aa213,0x69cb0185,0x3f878086,0x7d084031}},	//   _patj, _संघी, finu_, _eèrà,
   {{0x69cbc73f,0x7c29a214,0x68e9c31d,0x3866a215}},	//   _aige, _dper, ebed, ryor_,
   {{0x395f975f,0x61e1805e,0xa2be46fc,0xa3c0c314}},	//   _fous_, _ctll, वेश्, ंगस_,
   {{0x2ef800cb,0x261c4070,0xc5f300c3,0x395fa216}},	//   harf_, mío_, בדה_, _gous_,
   {{0x2d8480b3,0x1b0a0079,0xaca48044,0xa5c70086}},	//   _imme_, শ্যই_, _kpọp, _ljóð,
   {{0x6d4d02a4,0x2002c039,0xed5986f0,0xe3b78173}},	//   _snaa, škio_, _dižu_, _абу_,
   {{0x2ef800fa,0x6376c119,0x7bcac150,0x77b04041}},	//   darf_, _lâng, _vifu, växl,
   {{0x394d030d,0x2bd84db4,0x629a8140,0x395f80d2}},	//   ñes_, _भूभा, _ixto, _xous_,
   {{0x261c4018,0x6b8700a8,0x752f1e17,0x63748060}},	//   hío_, tijg, recz, _tànd,
   {{0x20096217,0x673c4396,0xc7c8c00c,0x83870026}},	//   vrai_, _narj, _cốt_, тыме,
   {{0x69cbc1c6,0xffb7c0c3,0x261c4070,0x644683aa}},	//   _yige, _שלוש_, jío_, _škil,
   {{0x261c42b0,0x81bcc03f,0x6d4d0150,0x316001a8}},	//   dío_, _spēj, _unaa, _goiz_,
   {{0xc05b00d9,0xb113825d,0x4993001c,0xeab0005f}},	// [1cd0] _цій_, hụch, _میگر, معہ_,
   {{0x261c42b0,0x66034166,0xf773454c,0x6560805e}},	//   fío_, ánko, جار_, _aomh,
   {{0x0ccb96c0,0x395fa218,0xe8cb8759,0x21040039}},	//   िश्म, _pous_, िश्च, sčių_,
   {{0x20094157,0x78ad01ae,0x67d5a219,0x26de8b87}},	//   prai_, _kyav, году, _afto_,
   {{0xf41f1afc,0xdce2c38f,0x64464077,0x8d7782f0}},	//   ntä_, _zloć, _grki, _یارا,
   {{0x7d02e21a,0x46398156,0x2126c88b,0xe816025c}},	//   _ados, ечия_, _aboh_, _तमसा_,
   {{0x2bda16c0,0xb5959d93,0xdb018061,0x68e9c31d}},	//   _यूना, _бивш, _bhlò, tbed,
   {{0x2294411b,0x6446469a,0xdced006f,0xe9a9c1aa}},	//   _тися, _yrki, _blač, رگان_,
   {{0x05848007,0x63a3a21b,0x753d621c,0x2d92005f}},	//   _турм, ponn, _masz, ézem_,
   {{0x60dbe21d,0x69cbc1c6,0xf1ca000c,0x753d621e}},	//   scum, _wige, _lạt_, _lasz,
   {{0xcb6881aa,0x6d4f488b,0xc7c8c0d1,0x200b0036}},	//   _جمله_, _onca, _rốt_, erci_,
   {{0xceb24916,0x973cc41b,0xc984c01d,0x9f5e0047}},	//   מיי_, roća, _кучи, čtí_,
   {{0x291e0036,0xe44eca23,0xa2aa4048,0x2ef80086}},	//   ęta_, _уж_, _जुन्, tarf_,
   {{0xdcef003f,0x69dca21f,0x7989c713,0xdee2c883}},	//   ficē, _érec, liew, _лоши,
   {{0x2d926220,0x7bc1c0fa,0x46a40a3c,0xdb1d4480}},	//   tnye_, mmlu, _खुशह, _lusó,
   {{0xb8864185,0x7989c064,0x79842221,0xa9280066}},	//   hlíž, niew, _umiw, _drží,
   {{0xdce400b3,0xc726423d,0xd00751af,0x9f4f810d}},	// [1ce0] _alić, лдай, лете_, yrgð_,
   {{0x69d56222,0x2d92405c,0x64464011,0x7989c0eb}},	//   _buze, snye_, _vrki, hiew,
   {{0x201fc051,0x68f601c8,0xa96a40b4,0x753d6223}},	//   htui_, _keyd, _зина_, _fasz,
   {{0x14c881aa,0x7c2be224,0x99908166,0x2578c0a8}},	//   نهای_, _opgr, ťaži_, _zélf_,
   {{0x7bd6009c,0x261c4004,0xdef4859d,0x6acca225}},	//   _juyu, sío_, аплы, ाश्र,
   {{0x394fe226,0x2012409c,0x3a3a0053,0x69d56227}},	//   _angs_, muyi_, _kspp_, _fuze,
   {{0x2a354156,0x69d56228,0x64428051,0x6b88e229}},	//   _кэтр, _guze, svoi, vidg,
   {{0x7d04222a,0x7524622b,0x6b88cb87,0x5e935438}},	//   _ndis, nfiz, widg, _الفط,
   {{0xb71681b4,0x3494e22c,0x61fe622d,0x8c4382f1}},	//   _مباش, рапр, lspl, _лете,
   {{0x61e2006c,0x37e3c079,0x85148374,0x69c28078}},	//   _čoln, _মিশর, _डाँट_, lmoe,
   {{0x80c20045,0x2d5c5353,0x8afec09c,0x2b1b139f}},	//   रेसे, _díez_, _noƙe, _बाबु_,
   {{0x38694813,0x7d040669,0x69c280bf,0xdb1c450e}},	//   yyar_, _cdis, nmoe, _cirú,
   {{0x200b01cb,0x6018e22e,0xf76fc01c,0x645dc7fb}},	//   urci_, _роля_, زای_, øsit,
   {{0xf487c08c,0xdb038016,0xa666ce5f,0xdcebc017}},	//   _حامی, gonè, _مطبو, _ilgā,
   {{0x6376c379,0x6303c032,0x333e8060,0xb87b401f}},	//   _vând, _طويل, _matx_, _ofíc,
   {{0x3d0f4045,0xb4db40d2,0x6d40d372,0x69d54f2d}},	//   िलें_, _anàr, ndma, _ruze,
   {{0xdb03c032,0x63a5622f,0x27f201f4,0x3f8a01f3}},	// [1cf0] _ghnó, tohn, _gwyn_, bibu_,
   {{0x3dcd8aef,0x70d1d15e,0x2d81c05f,0x7afae230}},	//   _siew_, _हल्ल, éhez_, natt,
   {{0xdcfbc077,0x6444604e,0xa7fdc107,0x963558d5}},	//   znuđ, avii, gyűj, рнец,
   {{0x7c2d0044,0x973cc0ab,0x69c2868e,0xe0df0157}},	//   _kpar, koćo, gmoe, ncò_,
   {{0x442b6231,0x212915ce,0xf8078381,0x7afae232}},	//   _upc_, _mbah_, учен, katt,
   {{0x69cf441b,0x68f981f4,0x68ed5b62,0x7afae233}},	//   _hice, sawd, lbad, jatt,
   {{0x27e96234,0x69cf4570,0x539a421d,0x69dcc018}},	//   lpan_, _kice, _יישו, írel,
   {{0x68ed6235,0x201fc051,0xd044409c,0x63a7013b}},	//   nbad, ttui_, cciɓ, hojn,
   {{0x27e96236,0x316dd390,0x7989e237,0x3075c3d0}},	//   npan_, rkez_, riew, руйс,
   {{0x671c8a94,0xb225c026,0x2bd84027,0x7bce4018}},	//   _नायक_, амол, _भंसा, _xibu,
   {{0x7bd610db,0x61e20077,0xdb038c1e,0xd5b545cb}},	//   _suyu, _čolo, joné, ंताज,
   {{0x186a0974,0x6443403f,0x2d8b2238,0x68461511}},	//   вами_, ānij, gice_, анма,
   {{0x44206239,0x7c2bd433,0x61e5223a,0x25db0027}},	//   xti_, _upgr, _athl, _खूबी_,
   {{0x213f8056,0xcf928009,0x290c0080,0x21290303}},	//   _lauh_, ַטן_, şda_, _ebah_,
   {{0x34b28b6d,0x67170045,0x27ffe23b,0x96630949}},	//   _जर्द, _तारक_, lsun_, окре,
   {{0x68ed623c,0x6449a23d,0x7a40805f,0xdb03a23e}},	//   gbad, _orei, látá, sonè,
   {{0x3940623f,0xe0436240,0x69d70018,0x7c3b8d0c}},	// [1d00] rdis_, онти, _euxe, _nsur,
   {{0x6ffb02a6,0x1db84048,0x7bfb0323,0xfe724032}},	//   _שפיג, _आठवत, _שפיצ, يدا_,
   {{0x27e94f7c,0x68ed6241,0x68fbc2ff,0x69cf6242}},	//   apan_, bbad, kaud, _fice,
   {{0x7afc2243,0x3940405c,0xfbe08083,0x442d97d2}},	//   lart, qdis_, _aṣọ_, _bpe_,
   {{0x442041c8,0x97c6970f,0x7afac06a,0xa01b00cb}},	//   qti_, айде, yatt, rzög,
   {{0xc5ebc079,0x69cf6244,0x6374829a,0xa318943c}},	//   _কিনা_, _zice, _bàna, ужку_,
   {{0x65bd2245,0x3f8f41cb,0x69dc0080,0x69c46246}},	//   léhe, ègue_, nqre, omie,
   {{0x63a700fd,0x29048620,0x2cafc4f5,0x28c72247}},	//   zojn, _udma_, _bygd_, रेडि,
   {{0x7763c018,0x4973c11b,0x4420024c,0x27ffe248}},	//   _bonx, ільс, _nqi_, gsun_,
   {{0x250904fc,0x20004057,0x69c46249,0x29dc0019}},	//   گردی_, isii_, hmie, _oía_,
   {{0x3eb8c4a0,0x7c2d0663,0x68fbcb68,0x9f5d41aa}},	//   årt_, _spar, baud, éwé_,
   {{0x200de24a,0x7c2d1afd,0x65b60047,0x7bcf81cb}},	//   brei_, _ppar, sáhn, _écur,
   {{0x69d7224b,0x7afc224c,0x63a700da,0x442d821b}},	//   _suxe, fart, tojn, _xpe_,
   {{0x69d7224d,0x7c22a24e,0x7c2da24f,0xd6d0c5a7}},	//   _puxe, itor, çari, _عقب_,
   {{0x7c22a250,0x29dc0019,0x60cc403a,0x3f8ce251}},	//   htor, _cía_, ənmə, midu_,
   {{0x3f8ce252,0x224d46f0,0x39402253,0x75d3c0b4}},	//   lidu_, _ček_, _gais_, _căzu,
   {{0x98b95edf,0xdfd14032,0xd83b0119,0x69cf4e83}},	// [1d10] улат_, سيا_, _рэй_, _vice,
   {{0xdb038319,0x68fd2254,0x7af8c590,0x09de4079}},	//   poné, lasd, _jevt, _ডিজা,
   {{0x39400022,0x2ef84070,0x7c22a255,0x69cf6256}},	//   _yais_, _derf_, etor, _tice,
   {{0x3940004d,0x3f8ce257,0xa5d9c052,0x7bdf81ff}},	//   _xais_, hidu_, אַסי, íquo,
   {{0x7c22a258,0x3f8cc6f0,0x798d6259,0x6d40845a}},	//   gtor, kidu_, miaw, _dama,
   {{0x7af8e25a,0xf1ca00d1,0x6d4080b9,0x644986bc}},	//   _nevt, _lạp_, _eama, _vrei,
   {{0xa91dc41b,0x44390046,0x6449802c,0xf53f225b}},	//   liži, hws_, _wrei, nlås_,
   {{0x200dc63f,0x7c3ba25c,0x7529a25d,0x442d81cb}},	//   trei_, _tsur, _ubez, _tpe_,
   {{0x25ad8283,0xe80e8b35,0x973cc077,0x68fd0ba2}},	//   _ikel_, _सिया_, moćj, dasd,
   {{0x02a791d7,0x27ffe25e,0x6374805e,0x68fbe25f}},	//   _крем, rsun_, _tàna, saud,
   {{0x798d4f7c,0xfaa5d0c4,0x69d8e260,0x68fbe261}},	//   kiaw, сано, _cuve, paud,
   {{0xf1bf400c,0x2902c107,0xaca380eb,0xc69240c3}},	//   _nhá_, ókat_, _ndịn, לאי_,
   {{0x9cdac009,0xc8dac052,0x3f8ce262,0xc19a8052}},	//   _עקספ, _עקסט, bidu_, רשרי,
   {{0xdee321a1,0x395fe263,0x3cfd823b,0x69d80107}},	//   зори, ljus_, hawv_, _évek,
   {{0x5f74c5a7,0x3eaac066,0xf0d2c25d,0x26c54574}},	//   _ظاهر, čité_, _rịzọ, _úloh_,
   {{0x4422007a,0x65930267,0x7bd9cfaa,0x25a94157}},	//   ptk_, _нају, _kuwu, goal_,
   {{0xf53f04c9,0x7c228402,0x2ef847b0,0x68e401c0}},	// [1d20] rlåt_, xtor, _perf_, _ifid,
   {{0x799ba264,0x65bd05ee,0x8afec09c,0x25bf8545}},	//   _ajuw, réhe, _koƙa, _ahul_,
   {{0x2ef84101,0xdfcf420c,0x7c22a265,0x65bd0107}},	//   _verf_, ريم_, wtor, séhe,
   {{0x61fc8240,0x2ef847f5,0xb87b0018,0xcd36401c}},	//   _ærli, _werf_, lcía, _اردب,
   {{0x25bfa266,0xdb018347,0x0b8a8760,0xdce280b3}},	//   _dhul_, _sklá, лски_, hkoć,
   {{0x39408039,0x7c245a71,0x68e2c0c4,0x200200f8}},	//   žis_, mtir, _sfod, iski_,
   {{0x63ae405c,0x6146a267,0x63ab0018,0x7afe4469}},	//   _ikbn, _лева, _ígne, mapt,
   {{0x6566409c,0x8d969438,0x7d968032,0x6d40809c}},	//   _jokh, _الرش, _الرؤ, _uama,
   {{0x26180a3c,0x6d446268,0xb4d8c50b,0xf1ca000c}},	//   बूती_, idia, _ाली_, _rạp_,
   {{0x39424240,0x64494570,0x3cf08374,0x68e28206}},	//   _laks_, _šeik, आरके_, lcod,
   {{0xdb1c5dfb,0x644be269,0x9999001b,0x657bc010}},	//   _chré, _ergi, икот_, bhuh,
   {{0x65664339,0x63a8e26a,0xf651805f,0x24804df5}},	//   _nokh, sodn, _کئے_, kzim_,
   {{0x644bc9fa,0x7a43005f,0x69da823c,0x2bd8626b}},	//   _grgi, kítá, _hute, _भूला,
   {{0x661500fc,0x24804047,0x7bdfcc43,0x32551cca}},	//   tuzk, dzim_, _équa, овгр,
   {{0xf773c0c3,0x5693e26c,0x4439004d,0x42db8052}},	//   _מקס_, _нашт, sws_, רקלע,
   {{0x2002226d,0x7c24626e,0x636dd9a9,0x3495023d}},	//   bski_, ftir, _rúni, _майр,
   {{0x657d01b4,0xf53f1127,0xc7b9c107,0x636b0107}},	// [1d30] mhsh, slås_, ktől_, _bünt,
   {{0xa91dc04f,0xdce0a26f,0x04e9402a,0xfb15001c}},	//   riži, _domč, গণের_, _بودج,
   {{0x3a3e80c9,0x3cfd8046,0x2eff41cb,0xce590ed5}},	//   _nstp_, tawv_, _œufs_, _танц_,
   {{0x69c08089,0xdce08053,0xdb01db9b,0x637d8396}},	//   _chme, _fomč, volí, _kèng,
   {{0x2d992270,0x63748580,0x3e4780d1,0x637d888b}},	//   inse_, _càno, _sđt_, _jèng,
   {{0x63aa81f4,0x3cfd8022,0x39424011,0x636b2271}},	//   gofn, sawv_, _zaks_, _günt,
   {{0x39424033,0x2e4840c5,0x637d8396,0x171c0052}},	//   _yaks_, _лято_, _lèng, אווע,
   {{0xdb0382b0,0x6009e272,0x636b00fa,0x249f8022}},	//   moní, аним_, _küns, _txum_,
   {{0x7afa88d2,0x4439a273,0x644d2274,0x21294056}},	//   _fett, _ès_, _nrai, ifah_,
   {{0x93978e40,0x7afa8093,0x2129405c,0xf41f0079}},	//   _اجرا, _gett, hfah_, ধবার_,
   {{0x6444c2bc,0x7c2440fc,0x6fe18079,0x657bc073}},	//   _šiit, ztir, _নিয়ে, phuh,
   {{0x3a98c04c,0x443f8085,0x3cca05a6,0x69d805ee}},	//   стью_, _ksu_, илно_, _évei,
   {{0x6566442c,0xdce442bc,0x7afe4611,0x2d9dc024}},	//   _rokh, lkić, yapt, _ijwe_,
   {{0x7c3bc024,0xdb1c4032,0x65bec0fd,0xa3dec045}},	//   mwur, _thré, rëhe, _दंत_,
   {{0x21294056,0x7f43e275,0x7a43005f,0x09e311fb}},	//   ffah_, _ianq, vítá, досн,
   {{0xaca380eb,0xf53f1a5e,0x6d4447f3,0x68fb856e}},	//   _adọn, slår_, udia, _neud,
   {{0xa76652bf,0x7bc1a276,0x6449c535,0xeb9a2277}},	// [1d40] окад, _ohlu, nvei, _вип_,
   {{0x27ede278,0xaade0314,0x6d462279,0x212d8303}},	//   ipen_, _मलिक, ldka, _abeh_,
   {{0xee3a627a,0x3942627b,0x9586a0a6,0x2d8fa27c}},	//   рне_, _taks_, олже, fige_,
   {{0x2d8fa27d,0x68ff4080,0x66e00031,0x7c3bc044}},	//   gige_, caqd, _fàkó, kwur,
   {{0x27edc1d4,0x4fc69df8,0xa3d4817e,0x2900627e}},	//   jpen_, оска, _सूख_, maia_,
   {{0x7d098051,0x2ca08283,0x7bc1a27f,0xe9e6a280}},	//   _edes, ħid_, _chlu, оцио,
   {{0x6d562281,0x7bc18061,0xfce680d9,0x69968119}},	//   _onya, _dhlu, _мово, _драх,
   {{0xdb1a8019,0x973cc6f0,0x7bc1800b,0x443f9053}},	//   _pitó, moći, _ehlu, _fsu_,
   {{0x68e44018,0x69da8044,0xdcfb8043,0x3d1bc5da}},	//   icid, _wute, _smuć, _यारे_,
   {{0x64408baf,0x543b881b,0xdb1a801d,0xd6dae282}},	//   _ismi, _דעמא, _vitó, шти_,
   {{0x6d440a49,0xb87b4019,0x973cc0ab,0x69da82f7}},	//   _baia, _afíl, noći, _uute,
   {{0x1bfe817e,0x2d9900c4,0xe1efc5d3,0xed57c5bf}},	//   _उबाल_, unse_, کسی_, _мох_,
   {{0x7afc55b6,0x798f2283,0x4346d3f8,0xf8ca83fc}},	//   _oert, ricw, _медв, िधिय,
   {{0x98b94119,0x7afc6284,0x68e46285,0xf41380c3}},	//   _lasă_, _nert, ecid, ופש_,
   {{0x6d442286,0xdcfb813f,0x4432088b,0x32050107}},	//   _faia, _umuć, _epy_, ély_,
   {{0x6d56002f,0xab5d8036,0xa91dc007,0x59cac048}},	//   _gnya, _duży, sižv, ागिर,
   {{0x644d2287,0x6441003f,0xe87c4bde,0x439501bc}},	// [1d50] _urai, ālis, rüşü, _наис,
   {{0x3946801d,0x394480c4,0x2139013b,0x9715109b}},	//   edos_, _aams_, lesh_, _эмоц,
   {{0x77b04041,0x27edc232,0x6440a288,0xbb3a00c3}},	//   växt, zpen_, _asmi, _העתי,
   {{0x7bc8c056,0xe9d840d7,0xf5380009,0x2004c017}},	//   hmdu, ікі_, ַטור_, ksmi_,
   {{0xdee5879a,0x3169009c,0x7d0980fd,0x78bd4017}},	//   поли, _moaz_, _vdes, _uzsv,
   {{0xdb01c804,0xa3dee289,0xe739912e,0xd7ab0384}},	//   kolá, _दूध_, сек_, चकिच,
   {{0xdb1c4004,0x39468105,0x2139228a,0x20190073}},	//   _eiró, bdos_, kesh_, husi_,
   {{0xf6524093,0x27f9421b,0x68fd4010,0x69c2e28b}},	//   _אצל_, _kwsn_, _jesd, _choe,
   {{0x7529e28c,0x98bf8a14,0x7bd54b97,0x6fab03ae}},	//   rfez, _kauč_, _kizu, चकां,
   {{0x644f5ca5,0x798d031c,0x547c4093,0x6603805c}},	//   _mrci, _amaw, יטחו, psnk,
   {{0xa91d8039,0x29d741b7,0x7bdd628d,0x31690472}},	//   _amži, _għat_, _lusu, _boaz_,
   {{0x20190418,0xb92381c0,0xcf8902a6,0xfd64c112}},	//   fusi_, _aarẹ_, _גט_, _mawụ,
   {{0x46abc54a,0xf2b84047,0xd7bd4048,0x3f910020}},	//   _घुरह, _अर्घ, ्गाच, fizu_,
   {{0x32180fb2,0x7c26228e,0x6569805e,0x798d1181}},	//   tury_, rtkr, _loeh, _emaw,
   {{0x3ebe04e6,0x6d440119,0x12fac093,0x6d560033}},	//   ått_, _taia, _ההצב, _tnya,
   {{0xa0a60e03,0x644f40b3,0x18a60289,0x06ab0079}},	//   _найд, _brci, _найм, _গৃহি,
   {{0xdca35924,0x290060e2,0x21674af9,0xd5af4865}},	// [1d60] еати, raia_, чити_, افق_,
   {{0x46a640c5,0x290040fc,0x2b458011,0x6e2d8036}},	//   пазв, saia_, _nalc_, łaby,
   {{0x7bd54232,0xdce2c04f,0x7d00e28f,0x11d6401c}},	//   _dizu, _sooč, yams, ستاد,
   {{0x7bdd6290,0xdb1c4ac6,0xa3e44028,0x39468007}},	//   _fusu, _piró, _पंप_, udos_,
   {{0x69d62291,0x7bdd400d,0x26180a3c,0x644f46f0}},	//   _miye, _gusu, बूरी_, _grci,
   {{0xa3c2c260,0x2d8d8112,0x636dc03c,0x272f806a}},	//   ्दछ_, _emee_, _xúnt, jını_,
   {{0x7d00e292,0x98ac8080,0x39468010,0x25adc99e}},	//   tams, ılıq_, pdos_, foel_,
   {{0x69c40015,0xdb1c4019,0x7e9b4093,0xdb01c531}},	//   _nhie, _tiró, _הסלו, volá,
   {{0x321a4066,0xdced0011,0x3ce6a293,0x38604004}},	//   lupy_, _hlać, mcov_, nxir_,
   {{0x29d741b7,0x69d60171,0x7d00e294,0x2d925d96}},	//   _għas_, _aiye, sams, hiye_,
   {{0xdb18c066,0x69c4005e,0x25adc4f1,0x69c88157}},	//   _chvá, _bhie, boel_, _èdes,
   {{0xdc2ac1aa,0x0dcac119,0x69c9c1c8,0xdb01c107}},	//   _هسته_, _улей_, cmee, rolá,
   {{0x2d8059b7,0x6c34c2cf,0xdb1e0019,0x645de295}},	//   dhie_, _آفتا, _nipó, äsit,
   {{0x213900fd,0x2002c007,0x69de00bc,0x7afe2296}},	//   sesh_, škis_, _bupe, _cept,
   {{0x20192297,0x4ea41c34,0x213900da,0xae1d0342}},	//   susi_, ерта, pesh_, बंधन_,
   {{0xe3b8c676,0x798d2298,0xdbd6c04c,0xc0d141c0}},	//   llı_, _umaw, sään, _abíọ,
   {{0x7f45005c,0x7ae56299,0x3ce68166,0xa068401b}},	// [1d70] _tahq, tcht, dcov_, паѓа_,
   {{0x673ae29a,0x69de0303,0x0bb444df,0xd25b40d7}},	//   netj, _fupe, ебую, йце_,
   {{0x2d92629b,0x7ae5543b,0x69d6229c,0x637d8016}},	//   biye_, rcht, _yiye, _lènc,
   {{0x6442c04c,0x7bdd629d,0x2d92629e,0xe3b8c59a}},	//   _osoi, _tusu, ciye_, hlı_,
   {{0x644f4194,0xb9058027,0x272f8189,0xbb45879c}},	//   _urci, _नल_, yını_, делк,
   {{0xdb1e0016,0xb8834066,0x673ae29f,0x7bdf22a0}},	//   _hipò, rníč, jetj, _muqu,
   {{0x25adc4e1,0x644d62a1,0x6da5e145,0x9951c047}},	//   toel_, lvai, мика, _zář_,
   {{0xa3dec045,0x657ba2a2,0xdb0a80cb,0xdea4808c}},	//   _दंश_, _uluh, elfä, رینی,
   {{0x69c401f4,0x394962a3,0x799be2a4,0x290da2a5}},	//   _rhie, idas_, rnuw, _idea_,
   {{0x8e09e2a6,0xeaf881aa,0x27eda2a7,0xdb1c098b}},	//   онов_, _فرمت_, _iten_, områ,
   {{0x6f01c06c,0xaca34094,0xd1b8c646,0x69d622a8}},	//   ralc, _baịb, _کالا_, _piye,
   {{0x3946c018,0xe8dfc0eb,0x6f01e2a9,0xfd1f0157}},	//   _gaos_, _kpọm_, salc, ggì_,
   {{0xe3aec5dd,0xd469c640,0x60db812c,0x8c45c3da}},	//   _аб_, _филе_, _mgum, _целе,
   {{0xdb1c41b4,0x2d9262aa,0x657d41c8,0x81e50079}},	//   _phrí, wiye_, _alsh, _নিজ_,
   {{0x60db81ae,0x2d8062ab,0x2fdf8010,0x1d0a401b}},	//   _ogum, thie_, _luug_, жеби_,
   {{0x78a4023b,0x9f590051,0x60d68007,0x6f03a2ac}},	//   _txiv, essä_, žymi, hanc,
   {{0x65644cff,0x656be2ad,0x61e4c60f,0xf9c70646}},	// [1d80] rjih, _mogh, _čili, _تحوی,
   {{0x753bc0c9,0x656be2ae,0x290da2af,0x69de22b0}},	//   heuz, _logh, _adea_, _tupe,
   {{0x2d8062b1,0xa6ca078a,0x637fe2b2,0x443fc056}},	//   phie_, _گوگل_, _gêne, hwu_,
   {{0x661c22b3,0xe3b8c530,0x673c22b4,0x6d59c044}},	//   murk, zlı_, lerj, _nnwa,
   {{0xd90d91be,0x661c07c5,0x2900001d,0xb8f6808f}},	//   صیل_, lurk, _meia_, _सण_,
   {{0x290022b5,0x7c29c7fb,0x7522c23f,0x2d8fc09c}},	//   _leia_, dter, _scoz, _amge_,
   {{0xa3c1cfd1,0x200680c4,0x3ce6802d,0x69d84107}},	//   ंतन_, ssoi_, pcov_, _éves,
   {{0x64440f63,0x071e4a3c,0x656be2b6,0x27ed00b4}},	//   _osii, _पाँव_, _cogh, ţeni_,
   {{0x6f03a2b7,0xe3b8c38a,0xb4db4031,0xa2d0e2b8}},	//   banc, tlı_, _baàj, डेन्,
   {{0x661c22b9,0xaca4c0eb,0x70db48b8,0x39494007}},	//   kurk, _nkụz, _भल्ल, zdas_,
   {{0xd5afc9cd,0xe3b8c38a,0x442962ba,0xaa58d0e9}},	//   _ас_, rlı_, zta_, чину_,
   {{0xe3b8c2d6,0x27e022bb,0x2d9e4107,0xc5f384e0}},	//   slı_, _buin_, étel_, _ידע_,
   {{0x9f590051,0x673c22bc,0xe3b8c138,0x7bd70379}},	//   yssä_, ferj, plı_, _pixu,
   {{0xd250c0b8,0xe8e000d1,0xc0580589,0x60c2e2bd}},	//   _منت_, _muội_, фію_, _izom,
   {{0x290022be,0x8d7741b4,0x356b6219,0x7bdf005c}},	//   _feia_, وارا, оран_, _wuqu,
   {{0x63748031,0x7d0d01c6,0x200f401f,0x637d888b}},	//   _dàni, _udas, ágio_, _mèna,
   {{0xfbdf62bf,0x644d401e,0x8cc4c036,0x27e00991}},	// [1d90] _quê_, uvai, ाइटो, _guin_,
   {{0x644d62c0,0xdb1c429a,0x60c022c1,0xdce2c085}},	//   rvai, _chrà, ümme, _fmoħ,
   {{0xdb1c62c2,0xa3e44c6b,0x394922c3,0x6d49c498}},	//   _virð, _पंथ_, _kaas_, ydea,
   {{0xf9d9c009,0x1fe68079,0x7c29e2c4,0x7d0462c5}},	//   פֿעל, _নিজস, yter, cais,
   {{0x7c29e2c6,0x31a4038a,0x69cba2c7,0x201b403a}},	//   xter, nıza_, rmge, quqi_,
   {{0x394922c8,0x637d80b6,0x7bd8c0af,0xdb0740d9}},	//   _laas_, _bèna, _nivu, _skjæ,
   {{0x3ce08066,0xbbbd4dd0,0xaca34044,0x2d87801e}},	//   živa_, ्गीक, _maọb, ènes_,
   {{0x443fc036,0x394922c9,0x673c004f,0x290da2ca}},	//   twu_, _naas_, zerj, _udea_,
   {{0x7bd8c00d,0x661c22cb,0x67200281,0x656bc23f}},	//   _bivu, zurk, _बालक_, _vogh,
   {{0x6b950043,0x20094007,0x6ade1057,0xc8a880b2}},	//   jizg, isai_, _मलेर, _छुटट,
   {{0x656bc032,0x7645000d,0xc3324009,0x3c29802d}},	//   _togh, _nshy, נוט_, lúv_,
   {{0x200b4123,0x753d22cc,0x636f8125,0xd848c02e}},	//   _ovci_, gesz, _tøns, _fọ_,
   {{0x7d0462cd,0x290022ce,0xb4d942ea,0x764501c6}},	//   vais, _veia_, ाशो_, _ashy,
   {{0x7643c07a,0x2d8200fd,0xd00ec61e,0x6b8380d1}},	//   _tsny, shke_, _الو_, nhng,
   {{0x29000c9e,0xdb01c4c9,0xcb12c0c3,0x753d0107}},	//   _teia_, rolä, _עלה_, besz,
   {{0x7bc762cf,0x7bd8c7cf,0x57ea47bc,0x69d9c2c0}},	//   _ahju, _zivu, здам_, _jiwe,
   {{0x66e607e1,0x2d8000b4,0x212f8011,0x7d1b0004}},	// [1da0] _попа, _ilie_, dfgh_, óuse,
   {{0x69d9e2d0,0x4a46011b,0x317f8303,0x7d00a2d1}},	//   _liwe, _знов, _aluz_, _sems,
   {{0x7e610041,0x7d0462d2,0xe802846d,0x61ebc0cc}},	//   älpt, pais, रीना_, _înlă,
   {{0x09e70079,0xee49c00c,0xceb2c323,0xd5b90017}},	//   _ফিচা, _mẽ_, ניא_, stāv_,
   {{0x26c70047,0x25a0404f,0x92e2002a,0xf9f2002a}},	//   _únor_, mnil_, দরী_, _জটিল_,
   {{0x2904e2d3,0xa294811e,0x25a053ca,0xfc3f403c}},	//   wama_, калі, lnil_, _uxía_,
   {{0x3ebe410d,0x7d00806a,0x69d9c1ae,0xa3e440b2}},	//   _átt_, _tems, _biwe, _पूत_,
   {{0xae09c17e,0x6d49802c,0x25a04d3c,0xf8bf41c0}},	//   _विजन_, _gaea, nnil_, _gbés_,
   {{0x2ac68171,0x03200374,0xdca390c2,0x7c2b80a8}},	//   _bíbí_, _बांह_, _бати, ctgr,
   {{0x2d9200bb,0x2d8022d4,0x2fd8c086,0x69d9c0cb}},	//   _amye_, _alie_, örg_, _eiwe,
   {{0x798440f7,0x2d800053,0x6721c045,0x661e40f8}},	//   khiw, _blie_, _मारक_, nupk,
   {{0xaaa9a2d5,0xc486c156,0xbcfb401e,0xbfa580d1}},	//   _चुटक, _плек, _inég, hiệ,
   {{0x7a36c080,0x7bd8c157,0xec13d546,0x394904f1}},	//   _bütö, _tivu, _موند, _vaas_,
   {{0xadc441c0,0x442b03a0,0x644f08c7,0xd5df8109}},	//   _ikẹt, rtc_, rvci, _पूँज,
   {{0xf9c74844,0x320a1f20,0x637901c0,0x81c74025}},	//   ещан, gsby_, _hìnk, ещае,
   {{0xf77341aa,0x8d77054c,0x6d960017,0x79844c47}},	//   گار_, _ساعا, lšan, ghiw,
   {{0xdb1c4359,0xdbe44031,0x29068140,0x20094026}},	// [1db0] _shrá, _jèèj, daoa_, usai_,
   {{0x200bc166,0xa30900fb,0x7bdaa2d6,0x2c18c314}},	//   ácii_, _کرکے_, _nitu, _दिनं_,
   {{0x6f05405c,0xe717c4e0,0x22594032,0x200b0157}},	//   rahc, תחבר_, بلاد_, lsci_,
   {{0x63bf00a0,0x752280bb,0xd5b30109,0x25a049a2}},	//   ůzně, ggoz, ीतिज, cnil_,
   {{0x6d960279,0x6d4b81b0,0xb954409b,0x69dac036}},	//   kšan, rdga, _свящ, _पंजी,
   {{0x3b05c435,0x6d4d4a63,0x248962d7,0x69d9e2d8}},	//   xalq_, ldaa, mzam_, _siwe,
   {{0x69d9e2d9,0xadc441c0,0xcf580093,0xdcfb8066}},	//   _piwe, _akẹt, תבות_, _hluč,
   {{0x6d9622da,0x7c2d62db,0x7bdaa2dc,0x11d48032}},	//   ešan, otar, _eitu, _متقد,
   {{0x4439421b,0xa3dd0a3c,0x6d5d40f8,0xd6db8976}},	//   _jps_, _तंग_, _mnsa, _ете_,
   {{0x69daa2dd,0x69cf0046,0x68e9e2de,0x68ed22df}},	//   _éter, emce, sced, _afad,
   {{0x6f070166,0x6d5d62e0,0x201900c4,0x60c40107}},	//   dajc, _onsa, ersi_, _szim,
   {{0xed57011b,0x7bc880fd,0xee49c015,0x3169405c}},	//   вою_, _zhdu, _vẽ_, jjaz_,
   {{0xfebbc08c,0x3dc901c8,0x6d4bc05e,0x69c98061}},	//   _کاشت_, _dhaw_, _iaga, _mhee,
   {{0x66e2c267,0xe0df4031,0x9724c5a7,0x69dc8157}},	//   _коша, _agò_, _مفهو, _èrec,
   {{0xa2d34185,0x66031892,0x394b62e1,0x637fc1cb}},	//   भेम्, ипра, _bacs_, _gêna,
   {{0x6569c0da,0x6d4d429e,0x69db8303,0x61e3c0f8}},	//   njeh, gdaa, _niue, _iunl,
   {{0x29024ec5,0xa3d64048,0x1ae64409,0x42c4002a}},	// [1dc0] _veka_, _हळद_, возм, ্ডেশ,
   {{0x6d4be2e2,0x656f41b4,0x25a062e3,0x8ad641b4}},	//   _laga, _eoch, snil_, نتائ,
   {{0xdce45361,0x7c2d53f3,0xf7434698,0x394dc033}},	//   ljič, atar, рехо, kdes_,
   {{0x7c2d62e4,0xa113871d,0x69c9a2e5,0xa91d8089}},	//   btar, لومت, _chee, _alžb,
   {{0x3ce0a2e6,0x661e4033,0x213fc033,0x394062e7}},	//   živo_, supk, deuh_, meis_,
   {{0x656f62e8,0xdb08c107,0x38bd0032,0xbb7640c5}},	//   _zoch, kodá, lárú_, _румъ,
   {{0x2d84c669,0x9e038007,0x394dc14b,0x44394147}},	//   thme_, ачыл, fdes_, _zps_,
   {{0x6288e2e9,0x3f9822ea,0x656f62eb,0x44204e5d}},	//   vzdo, hiru_, _xoch, oui_,
   {{0x75e783a6,0x37e6811b,0x98be0185,0x5c74d828}},	//   _hızl, _розг, ětě_, улпт,
   {{0x6d4bd2e4,0x75e783a6,0x2904a2ec,0x7f4ac03a}},	//   _eaga, _kızl, _hema_, _qafq,
   {{0x7bdc62ed,0x7d02e2ee,0x3f9b8669,0x3d1bc08f}},	//   _miru, _teos, èque_, _याचे_,
   {{0xd946c1bd,0x7dc5e2ef,0x39404070,0x76584051}},	//   _једи, rósc, jeis_, ävyy,
   {{0x7c2d594f,0x3f810046,0x5334e2f0,0x25754240}},	//   xtar, _plhu_, _белт, _målt_,
   {{0x29048714,0xfd554044,0x3f9822f1,0x7bdc46f3}},	//   _lema_, _fraị, giru_, _niru,
   {{0xe8d90112,0xd5b90017,0x69dccfc2,0xdced4077}},	//   _inọ_, utās_, _éres, nkać,
   {{0x88c80047,0x68ed1996,0xa49b45ef,0x6d4bc1c8}},	//   _stěž, _ufad, _deòn, _xaga,
   {{0xd1b8078a,0x656f62f2,0x69c990b5,0xb87b001f}},	// [1dd0] _جاوا_, _voch, _rhee, ecív,
   {{0x1b14c879,0xd9cba247,0x7bdc45c5,0x6d4d62f3}},	//   ত্রে_, िष्ट, _ciru, sdaa,
   {{0x656f62f4,0x24894036,0x645a003f,0xdcfb8570}},	//   _toch, szam_, ātie, _smuđ,
   {{0x27e48063,0x442de2f5,0x6d4d4057,0xfc3f403c}},	//   _bumn_, yte_, qdaa, _uxío_,
   {{0xec354009,0x4420402b,0x94874156,0x6d40d18d}},	//   _גאָר_, cui_, _рынд, dema,
   {{0x76554064,0x399ac017,0xdb01c02d,0x7982c1ae}},	//   _trzy, zīst_, solú, _alow,
   {{0x2d9922f6,0xe800ca3c,0x6f08c070,0x439450a1}},	//   kise_, लीसा_, dadc, _тарс,
   {{0x2d868004,0x7545d707,0xa3e7c8c5,0xb145c156}},	//   choe_, униз, _मंद_, унил,
   {{0x779380fb,0x6d4be2f7,0xd5b88b65,0x25a6c0ce}},	//   _پیغا, _vaga, _рср_, _djol_,
   {{0xe1f9cb0c,0x657bc56f,0xc0c8a2f8,0x61e3e2f9}},	//   нго_, skuh, _русе_, _punl,
   {{0xadf58844,0x7dc7c05f,0x25a6c041,0x5187c119}},	//   _спеш, _műsz, _fjol_, _иуда,
   {{0x7a7a8052,0x2d9922fa,0xda7a8052,0x7982e2fb}},	//   _ארעס, gise_, _אנער, _glow,
   {{0x6f03e2fc,0x69dcc23f,0x81ac4079,0x3f8340e5}},	//   _tenc, _èrea, গতম_, _olju_,
   {{0x63b522fd,0x200bc166,0xd3788514,0x44204823}},	//   gozn, áciu_, _tiće_, vui_,
   {{0x69c40064,0xdbd1c54a,0x61e3c02f,0x395fa2fe}},	//   रतदी, _müüj, _uunl, _onus_,
   {{0x2258c065,0x3f9822ff,0x645600c3,0x7f940080}},	//   ærke_, siru_, _tryi, _müqə,
   {{0x442d824c,0x79840150,0x25bfc0b4,0x53ca5948}},	// [1de0] _nqe_, _iliw, ilul_, егам_,
   {{0x6d40e300,0x25754041,0x64444149,0x09dc8048}},	//   zema, _sålt_, rwii, यद्य,
   {{0x7bdc6301,0x79842302,0x2904a303,0x6b7ac052}},	//   _viru, _kliw, _pema_, ערענ,
   {{0x05ba8e5f,0x2b4c953f,0x3f836304,0x394d8cc6}},	//   ردات_, _sadc_, _elju_, _caes_,
   {{0xdca38abe,0x7f41c13b,0x7dc7c107,0x79842305}},	//   баци, kelq, _fűsz, _mliw,
   {{0x6d40e306,0x2904932b,0xc319c079,0x1ae35702}},	//   wema, _wema_, ত্তি_, _горм,
   {{0xee3a4051,0x2d99018c,0x79842307,0x7c3b8a24}},	//   _янв_, yise_, _oliw, _epur,
   {{0xe5c6c39d,0x5e570009,0x81bd003f,0x6b83c303}},	//   ысло, ריקע_, ntēt, _alng,
   {{0x6da4006f,0x6d960e5a,0xa3b60036,0x442d817b}},	//   rđal, ršal, ड़ता_, _gqe_,
   {{0x7d0643db,0x9f406308,0x7c20d1e6,0xeb9f011b}},	//   _leks, mpió_, rumr, rsøk_,
   {{0x7c2d00fd,0x6e21e309,0x4e1a801c,0x6f08c750}},	//   _sqar, gulb, _ستاد_, radc,
   {{0x63748031,0x7984099e,0x6d428545,0x7982cfee}},	//   _gànr, _cliw, neoa, _ulow,
   {{0xa877d2c0,0x4422230a,0x657d230b,0x33f6c0b4}},	//   _محور_, guk_, rksh, _счес,
   {{0xb865d1be,0xdfd0c1b4,0x69c0e30c,0xc7a3c2f8}},	//   _خامو, _بيت_, llme, _личк,
   {{0x3da750fc,0xf1bf0089,0x387f03aa,0x6b9adadd}},	//   граб, plá_, šur_, mitg,
   {{0x7c22a30d,0x442f8157,0x44b60044,0x50f5442e}},	//   kuor, ytg_, ọsụ_, рзат,
   {{0xb87b402e,0x443b005c,0x68e2c12c,0x8ccb0036}},	// [1df0] _afír, _upq_, _mgod, सेखो,
   {{0x25e64027,0x65608b1a,0x27e6c00c,0x3d1b4031}},	//   _जूही_, _anmh, _muon_, _bàwà_,
   {{0x68fbc1f4,0xa3b208fb,0x27e6c0d1,0x7c3b835b}},	//   ybud, टकर_, _luon_, _spur,
   {{0x68e2c00b,0x7c2280c4,0x850483be,0x7bde1a5d}},	//   _ngod, fuor, مومن, _zipu,
   {{0xf3ff01ff,0x6ea34062,0x1b1a402a,0x7d09d664}},	//   ixão_, कपहु, ন্ধে_, vaes,
   {{0x3f9a40b3,0xab6281df,0x5c04839d,0x447c0009}},	//   cipu_, şünm, сяца, ענגע,
   {{0x27f8806c,0x7c3d40b9,0x7d09c025,0xa49b4321}},	//   _črne_, _hpsr, taes, _meòm,
   {{0x64498c5f,0x442f805c,0xdb15013b,0xa49b4321}},	//   _tsei, ptg_, fozë, _leòm,
   {{0x64a5e30e,0xdca5cb8e,0x27f8805b,0x9f85d17a}},	//   рапа, рапи, čený_, игид,
   {{0x27e6e30f,0x78a4cb7e,0x38696310,0x6615c066}},	//   _duon_, _živc, ixar_, ázko,
   {{0x442217a6,0x02a78f4b,0xa806c30d,0x290b2311}},	//   wuk_, _срам, _peñó, faca_,
   {{0x6d4f41c8,0x7f43a312,0xd5440031,0x7bde2313}},	//   _naca, lenq, _dé̟s, _sipu,
   {{0xc8d00045,0x69cd001c,0x39422314,0x6d7ac0c3}},	//   सेंट, _dhae, reks_, _שאנח,
   {{0x7df3c0cc,0x799bc230,0x6376c0cc,0x88c8c0d9}},	//   _răsf, liuw, _dâns, _слів_,
   {{0x121903d0,0x3ebe010d,0x645cc017,0x7d0b8006}},	//   люты_, ætt_, ārie, kags,
   {{0x79840150,0x60c9804f,0xa49b4060,0x6459c062}},	//   _uliw, _ozem, _teòl, _krwi,
   {{0x8c4612b0,0xdced1ba6,0x3f9a412d,0x9f448157}},	// [1e00] _тепе, _glađ, tipu_, _fumè_,
   {{0x69df2315,0x2578c10d,0x29d78085,0x81bd0017}},	//   _éper, _hélt_, _għaz_, stēt,
   {{0x81e7c079,0xa3e7c09d,0x171b0009,0x4a4653e2}},	//   মীর_, _मूस_, _בויע, рнев,
   {{0x2d8948c3,0x3f85a316,0x14c8801c,0x63748016}},	//   chae_, _allu_, ههای_, _rànq,
   {{0xdca68f1e,0x33d640d9,0x7afd8107,0x7c3d4140}},	//   шади, _вівт, _ősta, _gpsr,
   {{0xab094a1d,0x6d4280fc,0x6d446317,0x7c2281a8}},	//   _متفق_, seoa, leia, ruor,
   {{0x6f0a80b3,0x44326318,0x46a36319,0x27e6cb6f}},	//   rafc, lty_, _дарв, _suon_,
   {{0xdb0744f5,0x68e4231a,0x6d4f4004,0x3f85a31b}},	//   _skjø, _ngid, _xaca, _ellu_,
   {{0x61e0805e,0x69c0c086,0xa3c3c063,0x69c280b2}},	//   _iiml, rlme, ्षं_, mloe,
   {{0x69c281f4,0x6e3e00d9,0x39524051,0xe8e0035d}},	//   lloe, _oppb, hdys_, _nuối_,
   {{0x61e0838a,0x443dc05c,0xa3d74371,0x6459e31c}},	//   _kiml, _epw_, ागत_, _erwi,
   {{0x25a680de,0x27e6c04c,0x7c245ca5,0x61e0a31d}},	//   nnol_, _tuon_, kuir, _jiml,
   {{0x637d8303,0x3952631e,0x248dc036,0x7c244043}},	//   _bènh, ddys_, czem_, juir,
   {{0xdb0544d3,0x4ea71dc5,0x8cb0454a,0x68e4231f}},	//   llhö, арба, _अँजो, _egid,
   {{0xf206c0c5,0x7bdfc0c4,0x69c28545,0x44326320}},	//   _тяло, _èqua, kloe, ety_,
   {{0xccf8431f,0x7c246227,0x69cd043e,0xf8bf4053}},	//   ићу_, fuir, _uhae, _pyé_,
   {{0x752d003a,0x443240b1,0xc31c002a,0x61e88073}},	// [1e10] _icaz, gty_, দ্ধি_, _ludl,
   {{0xf0d2c0eb,0x63b88066,0x38694016,0x25a6802c}},	//   _aịkọ, jovn, rxar_, enol_,
   {{0x61e942d8,0xd8b801aa,0x656d4639,0xa91d8166}},	//   _čels, _مدیا_, pjah, _dlžn,
   {{0x27e91962,0x3f85807a,0xac19411b,0xdcebc0f1}},	//   _kuan_, _sllu_, _йому_, _imgħ,
   {{0x6f088033,0xb345810b,0xbcfb4032,0x3e478107}},	//   _bedc, jeçã, _gnéa, _sőt_,
   {{0x248dd2b8,0x3a3e8033,0x3dcd80f8,0xf745a321}},	//   vzem_, _bptp_, _whew_, секо,
   {{0x69c2a322,0x7f438580,0xceb48080,0xff1800c3}},	//   bloe, renq, şən_, בקות_,
   {{0x61e8a323,0x6b9c1b78,0x6e238232,0xa01b00fa}},	//   _dudl, zirg, runb, nzös,
   {{0x799d0073,0x63b88089,0x7422002a,0x753b84da}},	//   disw, bovn, _ফন্ট_, _ibuz,
   {{0x443fa324,0x9b7481b4,0x7d098057,0x7989e325}},	//   _ipu_, _والص, _hees, shew,
   {{0x644d2326,0x2ca9c0b3,0xdce9c451,0x28d00384}},	//   _asai, _žadd_, lječ, _सृजि,
   {{0x4424e327,0x2d9d8d08,0x7bc392ec,0xe8e000d1}},	//   bum_, niwe_, llnu, _suối_,
   {{0x27e9073f,0x443f807a,0x3bd5ca6b,0x6e3e005c}},	//   _cuan_, _jpu_, _люкс, _sppb,
   {{0xa8030018,0x2d9d80f7,0x6449c02c,0x7f85c01c}},	//   íñas, hiwe_, mwei, _دلتن,
   {{0x753b811c,0x7df3c119,0x27edc0fd,0xed5a2328}},	//   _obuz, _băse, lqen_, _бой_,
   {{0x44326329,0x29d781b7,0xb6a30dae,0xfaa3232a}},	//   tty_, _għax_, числ, часо,
   {{0x27e9021b,0x61e0a32b,0xe8f7023d,0x3b86632c}},	// [1e20] _guan_, _riml, _улы_, благ,
   {{0x7c24632d,0x66184066,0x60c08041,0xdfcf4032}},	//   ruir, ávko, _rymm, فيق_,
   {{0x6e3e00e8,0xdb01c018,0x539ac2a6,0x645b805e}},	//   _uppb, loló, ניעו, _arui,
   {{0x7df3c119,0x2d9d800d,0xe3bf003c,0x6455c017}},	//   _găse, giwe_, muña_, āzij,
   {{0xa3e7e32e,0xb87b232f,0x69c44a12,0xc013811b}},	//   _मूल_, ncíp, mlie, зміщ,
   {{0x2605408f,0x29004007,0x53e580d9,0x6f0e06df}},	//   हीही_, lbia_, іціа, nabc,
   {{0x645b81d4,0x8e8641b4,0x3f9c831c,0x61e0a330}},	//   _erui, _الأه, rivu_, _timl,
   {{0xa91b410d,0x2d9d81c6,0x645b8e6e,0x6449c0cb}},	//   _alþj, ciwe_, _frui, fwei,
   {{0x63ad801e,0x3f9c8011,0x77caa319,0xb4aa8fe8}},	//   éanc, pivu_, _благ_, _сказ_,
   {{0x3946819d,0xa3e7c08f,0x4426a331,0x5eab4079}},	//   leos_, _मूळ_, muo_, _করতে,
   {{0x6d4600bb,0x2012405c,0x4426a332,0x6ac68e5f}},	//   feka, hsyi_, luo_, _اقام,
   {{0x6562c04c,0x7d0d4057,0x398ac031,0x8afcc036}},	//   _unoh, xaas, _bùse_, ejęt,
   {{0x657dc4c9,0x32110062,0x637d8580,0xcc33c701}},	//   öshe, wszy_, _sèni, _فروع,
   {{0x27e9013b,0x6564075d,0x2d996333,0x60c2e334}},	//   _vuan_, _enih, _smse_, _iyom,
   {{0x877b82a6,0x6379002e,0x4426812c,0x1b7b8052}},	//   נאלי, _bìnr, huo_, נטלע,
   {{0x60f94c4e,0x35a40267,0xb8cf0079,0xe9a41025}},	//   рная_, _најг, _কর_, _најп,
   {{0x7d0d5fa5,0x79828036,0x2d584051,0xdb9948d3}},	// [1e30] raas, dkow, щить_, авач_,
   {{0x3f875f98,0x60cd0d08,0xb4e9009d,0x61eae335}},	//   ónu_, _izam, _बलु_, _kufl,
   {{0xdb174018,0xe3bf034d,0x64408017,0xf3eb002a}},	//   noxé, cuña_, _apmi, _কবির_,
   {{0x63bae336,0x61eae337,0xa1596338,0x20124853}},	//   hotn, _mufl, _таму_, bsyi_,
   {{0x3f9ee339,0xdc699934,0x25a94eaa,0xd4698186}},	//   kitu_, ралд_, mnal_, риле_,
   {{0x27eb633a,0xcec3c047,0x3f9ee33b,0xa09c0009}},	//   _iucn_, _jiří_, jitu_, ניגט,
   {{0x63bac033,0x7d099664,0x6d46233c,0x994d8166}},	//   dotn, _tees, yeka, môžu_,
   {{0x201fe33d,0x09e2c99b,0x290b4570,0x60c2c18b}},	//   trui_, мощн, _jeca_, _byom,
   {{0x61eac0fa,0x25bf80e2,0xa49b4321,0x60cd04da}},	//   _aufl, _ikul_, _beòi, _nzam,
   {{0xbca4854c,0x27f94033,0xeb99c0c1,0x7df3c119}},	//   _عملي, _mtsn_, рио_, _născ,
   {{0x4420633e,0x753d4064,0x61e2e33f,0x76ab85e9}},	//   zri_, _obsz, _fiol, _став_,
   {{0x68e24007,0x2b40841b,0x61e2c26b,0xb4db4083}},	//   žodi, đice_, _giol, _gbàg,
   {{0x6d9600e0,0x798d6340,0x69c46341,0xe6c646ff}},	//   kšav, dhaw, vlie, _वर्ज,
   {{0xc31f4079,0x50da821d,0xf1bf6342,0xdb01e343}},	//   ন্তি_, יקרא, _aká_, roló,
   {{0x644f6344,0x25bf83a6,0xdee32345,0xe296c157}},	//   _asci, _okul_, дори, _маш_,
   {{0xdb01c016,0x65c30a23,0x798d6346,0x008640bd}},	//   colò, _обща, ghaw, олбо,
   {{0xada3443e,0x37760119,0xa01b0107,0x92c5802a}},	// [1e40] фатл, _дынс, ször, _এলো_,
   {{0x3f9a0033,0x61e42347,0x7d0bc107,0x7989a348}},	//   _umpu_, _hiil, _legs, _alew,
   {{0x2b47a349,0x7c4300ab,0x798d634a,0xa3cd809d}},	//   denc_, čvrš, bhaw, रतन_,
   {{0x290fa34b,0xaca3c0eb,0xe45aa34c,0x973cc38f}},	//   gaga_, _atọm, иже_, miće,
   {{0x61e2c206,0x9b6a82f1,0x9c1380eb,0x20d658d5}},	//   _riol, ишка_, lọji, _фінс,
   {{0xceb4803a,0x39528007,0x61e2e34d,0x799b840d}},	//   şəm_, žys_, _siol, _emuw,
   {{0x66d041c0,0x637fc01f,0x09bd402a,0xdd92a34e}},	//   _dókí, _gêni, _আওতা, _قوس_,
   {{0xdb039243,0x63bac036,0x2d8dc0eb,0x799b817b}},	//   fonó, wotn, ghee_, _gmuw,
   {{0xdb1c4396,0xdb188066,0x63bac036,0x236ac244}},	//   _akré, hové, totn, ајно_,
   {{0xaac00705,0x973cc5c7,0xdb188347,0x63bc234f}},	//   _शुभक, kiće, kové, jorn,
   {{0x25a041c8,0xa3abc045,0x60cd1243,0xdb188066}},	//   kiil_, _गदर_, _szam, jové,
   {{0x3ce08089,0xa2bb0cbb,0x3dd202cd,0x61e40149}},	//   živu_, _शुष्, _chyw_, _ciil,
   {{0x2480404d,0x490b8549,0x7dd5c007,0x25a95208}},	//   jyim_, ारतो_, _išsp, vnal_,
   {{0x7d028451,0x33f08580,0x5fca8047,0x6442e350}},	//   hbos, _màx_, ितिल, _ipoi,
   {{0x3f830086,0xae17c185,0x3f9cc073,0x61e42351}},	//   rkju_, _थिएन_, _imvu_, _fiil,
   {{0x61e40006,0x645d47a7,0x35f7c7ce,0x27e34127}},	//   _giil, _prsi, _برود_, _sijn_,
   {{0x290f9461,0xfbca8047,0x403453d0,0x637fc1ff}},	// [1e50] vaga_, िताम, метс, _sêni,
   {{0x2484036b,0x25bf802f,0x637fc10b,0xdb188066}},	//   ømme_, _skul_, _pêni, bové,
   {{0x6da40aa2,0x7d0d0cff,0xed59c7ca,0xdea1405f}},	//   rđav, _keas, lože_, ریری,
   {{0x7bc7141b,0x51848c38,0x6d87c140,0xa9274182}},	//   llju, муча, _añan, _بعده,
   {{0x394948a6,0x7d0d2352,0x2b47a353,0x645d5f9b}},	//   meas_, _meas, tenc_, _ursi,
   {{0x752d6354,0x7df3c119,0x50da40c3,0xceb8c007}},	//   lgaz, _lăsa, _לקרא, ngęs_,
   {{0x2b47a355,0xf1a7859d,0x6e28c011,0x3da78589}},	//   renc_, _дран, judb, _драб,
   {{0xed59c013,0x442211c1,0x23d2084d,0x799b85bb}},	//   kože_, yrk_, _दीनद, _umuw,
   {{0xdb1885e5,0x5e59816a,0x5b3380b4,0x7d0be356}},	//   zové, _گلاس_, _омаӂ, _vegs,
   {{0x7bc70eca,0x386dc004,0x69d9a357,0x637d9d18}},	//   jlju, rxer_, lmwe, _cènt,
   {{0x644d6358,0x387fd17e,0xbcfb4181,0xb4b4017e}},	//   hwai, syur_, _aném, _जुड़_,
   {{0x66150036,0x28dfccbb,0xdb188066,0x27ed8396}},	//   dszk, _पृथि, vové, _kuen_,
   {{0xa2bf8027,0x61e42359,0x8069c183,0x213f8231}},	//   _लुत्, _viil, _دمشق_, _mbuh_,
   {{0xdce440ab,0x7052c032,0x6e28c0f8,0x644d41f4}},	//   ljić, _أنوا, budb, dwai,
   {{0x27ffc8ae,0x91fc8017,0xa96a45a4,0x7d028026}},	//   lpun_, _grād, бива_, ybos,
   {{0x63a1e35a,0x2bcfc578,0x250841aa,0x6579c1c8}},	//   liln, _सीता, ترسی_, _jowh,
   {{0x973cc0e0,0x3076635b,0xdb1c00fd,0x7643c07a}},	// [1e60] siće, чувс, norë, _hpny,
   {{0x7778c022,0x3dc6a35c,0x7af70157,0x7c228a26}},	//   _xovx, wlow_, _gfxt, vror,
   {{0x6ac641b4,0x2480635d,0xb77b0093,0x877b0093}},	//   أقام, syim_, _האיש, _האיי,
   {{0x7e6109ca,0x7c29c51f,0x7dc5c018,0x3cf7c036}},	//   ælpe, kuer, bósi, ीरों_,
   {{0x7dc5c004,0xe4e38289,0xf9930052,0x9f410303}},	//   cósi, нішн, ערד_, _sihé_,
   {{0x69d9a35e,0x69dcc107,0xcc3b0009,0x68ff803a}},	//   amwe, _érez, מענט, ıqda,
   {{0xaa434638,0xed5a8979,0xb4db41c0,0x67eb0283}},	//   _перл, _лов_, _gbàb, _iżje,
   {{0xe944808c,0x69c08007,0x68e98085,0x27ed8060}},	//   _ترسی, _ukme, _gged, _fuen_,
   {{0x2c1cc048,0x7dda80a0,0x7df3c379,0x2608a157}},	//   _मिळू_, _důst, _răsa, _सबकी_,
   {{0x35f4ca9b,0x53be4707,0x57fb8093,0x7d0d09a7}},	//   мпор, ्तिश, _ללמו, _seas,
   {{0x3940005e,0xfbcfc032,0x5694cc85,0xdb1ac8e8}},	//   _bbis_, دتي_, фант, noté,
   {{0xa3d345da,0x9f4486ed,0x61ee635f,0x2bca8036}},	//   _हीन_, _humà_, _mubl, ितवा,
   {{0x61ee5a03,0x442940fc,0x7d046360,0xfbbe4c13}},	//   _lubl, xua_, dbis, ्ताम,
   {{0xdb15039e,0xed59c013,0x629c8086,0x466ac662}},	//   pozí, rože_, _þros, _грим_,
   {{0x6d562361,0x61ee6362,0x8b3bc0c3,0x38fa4044}},	//   _faya, _nubl, _התוצ, _ọkụk,
   {{0x67eb00f6,0xb60686f0,0x0ef548c5,0x7bc8c69a}},	//   _ażje, mošć, इड्स_, lldu,
   {{0x7bc70a11,0x92bf0079,0xb6069b1a,0xceeb4973}},	// [1e70] plju, েশে_, lošć, مران_,
   {{0x61ee4066,0x04fe802a,0xe973005f,0x7dca8086}},	//   _bubl, ুলোর_, _آنکھ, sýsl,
   {{0x7f554019,0x6d408033,0x442b2363,0x61ee4231}},	//   _vazq, _bbma, luc_, _cubl,
   {{0x6d97c119,0xa49b4321,0x61f84089,0xdb1c4359}},	//   nţat, _beòt, ívla, _bhró,
   {{0x7c24401e,0x6579c0e2,0x777aa364,0x69d98372}},	//   crir, _rowh, _botx, rmwe,
   {{0x61e640fc,0x25a2013f,0x7d1d4f26,0xb60689fa}},	//   _zikl, zikl_, _hdss, košć,
   {{0x4424c085,0x7d0f4107,0x777a80b9,0x644241cb}},	//   erm_, _kecs, _dotx, çoiv,
   {{0x9f4343bc,0x7d1ba365,0xe818e366,0x26d14157}},	//   _sijè_, _udus, _दिखा_, _izzo_,
   {{0x6d562367,0x26d15f35,0x443900f1,0xa3e60b35}},	//   _raya, _hzzo_, jts_, _बूझ_,
   {{0x44390655,0x645bcb43,0x6281c7ab,0xdb1c013b}},	//   dts_, rvui, tylo, rorë,
   {{0x3ce64166,0x3dc945bb,0x394a2277,0x32014022}},	//   ľovi_, klaw_, озно_, nphy_,
   {{0x6d59a368,0x798d15b2,0xa96a01bd,0xe8f71626}},	//   ndwa, _claw, цима_, млю_,
   {{0x44392369,0x291242d6,0x6283a36a,0xdb1c001e}},	//   gts_, vaya_, lyno, loré,
   {{0x61e6636b,0x6d56236c,0x63a383ff,0x2912636d}},	//   _sikl, _waya, ninn, waya_,
   {{0x7643c033,0x63a38033,0x4439236e,0x2d8d8094}},	//   _upny, iinn, ats_, _olee_,
   {{0x27e7d667,0x290fe36f,0x7c246370,0xed59c077}},	//   _hinn_, _jega_, trir, ndž_,
   {{0x98a346dc,0x61e66371,0x7c2b8570,0x973cd813}},	// [1e80] вите, _vikl, jugr, lića,
   {{0x290fe372,0xef1a4589,0x6d598126,0x7f80403a}},	//   _lega_, іме_, edwa, _nöqt,
   {{0x61e66373,0x6f1cc01f,0x973cc077,0x6d4b8f02}},	//   _tikl, órci, nića, fega,
   {{0xed59c077,0xda654032,0x291dc17b,0x29125746}},	//   jdž_, عالي, _ndwa_, qaya_,
   {{0x69c9c1c8,0xdb1c4061,0xe2f8884e,0x25bfd38f}},	//   dlee, _dhrò, пелі_, doul_,
   {{0xaa58881e,0x6d408033,0x63a3a374,0xaca48112}},	//   зику_, _wbma, ginn, _nsụp,
   {{0x6da68547,0xcf57421d,0x62839207,0x28dbc5da}},	//   _жива, _קבלת_, gyno, मेसि,
   {{0xdb18810b,0xd378841b,0x27e7c8a6,0x78af4158}},	//   moví, _mići_, _ainn_, šivš,
   {{0x6da3a345,0xb906c033,0xe4c381f0,0xcf26c3a9}},	//   _рита, _यः_, _айти, وردي,
   {{0xf698c748,0x80db4079,0x4426a375,0x69c9cb28}},	//   звој_, যুক্, mro_, alee,
   {{0x2b586376,0x25bfe377,0x394b2378,0x657b8396}},	//   _marc_, boul_, tecs_, _youh,
   {{0x69d60141,0x442b05f3,0x5a174052,0x0086c0b4}},	//   _chye, tuc_, וקטן_, _олео,
   {{0xe8028048,0xd7f8092f,0x2d926379,0x02ee48b8}},	//   रीचा_, дус_, dhye_, जशाह_,
   {{0xb60686f0,0xe8d940eb,0xdfa6c7ce,0x6d4b8062}},	//   pošć, nkụ_, _تحصي, zega,
   {{0x7c26014b,0x7c2b80cb,0x386d00cc,0x7dea8062}},	//   arkr, zugr, ţer_, _gęst,
   {{0xea00000c,0x69c0e37a,0x26d1406f,0xd5b90017}},	//   _giật_, nome, _rzzo_, irāk_,
   {{0x4fd5637b,0x4426a37c,0xed59c011,0x7d0f637d}},	// [1e90] ежат, jro_, noža_, _vecs,
   {{0x65698166,0xdceb8066,0x6e954bb4,0x69c9c1a8}},	//   _sneh, čičk, низу, zlee,
   {{0x3d0b859c,0x98af4138,0x657b8047,0x1be8054a}},	//   ारले_, ıgı_, _pouh, _टूटल_,
   {{0xa49b4321,0x7c2ba37e,0x31b90c1e,0xe5074ba8}},	//   _deòr, tugr, tézy_, _تبدي,
   {{0x6d598f01,0xd00986c5,0x69dd026b,0x3f698fc8}},	//   rdwa, челе_, imse, зило_,
   {{0x777c5169,0x7c2b83b3,0xb4c1809d,0x7e5582e0}},	//   _gorx, rugr, _ुरी_, етиц,
   {{0x19958efa,0x2489a37f,0x27e7c4ff,0xdb0e2380}},	//   _завя, šam_, _rinn_, tobú,
   {{0x7dc5c10d,0x9f458089,0xc86780c5,0xdb01d12d}},	//   jóst, _milé_, _отзи, milé,
   {{0x98a04158,0xdb01d305,0x25bfc0b4,0x6fc48016}},	//   rgić_, lilé, roul_, tòct,
   {{0x96b9d8d5,0x25ade381,0x25bfc13b,0x82f8801c}},	//   зуму_, snel_, soul_, _قرمز_,
   {{0x2d894033,0x69c9c0bf,0x69c0c206,0x398e4086}},	//   kkae_, plee, bome, _lýsa_,
   {{0x3f8ec150,0x27e7e382,0xed5a1902,0x3991c031}},	//   _elfu_, _winn_, чом_, _báse_,
   {{0x7c2d4c69,0x8c45c5e0,0x443940fd,0x80c80079}},	//   juar, _челе, _nqs_, রেন্,
   {{0xdce4006c,0x60c9871c,0x987ac009,0x6d59d9c2}},	//   _unič, _myem, _מאנט, _hawa,
   {{0x69d600fd,0x20192383,0xcb66c051,0xdb01c694}},	//   _thye, assi_, _чаще_, vilè,
   {{0x69c42384,0x7bc500f7,0x9f4581c0,0xdce401d6}},	//   _ukie, _ekhu, _dilé_, _eliġ,
   {{0x809f96c0,0x657d6385,0x442de386,0x656bc056}},	// [1ea0] _खेले, _dosh, nue_, _mngh,
   {{0x63a54056,0x777c403a,0x3860c639,0x6fb641b4}},	//   gihn, _qorx, _širk_, رمضا,
   {{0x657d40fd,0x6ebf8314,0x6285497e,0xa3bd01f9}},	//   _fosh, _लुलु, gyho, इकर_,
   {{0xaca3c044,0x442de387,0xc05a8026,0x5efd8027}},	//   _chịk, kue_, зік_, रुस्_,
   {{0x6376c156,0x63a545ba,0x7bc1e388,0x29120987}},	//   _vânz, bihn, kolu, _meya_,
   {{0x29069d5c,0xa49b5cbf,0x2d8fe389,0x501b00c3}},	//   sboa_, _teòr, _alge_, לונו,
   {{0xd04e803a,0xbbbe4926,0xb7bdc0b4,0x442dc1cb}},	//   _ədəb, ्तीक, cuţi, eue_,
   {{0x7c3be38a,0x09e395a4,0x442de38b,0x291200bb}},	//   ftur, _босн, fue_, _neya_,
   {{0x57a6ce0d,0x98af8026,0x7dd605ca,0x6e2e031d}},	//   ешна, degė_, kásb, hubb,
   {{0x656bc1f4,0x7d164057,0x5a96a38c,0x96968186}},	//   _engh, hays, _преф, _преш,
   {{0xbcfb005f,0xdd950039,0x61e9a38d,0xd5afd4e9}},	//   ndég, ваны, _čelz, _бс_,
   {{0x399ac017,0x6fcb40cb,0x222b801c,0xec7ac119}},	//   gūst_, tück, _رزمی_, _нпе_,
   {{0x62854033,0x5fd2054a,0x7c2d638e,0x7dc5c019}},	//   zyho, _दीहल, xuar, róst,
   {{0xc0a9cde9,0x6d4400bb,0x291201c0,0x39595a30}},	//   _تامل_, _ebia, _eeya_, _sass_,
   {{0x8624009b,0x656bc0de,0x6f15238f,0x6e2e2110}},	//   льте, _yngh, razc, gubb,
   {{0x6d59c1c8,0xb4db405e,0x7c2d6390,0x657d6391}},	//   _xawa, _dbàn, tuar, _qosh,
   {{0xe894422b,0x161d0428,0x9327401c,0x9f47c0ce}},	// [1eb0] гать, _फिकर_, فران, _binè_,
   {{0xb7bdc156,0x39594033,0x7bc500f7,0xd6db4156}},	//   tuţi, _wass_, _ukhu, пте_,
   {{0x60c9a16b,0x7c3bc767,0x06df0079,0xa2950e99}},	//   _syem, ztur, _ব্রি, _рані,
   {{0x2d8b0185,0xdb03a392,0x236c8077,0xa91d806c}},	//   nkce_, miné, _andj_, _možg,
   {{0xdce9c514,0xd1164093,0xe10c0009,0x29094150}},	//   mjeć, _בקרה_, פּאָ, mbaa_,
   {{0x60c98150,0xbea59058,0xa49b4031,0xa3cfc036}},	//   _vyem, калк, _afòg, _वीं_,
   {{0xead44051,0x442dc112,0xe8df81c0,0x661ae393}},	//   _борь, wue_, _ibọn_, jstk,
   {{0x60c980f8,0x7e7e84c9,0x1c45c0d9,0xdce9c123}},	//   _tyem, äppa, вним, njeć,
   {{0x7989e394,0x200d805c,0x661c4123,0xe7b8425c}},	//   rkew, _uwei_, _zvrk, _आदमप,
   {{0x6d44023f,0x3d27c031,0x61fb4123,0xdb03801f}},	//   _sbia, _bìwà_, _čulj, gonô,
   {{0x7c3be395,0x20000119,0x442dc093,0x394de396}},	//   stur, _stii_, sue_, pees_,
   {{0x7d164057,0x7c3be397,0x7c3d2398,0x6d4bc089}},	//   xays, ptur, ftsr, ínač,
   {{0xdb18a399,0x55768009,0x442fa39a,0xdce9c4d6}},	//   lová, דערן_, nug_, djeć,
   {{0x3d27c031,0xc35505f5,0x317f80b6,0x656d00c7}},	//   _fìwà_, лъсъ, _louz_, _enah,
   {{0x7d164149,0xdb01c4c9,0x9f47c396,0x316d8545}},	//   tays, rnlä, _niné_, _onez_,
   {{0xdd9243be,0xf86607e3,0x7c29cc7c,0x3205c0c3}},	//   جور_, _авио, orer, mply_,
   {{0x2bf6639b,0xd70601bc,0x3940639c,0x442f888b}},	// [1ec0] тябр, _изпи, rfis_, jug_,
   {{0x442fa39d,0x63a7015d,0xdfcf4182,0x7bc3a39e}},	//   dug_, cijn, قيق_, jonu,
   {{0x9f47c01e,0xa3c2d890,0x317f8053,0x9f4dc34d}},	//   _ciné_, ंवत_, _bouz_, lpeó_,
   {{0x7c29d5db,0x7f5a8080,0x6d938138,0xb7d501c0}},	//   krer, _satq, _açab, _iṣan,
   {{0x2578c1af,0xb4db0060,0x69c4639f,0x442f8303}},	//   _gély_, leàr, moie, gug_,
   {{0xce6a87c2,0x661c4043,0x61ebcc76,0xe8df81c0}},	//   дрид_, _tvrk, _aigl, _gbọn_,
   {{0x82338032,0x6d4f23a0,0x98b2806a,0xfaa654e9}},	//   لريا, yeca, ıyı_, _раво,
   {{0x3869c1be,0x6d4f0016,0x63a7015d,0x41d84db4}},	//   _šara_, xeca, zijn, _भीमस,
   {{0xd3788043,0x69d9e3a1,0xe5770007,0x2e3c4086}},	//   _siću_, _dhwe, _nėšč, líf_,
   {{0x69d9d8c2,0xdb0a9f5f,0x7f5c40d2,0xd346801c}},	//   _ehwe, rofó, _jarq, _شیعه_,
   {{0xf8bf42cb,0xa2e6923a,0xdb188d04,0x2d9223a2}},	//   _idée_, _рожд, cová, _blye_,
   {{0x64480119,0x7c3d02e9,0x78a4c199,0xa183c051}},	//   ădin, ttsr, _živu, _вышл,
   {{0x81d84079,0x6d5d098f,0x63a70832,0x26c2c036}},	//   াদা_, rdsa, tijn, łko_,
   {{0xc4d3017e,0x60188359,0x798080bb,0x9f5200ce}},	//   _सरीख, _zúmá, _lomw, _juyè_,
   {{0x28e04045,0x2d80103c,0x63ada3a3,0xdb0640a0}},	//   पेसि, _foie_, éani, ámýc,
   {{0xa806406a,0x7bce23a4,0x2b5cc011,0x442f8c05}},	//   ktığ, albu, _havc_, yug_,
   {{0x7f5c45d1,0xdb0381b4,0xb87b4031,0x17ed409d}},	// [1ed0] _barq, siné, _agír, जदेव_,
   {{0x175500c5,0x63a8c0b3,0x6fcd8070,0x7dc5c019}},	//   _своя, nidn, cúch, hósp,
   {{0xa91d8158,0x80c9c185,0x9474801c,0x7dd623a5}},	//   _lože, _हुने, یدها, lása,
   {{0x7522c044,0xafdb00b0,0xaa644039,0x326451e5}},	//   _ndoz, stød, штук, штув,
   {{0xef18c03f,0x44294283,0x656f63a6,0xf4d18079}},	//   kaļ_, qra_, _inch, িশ্ব,
   {{0x442b0510,0x28c6c54a,0x764ac065,0x6d5b8150}},	//   irc_, _लड़ि, _opfy, _waua,
   {{0x290b0033,0x24894107,0x7980809c,0x27ec8093}},	//   kbca_, lyam_, _fomw, _didn_,
   {{0xf8d30314,0x1db788c5,0x60cd040d,0xdb1c002d}},	//   _सरूप, _अदित, _oyam, vorí,
   {{0x291923a7,0x69db8044,0x69c980f8,0x6d95c107}},	//   dasa_, _ihue, _ikee, _ráad,
   {{0x7522e3a8,0xe0d6c10e,0x69c457f2,0x2d80001e}},	//   _edoz, ывы_, zoie, _soie_,
   {{0x7d09c1b0,0x69c980bb,0x8e99825b,0x60d623a9}},	//   pbes, _kkee, _ثناء_, _szym,
   {{0xc105c032,0x2489417b,0x7c29e3aa,0x7dd60359}},	//   _صوتي, kyam_, prer, fása,
   {{0xdce98458,0x7afc02bc,0x7bc554ed,0x2489423b}},	//   _oneč, tcrt, kohu, jyam_,
   {{0x6d5d4703,0x291900f8,0x2d8dd7b4,0x63a50061}},	//   _aasa, aasa_, lkee_, _cmhn,
   {{0x69c9a3ab,0x2258c065,0x6288c036,0x60cd163e}},	//   _okee, ærkt_, cydo, _eyam,
   {{0xf1bb22cf,0x6f1887ca,0x5de64e32,0x443fe3ac}},	//   _उदयन, zavc, ужба, otu_,
   {{0xbcfb40d2,0x60cd01ae,0x20040359,0x645a0017}},	// [1ee0] _anés, _gyam, ímid_, ātis,
   {{0x69df00c4,0xe29a543c,0x6fcda3ad,0x4e17c0b2}},	//   _èper, наз_, búci, _दबाई_,
   {{0x6da655f5,0x69db8032,0xb2264007,0xba264119}},	//   _бина, _bhue, умел, удек,
   {{0x2489423b,0x399563ae,0x515641cc,0x49ba4107}},	//   byam_, _påse_, _стоу, _ساجد_,
   {{0x8eb3001c,0x6723c043,0x69db8303,0xd91b40c3}},	//   _نمیش, _odnj, _dhue, _אוכל,
   {{0x59d85c79,0x7d1623af,0xea00000c,0x316063b0}},	//   _भीतर, _leys, _ngẫu_, ldiz_,
   {{0x4432517e,0x56948a74,0x443fe3b1,0x69c623b2}},	//   luy_, райт, etu_, koke,
   {{0x7d0d810d,0x3ced0199,0x7df3c119,0x752423b3}},	//   ðast, ževi_, _găsi, _ndiz,
   {{0x2fc5c0fa,0x7bdc55f2,0xf8b44036,0x69c623b4}},	//   folg_, _khru, ंपिय, doke,
   {{0xc43b40c3,0x3dc681c8,0xdb054070,0x7bdd8157}},	//   עתיי, loow_, tihé, _èsup,
   {{0xf363c10e,0x63a8e3b5,0x973cc242,0x3f8123b6}},	//   стын, ridn, lićk, _rohu_,
   {{0x7dd6005f,0x3946c274,0xdb01c01f,0x3f810c4b}},	//   tása, _ubos_, gilâ, _sohu_,
   {{0x1439c1aa,0x7bc54150,0x443fe3b7,0x973cc123}},	//   _لينک_, yohu, ctu_, nićk,
   {{0x395dc23b,0x7d198036,0xd90ecde9,0x443263b8}},	//   _zaws_, zaws, _بیک_, duy_,
   {{0x395dc022,0xe919411b,0x7982c1c8,0x25a963b9}},	//   _yaws_, кові_, _koow, tial_,
   {{0x395dc23b,0x69c623ba,0xa15863bb,0x398ac031}},	//   _xaws_, coke, ласу_, _bùsi_,
   {{0xdb08c10b,0x2d824360,0x6560c032,0x39490070}},	// [1ef0] vidê, _doke_, idmh, _ibas_,
   {{0x69c9a3bc,0x9d154079,0x4ad8c027,0x38690020}},	//   _skee, িলেন_, _डराव, _irar_,
   {{0x248963bd,0x2d82407a,0x2cae403a,0x7bdc4e89}},	//   syam_, _foke_, _əldə_, _dhru,
   {{0x6440c621,0x25fb8036,0xceb3c052,0x2d8241c0}},	//   ktmi, _लंबी_, זיע_, _goke_,
   {{0xb8fd8b26,0x394900fd,0x6b81805f,0x7d199997}},	//   _डर_, _mbas_, _polg, raws,
   {{0x61e28800,0x7bdc424f,0x7d19802f,0xda659546}},	//   amol, _ghru, saws, لاعي,
   {{0x6f1accfe,0xa80643a6,0x628aa3be,0xdb1c23bf}},	//   datc, rtış, gyfo, norá,
   {{0x0c25c379,0x7bdc4347,0x386923c0,0x6d5f1ec0}},	//   амин, _zhru, _orar_, _naqa,
   {{0xd34781aa,0x7bc7003f,0x644d10ed,0xa91d806c}},	//   _میشه_, koju, _npai, _tožb,
   {{0xb4db4031,0x7d0d4303,0x257c4047,0x657bcc99}},	//   _abàk, hbas, _díly_, sjuh,
   {{0x6595e3c1,0x395dc24c,0xd575c768,0xe10a05a4}},	//   _кажу, _taws_, _вуль, кенд_,
   {{0x6fd04041,0x2611dc74,0xfce62162,0x6d5f01c8}},	//   täck, ršo_, ионо, _caqa,
   {{0x395fa3c2,0x6459c12c,0x20ba0523,0x7d1be3c3}},	//   _maus_, _uswi, тынь_, maus,
   {{0x2d8263c4,0x765a80de,0x7d0d63c5,0x38690383}},	//   _soke_, _ysty, ebas, _drar_,
   {{0xa3c2d33c,0x6b83e3c6,0x7c2d40fc,0x61e2a1da}},	//   ंवर_, _iong, erar, ymol,
   {{0x7bdc63c7,0x395fa3c8,0x7d1be3c9,0x38690283}},	//   _shru, _naus_, naus, _frar_,
   {{0x443f8022,0xfbc623ca,0x208740d9,0xcef64169}},	// [1f00] _nqu_, लकदम, айти_, ачењ,
   {{0x2d8259da,0xdb08e3cb,0x316023cc,0xdb038e85}},	//   _woke_, vidë, _haiz_, finí,
   {{0x7d1be3cd,0xf3c9471d,0x7d0d63ce,0x7c2d47d5}},	//   kaus, ابقه_, bbas, arar,
   {{0xdb1c44d3,0x6146a3cf,0x395fa3d0,0x6b83cdc5}},	//   _skrä, реда, _caus_, _long,
   {{0x205680c4,0x316023d1,0xed5740c5,0xdb0381ff}},	//   ртер, _maiz_, _тоя_, dinâ,
   {{0x6b83e3d2,0xdb08c6ed,0x0eba0027,0x8e2685af}},	//   _nong, cidè, _उखाड, афид,
   {{0x34d304fb,0x91e6801d,0x70d30185,0x257c40a0}},	//   _सर्द, _вове, _सर्ल, _síly_,
   {{0x31600232,0xdb08e3d3,0x442263d4,0x300680d9}},	//   _naiz_, midé, _kvk_, _взаг,
   {{0x9f4c8185,0x4fea88d3,0x9b44c6b0,0x7dd88004}},	//   _lidé_, _аман_, منظو, císa,
   {{0x23c649cb,0xfc4ac02e,0x07a39229,0x3946849a}},	//   वविद, _abíó_, _даун, lfos_,
   {{0x244083bc,0x395f804d,0x973cc158,0xadf20027}},	//   lòm_, _yaus_, nići, _आंगन_,
   {{0xa91d8158,0x0446c445,0x442263d5,0x395f804d}},	//   _koža, _ведн, _ovk_, _xaus_,
   {{0x23c64045,0x2fc700d1,0x9f4c801e,0x61ef4157}},	//   ववाद, _ưng_, _aidé_, _ricl,
   {{0x65608e94,0x29024057,0xdb1c0443,0x44205b62}},	//   _lamh, _afka_, torá, dsi_,
   {{0x69c0411f,0x442063d6,0x7bc70f56,0x973cc0b3}},	//   čmen, esi_, roju, jići,
   {{0x3f8363d7,0x637d8565,0x6560a3d8,0x8cddc549}},	//   _soju_, _dèny, _namh, _परमो,
   {{0x7c2d63d9,0xdce64039,0x395fa3da,0x6f170070}},	// [1f10] urar, _mokė, _raus_, _texc,
   {{0x973cc7ca,0x3866860f,0x7d1d23db,0x753b8119}},	//   fići, dvor_, lass, _scuz,
   {{0x7d0d4127,0x7d1bc6df,0x6560875d,0xcb5600c3}},	//   pbas, yaus, _bamh, _הסתה_,
   {{0xf65000fb,0x4422421b,0x395f8022,0x3ced0158}},	//   _کئی_, _fvk_, _qaus_, ževu_,
   {{0xe8200027,0x4dda40c3,0x9f400016,0xdb1c4240}},	//   _बिछा_, _תחרו, _guió_, _skrå,
   {{0x973cc41b,0x395f809c,0xd874801c,0xb3c88e99}},	//   bići, _waus_, تامب, аліз_,
   {{0x395f804d,0x5e9541b4,0x1ec9804c,0x291963dc}},	//   _taus_, _الأط, ылки_, _kesa_,
   {{0x6d070185,0xa2c1c048,0xa2cac0ba,0x7d1d23dd}},	//   _व्लग_, _रुग्, _सुध्, jass,
   {{0x7d1be3de,0x291da3df,0x6f1c0360,0x316001f1}},	//   raus, mawa_, yarc, _raiz_,
   {{0x6b9ac3e2,0x6141879f,0x61f8c4f9,0x224ec05c}},	//   ghtg, báló, _buvl, _bpfk_,
   {{0xe6b384e8,0x6b83e3e0,0xd3e6808c,0x645d4070}},	//   _بلاگ, _vong, _اقلی, _lssi,
   {{0x68ed805b,0x645d63e1,0x568c8009,0x6b83db8e}},	//   žadu, _ossi, _שטאַ, _wong,
   {{0x7643807a,0x7e6aca26,0x6b83e3e2,0x31568052}},	//   ltny, _erfp, _tong, זירן_,
   {{0xafe601fa,0xdb1e4c1e,0x60db82c0,0x25a923e3}},	//   согл, kopá, _mzum, _emal_,
   {{0xdb1ac032,0x644f4017,0x412a57dd,0x38668089}},	//   altó, _apci, лово_, zvor_,
   {{0x2919419d,0x76438033,0x442f805c,0x499947ad}},	//   _cesa_, itny, krg_, атуя_,
   {{0xa9674f36,0x61e463e4,0xa3ba01aa,0xcaf641b4}},	// [1f20] щита_, rmil, _مادر_, مساب,
   {{0xef174768,0x973cc91c,0xbcfb23e5,0xdce40011}},	//   йму_, tići, ndén, _anić,
   {{0x291d8067,0x799bc05c,0x644f4070,0x291940e2}},	//   fawa_, khuw, _epci, _fesa_,
   {{0x7bc8e3e6,0x7d19d2b4,0x38cb808c,0xf8bf4107}},	//   zodu, _news, گامی_, _idén_,
   {{0x260c454a,0x653b0009,0xf3f180d1,0xdb018107}},	//   डीजी_, רענד, _bị_, _emlí,
   {{0xdb1e4018,0x6d4be3e7,0x6d5663e8,0x9b964032}},	//   bopá, _abga, leya, _الست,
   {{0x60db8094,0x7d1d15ca,0x442fa3e9,0x64444051}},	//   _ezum, yass, arg_, ltii,
   {{0x7c24006c,0xd90dc646,0x799bc006,0x2bd0d3a2}},	//   _ovir, نیم_, ghuw, हत्थ,
   {{0x3f8580b3,0xf8dc809d,0x55774052,0x7bc8e3ea}},	//   _folu_, _बरिय, מעקן_, todu,
   {{0x25a90655,0x628e0039,0xf3f180eb,0x63a48101}},	//   _smal_, kybo, _gị_, ëind,
   {{0xcb134942,0x217901dc,0x7643807a,0x64444051}},	//   הלת_, айны_, ctny, htii,
   {{0xc6934052,0xdb1a927d,0x69dac032,0x7986418c}},	//   פאר_, _aktø, _صباح_, _nokw,
   {{0x7c22c0b3,0xb9010281,0x6d5663eb,0xe8140048}},	//   _uvor, _थर_, deya, तीला_,
   {{0x61faa3ec,0x5694e3ed,0xa91da3ee,0x9294c47f}},	//   _kutl, _малт, _nožn, _малц,
   {{0xdb0a9ea2,0xda780a23,0x798663ef,0xd6d90062}},	//   rifè, бят_, _bokw, ęło_,
   {{0x78adc026,0x2d8046a6,0x44220df2,0x00000000}},	//   _žavi, gjie_, bsk_, --,
   {{0x7d028010,0xdced0085,0x29194915,0x6d4d01c0}},	// [1f30] dcos, _flaġ, _vesa_, _ibaa,
   {{0x9f944051,0x61faa3f0,0xf3ff001f,0xba550244}},	//   jää_, _outl, lvão_, _двој,
   {{0x9f84009d,0x644463f1,0xdb01c0b0,0xdfd840c5}},	//   töö_, atii, bilæ, сът_,
   {{0x333e8024,0x2e3bc052,0xe3b8c080,0x7bd523f2}},	//   _actx_, רגאנ, hnı_, llzu,
   {{0x64444119,0xaacfc444,0xcfc34079,0x2d9941b0}},	//   ctii, _सुनक, ্গবন, _ilse_,
   {{0x77618080,0xdb1540b6,0xeb9687c2,0x7986400b}},	//   _qalx, _ekzò, жиш_, _zokw,
   {{0x4999c88c,0xdb1c010b,0xfbd08182,0x798640f7}},	//   ития_, sorç, رته_, _yokw,
   {{0xdb1c010b,0xc005cf93,0xe9d9c01b,0x1bf90045}},	//   porç, опик, јки_, ंदाल_,
   {{0xb17b0ded,0x7643a3f3,0x6a4a8080,0x2ed623f4}},	//   rmål, stny, _vəfa, _धर्त,
   {{0x76438033,0x69c7cc4b,0xd00ec2f0,0x799be3f5}},	//   ptny, ावही, کلی_, shuw,
   {{0x7d1ba3f6,0x764541f4,0xcb1284e0,0x6d4d01ae}},	//   _keus, nthy, _חלב_, _bbaa,
   {{0x7d1b8230,0x628e23f7,0x7dd6056e,0x2d9d8024}},	//   _jeus, vybo, pásm, nhwe_,
   {{0x44220007,0x06b0402a,0x7dd60107,0x399c4031}},	//   usk_, _করছি, lásk, _jíse_,
   {{0x200dd930,0x7d1b8820,0x6d4d23f8,0x2b90829a}},	//   mpei_, _leus, _ebaa, _càch_,
   {{0x6d9cc1b4,0x394d805c,0xa91da3f9,0x2d994011}},	//   _féad, _obes_, _rožn, _blse_,
   {{0x7c240039,0x6d4d1b43,0x7c22897e,0xdcfbc0ab}},	//   _tvir, _gbaa, ysor, kjuč,
   {{0xdb038047,0x7bca932b,0xae1a0027,0x2eb68f92}},	// [1f40] ziná, yofu, _फौरन_, _अख्त,
   {{0x394d805c,0x386023fa,0x6d5663fb,0xdb03c019}},	//   _abes_, _isir_, seya, _omní,
   {{0x7d1b8061,0x7763cf51,0x798663fc,0xdb038004}},	//   _beus, _manx, _tokw, xiná,
   {{0x7d1b8321,0xa96a4271,0x64460123,0xb6bac0c3}},	//   _ceus, _тима_, otki, בצעי,
   {{0x7bca841c,0x7c838051,0x386d850e,0x2912418b}},	//   tofu, дуще, _crer_, mbya_,
   {{0xdb038443,0x2120421b,0x69d64107,0x61faa3fd}},	//   tiná, laih_, llye, _putl,
   {{0xe29786b1,0xda7a899b,0x7c2463fe,0x2900834d}},	//   жај_, рял_, lsir, ñias_,
   {{0xdb03a3ff,0x65642400,0xfbc2002a,0x2d95a401}},	//   riná, _naih, োগিত, _ерус,
   {{0x61fc6402,0x6f1c4fc0,0xdb03a403,0x7bca812c}},	//   _hurl, _kerc, dinæ, pofu,
   {{0x21290450,0x0b8aca23,0xdb038c1e,0x7763e404}},	//   _sdah_, рсии_, piná, _canx,
   {{0xb7db4009,0x61fc4011,0x9f514053,0x7dfc00b6}},	//   שקיי, _jurl, _dizè_, _dčsk,
   {{0x61fc6405,0x29d90359,0x6d49c359,0xb7d501c0}},	//   _murl, céal_, cfea, _iṣin,
   {{0xdce9c514,0x78a28066,0xe786d3f4,0x48b88079}},	//   bjeđ, nzov, _муко, _জরুর,
   {{0x7c246406,0x4424c070,0x7d044017,0x44326407}},	//   dsir, msm_, ecis, dry_,
   {{0x8c488189,0x6aa20020,0xdef40c85,0x99d70a2c}},	//   lağı, _ƙofa, дпры, _وتعا,
   {{0x628348f0,0x7520c2c0,0x6b88a408,0x6f1c4145}},	//   änom, namz, _lodg, _aerc,
   {{0x69cba409,0x94744032,0x5fca8185,0x7c24581f}},	// [1f50] voge, ودكا, ाकाल, gsir,
   {{0x78a28166,0x26c10022,0x6564005c,0x80ddce45}},	//   dzov, _txho_, _zaih, _परसे,
   {{0x6dbca40a,0x61e2e40b,0x2d9d80f7,0xdb038138}},	//   rčan, _ohol, thwe_, linç,
   {{0x44324750,0x4424c05c,0x6fd681cb,0x4439240c}},	//   bry_, ksm_, lâch, ous_,
   {{0x3ce6854a,0x6ecb6073,0x7d1d499e,0x6d95c031}},	//   जेले_, _तुरु, _iess, _dáal,
   {{0x57f44051,0x29dc8018,0x7d1b812c,0x80c8002a}},	//   _опят, ríaa_, _weus, রেক্,
   {{0x4426e192,0x98bf8011,0x29dc830d,0xfe57805f}},	//   _avo_, _obuć_, mían_, تیاب_,
   {{0x3f87c1df,0xe4e780d9,0x61e2c8a8,0x386d84f5}},	//   _sonu_, _дізн, _chol, _trer_,
   {{0xa2cd13ea,0x753bc6df,0x7763e40d,0x61e2c880}},	//   _दुस्, rguz, _panx, _dhol,
   {{0x6d4b8414,0x656400fc,0xe739c6b1,0xf7708ce1}},	//   lfga, _saih, љен_, _لام_,
   {{0x9ad340eb,0xa96a1707,0x216a02f1,0x38600283}},	//   _dịgo, бина_, бини_, _ssir_,
   {{0x8c488696,0x2c5d80b6,0x4ac48314,0xbcfb41aa}},	//   bağı, _kňd_, _लुटव, _saén,
   {{0xe72ecfd4,0x7763c03c,0x2b5802bc,0x7dd60e79}},	//   _пе_, _tanx, terc_, nási,
   {{0x65640176,0x2245c010,0x7ddd240e,0x3f9ec799}},	//   _waih, ptlk_, résa, chtu_,
   {{0x6d598360,0xe29709a5,0x09e64661,0x2d96630e}},	//   kewa, пар_, зовн, прас,
   {{0x4432640f,0xb8838047,0x394000b4,0x6d598020}},	//   try_, _klíč, _ucis_, jewa,
   {{0x291dc02e,0x291240f8,0xe53b00c3,0xb6020018}},	// [1f60] _mewa_, rbya_, _התפר, ñába,
   {{0x799b80bc,0x29dc80e1,0x3ce00247,0x80c1402a}},	//   _aluw, gían_, _iziv_, _শৃঙ্,
   {{0xc332c093,0x7d1d4fda,0xf8a901aa,0xeab2035c}},	//   תוב_, _fess, _هدیه_, _سعد_,
   {{0x9f4c8066,0x8afec020,0x799b8303,0x0f14846d}},	//   _vidí_, _maƙa, _cluw, डर्स_,
   {{0x9f5fc01f,0x799b888b,0x79898303,0x17fa4032}},	//   rquê_, _dluw, _doew, _درجة_,
   {{0xae0087a0,0x61fc6410,0x39591d77,0x78a28d0e}},	//   _लंदन_, _turl, zess_, rzov,
   {{0x9ea744ee,0x9f48055d,0x9f4480e1,0x799ba411}},	//   _евра_, óhùn_, _sumó_, _fluw,
   {{0x7c262412,0xb6bb40c3,0x79846413,0x7a01c017}},	//   kskr, _הצלי, njiw, _pētn,
   {{0xdca39194,0x7bce2414,0x7dd6034d,0x63ae4303}},	//   _зати, kobu, cási, _kmbn,
   {{0xdce083de,0x2b940041,0x6721d2cf,0x61e2c093}},	//   _jamč, _däck_, galj, _whol,
   {{0xa935084e,0x7bce2415,0x9f4b40c4,0x799640e2}},	//   менш, dobu, _cucù_, kkyw,
   {{0x61e2e416,0xdb03801f,0x752282c0,0x7c2615b6}},	//   _uhol, tinç, naoz, fskr,
   {{0x25a06417,0x6d42c0b4,0x61e419f2,0xf3ff40d1}},	//   dhil_, _icoa, _dhil, _trãi_,
   {{0xdce080b3,0x6d598036,0xa91da00c,0x29dc8004}},	//   _namč, zewa, _rožm, xían_,
   {{0xa2cd2418,0x66094654,0x61fe2419,0xbef7c1b4}},	//   _दुश्, _čeko, _cupl, _عروض_,
   {{0xceb3c0c3,0x99644156,0xb33c817a,0x6e3acb4c}},	//   _ריק_, нтул, _imħu, mutb,
   {{0xfbdc80a0,0x7a08c047,0xf53f0730,0x6dbc841b}},	// [1f70] यताम, _děte, mgå_, rčal,
   {{0x7e6100b0,0x25ad80e5,0xceba80e2,0x61e9e41a}},	//   ælps, _smel_, zaƙa_, zmel,
   {{0x799b8c05,0x41ccc0c6,0xc33202a6,0x6e3ad4b2}},	//   _pluw, ावास, _בוי_, nutb,
   {{0x9cb5871d,0x3ea1c09d,0x7afa80b1,0x88bdc062}},	//   ومات, _ühte_, _agtt, naśc,
   {{0x23658011,0x6b658b54,0x61e1475a,0xa3c1c048}},	//   _palj_, дкла, ïllu, ्कम_,
   {{0x7dd6241b,0x9f8f40b2,0x9f474025,0x69cf08f1}},	//   rási, nüü_, önä_, hoce,
   {{0x7d060041,0x798980bf,0x29dc8018,0xed59c11a}},	//   ycks, _toew, cíao_, tež_,
   {{0x96270017,0xaad0c17e,0x7c26241c,0xcbf9002a}},	//   _ieņē, _हड़क, yskr, _অবৈধ_,
   {{0x7bce0f12,0xf771ce5f,0x7ddd0107,0x3166c0b9}},	//   yobu, ناد_, tésn, _daoz_,
   {{0x6d4d41c8,0x9f53001e,0xeb9f40b0,0xdb08c1ff}},	//   hfaa, _fixé_, _støj_, vidã,
   {{0xdb18805b,0xdb0387e5,0xee36c156,0xa3b54045}},	//   nový, rinä, мнэ_, _जगन_,
   {{0x7c2994bc,0xdb070089,0xdb038ff3,0x44290e5d}},	//   _kver, vijá, sinä, _bva_,
   {{0xdb188066,0x7aed8047,0x6aa20020,0xd7bf4048}},	//   hový, žitě, _ƙofo, ्वाच,
   {{0x69d98b4d,0x6d9cc1b4,0x2122241d,0x98b28064}},	//   hlwe, _téac, sakh_, żyć_,
   {{0xd5b24032,0x29090070,0x7d098044,0x6566641e}},	//   نفس_, _ffaa_, _ofes, _pakh,
   {{0x213fccff,0x7c260fa0,0xaca38031,0xdb188531}},	//   nguh_, pskr, _afọn, dový,
   {{0xdb08e41f,0x65664498,0xb9b30032,0x70dc8036}},	// [1f80] lidá, _vakh, _جميع, _बरेल,
   {{0x386ddcf7,0x25a06420,0x6d5be421,0xdb0aa422}},	//   iver_, shil_, heua, tifí,
   {{0x28afc285,0x7c3be423,0x59adc027,0xdb1a83bc}},	//   _जेसि, huur, टफार, _oktò,
   {{0x29dc8004,0x2cbf46f0,0x20000303,0xaae542f0}},	//   ríao_, _žude_, _kuii_, رسلو,
   {{0x386dc1d4,0xdb0e410d,0x9fca8051,0x7c3bc134}},	//   jver_, þjón, огда_, juur,
   {{0x2906a424,0xdce44066,0x7c3be425,0x2367c04f}},	//   scoa_, ndič, duur, _nanj_,
   {{0x291f888b,0xdb188089,0x7d09802c,0xf7435065}},	//   _feua_, cový, _ffes, _шеро,
   {{0x3942c09d,0x75246426,0xafdb0176,0x28afc0b2}},	//   üks_, naiz, ttøk, _जेहि,
   {{0x2616c374,0x7dd88070,0x6e3c07b6,0x3940409d}},	//   _भौजी_, jísi, hurb, igis_,
   {{0x6e3c0086,0x68fb80b4,0x44291e20,0x27e5805e}},	//   kurb, _zgud, _rva_, _ghln_,
   {{0x75246427,0x777a81a8,0x5694c23d,0x2b1480ba}},	//   kaiz, _intx, хант, _न्यु_,
   {{0x2000017b,0x14afc048,0x6449c0cb,0x40351948}},	//   _buii_, _जेवण, btei, немс,
   {{0xc3244079,0xf53f04cf,0x6e3ac300,0x3a2a4070}},	//   _পানি_, rgå_, sutb, _lvbp_,
   {{0xdb08c018,0x7dd60107,0xa3ce8c4b,0x36d51807}},	//   bidá, dásu, रवि_, еогр,
   {{0x2d8b4570,0x8afec0e2,0xdb0e4060,0x6e3c0397}},	//   _poce_, _haƙo, _imbè, gurb,
   {{0x2b499b1a,0xdb188066,0x6f0dd8ca,0x5edd4079}},	//   đaci_, vový, _đaci, _বললে,
   {{0x27f86428,0x6d4d41c8,0xdb1ac1cb,0x7ddec13b}},	// [1f90] _birn_, rfaa, enté, hëso,
   {{0x7ddec0fd,0x8afec0e2,0x6d4d6333,0x443b5767}},	//   këso, _maƙo, sfaa, ruq_,
   {{0x9f5dc88b,0xdde28011,0x443b5ec0,0xdb1c4089}},	//   _duwè_, _šušu, suq_, _ukrý,
   {{0x75208070,0x386dc1e5,0x63b513cb,0x2d990fd7}},	//   _cemz, yver_, lizn, nkse_,
   {{0x92bb8079,0xdb038ae1,0x9f5fcfda,0x62950089}},	//   _ঘরে_, minú, squé_, lyzo,
   {{0x23ddc39a,0xa3df084d,0x29094043,0xdee583e1}},	//   _नींद, तति_, lcaa_, ноли,
   {{0xdb08c10b,0xf1bf0066,0x02c342ea,0x533446b1}},	//   xidá, kná_, _शशिभ, _јест,
   {{0xa2d60474,0x8afec0e2,0x7c29a429,0x7dd6242a}},	//   _मुफ्, _baƙo, _tver, nást,
   {{0xa3df0eb5,0x69c2e42b,0x6569e3de,0xa3cf0ae7}},	//   तता_, _djoe, rdeh, षका_,
   {{0xdaa9ceb1,0x7dd88086,0x61ed642c,0x3f8c8017}},	//   звод_, vísi, hmal, _godu_,
   {{0x614604b6,0x752f4036,0x7c3be057,0xb345cfc2}},	//   нена, _odcz, suur, _acçã,
   {{0x6721a42d,0xa96a06b1,0x6dbc8123,0x3860402c}},	//   _helj, чима_, včak, ywir_,
   {{0x75244039,0x02cfc3b0,0x7f5c0a12,0x6601a42e}},	//   vaiz, _सुरभ, terq, _hulk,
   {{0x67218077,0x81bd0017,0xa2cae073,0x2d9916b5}},	//   _jelj, nsēj, _सुक्, akse_,
   {{0xe299c12b,0x7dd8830d,0x959a40b4,0x34dc8705}},	//   _хай_, sísi, птау_, _बर्द,
   {{0xdd924b3f,0x442b642f,0x7dd8834d,0x7dd60107}},	//   دور_, _bvc_, písi, tásu,
   {{0xb4ea408f,0x7d165900,0xea00000c,0x69dbcd87}},	// [1fa0] मधे_, rbys, _thắt_, ilue,
   {{0x7d1640de,0x6c3341b4,0x9e661099,0x6d9cc01e}},	//   sbys, افلا, _звод, _néan,
   {{0xfc3f0066,0x9f47c031,0x38605cbd,0x394040d9}},	//   nzín_, _binú_, swir_, pgis_,
   {{0x7bdc0621,0xd2b70323,0xd132801c,0x7ae10107}},	//   llru, _טלית_, امش_, ülte,
   {{0x3f9e807a,0x7c29c0b0,0xfaf8c017,0x660181a8}},	//   _pltu_, jser, ldīt_, _aulk,
   {{0xf1bf0531,0xa2cb4021,0x764a8041,0xcebac09c}},	//   zná_, _तुक्, ttfy, _leƙa_,
   {{0x3afb0009,0x660180b6,0x6d5d2430,0xa2e343e1}},	//   פּגע, _culk, yesa, _борд,
   {{0xf1bf002d,0x25bfc0cc,0x7c29c0cb,0x69d6017b}},	//   xná_, gnul_, fser, _nkye,
   {{0xe73a93dd,0x61f9c396,0x6da38143,0x5ed20048}},	//   _неа_, _diwl, _сита, _दुसऱ,
   {{0x2124c4f8,0xc6a6c156,0x29d74016,0x6d40c018}},	//   samh_, ерми, lçat_, sgma,
   {{0x36368646,0x68e42431,0x44294ebb,0xed5ad1cd}},	//   _سراس, _azid, zsa_, _нож_,
   {{0x23a444d3,0x7c3d0c99,0x9f4ec031,0xea0000d1}},	//   _höjd_, tusr, _difá_, _chật_,
   {{0x4429403a,0x7c29c107,0x5893c16a,0xc17380c3}},	//   xsa_, cser, _مجوز, אחר_,
   {{0x5334c858,0x69d6011c,0x49930107,0x442b4127}},	//   _рект, _ekye, ئیکر, _rvc_,
   {{0x443d801f,0xdb15013b,0x660181c8,0x2fd10011}},	//   zuw_, lizë, _xulk, rozg_,
   {{0x6d42806f,0x7c3d23be,0xcdd846b1,0x5c75074d}},	//   jgoa, pusr, ењу_, _алит,
   {{0xf3f9401b,0xdb01c4c9,0x9f5dc01c,0x40345feb}},	// [1fb0] днаш_, rnlö, _suwé_, летс,
   {{0xdb0380e1,0x7d09e432,0x73d85702,0x7522c43e}},	//   sinú, zces, едур_, _leoz,
   {{0xc7c461ab,0x61ed4165,0x88bdc036,0x67256433}},	//   усти, pmal, jaśn, rahj,
   {{0x442b46ed,0x6d9ce434,0x7f9486ed,0x98b90039}},	//   _tvc_, _séan, _màqu, nesį_,
   {{0x6721900c,0x3f698417,0x69dd2435,0xa3d0c185}},	//   _pelj, дило_, ilse, वका_,
   {{0x7c3f41c8,0x44390dc5,0x656d6436,0x7d0d0061}},	//   muqr, irs_, ldah, _lfas,
   {{0xada5c59d,0xdddc8107,0x8fa28051,0xfc3f0032}},	//   какл, _errő, раще, huí_,
   {{0x25bfc0b4,0xdb1ada1d,0xdb01c359,0x69c0d05f}},	//   unul_, kotó, mhlé, gnme,
   {{0x25bfc119,0x57f584c4,0xdd8ec032,0x6d9cc032}},	//   rnul_, _апат, توي_, _téan,
   {{0x3946c49a,0xdced038f,0x09ca0bc8,0x69dd2437}},	//   _ecos_, _znać, रव्य, else,
   {{0xa3c0808f,0xe5a61201,0x442b0119,0xea00000c}},	//   ीवर_, вини, esc_, _phật_,
   {{0x61e98303,0x80d3c02a,0xfbc900c3,0x7afa44dc}},	//   _jhel, দেষ্, _ות_, _útte,
   {{0xdb050041,0xd7d14048,0x7dd880a0,0xc5f28323}},	//   _omhä, तकाच, míst, ידט_,
   {{0x7dd6005f,0x2ca942bc,0x316de438,0x290b023f}},	//   táss, dzad_, ldez_, acca_,
   {{0x442b0032,0x799bc150,0xe50f425d,0x7d0d002c}},	//   asc_, okuw, _ụmụn, _ffas,
   {{0x7d1b010d,0x25a00450,0x656bc0f1,0x395fe439}},	//   ðust, _ulil_, _jagh, neus_,
   {{0x6603e43a,0xf5930032,0x39464017,0xb95b41c0}},	// [1fc0] _hunk, _خليج, ļos_, _ejìo,
   {{0x752400fa,0x395fd2e7,0x7c2b9462,0x61e9945a}},	//   _heiz, heus_, dsgr, _ahel,
   {{0x179b00c3,0x61e9a43b,0xe28640c5,0x443fe43c}},	//   _חייב, _bhel, ължи, huu_,
   {{0x644d643d,0x290d8004,0x60db96b4,0x6459c0bf}},	//   btai, _cfea_, _byum, _opwi,
   {{0x644d643e,0x91fcc03f,0x70548d72,0x61e9a43f}},	//   ctai, nvār, انتا, _dhel,
   {{0x61e981c8,0x2b47c09c,0xafdb0240,0xdb01802d}},	//   _ehel, _ncnc_, støv, _zmlú,
   {{0xdb01e440,0x442da441,0x442000ce,0x290001a8}},	//   chlé, _eve_, _lwi_, _ogia_,
   {{0x91e69e9b,0x443fc150,0xa91d841b,0xa2a0c08f}},	//   _робе, fuu_, _božu, खनस्,
   {{0x6603c34d,0x6d446442,0x67474086,0x66094e5a}},	//   _aunk, igia, _þrjá, _čeki,
   {{0x7d0d08e5,0x6723e443,0x69c28077,0x6d562444}},	//   _sfas, _cenj, lnoe, _abya,
   {{0xc7b340c3,0xd5b90017,0x7ddd0c5e,0x443901f4}},	//   שבת_, ksāt_, lési, wrs_,
   {{0x9f586445,0xf2d34942,0x2d8fe446,0x63b8a447}},	//   _diré_, יעת_, _goge_, livn,
   {{0x442d02cb,0x9f584004,0x7dd6005f,0x7dd8a0b0}},	//   ée_, _eiré_, tásr, líss,
   {{0xc7c40051,0x29000232,0x61bd4db4,0x6723e448}},	//   асси, _egia_, ्क्ष, _genj,
   {{0x93fbc087,0x7524009c,0x75e5c107,0x7dd8a310}},	//   _קלוי, _feiz, lóza, níss,
   {{0x67271415,0x44392449,0xc7b8c077,0x46b5809d}},	//   sajj, prs_, liđ_, _अइसह,
   {{0x3b554119,0x2d894018,0x394904c9,0x200480cc}},	// [1fd0] лкар, rjae_, _icas_, _numi_,
   {{0x3869244a,0x765a8036,0x9c140112,0xa49b40b6}},	//   _isar_, _opty, _kọns, _agòc,
   {{0x656d0e04,0xa3c88185,0x61fba44b,0xaa951dff}},	//   _kaah, ोकन_, _piul, _синч,
   {{0x29d74fc2,0x2d8b07ef,0x657d5e5b,0x6d938189}},	//   rças_, njce_, _unsh, _açar,
   {{0x2004800d,0x7ddec0fd,0x236c8053,0x9f5a0053}},	//   _cumi_, mësh, _badj_, _bipè_,
   {{0xe613438b,0x656d0057,0x7c2ba02b,0x7c2d644c}},	//   _نشر_, _laah, rsgr, msar,
   {{0x7d0d40c4,0x6d9cc032,0x29d90359,0xba528032}},	//   ocas, _téal, néas_, منوع,
   {{0x61e987fb,0x6440e0ae,0x442d8263,0xdcfbc7ca}},	//   _uhel, fumi, _tve_, njuć,
   {{0x4439a44d,0x3f9140e0,0x644d024c,0x65949441}},	//   _ís_, _kozu_, _nqai, _тату,
   {{0x6dbc8a11,0x60dd405c,0xea00000c,0x645b80fc}},	//   učav, _mysm, _giặt_, _ipui,
   {{0x2004a2d9,0x7ddec0fd,0x6d44402c,0x443fc5f9}},	//   _zumi_, kësh, ygia, suu_,
   {{0xcd2bc5d3,0x3f91441b,0xea00000c,0x4420244e}},	//   _آسان_, _lozu_, _nhạt_, _pwi_,
   {{0x6728c570,0x6723e44f,0xa3c78048,0x6dbc841b}},	//   badj, _tenj, _उदा_, pčav,
   {{0xfc031d8f,0x290dc119,0xaa462450,0x9f586451}},	//   спро, lcea_, легл, _tiré_,
   {{0x7e96c6b0,0x61fd6452,0x212962d7,0x5a9502d5}},	//   _منور_, _bisl, faah_, артф,
   {{0xdb1c0036,0x61fd4089,0x7bc741ae,0x46b2c036}},	//   toró, _cisl, _ajju, ुपरह,
   {{0x3f91405c,0x442005bb,0x69d9e453,0x00e65151}},	// [1fe0] _bozu_, _uwi_, _mkwe, ужан,
   {{0x7d0d4004,0xaca3c112,0x6d460240,0x6d44402c}},	//   acas, _nkọk, lgka, sgia,
   {{0x52762454,0x3f9160c8,0x656d0150,0xdb9ac009}},	//   _супу, _dozu_, _yaah, עסער,
   {{0xafdb0240,0x2d9e4017,0xeb9f4211,0x7d1bd891}},	//   støt, ītes_, _støt_, jbus,
   {{0xb4e2c027,0x70e2c58e,0x69d66455,0xdfda80c5}},	//   _धरे_, _परेल, moye, нък_,
   {{0x09ccc4eb,0xe4570087,0x7dd8a456,0x69d9c5bc}},	//   ाव्य, ריסט_, tíss, _akwe,
   {{0x7ddec0fd,0xaab85e85,0x442de457,0x69c46458}},	//   lësi, _आधिक, ese_, onie,
   {{0x7dd8a310,0xb034c7bf,0xe5a3841a,0xcbc0c02a}},	//   ríss, аниш, _лиси, _উঠেছ,
   {{0x7ddec0fd,0x48e38b24,0x69c46459,0x8afec6df}},	//   nësi, _готв, inie, _haƙi,
   {{0x7fd68026,0x6560c00b,0xbef40048,0x7526645a}},	//   _сібі, semh, _आणून_, _lekz,
   {{0x7641e45b,0x7d1bd3ab,0x7fd74009,0x66e68051}},	//   guly, bbus, רויס_, _сожа,
   {{0x8afec020,0x442fc0c4,0x6d95c031,0x290dc8e5}},	//   _maƙi, _fvg_, _dáas, ccea_,
   {{0x25b900b3,0xdb18801f,0x656f1f84,0x6440c073}},	//   risl_, vivê, rdch, qumi,
   {{0x656d245c,0x7d0d518d,0x60dd414d,0xa49b435d}},	//   _waah, wcas, _rysm, _ngòa,
   {{0x9f47c047,0x8cd5105d,0x7bd5245d,0x3f914043}},	//   _jiný_, _युरो, rozu, _rozu_,
   {{0xc27bc087,0x69d6645e,0x2d92009c,0xdb038066}},	//   _טרוי, goye, _goye_, diný,
   {{0x7bda8e67,0x61fd645f,0x2006c05c,0x61ed2460}},	// [1ff0] _oktu, _visl, _juoi_, _ihal,
   {{0x7c2f2461,0x7c22e462,0x66050134,0x44f46463}},	//   mscr, _mwor, _tuhk, спус,
   {{0x61fd6464,0x3f9157a8,0xf1ca0288,0x80d3402a}},	//   _tisl, _vozu_, रवचन, _দৃশ্,
   {{0xd56743c6,0x7127861e,0x7bc88123,0xdb0185ee}},	//   _стоп, ارال, _ajdu, _illé,
   {{0x63baccff,0xc3244079,0x8afec020,0x656f6465}},	//   kitn, _পারি_, _daƙi, _iach,
   {{0x629ac039,0x39468039,0x645d4230,0x798d6466}},	//   kyto, agos_, _ipsi, ljaw,
   {{0x61ed00b3,0x442de467,0x39544018,0xdce9c04f}},	//   _ohal, wse_, _éasí_, rdeč,
   {{0x7c22c449,0x7d1be468,0x56b800c3,0x3f9ec062}},	//   _bwor, ubus, טפון_, ektu_,
   {{0x2006c00c,0x23a44041,0x7a08c047,0x244f4165}},	//   _cuoi_, _höja_, _dětm, nüm_,
   {{0x63bacc47,0xe0d08d72,0x7c3be469,0xed598123}},	//   gitn, _رزق_, rrur, _hbž_,
   {{0x212b246a,0x244f4080,0xdd8ec2cf,0x8afec6df}},	//   fach_, hüm_, سوی_, _maƙw,
   {{0x645d646b,0x442fc48e,0x76439e5c,0xa2b85087}},	//   _opsi, _tvg_, muny, ्पत्,
   {{0xfe09c015,0xdd148166,0xdb018669,0x6d4608cd}},	//   _bắc_, núši, _allé, rgka,
   {{0x2bddc0b2,0xdb01c004,0x7641c080,0x0cc60036}},	//   _नीचा, riló, puly, _लखीम,
   {{0x7643a46c,0xf50645bd,0xe0df4083,0x2126e46d}},	//   nuny, изво, _ayò_, _yeoh_,
   {{0xd1ba00fb,0x4ad948c1,0x212b246e,0x44224033}},	//   _جاتا_, _बुधव, cach_, _pwk_,

   {{0x6fdf8669,0xf5074156,0x8afec09c,0x0326646f}},	// [2000] pêch, рнул_, _baƙw, идан,
   {{0x69db8398,0x109b0942,0x764f0107,0xafdb0586}},	//   _akue, _סביב, önyö, stør,
   {{0x7afcc2bc,0x25a9492c,0x6d59c31c,0x7f3b0093}},	//   žrtv, bhal_, _obwa, _בעיו,
   {{0x7ddec0fd,0xeae6408f,0x3207c396,0x7643875d}},	//   pësi, _करीत_, _muny_, duny,
   {{0x99984007,0xa91d8084,0x7d048017,0x629ac062}},	//   strų_, _požr, žiso, zyto,
   {{0x08770009,0x7643820e,0x69c980bb,0x212b1dd5}},	//   יענט_, funy, _ejee, zach_,
   {{0x2ca082bc,0xdd210047,0xa3c78045,0x628301cb}},	//   šid_, _růžo, _उदर_, _ànot,
   {{0x7c668973,0x7d042470,0x741687c3,0x99d3c1b4}},	//   _پارل, _ngis, _نورا, يتيا,
   {{0xef86a471,0x7f868de9,0xdca38aba,0x2904a472}},	//   _клап, _پلان, _дати, _igma_,
   {{0x321a423f,0x442481c8,0xbbd0c185,0x61e2a473}},	//   oppy_, _iwm_, सकेक, llol,
   {{0x63bac56e,0x6ed60185,0x244f40b5,0xa2d601f9}},	//   ritn, _मुलु, züm_, _मुल्,
   {{0x7c2f119e,0xac190f6d,0x24190523,0x61e2a474}},	//   tscr, лому_, ломы_, nlol,
   {{0xdb038a5d,0x98a24053,0x7c3d0a26,0xf99f00c4}},	//   cinó, _bekč_, ursr, rkè_,
   {{0xd83fa056,0x53d68a3c,0x7bd8a475,0x7d0401ae}},	//   _účet_, धविश, novu, _egis,
   {{0x25f3408f,0x212b2476,0x6d59c05c,0xe5c70051}},	//   ंगली_, pach_, _ybwa, _вспо,
   {{0x200f401f,0xae0bc09d,0x7ce10112,0xdce64017}},	//   ígio_, _संतन_, _ịrun, _sakā,
   {{0xfe09c015,0x225e8033,0x209845f1,0x88d8c079}},	// [2010] _tắc_, _lptk_, акты_, দেরক,
   {{0xa3e6e477,0x69db836b,0x0a51c0fb,0xdb1ac0fd}},	//   पति_, _skue, _بھیج, ditë,
   {{0x7bd8a478,0xa3bc009d,0x7ff403a9,0xb5228428}},	//   dovu, _आगत_, _بسيا, मरूप_,
   {{0x2009009c,0xbcfb4231,0x61e2802f,0x5f148047}},	//   _kuai_, _daér, glol, नुस्_,
   {{0x67275650,0xed59c06f,0x3ce00022,0x55528de9}},	//   _tejj, niže_, _xyiv_, سپور,
   {{0xa34987ea,0x20090033,0x3e1741aa,0x67288077}},	//   узка_, _muai_, _نظرس, _cedj,
   {{0x69c980a8,0x61e2891a,0x27e6409c,0x9f4580a0}},	//   _tjee, blol, ɓon_, _uhlí_,
   {{0x69c98057,0xdb1ae479,0x0d85d8cc,0x7bcac17b}},	//   _ujee, litè, слин, _ajfu,
   {{0x69d9a47a,0xe8f9c025,0x2009017b,0x3949647b}},	//   mowe, ыли_, _nuai_, igas_,
   {{0x200100eb,0x69d9a47c,0x3207c060,0x63bc247d}},	//   _nihi_, lowe, _puny_, xirn,
   {{0x59c748bc,0x4424823b,0x752980bc,0x752d57e6}},	//   रचार, _zwm_, _keez, kaaz,
   {{0x6d4bc018,0xdcfd40ce,0x13a7c08c,0x69d99a9a}},	//   _ucga, _ansč, انگی_, nowe,
   {{0x9f47c141,0x21290061,0x63a7404f,0x99d4c280}},	//   _dinò_, _deah_, _oljn, _بتلا,
   {{0xa01b410d,0x7bc7041b,0xb4e80a39,0xdb1c013b}},	//   _kröf, gnju, _भरी_, mirë,
   {{0x2365e47e,0x61e280f8,0x69d98036,0x8afec0e2}},	//   melj_, ylol, kowe, _baƙu,
   {{0xdced4166,0x63bc044e,0xa52600b4,0x2fd8247f}},	//   adač, sirn, _умид, sorg_,
   {{0x65646480,0x7bd8a481,0x1604105d,0x629c04c9}},	// [2020] reih, yovu, _शंकर_, syro,
   {{0x65662482,0xe8f745ac,0x447700c3,0xe80ac045}},	//   lekh, слу_, _פעיל_, _हंसा_,
   {{0x7529a483,0x386d8070,0x7bde00eb,0xee3a400a}},	//   _beez, _aser_, _ikpu, уне_,
   {{0x29dc830d,0x6d984018,0x2365c60f,0x69d99a9a}},	//   vías_, _vías, helj_, gowe,
   {{0xdb0e4018,0x98a4c03f,0x7529a484,0xc7ba81dc}},	//   _embá, kamā_, _deez, лёк_,
   {{0xdb1ac0fd,0x8afec0e2,0xe0858032,0x5f93800a}},	//   ritë, _zaƙu, تجمي, зишт,
   {{0x64461fc8,0x8afec09c,0x386d8138,0x7529840d}},	//   huki, _yaƙu, _eser_, _feez,
   {{0xb8000079,0xdb1ae485,0xa814c2e2,0x4424a486}},	//   ্ঠিত_, mité, одиш, _twm_,
   {{0xfd0fc79e,0x6ab2c298,0x9f5a00c4,0x320a4c81}},	//   رجي_, ुप्र, _pipì_, _huby_,
   {{0x752980a8,0xc301002a,0xa3e48048,0x2365c147}},	//   _zeez, ্রতি_, नतळ_, gelj_,
   {{0x2258c051,0x3860002f,0x4df842f6,0xdb1ac01e}},	//   шины_, _apir_, ंगाई_, nité,
   {{0x6446180c,0x65662487,0x7982c0ff,0xeae6409d}},	//   fuki, gekh, _unow, _करैत_,
   {{0x80da802a,0x2906c0b9,0xf8a88314,0xac94c5f5}},	//   _বৃত্, _igoa_, कनिय, _фалш,
   {{0x81c0802a,0x25754112,0x4fc70051,0x69d9a488}},	//   ুতি_, _ụl_, ссма, zowe,
   {{0x3d95016d,0x65950466,0x212040b3,0x7bdae489}},	//   _микр, _маку, fbih_, motu,
   {{0x212040b3,0x672ac086,0xdb1ac7b0,0xb6068011}},	//   gbih_, _hefj, dité, mišć,
   {{0xe4504ce1,0x32024066,0xf1bf0018,0xdb01c032}},	// [2030] فضل_, _diky_, miá_, mhlá,
   {{0xfe09c00c,0x6440c032,0xdb038032,0x613f402e}},	//   _mắn_, irmi, thní, _bàlà,
   {{0x660ac7ef,0x29dca48a,0x46d94036,0xb6068123}},	//   _jufk, víar_, _बुशह, nišć,
   {{0x443fe48b,0x6b84c09c,0xea00435d,0x6602e48c}},	//   yru_, _ɗiga, _phất_, _niok,
   {{0x5fc8c444,0x660ae48d,0x6d4f417a,0x68e2c8c3}},	//   िचाल, _lufk, _icca, _nyod,
   {{0xa2b84285,0x63a740ab,0x65aa4066,0xd9cf0079}},	//   ्पश्, _uljn, _výhe, রতিম,
   {{0x80da8079,0x443fe48e,0x6440cf64,0x7a11805e}},	//   _বৃদ্, wru_, ermi, _bāta,
   {{0xb6068458,0x7ddd0107,0x8459e48f,0x64462490}},	//   dišć, zésr, арот_, yuki,
   {{0x320a4066,0xf1bf0166,0xfe09c00c,0x6d4b8010}},	//   _zuby_, diá_, _cắn_, mgga,
   {{0x20036491,0x61e44165,0x644601c6,0xfe090045}},	//   _jiji_, zlil, vuki, वदास_,
   {{0x38602492,0x6d4f6493,0x4426e494,0x6b834107}},	//   _spir_, _occa, _ewo_, öngy,
   {{0x212b4166,0x9f5843e9,0x2367806c,0x7d090007}},	//   _nech_, _mirá_, lenj_, žesn,
   {{0x69dbc580,0xa2e66495,0x399c4047,0x25bfc0b4}},	//   moue, _कर्ज_, _míst_, miul_,
   {{0x656600f7,0xb4fa82a6,0x212f805e,0x69c9c7f5}},	//   sekh, יפרי, hagh_, lnee,
   {{0x44324062,0x9178c171,0x224785ca,0x1d0a45f5}},	//   wsy_, _jé̟_, nunk_, иеви_,
   {{0xdb01c032,0x79840036,0x3dc94105,0xa3ba008c}},	//   chlá, _uniw, gnaw_, _چادر_,
   {{0x69c9dc2e,0xb886c086,0x25e30374,0xfe09c00c}},	// [2040] inee, mtíð, _टीटी_, _xắn_,
   {{0x69dbe1e3,0x9b460107,0xceea4007,0xe9df41c0}},	//   houe, _بندو, адзе_, _ekú_,
   {{0x7bdc2496,0x7dd60107,0x200340b6,0x236780e5}},	//   moru, dász, _diji_, denj_,
   {{0x9f585b4d,0xec7aa497,0x7bdac12c,0x22478107}},	//   _dirá_, ипе_, zotu, dunk_,
   {{0x938a8473,0xeafa078a,0xdb1c03bc,0x200b6498}},	//   иска_, _حرکت_, tirè, _guci_,
   {{0x7a150036,0x2003466b,0xf767c68b,0x7dd60107}},	//   _wąte, _giji_, _غا_, gász,
   {{0x6da69575,0x7a1183a0,0x200b6499,0xfd558112}},	//   _дива, _pāta, _zuci_, ntaị,
   {{0x68e4075d,0x7e9b0009,0x25bfc0b4,0xdb0740ce}},	//   _oyid, יסצו, giul_, _aljè,
   {{0x0b8ac5a4,0x54ee8036,0x9958c047,0xd378c011}},	//   асни_, _जरिए_, _též_, hoće_,
   {{0xd378c013,0xb6068451,0xfe09c35d,0x61e615b6}},	//   koće_, tišć, _vắn_, elkl,
   {{0x7bdae49a,0x25bfe49b,0xcb134093,0xa01b44c9}},	//   rotu, biul_, ולת_, _trög,
   {{0xc486d6a8,0x7bdac85c,0x6d9cc359,0x69c9c149}},	//   _млек, sotu, _céat, cnee,
   {{0x212b649c,0xf1bf002d,0x752f0062,0xa3ea4bc0}},	//   _rech_, riá_, racz, मता_,
   {{0x7bdc139c,0x67efc065,0x23bc8ebe,0xdb01c032}},	//   goru, tøje, ्चिद, shlá,
   {{0x644288a6,0x212b4484,0xa3bc108d,0xb5c94032}},	//   hroi, _pech_, _आगर_, موسم_,
   {{0x64400019,0x6604249d,0xc808c35d,0xd7f8c379}},	//   ámic, _giik, _lởm_, lmă_,
   {{0xad9b403e,0xd2db0027,0x6d5f0031,0xa1f90107}},	// [2050] _fiún, _मुरझ, _ibqa, _پڑھا_,
   {{0x81c2c079,0xdb08c070,0x1fa715f5,0x7986649e}},	//   ৃতি_, midó, _фриг, _enkw,
   {{0x212b6493,0x2367804f,0x200b409c,0xf5188112}},	//   _tech_, venj_, _wuci_, _ịtụp,
   {{0x6442801e,0x45d5423d,0x9f58450e,0x9f47c359}},	//   froi, _хомс, _virá_, _mhná_,
   {{0x0c24811b,0x399c4086,0xfbd00567,0x6385858f}},	//   дмін, _víst_, _ستی_, згла,
   {{0x69dd249f,0x7b6464a0,0x6d4d64a1,0xeb9688d3}},	//   hose, _отсе, lgaa, зиш_,
   {{0x25bfc0b4,0xb90287a5,0x69c9c0bf,0x3ce9c043}},	//   tiul_, _नु_, tnee, _šav_,
   {{0x69dd24a2,0x9f4c80d2,0x20098070,0x9f5ce4a3}},	//   jose, _bidó_, íais_, _diví_,
   {{0x69c9c7d3,0x6604054a,0x6442a4a4,0xa3db0a3c}},	//   rnee, _riik, croi, ़वा_,
   {{0x7ae3d230,0xbcfb41c0,0x224785ca,0x2d9964a5}},	//   _pynt, _gbée, punk_, _lose_,
   {{0xe9da0e50,0x7a13c0b4,0x539c4052,0x66041139}},	//   йко_, _băta, ייזו, _piik,
   {{0x69cba4a6,0xc0b640d1,0x6d4d64a7,0x200d8303}},	//   nnge, _cưỡi_, jgaa, _kuei_,
   {{0x920bc3fc,0x261180d1,0xa3db4926,0x7ae3d2e7}},	//   _सूरज_, _háo_, डका_, _wynt,
   {{0xdb1524a8,0x7c29a4a9,0x6604011c,0x7d09809c}},	//   tizá, _mwer, _wiik, _lges,
   {{0x386dcfcf,0x8e8318ed,0xcb12c093,0x69dd04b5}},	//   lwer_, нгре, _אלו_, bose,
   {{0x3f9843a6,0x394de4aa,0x76438056,0x7bdc24ab}},	//   _soru_, nges_, irny, soru,
   {{0x442924ac,0xfe09c0d1,0x68e4075d,0xddc1c017}},	// [2060] _gwa_, _mắm_, _uyid, _aplū,
   {{0x69cb9263,0xdb18a4ad,0x287b00c3,0x20058024}},	//   enge, tiví, _פנימ, _nili_,
   {{0x2ca04782,0x44290053,0x7c29a4ae,0x657624af}},	//   syid_, _zwa_, _awer, _kayh,
   {{0x21024007,0x5f46005f,0x80dcc048,0x27170047}},	//   _ačiū_, _بنگل, _पडले, pění_,
   {{0x212d8033,0xa3cbc08f,0x3dd1c02a,0x397b40c3}},	//   _deeh_, रचा_, াতাল, _הטכנ,
   {{0x46db056c,0x2d99400d,0xb6024047,0x69dd20b4}},	//   _मुँह, _zose_, žáda, zose,
   {{0x2d99491f,0xdbc74f4c,0x7c3644cf,0x9f4c8031}},	//   _yose_, töös, lsyr, _bidò_,
   {{0x69c3805f,0x6d9cc032,0x752440fc,0x29f7c0eb}},	//   énet, _réas, nbiz, _ṅara_,
   {{0x76438056,0x660664b0,0xdcebc03f,0x7bc1c119}},	//   arny, _mikk, _pagā, filu,
   {{0x6c3381b4,0xec37821d,0x69c28ce6,0x316941a8}},	//   _أفلا, _מאמר_, lioe, zeaz_,
   {{0x69c0d30e,0xb1134112,0x0f574087,0x2258004f}},	//   pime, _kụta, היים_, jtrk_,
   {{0x752441d6,0x644464b1,0x6449c016,0x44204498}},	//   jbiz, krii, buei, kpi_,
   {{0x63aac018,0x2005a114,0xd7fad1cd,0xa2c48ebe}},	//   _tlfn, _yili_, _лук_, िपक्,
   {{0x77adc018,0x24800077,0x69dd21c8,0x9f5cc43e}},	//   _púxe, _drim_, sose, _divã_,
   {{0x660664b2,0x69cba4b3,0x69dd15b7,0x316940fc}},	//   _bikk, ynge, pose, teaz_,
   {{0x2ba9817e,0x199440c5,0x6b9a84f1,0xdd9464b4}},	//   _कत्थ, нася, _lotg, насы,
   {{0xa2be9888,0x113c00c3,0x9c194032,0x64444149}},	// [2070] _वेस्, _התחל, زياء_, grii,
   {{0x6d4d44a9,0x09c58048,0x9f5ea4b5,0x2d9941c6}},	//   sgaa, लच्य, _bití_, _wose_,
   {{0xe1f9c007,0x3ea749ac,0x6d4d64b6,0xb90444eb}},	//   ymų_, ánt_, pgaa, _पु_,
   {{0x65608061,0x9f5e8031,0x69c2a4b7,0x386dc14b}},	//   _cbmh, _dití_, gioe, ywer_,
   {{0x261180d1,0xeab0405f,0x69cb9fc6,0x6569c206}},	//   _sáo_, نٹے_, rnge, veeh,
   {{0xedf7d271,0xdb1ac032,0x1fa980b4,0xac1858d5}},	//   ुद्ध_, antú, юкли_, _хору_,
   {{0xdb03c089,0x3cffc048,0x69c28140,0x00000000}},	//   _plní, शेने_, bioe, --,
   {{0xcda981aa,0x7c2996fc,0x6d5d015d,0x6b8880cb}},	//   _بهره_, _twer, jfsa, _endg,
   {{0xe1f9c007,0x20059556,0xbcfb01cb,0x7aed80e2}},	//   rmų_, _tili_, nféd, ƙato,
   {{0xdb1e0669,0x644b9b03,0x2d891593,0xb1134044}},	//   _empê, mugi, _anae_, _zụta,
   {{0xdb0802cb,0xfe09c015,0x799b83e2,0x386dc093}},	//   _élém, _tắm_, _kouw, swer_,
   {{0x61e2c053,0x442b4303,0x80dd409d,0x201fc025}},	//   _gkol, _owc_, _मडूं, ppui_,
   {{0x644b8cd1,0x799b815d,0x777700f1,0xad9b401f}},	//   nugi, _mouw, _baxx, _ciúm,
   {{0x9814c032,0x6ed8c25c,0x656b8044,0xd84f80eb}},	//   _أبنا, _नुकु, hegh, lọsi_,
   {{0x91e64b24,0x68e6411b,0x38b401c0,0x777700f6}},	//   дове, _sykd, _búré_, _daxx,
   {{0xdb1c0019,0xd378c6f0,0x443964b8,0xfe09c35d}},	//   mirí, moća_, _bvs_, _lắk_,
   {{0x3ce6c04d,0x75245256,0xa3dd8185,0x777701d6}},	// [2080] _xyov_, rbiz, णका_, _faxx,
   {{0x200fdb8e,0x61e9c339,0x7bc3a4b9,0x249f00cb}},	//   _mugi_, hlel, jinu, äume_,
   {{0x7bde64ba,0x1d0a41e6,0xb4db4031,0x6444454a}},	//   ropu, _мени_, _adàd, srii,
   {{0x2007e4bb,0x29d74283,0x3ce3017e,0x25a68c47}},	//   _lini_, għad_, _टुडे_, ukol_,
   {{0x2613c015,0x4422021b,0x6b9a868e,0xb3a98048}},	//   _lão_, npk_, _potg, कसंख,
   {{0x69c3a4bc,0x61fbe4bd,0x69c2a4be,0x09d6c048}},	//   éner, emul, sioe, डक्य,
   {{0xb1134112,0xa2be8945,0x6281805e,0x656b8094}},	//   _tụta, _वेश्, _crlo, begh,
   {{0xdb1c0996,0x22408166,0x644b98c9,0x61e9d8be}},	//   dirí, čik_, bugi, glel,
   {{0x212fc033,0x62819939,0xdb1c4303,0x7bc3a4bf}},	//   _degh_, _erlo, _amré, binu,
   {{0x2613c015,0x26070027,0x7bc3a21e,0x61fbe4c0}},	//   _bão_, _सूजी_, cinu, amul,
   {{0xdb1e088b,0x2d9ac1cb,0x200fc0b9,0xf0d28044}},	//   _impè, êpes_, _eugi_, tịwọ,
   {{0x61e9e4c1,0x200fe4c2,0xfaa38ed1,0x56374052}},	//   clel, _fugi_, _шахо, ואטע_,
   {{0xd3788077,0x6ce400d9,0x79fbc0c3,0x6d5d0397}},	//   _kać_, віре, _ולאח, rfsa,
   {{0xe4c7c01c,0xa5c6c5e7,0x2902c007,0x9f58c051}},	//   _تصمی, bjóð, žkas_, örä_,
   {{0x443946bc,0x644624c3,0x656b8044,0xb90600e6}},	//   _svs_, arki, yegh, _बु_,
   {{0xdb070051,0x644b805c,0x61e0db33,0xb33c80f6}},	//   kijö, yugi, noml, _ilħu,
   {{0x77770283,0x798980c4,0x24584051,0x799b80a8}},	// [2090] _taxx, _rnew, мать_, _rouw,
   {{0x644b891f,0xd3788458,0x21f20166,0x6b9c64c4}},	//   vugi, _nać_, máha_, _corg,
   {{0xc808c00c,0x443924c5,0xa2be93c4,0x61e9c138}},	//   _cởi_, lss_, _वेल्, ylel,
   {{0xd6d84522,0x9f5a0051,0xd1b8849f,0x91fcc017}},	//   фту_, _eipä_, وانا_, _spān,
   {{0x61e0d48d,0x251a4323,0xa3b60185,0x7bc392c5}},	//   doml, _מורא, चोक_, tinu,
   {{0xdb189820,0x6562e4c6,0x62819a6c,0xf41f4025}},	//   tivá, _aboh, _prlo, _itä_,
   {{0xc2e7802a,0x644ba4c7,0x7d0d24c8,0xdb1a8107}},	//   গেনি_, sugi, _ogas, _ajtó,
   {{0xf41f4041,0xceb243bd,0x644624c9,0xdb1e04e2}},	//   _träd_, _עין_, yrki, _empè,
   {{0xf771c71d,0x3ce90046,0x7bc3a4ca,0xcc1781aa}},	//   هاد_, _nyav_, pinu, _آذرب,
   {{0x2613c10b,0xdb1c02b0,0xb87b4031,0x66098051}},	//   _pão_, tirí, _ayík, _hiek,
   {{0xddc603e1,0x7c2d24cb,0x65c624a0,0x442d80bb}},	//   ебни, _awar, ебна, _hwe_,
   {{0x9984c1b4,0x8d7604cc,0x31794064,0xdb1c02b0}},	//   _للمو, راجا, _nasz_, rirí,
   {{0x798be4cc,0xb6060031,0x29040c28,0x6609a4cd}},	//   _ingw, _akáá, äma_, _miek,
   {{0x7d0d040d,0x27e14391,0x3cf54045,0x7bc564ce}},	//   _egas, john_, ्धने_, jihu,
   {{0x799d4820,0x6383010e,0x4422005c,0x69c440cb}},	//   _bosw, ыгра, spk_, tiie,
   {{0xed640066,0x6283c0e1,0xdb1ac01f,0x644d4032}},	//   _drží_, _irno, pitã, fuai,
   {{0x6d56091f,0x1786423d,0xf390c00c,0xdb1ad1a6}},	// [20a0] _icya, нгам, _mảnh_, litá,
   {{0x290d9357,0x7bc5400d,0x657bd255,0x32d6424e}},	//   _agea_, gihu, hduh, нцес,
   {{0xb1469807,0xe1f24280,0x645be4cf,0x7c3b884f}},	//   енел, _مسح_, htui, _avur,
   {{0xa2da8185,0xe8fa8ecc,0x76434107,0x6b9c40b1}},	//   _पुग्, пле_, ánya, _worg,
   {{0x7c22a4d0,0x61e64283,0x3ce90046,0xdb1e64d1}},	//   upor, _ikkl, _xyav_, lipí,
   {{0x798be4d2,0x442024d3,0x765ac051,0x7bcfc1cb}},	//   _angw, _mti_, ytty, écul,
   {{0x387240de,0x412a85a6,0x765c24d4,0x44200031}},	//   lwyr_, _ново_, ntry, _lti_,
   {{0x2c26c11b,0x7c24c2d6,0x657bc105,0x69c6000b}},	//   ньог, _çirk, gduh, jike,
   {{0xdb1e24d5,0xc7c6d5a4,0x387241f4,0xb8868347}},	//   _empé, есни, nwyr_, _blíž,
   {{0x61e0d0bb,0x65640449,0x798bc7f2,0x6d560f2d}},	//   soml, _abih, _engw, _acya,
   {{0xf363c59d,0x387241f4,0x3f8ca4d6,0x200a41c6}},	//   утын, hwyr_, _indu_, _mibi_,
   {{0x798bc0f8,0x645bc2a4,0xd6d7c39d,0xa1bac6b0}},	//   _gngw, btui, эты_, _عطاء_,
   {{0x65aa4047,0x69cf0206,0x29190107,0x777a8545}},	//   _výhl, rnce, rcsa_, _katx,
   {{0x61e2a4d7,0x2746c1c0,0x656401ae,0xf412802a}},	//   hool, _dínà_, _ebih, _হবার_,
   {{0x777aa4d8,0x0edb07f6,0xdce08017,0xc98700d9}},	//   _matx, _मुखड, _kamē, _зупи,
   {{0x6e3ad628,0xdb18873b,0xdb1c001f,0x6dab06df}},	//   mstb, livä, tirã, rƙas,
   {{0x7c2464d9,0x656d4498,0xd16401bc,0xad9b0559}},	// [20b0] gpir, reah, _същи, rmúd,
   {{0x442da4da,0x75f60185,0xa91da4db,0x61e664dc}},	//   _rwe_, ráze, _inži, _ekkl,
   {{0x6e3ac8cd,0x68070031,0xbcfb402e,0x9f45805e}},	//   nstb, _eéjì, _gbén, _ghlù_,
   {{0x27e14a12,0x442d822f,0x7bc18047,0x200a417b}},	//   sohn_, _pwe_, _smlu, _eibi_,
   {{0x3f9ea4dd,0x798d012c,0x75248019,0xdb188025}},	//   _botu_, _mnaw, ñiza, kivä,
   {{0x7ddd005f,0x69c2e4de,0x66098064,0xcb668b24}},	//   gész, _amoe, _wiek, ваше_,
   {{0xdb1c030d,0x9e35422b,0x5275800a,0x656f1dc7}},	//   nirá, _шевч, тулу, kech,
   {{0xceb8c064,0x442d800d,0x656f24df,0x645bc051}},	//   dzę_, _twe_, jech, ttui,
   {{0x21294df5,0x61ed4c05,0x7bc724e0,0x7c3b8a85}},	//   ibah_, ilal, kiju, _uvur,
   {{0x387fc085,0x2132005c,0x2129421b,0xb17b4ded}},	//   rvur_, _seyh_, hbah_, _skål,
   {{0xa91d80b3,0x38690119,0x657ba4e1,0x7bc724e2}},	//   _anži, _apar_, _kauh, diju,
   {{0x656f0230,0xf99f64e3,0x20120396,0x645be4e4}},	//   gech, _noè_, _puyi_, ptui,
   {{0x657b80f8,0x645d24e5,0xdbe481c0,0x2129404f}},	//   _mauh, gtsi, _béèy, dbah_,
   {{0xf8b6c0c3,0x764e1bdb,0x7bc724e6,0x765c24e7}},	//   _בפני_, tuby, giju, ttry,
   {{0xed5a64e8,0x7bc3c67f,0x6449e4e9,0xcf928087}},	//   мов_, _imnu, lrei, סטל_,
   {{0x765c0098,0xd00f00fb,0x273c4185,0xb602c10d}},	//   rtry, صلہ_, kání_, _þátt,
   {{0x7bc724ea,0x6e3c52bb,0x6449e4eb,0x628500fa}},	// [20c0] biju, _svrb, nrei, _erho,
   {{0x7c245376,0x69c40085,0xd9f44048,0xc610c0b2}},	//   rpir, _hmie, _आठवत_, _ठूँठ_,
   {{0xf1c609af,0x442fc046,0x2d9e4669,0x27e7c05c}},	//   _लगान, _lwg_, êtes_, _mknn_,
   {{0x248d441b,0x18a683d0,0x7c3be4ec,0xd00f0de9}},	//   _šeme_, каем, ksur, _دلی_,
   {{0xaca44044,0x777a80fc,0x7c3bc077,0x6e3c006f}},	//   _kpọt, _patx, jsur, lsrb,
   {{0x35c84027,0xa3b64185,0xbcfb488b,0x7c220138}},	//   _रगड़, _जति_, _mbél, _çoru,
   {{0x2b5864ed,0x69c424ee,0x6449e4ef,0xd04d00e2}},	//   _icrc_, _omie, erei, _fyaɗ,
   {{0xadf84064,0x2489c2bc,0x442264f0,0x61e44051}},	//   ंगटन_, _šama_, _ktk_, noil,
   {{0x7c3be4f1,0x4422405c,0xa3b64285,0xa80680b4}},	//   gsur, _jtk_, _जता_, _азал,
   {{0x25a00e94,0x645d0022,0xc6008094,0x6e008112}},	//   _aoil_, vtsi, _ịchọ, _ịchụ,
   {{0x2bafa2cf,0x61e4404c,0x42569086,0x61ed64f2}},	//   जघरा, koil, _штат, ylal,
   {{0x645d011b,0x75f88047,0x6e3ad19e,0x4426812c}},	//   ttsi, bíze, rstb, opo_,
   {{0x6449d7d9,0x10740768,0x200c80e2,0x98740589}},	//   crei, аляю, _kidi_, аляц,
   {{0x8f34e4f3,0xfe6fc08c,0x26174085,0x656664f4}},	//   _секц, حدی_, _bħol_, _abkh,
   {{0x2fcd00e0,0x533415f0,0x645d24f5,0x9f4300fd}},	//   đeg_, рест, stsi, lojë_,
   {{0xa01b4041,0x442fc24c,0x62814018,0x77b00041}},	//   _fröl, _ywg_, _áloi, _växa,
   {{0x50f55822,0x2618a4f6,0x6295c02d,0x7bc8c0d1}},	// [20d0] узат, _léo_, äzov, oidu,
   {{0x660d0303,0x200ca4f7,0x61db86c1,0x62850c81}},	//   _hiak, _nidi_, यक्ष, _trho,
   {{0x3958402d,0xdce400f6,0x7bc50024,0x62850dd1}},	//   _šesť_, _iniġ, _imhu, _urho,
   {{0xdb1ae4f8,0x2fc7a4f9,0x814581aa,0x9f4300fd}},	//   litä, wing_, انشن, kojë_,
   {{0x777c4057,0x657b8051,0x7c22e4fa,0xdb070041}},	//   _farx, _vauh, _ntor, shjä,
   {{0xdb07405f,0xdb1adec9,0x2fc7814b,0x9f43013b}},	//   _eljá, nitä, uing_, dojë_,
   {{0x6e958b92,0x2486e4fb,0xfc3f469a,0x442fc05e}},	//   العا, _arom_, _hví_, _swg_,
   {{0xec79cf99,0x273c4047,0x96f840b4,0x3ea78b5e}},	//   епи_, pání_, _рест_, rynt_,
   {{0x7c3be4fc,0x68ed09a1,0x2486d1f9,0xd01181aa}},	//   usur, _nyad, _crom_, _طلا_,
   {{0x7d1bd3d6,0x200c8083,0x6d42c23f,0xaca3c044}},	//   scus, _gidi_, _edoa, _ntụm,
   {{0x7c3be4fd,0x660bc010,0x61fba4fe,0xdb1c010d}},	//   ssur, _tigk, _khul, gnrý,
   {{0xdea380fb,0xaca3c094,0x6281c353,0x973c838f}},	//   _میڈی, _atụm, rvlo, _voće,
   {{0xf539c166,0x68ed0f2d,0x63a1a4ff,0x6281c75a}},	//   mať_, _cyad, _koln, svlo,
   {{0x69c14045,0x442259fd,0xdb0a90e8,0x200c2500}},	//   रोसी, _rtk_, rifö, ödi_,
   {{0x61e4404c,0x6146620f,0xb7dac2a6,0x27e5c041}},	//   toil, лева, _אקסי, moln_,
   {{0x777c4004,0xaca3c112,0x60db803a,0x68ed06df}},	//   _sarx, _njịk, _oxum, _fyad,
   {{0xfe0a00d1,0x6d4401a8,0x78a9e501,0x61e46502}},	// [20e0] _dắt_, _idia, nyev, roil,
   {{0xb17b1539,0xdb1e4018,0xf539c166,0x61fb81a8}},	//   blås, fipá, hať_, _ahul,
   {{0x5336c009,0xf539c166,0x9f4300fd,0xf53f44c9}},	//   רנען_, kať_, zojë_, _plåt_,
   {{0x200ca503,0x7bc8e504,0xf539c02d,0x2246402d}},	//   _sidi_, zidu, jať_, čok_,
   {{0x61fba505,0x07a69729,0x8fa6a506,0x200c809d}},	//   _dhul, ладн, ладе, _pidi_,
   {{0x61fb80eb,0x63a1a507,0x7bc8c912,0x657d44da}},	//   _ehul, _coln, xidu, _zash,
   {{0x61fb82d4,0x656280cb,0x2baa84ef,0xad9b450e}},	//   _fhul, pfoh, _कवठा, _viúv,
   {{0x2d805d24,0x9f4300fd,0x200c85b2,0x6738a508}},	//   ndie_, tojë_, _widi_, savj,
   {{0x6602a509,0x4432002c,0x21391021,0x00000000}},	//   mmok, _nwy_, vash_, --,
   {{0x4734c3a7,0x75f600a0,0x63a19297,0x98b7d045}},	//   шнос, váza, _goln, ульт_,
   {{0x213900fd,0xe81a8036,0x7c22c036,0x9f67c887}},	//   tash_, _फंडा_, _wtor, урыз_,
   {{0x7a150064,0x69c9c15d,0xe45f004c,0xa01b4041}},	//   _wątk, ciee, ttö_, _dröj,
   {{0x2bdba50a,0x62888089,0x5ff50119,0x8c43c1eb}},	//   _बदमा, _hrdo, изму, _гече,
   {{0x6d5641c8,0xa01b44c9,0x2139250b,0x69c642c0}},	//   egya, _fröj, sash_, _amke,
   {{0x6602976f,0xbcfb4031,0x163505f5,0x9f8b80b2}},	//   kmok, _gbéj, ребя, _töös_,
   {{0xb5a44007,0x2912017b,0xdb1ae50c,0xbebcc8c7}},	//   бруй, _ggya_, sitä, ecīg,
   {{0xfe0a00d1,0x66154545,0xb6c94107,0x48b6802a}},	// [20f0] _vắt_, _suzk, ھائے_, জপুর,
   {{0x2489250d,0x673ae50e,0xfc3f0032,0x7bc5250f}},	//   _iram_, natj, msí_, _umhu,
   {{0x569515f5,0xb87b446a,0x76b3c03a,0x63a18064}},	//   _тант, _oxíg, təyə, _roln,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc3f09a8,0x3cf30036,0xdb1c00b2,0xb4ad8171}},	//   nsí_, _घरों_, birä, _gẹ́g,
   {{0x644d468a,0x10380087,0x69ca8744,0x9f478066}},	//   mrai, נטום_, éfer, plní_,
   {{0xa91dc0b3,0x3f91400d,0x41b5cc21,0x644d4269}},	//   hdže, _inzu_, исит, lrai,
   {{0x13d200e6,0xe045c47f,0x629a0051,0x31b8c107}},	//   _सद्भ, ании, ätoi, _nézd_,
   {{0x984881bc,0x6446c039,0xdb18c4d3,0x80cb4285}},	//   _бяха_, škin, _omvä, _सेमे,
   {{0x0e65d109,0x25addd11,0x443201f4,0x386d85d4}},	//   акон, skel_, _rwy_, _iper_,
   {{0x24892510,0x28c7506a,0x69c9e511,0x42998301}},	//   _aram_, _रेसि, piee, _جناح_,
   {{0x38604397,0x91e6237b,0x2d9d9fa4,0x261845da}},	//   ytir_, роме, njwe_, _बंसी_,
   {{0x55768052,0x75291c00,0x27e5c04f,0x673ae512}},	//   בערן_, ñeza, poln_, batj,
   {{0x69cba513,0x753be514,0xdfd20032,0x973c8011}},	//   hige, lauz, زيز_, _koća,
   {{0x69cb99f1,0x6da64051,0x62854089,0x61e6114c}},	//   kige, аива, jvho, pokl,
   {{0xa926459d,0x6d5b804d,0xa5264026,0x7bcaa085}},	//   рдал, _ncua, рмад, zifu,
   {{0x69cba515,0x660f6516,0x7c29e517,0xb4254a10}},	// [2100] dige, _dick, nper, معلو,
   {{0x7c29d5b3,0xcb12c009,0x2f1c0031,0xe3b75a0b}},	//   iper, ַלד_, _dàgó_, абу_,
   {{0x386da518,0x63a3dc2d,0x644d424f,0x660f6519}},	//   _aper_, _monn, arai, _fick,
   {{0x69cba51a,0x442940f8,0xa01b0086,0x291280d9}},	//   gige, bpa_, kvöl, øya_,
   {{0xa2ca0314,0x2e3c4031,0xeb9a9c27,0x62888123}},	//   _हेत्, _báfá_, кид_, _srdo,
   {{0x98a48047,0x6602a51b,0x973ca51c,0x2fc7c0f8}},	//   _země_, smok, _boća, _nmng_,
   {{0x69d644fd,0x443fe51d,0x7c29ca26,0xa91d86f0}},	//   onye, esu_, eper, _bažd,
   {{0xef18803f,0x62888f26,0x2fc7c010,0x6d46405c}},	//   _daļa_, _vrdo, _amng_, _jdka,
   {{0x7c29e51e,0xb997c051,0x443fc0f8,0xbcfb1608}},	//   gper, рвых_, gsu_, gfél,
   {{0xed59c7ca,0x1fa6c0b4,0xdb18c4c9,0x6569a51f}},	//   dižu_, рриг, _omvå, _zbeh,
   {{0x443fe520,0xd378c5c7,0xd5afdffc,0x77b00041}},	//   asu_, noći_, _дс_, _växl,
   {{0x31c704ce,0x753be521,0xdb01c4c9,0x644d402c}},	//   рсов, cauz, dklä, yrai,
   {{0x798082cd,0x443fe21e,0xf7730032,0x54540025}},	//   _mamw, csu_, ياس_, овят,
   {{0x6442e522,0x261c034d,0x673c2523,0x65b144c9}},	//   _ivoi, _bío_, garj, _påho,
   {{0xb87b4107,0x660f6524,0xfb8400d7,0x69cba525}},	//   _nyír, _pick, цыян, yige,
   {{0x7980818b,0x4255c0fb,0xd5b857c2,0x69cb81c8}},	//   _namw, _انٹر, асу_, xige,
   {{0x752d6526,0x753d0096,0x7bc8809c,0x673c2527}},	// [2110] rbaz, masz, _omdu, barj,
   {{0xa91d8039,0x261c0ad6,0x69cba528,0x6440e529}},	//   _maže, _fío_, wige, ismi,
   {{0x644d473f,0x7c29d9c6,0x660f652a,0xdb0181aa}},	//   srai, zper, _tick, _golè,
   {{0x79829b85,0x48fe0185,0x2eb08d6c,0x3d1d402e}},	//   gdow, रेको_, जनैत, _dáwó_,
   {{0xe6cb810d,0x7980802c,0xbcfb41cb,0xe0d09546}},	//   _íbúð, _damw, _obéi, وزه_,
   {{0x69cd41f4,0x63a5252b,0x6a14001c,0x753d0107}},	//   liae, _john, _دبیر, hasz,
   {{0x3875406a,0x0bb800c3,0x69cb901c,0x7c29c0a8}},	//   şarı_, שלום_, pige, wper,
   {{0x27e783bc,0x673c252c,0x213940fd,0x6569a52d}},	//   sonn_, zarj, _jesh_, _ubeh,
   {{0x6440e52e,0x628ac1f4,0x7c29c0d2,0x753be52f}},	//   gsmi, _arfo, uper, rauz,
   {{0xaca34044,0x4426e530,0x67f0404c,0x3f81021b}},	//   _adịb, _dto_, täji, _nahu_,
   {{0x2d92005c,0xfe0a000c,0xdee5c65e,0x7980a531}},	//   _pnye_, _bắp_, сони, _yamw,
   {{0x213940fd,0xed572532,0x753d0107,0xfe0a000c}},	//   _nesh_, бою_, gasz, _cắp_,
   {{0x644fe533,0xa91d89fa,0x98a041be,0x3e618107}},	//   ácid, _gaže, mbić_, lót_,
   {{0xdca2c081,0x6b83813b,0x09d04048,0x61ed2534}},	//   _хаши, ndng, सच्य, _ekal,
   {{0xa91d9498,0x3f8106f0,0x24868166,0x644f2535}},	//   _zaže, _dahu_, zvom_, arci,
   {{0x3d28401c,0x3ea504c9,0x09e305f5,0x2ef8c414}},	//   شتری_, älta_, _нощн, ürfe_,
   {{0x673c1c6d,0x3ff64032,0xe1ff4032,0xdb01c851}},	// [2120] parj, مكرر, _dhó_, sklä,
   {{0x6ee100eb,0x7980942a,0x3f810f2d,0x2259c062}},	//   _ịbel, _samw, _gahu_, ńsku_,
   {{0x2bb9408f,0x0a4a4051,0xdd11c085,0x61e9c7e6}},	//   _इतरा, узей_, _ażżm, koel,
   {{0xddd4802d,0x9f584157,0xdb01888b,0xed16802a}},	//   ťaži, _cirò_, _golé, ার্স_,
   {{0x6f154011,0x20114e5b,0x75240f2d,0x2eb080a0}},	//   _fgzc, _fizi_, _mfiz, जन्त,
   {{0x69c98d0b,0x6fb64200,0x9f58c06a,0x25b26536}},	//   _emee, _امسا, örü_, lkyl_,
   {{0x9c870166,0x37cdc079,0x6b81a537,0x248680b3}},	//   _kočí, রকার, _dalg, svom_,
   {{0xb8ce8079,0xdb1e4c99,0x442b0053,0xfad740c3}},	//   _ওই_, sipä, ypc_, _הולך_,
   {{0x7bce2538,0x6b81a539,0xe0da86b1,0x753d0107}},	//   kibu, _falg, _сва_, vasz,
   {{0xc07b42a6,0xe7d6c079,0x4426c06f,0x673e4107}},	//   נטיש, হত্য, _vto_, napj,
   {{0x64440b34,0x96f8c156,0xc986c119,0x5186d0d2}},	//   _avii, рент_, _гули, _гула,
   {{0x3f810020,0xadfac16a,0x9f45c051,0x7522a53a}},	//   _sahu_, _صراط_, ellä_, ncoz,
   {{0x6442a53b,0x8b038047,0x3eae84c9,0xd4f6c16a}},	//   nsoi, ěřen, lyft_, _اثاث,
   {{0x7bce253c,0x38cbc4e8,0x69cd41f4,0x8233c05f}},	//   gibu, _حامی_, wiae, _کروا,
   {{0xdb01a53d,0xa91dc2bc,0x75f88166,0x9562009c}},	//   _polé, ldža, vízn, _imمn,
   {{0x201141df,0x2019653e,0x79844c47,0x7c2b8c32}},	//   _sizi_, _pusi_, gdiw, ypgr,
   {{0x656d1b82,0x6440253f,0x69cf2540,0xa814479a}},	// [2130] _ibah, ámit, mice, здуш,
   {{0xdb03c0b6,0x75d3c0b4,0x60c94043,0xd84f8112}},	//   _bonè, răzi, _žems, pọzi_,
   {{0xa6354176,0x20116541,0x78ad4954,0x973c8011}},	//   інді, _vizi_, syav, _poćn,
   {{0x44292542,0xb17b4125,0x2d82484f,0xad9b4359}},	//   _kta_, _sjåf, _gake_, _dhúc,
   {{0xa91dc79b,0x7ae483a6,0x6d59a543,0x8c45800a}},	//   jdža, şitl, rgwa, целе,
   {{0x3e61805f,0x661aa544,0x623541ff,0x32068340}},	//   tót_, _butk, _мегу, amoy_,
   {{0x6605d43c,0x82a4406f,0x4ea440b4,0x248955b8}},	//   опка, _еште, _ерта, lvam_,
   {{0x21f90089,0x63a75466,0x69cf2545,0x75228157}},	//   dého_, _hojn, jice, ccoz,
   {{0x61e9e546,0x6b81a547,0xa01b44c9,0xdfe901f9}},	//   roel, _talg, _eröv, ओवाद_,
   {{0x7524023f,0x61e4c41b,0x2cb28125,0x387f80b9}},	//   _sfiz, čila, øyde_, _isur_,
   {{0x9986c0b3,0xd6db90c2,0x61e9e548,0x69e7c0d7}},	//   žiše_, _ста_, poel, _людз,
   {{0x65bfc031,0x20130016,0x8c960589,0x1d0a047f}},	//   _dàhù, _aixi_, оргі, иени_,
   {{0x3e458017,0xdb03c01e,0xdb0544c9,0x30798052}},	//   lēt_, _moné, lkhä, באָנ,
   {{0x25b94010,0xab29e549,0x7c2d44aa,0xb9020047}},	//   _alsl_, _тока_, dpar, _दश_,
   {{0x6b83e54a,0x213b021b,0x7c2d42a0,0xd378d0ce}},	//   _iang, _feqh_, epar, goću_,
   {{0x6b83dca1,0x452a4ff8,0x6d498032,0x201b1923}},	//   _hang, ржан_, _ndea, _fuqi_,
   {{0x7c2d654b,0x61eba54c,0x7bce0398,0x77ca423d}},	// [2140] gpar, dogl, pibu, алаг_,
   {{0x7984254d,0x7c24c1b4,0xe81d8a3c,0xdb0e654e}},	//   _haiw, _éire, _पढ़ा_, _albá,
   {{0x65b5c194,0xe5a644d5,0x387fa54f,0x61eba550}},	//   _náho, _дини, _asur_, fogl,
   {{0x673a8ae6,0x2d82404d,0x3e458017,0x3ea74041}},	//   _setj, _uake_, dēt_, änta_,
   {{0x7c2d405e,0x661aa551,0x6d5bc498,0x7a4041c0}},	//   cpar, _sutk, dgua, _bátá,
   {{0x1c398289,0xe79386b1,0x69cbc15a,0x6d4fd981}},	//   сяць_, дишњ, _amge, ócan,
   {{0x442dcb45,0xdb03e3e5,0x673aa552,0x0ef940d7}},	//   epe_, _foné, _vetj, _гэты_,
   {{0x746ad000,0x298acdfc,0x673c6553,0xed57907a}},	//   аров_, рско_, _herj, _мос_,
   {{0x44204080,0x2d82c02d,0x656d017a,0x7c294b39}},	//   nqi_, ľke_, _rbah, _çert,
   {{0x21f90531,0x628e4066,0x270ec03a,0x2d82ceae}},	//   tého_, _krbo, tən_, žke_,
   {{0x3e45803f,0xa2ca2247,0x656d0010,0x261a009d}},	//   cēt_, _हेल्, _pbah, _मूली_,
   {{0x661c6554,0x2d8489b8,0x2d86a555,0x186acacf}},	//   _murk, _jame_, ndoe_, _вади_,
   {{0x28c5022d,0x395f0017,0x65b5c512,0xf9d9c009}},	//   _लेखि, ļus_, _záho, _פֿעל,
   {{0x9f5a03bc,0x7bcac0f7,0x3866a556,0xcb67c6b1}},	//   _sipò_, _umfu, itor_, _даље_,
   {{0x661c6557,0x3940402c,0x69cbc1f4,0x67efc0b0}},	//   _nurk, fais_, _ymge, røjt,
   {{0x65b5c347,0x44206558,0xd378c036,0x65944030}},	//   _náhl, fqi_, leć_, масу,
   {{0x31694815,0x1af18079,0x545541bc,0xf1bf0032}},	// [2150] rfaz_, _চলছে_, яват, mhá_,
   {{0x6602c07a,0x7bdac10d,0x249d823b,0x24896559}},	//   _lhok, nntu, vxwm_, rvam_,
   {{0x6444655a,0xdb03c34d,0x798410ea,0x6746002d}},	//   asii, _poné, _yaiw, šujú,
   {{0x661c655b,0x248d84e2,0x127a0009,0x05b940fb}},	//   _durk, _prem_, _פארע, _اگست_,
   {{0x628e655c,0x76438033,0xf41f0041,0x673c655d}},	//   _erbo, wsny, kväm_, _ferj,
   {{0xd378c043,0x6602e55e,0x7643a55f,0x61ed61c8}},	//   jeć_, _ahok, tsny, loal,
   {{0x05778e5f,0x6298001e,0x8d77849f,0x5f748032}},	//   _وارد, _àvot, _وارا, ظاهر,
   {{0x4439424c,0x7bdae560,0x3e45803f,0x442b5a28}},	//   _kws_, entu, rēt_, _ktc_,
   {{0x7643a561,0x31790107,0x6602c01c,0x387f809c}},	//   ssny, desz_, _dhok, _usur_,
   {{0x69cd002c,0x79840020,0x61ed4140,0x3e458017}},	//   _amae, _saiw, hoal, pēt_,
   {{0x9ee98a10,0x4420618a,0x38722562,0x6d40e563}},	//   _افضل_, zqi_, _spyr_, bama,
   {{0x64444057,0x2c64197d,0x39404046,0x67efc0b0}},	//   ysii, töd_, xais_, tøjs,
   {{0x7bdac046,0x320945d1,0xdce98043,0xd378c011}},	//   bntu, dmay_, _obeč, beć_,
   {{0x6b83e564,0x78a9009d,0x35d1c027,0x1c1f409d}},	//   _uang, äeva, _तगड़, _बढ़ल_,
   {{0x656f4020,0xa3b8c3a9,0x7aeec089,0x59bd8045}},	//   _bbch, _ظاهر_, čité, ्फार,
   {{0x9c264445,0x644462ee,0xd5b9003f,0x61ed40fc}},	//   здад, tsii, spār_, goal,
   {{0x60000d88,0x753d6565,0x43764051,0x90460032}},	// [2160] römb, _desz, зует, _عنده,
   {{0x39422566,0x661c53fa,0xb4b82567,0x7f41c0cb}},	//   laks_, _purk, चनी_, nalq,
   {{0x39406568,0x64445845,0x6609e569,0x68120047}},	//   pais_, ssii, kmek, _vědě,
   {{0x80cd84ef,0xa91d8007,0x9f4a0066,0x4439457f}},	//   _देहे, _paža, dobé_, _fws_,
   {{0x6609c0b2,0xbd43801c,0x9f4581af,0xc18d0052}},	//   dmek, رنوي, _sklá_, יטאָ,
   {{0x661e0013,0x6d40e56a,0x68f60051,0x60c28360}},	//   _kupk, wama, _myyd, rzom,
   {{0x66040232,0x3f858923,0x629a4570,0xa01b4851}},	//   _ohik, _dalu_, _štof, _frös,
   {{0x3942054a,0xdef985dd,0x4439423b,0x6edb40c3}},	//   jaks_, цыі_, _yws_, _החלפ,
   {{0x4439424c,0x6f028031,0x442b4206,0x3942009d}},	//   _xws_, _bíbí, _xtc_, daks_,
   {{0xbcfb01cb,0x6446256b,0x9f45c56e,0x7bdae56c}},	//   ngée, dski, bolí_, untu,
   {{0xd378c043,0x3942256d,0x6602e56e,0x25a90060}},	//   reć_, faks_, _thok, _poal_,
   {{0x7bce403c,0xba9b80c3,0x629a401e,0x4efb82a6}},	//   _lmbu, _לסבי, _àtou, _פלאג,
   {{0xbcfb656f,0x753d5243,0x5c071129,0x6f028f84}},	//   _océa, _resz, зява, _fíbí,
   {{0x9178c02e,0xe8d940eb,0x75fd056e,0x7538c062}},	//   _fẹ́_, ndụ_, cézn, ńczą,
   {{0x2cb30047,0xad9b4359,0x64598230,0x64462570}},	//   _řadě_, _dhún, zuwi, aski,
   {{0x60c440cb,0x320949c7,0xdcee0112,0x3ea18025}},	//   fzim, umay_, ọrọl_, ähti_,
   {{0x44396571,0x765ac523,0x321e8036,0x2d86c396}},	// [2170] _qws_, luty, _luty_, _maoe_,
   {{0x3f984024,0x5ba701bb,0x9cd80d89,0x14d80d89}},	//   _cnru_, _хриз, _מוחה_, _מוחל_,
   {{0x27e4002d,0xfe240025,0x3d0f8048,0x60c4428d}},	//   émne_, _пьян, तेने_, azim,
   {{0x3135a532,0x442b4669,0x44394046,0x35b58be0}},	//   федр, _ttc_, _tws_, ьбер,
   {{0x81b000e2,0x29d2041b,0xa2d9417e,0xdb18c107}},	//   _jiɓa, kšan_, _मशक्, _elvé,
   {{0x9f47c166,0x321e8064,0x9f45c016,0x6002401e}},	//   _okná_, _buty_, tolí_, tôme,
   {{0x25bfe572,0x3f878199,0xbcfb4171,0x201dc231}},	//   thul_, rdnu_, _gbér, _suwi_,
   {{0x75fd0018,0x6d5f400b,0x3eae40cb,0x656d40cb}},	//   dézo, ngqa, äfte_, nfah,
   {{0x3f85a573,0x3942054a,0x6b87497c,0x4439cc2b}},	//   _talu_, vaks_, _kajg, ès_,
   {{0x69c0c2bc,0x321e809c,0x6562c43e,0x6d4d0d31}},	//   ahme, _futy_, _ecoh, _adaa,
   {{0x38696574,0x656d6156,0x8eb585d3,0x7f43a575}},	//   htar_, kfah, _تماش, manq,
   {{0x7c3b8efc,0xb1134112,0xdb1a8141,0x7a1c0570}},	//   _kwur, _mụba, _altè, _učti,
   {{0x777ac0fc,0x6d4d01ae,0x656d40cb,0x76550036}},	//   betx, _ddaa, dfah, erzy,
   {{0x6d4d0258,0xb17b4621,0xf53f0c9f,0x442da576}},	//   _edaa, _skåp, skåp_, _mte_,
   {{0x660400fd,0xe2f8005f,0x7bdc04c9,0xdb1e413b}},	//   _thik, سورڈ_, rnru, shpë,
   {{0x60db491c,0x7989e577,0x442da578,0x3f87e579}},	//   _žuma, ndew, _ote_, _hanu_,
   {{0x442d9724,0x3a2d4b22,0x600486ed,0x61e1430d}},	// [2180] _nte_, _čepa_, lòme, élla,
   {{0x7bc1e57a,0x6722046d,0x7a154036,0x657bc1ff}},	//   nhlu, _मलिक_, _wątp, heuh,
   {{0xe1f9c039,0x64498fc2,0x7c3b8171,0xf8bf064c}},	//   klų_, _avei, _awur, ncén_,
   {{0x3869657b,0x6043825d,0x02de4e47,0xd91042cf}},	//   btar_, _ọmar, _मशीन, _میز_,
   {{0xcb2205da,0x442d9021,0xa91d8224,0x397b40c3}},	//   _मलाड_, _cte_, _tažn, _וטכנ,
   {{0x6b8740b3,0x7bce40f7,0x4432645d,0xdce0c017}},	//   _gajg, _umbu, mpy_, zemē,
   {{0xe2978217,0x2e4a80c5,0xf6234768,0x7529840d}},	//   дај_, цяло_, _адсо, _ffez,
   {{0xbbbb06c1,0xd130c1b4,0x201840fc,0x248d4570}},	//   _उत्क, دمة_, _hiri_, _šemi_,
   {{0xdb0882cb,0x7c3b80eb,0x777ac0fc,0x9f5e8053}},	//   _modé, _gwur, tetx, _ditò_,
   {{0x765ae57c,0x7d1b80ab,0xa09b4052,0xa91d87ef}},	//   tuty, _zgus, קייט, _lažl,
   {{0x777ac232,0xa3c20374,0xbbd784e0,0xc7574323}},	//   retx, ंसन_, _קובץ_, וייץ_,
   {{0xadc3800c,0xa194011e,0x7c20a57d,0x8d93c032}},	//   _miến, ваюч, _kumr, _للمش,
   {{0x7bc1c046,0x777ac0fc,0x4fc6d4de,0x2ab4c031}},	//   bhlu, petx, _оска, _búbú_,
   {{0x4420257e,0x201850b6,0x3944d09c,0x3f87e57f}},	//   _dui_, _niri_, lams_, _ganu_,
   {{0x61e2c36b,0xdb01805b,0x7c20a580,0x29024033}},	//   _kjol, _kolá, _lumr, _azka_,
   {{0x39156581,0x6627c5e5,0x600004c9,0x3f87e582}},	//   ембр, žské, röma, _zanu_,
   {{0xdbd6804c,0x28f8404c,0x38694dde,0x44202583}},	// [2190] _kään, деть_, utar_, _gui_,
   {{0x657d2584,0xa2ca05a3,0x69c28078,0x63a54022}},	//   lesh, _हेक्, ehoe, ujhn,
   {{0x3944d2ae,0x7bd52585,0x61e2c070,0x2d890011}},	//   kams_, mizu, _ojol, _kaae_,
   {{0x657d2586,0xdbd6854a,0x29d74283,0x6d40a587}},	//   nesh, _lään, għat_, _cema,
   {{0x6d4f4f9c,0xe4e7411b,0x7f43a588,0x7c20a589}},	//   _idca, _цінн, tanq, _cumr,
   {{0x6d40854a,0x2018658a,0xf789c01f,0xe73040b8}},	//   _eema, _giri_, _maçã_, _نصف_,
   {{0xdb03cfc5,0x6d4080c3,0x7bddc1cb,0x2215c0b4}},	//   _poní, _fema, ésum, нфир,
   {{0xceb24093,0x3206c303,0x3f87c570,0xdb01a58b}},	//   _גיל_, _choy_, _sanu_, _colá,
   {{0x395fe58c,0x645d258d,0x3219658e,0x442da58f}},	//   rgus_, jusi, _misy_, _ute_,
   {{0x6b88a590,0x09dc4919,0x6560c1b4,0x248dcc9e}},	//   _gadg, _यद्य, agmh, rvem_,
   {{0x7c2080b3,0x6d40a591,0x25ad80bf,0x05d38021}},	//   _zumr, _yema, _koel_, _दगाब,
   {{0xcb1244e0,0x7c208189,0xb34581ff,0x6da60654}},	//   טלי_, _yumr, baçã, хима,
   {{0x6285000d,0x61fbc3a6,0x291dccc0,0x26c5e592}},	//   _asho, mlul, _igwa_, szlo_,
   {{0x437505a6,0xa3ab0028,0xf1bf5a6d,0x32194303}},	//   куст, कॉल_, _alá_, _aisy_,
   {{0x20186593,0x63738bde,0xdce41b1a,0x657d060d}},	//   _riri_, mını, _obić, besh,
   {{0x657d2594,0x3eb8d27d,0x25ad818a,0x64a64097}},	//   cesh, ørte_, _noel_, наба,
   {{0x98bfc011,0xdbdb0171,0x2f566595,0x98b900cc}},	// [21a0] kauč_, _fààn, етес, rasă_,
   {{0xb4e04048,0xaca440eb,0x7bc386ea,0x43864ce1}},	//   _तशी_, _nrụt, jhnu, علاق,
   {{0xd9464640,0x25ad80a8,0x7c20a596,0x9d4643fe}},	//   _пени, _boel_, _sumr, _пенд,
   {{0x6846830f,0x394081b4,0xaca440eb,0x186a8910}},	//   енда, úis_, _arụt, зади_,
   {{0x61fbc339,0x69d66597,0x6285013c,0x3944c007}},	//   dlul, miye, _zsho, vams_,
   {{0xdb01a598,0x7bc395a5,0xead4a599,0xb345801b}},	//   _solá, ghnu, коль, vaçã,
   {{0x3942413f,0xbcfb0669,0x6373838a,0x442fc3ad}},	//   _keks_, nfér, dını, _atg_,
   {{0x61fbe59a,0x69d6659b,0x4422659c,0x442fc05c}},	//   glul, niye, _kuk_, _btg_,
   {{0xdb018443,0x3946801c,0xe9df0166,0xdb0751fc}},	//   _volá, maos_, vnú_, _fljó,
   {{0x660d403f,0xafdb011b,0xe1fb0707,0x4f84805f}},	//   zmak, rsøk, ृष्ण_, _جارہ,
   {{0x7bd523c0,0x6e218b68,0x69d6659d,0x9696859d}},	//   vizu, _gulb, kiye, _яраш,
   {{0x69d64057,0x3f8a659e,0x98bf4158,0x92c28189}},	//   jiye, _labu_, _žuč_, ışın,
   {{0xecd04045,0x98b800c5,0x2e46c031,0x657d259f}},	//   _सेलफ, елят_, _bífá_, resh,
   {{0x63738530,0xdced04f9,0x5ea64079,0x7ae480b4}},	//   cını, _ubač, _গেছে, şitu,
   {{0x7bd525a0,0x69d665a1,0xdb0700d9,0x2e46c171}},	//   rizu, fiye, nkjø, _dífá_,
   {{0x645d25a2,0x98ad47ca,0x69d665a3,0x4efbc0c3}},	//   pusi, _žeđ_, giye, _מהוו,
   {{0x63ae40e5,0xa01b0fd0,0x6d4fc359,0x6b8ac14d}},	// [21b0] _bobn, rvös, ócai, _kafg,
   {{0x660d65a4,0x61fd10e8,0x973c8011,0xa8a441dc}},	//   smak, llsl, _koću, ырск,
   {{0x320900d1,0x25ad81b0,0x2a784024,0x88d4c02a}},	//   _khay_, _poel_, _cprb_, _হুমক,
   {{0x248d441b,0x201a25a5,0x644d0007,0x39424127}},	//   _šemu_, _zipi_, _kvai, _geks_,
   {{0x44224232,0x316f8018,0x69c0805e,0x50b30288}},	//   _guk_, rfgz_, _dlme, ुनिष,
   {{0x79898303,0x25a965a6,0x6e21a5a7,0x798d414d}},	//   _waew, ljal_, _pulb, ldaw,
   {{0xf991c032,0x44268149,0x7bc387cb,0xdb074224}},	//   لبة_, aqo_, rhnu, _kojí,
   {{0x442249ee,0xc6940087,0x63ae406c,0x644d25a8}},	//   _yuk_, ראק_, _zobn, _ovai,
   {{0x7529c23f,0x3f8a4112,0x22408077,0x798d4360}},	//   rcez, _yabu_, ćika_, idaw,
   {{0x7c22c17b,0x443f8efc,0x32090057,0x6e21a5a9}},	//   _duor, _iwu_, _ahay_, _tulb,
   {{0xeadc0879,0xd709c04c,0xdee5cb73,0x66e5cf37}},	//   _ধর্ম, ьное_, тони, тона,
   {{0x320925aa,0x645f40f7,0x3eba80d9,0x2b47a5ab}},	//   _chay_, kuqi, øpte_, lanc_,
   {{0x850c12c2,0x4c8325ac,0xa91dc4d6,0x69d6406a}},	//   सेंट_, аляв, jdži, viye,
   {{0x2b47a5ad,0x23bd01c0,0x0904d8d5,0x644d0147}},	//   nanc_, _dìjo_, _спін, _dvai,
   {{0x386dd2b4,0xdb01a5ae,0x69d665af,0xbb4325b0}},	//   lter_, _dolç, tiye, реск,
   {{0x60d6c007,0xdc1400b5,0xc174409c,0x645f413b}},	//   _žymi, rşıy, kiɗe_, fuqi,
   {{0x798be5b1,0x68fba5b2,0x63ae4022,0x443fa5b3}},	// [21c0] _magw, _nyud, _pobn, _nwu_,
   {{0x6e23c09c,0x644b80d9,0x61e4c795,0x799d40bc}},	//   _kunb, dsgi, čili, _ensw,
   {{0x20028039,0xdb03c05f,0x75f6030d,0x6e23c09c}},	//   _ūkio_, _elnö, lázq, _junb,
   {{0x0696c009,0xf2d300c3,0xe2970da4,0x68fb8329}},	//   כדעם_, _כעת_, _раю_, _byud,
   {{0x656280fd,0xa3c906ff,0x6d44001f,0x66098396}},	//   rgoh, लोक_, _meia, _dhek,
   {{0x6d4425b4,0x7c240510,0x66098cd1,0x44320070}},	//   _leia, _muir, _ehek, _mty_,
   {{0x29d2013f,0xe1268aba,0xd1b284e8,0x69269483}},	//   ršaj_, _амби, _پیشک, _амба,
   {{0x68ed40fd,0xdb0700d9,0x7bc1a5b5,0x236d0077}},	//   _ëndë, rkjø, _ellu, đeji_,
   {{0x798bc71c,0xa91dd7ff,0x443f817a,0xdb070125}},	//   _dagw, dežd, _gwu_, skjø,
   {{0x61e2a5b6,0x4424a5b7,0xb112c0eb,0xdb070125}},	//   lnol, _ium_, tụbe, pkjø,
   {{0x386de4a5,0x1f5b421d,0xe3afc20c,0x6e23c5ef}},	//   ater_, ודיא, تري_, _cunb,
   {{0x39448044,0x3f8ca5b8,0x9f5f0018,0xa5dacd9e}},	//   _jems_, _hadu_, _árúa_, _غبار_,
   {{0x4432000c,0xdb18809d,0x6ce70176,0x7980cdc0}},	//   _cty_, rivõ, тіне, memw,
   {{0x61e6417a,0xbcfb0070,0x6e23e5b9,0x7c24073f}},	//   _ajkl, bgén, _funb, _duir,
   {{0xf1b992b8,0xb4db4031,0xdb0e40fd,0x6e23e5ba}},	//   _hiše_, _adàp, _dobë, _gunb,
   {{0x3ce9004d,0x200a4085,0x61e2a1c5,0xb4db405e}},	//   _txav_, _ahbi_, jnol, _deàn,
   {{0x9f4cc574,0x34950039,0xdb050107,0x798d65bb}},	// [21d0] hodí_, _сапр, _dohá, rdaw,
   {{0xa283078a,0x65644010,0xad9b4032,0x61e28018}},	//   _پیرو, agih, _mhúi, enol,
   {{0x7e28513b,0x7bd88089,0x98144032,0x7bc7159a}},	//   віча_, divu, شبكا, mhju,
   {{0x68fb802f,0xdb0380cb,0xa91d92cc,0x6297017a}},	//   _pyud, rknü, _kaži, _irxo,
   {{0x387944a7,0x394965bc,0x6adb8891,0x6288802f}},	//   _upsr_, maas_, यप्र, _asdo,
   {{0x66e5859d,0x644d65bd,0x7afc5127,0x798bc7b6}},	//   лола, msai, _fyrt, _sagw,
   {{0x3f8ca5be,0x798be16b,0x661b8051,0x80cbc384}},	//   _dadu_, _pagw, _tiuk, _तेजे,
   {{0x394965bf,0x443fa5c0,0x3f8140b3,0xdb050004}},	//   naas_, _twu_, lehu_, _xohá,
   {{0x7bd8a5c1,0xa91dc514,0xf367883a,0x442965c2}},	//   bivu, ježe, _атен, nqa_,
   {{0x1db9808f,0x39494057,0xa91dc06c,0xdaa9c9d3}},	//   _आवडत, haas_, deže, евод_,
   {{0x216a25c3,0x2bb884e3,0x201cc017,0x394965c4}},	//   нини_, _अवता, _divi_, kaas_,
   {{0x60000041,0xbf0f809d,0x69c2ca26,0x386de5c5}},	//   römm, ाधीन_, _gloe, pter_,
   {{0xa01b405f,0x4424000c,0xe3b3c01c,0x6d4425c6}},	//   _csök, êm_, _پرش_, _veia,
   {{0x6e23e5c7,0x4852c107,0x7bc725c8,0x3eb81020}},	//   _tunb, _اپوز, ghju, tyrt_,
   {{0x69d9a5c9,0xe2a8c1b4,0xe299c4ce,0x2d84001e}},	//   kiwe, _لاين_, _чай_, ômes_,
   {{0xf2d28009,0x3b07001b,0xc4861828,0x443225ca}},	//   צען_, ѓето_, _блик, _tty_,
   {{0x2d8225cb,0x6721804f,0x64a3546b,0x2d8065cc}},	// [21e0] meke_, _oglj, бата, reie_,
   {{0x65698033,0x728a01bd,0x386057d9,0x798d2307}},	//   _aceh, _због_, ruir_, _zaaw,
   {{0x645bc032,0xdb1ae0ef,0xee3a5109,0x7980c40b}},	//   hrui, sitö, хне_, yemw,
   {{0x645bc353,0xdb1c25cd,0x4424a5ce,0x14d5408f}},	//   krui, chrá, _pum_, _ठेवण,
   {{0x61e2a5cf,0x38604580,0xdb0887cb,0x764e25d0}},	//   rnol, quir_, _vodí, lsby,
   {{0x645be5d1,0xbe8a8393,0xdb03e424,0xa634811b}},	//   drui, есие_, _gonç, анкі,
   {{0xdb1e13af,0x7bd8a5d2,0x61e465d3,0x66844973}},	//   _impó, rivu, onil, _خیال,
   {{0x9054c00e,0x6d4665d4,0x69d9a5d5,0x7c2665d6}},	//   авиц, _jeka, ciwe, _kukr,
   {{0x7980c1c6,0x645bcfd7,0x136ac0c5,0x6b8e4bc9}},	//   remw, grui, ншни_, _kabg,
   {{0x4274e5d7,0x6b81e5d8,0x3f9ea5d9,0x7980c12c}},	//   агос, gelg, _untu_, semw,
   {{0x61e465da,0x61f64105,0x7e61c02f,0x75fec13b}},	//   knil, koyl, gulp, hëzi,
   {{0x0ecf00b2,0x316699c6,0x764e159a,0x394941c8}},	//   _हेगड, ngoz_, dsby, xaas_,
   {{0xdb074070,0x7c26595d,0x6fb88048,0x2906c112}},	//   _mojá, _nukr, _अवां, _uzoa_,
   {{0x798d0057,0x5334cf99,0xdb18c107,0x661d65db}},	//   _waaw, _тект, _elvá, _sisk,
   {{0xa91d8039,0x201ea5dc,0x7bc71127,0xa91dc618}},	//   _važi, _miti_, rhju, reže,
   {{0xb0c48e31,0xa8a70b8e,0x628ac0f1,0x644d65dd}},	//   वनाग, _брок, _isfo, tsai,
   {{0x752d65de,0x03d54f6d,0x4426e5df,0x629ec018}},	// [21f0] rcaz, ажаю, _juo_, _ápob,
   {{0xa7fb0004,0x7c264007,0xf36700cc,0x752d4070}},	//   buña, _dukr, _стин, scaz,
   {{0x3f83006f,0xe3bf430d,0x4426e5e0,0x7afdc047}},	//   meju_, _cuña_, _luo_, řstv,
   {{0x893781b4,0x6d4665e1,0xa11981b4,0x7522dc50}},	//   اعضا, _geka, نقاط_, _ngoz,
   {{0x442965e2,0x69d989dc,0xb7b58112,0x629a4004}},	//   qqa_, riwe, _dịn, _áton,
   {{0x7bdae5e3,0xd246c0b8,0x69d9a5e4,0x7bd565e5}},	//   jitu, _ون_, siwe, _umzu,
   {{0x79828004,0x6b81cf37,0x200c8230,0xc2934231}},	//   beow, velg, _dhdi_, _دیاب,
   {{0x6442c17b,0xa91dc077,0x6b8e409c,0x6b81c0f8}},	//   _bwoi, vežb, _zabg, welg,
   {{0x61fb9c50,0x6b81e5e6,0x201ea5e7,0x7bdae5e8}},	//   _ikul, telg, _fiti_, fitu,
   {{0x645be5e9,0x61e984f5,0x249940c9,0x201e800d}},	//   rrui, _hjel, _mrsm_, _giti_,
   {{0x3946d84b,0xd5b994f7,0x645be5ea,0x8d77c183}},	//   _feos_, _आवाज, srui, _ماشا,
   {{0x6e27405c,0xa91dc04f,0xf99f488b,0xc17440e2}},	//   _mujb, režb, _dhèk_, kiɗa_,
   {{0x03a5dee9,0xdb088032,0x61fb8150,0xaca3c0eb}},	//   _вило, _iodá, _mkul, _mmịk,
   {{0x61e98077,0x09de4048,0x2d8fd2e2,0xa7fb0004}},	//   _ljel, नच्य, _hage_, tuña,
   {{0x6723d8ca,0x28d9c275,0x753d0107,0x78a9c2e3}},	//   _ignj, _बेति, bbsz, lxev,
   {{0x09e3123a,0x69c425eb,0x3946c018,0x69c9c1b0}},	//   _мощн, _ulie, _xeos_, nhee,
   {{0x0b4665ec,0x9346502d,0xab2a56ea,0xdb018359}},	// [2200] инан, инае, воза_, _colú,
   {{0xe29a4951,0xaca3c0eb,0x80a684fc,0xe3bf4004}},	//   каз_, _amịk, یمان, _puña_,
   {{0x06865bb2,0x27f80c32,0xae1f4027,0x7f47417a}},	//   рген, morn_, _मंचन_, _dejq,
   {{0xea76c81b,0x7bdae5ed,0x7bc8c0fd,0xd378c41b}},	//   יגער_, zitu, zhdu, miće_,
   {{0x24994010,0x7bdad9f1,0xdd8f820c,0x69dbc0fd}},	//   _grsm_, yitu, بون_, diue,
   {{0x3ce0c618,0xdb0ac2b0,0xdfcf854c,0xdb1a8c1e}},	//   _živo_, _sofí, وين_, _altá,
   {{0x201ea5ee,0xd378ca18,0x61e98761,0xdb074107}},	//   _viti_, niće_, _fjel, _tojá,
   {{0xa3d3ca3c,0x3f8325ef,0xd910849b,0xdd97c119}},	//   सोस_, zeju_, _فیض_, ашь_,
   {{0x29000022,0x27f81ef0,0x2d99830d,0x6e20a5f0}},	//   _nyia_, korn_, _ósea_, _iimb,
   {{0x6fc4c061,0x660d1af2,0x7bdc25f1,0xd378c011}},	//   _bòca, _shak, jiru, kiće_,
   {{0x660d0339,0x60cd65f2,0x3f830007,0xf1bf180a}},	//   _phak, zzam, veju_, tká_,
   {{0xdebb91bf,0xf1b98aa2,0xd378c351,0x6442c064}},	//   _שמאל, _kiša_, diće_, _twoi,
   {{0x7bc5023b,0xdddc95c5,0x44390093,0x6c34c01c}},	//   _plhu, _aprū, ups_, _افتا,
   {{0x6d56088b,0x7bdac0fd,0xdcfbc0b5,0x7bdc25f3}},	//   _edya, qitu, lduğ, giru,
   {{0xe0e8c079,0xdb01a5f4,0x1959410e,0x6602a5f5}},	//   _পরিভ, _solú, лавы_, klok,
   {{0x6d4ba5f6,0x660d04fd,0x75e80189,0x59d40032}},	//   xaga, _uhak, nızl, _وغير,
   {{0x91fd003f,0x26e28036,0xdb5b0051,0xb1134044}},	// [2210] stās, गपुर_, _июн_, _tụma,
   {{0x61e984ec,0x6671c1aa,0x69c665f7,0xa3b7408f}},	//   _sjel, _بگیر, _elke, _जवळ_,
   {{0x3ed945dc,0x6602810d,0x60cd4064,0xdb03c041}},	//   دواج_, flok, szam, _tonå,
   {{0x69c9c046,0x78a24089,0x6602a5f8,0x225e002d}},	//   xhee, ťova, glok, átke_,
   {{0x39491440,0x7f474022,0x18218578,0xa8794009}},	//   _meas_, _tejq, मदेव_, _גאָר,
   {{0x629a8011,0x6e2883ad,0xd6c6c3a9,0x60000051}},	//   _brto, _budb, _فق_, tömi,
   {{0x61e98539,0x442925f9,0xdb08805b,0x69c9c1d4}},	//   _tjel, _lua_, _podá, thee,
   {{0x4998c04c,0x442900b4,0x2d84ca85,0x61e9804f}},	//   атья_, _oua_, geme_, _ujel,
   {{0x657ba5fa,0xdb088066,0x386084ff,0x7dc60032}},	//   _ibuh, _vodá, àirt_, _nósa,
   {{0x78bd0051,0xd6db9822,0x7e6381aa,0x68e48032}},	//   dysv, _ите_, punp, úide,
   {{0x6e28a505,0xb1134044,0x3f9165fb,0xe61a06e4}},	//   _gudb, _bụka, _mazu_, лдо_,
   {{0x5184c523,0x39490119,0xc984c5ac,0xd543c031}},	//   _муча, _ceas_, _мучи, _dẹ̀d,
   {{0x34abc032,0x7bdc0c3f,0xe3bf4019,0x69a4c926}},	//   _جداً_, tiru, _nuño_, कारी,
   {{0x6723c2a3,0x6d4980b6,0x6569cd5b,0x30da8009}},	//   _ugnj, _leea, lgeh, אַלע,
   {{0x4e35ca1d,0x63bccd4d,0x394900e1,0x9695001f}},	//   _اعتز, örne, _feas_, ортш,
   {{0x7ae10a2c,0x3e71c107,0x248d8eae,0x3eb8c0cb}},	//   últa, mát_, _osem_, ärte_,
   {{0x44210283,0x10a342d3,0xe3bf4019,0xf992c916}},	// [2220] _fih_, питн, _cuño_, הרן_,
   {{0xd8d70009,0x79860a06,0x387245b0,0xd7641006}},	//   _לופט_, lekw, rtyr_, _بندی,
   {{0x7e6540c9,0x69d9e5fc,0x248da5fd,0x6e20817b}},	//   guhp, _omwe, _asem_, _pimb,
   {{0xf0d2825d,0x798600c2,0x6e288402,0x6569c0a8}},	//   bịlọ, nekw, _rudb, jgeh,
   {{0x6ba5010d,0x3e71c05f,0x2d9225fe,0xdcf6180a}},	//   _útgá, hát_, _maye_, _obyč,
   {{0xf1b980e0,0x3e71c804,0x232741ce,0x69dd00f7}},	//   _viša_, kát_, _гори_, zise,
   {{0xc3330093,0xa91de5ff,0x6f0181f4,0x248da600}},	//   לוג_, veža, _cylc, _esem_,
   {{0x6569cf64,0x9f64c018,0xadc380d1,0x629c6601}},	//   ggeh, _átúa_, _thạn, _irro,
   {{0x39490b61,0x7c3bd17e,0x3f91409c,0x644d8077}},	//   _reas_, gpur, _yazu_, šair,
   {{0xa4b74093,0x2d84e602,0x660463a0,0xd62a9654}},	//   צליה_, seme_, hlik, _боже_,
   {{0x7c2980fa,0x2003110f,0xa91dc7ca,0x39492603}},	//   _zuer, vlji_, reža, _peas_,
   {{0x2d92005c,0x31c70051,0x7dc60359,0xa91dc043}},	//   _caye_, ссов, _pósa, seža,
   {{0x10740660,0x2bfa48b8,0xe0df468a,0x2d922604}},	//   пляю, ्तां_, _ceòl_, _daye_,
   {{0x66046605,0x2a65d367,0x39490070,0x399540eb}},	//   elik, bulb_, _weas_, _ụs_,
   {{0x66046606,0x63b56607,0x7de54007,0x6377c093}},	//   flik, _rozn, lėsi, _הגוף_,
   {{0x6fc040fa,0x7c2d5894,0x4421007a,0xe3bf430d}},	//   _höch, tqar, _wih_, _puño_,
   {{0xbbeb05dc,0xa3e8808f,0x3dc905bb,0xcf8e01aa}},	// [2230] _مردم_, मचा_, _ilaw_, رژی_,
   {{0x2bbb4032,0x2d921216,0x7c2d6608,0x2a9800b6}},	//   دارة_, _zaye_, rqar, _fčb_,
   {{0xa3be0834,0x2bbe80df,0x3ebecd27,0x7d02c17b}},	//   _आवत_, ्सना, nytt_, _lyos,
   {{0x225c405b,0xfbcec079,0x63b56609,0x3f85c570}},	//   ávka_, িচিত, _wozn, zelu_,
   {{0x61ed260a,0x1be8c048,0x7bc1cb44,0xe9e9c02d}},	//   _mjal, टचाल_, yklu, nkúš_,
   {{0x6b8700fd,0xdb0e40b4,0x3e71c107,0x403446fd}},	//   nejg, _dobâ, yát_, _херс,
   {{0xd5ae805f,0x7c298414,0xa01b00cb,0x442b4556}},	//   رہے_, _wuer, rwöh, _huc_,
   {{0x657b9aed,0x61ed2470,0x9f5800fd,0x248d8046}},	//   _ubuh, _njal, torë_, _tsem_,
   {{0xe9df0032,0xf1b9806c,0x7d02c00d,0x394de60b}},	//   diú_, _hišo_, _cyos, raes_,
   {{0xd7fb8090,0x394f810d,0x7d02e60c,0x6569e60d}},	//   _суб_, lags_, _dyos, sgeh,
   {{0xf986044c,0x69c9a134,0x3b09cdce,0x7c3bc69a}},	//   огно, _klee, рено_, spur,
   {{0x216a0842,0x78a4c2d8,0x656b805c,0x2480021b}},	//   шими_, _šive, nggh, _ppim_,
   {{0x00e5c0fb,0x6e2dc0b3,0xe919c11b,0x61e9e60e}},	//   _بتای, _čabu, _тоді_, mnel,
   {{0x61b68c8c,0x657d660f,0x69c2a610,0x6d4bc232}},	//   _अक्ष, _absh, zkoe, _hega,
   {{0x80db0079,0x9f5807b0,0x98bd8036,0x69db817b}},	//   _যুদ্, noré_, rawę_, _omue,
   {{0xd378c068,0x66046611,0x442b6612,0xe1f201aa}},	//   mića_, ulik, _buc_, _تست_,
   {{0x394f908e,0xe1f7411e,0x546a543c,0x3860401e}},	// [2240] dags_, ігу_, разм_, urir_,
   {{0x69db9357,0x644040da,0xb7b580eb,0x442b6613}},	//   _amue, _çmim, _dịk, _duc_,
   {{0xd378ca11,0x7c23c07a,0xdb0e419d,0xe2975df0}},	//   nića_, _minr, _tobí, жах_,
   {{0x7ae34032,0x6d59c18b,0x2c7281f4,0xf8bf1ea2}},	//   únta, _ndwa, tâd_, ccés_,
   {{0x91fd003f,0x7bde41aa,0x629e0123,0xa3be02ea}},	//   duāl, pipu, _hrpo, _आवा_,
   {{0x69c2a614,0x6e22ce94,0x3cfdcb35,0x4423415d}},	//   skoe, _siob, _लड़े_, _gij_,
   {{0xa3bfc09d,0x3a2a4010,0x628a80a8,0x7c2bc0b1}},	//   ीसन_, _uubp_, uwfo, _augr,
   {{0x3e55c03f,0x2005e615,0x7c23ce94,0x61fbc746}},	//   dāt_, elli_, _ainr, goul,
   {{0x6d42a616,0xa91dc11a,0xdb1e0fc2,0xbfaac2c3}},	//   mboa, sežn, _impõ, атне_,
   {{0x7bc8803a,0x4423404d,0x6d4f2617,0x6d4bc1c8}},	//   _uldu, _xij_, waca, _eega,
   {{0xa91de618,0x3dc90022,0xe9df01b4,0xa3dc408f}},	//   bežo, _plaw_, tiú_, तोय_,
   {{0x7d040449,0x6fc040cb,0xa2d38047,0x80a6c7ce}},	//   _byis, _wöch, _भेट्, _ومان,
   {{0x60f803d0,0xa5bb4070,0x7c23c402,0x7bdc6619}},	//   жняя_, _bión, _finr, _omru,
   {{0x442b661a,0xcf2701b4,0x7d0400f8,0x06c34079}},	//   _ruc_, ترحي, _dyis, ্পতি,
   {{0x61ed0086,0xf8ae02cf,0x442b661b,0xd378c41b}},	//   _tjal, نکی_, _suc_, cića_,
   {{0x26d8c02d,0xc0354244,0x7c3d0621,0xa4d540d9}},	//   úrou_, знај, ppsr, побі,
   {{0xf8bf261c,0x4439443e,0x394b48c7,0x7bc387cb}},	// [2250] rcés_, _qts_, _vecs_, yknu,
   {{0x6b88e61d,0x442b661e,0x7de40107,0x91fd0017}},	//   nedg, _vuc_, rőse, zuāl,
   {{0x3f87a61f,0xaa9541b4,0x1b1cc079,0x394fa620}},	//   venu_, ثلاث, পুরে_, tags_,
   {{0x61fbc018,0x160ac036,0x8367001c,0x8afa00c3}},	//   xoul, _हीलर_, _ادکل, _להתי,
   {{0xa13642a6,0x3f87a621,0x61e0c561,0xd59c0009}},	//   _מארק_, tenu_, diml, יבאל,
   {{0x61fbc3e2,0x61fd056e,0x20054086,0x00ba40c3}},	//   woul, hosl, _óli_, _המשמ,
   {{0x7c2be622,0x6fc20166,0x212909ee,0x91fd003f}},	//   _sugr, _dôch, _ogah_, tuāl,
   {{0x78a69f35,0x2d894396,0x38608032,0x7c2f81cb}},	//   _škve, neae_, áirc_, _écro,
   {{0x7c23dbba,0xdb03c359,0x7c2d2623,0x2005c060}},	//   _pinr, _inné, _nuar, tlli_,
   {{0x25a6c018,0xa3ae6624,0x6f03c1f4,0x77f7c08f}},	//   _enol_, काय_, _pync, ुतेक_,
   {{0x394da625,0x76550036,0x386940fd,0x38cac01c}},	//   _kees_, jszy, huar_, لایی_,
   {{0x9f5e83e2,0x7c2d1842,0xdb074031,0x3e55c017}},	//   _aktè_, _buar, _bojú, rāt_,
   {{0xd9bd8079,0xe8eee626,0xf1b9a627,0xa3ae4389}},	//   _আগাম, _чл_, _moš_, काम_,
   {{0xdd92478a,0x78a6810d,0x63b8cfaf,0xd378c38f}},	//   کور_, _ákve, _govn, pića_,
   {{0x69c46628,0xd00ec032,0x6e2405f9,0xb7bd80cc}},	//   tkie, _حلو_, _tiib, _cuţi,
   {{0x656d6629,0x7c2d262a,0x5bb88028,0xb7b580eb}},	//   ggah, _fuar, _अव्व, _dịi,
   {{0x4425a467,0x442d801e,0x7d04262b,0xafe600b4}},	// [2260] _oil_, _nue_, _uyis, _ноил,
   {{0xdc9b262c,0x69dd40f7,0x317f8119,0xa09b02a6}},	//   _פסיכ, _emse, _abuz_, _פייט,
   {{0x249f85b2,0x7bde0ddb,0x2ca00043,0x34c48047}},	//   _arum_, _impu, _hrid_, वन्द,
   {{0x394da62d,0x443fc0eb,0x248dc044,0xf1cc23f4}},	//   _cees_, kpu_, kwem_, ासिन,
   {{0x7bc54022,0xd00aa62e,0x629c0713,0x33948007}},	//   bkhu, беде_, lvro, далё,
   {{0x6283c820,0x7c380013,0x3f8a002c,0xa3cc009d}},	//   _opno, _čvrl, nebu_, लसि_,
   {{0x59cc008f,0x2bc14048,0x8cd4c1f9,0x6b88c7fb}},	//   ासार, _शकता, _बेजो, vedg,
   {{0x249fa62f,0x5838c119,0x325380c5,0x6d446630}},	//   _frum_, озия_, хвър, nbia,
   {{0xa91de631,0x61e0c38a,0x6d4d0f4c,0x7bde017b}},	//   ležj, riml, _reaa, _ompu,
   {{0xe3a484fc,0xdb018996,0x6e2e6632,0x60c0c4d3}},	//   _تشری, _coló, _kubb, rymm,
   {{0x394d824c,0x6d4d009d,0x6e2e41c8,0x2bb00048}},	//   _yees_, _peaa, _jubb, ञाना,
   {{0x394d0019,0x6b88c011,0xdd8fcd9e,0x3869409c}},	//   úes_, sedg, _موم_, yuar_,
   {{0x64a3e633,0x386940da,0x6602c02e,0x63ba93ca}},	//   _паца, xuar_, _ikok, _kotn,
   {{0x386940fd,0xfbcfc032,0xbcfb001e,0xa49b4053}},	//   vuar_, _متى_, dgét, _dyòl,
   {{0x4b7bc21d,0xb93a4044,0xdb7bc0c3,0xd378c011}},	//   _האוו, _ọmụr, _הנוכ, lićo_,
   {{0x2ca02634,0xe51a0314,0xfe6fc032,0xdb018141}},	//   _frid_, नेहि_, _صدى_, _kolò,
   {{0x6e26414d,0x2bd9c0e9,0x7de54026,0x81c1402a}},	// [2270] _dikb, योवा, dėst, ্চল_,
   {{0xf99f40b6,0xbca44032,0x7dca4089,0x2d9908f9}},	//   _chèr_, عملي, _výsa, ldse_,
   {{0x2484805c,0x4425a4de,0x26c74047,0x853006df}},	//   _apmm_, _ril_, áno_, _haɗa,
   {{0x28de45de,0x4425a635,0xf09f4015,0x3e75556e}},	//   _नेवि, _sil_, _trà_, råt_,
   {{0x32094340,0xf09f40d2,0xe9df402e,0x6b954147}},	//   mlay_, _urà_, _imú_, _tazg,
   {{0x2ade854a,0x27e3015d,0x85300020,0x61ff4080}},	//   _केहु_, nijn_, _maɗa, loql,
   {{0xf1a9c036,0x4ea78097,0x9f45c138,0x69cd0140}},	//   कालन, ярда, rolü_, _olae,
   {{0x442da636,0x3209405e,0x2d8b0faf,0xdb01a637}},	//   _tue_, nlay_, jece_, _soló,
   {{0x442d854a,0xdb01a638,0x93279094,0x316dc669}},	//   _uue_, _colò, _فران, rgez_,
   {{0xcee9c051,0x600b62c1,0x0ae9c051,0x798ba639}},	//   ждое_, kümm, ждой_, legw,
   {{0x657d0c32,0x6d44402c,0x6d5d41b8,0x198a02d2}},	//   ffsh, ybia, _odsa, обни_,
   {{0x798b802c,0x6fc4c29a,0x3f8a263a,0x61ed663b}},	//   negw, _lòch, webu_, jnal,
   {{0x68e9438f,0x7bde005c,0x61ed456e,0x62850073}},	//   _žedn, _pmpu, dnal, _apho,
   {{0x81e3802a,0x7996099e,0x78a24089,0xe9df4359}},	//   নকি_, _wayw, ťovk, _amú_,
   {{0x7d06404c,0x69cd01f4,0xdb18c756,0x3f8a263c}},	//   _syks, _flae, _novè, rebu_,
   {{0x629c0101,0x853006df,0x9f45c23f,0x2d8b263d}},	//   rvro, _faɗa, colò_, cece_,
   {{0x7c2f400c,0x6d4f663e,0xeb9a0077,0xe45f0107}},	// [2280] _cucr, _deca, _дип_, ször_,
   {{0x6609c0f7,0x9f4a40b6,0x3dcd80b6,0x7bde07b6}},	//   hlek, _akbò_, _alew_, _umpu,
   {{0x6eb506c1,0x75494107,0x6fc4c68a,0x660400bb}},	//   _उपयु, észü, _dòch, _kkik,
   {{0x442fc0b4,0x6d4f663f,0x25ff4048,0x49150185}},	//   _oug_, _geca, लवणी_, नेको_,
   {{0x442fc24c,0x661bc0ab,0x4427cc4a,0xa3cdc575}},	//   _nug_, dmuk, _oin_, रसा_,
   {{0x3a26c1f4,0x8aa681bb,0x2d8b2640,0x59a3c048}},	//   _siop_, дрид, zece_, _खोबर,
   {{0x443dc07a,0xc246411e,0x6602c07a,0x442fc0c3}},	//   _atw_, _інак, _pkok, _aug_,
   {{0xcb130093,0x26040004,0x660409dc,0x68f607b0}},	//   כלו_, iños_, _nkik, _oxyd,
   {{0x0b8ae641,0x443dcb87,0x3cf181af,0x00000000}},	//   осни_, _ctw_, čovú_, --,
   {{0xdfa680b8,0x9ed8c01b,0x6609e642,0xe8d784e0}},	//   _تحري, змот_, alek, _חומר_,
   {{0x63bc40c3,0x442fc29a,0x9c12c0eb,0xdb1a86a6}},	//   _morn, _eug_, họgb, _motë,
   {{0x7dc3454a,0xceb38052,0x39468078,0xf1a7084e}},	//   _tõsi, _שיף_, nbos_, фрон,
   {{0x5c0701bc,0x621bc052,0xf09f4031,0x7c2880e5}},	//   дява, _וואק, _ayàn_, _kidr,
   {{0xe7840bf3,0x63bc6643,0x6fc4c0d2,0x7c28817a}},	//   кусо, _norn, _oòci, _jidr,
   {{0x85300067,0xbcfb001e,0x7dd14ded,0x27e32644}},	//   _waɗa, ggér, _låse, rijn_,
   {{0x7bc72645,0x442fc24c,0xb17b4b9f,0x3f8ce646}},	//   skju, _yug_, _småb, ledu_,
   {{0xdb1a8a54,0x61ed6647,0x9f58410d,0x48155bd9}},	// [2290] _botë, rnal, _skrá_, емас,
   {{0x2909211e,0x6609c05f,0x63bc5ef4,0xb4db45ef}},	//   _iyaa_, zlek, _corn, _beàr,
   {{0x644d0033,0xf1b9806c,0x2a6cc06c,0x9f5c8066}},	//   _hwai, _hiši_, nudb_, cové_,
   {{0x7c28a648,0x7f550070,0x386681f4,0xb4db4321}},	//   _aidr, lazq, fror_, _deàr,
   {{0xb7d54031,0x25ab434b,0x52cac945,0x63858f37}},	//   _aṣej, _incl_, ानुस, егла,
   {{0x3e78c05f,0xf1bf4018,0x60104041,0xe2998401}},	//   két_, _xián_, lämn, зак_,
   {{0x6b684107,0xdd320080,0xb4db45ef,0x6609d25f}},	//   ségü, _nəşr, _geàr, tlek,
   {{0x9f580038,0xfc3f41b4,0x2486c07a,0x2c14cc63}},	//   vorí_, _tríd_, _bpom_, _नीबू_,
   {{0x29092649,0x4427c69c,0xe7cac062,0x644d005e}},	//   _nyaa_, _pin_, िसंप, _nwai,
   {{0x6609e64a,0x6604264b,0x244d00b3,0xf2c784df}},	//   slek, _skik, džm_, _осен,
   {{0x5fac8b23,0x5de613f7,0x63b84041,0x2005802f}},	//   चारल, ежна, övni, _ikli_,
   {{0x4427dabd,0xdcebc283,0x76438033,0xdb03c053}},	//   _win_, _nagħ, mpny, _bonò,
   {{0x6459919e,0x61e44134,0xdb0880b6,0x22918123}},	//   nswi, viil, _andè, _hšk_,
   {{0xa91dd295,0x7641e64c,0x6459815d,0xdb1a8396}},	//   ježi, pply, iswi, _botè,
   {{0xfc3f41c0,0x2d996493,0xdcebc1d6,0x28e0264d}},	//   _atí_, _base_, _bagħ, _पेरि,
   {{0x98ac003a,0xaca381c0,0x6014c016,0xdcebc085}},	//   şdı_, _ayọn, ràme, _cagħ,
   {{0xe0da41bc,0x386dd682,0x2d994018,0x8fa60179}},	// [22a0] чва_, nuer_, _dase_, _запе,
   {{0x317fc0c9,0x9f5c8066,0xdb1ac032,0x447b02a6}},	//   hfuz_, pové_, chtó, _צניע,
   {{0x44320015,0x3f984017,0x056692bf,0x6fcdc018}},	//   _huy_, _varu_, евен, _xúca,
   {{0xa2b50185,0x7d0980bc,0x7dd1426c,0x3866a64e}},	//   _उपत्, _byes, _påse, tror_,
   {{0xdd99805b,0x6459882e,0x3946a64f,0xa3ac8f8b}},	//   _daň_, gswi, rbos_, गाल_,
   {{0x3866a650,0x69c9e651,0xed59a652,0xa3e1c8b8}},	//   rror_, ekee, _rože_, नोम_,
   {{0x78a2e653,0x44322654,0x68294039,0xd90d805f}},	//   _srov, _luy_, _užda, میہ_,
   {{0x3f9a003f,0x249f40e0,0xd84f00eb,0x3949810d}},	//   _lapu_, _šumi_, _bọlb_, ðast_,
   {{0x7999e655,0x29f88077,0xdb1c0851,0x28e001f9}},	//   _daww, rčad_, lkrä, _पेलि,
   {{0x79842656,0x3f9a0011,0xe29a823d,0x7dca4086}},	//   _abiw, _napu_, _наз_, _sýsl,
   {{0xe0cfc01c,0x61e61597,0xf7738323,0x6600e657}},	//   لزی_, fikl, _תקע_, pomk,
   {{0x386de658,0xf1b98618,0xdb1a801e,0xab64406a}},	//   buer_, _piši_, _noté, ldüğ,
   {{0xdd8fc1b4,0x2ca042d8,0xc458004c,0xe516c185}},	//   _دون_, jvid_, ниях_, देखि_,
   {{0x2ca044d3,0x6fcb003a,0x20050166,0x2d996244}},	//   dvid_, _gücl, ôli_, _sase_,
   {{0xdb1c40da,0xdb155744,0x98a900b3,0x61e616e2}},	//   _dorë, _pozí, _igač_, bikl,
   {{0x3ebe04d3,0x752d2659,0x6594665a,0xdb1a81cb}},	//   ätta_, _ugaz, ласу, _coté,
   {{0x24f86112,0xa91da2e9,0xacf8665b,0x644440f8}},	// [22b0] енты_, _obža, енту_, gpii,
   {{0x20184061,0x65608032,0x6b9a80b1,0x601044c9}},	//   _chri_, _admh, _natg, sämn,
   {{0x765ae65c,0x6440a58d,0x6595a65d,0xa91dc120}},	//   nsty, _atmi, кажу, reži,
   {{0x7d09a65e,0x645991fd,0xa2a4842f,0x765ae65f}},	//   _pyes, tswi, किन्, isty,
   {{0x69c9c046,0x83fdc107,0xdb1c0359,0xdb1c4396}},	//   vkee, rtőz, bhró, _lorè,
   {{0x3206cc47,0x64599b5d,0x7999e655,0x6e299078}},	//   _akoy_, rswi, _saww, _wieb,
   {{0xa3e90b35,0xc33400c3,0xe29680c5,0x9f5ec1cb}},	//   _मगन_, נוק_, ващ_, coté_,
   {{0x20030150,0x61e2c011,0xdb0ac88b,0xceb244e0}},	//   hoji_, _cmol, _infè, _דיל_,
   {{0x2003056e,0x7fd5c589,0x7de8c0a0,0x7d09a660}},	//   koji_, віні, věst, _uyes,
   {{0x442a424c,0x28d00028,0x765ac14b,0xdb018019}},	//   _xib_, हनसि, fsty, _enlá,
   {{0x216a1771,0x78a42661,0x799ba662,0x3f9a2663}},	//   мини_, _sriv, _kauw, _rapu_,
   {{0x2d9da664,0x7bc11254,0xb346c10b,0x8937c032}},	//   ndwe_, ölun, tiçõ, _أعضا,
   {{0x3f9a2665,0x799ba54a,0x32020066,0x2d998018}},	//   _papu_, _mauw, roky_, _óseu_,
   {{0x6a85c184,0xf1bf4070,0x27e78086,0x799ba666}},	//   _алка, _diám_, ninn_, _lauw,
   {{0x07a30267,0x660d6667,0x61e62668,0xe737065e}},	//   јасн, flak, pikl, тес_,
   {{0xf1b9838f,0xb222c086,0x8d7607d8,0x69cb80a8}},	//   _kišu_, _þætt, _شابا, jkge,
   {{0x7e7c011a,0xdb1c0032,0x61e42669,0x3e7a80fd}},	// [22c0] strp, thró, _imil, zët_,
   {{0x98a002bc,0x7c2ac6ed,0x9f4a05b1,0xfaa658a4}},	//   _agić_, _xifr, robó_, казо,
   {{0x7c3640fd,0x660281ae,0x7c2b00c4,0x64444134}},	//   sqyr, took, _ègra, spii,
   {{0x6b9a842c,0xa91dc04f,0xdb08830d,0x3abac052}},	//   _satg, ležu, _undé, ומענ,
   {{0x27e7a66a,0x799ba66b,0x61e4266c,0x76418007}},	//   finn_, _dauw, _mmil, _atly,
   {{0x6602831c,0x64460007,0xa3ae4048,0x20184025}},	//   sook, ipki, काळ_, _uhri_,
   {{0x7dc3454a,0xfc3f430d,0xab64406a,0x539b40c3}},	//   _tõst, _iría_, rdüğ, _קילו,
   {{0xd87680fb,0x3f8e8150,0xad9b4031,0x69cb80fa}},	//   _لائب, sefu_, _akúj, ckge,
   {{0xdb170004,0xdb0ac01e,0x3e7c666d,0x02cacc13}},	//   _roxí, _infé, lít_, ान्न,
   {{0xd9bf50de,0x7982a66e,0x799b8036,0x29f88077}},	//   _एक्ट, lfow, _zauw, bčac_,
   {{0x2ba6c08f,0x6b9c435b,0x78a28066,0x9e65878a}},	//   _कोणा, _marg, lvov, _مانن,
   {{0x3869666f,0xd946d201,0xf3ff001f,0x765ae670}},	//   yrar_, _реди, trão_, rsty,
   {{0x20030e5a,0xdb1ad29d,0xe0df468a,0x6b9c40b9}},	//   toji_, nktú, _leòr_, _oarg,
   {{0x60c004d3,0xe6b68185,0x7c2f8157,0xed59804f}},	//   ämma, _अपाङ, _ècre, _moža_,
   {{0x20031e41,0xa3b3808f,0x257da671,0xd378c2a3}},	//   roji_, टात_, náló_, jići_,
   {{0x6b9c6672,0x27ed0107,0xdb1c4396,0x20032673}},	//   _aarg, ően_, _goré, soji_,
   {{0x442ca674,0x2489006c,0x394642b0,0x39590716}},	// [22d0] _oid_, _upam_, ñosa_, mass_,
   {{0xb8db44d0,0x7d0d2675,0x9327401c,0x799ba676}},	//   _अप_, _iyas, نران, _sauw,
   {{0x320ddb2d,0x3204cf6f,0xa3d00045,0x3e7c4107}},	//   yley_, komy_, वघर_, gít_,
   {{0xe819c045,0x700100eb,0x320dc5e2,0x27e780cb}},	//   _नीना_, _ịcho, xley_, winn_,
   {{0x6b9c4517,0x26c780de,0x07f8078a,0x69c092c5}},	//   _farg, wyno_, _سریع_, _dome,
   {{0x9f4780fd,0x6e2be677,0x6562c88b,0x8699917a}},	//   minë_, _sigb, _adoh, етит_,
   {{0xc29341aa,0x9f4780fd,0xdb1e2678,0x2eb480c5}},	//   _خیاب, linë_, _copè, исъс,
   {{0x6b9c4813,0x09ca8079,0x3f912679,0xd8b7805f}},	//   _zarg, লোবা, hezu_, _لگتا_,
   {{0xe4e78761,0x7dc620b9,0x799d44fd,0x7d048160}},	//   _рівн, _móst, _masw, üist,
   {{0x7dc60004,0x6ed3c03a,0x3a2d800c,0x60c48051}},	//   _lóst, ləbə, _hiep_, äime,
   {{0x645bd532,0x3f91267a,0xdb01810b,0x6e2bc105}},	//   ssui, dezu_, _colô, _tigb,
   {{0xa06a06b1,0x7d0d16b4,0xb17b4300,0x9f80c031}},	//   нама_, _byas, _smån, _bòó_,
   {{0xed59e652,0x9f47813b,0x8d5ac0c3,0x6298cf9c}},	//   maž_, jinë_, _נכסי, _esvo,
   {{0xdee62012,0x799d40bb,0xa3ac8384,0x7d0d03e2}},	//   гоги, _aasw, गाए_, _dyas,
   {{0x3f87e67b,0x7bc1a67c,0x29c3c815,0x09cc4079}},	//   _ibnu_, _molu, _uñas_, রোফা,
   {{0x2005e00e,0x6e2d0105,0xa2b50285,0x60104041}},	//   loli_, _giab, _उपर्, rämm,
   {{0x64a6267d,0x1867667e,0x3b8641f0,0x2d9dc150}},	// [22e0] _сапа, лати_, ллаг, _mawe_,
   {{0x7643c07a,0x66044d97,0x661b812c,0x9f45c1cb}},	//   _ktny, soik, _ahuk, filé_,
   {{0x8b56c009,0xc332c093,0x7dca4086,0x661ba176}},	//   ריעס_, צוא_, _lýsi, _bhuk,
   {{0xd378c0e0,0xf1a3c064,0x9f5806ed,0x3f87c05c}},	//   rići_, _खोलन, forç_, _lbnu_,
   {{0x2005e67f,0x6fcb00fa,0x61e9c166,0x9f45c3bc}},	//   koli_, _büch, diel, pilè_,
   {{0x66062680,0xd378c0ab,0x60dbc017,0x25a0409d}},	//   hokk, pići_, dzum, ldil_,
   {{0x741344e8,0x2005c02c,0x65642681,0xdb18c047}},	//   _طوفا, doli_, _odih, _poví,
   {{0x6d59a2d7,0x6444017b,0xa2a2c285,0x2ba48b6d}},	//   cawa, _otii, गिस्, _गोरा,
   {{0xf48784fc,0x7643c056,0xbb4682d0,0xdb08a682}},	//   _مالی, _atny, _безк, _indí,
   {{0x3204c0c7,0x807b4052,0xa91dc026,0x7d0d01c6}},	//   somy_, עניצ, vežt, _ryas,
   {{0x96f8cf21,0x7d0d25c0,0xe8d90094,0x3c3983e2}},	//   тент_, _syas, _mbụ_, _zèv_,
   {{0x3d05cb35,0x2e16c1b4,0x2ca0c06f,0x3940005e}},	//   _हुवे_, _صباح, _šidu_, _cfis_,
   {{0xbcfb614f,0x6d562683,0x2ca6c043,0x3f9cc017}},	//   _adén, _deya, _urod_, _tavu_,
   {{0x7d0d06f3,0x6d562684,0x6444005e,0x629a817b}},	//   _vyas, _eeya, _dtii, _ksto,
   {{0x7dc61e6f,0x6d4b8057,0x3f9ea685,0x6e2d0010}},	//   _póst, ybga, _matu_, _tiab,
   {{0x9f4780da,0x442ee686,0xb8868166,0x2499405c}},	//   tinë_, _hif_, _zníž, _pssm_,
   {{0x3a2d80a8,0xfc3f4031,0xdb0184c9,0x629a8085}},	// [22f0] _riep_, _erín_, _inlå, _lsto,
   {{0x6d59a687,0x6aa89e0f,0xb33c8283,0x2ba49527}},	//   wawa, _ordf, _jaħd, _गोला,
   {{0x2ca90066,0x02a7423d,0xdb1a8559,0x25a04283}},	//   _hrad_, ырам, _botí, bdil_,
   {{0x7887403f,0xe45f410d,0x9f908031,0x2ba6c49d}},	//   tīvā, _tvö_, _aàà_, _कोसा,
   {{0x2d9dc396,0x9f908031,0xbcfb5d05,0x2480505f}},	//   _rawe_, _bàà_, _idéo, ctim_,
   {{0x6d4d6688,0x442ee689,0xfe458ef7,0x8f344d9b}},	//   lbaa, _nif_, анко, _герц,
   {{0x61e9debf,0x69c2c303,0x63a4c09c,0x66098140}},	//   tiel, _booe, _ɗint, _tkek,
   {{0x66098bc9,0x60dbc918,0xdb1a81ff,0x4df98052}},	//   _ukek, tzum, _botâ, _ספּא,
   {{0x629aa68a,0x6d560565,0x2ca90046,0x3f87c07a}},	//   _esto, _reya, _nrad_, _pbnu_,
   {{0xed59806c,0xf1f94b35,0x7c2e668b,0x7dd5c0e1}},	//   _kožo_, ्कड़_, _xibr, _básc,
   {{0x6444268c,0x2ca90119,0x60c9e16b,0x72b98032}},	//   _stii, _arad_, syem, _جهاز_,
   {{0x442ee68d,0x9f5c8066,0x6d4d415d,0x601200b0}},	//   _eif_, mová_, jbaa, ræmm,
   {{0x8934c51b,0xc2ec4079,0x394de68e,0x7645010d}},	//   _اعما, _করছি_, mbes_, _athy,
   {{0xfaa5e68f,0x69c2c053,0x61eb80c4,0xe736c42e}},	//   _вако, _zooe, higl, _кеш_,
   {{0xdbcf4166,0xd378c1be,0x7bc3d8bd,0xb7d54171}},	//   bľúb, giću_, _ionu, _aṣoj,
   {{0x6d4d6690,0x27e7c0f8,0xfc3f4070,0x442ee691}},	//   gbaa, _hmnn_, _crío_, _zif_,
   {{0x9f5ca09c,0x61eba692,0x25a06693,0xd00f00fb}},	// [2300] hová_, digl, rdil_, سلہ_,
   {{0xb4c2008f,0xed59860f,0x24806694,0x7989a695}},	//   ंही_, _božo_, rtim_, _abew,
   {{0x2007a696,0xfc3f4319,0x6d5be697,0x78a9976b}},	//   doni_, _frío_, kaua, _arev,
   {{0xdb1ac6a9,0x69c42698,0x9f5c8531,0x24806699}},	//   rktø, _joie, dová_, ptim_,
   {{0x81cd8079,0x913b0009,0x6281c414,0xe8e1035d}},	//   ষোভ_, דענק, htlo, _địu_,
   {{0x9f90802e,0xbf218048,0xe2f8884e,0xfc3f030d}},	//   _bàá_, मधून_, лелі_, nvía_,
   {{0xae060384,0x853006df,0x386de69a,0xd2578039}},	//   रवान_, _daɗi, erer_, ацы_,
   {{0x7dd841b4,0x298add93,0xdb18c347,0x442ee69b}},	//   _físe, тско_, _nová, _sif_,
   {{0xdfdac1bc,0x386de69c,0x8c438434,0x853006df}},	//   вън_, grer_, _мете, _faɗi,
   {{0x66e685e9,0x69d6249e,0x9f9081c0,0x2b584580}},	//   _коза, _alye, _fàá_, _jerc_,
   {{0xe737804c,0x29f887ca,0x195924b4,0x7bddc0fd}},	//   _тех_, nčao_, ланы_, ësua,
   {{0x7de700d9,0xe8eac0b4,0x9257c025,0x5fa6c063}},	//   ріод, _имед_, шают_, _कोरल,
   {{0x58870026,0x69cf006a,0x7bc3d14f,0x92b6c02a}},	//   шына, rkce, _fonu, ছনে_,
   {{0x7dd5c032,0xc8848080,0x69d6269d,0xd7f8092e}},	//   _tásc, mağı_, _elye, аус_,
   {{0xd7f80f93,0x6446669e,0x637bc2a6,0x4ea42145}},	//   руя_, _atki, _סנהד, орта,
   {{0xdb1c401f,0x6d4d53f9,0x69d6014d,0x629dc8c7}},	//   _corí, ubaa, _glye, āsot,
   {{0x61eb80c5,0x7f5c1adf,0xd90481aa,0x9f47801c}},	// [2310] vigl, barq, _آی_, siné_,
   {{0xcb99011b,0xdb0ac10b,0x200780fd,0x7dc603bb}},	//   _свої_, _infâ, xoni_, _hósp,
   {{0x76450041,0x61eb8511,0x78a98018,0x3a384070}},	//   _uthy, tigl, _srev, _curp_,
   {{0x76ac4031,0x6ec40047,0x3166c396,0x201e88a1}},	//   _e̟yo, रहरु, _ndoz_, _ahti_,
   {{0x660d0150,0xdca5806f,0x9b458032,0x6e3b4077}},	//   _mkak, сали, منشو, _čubu,
   {{0xdb1a8580,0x60cd4568,0x3166c0b9,0xa3cc81f9}},	//   _botà, myam, _adoz_, _लवण_,
   {{0x60cd52b5,0x249542d6,0x61eba69f,0xe81d4549}},	//   lyam, şamı_, pigl, _बीया_,
   {{0xa3b5532e,0x9f5c8531,0x386de6a0,0xdce84036}},	//   झाव_, rová_, trer_, śląs,
   {{0x2007a6a1,0x9f5c805b,0xcdb84093,0x6fcb003a}},	//   poni_, sová_, שפחה_, _hücu,
   {{0x61fb9060,0x3cff4064,0x69c40669,0x6d5be6a2}},	//   _hjul, _रखने_, _soie, saua,
   {{0x7bc3e6a3,0xa5bb26a4,0x81d6c079,0x11d601b4}},	//   _vonu, rmón, _সদর_, متحد,
   {{0xfc460047,0x61fb80bb,0x9f510107,0xc8848696}},	//   říme_, _jjul, kozó_, bağı_,
   {{0xa069d450,0x628380ab,0x60cd400d,0x9045c00f}},	//   _сала_, ltno, jyam, _انته,
   {{0x395d824c,0xd91a8916,0xa5bb0019,0x6609e6a5}},	//   haws_, טורל, lmól, loek,
   {{0xf99f0315,0x61fba6a6,0x216a4457,0x6fd0137b}},	//   glès_, _ojul, ливи_, _häck,
   {{0x386066a7,0x1a2a54cf,0x69dbc070,0xfc3f0019}},	//   tsir_, ужби_, nhue, svía_,
   {{0xe3b20e5f,0x7f5c0a5d,0x3a200340,0x395d823b}},	// [2320] _فرد_, parq, _ihip_, daws_,
   {{0x320d80b6,0x6609e6a8,0x291206df,0x25bfc253}},	//   _akey_, hoek, _iyya_, hjul_,
   {{0x6609e081,0x4e1a44e8,0xed59a6a9,0xdce64138}},	//   koek, _متحد_, _bež_, _vakı,
   {{0xc884891a,0x60cd59f1,0x261907b0,0x499a4800}},	//   yağı_, byam, héon_, _стоя_,
   {{0x443966aa,0xdce64f3e,0x443166ab,0x61fb80a5}},	//   _gus_, _takı, _fiz_, _djul,
   {{0x39594018,0x3a3866ac,0x7dca4347,0x78bbc018}},	//   _zess_, _turp_, _výsu, dxuv,
   {{0x2ca6a6ad,0xa3b54c4b,0x6d440036,0x7d1ba6ae}},	//   svod_, झार_, _ofia, _ezus,
   {{0xd6d980d9,0x443140e5,0x25a2456e,0xc884891a}},	//   шті_, _ziz_, _jakl_, tağı_,
   {{0x8530009c,0xdb1a8574,0xb17b4730,0x64400018}},	//   _kaɗu, _dotá, _småk, ímil,
   {{0x389b4093,0x78a942bc,0x63a1a6af,0x2e4ac0c5}},	//   ניינ, _ševk, _galn, лямо_,
   {{0x37a7c097,0xadc380d1,0x9df9001d,0x5986c007}},	//   стын_, _chặn, инот_, _глеб,
   {{0x69c666b0,0xe8d94044,0xdb1c40d2,0x3a2026b1}},	//   _noke, lfụ_, _morà, _chip_,
   {{0x7bc526b2,0x91fd0017,0xae1bc0c3,0x2ed1007c}},	//   _pohu, drāt, _עודכ, सन्त,
   {{0x27184028,0x07a3cce8,0xa3d88c13,0x3eb8c0cb}},	//   _थरूर_, _начн, ासि_, ärts_,
   {{0x98a4c06a,0x44314d4a,0xd9ecc048,0x6fd000cb}},	//   mamı_, _riz_, _जगात_, _mäch,
   {{0x6fd000cb,0x5c750051,0x660d1955,0x3ebf0123}},	//   _läch, _длит, _ukak, ćut_,
   {{0x200a0360,0x798d26b3,0x2281805f,0x69dd1440}},	// [2330] bobi_, _ibaw, zók_, mhse,
   {{0x44314080,0xdb050041,0x7bdc1856,0xdcf3c06f}},	//   _qiz_, _anhå, chru, šaće,
   {{0xe61f40d1,0x78ad0066,0xad274de9,0xfbd04032}},	//   _thô_, _hrav, _گردو, رتك_,
   {{0x7dd84018,0x391598f9,0xb884005f,0xb91581c0}},	//   _vísc, омер, _بلیٹ, _igbẹ_,
   {{0x2ed18185,0x7dd5c066,0x893481b4,0x798d26b4}},	//   तन्त, _básn, أعما, _mbaw,
   {{0xdb1ad243,0x395d8022,0x185c0009,0x61ef26b5}},	//   nktó, saws_, רכגע, hicl,
   {{0x321f80d1,0x6fd00851,0x61e98089,0x6609dab9}},	//   _thuy_, _säck, _tmel, toek,
   {{0x2d8ac05f,0x6d5f4149,0x78ad26b6,0x628566b7}},	//   őben_, naqa, _orav, mtho,
   {{0xc795c5f1,0x7d1b812c,0x85300020,0x61ef0724}},	//   орны, _uzus, _yaɗu, dicl,
   {{0x6fd004d3,0x6d59c5dc,0x6498c1bc,0xbcfb4171}},	//   _väck, _wewa, стър_, _adék,
   {{0x27e08067,0x3a20005c,0xdb1e0066,0x798d017b}},	//   ɗin_, _phip_, _popí, _bbaw,
   {{0xe819c028,0x9c134031,0xee2ec0d9,0x69aa00c6}},	//   _नीरा_, _dọin, _ін_, _जोशी,
   {{0xdb1c66b8,0x7bdc26b9,0x6d5f66ba,0x1bfb48b8}},	//   _morá, thru, daqa, ्वाल_,
   {{0xab29c19b,0xb4c7c09d,0x798d040d,0x25e5ca94}},	//   _кола_, ैनी_, _ebaw, जोरी_,
   {{0x78ad26bb,0x63a3e6bc,0x69c666bd,0x232a0c86}},	//   _erav, _iann, _poke, рови_,
   {{0x657be6be,0x660f50e6,0x6d5f530b,0x798d021f}},	//   nguh, _ckck, gaqa, _gbaw,
   {{0x61ebc05c,0x973c8077,0x443fc0f6,0x26174018}},	// [2340] _mmgl, _laća, nqu_, cçom_,
   {{0x95f48dc7,0xe3b74920,0xa5bb4359,0x69d9c17b}},	//   ेक्ट_, обу_, _phóc, _llwe,
   {{0x78ad006c,0x2ba48428,0x91fd0017,0x5fb700c3}},	//   _zrav, _गोगा, prāt, _והיא_,
   {{0x2a054044,0xbc4a831f,0x6fd00414,0x6e3a8398}},	//   ịara_, ачке_, _säch, _rutb,
   {{0x27ea4070,0x649aa145,0x6285529a,0x2fc7c17b}},	//   _tmbn_, ртер_, atho, _oong_,
   {{0x2d8d80eb,0x69d9cfd7,0x6285608e,0x6e3a80f8}},	//   _ebee_, _alwe, btho, _putb,
   {{0x8e835123,0x7d15c080,0x64498bbd,0xdcf68138}},	//   _огре, əzsi, _etei, ğcıl,
   {{0x7bc7415d,0x99838007,0x85484007,0x657be6bf}},	//   _zoju, _dujų_, brėž, gguh,
   {{0x6141405f,0x2fc7e6c0,0x9f4cc01e,0x2b11009d}},	//   _háló, _bong_, lidé_, _दुनु_,
   {{0xd7f7c660,0x388e4017,0xb33c81d6,0xe00a45da}},	//   жую_, mērā_, _faħa, वविद_,
   {{0x443b01b7,0x7f5c4004,0x4433017a,0x6014c6ed}},	//   _suq_, _merq, _rix_, nàmi,
   {{0xd0ebc048,0x7c3ba6c1,0xdce4056e,0x7df58026}},	//   _जेवण_, _yuur, _edič, tąsi,
   {{0xe3b30d9e,0x7a358007,0xba29c107,0x6e22e6c2}},	//   ورس_, _išta, _اسلم_, _ihob,
   {{0x6d4666c3,0xdb0aca5d,0xdde24077,0x78ad26c4}},	//   _afka, _enfá, _ćušk, _vrav,
   {{0x31604033,0x600fc240,0x06e1002a,0x25a680f8}},	//   faiz_, rømt, _মুজি, kdol_,
   {{0xad9b4171,0x6560e6c5,0xd9ff0d13,0x2b49c4f9}},	//   _ojúe, namh, _उदित_, _đaci_,
   {{0x045941b4,0x7f5c40f6,0xe9df0032,0xdb0180fd}},	// [2350] صلاة_, _berq, mhú_, _palë,
   {{0x7658c022,0x7f5c4f51,0x200cc02c,0x644f0016}},	//   _kwvy, _cerq, nodi_, mpci,
   {{0x7a35841b,0x6e3c66c6,0x80acc027,0xdb1c54f0}},	//   _ošta, _curb, जिडे, _porá,
   {{0x7c3ba6c7,0x248686f0,0x2d9926c8,0x7ddce6c9}},	//   _puur, ftom_, nese_, _lésb,
   {{0x6560e6ca,0x2d9900c4,0x26f6c036,0x224a4140}},	//   damh, iese_, ँपुर_, _etbk_,
   {{0x2d9926cb,0x6e3c655c,0xf1a3c036,0x05a3c384}},	//   hese_, _furb, _खोजन, _खोजब,
   {{0xdb01a6cc,0x2d9926cd,0x9f4cc669,0x61ed1d7f}},	//   _kalé, kese_, cidé_, _omal,
   {{0x9599c43c,0x6560e6ce,0x317f81df,0x0165c01b}},	//   стку_, gamh, _ucuz_, чкио,
   {{0x395fe6cf,0x249f888b,0xdb01856e,0x3866c41b}},	//   raus_, _usum_, _malé, _cvor_,
   {{0x395fd045,0x7afc804f,0x3866c29f,0x7dd5c089}},	//   saus_, _žrte, _dvor_, _zásl,
   {{0x68294007,0x7c354053,0x660d66d0,0x3b09e5c3}},	//   _uždu, _mizr, koak, сено_,
   {{0x2440c3bc,0x37bd8079,0x6e22d335,0xa01b26d1}},	//   _fòm_, _অতির, _ghob, stöl,
   {{0x3ea100fd,0x2fda007a,0xe449c032,0xddce406c}},	//   _asht_, _plpg_, _التى_, jubš,
   {{0x600fc240,0xdd99c574,0x59c80048,0x69cb5da9}},	//   røms, leň_, _लवकर, ögen,
   {{0xe9df0032,0x443dc72b,0x68e28157,0x9f990086}},	//   bhú_, _huw_, zzod, ráðu_,
   {{0x2b8f8138,0x6e29ccc6,0xe9df26d2,0xb4660119}},	//   lıcı_, nmeb, chú_, _екил,
   {{0x3ea100fd,0x75d34032,0xdb01a6d3,0x91e3499b}},	// [2360] _esht_, ريكا, _dalé, хоте,
   {{0xe1ff41c0,0x386f4107,0x6d5d4573,0x443dc84f}},	//   _ejó_, ágra_, _eesa, _muw_,
   {{0x7f5c66d4,0x91dbc4b4,0xb87b0066,0xcf5700c3}},	//   _verq, बसाई, nzín, _מבית_,
   {{0x6014c6ed,0x248680c3,0x21678217,0x568cc009}},	//   ràmi, ttom_, зици_, שטאַ,
   {{0xa11641aa,0x61fbc013,0x60169412,0x603640b6}},	//   _روست, dnul, lâmi, _fņma,
   {{0x9f5c802d,0x69c2a6d5,0xdb1e002d,0x9f4a4396}},	//   lovú_, sjoe, _zopá, _ombé_,
   {{0x6d5d66d6,0x6459c0f1,0x53338156,0x8f9b0323}},	//   _yesa, _awwi, нешт, מיסי,
   {{0x7d040018,0x69c466d7,0xada380d7,0xe5a380b4}},	//   _oxis, njie, _пасл, _писи,
   {{0x74168301,0xfc3f0047,0x6306816a,0xeb36801c}},	//   _فورا, tvím_, _کوال, _فراخ,
   {{0x9f9413c6,0x443dc1f4,0xdb1c40d2,0x38668d88}},	//   _jää_, _duw_, _corç, msor_,
   {{0x98b8c91a,0x04f9002a,0xdb03c0b6,0xdd99c56e}},	//   ğrı_, _ঘরের_, _janè, beň_,
   {{0x9c870347,0x3ddfc15d,0x6562812c,0x671f439a}},	//   _načí, chuw_, naoh, _भरसक_,
   {{0x200cc157,0x05004079,0xf8be8549,0x6e36005e}},	//   podi_, ্ধুর_, ्हिय, _diyb,
   {{0xaa66e6d8,0x7d1de6d9,0x3ea10033,0x3866805c}},	//   _етик, üsse, _psht_, isor_,
   {{0xdb0540fd,0xb17b00b0,0x764ac125,0x61e1413b}},	//   rdhë, rhåb, _utfy, ëllo,
   {{0x41ab8027,0x7d160051,0x63a500cb,0x64be8048}},	//   _घोंस, _fyys, _wahn, ्हाळ,
   {{0xdb01a6da,0x6d5d66db,0xe0df4031,0x6d5f00f6}},	// [2370] _valé, _vesa, _efòn_, _ieqa,
   {{0x67e04041,0x644d0eb6,0x2d8240cb,0x4ea70523}},	//   _nöjd, _itai, _ecke_, _ерма,
   {{0x75484107,0x200426dc,0x1d4a8044,0x61fd134b}},	//   észí, émie_, _ịdịm, onsl,
   {{0x7e9bc009,0x7dd5c066,0x3a248070,0x25e88027}},	//   מסבו, _pásm, _chmp_, चोली_,
   {{0x5fd100aa,0x200e8360,0xb4574de9,0x656d02c0}},	//   _सकाल, fofi_, _ریاض_, _mdah,
   {{0xc879c50c,0xdb1c44c9,0x7c3701d6,0x644d21df}},	//   vuş_, _borä, _jixr, _mtai,
   {{0x78a2c06f,0x78ad409d,0xa01b0025,0xf41f0025}},	//   _asov, lvav, ttöj, ytän_,
   {{0x56b80093,0x63b8c053,0x3946a6dd,0x63a766de}},	//   לפון_, _anvn, ccos_, _hajn,
   {{0xdb1c410b,0xdd99c166,0x8f75c93d,0x3775c3d0}},	//   _porç, reň_, муні, мынс,
   {{0x7ddcc018,0x7dd84070,0x7bcae6df,0x395fa6e0}},	//   _pésc, _aísl, _cofu, _heus_,
   {{0x66e5c768,0x6d5f26e1,0x38cac1aa,0xd3e684e8}},	//   фона, _beqa, مایی_, _تقلی,
   {{0x248966e2,0x7dd5c107,0x7d160025,0x61fd26e3}},	//   ktam_, _másk, _pyys, gnsl,
   {{0x644bc383,0xdb0ac0fa,0x09e30dae,0xdb03d028}},	//   _utgi, _anfä, тоян, _mané,
   {{0x6295415d,0x6b9ac018,0x320f8107,0x7c250061}},	//   _opzo, cetg, hogy_, _chhr,
   {{0x644d0669,0x6d5f021b,0x753b8869,0x25a966e4}},	//   _etai, _feqa, _oguz, fdal_,
   {{0x395fa6e5,0xe1f2001c,0x9f940051,0x3866897e}},	//   _neus_, _جست_, _sää_, ysor_,
   {{0xfc3f4032,0xb4d78cbb,0xdce981d6,0xdbdc4171}},	// [2380] _cuí_, ानो_, _ddeċ, _fáìl,
   {{0x753ba6e6,0x46f6495c,0x25a64618,0x69dd66e7}},	//   _aguz, мчет, žol_, _else,
   {{0x7a01c017,0x3f9a406f,0xb33c80f1,0x3a2646b1}},	//   zēta, repu_, _daħl, _омог,
   {{0x601dc157,0x63ad8020,0xdb03c181,0x00000000}},	//   kèmo, ɓani, _cané, --,
   {{0x44259547,0x04438030,0xac0aa6e8,0x248966e9}},	//   _bhl_, вечн, онда_, ctam_,
   {{0xafdb436b,0x44258061,0xf1bf400c,0x77638016}},	//   _støv, _chl_, _thác_, ganx,
   {{0x316d8019,0x9f58034d,0x63adc09c,0x395f8580}},	//   _fdez_, loró_, _ɗant, _feus_,
   {{0x2d8066ea,0x7ddcc070,0x69d88017,0x2613c3bb}},	//   ngie_, _bésa, īves, dãos_,
   {{0xfcaa816a,0x443fa6eb,0x7dd5e6ec,0x23834086}},	//   _بازو_, _guu_, _másh, _þrjá_,
   {{0x44384057,0x6f0d81df,0x77638018,0xab2a8640}},	//   _jir_, şaca, canx, _доза_,
   {{0xdb1c436b,0x2613c10b,0x69cbe6ed,0xa01b1b52}},	//   _forå, gãos_, _foge, stök,
   {{0x3f9ca6ee,0xafdb40d9,0x2b51c06a,0x63a8a6ef}},	//   levu_, _utøv, ızca_, _hadn,
   {{0x7bcac2df,0x61fd064b,0xb8f3c02a,0xd943dee1}},	//   _tofu, rnsl, _হে_, _речи,
   {{0x4fc6c31e,0x6b9c04aa,0x2d92040d,0x6fdd8303}},	//   _ісла, gerg, _ebye_, _kèca,
   {{0x403426f0,0x78a41274,0x1d4c40eb,0x494c40eb}},	//   терс, _esiv, _ọdịm, _ọdịy,
   {{0x63a7405f,0x386901b8,0xd8388011,0x6d5666f1}},	//   _sajn, _tvar_, _lič_, gbya,
   {{0xd7e7011b,0x63a74022,0x25a94ae6,0x799d26f2}},	// [2390] _жіно, _pajn, rdal_, mesw,
   {{0x6fd48315,0x248966f3,0x78ad66f4,0xa774401b}},	//   _fàci, rtam_, rvav, клуч,
   {{0x656445bb,0xbcfb4171,0x78ad4134,0xf3ff001f}},	//   baih, _adét, svav, lsão_,
   {{0x9f5800e1,0x248966f5,0x61e29462,0x63ba9178}},	//   boró_, ptam_, ghol, _antn,
   {{0xf99243bd,0x6e2d66f6,0x244466f7,0x443866f8}},	//   _ערך_, mmab, _göm_, _fir_,
   {{0x628a8240,0x6602c051,0x6a858069,0x63adc0e2}},	//   ftfo, _ajok, елка, _ɗans,
   {{0x61e295cd,0xd8388066,0xe7368f8d,0x41d3409d}},	//   bhol, _dič_, неш_, _सवास,
   {{0x6fdd86ed,0x6e928032,0x7ddcc30d,0xdbcc8031}},	//   _dèca, اليا, _pésa, _bóól,
   {{0x2d9da040,0x603980ce,0x3f89809c,0x8b07c0a0}},	//   mewe_, _fňma, ƙau_, _ohří,
   {{0x6b9c0fc2,0x9327861e,0x69d9875a,0xddc8c017}},	//   xerg, _قران, lkwe, ļoša,
   {{0xef19c4df,0x69cbd80e,0x7ac49482,0x7a35c011}},	//   ямо_, _toge, _исце, _ušto,
   {{0x6440a6f9,0x2cb201f4,0x6fd6c01e,0x799d00b1}},	//   _yumi, _pryd_, _lâch, gesw,
   {{0x9f47806a,0xa3d5c623,0x68fb40ab,0xdb0182f4}},	//   ginç_, _подч, _žudn, _malí,
   {{0x38c5013b,0x8afe809c,0x764181ae,0x6564409c}},	//   _sërë_, laƙa, _kuly, waih,
   {{0xb5e8802e,0x41b64dd3,0x6d49c157,0xdb15402d}},	//   _bẹ̀r, нсат, ocea, _pozý,
   {{0x61e2a6fa,0x6e2d4105,0x661be6fb,0xee374563}},	//   xhol, gmab, nluk, енс_,
   {{0x443849b8,0x6d49d440,0x92170009,0x78a94077}},	// [23a0] _pir_, icea, _אַזױ_, _ševr,
   {{0xbcfb41c0,0x26e58079,0x394940e1,0x66e65109}},	//   _adés, _কখনো_, acas_, ноза,
   {{0x2003cf47,0x38c500fd,0xb17b4065,0x39494022}},	//   čjih_, _tërë_, _slåe, bcas_,
   {{0x2d8226fc,0x6566118a,0x661bc242,0x69d98274}},	//   ngke_, nakh, jluk, gkwe,
   {{0x8afe80e2,0x7c2e0157,0xdb074396,0x661be6fd}},	//   daƙa, ombr, _lajè, dluk,
   {{0xa5208048,0xd25a8143,0x6fd6c1cb,0x752402c0}},	//   _बरीच_, пци_, _gâch, _mziz,
   {{0xdb155981,0xe2974949,0x61e2a6fe,0x09e6811b}},	//   _dozó, _пар_, phol, _зовн,
   {{0x69c0c891,0x66040efc,0x752426ff,0x7bce409d}},	//   वाधी, _njik, _oziz, _hobu,
   {{0x752416b4,0x60c44004,0x32078107,0x98ab00b5}},	//   _nziz, nxim, énye_, yacı_,
   {{0xa5bb04ed,0xddc90036,0x9873cc38,0x6ecac080}},	//   ológ, łożo, ыльц, bəbl,
   {{0xd6d7c657,0x61e46700,0x45e4c00c,0x25a90fd7}},	//   етя_, khil, _đượ, _paal_,
   {{0x20110f6f,0x656600f7,0x4427e701,0x6b850157}},	//   wozi_, gakh, _ehn_, _schg,
   {{0x442ea702,0x3a3940c4,0x66e6c107,0x20d3ce5f}},	//   omf_, _risp_, _béké, _متوج,
   {{0xf1bf400c,0x7c3a86db,0x25a92703,0x7bce6704}},	//   _chán_, _jitr, _waal_, _nobu,
   {{0x38694067,0x29dc4004,0x656600f7,0x75242705}},	//   wsar_, _vían_, bakh, _eziz,
   {{0x7a25e533,0xb6060066,0x7ddce706,0x443a2707}},	//   póte, _pláš, _méso, _eip_,
   {{0xa31d817e,0x201102c0,0x6d4d2708,0x85740523}},	// [23b0] _फर्ज_, pozi_, _ifaa, _слых,
   {{0xdb0185b1,0x443a1f17,0x37074bd4,0x38696709}},	//   _salí, _gip_, нчев, rsar_,
   {{0x34d98185,0x61e440f7,0x7e7e44c9,0x63ad0017}},	//   भन्द, bhil, gupp, ļinā,
   {{0xdb1aa70a,0x2ca6c02c,0xdb0e41ff,0x443a0129}},	//   _intè, _osod_, _robô, _zip_,
   {{0x6fd6c01e,0x98a5a280,0x10a585a4,0x6f1a8053}},	//   _tâch, тиле, тилн, _aytc,
   {{0x25a99ac6,0x443a0016,0xeb969027,0x0454805f}},	//   žal_, _xip_, виш_, ائند,
   {{0xed59804f,0x2fc7410d,0x6566000b,0x2d9d812c}},	//   _anže_, öngu_, yakh, pewe_,
   {{0x4427e70b,0x77670022,0x3a29000c,0xf9938e70}},	//   _shn_, hajx, _nhap_, _حبس_,
   {{0x6d49df8a,0xf8bf8066,0x2499421b,0x6442e70c}},	//   rcea, _šéf_, _jpsm_, _cuoi,
   {{0x764181ae,0xdb01810b,0x442e8018,0x7d0980c7}},	//   _tuly, _calã, cmf_, _ixes,
   {{0xd6db804c,0xdb03c053,0x63aae70d,0x2365c011}},	//   _эта_, _annò, _dafn, ralj_,
   {{0xa06a0883,0xdb1c670e,0x386980ab,0x75e60062}},	//   мама_, _corù, šaru_, _mózg,
   {{0x200740b3,0x3e414007,0xdb1a8141,0xddc90242}},	//   čnij_, _dėti_, _antè, budž,
   {{0x3f830397,0x7dd84086,0x4427c011,0xab2a0007}},	//   ggju_, _tísk, _uhn_, дога_,
   {{0xdb0880d2,0x96630dd2,0x46a5c4c5,0x6d4d040d}},	//   _cadè, икре, _райв, _ffaa,
   {{0xb17b04c9,0xbcfb41cb,0x7bce40f7,0x69dbd864}},	//   nhål, _adéq, _sobu, nkue,
   {{0x7643e70f,0x2367a710,0xe043568d,0x61f643a6}},	// [23c0] _huny, kanj_, инти, riyl,
   {{0x69cf4018,0x61f64530,0x7e7e5e7a,0x4a460c86}},	//   _eoce, siyl, tupp, _инов,
   {{0x69dbc04c,0x7d1b85bb,0x387fde52,0x23678158}},	//   kkue, _ayus, huur_, danj_,
   {{0x7c3aa711,0x7bce400b,0x7d1b8024,0xdd908032}},	//   _sitr, _wobu, _byus, صوت_,
   {{0x69c9c0b3,0xf767c5d3,0xdc2a8231,0x69c0c185}},	//   djee, _پا_, وسته_, वासी,
   {{0x25a06712,0xb4de4036,0xdb01802e,0x9cd700c3}},	//   leil_, तनी_, _balà, כונה_,
   {{0xdb088303,0xdb03c089,0x9f5c8089,0x3263909b}},	//   _kadé, _baní, cový_, атыв,
   {{0x225e005b,0xdb01801d,0x63aac10d,0xa01b0107}},	//   átky_, _salã, _safn, ltöt,
   {{0x2367838f,0x6d40a713,0x8c46a714,0x7763e715}},	//   banj_, _igma, _резе, _benx,
   {{0xbbd10185,0x25ade716,0x9f5e8053,0xdd0cc036}},	//   _सकेक, adel_, _ektò_, _półk,
   {{0x9635099b,0xb4de508d,0xdce98017,0x66f4c1dc}},	//   лноц, तनु_, _ideā, упну,
   {{0x387fc1c8,0x7a25c036,0x6602981b,0x92e48138}},	//   buur_, rótc, nnok, ışıl,
   {{0xfc3f4031,0x69cf6717,0x64440303,0x2955c0c5}},	//   _asín_, _roce, _cuii, _съхр,
   {{0xf1bf400c,0x5c040097,0x64440061,0x69cf6718}},	//   _pháo_, аяса, _duii, _soce,
   {{0xed5f8066,0x7a25c82f,0xb5fcc0f6,0x3a292719}},	//   ážka_, lóta, _ewġe, _thap_,
   {{0x2018488b,0x7c2dc0c4,0xddc800b4,0x201ee71a}},	//   _akri_, _èarr, ălţi, llti_,
   {{0x442a4693,0x24804016,0xbddb401e,0xdb0ac240}},	// [23d0] _bhb_, guim_, _lièg, _anfø,
   {{0x6e2989f3,0xf1bf400c,0x3b544441,0xe7bd8079}},	//   _sheb, _tháo_, икур, _অত্য,
   {{0x61e2de63,0xd5758d9b,0xfc3f0018,0x3a7559a2}},	//   _olol, гуль, rvíu_, улер,
   {{0x9f5c805b,0xdd01c38f,0xa2b883a8,0x66dc0051}},	//   rový_, _žučn, ्मन्, säkö,
   {{0xbc1980d7,0xf1bf671b,0x23678077,0x7e6e4396}},	//   нікі_, _iná_, tanj_, _evbp,
   {{0xe4f60275,0xfc3f0004,0x387fc68e,0x67e044c9}},	//   ीपति_, lvís_, vuur_, _höjn,
   {{0xb17b04c9,0x69dd271c,0x6e3b8359,0x7a054026}},	//   thål, kkse, _tiub, nėto,
   {{0x443cc022,0x764500c9,0x25add305,0xa2a84285}},	//   _aiv_, _muhy, udel_, _घनत्,
   {{0x25adc1e5,0x656400fa,0x601dc6ed,0x7c2ac032}},	//   rdel_, _reih, lèmi, _bhfr,
   {{0x47c5c9d3,0x69dbe71d,0x7aa5c210,0x387fc1c8}},	//   убов, skue, гиоз, ruur_,
   {{0x68e9c096,0x325587de,0x2ca9271e,0xdce08047}},	//   szed, _свер, _asad_, _odmě,
   {{0x6016801f,0x5ed7002a,0xa5bb4359,0x7a25c397}},	//   lâmp, _ডেভে, _fhói, bóta,
   {{0xdb1a8066,0x20041412,0x69c0c4eb,0x7d1d40b1}},	//   _motý, émio_, वारी, _nyss,
   {{0x69dd0051,0xaae5d094,0xdb08888b,0x7643d24b}},	//   akse, _مسعو, _sadé, _tuny,
   {{0xe81b8027,0x442a671f,0xf3f0c1b4,0x7dd5c032}},	//   _पीछा_, _rhb_, _بأن_, _fást,
   {{0xdca65828,0x290500b5,0x248044c0,0x6d4f40b9}},	//   лаби, ğlar_, tuim_, _cfca,
   {{0x7c3c6720,0x443cc022,0x61e42721,0x59b6c3fc}},	// [23e0] _pirr, _yiv_, _ilil, _अफसर,
   {{0x79898020,0x20030570,0x934640b4,0x3d04425c}},	//   _acew, cnji_, унже, _रखीं_,
   {{0xf99f4303,0x61e40303,0x2bc786fc,0x394dc062}},	//   _ijèn_, _klil, लाना, kces_,
   {{0x5f46008c,0x79860986,0x7a3ec017,0x63a1e722}},	//   _جنگل, ngkw, _jūta, heln,
   {{0x24806310,0x6281e723,0x2449e724,0xdce0c017}},	//   quim_, hulo, _núm_, kamā,
   {{0x656640f8,0xaca48044,0xdce0c017,0xbddb401e}},	//   _hekh, _ntụp, jamā, _pièg,
   {{0xa5bb4032,0x63ae40f8,0x1ae64051,0x998d8166}},	//   _shói, _iabn, _совм, _sieť_,
   {{0x64466725,0x20031b1a,0xa01b04d3,0x9874c081}},	//   _kuki, znji_, ntör, алиц,
   {{0x80a40b0d,0x63ae4022,0x090683d5,0xd9108646}},	//   _चैले, _kabn, _спан, _بیش_,
   {{0x7dd5c1b4,0x97a6c00a,0x443cc04d,0x63a1e726}},	//   _sást, урил, _qiv_, geln,
   {{0xa01b2727,0x19590523,0xb87b2728,0x7bde421b}},	//   ktör, каны_, nzív, ikpu,
   {{0x61e4005e,0xd946c244,0x386dc14b,0x0f374052}},	//   _clil, _седи, bser_, טריט_,
   {{0x7dd5c46a,0x69dd011b,0xdb18c019,0xb4de409d}},	//   _vást, rkse, _inví, तनो_,
   {{0xe7bf4079,0xd7c7808f,0x3a2b4070,0x61e400f7}},	//   _ইত্য, लायच, _shcp_, _elil,
   {{0x539bc093,0x7d1d5539,0x7dd5c1b4,0xaab7c20c}},	//   _ניהו, _syss, _tást, _مدير_,
   {{0x7bde4a26,0xa01b0107,0x61e40061,0xd2440156}},	//   ekpu, gtör, _glil, сэри,
   {{0x20032729,0x64466186,0xad9b4086,0x63ae4147}},	// [23f0] pnji_, _cuki, _hjúk, _babn,
   {{0x21290696,0xad9b4086,0xb17b04c9,0x65664a26}},	//   _izah_, _kjúk, skåd, _eekh,
   {{0x5f1840b2,0xa01b0051,0x9ac5840d,0xdb05002c}},	//   _बुद्_, stös, _kiŋŋ, _wahâ,
   {{0x2bc301b6,0xa567808c,0x63a1e72a,0x64464876}},	//   शावा, ادان, zeln, _fuki,
   {{0x6281e72b,0xdcebc283,0xdb1e00b6,0x973c8013}},	//   zulo, _ibgħ, _anpè, _maću,
   {{0xd47a4052,0x2d84406a,0x6d42c0b9,0x25ada72c}},	//   _באשל, _ömer_, _agoa, _wael_,
   {{0xd24e8ba8,0x68ed672d,0x7a01c03f,0x2bc78578}},	//   ونو_, lzad, lēti, लाबा,
   {{0x67e04041,0xf1bfc004,0xdb03c089,0xdb054359}},	//   _löjl, ñá_, _naná, cdhá,
   {{0x394dd5b7,0x660982a3,0x386de72e,0x661b8094}},	//   rces_, _ijek, user_, _ikuk,
   {{0x443e83a6,0xdb1a8018,0x7647400d,0x7dd5c10b}},	//   _git_, _cotó, _kujy, _páss,
   {{0x02060156,0xe1f9c007,0xaf98c10e,0xf1224036}},	//   изон, pių_, утых_, _मर्द_,
   {{0x1959cefa,0x656b917e,0x7c3e272f,0x3a2d805c}},	//   _рады_, nagh, _sipr, _jhep_,
   {{0x61e9e730,0xb606002e,0xb17b4041,0x4c8300c5}},	//   mhel, _aláá, _plån, оляв,
   {{0x61fbe731,0x0eb3009d,0x63a3a732,0x2d99588c}},	//   liul, ुमंड, nenn, _abse_,
   {{0x6283a733,0x64464f59,0x21760f29,0xdb03e2ef}},	//   nuno, _suki, _купр, _faná,
   {{0xd848c015,0x661b96b4,0x61fbe734,0x06074442}},	//   _họa_, _nkuk, niul, анск_,

   {{0x656b9ab2,0x1f665b55,0x7bc1a735,0x80b24028}},	// [2400] dagh, икам, _onlu, ीमें,
   {{0x60c9c6ed,0x661ba736,0xa3ea02ea,0x66098031}},	//   ixem, _akuk, _मति_, _ajek,
   {{0x68ed403c,0x66098054,0x628386f0,0x22a78107}},	//   azad, _bjek, juno, _nők_,
   {{0x61fbc150,0x2367e737,0x443ea6f8,0xe0da81bd}},	//   jiul, _lenj_, _sit_, кве_,
   {{0xf3c9001c,0x644640f8,0x3a2d8303,0xc7c68245}},	//   _شبیه_, _uuki, _dhep_, иски,
   {{0x0ca6825c,0x6283a738,0x661b80f7,0x635300a0}},	//   _गनीम, funo, _ekuk, mění,
   {{0x68fb4038,0x98b243a6,0x9f45c047,0x6d5d01c8}},	//   _ľudi, mayı_, chlé_, ybsa,
   {{0xba5742a6,0x3a3f80d1,0x61fbc442,0xdb0720c0}},	//   _כסלו_, _giup_, giul, ndjá,
   {{0x63a380de,0x973cc2d8,0x27f84b64,0xb37681aa}},	//   benn, deća, _kmrn_, _نداش,
   {{0x628387b6,0x9f58034d,0x3879c107,0x2ca9801e}},	//   buno, biré_, ásra_, çade_,
   {{0x91e6e739,0x7640a73a,0x0bb74093,0x62534283}},	//   _коже, _kimy, בלים_, _għod,
   {{0xdb1a8016,0xc983cb8e,0xdb050c1e,0x60dbc1c6}},	//   _fotò, _души, _nahá, byum,
   {{0x20181d58,0x2bc9448b,0x6fdd80ce,0x4dc8802a}},	//   fori_, रामा, _bèch, _শতাং,
   {{0x8fa3c911,0x6fb3c032,0xdb1c4031,0x249247cb}},	//   _маче, _ومنا, _joró, dtym_,
   {{0x69c2c1b0,0xe817884d,0x2247c085,0x6d44005e}},	//   _knoe, दकता_, _gunk_, _fgia,
   {{0x6e2d1fc8,0x9f5ec359,0x5187401d,0x63a39a1d}},	//   _uhab, intí_, јува, zenn,
   {{0xdb074066,0xb87b0107,0xdef88085,0x629e0157}},	// [2410] _vají, gzít, _deċi_, _eppo,
   {{0xd6db5d8f,0x6609811b,0x6283a73b,0xdb17001f}},	//   кте_, _sjek, yuno, _enxá,
   {{0x6fc94036,0x4423041b,0x660980fd,0x75298107}},	//   राबं, mlj_, _pjek, _szez,
   {{0x61fbc018,0x76408024,0x61e9e73c,0xa5bb529a}},	//   xiul, _cimy, xhel, _chót,
   {{0x6abaa73d,0xa8a78051,0xc1048032,0xf1bf40d1}},	//   _artf, ррек, يومي, _nhái_,
   {{0x61fd273e,0x69c2e73f,0x62839708,0x9f582740}},	//   hisl, _anoe, tuno, tiré_,
   {{0x3f8780b3,0xbab583d0,0x5187943c,0x63a5406f}},	//   rgnu_, сёлы, _вуза, mehn,
   {{0x2367c60f,0x63a542ad,0x78ad08a1,0x3ebe4086}},	//   _senj_, lehn, _osav, _átta_,
   {{0x5ef94079,0x61fbc119,0x7076c032,0x2ca9402c}},	//   _অডিও_, riul, مميز_, nwad_,
   {{0xdb0e4053,0x61fbe741,0x6283a742,0x7d048359}},	//   _babè, siul, puno, úise,
   {{0x60dbc056,0x61fbc119,0x7a23854a,0x261c830d}},	//   syum, piul, võtj, cíos_,
   {{0x61e9c00b,0x78bba743,0xb17b4588,0x98a605f5}},	//   qhel, _kruv, _blåm, биме,
   {{0x7ddf00fd,0xd848c0d1,0xdcf60696,0x6569a20b}},	//   _mësh, _tọa_, _payı, _meeh,
   {{0x973cc654,0x7ddf00fd,0xe8df800c,0x66198036}},	//   seća, _lësh, _ngọn_, howk,
   {{0xdb01c05f,0x32068d6e,0x66e32345,0xc255c4a4}},	//   kelé, ynoy_, пора, _اختت,
   {{0xa3b805da,0x2d8d8022,0x2291c107,0x395fe744}},	//   _घोर_, _ncee_, mák_, nbus_,
   {{0x2ca94010,0x25fd0036,0x2291c804,0x6e2f405e}},	// [2420] gwad_, _लगती_, lák_, _dhcb,
   {{0x201806e2,0x44230077,0x3b860217,0x799b840d}},	//   qori_, clj_, _улог, _abuw,
   {{0xdb03c01d,0xa13641aa,0x1c39409b,0xdb0e488b}},	//   _danç, _گردش, рять_, _kabé,
   {{0x765c0010,0xed5a40c5,0x3d18d543,0x09b6c062}},	//   mpry, _щом_, _पडले_, _अफेय,
   {{0x7989e745,0xad9b402e,0x25f6c028,0x6d464010}},	//   dgew, _ajúw, एफसी_, _igka,
   {{0x80d14079,0xd848c015,0x2291c107,0x69d6001e}},	//   _সেক্, _bọn_, kák_, _loye,
   {{0x7989e746,0xaaba0045,0xd7e76641,0x7cef0031}},	//   fgew, ॉमिक, _умре_, _kòré,
   {{0x6e2445bb,0x69d62747,0x7989d69b,0x261c8996}},	//   nlib, _noye, ggew, ríos_,
   {{0x7bd54561,0x6d46402f,0x78bb8d27,0xdd8f8107}},	//   _yozu, _mgka, _gruv, _سول_,
   {{0x764880f8,0x4adc46fc,0x61fd002c,0x13f4c0d9}},	//   _tudy, _यथाव, wisl, ізня,
   {{0x69c401b7,0x61e2828d,0xf54f4112,0xfd4d80eb}},	//   _bnie, okol, _kụta_, _nshọ,
   {{0xf4004079,0x5693c09b,0x24806748,0xb95b4031}},	//   ্তির_, чают, krim_, _anìn,
   {{0xdb074c1e,0xf1c5c1f9,0x1dc5c8b8,0xa5bb002d}},	//   _majá, वारन, वारत, blón,
   {{0x2291e749,0x6d46674a,0x61fd274b,0x69c400d2}},	//   bák_, _agka, sisl, _enie,
   {{0x9b580119,0x69d6041d,0x9f5a401e,0x69c4017a}},	//   сист_, _foye, cipé_, _fnie,
   {{0xa5bb4070,0xdb03cf52,0x61e2a74c,0x4cd1402a}},	//   _ahór, _sanç, jkol, _সেগু,
   {{0xe1ff2308,0x61e29466,0x7642c12c,0x2007a74d}},	// [2430] mió_, dkol, _mioy, ynni_,
   {{0xdd310064,0x9f4541df,0x61e28f6f,0x6e2441ae}},	//   _mężc, _ölü_, ekol, alib,
   {{0x6441a74e,0x2bc78048,0x61e340b4,0x660d0176}},	//   _rili, लासा, _înlo, _kjak,
   {{0x3ebe0065,0x19ab4b0c,0xf8bf402e,0x7a054007}},	//   ætte_, _стоп_, _ayée_, kėti,
   {{0xdb0503a6,0xa5bb4032,0x62871f53,0x629500fc}},	//   _bahç, _fhór, lujo, ltzo,
   {{0x7a054039,0x660d02bc,0x3209674f,0x973cc38f}},	//   dėti, _ljak, lnay_, jećo,
   {{0x656f2750,0x02b38021,0xdb088016,0x629501a8}},	//   kach, ंटेन, _cadà, ntzo,
   {{0x656f2751,0xe1ff0070,0x395fc006,0x78bba752}},	//   jach, jió_, ubus_, _truv,
   {{0xd848df18,0x60cd4160,0x6441a753,0x7658c039}},	//   _wọn_, nxam, _tili, _atvy,
   {{0xcf39c11b,0x2251c066,0x61ed6754,0xdb1e006a}},	//   ичні_, ízko_, hhal, _popü,
   {{0x060a009b,0x69c402c7,0x8e0a0210,0x656f2755}},	//   инок_, _pnie, инов_, fach,
   {{0x2291c6c4,0x3634c032,0xa2b888b8,0x7ddcc396}},	//   rák_, _فرنس, ्मर्, _bésu,
   {{0xdb038066,0x63a71396,0x32094149,0xf99f4303}},	//   dené, fejn, dnay_, _ijèh_,
   {{0x7bc3c397,0x9f45c019,0x653a8052,0x8afe809c}},	//   _unnu, riló_, יערד, waƙi,
   {{0x6609c4fd,0x644be756,0x656bc0c9,0x752d2757}},	//   onek, _hugi, _kegh, _ezaz,
   {{0x6443e758,0xceb282a6,0xa5bb53c3,0x248046a6}},	//   _hini, ויל_, _akób, trim_,
   {{0x3a20042c,0x4425c73f,0x6609e759,0x765c1503}},	// [2440] _ikip_, oll_, inek, spry,
   {{0xdb1c410d,0x6443e75a,0x6281c353,0x248040fd}},	//   _borð, _jini, orlo, rrim_,
   {{0xd9465201,0x5ea643a9,0x644be75b,0xdb038c1e}},	//   _мени, تمال, _lugi, bené,
   {{0x64a684c5,0x61e98157,0x2bdc4185,0x201a40f8}},	//   жада, _clel, _मकवा, sopi_,
   {{0xf1bf4015,0xa6dec00c,0x93fe0048,0x61e44cb1}},	//   _cháu_, _ngưn, _उगाच_, mkil,
   {{0xdb1aa75c,0x7524000d,0x2716c047,0xdb1c4086}},	//   _antá, _myiz, něné_, _forð,
   {{0x9f5c8089,0x533391e8,0x6d46c089,0x2176823d}},	//   nivé_, мешт, žkam, _муар,
   {{0xd49ac979,0xe1ff06ed,0xbcfb402e,0x7ddce75d}},	//   аро_, xió_, _adéy, _nést,
   {{0x9f47834d,0x973cc41b,0xc05ac0d9,0x752416a3}},	//   ginó_, tećo, шій_, _nyiz,
   {{0x33d5812b,0xdb03a75e,0x5397c051,0xbea6a1c8}},	//   _ніхт, zené, овья_, _мазк,
   {{0x69c65230,0x320941c8,0x61e4675f,0x644bc0b9}},	//   _onke, ynay_, kkil, _eugi,
   {{0x29dc40e1,0xdb038004,0x61ed6760,0x7bda1f1b}},	//   _mías_, xené, xhal, ötun,
   {{0x6281c1b0,0x47ad802a,0x9f479554,0x682d8032}},	//   arlo, চারী, cinó_, lúda,
   {{0xd250c1b4,0xbddb4315,0x36d513d0,0x9c838047}},	//   _كنت_, _cièn, погр, _účet,
   {{0x63a70e66,0x63b50279,0xf96b41bc,0x3a20007a}},	//   rejn, rdzn, ирай_, _fkip_,
   {{0x61e4616b,0x6288e761,0x7bd8c4f5,0x533420a2}},	//   gkil, mudo, _hovu, фест,
   {{0x68fb4166,0x752d2762,0x7bd70080,0x0596001c}},	// [2450] _ľuds, _uzaz, _toxu, _رايگ,
   {{0x3f8ccd94,0xcd340032,0x2fd8405e,0x62870070}},	//   ngdu_, _غريب, _corg_, pujo,
   {{0x644500f8,0xd848c112,0x2bdc48b8,0x6609e763}},	//   _iihi, _sọl_, _मकरा, ynek,
   {{0xdb018032,0x61ff4561,0x6dc78280,0xd848c25d}},	//   _talú, qiql, غزال, _pọl_,
   {{0x3ebe85f5,0x24f8839d,0xad9b4107,0x656be764}},	//   _artt_, онцы_, _amúg, _regh,
   {{0x6288e765,0x656bc0c4,0x6445009c,0xb4e74314}},	//   kudo, _segh, _jihi, बनी_,
   {{0x6443e766,0xb4e3c185,0x9f5ec016,0x661d2767}},	//   _rini, नन्_, mitè_, kosk,
   {{0xf1b9db1a,0x64452768,0x349595bc,0x6723c05c}},	//   koše_, _lihi, _набр, _rynj,
   {{0x212d8570,0x656be769,0x657b8449,0x24588025}},	//   _uzeh_, _vegh, _iduh, _мать_,
   {{0x200158da,0xe8f6c039,0x201ca76a,0x61e441a8}},	//   nihi_, ялы_, covi_, zkil,
   {{0x2716c047,0x2489424c,0x7a054007,0xe61a19a2}},	//   věné_, huam_, lėtu, йдо_,
   {{0x3869276b,0x2d9dc1c6,0x9f479554,0xc7b8c0ab}},	//   _bwar_, _ubwe_, pinó_, vođe_,
   {{0xdb03c80f,0x7bc7415d,0x6459c809,0x7a13c0b4}},	//   _janú, _onju, _utwi, găte,
   {{0x4444276c,0xd11c449d,0x7ddcc060,0x683200b0}},	//   _qi_, _भुषण_, _féss, kæde,
   {{0x9f5ec0fd,0xdb03e76d,0x321d8036,0x442100f8}},	//   zitë_, _lanú, kowy_, _dkh_,
   {{0x2fd8676e,0x798d676f,0x67ef8065,0x40962770}},	//   _sorg_, ggaw, _højd, _ерот,
   {{0x64452509,0x63b5403f,0xf1b9c2a3,0x32020066}},	// [2460] _fihi, _bazn, coše_, miky_,
   {{0x657ba771,0x69d9c093,0x4abd85a3,0x6d49817b}},	//   _aduh, _lowe, ्माव, _agea,
   {{0x25a96017,0xf1bf0004,0x6832093b,0xe7db00c3}},	//   beal_, ilán_, rædd, _הקיש,
   {{0x628fc064,0x0446404c,0x7bc7411c,0x9f582772}},	//   ńcow, _немн, _enju, lirà_,
   {{0x65644c47,0x25a00033,0xdb18c041,0xc1bb40c3}},	//   mbih, _mbil_, _invå, _המכש,
   {{0xe3b8c3a6,0xa533893d,0x9f582773,0x62974022}},	//   rlık_, хніч, nirà_, btxo,
   {{0x9f5ec0fd,0xa01b0851,0x78a2e774,0xd2578523}},	//   sitë_, krön, _spov, пцы_,
   {{0x2fc7c303,0x682d8359,0x2d8de775,0x1dd08db4}},	//   _anng_, rúda, ggee_, _सचित,
   {{0x7646417b,0x61358107,0xa0678403,0xdb07013b}},	//   _miky, rülé, _ната_, tejë,
   {{0x764e56b4,0x25a0009d,0x7b078107,0x25a94379}},	//   _kuby, _abil_, ártá, zeal_,
   {{0x661d2776,0x9f5ee777,0x2127400c,0x8146c79d}},	//   tosk, nité_, ́nh_, _فنان,
   {{0x63a8ddc3,0xaca441c0,0x78ad4033,0xb05b0041}},	//   sedn, _awọt, ywav, nväg,
   {{0x64452778,0xdb1e00b6,0x764e6779,0xbddb4303}},	//   _pihi, _anpà, _luby, _dièl,
   {{0x307bc2a6,0x2d9c4107,0x765c44c9,0xead0c1c0}},	//   _פאונ, ővel_, _otry, _dẹri_,
   {{0x7bc8805c,0x69d9e77a,0x62988f64,0x798d677b}},	//   _mndu, _yowe, ntvo, tgaw,
   {{0x78ad40bb,0xdb1a8041,0x629884f1,0x7a25d412}},	//   twav, _intä, itvo, tóti,
   {{0x7646402f,0x73d941a2,0x386906df,0x63b5677c}},	// [2470] _diky, одар_, _uwar_, _pazn,
   {{0x4ab0c22d,0x44210033,0x9f58023f,0xaab0c185}},	//   _जनाव, _ukh_, cirà_, _जनाक,
   {{0x2003277d,0x2452c015,0x321d8064,0xd6db40c5}},	//   miji_, _lâm_, towy_, щта_,
   {{0xa2c08a94,0x98b902d6,0x2cadc1f4,0x68320065}},	//   विन्, lası_, ywed_, ræde,
   {{0x7bdaa77e,0x201ecc38,0xb9224044,0xb17b4588}},	//   _botu, koti_, _mkpị_, _blåv,
   {{0x645d41c6,0x61ed1fc2,0x6e22e77f,0xdb0e45e5}},	//   _itsi, _llal, _akob, _zabí,
   {{0xe29998c8,0x764e6780,0xe69281aa,0xb8d4809d}},	//   цай_, _guby, نلود, _छै_,
   {{0xb9c581b4,0x44234033,0xb4db405e,0xe459c19b}},	//   _تقري, _hkj_, _agài, ожи_,
   {{0x69c9a781,0x656f6782,0x660d427c,0x3a29402f}},	//   _inee, _mech, inak, ilap_,
   {{0x69c98046,0x2452c015,0x69db814b,0x644f6783}},	//   _hnee, _dâm_, _houe, _muci,
   {{0x61ed2784,0x69db814b,0x98b900b5,0xc9aa13f8}},	//   _blal, _koue, dası_, овне_,
   {{0x9f58212b,0xd6d8804c,0x61ed0033,0xf2d24009}},	//   dirá_, _эту_, _clal, דעט_,
   {{0xe8f710fc,0x32020066,0x2bb240e9,0x6d59c398}},	//   для_, riky_, ीयमा, _ifwa,
   {{0x61ed005a,0x660dc06c,0xa3ac4b35,0xdca2cce0}},	//   _elal, čaku, कड़ा_, _раши,
   {{0x50430505,0x764640f8,0x9f5ec1cb,0x00000000}},	//   терб, _piky, xité_, --,
   {{0xbbda8021,0x290ec2bc,0xdb038066,0x8e3a008c}},	//   _बक्क, šmaš_, jení, _بستر_,
   {{0xdcfd438a,0xdb03805b,0xa3bd809d,0x25fd45d5}},	// [2480] _bası, dení, इया_, रोधी_,
   {{0x69c9a785,0x6e29c235,0xe50ec705,0x68e2812c}},	//   _anee, hleb, ापति_, vyod,
   {{0x645d6786,0x9f5802b0,0x644f4018,0x69dba787}},	//   _etsi, cirá_, _euci, _boue,
   {{0xe45f4041,0xda0e008f,0x09068179,0x27ec805c}},	//   _bröd_, ाचित_, мпен, _sldn_,
   {{0xc1734093,0xe3b8c38a,0xb05b04d3,0x9f5ec669}},	//   _בחר_, ydı_, rväg, sité_,
   {{0x6d59ca26,0x2365c0b3,0x69c981ae,0xe3b8c080}},	//   _afwa, jblj_, _enee, xdı_,
   {{0xdb07005f,0x2d969654,0xc6e8c079,0x7ae380d9}},	//   tejé, _орас, _পশ্চ, gynt,
   {{0x69dba788,0x7ddcc2b0,0x6e29e789,0xb4db678a}},	//   _goue, _césp, gleb, _afày,
   {{0x3ea9c570,0xdb050031,0x973cc077,0x201ee78b}},	//   _ćata_, _dahù, meći, toti_,
   {{0x660080f8,0xad9b0032,0x2486a78c,0x200ce78d}},	//   _hmmk, giún, mrom_, undi_,
   {{0x61ed278e,0x660d43a6,0x3a294006,0x6604431c}},	//   _plal, ynak, ylap_, kiik,
   {{0xd3788043,0xd257c0d7,0xdb1c44c9,0x00e6e641}},	//   _doće_, ьць_, _inrä, _ожен,
   {{0x98b9038a,0x6eb883ae,0x3e7a8017,0x200e8157}},	//   tası_, ्मकु, līt_, onfi_,
   {{0xdb038047,0x6448a78f,0x7fb8c01c,0x60c2e790}},	//   zení, _jidi, _رهبر_, _irom,
   {{0xdb08c05f,0x61ed2003,0x3e7a803f,0x24868061}},	//   kedé, _tlal, nīt_, hrom_,
   {{0x62854066,0x63b8d27d,0x660d4719,0x61ed00c2}},	//   vrho, _havn, unak, _ulal,
   {{0x6447407a,0x7b670844,0x2298cde9,0x8cc28dd0}},	// [2490] _piji, _отне, lék_, लिफो,
   {{0x7a12003f,0x69c98b32,0x21290dff,0x69db8053}},	//   nātn, _snee, _iyah_, _soue,
   {{0x625341b7,0x660d4033,0xe0d0801c,0x644f4360}},	//   _għol, pnak, یزه_, _wuci,
   {{0xd1318032,0xdb01c066,0x6e20e791,0x050d402a}},	//   هما_, nelá, jomb, _শরীর_,
   {{0xdb03802d,0x415a421d,0x3eb9c017,0x07a585a6}},	//   rení, _מדרג, āsti_, еалн,
   {{0xbcfb4031,0x629acc9f,0xf1bf0089,0x69a1c047}},	//   _feér, ktto, dlám_, क्नी,
   {{0x6e20c2b0,0x2bd2c048,0x2ca6e792,0x48ff8027}},	//   fomb, ताना, _apod_, _शेरो_,
   {{0xfe4391be,0x9e480166,0xf77040fb,0x24864007}},	//   _شکای, _keďž, _ماہ_, šome_,
   {{0x44214498,0x7ae3a793,0x6d5b8150,0x6e3601f4}},	//   ooh_, synt, _ifua, _rhyb,
   {{0x0e65c466,0x443c8077,0xb4bd915e,0x224900b9}},	//   нкон, cmv_, ेमी_, _aiak_,
   {{0xdb0e4443,0xe9ff8015,0xf99f00c5,0xfbd24093}},	//   _kabá, _giản_, ffè_, אתי_,
   {{0x68e46794,0x02bd825c,0x60c2e795,0x98a0c039}},	//   yyid, ्मीन, _from, _šią_,
   {{0x25adc3c3,0x64a5c0d7,0xf1b9a796,0x39440041}},	//   meel_, _чала, _maš_, äms_,
   {{0xad9b0032,0x644881c8,0x6d4d2797,0x7bcac0bb}},	//   liúl, _xidi, _egaa, _gnfu,
   {{0x69dd4c46,0x76b3803a,0xada64051,0xad9b0086}},	//   _bose, _bəyə, навл, gnús,
   {{0xa2c08e1a,0x7bcac077,0xad9b0032,0x63b8c043}},	//   वित्, _znfu, niúl, _zavn,
   {{0x248de310,0x6606204e,0x61e9c15d,0x26c34303}},	// [24a0] nuem_, mikk, ikel, _arjo_,
   {{0x2bd2c5de,0x442151ca,0x1f660187,0x60c401c6}},	//   ताया, goh_, _яком, _irim,
   {{0x68e45eb5,0xdcf485c7,0x973cc5c7,0x7bdc410d}},	//   syid, đači, teći, _voru,
   {{0x6d5980f7,0x7c2a81f4,0x69dd6798,0x2005d9c2}},	//   gcwa, wlfr, _gose, hili_,
   {{0x973cc0e0,0xbcfb41c0,0x2129005c,0xf1b9811a}},	//   reći, _aféf, _xyah_, _daš_,
   {{0x66062799,0xb05b537b,0x2486a79a,0xdb1a8018}},	//   hikk, _krän, rrom_, _intú,
   {{0x2cb241f4,0x9f5a4070,0xa96a8d32,0xdb01c240}},	//   lwyd_, cipá_, _нива_, lelæ,
   {{0x6448a79b,0x69dd5169,0x60c4279c,0x6576679d}},	//   _widi, _xose, _orim, nayh,
   {{0xa3d083b0,0x69cbc033,0xbc6a81aa,0x629c279e}},	//   षाद_, _dnge, _رمان_, htro,
   {{0x9f4cc815,0xa2c08e18,0x2d80002e,0x3204c064}},	//   vidó_, विद्, _adie_, simy_,
   {{0x63ae0185,0xf1b9c3c5,0x7dd8405f,0x212925be}},	//   debn, soša_, _dísz, _syah_,
   {{0x66060b44,0x2298cde9,0xad9b0032,0xa3d248c5}},	//   gikk, rék_, ciúl, वाड_,
   {{0x629c0498,0x2ca6c71c,0xdb038574,0xd5afc3be}},	//   etro, _upod_, mená, _دفن_,
   {{0xdb01c018,0xa5bb4031,0xdb03a79f,0x6e228149}},	//   selá, _ekól, lená, hoob,
   {{0xdb1a8070,0xf1c5c185,0x68304041,0x628e075e}},	//   _antú, वाचन, tädn, gubo,
   {{0x6d4d0057,0x99cf4079,0x2cb241f4,0x8e83c032}},	//   _ugaa, রস্ক, fwyd_, _إليه,
   {{0x2cb241f4,0x04f2802a,0xb17b44a0,0xc61d00e4}},	// [24b0] gwyd_, জপুর_, _slås, नवीय_,
   {{0x6fb856f6,0x7bde0085,0x61e9e7a0,0xd7c9401c}},	//   нгур_, _gopu, zkel, بوطه_,
   {{0x629c0825,0xb4e988b8,0x56954051,0x61e9e7a1}},	//   ctro, मन्_, тает, ykel,
   {{0x2467c031,0xf1bf056e,0x443842ad,0x69df06a6}},	//   _jímò_, dlák_, _ehr_, _joqe,
   {{0x44384123,0x7bde0070,0xdb038066,0x2005ceb3}},	//   _fhr_, _yopu, dená, yili_,
   {{0x2005c03a,0xd83880ce,0x660627a2,0x6e2d4506}},	//   xili_, _chč_, zikk, llab,
   {{0x25a48077,0x69cbc07a,0xad9b0032,0x3da78039}},	//   _fbml_, _pnge, tiúl, _праб,
   {{0x644ae7a3,0x248de7a4,0x63a480b3,0x442ce7a5}},	//   _aifi, tuem_, đina, eld_,
   {{0x25adc101,0x66060134,0x00db83be,0x63baa7a6}},	//   reel_, vikk, _عبرت_, _fatn,
   {{0xe9df41b4,0x44258033,0x7c38c011,0xf09442a6}},	//   _siúl_, _ukl_, _chvr, אנץ_,
   {{0x442327a7,0x35c68c63,0x2ca927a8,0xbcfb0004}},	//   doj_, _रोड़, _apad_, ncéf,
   {{0x63a5005e,0x224b4aa1,0x7c23a7a9,0x63ae0157}},	//   _abhn, _nick_, lonr, webn,
   {{0xe3aec78b,0x63ba8033,0xeb99e7aa,0xdb01830d}},	//   _кб_, _yatn, _жил_, _taló,
   {{0x6e2d5062,0x6d5d67ab,0x6d5bc070,0x69cd017b}},	//   elab, _afsa, lcua, _enae,
   {{0x63ae0038,0x7a13c119,0x4427c05c,0xfc48c0d1}},	//   rebn, năto, _ikn_, _cửu_,
   {{0x60c412c5,0x6d5be7ac,0x644acd08,0x248967ad}},	//   _trim, ncua, _zifi, fram_,
   {{0xe3ba400a,0x7a38a7ae,0x1d074495,0x248967af}},	// [24c0] мба_, níte, вети_, gram_,
   {{0x6e2d67b0,0x2cb241f4,0x0fc94036,0x26c580c4}},	//   alab, rwyd_, रागढ, _orlo_,
   {{0x3ddf81d4,0xf98650d0,0x443a005c,0x2489410b}},	//   _bouw_, _игно, _ihp_, aram_,
   {{0xa3c8d1aa,0x4427e7b1,0xb1130efc,0x443a005e}},	//   _लोन_, _lkn_, pụta, _hhp_,
   {{0x442ce7b2,0xf9930093,0x26c580fc,0x40968051}},	//   yld_, שרד_, _arlo_, трет,
   {{0x6602e7b3,0xdb18c0d2,0x78fb00c3,0x6288c3ad}},	//   _smok, _favè, ופנו, yrdo,
   {{0xe7a40891,0x764be7b4,0x7bce5628,0x63a327b5}},	//   ख्यप, _bigy, _inbu, _önne,
   {{0xd848e7b6,0x6e93449f,0x7ae356df,0x443a035d}},	//   _lọt_, _خلفا, änte, _lhp_,
   {{0x7a38805f,0x644ac34d,0xd9438dd3,0x224040f8}},	//   gíte, _pifi, _вети, imik_,
   {{0x9ed8c01d,0xdb0180d2,0x394fd05f,0x61e085ca}},	//   емот_, _valò, _eggs_, _homl,
   {{0x442ce7b7,0xd5afe7b8,0xd00f84a4,0x61e090bb}},	//   rld_, _кс_, _ظلم_, _koml,
   {{0x3ebe4086,0x6e2d4018,0xdb1c013b,0x067b4052}},	//   _áttu_, xlab, adrë, ונטל,
   {{0xd848e7b9,0x973cc013,0x7982c1c0,0x2a054044}},	//   _bọt_, veću, _idow, ịaka_,
   {{0x9f4a40d2,0x7aedc09c,0x6e2d67ba,0x629e597a}},	//   _albí_, _ƙatt, wlab, ktpo,
   {{0x973cc0ab,0x2bd527bb,0x2019c694,0xf837c0c3}},	//   teću, दाबा, ésie_, _שנות_,
   {{0xf8b6c0df,0x61f641f4,0x9964590e,0x69cd0150}},	//   _अनाय, ghyl, итул, _unae,
   {{0x31791243,0x6d5f00f6,0x7a13c0cc,0xe3b8c561}},	// [24d0] masz_, _ifqa, zăto, llıq_,
   {{0x4427400c,0xa3d5c22d,0x4427c05c,0x7a361b87}},	//   ôn_, हाय_, _xkn_, máta,
   {{0xe3b8c03a,0x25a6c011,0x61e09cf4,0x46154032}},	//   nlıq_, _obol_, _boml, _مودر,
   {{0xfd1f402e,0x200780f7,0xa01b0086,0x752d00bc}},	//   _adìe_, wini_, fsög, _kyaz,
   {{0x1da50a94,0x0d84811e,0x458480d9,0x24894080}},	//   ग्यत, рлін, ргів, qram_,
   {{0xf41f04c9,0x764d27bc,0x229c4089,0xdb1a8b94}},	//   kräm_, _liay, bík_, _katè,
   {{0x3a2927bd,0x31791243,0x6569c31d,0x3c39c01e}},	//   _okap_, kasz_, tbeh, nève_,
   {{0x442e8101,0x8504808f,0x7a13c0b4,0x5f74405f}},	//   alf_, _शेवट_, răto, _ماہر,
   {{0x75f5c185,0xa5bb4031,0x391582d5,0x78a98066}},	//   _náze, _akók, _смар, _upev,
   {{0xd378c036,0xa7b5cafa,0x61438031,0x9f5ec157}},	//   gać_, усиј, _ẹlò, gità_,
   {{0x7a38a245,0xa91d8a11,0x26c5823f,0x764bc0f8}},	//   síte, _udžb, _urlo_, _tigy,
   {{0x394fc127,0x752d19f1,0x28c784d8,0x7bdac13b}},	//   _uggs_, _byaz, लिपि, ajtu,
   {{0xc7a5c95c,0x53a5c030,0x69dbc077,0xdb1c67be}},	//   _билк, _балб, mjue, _carê,
   {{0xec358052,0xd378c062,0x44150f37,0x6fb38045}},	//   טאָר_, cać_, афст, ंजिं,
   {{0x539ac093,0x9324c01c,0xfb24c16a,0x752d163e}},	//   _ניקו, _پرون, _پروپ, _eyaz,
   {{0x4425e7bf,0x63bc454a,0xdb01c4d3,0xdb1c27c0}},	//   lol_, _sarn, relä, ndré,
   {{0x7a360018,0xdb0e0086,0xdb1a813b,0xa3c8e7c1}},	// [24e0] cáta, ndbú, _patë, _लोड_,
   {{0x61ed67c2,0xb143460e,0x63bc67c3,0x6e29a7c4}},	//   akal, снул, _qarn, _akeb,
   {{0x179b0009,0x66e607f1,0x61e08618,0xb05b0041}},	//   _אייב, _сона, _poml, nvän,
   {{0x249fd914,0x63bc67c5,0x63be27c6,0xa5bb1792}},	//   ktum_, _warn, _hapn, llór,
   {{0x5c06811e,0xa0754051,0x2eb0e7c7,0xbcfb01cb}},	//   ляка, _высш, _जन्त, ccéd,
   {{0xbddb40ce,0xb4c067c8,0xa01b0086,0xf1bf0089}},	//   _chèf, ंटी_, rsög, zdá_,
   {{0x61e0a7c9,0x6609c353,0x645dc086,0x224d805c}},	//   _toml, fiek, ísin, _fiek_,
   {{0x2bd24c7e,0x798427ca,0x38668041,0x5d54c47f}},	//   सावा, _ndiw, ppor_, шкит,
   {{0x2ca05fdb,0x25d74009,0xc79680a3,0xd378c064}},	//   ntid_, רופן_, _مشاب, tać_,
   {{0xad9b01b4,0x21f1c066,0x60cdc1be,0x224d815d}},	//   miúi, _váha_, _šamc, _ziek_,
   {{0x752d00c9,0xdb03a7cb,0xad9b01b4,0x8f34e3e6}},	//   _syaz, venç, liúi, ренц,
   {{0x2ca0454a,0x75f84185,0x6441e7cc,0x27e100fa}},	//   ktid_, _jízd, amli, _sohn_,
   {{0xad9b0032,0x200a27cd,0x9f5ec016,0x442a40fd}},	//   niúi, fibi_, pità_, _okb_,
   {{0xf41f44d3,0x682da7ce,0x69c0e7cf,0x3083c032}},	//   _iväg_, túdi, ldme, _الوف,
   {{0x59b8c036,0x3f874086,0xad9b0032,0x9f5ecfb4}},	//   _आसार, ónum_, hiúi, citá_,
   {{0xb4c067d0,0x9f51046a,0x644e67d1,0xa3d5c2ea}},	//   ंटू_, tizó_, _aibi, हाथ_,
   {{0xdbd2409d,0x3a26814b,0xab755614,0xcfb7c02a}},	// [24f0] _füüs, doop_, игаш, জারন,
   {{0x224da7d2,0x9f5103e9,0xb6068011,0x41c30fb2}},	//   _siek_, rizó_, _lašć, षयवस,
   {{0x41559151,0x41e7913b,0x5d559654,0xf3ff001f}},	//   авес, ліда, акет, lpão_,
   {{0x25b241c8,0xdb1c40d2,0x249fd9c3,0x9980402d}},	//   ceyl_, _marè, ytum_, tliť_,
   {{0xdb17090a,0xed59c2bc,0xeb99a7d3,0x7a360347}},	//   _maxí, jdža_, вил_, kátn,
   {{0x6609c064,0x25bdc1f4,0x644e67d4,0x224d8036}},	//   wiek, _sawl_, _gibi, _wiek_,
   {{0x4425e7d5,0x77770283,0xb6068123,0x09f5c393}},	//   vol_, _mexx, _bašć, ичия,
   {{0x270e803a,0x644e67d6,0x78ad0047,0x2bb7e7d7}},	//   _dən_, _zibi, _opav, _असहा,
   {{0xfa34801c,0x443cddda,0x69a1d15e,0x764f4f2d}},	//   _طرفد, _bhv_, क्षी, _micy,
   {{0x7a12003f,0x656d4056,0x78bb8570,0x764f4036}},	//   māti, hbah, _isuv, _licy,
   {{0x3ea5cce0,0x44278a38,0x25bfa7d8,0xad9b4031}},	//   шинг, mon_, _kaul_, _amúm,
   {{0xd9460a49,0x63be27d9,0x3f858123,0xdb074107}},	//   иени, _sapn, _hdlu_, _hajó,
   {{0x200a27da,0xed4ee497,0xdb03a7db,0xdb1c40fd}},	//   tibi_, _фо_, senä, _parë,
   {{0x64438032,0x660b80fa,0x9f478032,0xb4fac0c3}},	//   nmni, higk, dhnú_, _בפני,
   {{0x6443a7dc,0x4427a7dd,0x5275d0fc,0xf1bf4031}},	//   imni, ion_, _тулу, _baá_,
   {{0x656d4e67,0x7a360066,0xdb1e00da,0x716641b4}},	//   gbah, máto, _hapë, شارك,
   {{0x273c0031,0x975646b1,0x6b9b006f,0xdb1e013b}},	// [2500] _bání_, атељ, đugr, _kapë,
   {{0x307b0093,0x27228166,0x657bc10b,0x656d41c8}},	//   _שאינ, nčné_, hauh, abah,
   {{0x78bb8c99,0x60c99698,0x237741aa,0xdb1c464c}},	//   _asuv, _arem, شمند_, _karé,
   {{0x7053078a,0x61e4004c,0xc8668911,0x644e67de}},	//   _دنیا, _joil, атки, _wibi,
   {{0x649a9efa,0xdb074070,0x3a2680bf,0x683040fa}},	//   ттер_, _bajó, roop_, hädi,
   {{0x7a3d005f,0xa3ba4185,0xb2270086,0x248de7df}},	//   méte, _अघि_, _klæð, drem_,
   {{0x645bc070,0xb6068570,0xd33540d7,0xd00740b4}},	//   equi, _pašć, _гэты, _тере_,
   {{0x6ca6d0f2,0x66164051,0x443cda04,0x7866811b}},	//   арож, nnyk, _shv_, _вказ,
   {{0x94a983be,0x69c0c0d9,0x387fcb0e,0x26174283}},	//   _مطلق_, rdme, gsur_, dħol_,
   {{0x53e6c0b4,0xdb154107,0x245bc14d,0x2258525f}},	//   рциа, _hazá, _dêm_, _kurk_,
   {{0x3fc8c78a,0x869a8d9b,0xec374093,0x7a3627e0}},	//   ندگی_, _штат_, שאיר_, gáto,
   {{0xa3d2454a,0x69c2a7e1,0x248067e2,0x69c0a7e3}},	//   वाँ_, ndoe, ksim_, _jame,
   {{0x98b818c8,0x61e427e4,0xdb1c4018,0x645bd2a2}},	//   алят_, _doil, _daré, cqui,
   {{0x7792c5d3,0x7a3d0fa3,0xed598026,0x25bf0123}},	//   _بیدا, déte, _maža_, žul_,
   {{0x7c28e7e5,0x89d904fc,0x656d45bb,0x75f5c05f}},	//   modr, _موثر_, tbah, _háza,
   {{0x78a28089,0x80ad8879,0x69c0a7e6,0xdb18c05f}},	//   ktov, চিত্, _name, _javí,
   {{0xa3b68036,0xf1da8314,0x2608454a,0x444467e7}},	// [2510] ज़ा_, णानन, _सगरी_, fm_,
   {{0xf3675720,0xb8ff4185,0xeb93438b,0x4444417b}},	//   ртан, _थप_, تظر_, gm_,
   {{0xa3d0854a,0x752f4036,0x25bfa7e8,0xe945401c}},	//   षाई_, _wycz, _paul_, _گردی,
   {{0x386944a0,0x69c09ef4,0x2d9927e9,0x66eac03a}},	//   ppar_, _came, ngse_, məkd,
   {{0x7a3d02b0,0xfd10800f,0x660d67ea,0xf1bf0107}},	//   céte, وجه_, miak, llás_,
   {{0xa01b04c9,0x289a0052,0xe8f88039,0xdb03802d}},	//   mrös, ריװא, шлі_, menú,
   {{0x3866c01d,0x6e2d0f6f,0x6443a7eb,0x629500b3}},	//   _ator_, _okab, rmni, nuzo,
   {{0xef1fc06a,0x4095d201,0x7a389752,0x6e2d000d}},	//   şük_, брот, píta, _nkab,
   {{0x63b5005f,0x316dc070,0x200cc284,0x442c80e2}},	//   kezn, rbez_, fidi_, _fkd_,
   {{0xdb088018,0x200ce7ec,0x64454510,0xdb1c41aa}},	//   _cadó, gidi_, nmhi, _saré,
   {{0x7a158064,0x7bc1c09d,0x660d67ed,0xdb0553f6}},	//   jątk, rdlu, kiak, behå,
   {{0xc692481b,0xf3e90626,0x186a0974,0xa159e7ee}},	//   האט_, _אף_, лами_, _саду_,
   {{0x705601b4,0xed59c2bc,0x320dc05c,0xdb08c166}},	//   إنسا, ldžo_, miey_, redá,
   {{0xe3630657,0x2007c0b3,0x68ed494a,0x2d9904e1}},	//   зкри, _umni_, dyad, agse_,
   {{0xa3a98575,0xe695c1b4,0x660980e0,0x629502bc}},	//   ग्य_, _العد, _omek, guzo,
   {{0x51f600fe,0x6a64c1b4,0x657d130b,0x320dc0c9}},	//   _دستر, _بطول, cash, niey_,
   {{0x5baa4039,0x81ccc079,0x753b825d,0x7644406a}},	// [2520] лкам_, _রকম_, _nzuz, rmiy,
   {{0x99474119,0x60dbc018,0x6281c41b,0x3ea98036}},	//   спуб_, ixum, oslo, łaty_,
   {{0x44446408,0xcf570093,0x6459d84f,0x74adc079}},	//   rm_, _לבית_, _luwi, কটিউ,
   {{0x26ca67ef,0x7bc180f8,0x78a2a471,0xb17d802d}},	//   _vrbo_, _aalu, ttov, _poťa,
   {{0x661b8590,0xd378838f,0x442a0022,0xceb8c036}},	//   _djuk, _peć_, oob_, zwę_,
   {{0x92df0079,0x225867f0,0xf3e6411b,0xdb01c240}},	//   _দেয়_, _turk_, _ужго, belø,
   {{0x7bc1a7f1,0x60cbc05e,0x4667810e,0x7e64c870}},	//   _dalu, _argm, брым_, _čipo,
   {{0x7c28c1f4,0x69d5c384,0x69c46670,0x200ce7f2}},	//   wodr, भाषी, ndie, widi_,
   {{0x4062df0f,0x7bc1a7f3,0x443e8398,0x657d0ecf}},	//   _bọọl, _falu, _tht_, vash,
   {{0x6c36808c,0x28c94b08,0x65642185,0x3f9a402f}},	//   _افطا, रिति, _afih, ngpu_,
   {{0x78a44c99,0xdd91079e,0x442a145c,0xe5b50ce8}},	//   htiv, وود_, dob_, ойны,
   {{0x68ed4360,0x7c2a834d,0xa2cc0e18,0xdb0a87c9}},	//   yyad, lofr, हिन्, cefá,
   {{0x200ce7f4,0x200a4150,0xa2c08430,0x68ed41c8}},	//   pidi_, _ombi_, विक्, xyad,
   {{0xdb1a82b0,0x67d4c604,0x4062c044,0x69c44017}},	//   _latí, _фоку, _gọọl, edie,
   {{0xa3d24419,0x657d27f5,0xb4d167f6,0x6fd74048}},	//   वाई_, pash, वम्_, ठासं,
   {{0x69c467f7,0x7bcb4017,0x5ebb002a,0xa3ab4185}},	//   gdie, ēgum, _উপদে, क्न_,
   {{0x31794107,0xb87b05ca,0x629527f8,0x13acc02a}},	// [2530] _vesz_, gyít, suzo, _কোয়,
   {{0xf1b9c3c5,0xa3b00b1c,0x6009403a,0x69c44286}},	//   roši_, _टॉप_, _kömə, adie,
   {{0x7bc180b4,0xf1b9c3c5,0x255e80eb,0x31794107}},	//   _ralu, soši_, _ịla_, _tesz_,
   {{0xe7f54048,0x200a5030,0x777a80b9,0xa69bc052}},	//   _इतका_, _embi_, _aetx, רשאפ,
   {{0x68ed41c8,0x27e5804f,0x628a0125,0x661d40a8}},	//   qyad, _poln_, _åfor, _ijsk,
   {{0xf7718032,0x7c2a9d58,0xb7b5c112,0x57b7c048}},	//   ذات_, gofr, họr, _असेह,
   {{0xbb4280d5,0x5694423d,0xa2c088b8,0x660f27f9}},	//   мешк, _нарт, विग्, kick,
   {{0x7aea4095,0x60cd27fa,0x291f823b,0x6459cc47}},	//   äfte, _oram, _txua_, _puwi,
   {{0x2019c01f,0x777a80b9,0x1fa7892f,0x41dd0759}},	//   ésio_, _fetx, _грег, यानस,
   {{0x69c44166,0x5285e7fb,0x2cbf8010,0x7bc18022}},	//   zdie, огоб, _isud_, _ualu,
   {{0x3ebe805c,0xe9ff800c,0x38cac1aa,0x61fbc0f7}},	//   _gstt_, _nhẫn_, هایی_, phul,
   {{0x6aa54c5f,0x98a601a9,0x2283c06a,0xd9f981f9}},	//   ithf, оиме, rık_, ंसित_,
   {{0x6459c0f8,0x91bf80d1,0x442ec031,0x628502e9}},	//   _uuwi, _chủ_, _fkf_, _avho,
   {{0xae024045,0xdb018089,0xd874c7ce,0xf772130d}},	//   रोईन_, _zblá, _راهب, باح_,
   {{0xd347c1aa,0x7a360089,0x224027fc,0xe299c651}},	//   _دیده_, nátk, _thik_, _тай_,
   {{0x799be7fd,0x69c467fe,0x628c8574,0x61fd00cb}},	//   nguw, udie, _úlož, chsl,
   {{0x7a360066,0x3fe645a4,0x6441a7ff,0xf1b2c916}},	// [2540] hátk, ожав, _ohli, וסן_,
   {{0x6026011b,0xdb18e6b8,0xa01b04c9,0xa91dc02d}},	//   _єдна, _havá, srör, mažd,
   {{0xf746019b,0x5693411b,0xa01b0041,0x1c39409b}},	//   _фено, даєт, prör, сять_,
   {{0xdb1a801f,0x7a360089,0x6b8dc09c,0x7bd56800}},	//   _latã, dátk, _ɓaga, _enzu,
   {{0x6366c047,0x69c42801,0x21f8c107,0x2034405f}},	//   nční, _maie, _néha_, _فہرس,
   {{0x200a6802,0x7989a803,0x69c42804,0xa3b00028}},	//   _umbi_, _edew, _laie, _टॉम_,
   {{0x59ca0d6c,0x200ea805,0xdb1c0016,0x26c38123}},	//   ियार, rifi_, ndrà, _šjor_,
   {{0x660f0066,0x799bc006,0x95cac6b1,0xdb18c0a0}},	//   xick, gguw, рука_, _navá,
   {{0x59a6c891,0x75fcc05f,0x7bc3e806,0xa0678119}},	//   क्षर, _néze, _banu, _мата_,
   {{0x660f164c,0x27f8c10d,0x25a0006a,0xdb0e0397}},	//   wick, órn_, _acil_, ndbó,
   {{0x2bde04eb,0x765c44a0,0x4734df7a,0xab5c8017}},	//   माना, _jury, янос, _gaļa,
   {{0x69c42807,0x320b043e,0xdb0a80b0,0xe9ff835d}},	//   _caie, рхон_, tefæ, _miến_,
   {{0x7a13c119,0x38cbc0fb,0x99a50107,0x7bc3e808}},	//   gătu, _پانی_, ítők_, _fanu,
   {{0xdb150107,0xe9ff80d1,0x27e7c0b6,0xc04fc289}},	//   lezé, _phẫn_, _gonn_, _іі_,
   {{0xadeecb26,0x15eec0b2,0x45d55124,0xe297c16f}},	//   _जवान_, _जवार_, повс, _дај_,
   {{0x69c400fc,0x2c60c3bc,0xf54f4112,0x02fbc4e0}},	//   _gaie, _kòd_, _rụba_, _כלומ,
   {{0x60cd2809,0x8ccdc064,0x7bc3c664,0x6aadc0b3}},	// [2550] _uram, तियो, _yanu, _ćafi,
   {{0xf7704228,0xdb18c066,0xdb17003a,0x62810047}},	//   نام_, _zavá, _naxç, álos,
   {{0xf4028079,0x35b58477,0xdb18820b,0x7980e80a}},	//   ৎকার_, збер, ndvä, kamw,
   {{0x2bb7c814,0x799d07b5,0xaca34112,0x6aa541f4}},	//   _अस्थ, ngsw, _ahục, rthf,
   {{0x70a9c09d,0x68304414,0xf8bf5496,0x6e2ba80b}},	//   _कहेल, tädt, _usé_, rogb,
   {{0x645d4010,0x7bc70107,0x6283853d,0x7ae340b0}},	//   _iusi, ndju, tsno, ønts,
   {{0x6e9581b4,0x38a4005f,0x442ce80c,0x765c4057}},	//   ألعا, zör_, dod_, _gury,
   {{0x2249680d,0x6455680e,0x171c0009,0x2011280f}},	//   nmak_, _hizi, יווע, hizi_,
   {{0x61fba810,0x201125dc,0x7642c88b,0x2c60c29a}},	//   _ilul, kizi_, _dhoy, _còd_,
   {{0xaf05c1bc,0xa91dcc14,0x60c9e811,0xa3cb014a}},	//   зпол, jaže, rvem, _रोल_,
   {{0x61e9911b,0x20112812,0x2249406a,0xdb074089}},	//   _koel, dizi_, kmak_, _objí,
   {{0xfe70801c,0x7bc3e813,0xf1b9c017,0xdb01c089}},	//   _شدم_, _wanu, tošu_, celý,
   {{0x7a362814,0x455ac3bd,0x20112815,0x6d59e816}},	//   náti, _הכנס, fizi_, _igwa,
   {{0x9f47c0fd,0xf1b9e817,0xcb670156,0x644fc016}},	//   _jonë_, leš_, заре_, ïcid,
   {{0xdb1c6818,0x69c42819,0x2d8040b4,0x7d028157}},	//   _parí, _taie, taie_, zzos,
   {{0xa5bb4b75,0xe1ff281a,0x6b81c031,0x7649c3a6}},	//   _skór, chó_, lalg, nmey,
   {{0xd347c1aa,0xd5af41b4,0x777c4160,0x27fa007a}},	// [2560] _دیگه_, طفل_, _perx, _tlpn_,
   {{0x7980e81b,0x64554047,0x9742c570,0xb4bc41ac}},	//   zamw, _cizi, šćem, _आनी_,
   {{0x2ec641b4,0xdb1e0565,0x7e64e81c,0x61e981b0}},	//   ثقاف, _enpò, _čipk, _boel,
   {{0x443140b6,0x28c9681d,0x64a6828a,0xad9b402e}},	//   _ekz_, रिशि, зада, _alúf,
   {{0x3e61c00c,0x645d681e,0x6443c066,0x61e29ebf}},	//   _lót_, _gusi, _ohni, rjol,
   {{0x765c4064,0x7c2e02eb,0x4adbc59c,0x61f64c9f}},	//   _tury, nobr, यमाव, lkyl,
   {{0xb05b54a6,0xdb1a9792,0x63b88185,0x7980e81f}},	//   _fräs, _batá, revn, tamw,
   {{0xb05b44d3,0xdca69109,0x64a68949,0x63b8a820}},	//   _gräs, _наби, _наба, sevn,
   {{0x2d822821,0xdb1c401f,0xa967c01b,0x645540f7}},	//   dake_, _farã, чиња_, _yizi,
   {{0xe9df4015,0xa2f4c11b,0x2ef4cf10,0x765600e2}},	//   _khúc_, дпоч, дзор, _aiyy,
   {{0x765600e2,0xf1b9e822,0xa91dc0ab,0xdfa58b92}},	//   _biyy, beš_, važe, _تحقي,
   {{0xf1b9c194,0xaadb8093,0x76440053,0x442ea823}},	//   ceš_, _לחבר, _chiy, lof_,
   {{0xdb0e0af3,0xdb1c0086,0xa91dc0a0,0x113ac032}},	//   nebæ, ndræ, taže, _اثاث_,
   {{0x99804039,0xf1daceb4,0x442cd876,0x7d046824}},	//   klių_, भावन, qod_, dzis,
   {{0x2011124b,0x7bd8e825,0x7bc72826,0x2d822827}},	//   rizi_, _invu, rdju, bake_,
   {{0x660d2828,0xbbb980df,0x442e9f30,0x7bc52829}},	//   _umak, _इस्क, hof_, _wahu,
   {{0xd3788a11,0x2249682a,0x7c2e282b,0xbd45021a}},	// [2570] _hoću_, rmak_, bobr, _تنظي,
   {{0x26c1004d,0x7bc8c4c9,0x61e98396,0x7a3884cc}},	//   _tsho_, nddu, _soel, líth,
   {{0x6d40a82c,0xdb1c4315,0x224943a6,0xa7fb5de1}},	//   _azma, _carà, pmak_, _nuñe,
   {{0x63bac05f,0x7aea4041,0x3f8c8360,0x4421021b}},	//   hetn, äfta, _addu_, _hjh_,
   {{0x25e0e82d,0x6455423f,0xdb1ac4d3,0xf3f341b4}},	//   कानी_, _tizi, ldtä, _كأس_,
   {{0x645f16d4,0xfe70001c,0xdb1a80e1,0x63ad8054}},	//   _muqi, _جدی_, _satá, đano,
   {{0x60c2e035,0x6287282e,0x9f47c0fd,0x2d821d0f}},	//   _asom, nsjo, _vonë_, yake_,
   {{0x798d00f7,0x7bd8cbed,0x7bc7682f,0x05dac045}},	//   _ndaw, _anvu, _haju, भाषब,
   {{0xf1b9d2b8,0x60c2c05f,0x7bc75d38,0x9f5a446a}},	//   reš_, _csom, _kaju, cipó_,
   {{0xdb1c6830,0x386d85d4,0xdb0e4018,0x7963c1c0}},	//   _hará, _iter_, _gabó, _bíwó,
   {{0x2eac0c63,0x7c2e0199,0x6b81c372,0xea004015}},	//   _चहेत, vobr, ralg, _loạt_,
   {{0x6b81d29b,0x7bc8e831,0x44210789,0x7a3ec0fd}},	//   salg, addu, _ajh_, pëta,
   {{0x522ac81b,0x64572505,0xddcd0064,0xfc3f0996}},	//   _ווײַ, _bixi, _biał, rtín_,
   {{0xfc3f2832,0x69c9e081,0x44210033,0xddcd0064}},	//   stín_, ldee, _cjh_, _ciał,
   {{0x2fc7c010,0x2d8d8044,0x9f434089,0x6445005e}},	//   _iang_, _odee_, _bojí_, _dhhi,
   {{0x244404d3,0xc8c94028,0x61ebe833,0x6d5ba834}},	//   döme_, रिंट, _jogl, _ngua,
   {{0x444403d4,0xdb03805b,0x69c66835,0xfd568112}},	// [2580] _th_, vený, _vake, _dibị,
   {{0x69c66836,0x61f66837,0x7b164032,0xaca3c044}},	//   _wake, skyl, وظائ, _nnọk,
   {{0x63bc2838,0x99804039,0xdb03a839,0x386d801c}},	//   mern, ulių_, genü, _ater_,
   {{0x629c283a,0x78a9c0da,0x3f874086,0x25adc15d}},	//   muro, ktev, ónur_, jfel_,
   {{0x6457283b,0x69c9e83c,0xdbc6854a,0x91bb40c3}},	//   _yixi, ddee, _mööb, _ומכי,
   {{0x64570b0e,0xe9df4015,0x6d5ba83d,0x0a6a879c}},	//   _xixi, _thúc_, _egua, ории_,
   {{0x3a2242bc,0x661d0166,0xe81f8a71,0xa3df0048}},	//   _kjkp_, ynsk, _बदरा_, णात_,
   {{0x63bac033,0x69d5c281,0xef188017,0x9f458060}},	//   wetn, भागी, _ceļa_, _alló_,
   {{0x80c447c6,0x2fc7d4d9,0x629c283e,0x78a9d504}},	//   रिटे, _bang_, huro, gtev,
   {{0x69c9c057,0xddc98017,0x2fc7c0d1,0x44388359}},	//   adee, _cieņ, _cang_, _ór_,
   {{0x2fc7e83f,0xa3bd8fb2,0x6457247d,0xbcfb001e}},	//   _dang_, ेयर_, _rixi, rcém,
   {{0x99894036,0x63bacae6,0x64572840,0x7bc8a841}},	//   ział_, setn, _sixi, _hadu,
   {{0xd5a50028,0x60c2e209,0x2be28045,0xbddb4303}},	//   ग्गज, _usom, पापा, _dhèl,
   {{0xdb038018,0x7a388107,0x62871bfc,0xbbc847c6}},	//   cenó, síth, tsjo, रयोक,
   {{0x53342842,0x660280f7,0x7a3ec0fd,0x61ebc046}},	//   верт, khok, nëto, _yogl,
   {{0x6287011b,0x7bc76843,0xdcc8c00c,0x7980a844}},	//   rsjo, _saju, _kỉ_, _nemw,
   {{0xe9df4015,0x660296f3,0x7e6e40f8,0xa01b0041}},	// [2590] _chúa_, dhok, _atbp, nsök,
   {{0xeddbc281,0xb90747c4,0x7bc8a845,0x9f4509ac}},	//   _मच्छ, _मऊ_, _nadu, óló_,
   {{0x2d84e846,0xed59c79b,0x6288e847,0x386d84e1}},	//   kame_, leže_, nsdo, _ster_,
   {{0xceb20009,0xa91d8ac0,0x6e22cc87,0xe45f4041}},	//   _גיט_, _leže, _njob, _bröt_,
   {{0x61ed2848,0x798080ce,0xcb699854,0xdb1c4107}},	//   _moal, _demw, пале_, _vará,
   {{0x6cd2805f,0xf745800a,0xb05b16df,0x6e22c0bb}},	//   اقوا, нело, lväs, _ajob,
   {{0x7bc8a849,0x4255c47d,0x75f5c05f,0xf1a79c19}},	//   _dadu, нтит, _házi, _оран,
   {{0x78a9e84a,0x6b854782,0x6602939a,0x6d5b80c5}},	//   ttev, lahg, chok, _ugua,
   {{0xf8c8c082,0x63bc101a,0xddc9803f,0x4431284b}},	//   _cứ_, yern, _pieņ, koz_,
   {{0x60004107,0xd709c051,0x25adc041,0x6b83a84c}},	//   _töme, зное_, sfel_, qang,
   {{0x26d1cc5a,0x2fc7e84d,0x80cdc314,0xdbdac031}},	//   ízo_, _vang_, तिहे, _dààb,
   {{0x60c400e0,0x201ecb18,0x63bc1b96,0xa2d30185}},	//   _psim, anti_, wern, डिन्,
   {{0x24894022,0xed350097,0xbddb40ce,0x61ed0545}},	//   jsam_, вэрэ, _chèm, _doal,
   {{0x6b81803f,0x4431284e,0x7e61a84f,0xa2cc0048}},	//   _jelg, goz_, _kulp, हिल्,
   {{0xed598017,0x45d6447f,0xe736d252,0x2612002d}},	//   _daži_, нцат, _пеш_, lšom_,
   {{0x629c2850,0x69c980f8,0xdb1ac0fd,0x7a36001f}},	//   ruro, _naee, zetë, tátu,
   {{0xa3cb2851,0xdb170018,0x6b85421b,0x224dc06c}},	// [25a0] _रोक_, _xaxú, fahg, imek_,
   {{0x59d1c54a,0xfd470ce8,0x38a9a852,0x6e3be853}},	//   _दोसर, _язык_, dúr_, hlub,
   {{0x8f9b0009,0x24894c47,0x9f458066,0x69cb80a8}},	//   _ציטי, asam_, _bolí_, fdge,
   {{0xa9269198,0x7a360fb4,0xb05b04c9,0x26120011}},	//   ндел, pátu, mvär, kšom_,
   {{0xb05b020b,0xc95540d7,0x248941f4,0xdb01c851}},	//   lvär, _атры, csam_, lflä,
   {{0x22594066,0xdb1e0066,0x2246c13b,0x6d5d4011}},	//   _zisk_, _zapá, _shok_, _zgsa,
   {{0xf8c8c00c,0xa91d860f,0x8f9b0052,0x7980a854}},	//   _sứ_, _reže, ליסי, _temw,
   {{0x629e6855,0xb148805f,0x9f5c80e1,0x66045999}},	//   mupo, _قیام_, tivó_, nhik,
   {{0x7659c0de,0x6458c053,0x1aedc079,0x3f85c1f4}},	//   _diwy, _pivi, _ছেলে_, falu_,
   {{0xaca4425d,0xeac9c171,0x66e698cc,0x7c3acd76}},	//   _ahịr, _bẹ_, _поза, ultr,
   {{0x6d442856,0x7a360107,0x66eac03a,0x798605bc}},	//   _azia, játs, cəkl, fakw,
   {{0x6288db39,0xdcc8c015,0xb05b0041,0x628a8240}},	//   rsdo, _tỉ_, dvär, msfo,
   {{0x7bdc4101,0x6f06c01e,0xe61f010b,0x629e4286}},	//   _onru, _bébé, rnô_, hupo,
   {{0xdb1ac01e,0xeac9c55d,0x77930de9,0xa3c8c5da}},	//   heté, _fẹ_, دیدا, _लोच_,
   {{0xe9df4032,0x5fce40aa,0x399ac189,0x225947fb}},	//   _dhún_, _होइल, cüsü_, _pisk_,
   {{0xbedb0031,0xed59c0e5,0x443108bd,0x66046857}},	//   _aṣòw, seže_, soz_, ghik,
   {{0x7bcae858,0x44234df5,0x4c94407b,0x2d826859}},	// [25b0] _kafu, _pjj_, литс, _deke_,
   {{0x764d685a,0x2489685b,0x628aa85c,0x69c98573}},	//   smay, rsam_, ksfo, _saee,
   {{0xfbdf80d1,0x3eb84303,0x22490303,0x9f458089}},	//   _đê_, _cprt_, _khak_, _polí_,
   {{0x645a810f,0x628a81e5,0xf770001c,0x64488051}},	//   _aiti, dsfo, _پای_, _ahdi,
   {{0x64488061,0x6b81a85d,0xa3cc5088,0x61ef405e}},	//   _bhdi, _pelg, _शोक_, _iocl,
   {{0x64488061,0x5274001c,0xf99f40b6,0x290942c0}},	//   _chdi, _جایز, _emèt_, mzaa_,
   {{0x9f4dc9d7,0x224dc3a6,0x63a3010d,0x628aa85e}},	//   ünün_, tmek_, _önnu, gsfo,
   {{0xe8d9002e,0xb606c7ef,0x7e61a85f,0x660dc166}},	//   _agọ_, ješć, _vulp, ďako,
   {{0x3f8347a8,0x9f5c823f,0x3f85d57c,0x2612006f}},	//   _keju_, rivò_, talu_, ušom_,
   {{0x9f5ec070,0x5fdbd088,0x753b8024,0x6d5f0073}},	//   ditó_, बाइल, _iyuz, _agqa,
   {{0xcd2bcde1,0x7bcacec7,0xd5dd009d,0xfdf58fb2}},	//   _کسان_, _dafu, यांज, _आवास_,
   {{0x3f85c09d,0xc3328087,0x1515c844,0x24440041}},	//   salu_, _דוב_, _идея, döma_,
   {{0x7bcad85a,0xf6528009,0x28c783ae,0x22490303}},	//   _fafu, יצט_, लिटि, _dhak_,
   {{0xe787e506,0x7d09c2bc,0x7bcac4db,0x63a3807a}},	//   _чудо, mzes, _gafu, ngnn,
   {{0xa3e28048,0x61ef405e,0x47ca402a,0x61e9c051}},	//   धात_, _bocl, রামী, ojel,
   {{0x6e24179a,0x3f87a860,0x66044033,0x61ef4157}},	//   _ujib, hanu_, uhik, _cocl,
   {{0xb05b04d3,0x25b2c3a6,0xe45a6861,0x9f5ec46a}},	// [25c0] rvär, _öyle_, джа_, citó_,
   {{0xb05b2862,0x6b83c729,0x2d824b45,0x76498057}},	//   svär, _jeng, _weke_, _ahey,
   {{0x38abc36b,0x645aa863,0x61ef41b4,0x61e9c11b}},	//   hør_, _riti, _focl, kjel,
   {{0x7e6dd91f,0x4425821b,0xed5980e0,0xa91dc7cb}},	//   _čapl, _ajl_, _lažu_, važn,
   {{0x78ad4016,0x8b664425,0xdb05001e,0x60c94018}},	//   ctav, _لازم, _achè, _áemp,
   {{0x6b83e864,0x6d4647b4,0x798400c4,0x7bce11fd}},	//   _neng, _izka, _leiw, ndbu,
   {{0x3940e58d,0xdb1c0559,0x27e0c0b3,0x60c4610f}},	//   _šis_, feré, _đin_, lwim,
   {{0x645a9962,0x765b8010,0xddc98036,0x38abc240}},	//   _witi, _giuy, _mieś, før_,
   {{0xb606d8ca,0x673c40fd,0xa91de865,0x26c7ce3d}},	//   vešć, _hyrj, sažn, _asno_,
   {{0x6ebd8028,0x645a911b,0xa91de866,0xaca44094}},	//   _वैकु, _uiti, pažn, _nhọr,
   {{0x2fde803c,0x2cade867,0x60c440fa,0xa3e627c8}},	//   _intg_, ated_, hwim, फान_,
   {{0xaca44044,0xdb154066,0x2ca0454a,0x6b83e868}},	//   _ahọr, _nazý, kuid_, _eeng,
   {{0xa3df2869,0x7d09c064,0x645c41b4,0x4421400c}},	//   णाल_, czes, _oiri, ynh_,
   {{0x6602c073,0x44334085,0x645c686a,0x59c986ca}},	//   _hlok, xox_, _niri, _रसभर,
   {{0x199558c8,0xdb18801f,0xdb1e0166,0xf1a74594}},	//   лавя, levâ, _napä, кран,
   {{0x60d600da,0x2d848f0f,0x6b83e86b,0x31355045}},	//   _frym, _neme_, _zeng, гебр,
   {{0x60d6286c,0x4438686d,0xdb174018,0x69c0e86e}},	// [25d0] _grym, _bkr_, rexí, ieme,
   {{0x6b88e86f,0x6e228018,0x61fd0d5b,0x3946c123}},	//   nadg, enob, lksl, _mzos_,
   {{0x69c0e870,0x89340973,0xfb154d9e,0xf1aa0d6c}},	//   keme, _معیا, دواج, _कामन,
   {{0xfd6680eb,0x78ad4086,0x9294410e,0x248d8070}},	//   _izuụ, ptav, рацц, _pvem_,
   {{0x5884439d,0x61e9e871,0x30a78a49,0xc19a42a6}},	//   _выса, vjel, трев, _אשרי,
   {{0x765d4df5,0x656d6872,0x7e65007a,0x02a2c083}},	//   _hisy, lcah, _kuhp, _akọọ,
   {{0xa3a98c4b,0xad9b0032,0x61fbe873,0xed59e874}},	//   ग्ग_, thúl, tkul, deža_,
   {{0x38abc36b,0x645c6875,0x2cade876,0x7d09d939}},	//   tør_, _ziri, tted_, tzes,
   {{0x644ac1b4,0x7a3d04f2,0x645c6877,0x3f87a878}},	//   _bhfi, céti, _yiri, panu_,
   {{0x3fce0079,0x61e9e879,0x765d687a,0x38abc240}},	//   _রক্ষ, sjel, _lisy, rør_,
   {{0x7a3884f2,0x38721a5e,0x765d4010,0x2018122d}},	//   mítr, _styr_, _oisy, viri_,
   {{0x15e40048,0x7524d7ff,0x2cadc0c3,0x02fa8052}},	//   गाधर_, _žize, pted_, _אלעמ,
   {{0x629ac127,0x3eba0033,0xdb01d9a9,0x7c3e4402}},	//   arto, _sppt_, nflú, ylpr,
   {{0x3f8582a3,0xab29dd91,0x6fde0064,0x7c92c1b4}},	//   _jelu_, _пола_, माइं, _الوص,
   {{0x645c687b,0x4427c05c,0x765d687c,0x75ff00fd}},	//   _riri, _ijn_, _bisy, _gëzo,
   {{0x61fd0d4d,0x60d6287d,0x657bc010,0x765d4303}},	//   cksl, _trym, nbuh, _cisy,
   {{0x443844a7,0x645c687e,0x6e22a87f,0xfce35637}},	// [25e0] _pkr_, _piri, vnob, бото,
   {{0x7f864aaa,0x5fce454a,0x5aca085e,0xe9df4031}},	//   الان, _होखल, _злом_, _enú_,
   {{0x657bcc47,0x765d6880,0x9eaa1136,0xda654032}},	//   kbuh, _fisy, _явна_, لاني,
   {{0x831b0009,0x78a0e040,0x5336c009,0x628e2881}},	//   _טויז, yumv, אנען_, msbo,
   {{0x443ee66f,0x81ce0079,0xddc44036,0x4e370009}},	//   ylt_, রাপ_, rmiń, אָגן_,
   {{0xdb018004,0xbe86461e,0x3e8641b4,0x57b3859d}},	//   _eclí, _مجرو, _مشرف, йбіт,
   {{0x25e0c705,0x201a402f,0x7986421b,0x7bce40f8}},	//   काली_, mipi_, _kekw, _iabu,
   {{0xbddb41aa,0x7a3d001e,0x657bc71c,0x78a0e5fb}},	//   _dhèw, péti, gbuh, tumv,
   {{0x3204805c,0x2dd7c032,0x60cdc077,0x443a0043}},	//   _ilmy_, طبية_, _šamr, _okp_,
   {{0x78a28844,0xd70404e3,0x628e1b1d,0x66042882}},	//   muov, रनाथ_, ksbo, _alik,
   {{0x7a3ec0fd,0xa5bb4086,0xa3ac4705,0x6d40006a}},	//   hëti, _sjóm, _गान_, üman,
   {{0x25e0c048,0x443a2883,0x4427c085,0x6604027f}},	//   काळी_, _akp_, _ejn_, _clik,
   {{0x60c9805c,0xdb1ac30d,0x61fd20d2,0x44f7c1e3}},	//   _xsem, metí, rksl, _مروج_,
   {{0x645e2884,0x628e1254,0xdb1c41c0,0x36d4d09b}},	//   _cipi, fsbo, _darú, _вокр,
   {{0x628e0588,0xfc3f0cec,0x731b0031,0x79866885}},	//   gsbo, ktív_, _bìjẹ, _bekw,
   {{0x44f50525,0x8215005f,0x05dac17e,0xe4e74e99}},	//   _впис, _خوبص, _मोमब, лізн,
   {{0xbcfb6886,0x656d4f7c,0xa3c2448b,0x7afae887}},	// [25f0] _afér, rcah, ्यं_, lytt,
   {{0x32048303,0x765d40f8,0xb8dd6888,0xeae48b35}},	//   _almy_, _wisy, _आह_, _कपूत_,
   {{0x656f023f,0x9f47e889,0x765d4537,0x5e474032}},	//   occh, _koná_, _tisy, _مضحك,
   {{0xdb154019,0x248de88a,0xa91d804f,0x956440c5}},	//   _sazó, ysem_, _dežn, _гърд,
   {{0x765f0561,0x61ed5816,0x764d0398,0x645e09f3}},	//   _miqy, mjal, _mhay, _yipi,
   {{0x683dc315,0x3209635c,0x248dc06c,0xa3b092c2}},	//   pèdi, lhay_, vsem_, ट्ल_,
   {{0x38af41df,0x26c54157,0xd5bb8f99,0x798647f2}},	//   lür_, _èlo_, _пса_, _yekw,
   {{0x3209413c,0xa5bb0004,0x2d86c861,0xb5fb4107}},	//   nhay_, lióf, _ceoe_, _hiáb,
   {{0x3f85a88b,0x60c9a88c,0xfde6cc85,0xdd91c0fb}},	//   _telu_, _usem, рдык_, موں_,
   {{0x6616036b,0x41a7c028,0x69cf688d,0x61ed5845}},	//   _smyk, _गावस, _lace, hjal,
   {{0x2240688e,0x645e288f,0x764d2890,0xd5e60def}},	//   ylik_, _ripi, _bhay, ажни,
   {{0xc10601b4,0x22161065,0x2c6b8065,0xa06a20a1}},	//   لوجي, рфор, _kød_, кама_,
   {{0x04460291,0xef18c017,0xdceb8007,0x37e5e188}},	//   иемн, daļu_, ragė, _волг,
   {{0x6609c1b7,0x69cf4010,0x46f5c11b,0x225fa891}},	//   lhek, _aace, _вчит, _liuk_,
   {{0xdb0aa212,0x69cf6892,0x78bd55c5,0xa22501aa}},	//   lefò, _bace, _apsv, _گروه,
   {{0x66042893,0x2d8b2894,0x61ed4086,0xf1bdcc13}},	//   _ulik, cace_, gjal, ्यटन,
   {{0x443a2895,0xa3d14fb2,0x18a65f7a,0x9f864dce}},	// [2600] _tkp_, वयं_, разм, игад,
   {{0x6aa380fa,0x7bc3a896,0x6e3ba897,0x60006898}},	//   kunf, jenu, _akub, _göml,
   {{0x6705d6c0,0x201a6899,0x68fbd2ee,0xa3a98185}},	//   शनिक_, ripi_, hyud, ग्छ_,
   {{0x3f87e89a,0xe8fa9534,0xdca64f75,0x6609e89b}},	//   _lenu_, кле_, _ками, jhek,
   {{0x224d8231,0x7d0d4062,0x53e688b1,0xdb0a8414}},	//   _dhek_, czas, ицка, sefü,
   {{0x44380663,0x25a681f4,0x69cf4084,0x6e3b818c}},	//   nor_, sgol_, _zace, _ekub,
   {{0x2cb242a4,0x44381412,0x3866cc9e,0xbcfb00dd}},	//   ltyd_, ior_, _suor_, ncér,
   {{0xe5a38f4b,0x69c4689c,0xa2c34285,0x3d11854a}},	//   _миси, neie, रबर्, _देके_,
   {{0xdddc8199,0x3f87e89d,0x546a8c38,0x7e60a89e}},	//   _kvrž, _benu_, _разм_, _iimp,
   {{0x6abe011b,0x2d8b0067,0x4438289f,0x7afac051}},	//   _oppf, wace_, jor_, tytt,
   {{0x7bd94009,0x78a468a0,0xdb1ac019,0x6d40832a}},	//   אַרק, huiv, petí, _hyma,
   {{0xd5b0c78a,0x39490070,0x201ca8a1,0x78a44134}},	//   _رفت_, _pzas_, livi_, kuiv,
   {{0x3f87c9de,0x443804f5,0xe9470623,0x799601f4}},	//   _fenu_, for_, рхно, _ddyw,
   {{0x3cee8064,0x60db438f,0x2d8b28a2,0x6004c3bc}},	//   _आपने_, _šumo, sace_, _fòma,
   {{0x6e94cf35,0xdb1c253f,0xe694c1b4,0x3f87410d}},	//   _البا, berí, _البد, ðnum_,
   {{0xdb170004,0x38af542b,0x8c3de8a3,0x68e20011}},	//   _saxó, tür_, muşa, _šode,
   {{0x478b523a,0xc953c009,0x6b8740fd,0x6d408655}},	// [2610] всем_, ַמע_, _pejg, _nyma,
   {{0xc7b8c158,0x6b888ded,0x2c6b927d,0x3f8ce8a4}},	//   biđe_, _nedg, _rød_, nadu_,
   {{0xe71941b4,0x69c468a5,0x6d408573,0x7e60a8a6}},	//   ديات_, beie, _ayma, _bimp,
   {{0xb05b4041,0xfc3f0018,0x3f8cd45c,0x78a44157}},	//   _späd, rtíu_, hadu_, buiv,
   {{0x26cc8018,0x6441e8a7,0x49118036,0x80e18028}},	//   _asdo_, ylli, _देखो_, पमें,
   {{0xd838c04f,0x3206c0d2,0x8d5a40c3,0xf8bf4303}},	//   joč_, _aloy_, _תכשי, _ipé_,
   {{0x929446e0,0xfeca0052,0x661bdf72,0x798b8340}},	//   _марц, ָמפּ, tiuk, pagw,
   {{0x16348842,0xdb0e0b01,0x798d4b1f,0xb5fd98ca}},	//   _деся, ékér, naaw, _biše,
   {{0x20248086,0x83fc8077,0x6441e8a8,0x661bc39d}},	//   ðrið_, _siđe, tlli, riuk,
   {{0x3206c019,0x61e2e8a9,0x6006c39d,0xdb1898ac}},	//   _eloy_, _enol, йным_, devæ,
   {{0x6609c0f7,0x39460017,0x6441e8aa,0x98b8c8c7}},	//   phek, _šos_, rlli, ārā_,
   {{0x3255e8ab,0x3f87e8ac,0xb5fd8570,0x2cbf807a}},	//   _увер, _wenu_, _fiše, _kpud_,
   {{0xdb1c02b0,0x5a0cc009,0x3f87c669,0x69c440d9}},	//   rerí, _בלאַ, _tenu_, veie,
   {{0x59aa0b5b,0x81ce0079,0x186711a0,0x249fe8ad}},	//   _कावर, রাধ_, сари_, mrum_,
   {{0x69c468ae,0xf8bf4031,0x81cc4079,0x7bc547fb}},	//   teie, _apé_, লাস_, dehu,
   {{0x249fe8af,0x056640c5,0xf09f0016,0xf1b9c570}},	//   orum_, сван, brà_, biše_,
   {{0xdb18c070,0xc044c00c,0xa01b0041,0x249fe8b0}},	// [2620] _favó, _đoạt_, rsör, nrum_,
   {{0x657f4022,0x2cb242a4,0x44380c64,0xa01b04c9}},	//   abqh, rtyd_, qor_, ssör,
   {{0x7afc00fd,0x09a7c021,0x61e40340,0x249fc696}},	//   qyrt, _गांठ, _knil, hrum_,
   {{0x81cc4079,0x3f8cc066,0x6443a8b1,0x3a3dc112}},	//   লাহ_, zadu_, elni, _nkwp_,
   {{0xa5bb4031,0x249fc436,0x60cd28b2,0x3ea5cd4d}},	//   _ajów, jrum_, _xsam, hult_,
   {{0xaca40112,0xdee6508b,0x249fe8b3,0x7e608f64}},	//   _adịw, _логи, drum_, _wimp,
   {{0x61e428b4,0x764294ef,0xf1760031,0x6674808c}},	//   _onil, ploy, _abọ́_, زگار,
   {{0x9874dc34,0x201c92b6,0x2be04b26,0xe5c6c04c}},	//   олиц, sivi_, नाका, сско,
   {{0x4444518d,0x2902e8b5,0x201a0070,0x32eec080}},	//   ol_, áka_, _ompi_, məyi_,
   {{0xf09f00c5,0x7cde8119,0x2ca068b6,0xdb1c04ed}},	//   vrà_, _cărţ, irid_, ndró,
   {{0x443ea8b7,0xc5e40027,0xdc190036,0xdb0e00cb}},	//   _ikt_, गांठ_, _głęb, gebü,
   {{0x3f8e84fd,0x386128b8,0x201a023f,0x02a8c027}},	//   lafu_, _sihr_, _ampi_, _कमीन,
   {{0x2ca0405c,0xdb18c019,0x44fad546,0xade5c54a}},	//   jrid_, _pavó, _حراج_, कारन_,
   {{0x7bd828b9,0x25ad0283,0x61e401f4,0x798d431c}},	//   _óvul, żel_, _enil, waaw,
   {{0x661d28ba,0xfc3f0319,0x443ea8bb,0x44446646}},	//   pisk, guía_, _mkt_, dl_,
   {{0x3f8ea8bc,0xf09f023f,0x9f4c8157,0xa91d804f}},	//   hafu_, prà_, _modà_, _dežj,
   {{0x26dcc0b3,0x644383ad,0xdb18873b,0x798d5238}},	// [2630] _hrvo_, ylni, levä, raaw,
   {{0xbddb4694,0x764441c8,0x443a68bd,0x798d411c}},	//   _chèr, aliy, gop_, saaw,
   {{0x7c28e8be,0xdb1a8019,0xdb188051,0x60c9e8bf}},	//   indr, _mató, nevä, zwem,
   {{0x8d87804c,0x201ee8c0,0xa91dcb68,0xdb1a80e1}},	//   сужд, hiti_, saži, _lató,
   {{0xda788166,0x6b65a8c1,0x75ff013b,0xe365834a}},	//   _atď_, окла, _vëzh, окли,
   {{0x444468c2,0xd0068c21,0xbddb401e,0x0ea8cc5c}},	//   cl_, жеше_, _thès, _कमंड,
   {{0x6d42e8c3,0x443ea8c4,0x69c628c5,0x59d48c4b}},	//   _ayoa, _dkt_, yeke, _ठोकर,
   {{0xb05b00fa,0x6e2d01aa,0x60dd4590,0xa3d14045}},	//   swäh, _njab, _krsm, वयक_,
   {{0x6443805b,0xa3e98371,0x7cde8119,0x443e8451}},	//   plni, याद_, _părţ, _fkt_,
   {{0x3ea5c54a,0x115c4009,0x6e2d28c6,0x201ee8c7}},	//   tult_, נדזע, _ajab, giti_,
   {{0xf1bf254e,0x2be30b35,0x249fcccb,0x39ea10c4}},	//   rnán_, खाईं_, srum_, адно_,
   {{0xcad64093,0x201a00c9,0xef18803f,0xc69242a6}},	//   קורת_, _smpi_, _ceļu_, ואט_,
   {{0x3a295985,0xc4830d9b,0x661b8a15,0x26c1075d}},	//   dnap_, мляк, _mmuk, _apho_,
   {{0xee3f4166,0x3a2d8043,0xa3d40384,0x3a29c077}},	//   _aký_, _ljep_, _सोख_, čapu_,
   {{0x661b9415,0x3f8a4acc,0x2d8fa8c8,0xdb1c0443}},	//   _omuk, _rebu_, kage_, ferá,
   {{0xe57a42d3,0xdb1a8141,0x21674ec5,0x629841af}},	//   рза_, _katò, жити_, ávom,
   {{0xbddb4669,0xfc3f0004,0xdb1e462a,0xdcebc085}},	// [2640] _chèq, muín_, repí, _ddgħ,
   {{0xeb9a4cc4,0xdb08c4c9,0x2ca04c4b,0x764468c9}},	//   риж_, redö, rrid_, sliy,
   {{0x2d8f8669,0xfc3f02b0,0x660d400b,0xf1bf0107}},	//   fage_, quía_, bhak, knál_,
   {{0x3a3fa18a,0x3ea78314,0x2d8b4530,0x752fc064}},	//   _ckup_, dunt_, _gece_, żczy,
   {{0x201ee8ca,0x8e570087,0x661b805c,0x443ea8cb}},	//   yiti_, קינג_, _dmuk, _pkt_,
   {{0x2d8b4119,0x7aea44c9,0xec3445d3,0x6604559b}},	//   _zece_, äfts, _روزگ, lkik,
   {{0x660986a9,0xdb1c40da,0x3ea7a8cc,0x3f8e8150}},	//   _flek, _mbrë, gunt_, rafu_,
   {{0xf1bf0512,0x69d668cd,0xdcbac0c5,0x11eac032}},	//   gnál_, ndye, ащо_, شعبي_,
   {{0x2fc797ef,0x290068ce,0x225e4066,0x1d078051}},	//   beng_, nyia_, ítky_, _дети_,
   {{0x2fc799bd,0x7c3c0070,0xd9c7409d,0x25dac2ea}},	//   ceng_, jorr, _लस्ट, _खोरी_,
   {{0x2c6f28cf,0x27f84053,0xfc3f034d,0xc7d74323}},	//   _süd_, _morn_, nríe_, קוטי_,
   {{0x320dc100,0x6b820654,0xdb1d0047,0xfc3f019d}},	//   chey_, _đoga, ázít, guín_,
   {{0x3f8c8094,0xed5ac27f,0xf993821d,0x7d00c1c0}},	//   _kedu_, _тод_, ורר_, _dárú,
   {{0x38b44041,0x63bb03c7,0x60c2c8d7,0xa91dc054}},	//   där_, đuno, _ipom, gažu,
   {{0xdb1c28d0,0xf48505d3,0x2d8b456e,0x6579c01e}},	//   terá, _کابی, _pece_, _éché,
   {{0x69d64105,0x1dbcc1ac,0xf1bcc371,0xb5fcc085}},	//   gdye, ्जित, ्जिन, _buġi,
   {{0x200a4033,0x3a29405f,0x38b44041,0x2fc7a8d1}},	// [2650] _blbi_, rnap_, gär_, yeng_,
   {{0x35b10c63,0x78a2a8d2,0xd37b68d3,0xd7b2008f}},	//   _झाड़, drov, рча_, _जायच,
   {{0x81ce0079,0xc7b203bd,0x798d0033,0xa3ae875b}},	//   রার_, _אבי_, _keaw, कलन_,
   {{0xb87b68d4,0xdb1c434d,0x6e20c150,0x83fc8043}},	//   _príd, _aaró, jimb, _riđa,
   {{0x443ca8d5,0x3f8c9a45,0x2bb204ef,0x7c2a810d}},	//   fov_, _bedu_, _जामा, fnfr,
   {{0xf1b9c7ca,0xa91d867d,0x6d4f434d,0xee7b43be}},	//   diša_, _ježi, _izca, _نصرت_,
   {{0x7bc8e8d6,0xe7ec01f9,0x60cda0b0,0x78a2856e}},	//   dedu, ञाता_, çamb, arov,
   {{0xa91d86b7,0xddc1c077,0x4c85d19f,0xdce44036}},	//   _leži, _bulš, плив, ecię,
   {{0xf1bf033c,0xdb1c68d7,0x99ca0079,0x248928d8}},	//   rnál_, _abrè, ষাৎক, _nwam_,
   {{0x6009c2f8,0x320dc1c8,0xb17b4041,0xa5bb4086}},	//   сном_, shey_, _snål, _kjós,
   {{0x6d4428d9,0xee3a0297,0xa91dc531,0xe1fb408f}},	//   _syia, йно_, važu, _एकूण_,
   {{0xd12ec4e8,0x78b6404c,0xf1b9c06f,0xb2ba8093}},	//   ئمی_, ytyv, biša_, _למער,
   {{0xa91d8494,0xa3ac6869,0xec6bd1dd,0x386d809c}},	//   _beži, _गाल_, _трек_, _juer_,
   {{0x61f9c057,0x78a9c815,0xf1bf41c0,0x60dbc00b}},	//   _howl, muev, _abá_, mvum,
   {{0xdb1c059a,0x66e315d5,0x6d4f434d,0xed59d188}},	//   _üzün, нора, _azca, deži_,
   {{0x6569a8da,0x7afce8db,0x966368dc,0x75fcc303}},	//   _ngeh, ärte, ексе, _hézr,
   {{0xb95b4031,0x24890112,0x64418084,0x437600b4}},	// [2660] _abìb, _gwam_, _okli, _нунт,
   {{0x04466506,0x25bf98da,0xe8d9000c,0x61f9e674}},	//   чезн, _abul_, _ngộ_, _lowl,
   {{0xb5fb405f,0xf1bf0066,0xdb1ac3a6,0x4426438f}},	//   _kiál, znám_, retç, đo_,
   {{0x38c8808c,0xdb050e9a,0x25adc077,0xdb1c4580}},	//   قاتی_, _uchá, jgel_, _barò,
   {{0xdb1c654e,0x2d9268dd,0x200e90e6,0x6d5d8070}},	//   _paró, maye_, thfi_, _úsal,
   {{0x0ee00a30,0x386d8415,0x7bd54de0,0x6e20d955}},	//   _पछाड, _duer_, _gazu, wimb,
   {{0x2a64805c,0x224697a6,0xb05b0041,0x386d80cb}},	//   _timb_, plok_, rväx, _euer_,
   {{0xa3dc809d,0xc181c05f,0x386d80cb,0x2d9268de}},	//   _तोर_, پیوٹ, _fuer_, naye_,
   {{0x9f4ee8df,0xdca39978,0x64a38603,0xe8e0c0d1}},	//   _sofà_, _пати, _пата, _đồi_,
   {{0xd77681b4,0x69d61743,0x6e22a8e0,0x6b8e4043}},	//   _رائع, _aaye, liob, _jebg,
   {{0x26de40b3,0x7bca8150,0xdcf6003a,0x660f00fd}},	//   _štoj_, mefu, _peyğ, thck,
   {{0x6004c141,0x3f83c086,0xa2c44047,0xa91d8147}},	//   _kòmk, ðjur_, _रहन्, _seži,
   {{0x23ac4ca2,0x7c21d594,0x9f4583bc,0x69d628e1}},	//   _चांद, bilr, _anlè_, _daye,
   {{0x2005c06a,0x96054281,0xc605407a,0x3ce004f5}},	//   ckli_, रस्ट_, रस्य_, _driv_,
   {{0x3f910b6b,0x3bbbc21d,0xed59e8e2,0xa91da8e3}},	//   razu_, _המוד, veži_, _veži,
   {{0x38b61b59,0xa5bb402e,0xad9b0086,0x6d4642a4}},	//   bær_, _ajór, rhús, _byka,
   {{0x7bd568e4,0xd8794032,0x443ec8f9,0x442cca26}},	// [2670] _pazu, زمات_, oot_, ond_,
   {{0x39474017,0xa3dc8e47,0xb8830047,0x6d4100b5}},	//   āns_, _तोल_, říst, ğlad,
   {{0xb5fd89fa,0xda0cd08d,0x99900166,0xceb8c007}},	//   _dišn, िघात_, ťaťa_, ntę_,
   {{0x7bd568e5,0x98b10384,0xb87b4032,0xb812c02a}},	//   _wazu, _जमाए, _críc, িচিত_,
   {{0x3e718082,0xa3acc08f,0xa5bb410d,0x92ad4079}},	//   _sát_, गला_, _fjór, কবে_,
   {{0x7c3e423f,0x466b68e6,0x3e718047,0xdb1c0041}},	//   copr, _грам_, _pát_, berä,
   {{0x6263c05f,0x7d028010,0xc1740020,0x69dd8019}},	//   _főol, ayos, _haɗe_, _óseo,
   {{0x386d801e,0xc1740020,0xec79c477,0x65698073}},	//   _tuer_, _kaɗe_, опи_, _ugeh,
   {{0xdb1c4086,0x61e9a8e7,0x25ade8e8,0xda348051}},	//   _harð, _inel, rgel_, _четы,
   {{0xad9b069a,0x99ddc05b,0x9f4ecfb4,0xaf05d43c}},	//   skúl, plňo, _sofá_, дпол,
   {{0x4423100c,0x224968e9,0x2d924067,0x61e99a41}},	//   dij_, klak_, yaye_, _knel,
   {{0x6448c232,0x442cdea1,0x38b6036b,0x7ae34051}},	//   aldi, and_, tær_, änty,
   {{0x9f588107,0x7bd701a8,0x628ac085,0x6ff5c032}},	//   özök_, _baxu, _ewfo, _يستط,
   {{0x2d9268ea,0xb5fb4319,0x200c28eb,0x81ce0079}},	//   waye_, _diám, ódi_, রাই_,
   {{0x61e9a8ec,0x69cba8ed,0xaad1c54a,0xfd4a40eb}},	//   _onel, kege, _तनिक, bulọ,
   {{0xa5bb0038,0x6aa1266a,0x7649e8ee,0x261a0028}},	//   lión, álfa, nley, मोशी_,
   {{0xa3d905da,0x764428ef,0x7bcaa430,0x3946c022}},	// [2680] _ठोक_, _ikiy, yefu, _xyos_,
   {{0x7c2d8032,0x7d06854a,0xc1740020,0x6d464066}},	//   éarl, _üksi, _daɗe_, _vyka,
   {{0x600b054a,0xf986410b,0xb87b4166,0x6d464036}},	//   _kümn, _огно, _príc, _wyka,
   {{0x2d8fe8f0,0x27e9c0e2,0x3a2dc011,0x6f038036}},	//   _nege_, _ɗana_, jnep_, dync,
   {{0xe7e3008f,0xdb1e28f1,0x2fc1021b,0x7bd7003a}},	//   खाचा_, _tapó, _ybhg_, _yaxu,
   {{0xdb1c004c,0x7e6e4022,0x75360010,0xa3ae8048}},	//   perä, _tubp, _mxyz, _काळ_,
   {{0x7d0468f2,0x07a34217,0x9f4341c0,0x6b634039}},	//   lyis, _јасн, _dojó_, _акра,
   {{0xe1ff4018,0x7bca8391,0xd5aa05de,0xfc3f04f2}},	//   _lión_, sefu, _कागज, iría_,
   {{0x7bca99c2,0x64468026,0xeb9a801f,0x26c582ea}},	//   pefu, _ūkiu, _миа_, _eplo_,
   {{0xa5bb0166,0x660d28f3,0x31574052,0x6aaa813a}},	//   gión, _slak, ויפן_, puff,
   {{0xd5afe8f4,0xed59c04f,0x44230114,0xe57ac0d7}},	//   _ис_, dežu_, vij_, _дзе_,
   {{0x6dc482bc,0xceb8cf59,0x0906d807,0x7c2e0820}},	//   _učač, rtę_, _опен, enbr,
   {{0x1169c4e8,0xceb8cf59,0x9f5841cb,0xdfd2c032}},	//   _علوی_, stę_, _doré_, _ليش_,
   {{0xdb1e03bc,0xe1ff430d,0xc17400e2,0xddc440b5}},	//   _rapò, _ción_, _raɗe_, tmiş,
   {{0x660d193f,0x2019e8f5,0x394d42bc,0x6298a8f6}},	//   _tlak, ësie_, _šes_, nsvo,
   {{0x600b009d,0x7bdae8f7,0x442328f8,0xfbac45da}},	//   _gümn, ldtu, sij_, _चाउम,
   {{0x2904e5b9,0x78a60077,0x44230147,0x7bd7190d}},	// [2690] nyma_, crkv, pij_, _taxu,
   {{0x9f890086,0xaca3c044,0x9f658089,0x05df4045}},	//   _góðu_, _saịk, _štít_, _पोरब,
   {{0x7649c3a6,0x7c2d8032,0x08f8008c,0x7bd8d19b}},	//   yley, éarm, _فریب_, _mavu,
   {{0x7bc1812d,0x6298814c,0x444428f9,0xdd9b811b}},	//   _sblu, dsvo, _zk_, іше_,
   {{0xb87b68fa,0x5d7a4052,0x64a58de0,0x2d8fe8fb}},	//   _fría, _מארק, хала, _rege_,
   {{0xb4cb44ef,0xdb1c0041,0x3e750300,0x9c138112}},	//   लबी_, rdrö, _kåt_, _sọbj,
   {{0x442128fc,0x78ad4051,0x68e2c017,0x60124086}},	//   _mmh_, luav, _arod, _dæmd,
   {{0x44212831,0x53d7c09d,0xad9b5b9d,0x63ad40b4}},	//   _lmh_, _भोजश, _glút, şină,
   {{0x68e2c29a,0x63ad8360,0x7649e8fd,0x9f47c032}},	//   _crod, ɗann, rley, _inné_,
   {{0x2d8fc0cb,0x68e2c036,0x7bd8c024,0x69c2c14b}},	//   _wege_, _drod, _cavu, _eboe,
   {{0xa5bb0019,0x2d8fc127,0x47ca402a,0xc7d680c3}},	//   rión, _tege_, রাচী, _רועי_,
   {{0x64a6146b,0x44210e89,0xd875c1b4,0x248da8d8}},	//   нама, _amh_, _كاتب, _kwem_,
   {{0xea9fc1c0,0xe8e08112,0x7e698127,0x32094d31}},	//   _baṣi_, vaịs_, _miep, dkay_,
   {{0x444401d6,0x69dbc0fc,0x3e750383,0x09a84048}},	//   _qk_, ldue, _båt_, गल्य,
   {{0x78bbc8a1,0x7c2e1e0b,0x442102a4,0x68e2c65a}},	//   ltuv, rnbr, _dmh_, _zrod,
   {{0xfc3f0319,0x7c3602bc,0x61fd68fe,0x6000403a}},	//   rría_, _šarč, _cosl, _nömr,
   {{0xa3b6c260,0x25bfd529,0xb5fd8013,0x25a028ff}},	// [26a0] ङ्क_, iful_, _višl, _idil_,
   {{0x25bfe900,0x41c10185,0x6e260006,0x248005bb}},	//   hful_, ष्ठस, likb, _itim_,
   {{0x78bbcc99,0x2fd85477,0x61ebe901,0x93b700c3}},	//   htuv, _varg_, _ongl, _אליו_,
   {{0x7e698064,0xdd8f8d72,0x78bbd09c,0x2a69023b}},	//   _ciep, موم_, ktuv, _xiab_,
   {{0xc8b64523,0xa5bb0070,0xa4d484c5,0x25bfc15a}},	//   _ясны, diól, толі, dful_,
   {{0xb3cf4079,0x99894036,0x62810019,0x6abac621}},	//   রাউজ, chał_, ílog, yttf,
   {{0x5334804c,0xa3b3cb35,0xdc12c080,0xa2e34ae4}},	//   ъект, टलन_, xşıl, _йорд,
   {{0xb6bb43bd,0xdb1e409d,0x4425e902,0x79964010}},	//   _מצלי, repä, eil_, nayw,
   {{0x69d9e903,0x63b780fd,0x3f9149dc,0x6253401f}},	//   _dawe, çanë, _yezu_, nçoa,
   {{0x9f458070,0x6253401f,0x2b168119,0x7640c9dc}},	//   _coló_, içoa, _пьер, somy,
   {{0x69dbe904,0x62588032,0xd36f8182,0x25a001d6}},	//   bdue, ríof, _اهم_, _bdil_,
   {{0xb87b0047,0x68e42905,0xa3e740b2,0x6609e906}},	//   jvíc, _brid, _मोन_, ckek,
   {{0x2d921786,0x7bdc12c8,0xf8cf4374,0x7bd8e907}},	//   _deye_, fdru, _सैंय, _tavu,
   {{0xdb1c4250,0xd7f8016d,0x78adc066,0x26020031}},	//   _abrí, нус_, ňový, _bóos_,
   {{0x99804038,0x61ebc1f4,0xa3ae817e,0xfc3f0004}},	//   zniť_, _yngl, _काई_, brín_,
   {{0x6ed38080,0x62588359,0x61fd4149,0xdb1ac7fb}},	//   _qəbə, níod, _qosl, detø,
   {{0x69cf2908,0x76428057,0xd2f8c05f,0x7bce2909}},	// [26b0] mece, dooy, _رکھا_, bebu,
   {{0xb4bf1f38,0xb4cd009d,0x6a62c112,0xa01b40cb}},	//   ीबी_, रबी_, _ọfla, _stöb,
   {{0x3f91690a,0xcf93c009,0x81da8079,0xe9d98036}},	//   _vezu_, רטע_, ়ান_, _paź_,
   {{0x764281c8,0x7c2540b3,0xb5fd8077,0xddc78011}},	//   gooy, sihr, _tišm, _bujš,
   {{0xfd964626,0x69dd290b,0xfbb84079,0x78ad40c4}},	//   _בדרך_, idse, ীয়ত, quav,
   {{0x764d690c,0x6e22e90d,0x6441c0c2,0x63b54036}},	//   llay, _amob, xoli, _uczn,
   {{0x41b10036,0x69cf290e,0x69d9dfca,0xe7e08048}},	//   _झांस, kece, _pawe, _गोळा_,
   {{0x69cf0451,0x2d894b64,0x6441e90f,0x2ca9424f}},	//   jece, nbae_, woli, orad_,
   {{0x4ec3802a,0x25bfe3a6,0xa3acc048,0xf99f40b6}},	//   ্মেল, rful_, गलं_, _flèv_,
   {{0x2b9c4185,0x764d530b,0x1309c04c,0x68e41894}},	//   mácí_, hlay, дной_, _rrid,
   {{0x2d920565,0x24800c5d,0x2ca94066,0x69db8134}},	//   _peye_, _stim_, hrad_, _kaue,
   {{0x6281829e,0x62854af1,0x7bdaa910,0x78bd2911}},	//   _itlo, ipho, _zatu, ftsv,
   {{0x7bdaa912,0x7bdc2913,0xb5fd8039,0x7bce2914}},	//   _yatu, tdru, _aišk, tebu,
   {{0x33d5093d,0x7d062915,0x4425d746,0x7e6bc340}},	//   ліст, ryks, qil_, _higp,
   {{0x78bd1d50,0x539ac0c3,0x1867065e,0x7db64a55}},	//   atsv, _חיצו, тари_, ксац,
   {{0x69cf2916,0x7bdc260d,0xc17406df,0x657bc21b}},	//   cece, sdru, _faɗa_, ncuh,
   {{0x6e241fb5,0x6fe18048,0x6b974018,0x3b964244}},	// [26c0] _imib, पयां, faxg, вјет,
   {{0x81ce002a,0x764d5238,0xaf060c00,0xf41f402d}},	//   রাও_, alay, _апол, _zväz_,
   {{0x764d523b,0xa3b341f9,0xa3d58a94,0xe73a167a}},	//   blay, _टार_, िजन_, _цен_,
   {{0x7989c15d,0x44278359,0xb87b04f2,0xbea341dc}},	//   jbew, ein_, lvía, рацк,
   {{0x216785a6,0x853040e2,0x6d4bc730,0x629ae917}},	//   вици_, baɗa, _nyga, zsto,
   {{0x629ae628,0x6383495c,0xb87b019d,0xdb21402d}},	//   ysto, _вгра, nvía, štát,
   {{0xf77300c3,0x41dd8e95,0x628557f7,0x69dd00b0}},	//   סקה_, _नोकस, cpho, ydse,
   {{0x7659e918,0x58d8e919,0x26d84033,0x69db80fc}},	//   _chwy, едия_, _isro_, _gaue,
   {{0x6258a91a,0xe3ba8bb4,0x78a9e91b,0x7cebc10d}},	//   ríod, _оба_, grev, vörð,
   {{0x61ed0068,0x7afcc041,0x3a2480f8,0x1daec048}},	//   _snal, ärto, _hmmp_, _टाकत,
   {{0xb95b4031,0x65950c35,0x6448803f,0x69cf291c}},	//   _abìl, лану, _ikdi, tece,
   {{0xa5bb4031,0x764d403a,0xa526c02b,0x78bd291d}},	//   _amón, xlay, _имед, ttsv,
   {{0x629ae356,0x68e282bc,0xa3b34027,0x3f98291e}},	//   ssto, nvod, _टाल_, faru_,
   {{0xf1bf0018,0xb4bec39a,0xfc3f0ad6,0x78bd0407}},	//   cián_, ँझी_, rrío_, rtsv,
   {{0xd37880e0,0x333a0018,0x9f47c070,0x07a3c748}},	//   _gaće_, _cxpx_, _donó_, _тајн,
   {{0x22840651,0xae1f0b35,0x2ca94824,0x58d50dbe}},	//   рург, मोशन_, trad_, _боит,
   {{0x3f98291f,0x9f5e80da,0x5d554bd4,0xbcfb4031}},	// [26d0] baru_, _botë_, укат, _agér,
   {{0xf99f40ce,0x764d6920,0xf8bf001e,0x224de921}},	//   _alèt_, slay, mté_, zlek_,
   {{0x8c3dc06a,0x2d9900b4,0x6b680107,0xb5fd804f}},	//   muşt, oase_, _végü, _hiši,
   {{0x2ca94166,0x62870283,0x764d4c64,0x2b000185}},	//   prad_, mpjo, qlay, रहरु_,
   {{0x7659c1f4,0x8fa5a922,0x80d92923,0x8557405f}},	//   _rhwy, гале, मिटे, _شیئر_,
   {{0xf1bf0004,0x660d6924,0x628544f5,0x6d4d040d}},	//   xián_, lkak, ppho, _myaa,
   {{0xe4580052,0xf1b9c011,0x99760080,0x6d4d00bc}},	//   דיגט_, liši_, _nəşr_, _lyaa,
   {{0xa3c1523e,0xb4cec027,0x3e7887a4,0xf99f5a1c}},	//   ंभव_, शबू_, _dét_, _doèg_,
   {{0xb5fd8570,0xa5358051,0xfc3f003c,0xd3788011}},	//   _niši, _снач, luíu_, _saće_,
   {{0x87d78228,0x6a734085,0xf076c05f,0x7989e925}},	//   _جغرا, _aħfi, دیوں_, sbew,
   {{0x224dc75a,0x2019c039,0x6281a926,0x7e6bc71c}},	//   plek_, ėsi_, _utlo, _tigp,
   {{0x2d990339,0x7e6d0b87,0x9f47c34d,0xa2a4c0c6}},	//   gase_, _ciap, _sonó_, _किर्,
   {{0xb05b404c,0x18a5d511,0x645a8051,0x74b9164e}},	//   _epäi, _салм, _yhti, курс_,
   {{0x29094010,0x629c0206,0x70560865,0x7c250061}},	//   dyaa_, tsro, انسا, _cmhr,
   {{0x8c1ac093,0x7d09e927,0xe5a66506,0xe737065f}},	//   _רוצי, lyes, ливи, гер_,
   {{0x6e29d703,0xa3e58045,0xb5fd8639,0x69dd5ef4}},	//   nieb, _बोस_, _fiši, _case,
   {{0x2cbfe928,0x6b956929,0x7d1be92a,0x1bea443e}},	// [26e0] ntud_, _bezg, nzus, ндаи_,
   {{0xb8cc4c4b,0xb05b0051,0x28a6c09d,0x9d1b0323}},	//   _गि_, ttäe, _खिसि, _נויט,
   {{0x6e29c1d4,0x09e6887b,0x41aa8b24,0x2a6d80f1}},	//   kieb, ложн, евен_, _bieb_,
   {{0x2bc006fc,0xf2d30087,0x442581f4,0x7e7ec05f}},	//   श्रा, _פער_, _aml_, _éppe,
   {{0x8cd3c045,0x69c44206,0x3e7880d1,0x67360017}},	//   _बैलो, mfie, _sét_, šajā,
   {{0xfc3f003c,0x78a48158,0xbddb4231,0xddcbd09c}},	//   buíu_, šivo, _akèh, _figū,
   {{0x2d990196,0xa3e9a92b,0xfd5040d1,0x26d84043}},	//   yase_, याज_, _nghẹ, _usro_,
   {{0x6b989539,0x4425a92c,0x2fc7c010,0x68e4409d}},	//   savg, _eml_, _abng_, ovid,
   {{0x7e6d05f5,0xb87b4031,0x2d99292d,0x7e7b497c}},	//   _riap, _aríj, vase_, _čupi,
   {{0xa3dc8048,0x1cbb4052,0x629e4011,0x28ac5d70}},	//   _तोच_, עמיע, ospo, _चिनि,
   {{0x6d4d00c9,0xe9ff800c,0x23c640c6,0x62588032}},	//   _syaa, _chặn_, र्यद, cíoc,
   {{0x7c28d46b,0x6445692e,0xf1bf05e5,0xdb0540cb}},	//   sidr, zohi, ciál_, pfhö,
   {{0x3f9a692f,0xb87b529d,0x6445412c,0x7bde2930}},	//   kapu_, _prím, yohi, _bapu,
   {{0x69dd6931,0x5fc64cbb,0xf1b9c570,0x9f5e8157}},	//   _sase, र्मल, viši_, _potè_,
   {{0x6016c01d,0x2fde8010,0x6b9ae932,0x68e4580a}},	//   _câme, _matg_, matg, evid,
   {{0x6b9aded3,0x9f5e8694,0x6288c0c4,0x7abbc2a6}},	//   latg, _coté_, mpdo, _נצחו,
   {{0x947747c3,0x37ab447f,0x2001009d,0xfbab47d4}},	// [26f0] ادرا, етен_, _tohi_, етей_,
   {{0x4438407a,0x6fb20064,0x60cd2933,0x442a0e2e}},	//   _cjr_, _जाएं, _ipam, cib_,
   {{0x629a151a,0x645c4e94,0xd6d142f0,0x96e8559b}},	//   štor, _dhri, تقا_, льца_,
   {{0xd6d8410e,0x7bde0618,0xc64b8032,0x6285000b}},	//   ыту_, _zapu, رجال_, _itho,
   {{0xdce0c0b5,0x3f9a4112,0x2ed1dfee,0x644542c0}},	//   kamı, bapu_, _तन्त, pohi,
   {{0x625881b4,0x3dddc056,0x7d1bc03a,0x6a8589db}},	//   tíoc, _saww_, vzus, алка,
   {{0x80d58028,0x6b9ae934,0x80c88079,0xf2e4411b}},	//   _मैरे, datg, লিষ্, _люто,
   {{0x7999805c,0x44258085,0xf1bf002d,0x6d578080}},	//   qaww, _wml_, fiám_, əxan,
   {{0x7c2a8af2,0xd5ed00d1,0x61fbe935,0x442588c7}},	//   bifr, _giả, rjul, _tml_,
   {{0xb5fb4032,0x7d1be936,0x6b9ac060,0xdb1ac01f}},	//   _fhág, rzus, gatg, jetó,
   {{0x69c46937,0x442a2938,0x26c16939,0x68e4404f}},	//   yfie, vib_, ntho_, zvid,
   {{0x6d5d803c,0xed598011,0x78ad462b,0x6602c40d}},	//   _úsas, _kzž_, krav, _gook,
   {{0x68e44669,0x661d00fd,0x3eacc4f1,0xc956109b}},	//   xvid, ërka, ardt_, ртны,
   {{0xa136c009,0xb4d6046d,0x60db812c,0x7d06c051}},	//   _דאנק_, _सनी_, _msum, äkse,
   {{0x699641bc,0x9f5e8047,0x249fc397,0xe9df401f}},	//   ирах, _poté_, lsum_, _baú_,
   {{0xcb128009,0xb5fb1a6d,0x629e4065,0x7e6f434d}},	//   קלן_, lmán, vspo, _cicp,
   {{0x7bde293a,0x6285293b,0x14265a0b,0xd0264026}},	// [2700] _tapu, _etho, адам, амай,
   {{0x442a293c,0xa3e58e31,0xc7b8c0b3,0x6016cdd3}},	//   qib_, _बोल_, biđu_, _zâmb,
   {{0xf1bf40e1,0x81df8079,0xdef905dd,0x74da01f9}},	//   _imán_, তান_, _быў_, _पैतृ,
   {{0xb5fb5847,0xda6581b4,0x69c99c61,0x55e653f3}},	//   _diás, ماني, _cbee, _томб,
   {{0x80c40079,0xb5fb4019,0xdce0c189,0x228c40ce}},	//   শিক্, _viát, yamı, _bòkò_,
   {{0x02a68299,0x4427e93d,0x6b9c293e,0xfc3f003c}},	//   арим, _nmn_, narg, luír_,
   {{0x99990038,0x82a34119,0xdce0c530,0x8f9b0052}},	//   losť_, _марж, vamı, דיצי,
   {{0xe643a93f,0x3ddf815d,0x35f4dd03,0xfc3f2940}},	//   _десп, _gauw_, спир, nuír_,
   {{0x6d59c036,0x3e7c2941,0xc7b8c570,0x2bc640ba}},	//   _czwa, _lít_, ziđu_, र्था,
   {{0x4427d3e1,0x46c713a2,0xbea6811b,0xf1b9c077}},	//   _cmn_, _लहलह, _важк, dišu_,
   {{0xbb4681bc,0x78ad4451,0x661627d2,0x3f9c8150}},	//   _тежк, zrav, _blyk, mavu_,
   {{0x2ca04834,0x6b9ac6ed,0x2d804036,0xe4e6c0d9}},	//   ksid_, satg, jcie_, _вікн,
   {{0x61e281b1,0x601004c9,0x628a8206,0x7982c02e}},	//   idol, _täml, lpfo, _ifow,
   {{0x99990166,0x3f9ca942,0x2486c006,0xbb84c1b4}},	//   dosť_, navu_, _itom_, _الغي,
   {{0x64472943,0x443a0033,0x66162944,0x442ce945}},	//   roji, _djp_, _flyk, mid_,
   {{0x9dab00c5,0x6447124a,0xf1b9c077,0x660400fc}},	//   _ръка_, soji, bišu_, _goik,
   {{0xcf9b401b,0x799d01c6,0x81df802a,0x32d880d1}},	// [2710] вје_, masw, তাম_, _lũy_,
   {{0xdd9101aa,0x78ad6946,0x46a78b35,0x798d407a}},	//   _بوک_, rrav, _गिलह, sbaw,
   {{0xdc3c00c3,0x22524177,0x7bd52947,0x78ad4134}},	//   _בעזר, blyk_, mezu, srav,
   {{0x249f0017,0xe45f0041,0x799d2948,0x61e2a949}},	//   šumu_, stöd_, nasw, gdol,
   {{0x2ca0694a,0x3204a45d,0xb9c481b4,0x2486c022}},	//   csid_, _domy_, تقني, _ntom_,
   {{0x600f8240,0x3f9ca94b,0x25a6c231,0x224940fc}},	//   _tømm, gavu_, _adol_, loak_,
   {{0x68e9a94c,0x60c2a8c3,0x2a78658b,0x61e280c4}},	//   _wred, atom, _gurb_, bdol,
   {{0x442ce8a0,0xdb164032,0xed59e94d,0x7bd5000b}},	//   eid_, _ócái, лой_, hezu,
   {{0x7a334283,0x799bc21b,0x9d15a94e,0x6448c02c}},	//   għti, rauw, _удач, fodi,
   {{0xf8ae81aa,0x2cadc093,0x62588032,0xf1b9c590}},	//   _سکه_, rred_, níon, višu_,
   {{0x2cadc38f,0x26c10022,0x59a7408f,0x6b9c294f}},	//   sred_, _nqho_, गणार, varg,
   {{0xe9df400c,0x2d9da950,0x2ca041c8,0xc332421d}},	//   _thúy_, nawe_, ysid_, לוי_,
   {{0x6c85c1b4,0x442ce951,0x224d80b3,0x78a92952}},	//   _التم, bid_, _mkek_, ševn,
   {{0x2005a953,0x661bc033,0xa3e75f38,0x63830c1b}},	//   _joli_, lhuk, _मोल_, згра,
   {{0x81cd0079,0x639ac052,0xdcebc085,0x61e2a954}},	//   রয়_, _עסקנ, _begħ, ydol,
   {{0x6616127d,0xf2d2c009,0x99990166,0x6e2d6955}},	//   _ulyk, _זעה_, tosť_, giab,
   {{0x7d0d405f,0x6e36513b,0x2bbdc028,0x7fd60363}},	// [2720] gyas, rnyb, ्भपा, _ліні,
   {{0x68fb00c3,0x80ca402a,0x2d994031,0x78a48089}},	//   _עליה, রিল্, _eese_, šivk,
   {{0xe6464d9b,0x22494232,0x6e2d6956,0xb5fdc0b3}},	//   _генп, boak_, biab, zmša,
   {{0x2d9d85dc,0x443802de,0x2249407a,0x2d9942a4}},	//   gawe_, lnr_, coak_, _gese_,
   {{0x6448e957,0x6fd84374,0x225f8303,0x3a2de958}},	//   yodi, ड़दं, _dhuk_, diep_,
   {{0x60c440fd,0x6e298094,0xb95b41c0,0xb87b41c0}},	//   mtim, _emeb, _abìw, _aríw,
   {{0x2486ca26,0x91e6895c,0xb7db00c3,0x61e0a959}},	//   _stom_, _лове, רקצי, _taml,
   {{0xf1bf0107,0x661bc71c,0x6b83c396,0x60c2a95a}},	//   riák_, ghuk, _afng, ptom,
   {{0xb5fd8007,0x99804007,0x6606695b,0x26388013}},	//   _višt, lnių_, _mokk, nčom_,
   {{0x3e414039,0x7984002e,0x799d0418,0x3f98ce57}},	//   mėte_, _afiw, wasw, úru_,
   {{0x4bfb4087,0x0dcac11b,0x78a2a95c,0x661bc00b}},	//   אליס, _були_, lsov, bhuk,
   {{0xaaa9e95d,0x9e66e95e,0x786b01b7,0x78600041}},	//   _किरक, _увед, _iżvi, hövd,
   {{0x2d9940c4,0x2a6001c8,0x442ce95f,0x6b9e6960}},	//   _rese_, _dhib_, pid_, kapg,
   {{0x442e9679,0x61e44b9b,0x3959c0fa,0x65760107}},	//   nif_, edil, üsse_, _egyh,
   {{0x799d04fd,0x5333e961,0x9f4140fd,0x6e2d40aa}},	//   pasw, _нешт, rdhë_, tiab,
   {{0x61e44d45,0xe6674603,0x7bd500f7,0x9f5e80d2}},	//   gdil, стго, sezu, _notí_,
   {{0xb87b0066,0x53994051,0x66066962,0x6e2d6963}},	// [2730] zvíj, ивая_, _dokk, riab,
   {{0x68ed2964,0x6b9a8007,0x99894166,0x78a29215}},	//   _irad, _netg, dnať_, dsov,
   {{0x61e46252,0x66066965,0x3f8141f4,0xb5fb4ed0}},	//   bdil, _fokk, rchu_, _chác,
   {{0x63a880e2,0x224b0053,0x3206c0f8,0xd131883b}},	//   _addn, nock_, _nooy_, وما_,
   {{0xbddb4031,0x2bc64045,0x7c2ac6bc,0x2d9d86ce}},	//   _ajèg, र्हा, _omfr, rawe_,
   {{0x6d5d4017,0x186985ac,0x442ea2fe,0xaaa9c045}},	//   _izsa, шали_, gif_, _किलक,
   {{0x28dd4281,0xf991c1b4,0x661d02bc,0x6265c6dc}},	//   _नैति, وبة_, khsk, овка,
   {{0x99801d56,0x225f807a,0x0609e966,0x291fc232}},	//   _omiš_, _uhuk_, рник_, tzua_,
   {{0xe7c64914,0x61e2c05e,0x3f9ec2bc,0xe616c11b}},	//   र्वप, _daol, fatu_, ідь_,
   {{0xb5fb2967,0x644aa968,0xa7fcc06a,0x69cd01ae}},	//   smál, cofi, smın, _abae,
   {{0x78602969,0x26de80f8,0xc17400e2,0x61e4696a}},	//   növe, _gsto_, _haɗi_, ydil,
   {{0x60c454d9,0xe0df4141,0xe56a0119,0xba3d0026}},	//   ytim, _osò_, иинд_, drįs,
   {{0x4438013a,0x41c2c045,0x60c446e2,0x25a9002c}},	//   tnr_, _वॉटस, xtim, _ddal_,
   {{0x78600107,0xcb69cd0d,0x3f69d07a,0x99804026}},	//   köve, _кале_, _кило_, ynių_,
   {{0xe0df402e,0x66065664,0xe29a296b,0x9989402d}},	//   _asò_, _pokk, раб_, znať_,
   {{0xd7f880d1,0x3f9a0044,0x799b80cb,0x69c9c206}},	//   _nhăn_, _wepu_, _neuw, nfee,
   {{0x644aa0b4,0x68e9c107,0x8f76031e,0xa5bb0004}},	// [2740] yofi, nved, _муні, riót,
   {{0xb05b537b,0xa3e20374,0xb5fb40d1,0x80d70036}},	//   _spär, _नोच_, _phác, यबरे,
   {{0xe57aa96c,0xdc2a801c,0x3e7740f6,0x6258843e}},	//   азе_, یسته_, _oħtu_, bíol,
   {{0x6b9aa96d,0x76a041c0,0x442e805c,0xdd8f820c}},	//   _setg, _aáyá, wif_, نوم_,
   {{0x442a696e,0x7641405f,0x92e68079,0x91a6c031}},	//   _tmb_, élye, _পথে_, _ajo̟_,
   {{0x2cb240de,0x78a2a96f,0x799b81d4,0x28b2054a}},	//   mryd_, rsov, _eeuw, _जिनि,
   {{0xff47c182,0x7bce41d6,0xdb1c0086,0x24804fc0}},	//   _آخ_, _ibbu, sfræ, lqim_,
   {{0x2bc66970,0xddc98119,0x6ca6c698,0x2bd84027}},	//   र्रा, _vieţ, орож, ड़वा,
   {{0xc17406df,0xb4c9054a,0xdb074053,0xb87b0086}},	//   _faɗi_, _ईहे_, _adjè, rvík,
   {{0x7e7c625f,0x2007e971,0x136ac3dc,0x68ed00fd}},	//   _kurp, _coni_, ишни_, _rrad,
   {{0x25a90018,0x61e2c0b2,0x24892972,0x2007e973}},	//   _pdal_, _taol, _stam_, _doni_,
   {{0xa2cd4abd,0x7c3e084f,0x2007c053,0xe1ff435d}},	//   _सहस्, _ajpr, _eoni_, _khóe_,
   {{0x0e69c3a9,0x7e7c41a8,0x7e62cc9f,0x6b9c415a}},	//   _اصلي_, _lurp, _ihop, _oerg,
   {{0xdfcfc032,0xddc9802d,0x63ad86df,0xa3cd909f}},	//   _ليه_, _mieš, ɗans, ष्प_,
   {{0x443e80c4,0x3de3002a,0x2d884044,0x93cbc05f}},	//   _mjt_, যাবল, _ọlị_, _خانہ_,
   {{0x7afcc54a,0xbddb4031,0x09acc079,0x7bda001e}},	//   ärtu, _akèr, ক্রা, ôtur,
   {{0xd37b5987,0xb4e5425c,0x4035007b,0x443e8033}},	// [2750] аче_, पटे_, _неис, _ojt_,
   {{0x3eb800cb,0x79864053,0xb8d34db4,0xc7f840d9}},	//   burt_, _efkw, _टि_, онує_,
   {{0x4cd3c079,0x7c3ae974,0xb05b0051,0x8ca749fd}},	//   তিযু, intr, ntäm, _चिको,
   {{0x7bce41ae,0x92598051,0x248dc018,0x2cb2402c}},	//   _ebbu, щает_, ypem_, bryd_,
   {{0x201ec1c8,0x6016c0cc,0xddc98017,0x442ca975}},	//   khti_, _râmn, _cieš, _bmd_,
   {{0x799d4340,0xfc04811b,0x94258660,0xeb9687c2}},	//   _hesw, мпіо, ямле, пиш_,
   {{0x442c9e98,0xb5fb0107,0x82a44169,0x09c2802a}},	//   _dmd_, rmáj, _оште, োয়া,
   {{0x13e40079,0x68e9c017,0x66028396,0x6b85402c}},	//   মায়, tved, cjok, lchg,
   {{0x3a2d80d2,0x61e42976,0x7a36053e,0x661ba977}},	//   _imep_, _rail, nšte, _iluk,
   {{0x7bd881bc,0x68e9e978,0x69c9c353,0x68edc018}},	//   cevu, rved, sfee, _áadm,
   {{0x68e9e979,0x59cb4578,0xe945cde9,0xb17d802d}},	//   sved, ाभार, _کرای, _zaťa,
   {{0x799d47f2,0x44dd8141,0x19b8c0b4,0x25a04561}},	//   _nesw, _kň_, _душь_, xail_,
   {{0xdb1c0fd0,0x8d5601dc,0x600dc1ff,0x661ba97a}},	//   nerö, яточ, _súmu, _mluk,
   {{0xa06a023d,0x25a04340,0x2d9dc024,0xe3b3c01c}},	//   сага_, wail_, _hewe_, _آرش_,
   {{0x799d697b,0x64434089,0x973cc054,0xdb1c04c9}},	//   _besw, čnil, taće, kfrå,
   {{0xbc764032,0xe73700b4,0xac864f37,0x2618dc2d}},	//   كهرب, чес_, згал, _léon_,
   {{0x55bb00c3,0x2bdc8185,0xb1435d5e,0xa967512e}},	// [2760] _המפו, _यसला, ентл, зита_,
   {{0x224de97c,0xb90445de,0x661ba97d,0x7e7c4093}},	//   hoek_, _भई_, _aluk, _purp,
   {{0x248b405c,0xa5bb41c0,0xe2ca5520,0xdb03c089}},	//   _etcm_, _amóu, след_, _odní,
   {{0x7bc1a013,0x44dd8141,0x799d414b,0xf99f40b6}},	//   _aclu, _bň_, _gesw, _joèl_,
   {{0x66098b32,0x6e3bc077,0x7ded0052,0xf772001c}},	//   _doek, dnub, יקאַ, _تاک_,
   {{0x3fe6c079,0x78a2580a,0x9f4c8070,0xb05b0051}},	//   _পক্ষ, šovs, _andá_, ytäm,
   {{0x2bc2c3b0,0x877b0009,0xbb434051,0xb87b4397}},	//   _शाबा, זאצי, _зерк, _frís,
   {{0xb226a97e,0xbb3b43bd,0xdb1c0d88,0xb5fb297f}},	//   _эмбл, _העלי, berö, rmák,
   {{0x0ef4c9af,0x0c268846,0x2d9de980,0x75244536}},	//   इम्स_, _еман, _dewe_, nziz,
   {{0x9f514070,0xe0cfc20c,0x7bc18032,0x7c3ac379}},	//   _gozó_, ازي_, _gclu, untr,
   {{0x44312981,0x61e6522b,0x6fc1446d,0xd5afd934}},	//   viz_, _oakl, र्टू, _пс_,
   {{0x201ec0fd,0x2d868053,0xa5bb4070,0x6012410d}},	//   shti_, ncoe_, _ilóg, _dæmi,
   {{0x78a606a7,0x0cd74079,0x5e25c05f,0xfc3f02b0}},	//   gskv, _সপ্ত, _تعلق, esía_,
   {{0xb5fb5a34,0x644e02cd,0xe8d90112,0xb4e8c045}},	//   _chán, gobi, _uzọ_, मटी_,
   {{0xe1ff40d1,0x69d9812c,0x764d6982,0x2d9dc1c6}},	//   _nhóc_, yewe, toay, _yewe_,
   {{0x6443406c,0x433bc0c3,0xd2511546,0x75480107}},	//   čnim, _לעוב, _جنب_, észé,
   {{0x644e06df,0x6609868e,0xd5ed00d1,0xd9bec02a}},	// [2770] bobi, _roek, _giá, _আসাম,
   {{0x661b851f,0x2ca6802f,0xfc3f003c,0x7e69c070}},	//   _sluk, dsod_, rrís_, zmep,
   {{0x6e3d1628,0x69d981b0,0x661b86a9,0x7ac70007}},	//   onsb, tewe, _pluk, _эспе,
   {{0xf1bf2983,0x7c2e4dc5,0x6e3d0ae6,0xdcfbc011}},	//   ngá_, _embr, nnsb, zbuđ,
   {{0x3f9e8011,0x661d4041,0x69cb9b5d,0x49745000}},	//   _betu_, _ilsk, rfge, _плюс,
   {{0xe3b8803a,0x69cd41f4,0x7bdae984,0x6eca8080}},	//   _alıb_, lfae, jetu, _təbl,
   {{0x248f805c,0xe45f0051,0xcb668b24,0xb7c88032}},	//   spgm_, ytön_, маше_, سبوك_,
   {{0x2bcfc048,0x601485ef,0x661ba985,0x200a6986}},	//   त्ना, _làmh, _uluk, _zobi_,
   {{0xf99f48d7,0xc17400e2,0x320b4036,0xf2b6c02a}},	//   _blèz_, _yaɗu_, _mocy_, _জনগণ,
   {{0xc87f40fa,0x248d83d3,0x7e640093,0x68e94018}},	//   _muß_, _item_, _ship, _áedu,
   {{0x68e2e987,0xa294811b,0xfb158032,0x9f436988}},	//   _esod, _захі, _تواج, _bajé_,
   {{0x387fa989,0x600b00b2,0xce35c01c,0xb0d8c17e}},	//   _kuur_, _sümp, _کوچک, _बैकग,
   {{0x7bdae98a,0x3ea0a98b,0xe44ee98c,0xa5bdc039}},	//   betu, ćite_, _аж_, siųs,
   {{0x7bdadf9b,0xe45f0051,0x60c9e98d,0xa2d8c3fc}},	//   cetu, stön_, mtem, _फैक्,
   {{0x200a5048,0x248d8010,0x601485ef,0xb34701ff}},	//   _robi_, _ltem_, _dàmh, _raçõ,
   {{0x6d44298e,0xdb1c298f,0x290040fc,0x69dbc0cb}},	//   _txia, ngré, txia_, neue,
   {{0xa5bb403c,0xed57401b,0x037a008c,0x6b67001e}},	// [2780] _amós, дот_, _وحدت_, tégé,
   {{0x27e7c053,0x8d634051,0x2ca6806c,0x601fc01f}},	//   _jann_, твуе, vsod_, _fême,
   {{0xfbcfc0a0,0x6d41006a,0x0e66585b,0x601fc01f}},	//   त्यम, şlat, _окон, _gême,
   {{0x7bdc2990,0x64418077,0x27e7ce89,0x3eba6616}},	//   leru, _ajli, _lann_, rupt_,
   {{0x25a0054a,0x6da387e3,0xfc3f0032,0xe5a38119}},	//   _meil_, тича, isín_, тичи,
   {{0xa01b44c9,0xfa8a95d5,0x2d9f814b,0x6d46417a}},	//   _stöv, осий_, _eeue_, _ixka,
   {{0xa6e1c10d,0x7bdc00b4,0xc3344052,0x69dbc0cb}},	//   óðle, ieru, _װוּ_, feue,
   {{0xd257cefa,0x68204041,0x9f4583e2,0x27e7c061}},	//   мцы_, _döde, _malè_, _aann_,
   {{0x442ee991,0x3f9e8011,0x7bc3c349,0x60c9e992}},	//   _pmf_, _tetu_, _bcnu, gtem,
   {{0xb463a861,0x3958c03f,0x61e9e993,0x78638156}},	//   _акул, ārs_, adel, _акуз,
   {{0x764f0750,0x68ed6994,0x61e9e6df,0x25a02995}},	//   tocy, zvad, bdel, _beil_,
   {{0x200ca996,0x6e22a997,0x27e7c755,0x32068398}},	//   _hodi_, nhob, _eann_, njoy_,
   {{0xd90fc05f,0xc8c8c01c,0x68e2c04f,0x7d02a275}},	//   _نیٹ_, _روغن_, _usod, nxos,
   {{0xdb1c4fb4,0xdce2ccfe,0xb8d700b2,0x9f458171}},	//   _acrí, _ugođ, _चट_, _balè_,
   {{0x25a0011b,0x69cbca8a,0xb4bb825c,0x68e400f7}},	//   _feil_, थ्वी, _अम्_, _esid,
   {{0xa5bb4031,0x601000fa,0x9f458031,0x786004c9}},	//   _amór, _sämt, _dalè_, röva,
   {{0x04670a49,0x7d000041,0xf4bcc079,0x27e7e998}},	// [2790] _отом, ämst, _অনুব, _yann_,
   {{0xdefb03d0,0x7c6703a9,0x3dc0402f,0x63a39fdb}},	//   _дым_, _تابل, agiw_, xann,
   {{0x7a360590,0x645ae999,0x6e2f4033,0x81e88079}},	//   lšta, ilti, _tmcb, বান_,
   {{0xa294411b,0xdb1c4032,0x387fa99a,0xddcf40b4}},	//   таці, _gcrí, _puur_, _dicţ,
   {{0x7e6d699b,0x61e9e99c,0x3e61c086,0x92c1402a}},	//   mmap, vdel, jóta_, ্টে_,
   {{0x200c9ab3,0xd366c3a9,0x7e6d62ee,0x81d30079}},	//   _codi_, _مه_, lmap, _হোম_,
   {{0xdb0380fd,0x69dbc0fa,0x6562e99d,0x44264020}},	//   manë, teue, _azoh, ɗo_,
   {{0xee3f0531,0x7a360039,0x3ebe44d3,0xaca38044}},	//   jný_, kšta, _åtta_, _arụn,
   {{0x973ce99e,0x3dcdc498,0x7bc50066,0x629c4036}},	//   vaća, rfew_, _ochu, _zwro,
   {{0x63a38d31,0x200c81f4,0x93bc80b4,0x92ce8079}},	//   qann, _godi_, _clăd, ষয়ে_,
   {{0xe9ffc00c,0x25a0299f,0x61e9d59a,0xc7cec00c}},	//   _ngầm_, _peil_, pdel, _tống_,
   {{0x660d0033,0x7bc529a0,0x61e9a9a1,0x98abc06a}},	//   _coak, _achu, _jael, şlık_,
   {{0xb5fb4ad6,0xd378c5c7,0x62818d66,0x660d29a2}},	//   _chám, veće_, _hulo, _doak,
   {{0x201e29a3,0x7d04804c,0xa3cf4028,0x6abc1020}},	//   óti_, äisi, _वॉल_, turf,
   {{0x9f45a9a4,0x7e5603e1,0x63a1803f,0x60100041}},	//   _balé_, _птиц, _meln, _säms,
   {{0xee3f0066,0x09e369a5,0xbca601b4,0x6d4101df}},	//   cný_, лосн, _كمبي, ğlar,
   {{0x52754119,0xd54740b4,0xb1464039,0x78a9e9a6}},	// [27a0] туру, епте_, хнал, nsev,
   {{0xaf9a004c,0x2482c166,0xe4574f67,0xd378c13f}},	//   _этих_, íkmi_, ежу_, seće_,
   {{0x7c3e4098,0x6281886f,0xe8038e47,0x61e980d2}},	//   rnpr, _nulo, लाना_, _bael,
   {{0x5ab70009,0x78a9c94f,0x1a9ac009,0x6fc24048}},	//   _אלטע_, ksev, פינע, _लावू,
   {{0x69c643ad,0x644100a0,0xb4ce1561,0x200ca9a7}},	//   _icke, čliv, _रहो_, _podi_,
   {{0xb4ce15a8,0x63a569a8,0x6e244010,0x2bc6459c}},	//   _रहै_, cahn, lhib, र्खा,
   {{0x63a30834,0x50435ae4,0x2482405c,0x6d59c0f8}},	//   _õnne, _серб, _hukm_, _aywa,
   {{0x2a66c022,0x22404f8b,0x60f8c0c5,0x9e66801c}},	//   _qhob_, nnik_, дния_, _سازن,
   {{0x6281a9a9,0x63a1a9aa,0x69c0e9ab,0x1c46a20f}},	//   _eulo, _feln, rgme, _знам,
   {{0x69c280bf,0xb05b16df,0x3a201f41,0x7bc1c3ad}},	//   lgoe, ltäv, _alip_, gglu,
   {{0x6281a9ac,0x69c643ad,0xdb068051,0x2cb08007}},	//   _gulo, _ocke, ämäl, žodį_,
   {{0x78bd0c99,0x63a569ad,0x69c2a9ae,0x7bc1c022}},	//   tusv, zahn, ngoe, aglu,
   {{0x628181a8,0xf1d000d1,0xdb150086,0x6606c086}},	//   _zulo, _tạng_, _íbúa, ökku,
   {{0x7a360007,0xe8038036,0xb4acc048,0x69c650fe}},	//   ršta, लाया_, गळी_, _acke,
   {{0x628180d2,0x22ac8047,0x656400f7,0x27ff40d1}},	//   _xulo, něk_, _ezih, _đun_,
   {{0x3a2029af,0x4431412c,0x2ca94c28,0xc1520112}},	//   _glip_, _smz_, tsad_, ọkọr,
   {{0xe8038185,0xe8df8112,0x64554010,0xdb01c5e5}},	// [27b0] लामा_, _kwụa_, _pkzi, valé,
   {{0x765d29b0,0x4ea7507a,0xda7b084e,0x9f47c053}},	//   llsy, ерда, _ням_, _banè_,
   {{0x2a69023b,0x442100b3,0xdd9181b4,0x08f8005f}},	//   _khab_, _ilh_, لوا_, _قریب_,
   {{0x7bc1e9b1,0xfe70821a,0x200ee9b2,0xddc44379}},	//   zglu, مدن_, _lofi_, rmiţ,
   {{0x1dd30db4,0x61ed69b3,0xdb0382e3,0x2ca945d1}},	//   ध्यत, mdal, mané, qsad_,
   {{0x21294a28,0xa1364009,0xa3d2c08f,0x61ed69b4}},	//   mzah_, _יארק_, ह्म_, ldal,
   {{0x92e88032,0x63a1909c,0x3ebee9b5,0x073545f5}},	//   فريق_, _veln, jutt_, _ревю,
   {{0x7bc1c022,0xdb03856e,0x628186a6,0x60cd69b6}},	//   wglu, nané, _vulo, otam,
   {{0x7989e9b7,0x9f47c0fd,0x63a702bc,0x21294033}},	//   rcew, _tanë_, kajn, nzah_,
   {{0x61ed4051,0x2129405c,0xa934801d,0x3e7b19b6}},	//   hdal, izah_, _сеуш, _rūta_,
   {{0xf745d2bf,0x60cd42f7,0x263880b3,0x78a9d9cf}},	//   тено, htam, mčor_, ssev,
   {{0x44331c0b,0x9a848156,0x224046e2,0x237480a3}},	//   _amx_, _суфл, xnik_, _صالح,
   {{0x9f47c1ff,0x60cd5ce5,0x271cc35d,0xc243168c}},	//   _mané_, jtam, ản_, рняк,
   {{0x61fd42e9,0x7bc3a9b8,0x3ebec1d6,0x61ebc407}},	//   _ansl, ngnu, butt_, _hagl,
   {{0x60100095,0x660f4136,0xf09f41c0,0xc7a30afa}},	//   _dämp, _bock, _awà_, риск,
   {{0x7e7b8398,0x7866c086,0xf8bf001e,0xb5fb1b10}},	//   _niup, rðve, bué_, umát,
   {{0x6e2469b9,0x63a3c35b,0xa0a64007,0x63a729ba}},	// [27c0] rhib, _kenn, тазд, bajn,
   {{0x61ed69bb,0x61ebc621,0xe3b880b5,0x973c8123}},	//   adal, _lagl, _alın_, _leća,
   {{0x7bde69bc,0x6eca803a,0x60cd69bd,0x61ed69be}},	//   repu, _təbi, atam, bdal,
   {{0xdb1c28fa,0x6441c0fa,0x22ac8185,0x7e7b8119}},	//   ngrí, hnli, věk_, _ciup,
   {{0x6283e9bf,0x63a3c033,0x2bc2c045,0xc5f302a6}},	//   _luno, _oenn, _शाला, ידא_,
   {{0x905385dd,0x8d774107,0x3e67809d,0x7a360007}},	//   авіц, _جاپا, võte_, kšto,
   {{0x7a3ec03f,0x2d8029c0,0x973cc0ab,0xb6a3411b}},	//   līti, _ogie_, vaćo, _висл,
   {{0x3ce6cc9c,0x7e7b8105,0x6cedc3ae,0x9f47c070}},	//   _psov_, _giup, जिंग_, _gané_,
   {{0x63a3e9c1,0xdb20e9c2,0x6283c49c,0x62834066}},	//   _benn, _àtún, _auno, ínov,
   {{0xa3ba8182,0xe80551aa,0x3e45c017,0x69d60568}},	//   _زائر_, राया_, rēta_, _abye,
   {{0x2a69023b,0x539b84e0,0x26d8c7f5,0x42751dac}},	//   _phab_, _חיבו, ïro_, лгос,
   {{0x3ce6c04d,0x9f410089,0x68e469c3,0x7e69813b}},	//   _tsov_, _nahá_, kwid, _xhep,
   {{0x26da007a,0xe8054185,0x2246c0c9,0x23c98578}},	//   _appo_, रामा_, _ijok_, _रामद,
   {{0x68f6002c,0x3ebec0cb,0x7a3ec017,0x4425e9c4}},	//   _dryd, putt_, dīti, chl_,
   {{0x9f41169e,0x6458c03f,0x5fd204eb,0x6824c060}},	//   _bahá_, _ikvi, द्धल, _còde,
   {{0xd838d3ca,0x68f60b44,0x61e0e9c5,0x2bc646fc}},	//   lič_, _fryd, neml, र्घा,
   {{0x4421218a,0x32094033,0x39498036,0x61ed002f}},	// [27d0] _tlh_, rjay_, żasz_, _iaal,
   {{0x61ed4833,0x63a8cebc,0x6283c0a8,0xb5fb4032}},	//   sdal, nadn, _yuno, _mhái,
   {{0x9f4369c6,0x7e7b80b3,0x6d5b821b,0x25ff808f}},	//   _tají_, _piup, _syua, ळाली_,
   {{0x28ac458e,0x3a2680f8,0xd04d009c,0x61e0c04f}},	//   _चिचि, ghop_, _tsaɓ, jeml,
   {{0x6d4ec0fa,0x61ebc1f4,0x7e7d69c7,0xd838c04f}},	//   ßbal, _ragl, _iisp, kič_,
   {{0xe8d90112,0x25a94057,0x645500d3,0x251c0087}},	//   _ayị_, laal_, nozi, וודא,
   {{0x78ad69c8,0x4993c1aa,0x628529c9,0x6441c586}},	//   lsav, لیار, _juho, vnli,
   {{0x6e22c061,0x2bcf69ca,0x7e7d4283,0x3a2680a8}},	//   _clob, स्रा, _jisp, chop_,
   {{0xd378c5c7,0x34b2c1b4,0x7d04804c,0xa7fcc3a6}},	//   veća_, مميز, äist, klıd,
   {{0x661bcff3,0x63a8e9cb,0x7c388018,0xaca34112}},	//   skuk, gadn, civr, _nkọc,
   {{0xe8070342,0x6d5d69cc,0x25a941ed,0xd378d8ca}},	//   शाना_, _lysa, kaal_, teća_,
   {{0x6e22e9cd,0x7e7d69ce,0xaca34112,0x2604c14a}},	//   _glob, _nisp, _akọc, वाणी_,
   {{0x63a3d015,0x799be9cf,0x4423404f,0x63a8e9d0}},	//   _tenn, mbuw, _olj_, badn,
   {{0x395e003f,0x34b2c1aa,0x59c6008f,0x60dba9d1}},	//   āts_, _اموز, _वावर, _mpum,
   {{0x6d5d6505,0x2cadc09d,0xdc6707bc,0xab2a0675}},	//   _aysa, lsed_, уард_, хова_,
   {{0x61ed0a6c,0x69c9804d,0x6e92c1b4,0x5fcfe82d}},	//   _gaal, _ncee, _اليا, त्रल,
   {{0x2604e9d2,0xaca44112,0xb05b0fd0,0x9f4c801f}},	// [27e0] वाती_, _otụt, ttät, _cadê_,
   {{0x7e7d51ce,0xaca440eb,0xb97b0052,0xab2a419b}},	//   _eisp, _ntụt, _אנפי, ноза_,
   {{0x68e9a9d3,0xe29754ea,0x7d0900fd,0xbcfb4171}},	//   _ased, гах_, _tërë, _ayéd,
   {{0x225fe9d4,0x7e7d4060,0x2cadc09d,0xdb01c30d}},	//   jluk_, _gisp, ksed_, jalí,
   {{0x3e4cc047,0x69c600cb,0x7644409c,0x99820026}},	//   něte_, igke, mniy, likų_,
   {{0x76428398,0x2d8fc14d,0x20114398,0xd00783dc}},	//   snoy, _afge_, _gozi_, лече_,
   {{0x61e0e9d5,0x644341fd,0x0b594c38,0x201ca3ee}},	//   teml, čnit, _арты_, rkvi_,
   {{0xb5fb41b4,0xdb01c30d,0xe4e6c11b,0xb05b13e5}},	//   _phái, galí, гіон, ntär,
   {{0x645520b4,0xd838dd0c,0xdcef00b5,0x78bbe9d6}},	//   yozi, tič_, yacı, gruv,
   {{0x7644518b,0x25a940a8,0xa3e88ad4,0x442782ad}},	//   hniy, zaal_, _बसि_, chn_,
   {{0xe4574009,0xb05b0041,0x9f4a4303,0x2cadc093}},	//   רייט_, ktär, _babé_, ased_,
   {{0x64a6e9d7,0x443a69d8,0x444469d9,0x61e2a9da}},	//   _бада, hip_, hn_, neol,
   {{0x68e9805c,0x25a969db,0xddc9c06a,0x444469dc}},	//   _xsed, vaal_, lleş, kn_,
   {{0x8c43c381,0x61ed29dd,0x7e7d43bc,0x3e414007}},	//   _лече, _waal, _sisp, mėti_,
   {{0xdddbc59a,0x443a69de,0xddc9c165,0x3e414007}},	//   nmuş, dip_, nleş, lėti_,
   {{0x60c2a9df,0x95e2c5da,0x4956025d,0x63aa8086}},	//   kuom, _खसोट_, ọtụ_, hafn,
   {{0x444469e0,0x3e414039,0x7e6d0010,0x628500f8}},	// [27f0] fn_, nėti_, _ihap, _wuho,
   {{0x25a969e1,0x8574431e,0x47350e50,0x6d5d4531}},	//   saal_, слух, _внос, _vysa,
   {{0x7e7d5f1c,0x60db85af,0xe80384fb,0x2a60517e}},	//   _tisp, _spum, लासा_, blib_,
   {{0x5fc7408f,0x7982e9e2,0x61e2a9e3,0xceb3c2a6}},	//   _लावल, _ngow, geol, מיע_,
   {{0x0526c02a,0xae95035d,0x62988177,0x9f45856e}},	//   মপুর_, _kẹos, epvo, _valí_,
   {{0x973c806f,0x62834066,0xdb03e9e4,0xdb1c14f2}},	//   _većn, ínos, _fenè, lgrá,
   {{0xbddb4053,0x752d40b9,0x64454104,0x225fe9e5}},	//   _skèy, lzaz, mnhi, tluk_,
   {{0x0d85cf93,0xe8d901c0,0x22490043,0x61e28359}},	//   шлин, _ayọ_, _njak_, ceol,
   {{0xf1bf0032,0xf77880f6,0x10d8883b,0x225fd01f}},	//   thán_, _daħq_, _مبلغ_, rluk_,
   {{0x225fe9e6,0x391480b4,0x628769e7,0x6d44c02d}},	//   sluk_, _умур, _kujo, _žiac,
   {{0x2cadc093,0x4425a9e8,0x9f5e400c,0x2a7f821b}},	//   ssed_, _ill_, _ôtô_, _kiub_,
   {{0x63a769e9,0x3eb8c03e,0x6287413b,0xa4d5c0d9}},	//   _lejn, árta_, _mujo, _воді,
   {{0xdb03e9ea,0xd5e400d1,0x18a5c59d,0xdca5d8f9}},	//   _mené, _chí, _талм, _тали,
   {{0x752d40b3,0x9f4c80b6,0x99820007,0x2fc7a9eb}},	//   dzaz, _badè_, tikų_, ngng_,
   {{0x25a6d3e1,0xb05b0051,0x68204041,0xa7a70466}},	//   _yeol_, ttär, _dödl, ркса_,
   {{0x224900fd,0x6abcc086,0x6e29cc1c,0x6e2429ec}},	//   _gjak_, árfe, nheb, _ulib,

   {{0x63a75ebc,0x09064026,0x6fd6011b,0x9f47c34d}},	// [2800] _bejn, шпан, _кінц, _maní_,
   {{0x660d4134,0x9f584086,0xb05b0d42,0xcef646b1}},	//   ajak, _borð_, stär, ичењ,
   {{0xe6d4839a,0x443a69ed,0x61e2a9ee,0x6287401f}},	//   _दहेज, rip_, teol, _cujo,
   {{0xfbd20281,0xdb03e9ef,0x444469f0,0xdb03803c}},	//   द्रम, _venè, sn_, ganí,
   {{0x859b40c3,0x272c0031,0xb05b04c9,0x386c8089}},	//   _בשכו, _fóné_, bräd, _phdr_,
   {{0x61e2a9f1,0xdca35807,0x60c28039,0x44258070}},	//   seol, _фари, ruom, _cll_,
   {{0x387ea9f2,0xb87b41c0,0xb7db44e0,0x6a65c018}},	//   _vitr_, _asíw, _שקלי, gófo,
   {{0xd90dc1aa,0x63aa810d,0xa3de4b35,0xb05b0455}},	//   کیه_, safn, ढ़क_, präg,
   {{0x443869f3,0x390ac23d,0xa3d608c4,0xd846d4e9}},	//   _kmr_, тэйн_, सभा_, ихоп,
   {{0x3e414007,0x798400bc,0x7e6d00c3,0xe8d900d1}},	//   rėti_, _agiw, _shap, _ngỡ_,
   {{0x201ec039,0xb87b4166,0x7e6d29f4,0x443ca9f5}},	//   rkti_, _príz, _phap, miv_,
   {{0xd258011b,0x2bc2d05d,0x7f3b80c3,0x62808303}},	//   иця_, _शाका, _בעבו, _jimo,
   {{0x3ea98aa2,0x4aa6c4ef,0x62888166,0x940c403a}},	//   ćate_, _कौरव, _hudo, şlər_,
   {{0x7c3c00fc,0x28b74036,0x7e6280c2,0xb95b4171}},	//   girr, ेंसि, hlop, _gbìy,
   {{0x3a26e9f6,0x2bc98281,0x7e6d0311,0x7cda803f}},	//   _klop_, _रासा, _thap, lārā,
   {{0x60dd40c9,0x27e3289b,0x224907ca,0xe1ff400c}},	//   _ppsm, sejn_, _ujak_, _khói_,
   {{0xdb038038,0x6e3d03b3,0x69cd00d2,0xdb03c36e}},	// [2810] vaní, misb, _icae, _rené,
   {{0xdb03c004,0x7afa817b,0x3ec3c047,0x3a26c016}},	//   _sené, _ortt, _ústí_, _llop_,
   {{0x628880e1,0xdb018065,0x61ef69f7,0x9984c007}},	//   _nudo, _udlø, _tacl, nimų_,
   {{0x7e62a9f8,0x973cc0ab,0x3f79c009,0x1e84459d}},	//   glop, gaći, אָנע, ілім,
   {{0x24e78244,0x601480d2,0x8cf44039,0x68ed0085}},	//   рцег, _pàmp, _дзяц, _jsad,
   {{0x1ee7405f,0xe3b181aa,0x99824141,0xa3cf4045}},	//   _پوری_, سرت_, _ankň_, _वॉच_,
   {{0x9f47c047,0x7d1d04c9,0x6ef04107,0x63a880e5}},	//   _paní_, hyss, róbá, _dedn,
   {{0x9984c007,0x1c05439a,0x3dc9429e,0x22468070}},	//   dimų_, रावल_, ngaw_, cnok_,
   {{0x6447011a,0x34948c93,0xdb01c107,0x656081f4}},	//   knji, _матр, dalá, _gymh,
   {{0x9f4c0531,0x6602e9f9,0x69cd0019,0x76598036}},	//   ždé_, _enok, _acae, lowy,
   {{0xa5bb4031,0x68fb8066,0x6e29c75d,0x25a90359}},	//   _alóm, _hrud, pheb, _beal_,
   {{0x69d9c00d,0x24890061,0x76598036,0x25a90032}},	//   _ubwe, _buam_, nowy, _ceal_,
   {{0xf8bf0669,0x3075c760,0xd6cec1aa,0x7c3c29fa}},	//   gré_, _лукс, وقی_, tirr,
   {{0xe3b8c138,0x656bc0f6,0x3395c82f,0x68fb8230}},	//   lkın_, _izgh, _الغز, _mrud,
   {{0xab270072,0x68e9c0de,0x25a90018,0x76598036}},	//   бора_, lwed, _feal_, kowy,
   {{0x60c4404c,0x24890022,0x68fba9fb,0x25a9024f}},	//   tuim, _fuam_, _orud, _geal_,
   {{0x973cc5c7,0x76598064,0xf8bf0669,0x660424fe}},	// [2820] vaći, dowy, cré_, _inik,
   {{0xb4e40027,0x3b0a5532,0x3dc9402f,0x3a2069fc}},	//   नबी_, лезо_, agaw_, skip_,
   {{0x9f4ee8df,0x68e9c0fa,0x60c6042c,0xdb018fc2}},	//   _cafè_, hwed, lukm, _belí,
   {{0x443a002f,0xb346c10b,0x98a042bc,0x2489024c}},	//   _hmp_, leçõ, jzić_, _yuam_,
   {{0x7a23454a,0xdb01a9fd,0x24890022,0xdb050070}},	//   _mõtl, _delí, _xuam_, _rehé,
   {{0x7e62a393,0x62889f65,0xe8b6025c,0x8aa69198}},	//   slop, _pudo, _अटैच, брид,
   {{0x645e0044,0x7e629628,0xd25acc86,0x76598036}},	//   _mkpi, plop, лци_, bowy,
   {{0x644702a3,0x9984c007,0x80bec02a,0x660d84c9}},	//   znji, vimų_, ্বস্, öakt,
   {{0x25a90e82,0xf98fc1b4,0x270ec03a,0x9f4ec3bc}},	//   _real_, ربي_, məni_, _zafè_,
   {{0x443a0033,0x6016c119,0x645e00eb,0x8006c02b}},	//   _nmp_, _câmp, _nkpi, счие,
   {{0x629c0a30,0x25a9054a,0xeb9780c3,0x644700b3}},	//   jpro, _peal_, _הדבר_, vnji,
   {{0xf8bf17cd,0xc0cb031f,0x4427c070,0x61e61f30}},	//   tré_, луге_, _eln_, gekl,
   {{0x629c0fd7,0x5c0700c5,0x629ad138,0x463b8052}},	//   epro, бява, spto, רעכע,
   {{0x7a2629fe,0x629c0372,0xdb038410,0x973c8011}},	//   _vóta, fpro, laná, _nećk,
   {{0x644fc669,0xdc3bc009,0x3a22005c,0x61e629ff}},	//   écie, _געגר, bkkp_, bekl,
   {{0x7e644f74,0x68ed0360,0x9f51401f,0x7e918017}},	//   glip, _tsad, _fazê_, _jāpa,
   {{0x48155f7a,0xe805408f,0x764d04fd,0x443a006f}},	// [2830] омас, राला_, _ijay, _fmp_,
   {{0x7afc4033,0x6448ea00,0xb4e94fa8,0xb5fb44e4}},	//   _brrt, nndi, _मनी_, _chár,
   {{0xf7484032,0x207c0052,0x69c9c149,0x64894247}},	//   ملكي_, _גאזא, ygee, _ožig,
   {{0xa5f961ab,0xa2c0c281,0x7afc4033,0x443a003c}},	//   _тему_, _विन्, _drrt, _zmp_,
   {{0x9f47c34d,0x067c0052,0x9f45c14b,0x69dd4a62}},	//   _maná_, אנאל, gelê_, _ibse,
   {{0xe894420d,0x76598036,0xd5bf4017,0xa6958748}},	//   _харь, sowy, žādu_, ориј,
   {{0x69c9c15d,0xe2998039,0xa49b4321,0x27e5c851}},	//   tgee, шай_, _bròg, veln_,
   {{0x6e2d6a01,0xbb4841b4,0x68e9c0fa,0x443ec15d}},	//   nhab, _الفن_, twed, eit_,
   {{0x27e5c095,0x98a048c9,0x786fd6a9,0x6e298ec8}},	//   teln_, rzić_, høve, _ileb,
   {{0x2ca9c283,0x5ba9cef7,0xe705801c,0x63ae0022}},	//   _ħadd_, шком_, _وسای, xabn,
   {{0x6e2d6a02,0x69cbaa03,0x68e9c049,0x69c0401f}},	//   khab, ogge, swed, _ômeg,
   {{0x26c7aa04,0x443ed973,0x27e5ea05,0x7a3ec03f}},	//   muno_, ait_, seln_, pūta,
   {{0xb5fb00b7,0x9f5140fd,0x26c5c11c,0x764d2a06}},	//   plán, _bazë_, sulo_, _djay,
   {{0x2249c0e0,0x4add8575,0x22494232,0x63aae9e0}},	//   čaku_, _महाव, enak_, _gefn,
   {{0xb346c01f,0xdb074107,0x628ac003,0x629c014d}},	//   reçõ, _fejé, _gufo, upro,
   {{0x2bdb0707,0x9f47c070,0x6e29825d,0xa5bb180a}},	//   म्बा, _ganá_, _nleb, lkón,
   {{0x25a06798,0x27e783bc,0x94054028,0xd7c98575}},	// [2840] rbil_, kenn_, रांच_, _रांच,
   {{0x7d1b00fa,0x224d8303,0x7e646a07,0x7d04c032}},	//   äuse, _ajek_, slip, _áise,
   {{0xddcd4080,0x2c0380b2,0xf9864025,0x78704dd1}},	//   qlaş, लाईं_, _мгно, jäve,
   {{0x2005aa08,0x26c785f5,0x7c3e6a09,0x2b170185}},	//   _anli_, duno_, sipr, नहरु_,
   {{0x7649d89d,0x6282c0bf,0x443eea0a,0x637041c0}},	//   dney, _rioo, yit_, _bóní,
   {{0x27e7805e,0xdb01c01f,0x443e4107,0x645ae997}},	//   genn_, calç, _öt_, xoti,
   {{0x9f4caa0b,0xe5c6ea0c,0xddcd4451,0x09b0002a}},	//   _andò_, оспо, lmaš, _কানা,
   {{0x22a7c107,0x22b5c8c7,0xb114c31f,0x6e298062}},	//   dők_, dāk_, змиш, _gleb,
   {{0x27e78141,0x6faa0048,0x212040c9,0x629e4051}},	//   benn_, करां, nyih_, lppo,
   {{0x6448c34b,0x68edaa0d,0x443ec061,0x6e2d46df}},	//   undi, çade, uit_, zhab,
   {{0x26c79849,0x6fcf4045,0x6e2440bc,0x9f5e834d}},	//   cuno_, स्टं, kkib, _votó_,
   {{0x0dc7c6dc,0x95c7d61d,0x261c434d,0xbf168027}},	//   _души_, _душа_, _míos_, तहीन_,
   {{0x51840442,0x261c4019,0xc9840b65,0xe80704fb}},	//   дура, _líos_, дури, शाला_,
   {{0x442a6652,0xc05b00d9,0xddcd6986,0x644aaa0e}},	//   _nlb_, рім_, dmaš, nnfi,
   {{0x6e2d6a0f,0x973c84d6,0x539bc3bd,0xb5fb0107}},	//   thab, _beći, _דיוו, llám,
   {{0x442a6a10,0xe8d9025d,0xb5fb4066,0x682b003a}},	//   _alb_, _agụ_, _cháp, _büdc,
   {{0xfbd311c8,0x6b8dc080,0xacf85a0b,0x26c79351}},	// [2850] _तापम, _şagi, онту_, zuno_,
   {{0x442a4015,0xf3676a11,0xad9b410b,0x201848e5}},	//   _clb_, отен, _inúm, _cori_,
   {{0x161f03ae,0xdb038080,0xbd9880eb,0x7640ea12}},	//   _पवार_, manç, _ịpụt, kimy,
   {{0xfe70801c,0xb5fb20c0,0x3a2dc13b,0x7aed8036}},	//   ندن_, klám, xhep_, łatk,
   {{0x27e7a13d,0x09b0002a,0x69cb97f1,0xd9c2c02a}},	//   tenn_, _কামা, rgge, ্জাম,
   {{0x26c781f4,0x78704041,0x6a65c018,0x6824c0ce}},	//   tuno_, täve, mófi, _bòdm,
   {{0x44ed5d56,0x27e7aa13,0x2009c00c,0x2a669b85}},	//   _hž_, renn_, _đai_, blob_,
   {{0x22a7c107,0x92588025,0x7c2ac35b,0x22b5c8c7}},	//   vők_, _даст_, _alfr, vāk_,
   {{0x443cc070,0x442e80b3,0x6a65c019,0x68ed6375}},	//   _bmv_, bhf_, nófi, nwad,
   {{0x2005802f,0x44ed4011,0x22b5c017,0x98a20036}},	//   _unli_, _mž_, tāk_, czkę_,
   {{0x2ca92a14,0xab65d0f2,0xb5fb0107,0x764b81f4}},	//   _awad_, явол, plál, ongy,
   {{0x60d64051,0xe8038444,0x3cff8011,0x15e2c045}},	//   ytym, लाका_, _kruv_, _कॉपर_,
   {{0x61e9cd14,0x2806c047,0xb5fb04f2,0xdb08801e}},	//   meel, ávní_, clám, _redé,
   {{0xeb970982,0x6a65d0ec,0x317ac093,0x5edac079}},	//   зир_, dófi, _פרסמ, _বছরে,
   {{0x0e6a41b4,0x09b0002a,0xf1d40045,0x260859d6}},	//   مصري_, _কাঠা, _थापन, हाली_,
   {{0x61e9e6d5,0x60d6404c,0x69dbc0b6,0x69cd6a15}},	//   neel, ttym, nfue, ggae,
   {{0x6e245a14,0x6adbd167,0x9f4c8066,0xdb18c0ce}},	// [2860] rkib, _बहुर, _radí_, _advè,
   {{0x261c62de,0xddcd4639,0x201841c8,0x7a260086}},	//   _píos_, rmaš, _qori_, _mótm,
   {{0x141b02a6,0xdcf641df,0x1ee8401c,0xa49b405e}},	//   _הויב, rayı, توای_, _cròb,
   {{0x98a0a796,0x26ca181f,0x224200d9,0xdb0ac3e2}},	//   šič_, mubo_, nikk_, _defè,
   {{0x61f62a16,0x261c41b4,0x442a402f,0xa5bb41c0}},	//   _mayl, _fíor_, _tlb_, _alów,
   {{0x261c4996,0x61f6123b,0x59d18036,0x248daa17}},	//   _tíos_, _layl, _हाथर, _duem_,
   {{0x3f8a425d,0x25ad8093,0xdb0e0e84,0x53348119}},	//   _igbu_, _feel_, fabé, ьект,
   {{0xa3d9c4c7,0x61f62a18,0x11da81b4,0xc1eac11b}},	//   ड्स_, _nayl, _دورة_, ське_,
   {{0xdb01830d,0xe8df400c,0x7c3e2a19,0x7640ea1a}},	//   _velá, _phức_, _ompr, rimy,
   {{0x76b8ea1b,0x6ec0dcfa,0xb033c051,0xe3668156}},	//   олор_, _विदु, еньш, _екзи,
   {{0x29002a1c,0x7522805f,0xdb08c3bb,0xfd0fc1aa}},	//   _aria_, lyoz, dadã, نجی_,
   {{0xdb03c10b,0xae02848b,0x29000053,0xdb0180b0}},	//   _senã, _रोमन_, _bria_, _belæ,
   {{0xe1ff2a1d,0x7e62c284,0x682f8a62,0x26d800c4}},	//   blón_, _ikop, _fødd, etro_,
   {{0x442c80c9,0x717bc0c3,0x201a002c,0x765d260c}},	//   _jld_, _הנדס, _copi_, sosy,
   {{0x61f612f6,0x1dc60048,0x26ca2a1e,0x3fdbc0c3}},	//   _fayl, _वाचत, gubo_, _הקוב,
   {{0x7a2a4166,0x3e720066,0x34dc8444,0x6a65d792}},	//   _pýta, táte_, _यहूद, tófi,
   {{0xc1bc0093,0x683004d3,0x69cd57d2,0x6e2d0c47}},	// [2870] _המחש, _bädd, rgae, _ilab,
   {{0x3e720089,0x7a2a40a0,0x2240c02d,0x61e9c379}},	//   ráte_, _výta, čiky_, zeel,
   {{0x60c466bb,0x68ed5919,0x99898047,0xf8bf0107}},	//   arim, swad, íkům_, pzés_,
   {{0x442caa1f,0xfbdf8185,0x443ea69a,0x6a65d0ec}},	//   _ald_, प्नम, _amt_, pófi,
   {{0x60c453f3,0x443e8080,0xdb0ac018,0x6441c850}},	//   crim, _bmt_, _defé, yili,
   {{0x7e62ea20,0x6286426d,0x443eaa21,0x9f4c81c0}},	//   _akop, _ziko, _cmt_, _badà_,
   {{0x9f45c01e,0x04ff802a,0x764d41c8,0x628e565c}},	//   pelé_, ্নের_, onay, _gubo,
   {{0x9f478166,0xdb074185,0x63ae4158,0x63a4c0b3}},	//   nené_, _její, _zebn, _đina,
   {{0x61f60696,0x9f5e80d2,0x764d41c8,0xe1ff0019}},	//   _rayl, _entà_, inay, tlón_,
   {{0x61e9d664,0x6619c033,0x4b25c11b,0x68300051}},	//   seel, _wowk, дмов, _käde,
   {{0x22420761,0x44ef0064,0x68fbc123,0x69dd0d4d}},	//   tikk_, _aż_, svud, ffse,
   {{0x2bdd43a8,0x9f47805b,0xdb03ea22,0xa96a1349}},	//   न्ता, jené_, _cená, жима_,
   {{0x682b0969,0x68300095,0xb05b091d,0x4425c05c}},	//   _süda, _läde, rrän, pkl_,
   {{0x682f96a9,0x26ca216b,0x3b0a004c,0x4427821b}},	//   _føde, tubo_, оего_, nkn_,
   {{0xab2a059d,0x44ef00f1,0x2bdf915e,0x224dea23}},	//   цова_, _eż_, प्या, onek_,
   {{0x6443aa24,0x4427812d,0x09e35ea7,0x6e2d0017}},	//   hini, hkn_, косн, _glab,
   {{0x2167481e,0x4427821b,0x7e642040,0x62866a25}},	// [2880] дити_, kkn_, _ikip, _viko,
   {{0xf1bf6a26,0x60cb8010,0x2a6940f8,0xdb08ccec}},	//   _lláh_, dugm, alab_, ladá,
   {{0x661b83e2,0x26ca000b,0x7e69ea27,0x3e4840b4}},	//   _bouk, qubo_, klep, eşte_,
   {{0xf987ce40,0x629e00f8,0xd5ed000c,0x9f478047}},	//   _لب_, _itpo, _khá, cené_,
   {{0x63ae4022,0x661b80b6,0x3a269932,0x60cb871c}},	//   _tebn, _douk, rkop_, gugm,
   {{0x68ed810b,0x6609a251,0x798bc40d,0x3f8a4efc}},	//   çada, _enek, _aggw, _ugbu_,
   {{0x628e402f,0xdb834119,0x6f01805e,0x7c2e4157}},	//   _uubo, _агри, _crlc, _ilbr,
   {{0x29026a28,0x44f4ea29,0x61eb8123,0xb5fb2a2a}},	//   _krka_, епис, cegl, zoáb,
   {{0x01639301,0x26c5cbf5,0x1b1bc02a,0x25afc157}},	//   _акто, erlo_, _ফেলে_, _degl_,
   {{0x7e640150,0xdb03c066,0x443e805c,0xdb050066}},	//   _akip, _sená, _umt_, _lehá,
   {{0x9726801c,0xdb1a8580,0x78a28123,0x59f90039}},	//   _تفاو, _ectò, lpov, пеня_,
   {{0x7874c016,0x64a6c039,0x27e100f8,0x60e7c041}},	//   dàve, _жада, _sbhn_, örmå,
   {{0x09d7c02a,0x63be00d2,0x03f1802a,0x69cf0206}},	//   _দোকা, _bdpn, চারী_, rgce,
   {{0x7d048051,0x3e6e802d,0xf99f4053,0xd84880eb}},	//   äisy, kýto_, _enèl_, kọm_,
   {{0x9f47aa2b,0xb5fb0032,0x3e45c017,0xdb0180cb}},	//   tené_, hlái, cēts_, _gelä,
   {{0xf1b98066,0x644e04f1,0xa7fcc06a,0x6616413b}},	//   _koše_, anbi, klık, gjyk,
   {{0x9f478038,0x22844675,0xa3c38c4b,0x682dc032}},	// [2890] rené_, тург, ्लम_, _húda,
   {{0x4427000c,0x47c74079,0xa3d60389,0x7e69c089}},	//   _ôn_, র্নী, _हाय_, zlep,
   {{0x26ccea2c,0xd25144fc,0xb5fd8639,0x27f8402c}},	//   nudo_, _مند_, _akša, _darn_,
   {{0x60cb8f74,0x78705478,0x682dc018,0x7a314383}},	//   tugm, räva, _múda, _båte,
   {{0x44278853,0x3438001c,0x61ed44e7,0x0ef98045}},	//   tkn_, _رسید_, meal, ्म्स_,
   {{0xeb999585,0x27f8451f,0x60cd412c,0x2c054036}},	//   чик_, _garn_, muam, राओं_,
   {{0x999fc166,0x60cd4051,0x661dd368,0x61eb8fb3}},	//   hnuť_, luam, ösko, pegl,
   {{0xae09c045,0x248fc05c,0x442ed2e2,0x3a2943b3}},	//   वाइन_, _pugm_, _alf_, nkap_,
   {{0x7fd5cf37,0x7d02e7b7,0x224dea2d,0x7085d9a2}},	//   ніні, _cros, rnek_, нгиз,
   {{0x6ec0c384,0x699fc191,0xb5fdc60f,0x7e69ea2e}},	//   _विशु, _ग्री, doše, slep,
   {{0xd24ec973,0x60cd6a2f,0xf99f4396,0x9f4ec085}},	//   شنی_, huam, _anèm_, _cafà_,
   {{0xc7b8aa30,0x661d4767,0x3495c748,0xc8690093}},	//   _vođe_, _nosk, _задр, _הן_,
   {{0xad27c7c3,0x7d02ea31,0xdcfbc283,0xb5fdc06f}},	//   _تراو, _gros, bbuġ, goše,
   {{0x26ccc48c,0xb5fb0018,0x61e2c04f,0x316900b6}},	//   budo_, toác, _zbol, _dyaz_,
   {{0x64454057,0x2604c08f,0x5884c10e,0x66e31807}},	//   dihi, वाची_, _рыца, лора,
   {{0xd7df809d,0x62898036,0x61e2c21b,0x201cc0ab}},	//   प्तच, _nieo, _xbol, _zovi_,
   {{0x6f03c066,0x69d6000d,0x64418820,0x7a314854}},	// [28a0] _hrnc, _icye, _omli, _båtb,
   {{0xdb088089,0x7d041b0e,0x6824c0d2,0x64456a32}},	//   _sedí, _iris, _pòdi, gihi,
   {{0xa6865575,0xfeba0c59,0xfbc986d6,0xdb05005f}},	//   _плод, _عادت_, _राजम, _tehá,
   {{0x2bd2808f,0x4a9b0009,0xe3b8806a,0x61ed6a33}},	//   _साहा, _מיטג, _alıp_, ceal,
   {{0xa06a93a8,0x67d49450,0x2bdd6a34,0x7af54107}},	//   пада_, волу, न्हा, _eszt,
   {{0xf1b980b3,0xdb03c3a6,0x3e4cc047,0x661d402d}},	//   _roše_, _genç, měti_, _zosk,
   {{0x799b817b,0x6b8e4031,0x6569875d,0x68324329}},	//   _ffuw, _igbg, _eyeh, _vædd,
   {{0x61fbcaee,0x6441a482,0x29004157,0x30a6d934}},	//   gdul, _emli, ovia_, нров,
   {{0xd7fac846,0xe805408f,0x2bd4c48b,0x7d040303}},	//   пун_, राचा_, _दादा, _nris,
   {{0x61ed6a35,0x26c7a1ad,0x2c86802e,0x69d60f2d}},	//   zeal, brno_, _dídì_, _acye,
   {{0x3a75217f,0x3169005c,0x63b52a36,0x61e4017a}},	//   клор, _syaz_, vazn, _bbil,
   {{0xf1b980ab,0x64456a37,0xadf4cb35,0x201eaa38}},	//   _toše_, zihi, _आसिन_, _hoti_,
   {{0xdca3c11b,0x201eaa39,0xdb0e430d,0x28f8c051}},	//   _бачи, _koti_, _debé, _цель_,
   {{0xf9f10079,0x63adea3a,0x442ec4a0,0xa49b429a}},	//   টাইল_, _đang, _ulf_, _bròn,
   {{0xb5fdc810,0x69c0aa3b,0xa49b4345,0x09b00079}},	//   soše, _odme, _cròn, _কারা,
   {{0xddcf90ce,0xdb0e4396,0x28d19088,0x798d02c0}},	//   _žeže, _gebé, _समलि, _ugaw,
   {{0x7e628c39,0x3a296a3c,0x9f58413b,0xb5fdc011}},	// [28b0] doop, rkap_, _farë_, lošc,
   {{0xc058493d,0x61fd106f,0x38784053,0xd37b4c21}},	//   ніх_, ldsl, _chrr_, пче_,
   {{0x53350651,0x249f864b,0x61ed6a3d,0x8f3500b4}},	//   _рент, _stum_, peal, _ренц,
   {{0x68eda456,0x64456a3e,0xb6ba00c3,0x787200b0}},	//   çado, sihi, _קצרי, nævn,
   {{0xdb07446a,0xfd664044,0x6830009d,0x61fd0820}},	//   _dejá, _mkpị, _häda, idsl,
   {{0x7642e49d,0xa5bb6a3f,0x290480ab,0xb05b04c9}},	//   _amoy, _glór, _drma_, dräk,
   {{0xa3d28045,0xb3d2808f,0x4255c47f,0x201e9049}},	//   _वार_, _सारख, ктит, _doti_,
   {{0x7e6d405f,0x60dd2a40,0x7e918017,0x61fd0065}},	//   nlap, ktsm, _jāpi, jdsl,
   {{0x09e0c079,0x3ea0c0e0,0x60dbc04c,0x3ce9004d}},	//   _মোহা, _čita_, utum, _npav_,
   {{0x601ec047,0x64418b4d,0x7a47c88b,0x61fbaa41}},	//   _námě, _umli, _bètè, _haul,
   {{0xe6c781b4,0xb5fb4031,0x80d1809d,0x26dc980a}},	//   _ستاي, _akám, _समुं, ctvo_,
   {{0x60dd230c,0x9f478166,0x25a94089,0x8be6802a}},	//   ftsm, není_, jbal_, _গোপন_,
   {{0x628ed02c,0x7e6d6a42,0x9f5e8051,0x54e5c17e}},	//   íbor, dlap, _entä_, _कहिए_,
   {{0xb5fdc0b3,0xa0a310a1,0x6f03c123,0x7d0427a7}},	//   bošc, рард, _trnc, _vris,
   {{0x7e62817b,0x60dd0572,0xeb97092e,0x1f590fd4}},	//   yoop, atsm, тис_, ешть_,
   {{0xcfca8079,0xdb03c04c,0x61fbaa43,0xa7fc806a}},	//   ল্পন, _venä, _naul, _akıl,
   {{0x60c9ea44,0x628bea45,0x442a0056,0x6e3d00fd}},	// [28c0] nrem, _migo, pkb_, ërbe,
   {{0x60c9c669,0xddc2813f,0x656f8066,0xdb051da9}},	//   irem, dloš, _úchy, _behä,
   {{0x16004045,0x6fd705da,0x3daa4025,0xcb0a4032}},	//   _लोअर_, _बातू, _окно_, بيان_,
   {{0xfb1ac009,0x64a690d0,0xfc3f0019,0x60c9006f}},	//   וועמ, вада, mpía_, šeme,
   {{0x9986c41b,0x34d184fb,0xfc3f0004,0x78bbd1ae}},	//   _ološ_, _समृद, lpía_, jsuv,
   {{0xf99f4231,0xfc3f030d,0x07ba4032,0x81d6c02a}},	//   _anèh_, opía_, _زهرة_, াড়া_,
   {{0x7a23454a,0x60c9c240,0xdb0500fa,0x7c2a8086}},	//   _tõtt, erem, _gehä, rkfr,
   {{0xdcfd0bde,0x5186e112,0x60c9ea46,0xc986dd10}},	//   zası, купа, frem, купи,
   {{0x8e55811b,0xd91084e8,0xb5fb0018,0xad9b0070}},	//   _стрі, _دیش_, ilát, ndúe,
   {{0xe9df0032,0x7e6d6a47,0x61e29cf4,0xf99f4303}},	//   giún_, zlap, lfol, _enèh_,
   {{0xa3d6054a,0xdcfd00b5,0x7d0281dc,0xf1b9c017}},	//   हलन_, vası, lvos, ekšu_,
   {{0x644705dc,0x8143c1aa,0xd36f85a7,0x7642c339}},	//   wiji, اپیم, _بهم_, _umoy,
   {{0x9f58434d,0xecc700c5,0xdb150e79,0x61fd1400}},	//   _daré_, ъщно, mazé, rdsl,
   {{0xf1b98077,0x61ef1e71,0x63b88240,0x68302a48}},	//   _moša_, secl, navn, _päda,
   {{0x9f584016,0x8ccc8045,0xf487c01c,0x35d8809d}},	//   _faré_, _समझो, _شاهی, _डाढ़,
   {{0x660d2a49,0x64472a4a,0x27fcc7a4,0x63b887a4}},	//   _unak, siji, _havn_, havn,
   {{0x3d0d4064,0xd7d2809d,0xb5fdc03f,0x44316a4b}},	// [28d0] समें_, _सांच, noša, _plz_,
   {{0x26decb6f,0xb5fd8011,0x6e20812c,0x628a4157}},	//   otto_, _ekšl, _aomb, _èfon,
   {{0xe0df00c4,0xa3c447db,0x99804013,0xd6db4d4c}},	//   ltò_, _एयर_, rkiš_, ьта_,
   {{0x26d100c2,0x628d2a4c,0x61e28240,0xb5fdc017}},	//   muzo_, _jiao, gfol, koša,
   {{0xb5fb005f,0x22494545,0x9f478166,0xe7f3c048}},	//   llás, miak_, rení_, _असला_,
   {{0x44330033,0x628bc06a,0xdb08a09c,0x9f478347}},	//   _jlx_, _sigo, _sedá, sení_,
   {{0x9f478d04,0x81b90079,0x3cef82f6,0xaa45cba0}},	//   pení_, _চান_, _इनके_, лекл,
   {{0x6e20aa4d,0x998fc038,0xa3e30474,0xc1b9c1b4}},	//   _gomb, ťaže_, फ्त_, رابط_,
   {{0x26dec5f5,0x2906c004,0x7e6995d9,0x23d30048}},	//   etto_, _croa_, _ikep, _तांद,
   {{0x6fd8c08f,0x44212a4e,0x35b98374,0xa3ba9001}},	//   _माणू, _noh_, _उजड़, _अजय_,
   {{0x9f585aff,0x78a2ea4f,0x628bc0b6,0x0686043e}},	//   _paré_, _etov, _tigo, лгон,
   {{0xfbdf808f,0x629a005b,0x23df814a,0x21294853}},	//   प्रम, ítom, प्रद, kyah_,
   {{0x656bc05c,0x44212a50,0x656d000d,0xb4c0008f}},	//   _uygh, _boh_, _cyah, ुढे_,
   {{0x656d00f8,0xd040c03a,0x21294853,0x55768009}},	//   _dyah, kumə, dyah_, טערן_,
   {{0xb7b580eb,0x61e2aa51,0xe1ff0070,0x6445005e}},	//   _nọm, yfol, bdó_, _dmhi,
   {{0x44442a52,0xf1b9d361,0x44330060,0x7a314ded}},	//   _wm_, naš_, _elx_, _påta,
   {{0xe09ec0eb,0xb5fb0107,0xfc3f019d,0x7e644070}},	// [28e0] _kọọ_, rlát, mpín_, roip,
   {{0xb5fb0c24,0x5fd28384,0xb8ec4b35,0xf99f43e2}},	//   slát, _साइल, _रट_, _efè_,
   {{0xa5650de9,0xa3d2809d,0xa3ba9001,0xdb070166}},	//   _مدین, वलस_, _अजब_, zajú,
   {{0xb5fb0cec,0xdb088107,0x7c2e2a53,0x7afa0397}},	//   llár, _ülés, lkbr, ættu,
   {{0x627c0036,0x2ca68105,0x2bd4c25c,0x7a2a4086}},	//   _głoś, upod_, _दाला, _nýti,
   {{0x61e286a1,0xf1b9806f,0xe09ec0eb,0x7c2e0b32}},	//   sfol, _voša_, _nọọ_, nkbr,
   {{0xaa66c09f,0xaae68301,0x2ca69a5b,0x68f641f4}},	//   лтик, استو, spod_, lwyd,
   {{0x69c400fd,0xb05b0041,0x7649c070,0x7a260397}},	//   _ndie, psäg, giey, _móts,
   {{0x8fa6a345,0x049ec112,0x7c9ec0eb,0xd83f006c}},	//   _базе, _bọọd_, _bọọl_, ščih_,
   {{0x9f458674,0xdb0e0107,0xdb070166,0x09bf0945}},	//   _caló_, zabá, rajú, ्ल्य,
   {{0x656d28d9,0xf1b9dca5,0xddc44d04,0x7d04404c}},	//   _syah, baš_, zliš, hvis,
   {{0x7d0443ad,0x6676c05f,0xe0df023f,0x2fda0580}},	//   kvis, _صدار, ttò_, _acpg_,
   {{0xc5f3c093,0xd90f0646,0x673ac107,0x10044ad4}},	//   _לדף_, سید_, sztj, रयाश_,
   {{0x961d803f,0xe0df023f,0x2a66804d,0x63a9406f}},	//   _viņi, rtò_, hoob_, _đeno,
   {{0x62980f2e,0xa3e6808f,0x5334000a,0xdb0e0fe5}},	//   _évol, य्य_, берт, tabá,
   {{0x9f478166,0x62828022,0x682b0080,0x26d12a54}},	//   nená_, jmoo, _müdi, ruzo_,
   {{0x644aaa55,0xdb03805b,0x61fd6a56,0x69d7d5a8}},	// [28f0] kifi, daný, _vasl, _यासी,
   {{0x69c40038,0x63baea57,0x290900b3,0x212b0064}},	//   _zdie, natn, _iraa_, mych_,
   {{0xbcfb4171,0x1a65805f,0x64894007,0xf8bf001e}},	//   _ayét, لیسی_, _užim, lsé_,
   {{0x68ed0056,0x7d044070,0x9f478066,0x62828057}},	//   _kpad, bvis, jená_, gmoo,
   {{0x61ff2252,0xf8bf2a58,0xb87b4ad6,0x629a4669}},	//   _maql, nsé_, _osíx, _éton,
   {{0x1aebc079,0xb5fdc0b3,0xfbcc4079,0xf8bf001e}},	//   টিতে_, gošn, র্বত, isé_,
   {{0x75d5c01c,0x64474303,0xc7c48051,0x628f417b}},	//   ليغا, _imji, ссчи, _kico,
   {{0x9f458016,0x248ec0f6,0x81cb002a,0xe09ec112}},	//   _saló_, _aifm_, র্ত_, _sọọ_,
   {{0x61e9aa59,0x6d44c166,0xb5fdc2bc,0x6e22ea5a}},	//   _ibel, _žiar, bošn, _doob,
   {{0x661bc300,0x1c45dc34,0x1309c04c,0xaae781b4}},	//   sjuk, рном, вной_, _مسؤو,
   {{0x78a4129b,0x9f47805b,0x35f5d2b0,0xe8190021}},	//   _stiv, bená_, _впер, दाना_,
   {{0xb87b4004,0x764b85bb,0x645505f5,0x224b2a5b}},	//   _esíx, nigy, enzi, gick_,
   {{0xdb01ea5c,0xae006a5d,0xe8f71da5,0x25adea5e}},	//   taló, _लोगन_, аля_, mbel_,
   {{0x645dcf2e,0x63baea5f,0x2ca94340,0x03a5c119}},	//   ésid, catn, dpad_, _тико,
   {{0x60cd4f6f,0x7ae304d3,0x2a7dc23b,0x6297003c}},	//   eram, _äntl, _khwb_, _cuxo,
   {{0x201163e1,0xaca380eb,0x69c42a60,0x64550150}},	//   _anzi_, _arọn, _udie, anzi,
   {{0x87ba4051,0x3e7c8066,0x7d09aa61,0x68fb80bb}},	// [2900] вует_, níte_, _nres, _nsud,
   {{0x656f6a62,0x3ce06a63,0x7c23c34d,0xda0b8048}},	//   _dych, rtiv_, _jonr, _सोबत_,
   {{0x60cd6a64,0x30754051,0x7d0441f0,0x5fddd543}},	//   aram, сутс, svis, _मानल,
   {{0x0906841a,0x91e693fd,0x7d046a65,0x25adc15d}},	//   ипен, роде, pvis, jbel_,
   {{0xb5fdda2d,0x6e22c1c8,0x9f5806ed,0x6fb681b4}},	//   tošn, _roob, ldrà_, لمشا,
   {{0xf2c68ff8,0xd90d84e8,0x7d09869c,0x69db8019}},	//   асин, عیل_, _dres, _ecue,
   {{0x6e22ea66,0x27fe8ae6,0x9f4580c4,0x9f478574}},	//   _poob, _vatn_, _salò_, tená_,
   {{0xddcd46f0,0x4423423b,0x81e48079,0x25a06a67}},	//   zmaž, _zoj_, _ভোর_, ncil_,
   {{0xdca38299,0x100ac032,0xb4d50036,0x44234046}},	//   _мати, نتدى_, _हमे_, _yoj_,
   {{0x66029256,0x91a6c036,0x212b0066,0x6e240269}},	//   ldok, _ट्रै, vych_, _aoib,
   {{0x3cfe8549,0xeb978af9,0xcfcc4079,0x6600856e}},	//   लिके_, _тих_, র্থন, _kamk,
   {{0x3e720032,0xc986c670,0xf64704f5,0x0586cda3}},	//   náth_, _кули, рхон, _кулм,
   {{0x63bc0786,0xddc28064,0xdce0803f,0xe1ff46ed}},	//   farn, wnoś, _izmē, _raó_,
   {{0x2bddc75b,0x63bac0f6,0xf8bf2a68,0xdb038018}},	//   _माया, qatn, rsé_, canó,
   {{0x87040623,0x645ddea2,0xc7b887ca,0x61ff2a69}},	//   ояте, ésie, _međ_, _taql,
   {{0x6600a0b4,0xbdb50217,0x229c05e5,0x6e242a6a}},	//   _namk, _убиј, _dík_, _goib,
   {{0x7e6d2a6b,0xdb1ac0fd,0x628f6a6c,0x60cd46ed}},	// [2910] _ikap, katë, _vico, uram,
   {{0xa8145148,0x25e30814,0x6298ea6d,0xf99f40b6}},	//   одуш, ट्री_, _kuvo, _anèt_,
   {{0x9f5e80fd,0xf09f400c,0xa7fcc080,0xdb1ac0fd}},	//   _datë_, _trào_, nlıq, datë,
   {{0x44234036,0x6602aa6e,0x67280041,0xdb018066}},	//   _woj_, gdok, ädje, _celý,
   {{0x7e6d0150,0xa3d28048,0x181a049b,0x787dc01e}},	//   _mkap, वलं_, _شریک_, lève,
   {{0x3e7c8d04,0x44e2800c,0xe8df400c,0x73c54032}},	//   víte_, _dư_, _chục_, _ديسم,
   {{0x7afc405c,0x2499421b,0x6283423f,0x6600aa6f}},	//   _gsrt, _husm_, _ènos, _famk,
   {{0x20012a70,0x5f080b0d,0xcf580626,0x764d5eb5}},	//   _lahi_, हित्_, יבות_, niay,
   {{0x25addf9a,0x9f5e83bc,0x752d4e3e,0xa49b4061}},	//   rbel_, _latè_, nyaz, _bròi,
   {{0xb113c112,0x4ee7811b,0x12e7811b,0x78704051}},	//   _kụzi, _відз, _відг, tävi,
   {{0x44258755,0xfeb9c1aa,0xa3d6054a,0xdb03aa71}},	//   _iol_, داخت_, हलस_, ranó,
   {{0xb995c1b4,0x201ec13b,0x78a9ea72,0xdb26801c}},	//   _الإب, ajti_, ppev, _دومی,
   {{0x53dc0814,0x7c2500cb,0xf1dcc4d8,0x61ebc085}},	//   _बादश, _bohr, _यातन, _ibgl,
   {{0x07a30fd9,0xdb0ac851,0x7d1bc046,0xdd990166}},	//   зарн, _befä, mxus, ľňa_,
   {{0x9f95c54a,0x200110db,0xb05b0041,0x7a2ec321}},	//   _müük_, _dahi_, vrät, _bùth,
   {{0x7bc746d9,0x9f5e8053,0xe9da127f,0xdb1ac13b}},	//   _adju, _datè_, _ски_, zatë,
   {{0x25a0576b,0x14c8401c,0x3a248fd7,0xb05b04c9}},	// [2920] rcil_, شهای_, _romp_, trät,
   {{0x44258977,0x44e0aa0b,0xdb1c2a73,0x9f9fc1cb}},	//   _nol_, vò_, narë, _déçu_,
   {{0x5f060c4e,0x764d412d,0x657baa74,0x3a24aa75}},	//   _узна, biay, _azuh, _pomp_,
   {{0xf1b98043,0x7c25002d,0x7afe00f1,0x3e7ac13b}},	//   _ceš_, _zohr, _ispt, këta_,
   {{0xc7b88077,0x6e3bc12c,0xe91898d5,0x5118a532}},	//   _peđ_, dhub, ролі_, ролю_,
   {{0x6c3644fc,0x44e0aa76,0xdb01805f,0x249f401d}},	//   _افسا, rò_, _felü, _éuma_,
   {{0x6600aa77,0x63b8ea78,0x28d801f9,0x81c28079}},	//   _tamk, _revn, भूति, ্ভব_,
   {{0x224dea79,0x3ea76a7a,0x6e3bcfad,0x4425915a}},	//   giek_, ínte_, ghub, _eol_,
   {{0x4425a7a7,0x9f4cc166,0xe8df40d1,0xaa3b41c0}},	//   _fol_, redí_, _thục_, _díẹ̀_,
   {{0xd49180d1,0xa3ca4c4b,0xdb018036,0x7423002a}},	//   _gì_, ोलि_, _celó, _নষ্ট_,
   {{0x2c1ac7f6,0x888182f0,0x2d9e0047,0x7c2500cb}},	//   बाबू_, _تیون, ěten_, _rohr,
   {{0x60c2aa7b,0x3cf94260,0x63be4056,0x224dc881}},	//   osom, _उनले_, hapn, ciek_,
   {{0x6265c1b4,0x629aaa7c,0x66046a7d,0x648940e0}},	//   _بالق, _huto, ddik, _iživ,
   {{0x2348c1aa,0x645888f2,0x9f5e8157,0x2708402e}},	//   _پستی_, nnvi, _patè_, _e̟ni_,
   {{0x68e46a7e,0x25e10275,0x63baaa7f,0x9f5e8031}},	//   etid, _कापी_, _metn, _baté_,
   {{0x4438405e,0x3179c036,0x3a26c206,0x66045b85}},	//   _alr_, ższe_, _joop_, gdik,
   {{0x68e44791,0x6e264303,0xd7c88048,0xaea200eb}},	// [2930] gtid, _dokb, रणाच, _ọptị,
   {{0x44386a80,0xaca4c0eb,0x63be4cff,0x81cb0079}},	//   _clr_, _adịz, gapn, র্শ_,
   {{0xa1954acf,0x25a98019,0xf1b9804f,0xf19558dc}},	//   _манч, ñalo_, _peš_, _минь,
   {{0xdb018107,0xf1c34283,0x27ecaa81,0x49758119}},	//   _velü, _diġà_, _abdn_, олес,
   {{0x290b40b4,0x25bd82cd,0x60c28407,0x22a14026}},	//   _urca_, rawl_, gsom, _dėka_,
   {{0xbcfb4669,0xdb1ac5dc,0x224dc036,0x3e790166}},	//   _exéc, patè, wiek_, kéto_,
   {{0x02a2c044,0xb21b0086,0x44259d80,0x682f8af3}},	//   _blọọ, tmæl, _vol_, _jødi,
   {{0xed15805f,0xa4d5811b,0x629aaa82,0xd7d94444}},	//   _وہاں_, _мобі, _duto, _ढाँच,
   {{0xdb018070,0x54558b24,0xee36c289,0xd83880ce}},	//   _peló, _дват, інь_, _flč_,
   {{0x752f0064,0xb95b41c0,0x99824141,0xdb0180b6}},	//   dycz, _adìk, _dakň_, _delò,
   {{0xbb55801c,0xdb0181ff,0xe3b8002a,0x8699c01d}},	//   _بناب, _veló, _জালব, јтот_,
   {{0x02a2c112,0x7d0dc018,0x7bdac23b,0x7b204242}},	//   _glọọ, _áaso, agtu, _ušuš,
   {{0x63be412d,0xcd2bcdd8,0x3e56003f,0xdb1c01aa}},	//   yapn, _حسان_, nāti_, maré,
   {{0xb05b44d3,0xdb08803c,0xdb0d0066,0x628880c4}},	//   _svän, _redú, _škál, _èdov,
   {{0xa3a9ccbb,0x66044080,0xa3d28048,0x2cadd05f}},	//   गुण_, tdik, _वाघ_, lped_,
   {{0x6d054045,0xee375341,0x41aa424e,0x60c4aa83}},	//   रिंग_, онс_, рван_, šimi,
   {{0xec4a404c,0x9c264457,0xb4e895a8,0x142645bd}},	// [2940] азал_, одад, _बहे_, одам,
   {{0xf772016a,0xb4ea4c4b,0xb5fb4031,0x26d100ab}},	//   _ياد_, _मही_, _ajád, brzo_,
   {{0x9f584018,0x200344c8,0x64800051,0x443a2a84}},	//   _bará_, _daji_, röid, _ilp_,
   {{0x629aaa85,0x38c8808c,0x94aa84b6,0x26d80449}},	//   _ruto, ماتی_, атка_, muro_,
   {{0x4427ea86,0x60c28039,0xdb152a87,0x63be405c}},	//   _oon_, usom, mazá, papn,
   {{0x20036a88,0xbddb02cb,0x60c28e7c,0x02a68f1e}},	//   _gaji_, nièr, rsom, орим,
   {{0x9f586a89,0xd8388f26,0x34b7014a,0xd6d08032}},	//   _fará_, _vlč_, _अब्द, رقة_,
   {{0x69dbea8a,0x69d6014a,0x629c40f8,0x4444805f}},	//   ggue, _भागी, _iuro, _کررہ,
   {{0x25ebea5d,0x80c48028,0x7d09ea8b,0x290d80b4}},	//   _अउरी_, _रिटे, gves, _grea_,
   {{0x63bc46a9,0xdb1c2a8c,0x394202bc,0x27f82a8d}},	//   _jern, parè, dzks_, jern_,
   {{0xd25105dc,0x63bc6a8e,0x68e42a8f,0x6fdd408f}},	//   فند_, _mern, _aqid, _पासू,
   {{0x09b4c079,0x29000033,0x32069b85,0x3c3bc669}},	//   _টাকা, _bsia_, ndoy_, _rêve_,
   {{0xa5bb4018,0x5fba4185,0xb606c2a3,0x78adc066}},	//   _ilóx, इराल, rašć, čový,
   {{0x26c74038,0x752f0064,0x7bdc2a90,0x212bc0fa}},	//   ánok_, rycz, ggru, äche_,
   {{0x43942a91,0x29002a92,0x2bdc27c1,0x0dcb1988}},	//   дарс, _esia_, _बारा, _купи_,
   {{0x20034a98,0x6fdd408f,0x69c0ce83,0xed59e6a9}},	//   _saji_, _पाहू, name, laža_,
   {{0xe04b01aa,0x7d0d15e0,0x629c5f4e,0x7aedcc82}},	// [2950] _نشده_, _uras, _auro, _ćati,
   {{0x26d82a93,0xf1b982bc,0x7a386a94,0x80c4884d}},	//   buro_, _tošk_, _víta, _रिजे,
   {{0xdb08c82f,0x629c4123,0x5695404c,0x60c441c8}},	//   madó, _curo, чает, asim,
   {{0xfad60093,0xdb150018,0x7b6440c5,0xf1b98114}},	//   _צורך_, cazá, фтуе, _koši_,
   {{0xf990871d,0x25bfc0b3,0x20036a95,0xed59c077}},	//   نبه_, vaul_, _taji_, kaža_,
   {{0x35e14b35,0xdb08ea96,0x2be24048,0xb5fdd208}},	//   _फाड़, nadó, _पाया, pošk,
   {{0x61e9ea97,0xa49b4580,0xdb1a80b6,0xdb188089}},	//   tfel, _eròt, _jetè, baví,
   {{0x645aea98,0x63bc427c,0xa3ab8891,0x69dbea99}},	//   enti, _zern, _क्र_, ugue,
   {{0xe8e0c015,0xed598654,0x98b24064,0x9f4cc166}},	//   _đợi_, _beže_, rzyć_, vedá_,
   {{0x69dbc30d,0x6e3baa9a,0x7c3a8070,0x7c28a0c9}},	//   sgue, _hlub, _gltr, _godr,
   {{0xbddb0669,0xdb03c018,0x629c48ca,0xdb1c001e}},	//   vièr, _renó, _xuro, paré,
   {{0x6aaac079,0xc0490093,0x2cadea9b,0x7a3cc107}},	//   _কিশো, _גז_, pped_, _péte,
   {{0x02db86ff,0x69cbc010,0x443ec2d4,0x225f8300}},	//   _यमुन, _idge, bht_, _mjuk_,
   {{0xfbd3c78a,0xdb1a8141,0xc7b88011,0xb05b2a9c}},	//   _آتش_, _betè, _pođi_, ssän,
   {{0x290fc056,0x6e3baa9d,0x638303d5,0x25bdc0f8}},	//   _hrga_, _olub, егра, _kewl_,
   {{0xba2342f1,0x9f4b0107,0x27f82a9e,0xc7b88242}},	//   ндск, áját_, sern_, _vođi_,
   {{0x998942bc,0xb146447f,0x443a2a9f,0x4a5700c3}},	// [2960] tkaš_, чнал, _tlp_, _משקל_,
   {{0xaf9a5086,0x3204856e,0x62960bc9,0xdb1a80fd}},	//   стах_, _samy_, _hiyo, _qetë,
   {{0x6e3b882e,0x99894242,0x69c0eaa0,0x04048079}},	//   _blub, rkaš_, yame, লামী_,
   {{0x629e0105,0x83fcc06f,0x6e298053,0x9f58013b}},	//   _iupo, rođi, _coeb, herë_,
   {{0x62962aa1,0x62840b90,0x225f8077,0x26c50166}},	//   _miyo, _mhio, _djuk_, álov_,
   {{0x645c005e,0x63be00fd,0xd49980d9,0x3ce6a838}},	//   nnri, _jepn, ірі_, rtov_,
   {{0x69c0ce83,0x09c70079,0xf1be0185,0xed59aaa2}},	//   tame, ষ্টা, ्णान, _reže_,
   {{0x645adb2d,0x6e364007,0x629e16a3,0x63be2aa3}},	//   wnti, nkyb, _mupo, _lepn,
   {{0xfe4584e8,0x98a4c007,0x23dc11aa,0xdb08c2d6}},	//   _تکلی, kymą_, _बांद, sadü,
   {{0x81b90079,0x09c5008f,0x2a600dff,0x442a6aa4}},	//   _চাই_, वण्य, _ajib_, _job_,
   {{0x2d802aa5,0xe41ac166,0x833aa4a0,0x645ac838}},	//   _azie_, _kľúč, _учат_, rnti,
   {{0x0e9b8093,0x6d446aa6,0xed59eaa7,0x26f8808f}},	//   _השאל, kzia, saža_, ंबीर_,
   {{0x644e6aa8,0x20059415,0xb87b0152,0x442a4046}},	//   _ombi, _yali_, stím, _oob_,
   {{0xc05b09b1,0x7d02eaa9,0xb7b580eb,0xb5fb4031}},	//   сім_, _isos, _họr, _akáp,
   {{0x9f5a02b0,0xb17b0065,0x7a384032,0x2742c1aa}},	//   _papá_, dgåe, _vítn, _déné_,
   {{0x66066aaa,0x62842aab,0x80cd846d,0x443cc00c}},	//   _cakk, _ghio, _सिले, _hlv_,
   {{0x8d7741b4,0x66064b89,0x629e00f6,0xdb1a850e}},	// [2970] سارا, _dakk, _eupo, _deté,
   {{0x7c2ac060,0xdb1c4053,0x7e6d40cc,0x7a33891a}},	//   _jofr, _kerè, soap, _içti,
   {{0x02a412b0,0xa3c28945,0xf7734d72,0xbddb03bc}},	//   _прям, ्णन_, راط_, chèc,
   {{0x7bc1dff2,0xddcd6aac,0x66066aad,0x9f5e80d2}},	//   zalu, blaš, _gakk, _catí_,
   {{0x2bddc5a3,0xe534811b,0x7bc1eaae,0xc7b886f0}},	//   _माला, нець, yalu, _lođu_,
   {{0xddc44158,0x7c2ac966,0x7a3853ab,0x320945d1}},	//   moiš, _nofr, _lítl, lday_,
   {{0x2007aaaf,0x7d0d6ab0,0x26da40c4,0x25a9002c}},	//   rdni_, lvas, cupo_, _ofal_,
   {{0x7bc1d63e,0x32094db2,0x443cc051,0xfbe3002a}},	//   walu, nday_, _alv_, য়িত,
   {{0x51878176,0x7d0d59af,0x58d4a65d,0x4c85c640}},	//   _хува, nvas, _потт, млив,
   {{0x60c98013,0x69cd002c,0xdb1c4053,0x5ac9ddf6}},	//   _ivem, _adae, _berè, олом_,
   {{0x60c48039,0x7d0d4c99,0x62962ab1,0x6d446ab2}},	//   šimt, hvas, _piyo, zzia,
   {{0x7ec2cb01,0xdb01aab3,0x290fc11a,0xa5bb0086}},	//   _sípá, _belö, _trga_, sjón,
   {{0x66066ab4,0x69cd01f4,0xd012005f,0xec6ec2f1}},	//   _rakk, _ddae, پلز_, _ап_,
   {{0xddcd6ab5,0x7c2ac1f4,0x7bc7c10d,0x3c340051}},	//   vlaš, _gofr, ðjud, _kävi_,
   {{0x224041aa,0x81e64079,0x224fc033,0xdb1c6ab6}},	//   thik_, _যোগ_, _kmgk_, _verë,
   {{0x799baab7,0xb5fb0018,0x7a384f02,0xb904002a}},	//   _nguw, gnád, _víto, _নন_,
   {{0xdb0180fa,0x2baf0578,0x224040b3,0x7d0d557b}},	// [2980] _gelö, _ज्वा, rhik_, gvas,
   {{0x7d042ab8,0x261c008f,0x7bc3aab9,0x2ca0010b}},	//   _isis, यावी_, janu, _iuid_,
   {{0x141b0009,0x2ca001d4,0x7bc3aaba,0x63870669}},	//   _וויב, _huid_, danu, réné,
   {{0x32096505,0xb8e44079,0x26da6abb,0x2007eabc}},	//   cday_, _এম_, rupo_, _lani_,
   {{0x290246f0,0x81d40079,0xdb1c0018,0x8c4680c5}},	//   _uska_, স্থ_, iarí, меде,
   {{0x69c46022,0x7d04012c,0xdb1c0019,0x645dc01e}},	//   laie, _msis, harí, ésil,
   {{0x38a454a6,0x3e56003f,0x8c3b40fa,0x26cac1b7}},	//   _hör_, nāts_, _fußb, ġbok_,
   {{0x26069c79,0xe81c4021,0x2007e5bc,0x68e9dcd3}},	//   _सोची_, नावा_, _aani_, fted,
   {{0xab5cc03f,0x7d094018,0x6ad34079,0xb6068077}},	//   daļa, _áest, _সহযো, _vešć,
   {{0xdfd0c54c,0x69c45437,0x7bc390c7,0xfbde809c}},	//   ديد_, haie, canu, _øª_,
   {{0xbbd74087,0x9986c066,0xda6fc3d0,0x61ed4a1f}},	//   וויץ_, _ulož_, _ая_, yfal,
   {{0x201a0c98,0x290480f8,0xb05b07c1,0x2ca0005e}},	//   _anpi_, _ksma_, rsäm, _buid_,
   {{0x0936cd72,0x2007eabd,0x443e802f,0xad9b0032}},	//   _تراج, _fani_, _klt_, ndúi,
   {{0x2056c11b,0x260f058e,0xed598011,0xdb1e0396}},	//   _ютер, _तोरी_, _ježa_, _kepè,
   {{0xdb1c04f2,0x443e8aef,0x25a901b7,0x261c0048}},	//   barí, _mlt_, _tfal_, याशी_,
   {{0x2498424f,0xbddb6abe,0x2007eabf,0xea9f002e}},	//   _airm_, _amèr, _zani_, _aiṣe_,
   {{0xe80f0028,0x682f8240,0xb5fdc123,0x5c752159}},	// [2990] ायदा_, _mødr, mošt, _плит,
   {{0x38a44041,0x32096ac0,0xdb0880cb,0x44382ac1}},	//   _dör_, sday_, _bedü, ckr_,
   {{0x64894e09,0x7d0d48a1,0xc108c00c,0x7d00c046}},	//   _džip, svas, _lỗ_, hwms,
   {{0x78a0800d,0x26dc8070,0xfa8a00d1,0x6f050e05}},	//   _bumv, duvo_, _bẫy_, _ishc,
   {{0x443ea9f3,0x78a080b4,0xc108c00c,0x249840c3}},	//   _blt_, _cumv, _nỗ_, _firm_,
   {{0xdb1c02b0,0x25b295e7,0x6fddc045,0x6e2d0019}},	//   zarí, ıyla_, _माइं, _loab,
   {{0x61fbeac2,0x7a3cc534,0x45d5809b,0xb5fdc123}},	//   teul, _séta, _повс, košt,
   {{0x60dbeac3,0xdb1e0016,0x7a3ceac4,0x7bc3aac5}},	//   tuum, _depè, _péta, sanu,
   {{0x2007eac6,0xdb18817c,0xa3e78027,0x2d588051}},	//   _pani_, ravá, _भाप_, _жить_,
   {{0x518487bc,0x26dc8039,0xed59c420,0xe3b1c1b4}},	//   _руса, buvo_, sažo_, درة_,
   {{0x25e10342,0x2ca0150e,0x644384f8,0x7a35d1fc}},	//   _काशी_, _suid_, mhni, _láti,
   {{0x78a0800d,0x7bc56ac7,0xb5fdeac8,0x69c0aac9}},	//   _yumv, hahu, tošu, _xeme,
   {{0xdb1e00da,0xdb1c28fa,0x98e5c1b4,0xc108c015}},	//   _tepë, rarí, _أكتو, _gỗ_,
   {{0x7bc19d2e,0x69cf6aca,0x443e0107,0x6609809d}},	//   _jelu, _adce, ót_, _laek,
   {{0x6299eacb,0x5e964032,0x99804007,0xdb1c2acc}},	//   _kiwo, فلسط, ykių_, parí,
   {{0xc323010e,0x60d66acd,0x6609807a,0x661b8efc}},	//   ымск, trym, _naek, _nnuk,
   {{0xd943535b,0xed5a0b2c,0x7e640044,0x60c9d9c4}},	// [29a0] гети, _хоп_, _ijip, nsem,
   {{0x1aff0079,0x69c46ace,0x7a35c019,0x6cd34032}},	//   _উপরে_, saie, _dáti, اقلا,
   {{0x2d9dc044,0x38b64031,0x7a35c359,0xe29a4039}},	//   _ogwe_, _bùrò_, _táth, чае_,
   {{0x66768646,0xdb1ace79,0x9fb8002a,0x443e87b0}},	//   ردار, natá, _জায়গ, _slt_,
   {{0xe61f400c,0xdb18c934,0x2610eacf,0x69c0813b}},	//   _khôn_, _reví, _दोषी_, _veme,
   {{0x7bc56ad0,0x7bce4065,0x64438e94,0x66ea803a}},	//   cahu, _udbu, ghni, _həki,
   {{0x316c0064,0x443e8136,0xcb674aec,0x3e758d27}},	//   ędzy_, _vlt_, _заре_, tått_,
   {{0x3f7b4052,0x6443aad1,0xb21b00b0,0x7c2e6ad2}},	//   _זאלס, ahni, mlæg, _hobr,
   {{0xed598618,0x442caad3,0xb21b00b0,0x64551e5c}},	//   _teža_, _tod_, llæg, yizi,
   {{0xb80680fb,0x7656403a,0x61e2aad4,0x7338cce0}},	//   _سکتے_, hiyy, lgol, дзор_,
   {{0xe8168374,0x44446ad5,0xb05b2a9c,0xe1ff0032}},	//   _धोया_, ih_, ssäk, nnóg_,
   {{0xdb1aead6,0xe508c082,0x60dd0c99,0x69c62ad7}},	//   gatá, _tỷ_, tusm, gake,
   {{0xdb056434,0x7bc560a3,0x3ea10c99,0x7e640053}},	//   rché, yahu, _suht_, _djip,
   {{0xdb05529a,0xe61f40d1,0x61fd0080,0x22402ad8}},	//   sché, _chôn_, sesl, _elik_,
   {{0xddc44036,0x60dd009d,0x442eead9,0x61e28049}},	//   bliż, susm, _iof_, kgol,
   {{0xb21b0065,0xb8f70079,0x6b9e0018,0x9f478066}},	//   dlæg, _সহ_, _egpg, jený_,
   {{0xb87b0c5a,0x68300041,0x61e2aada,0x3a2d87f5}},	// [29b0] tuíd, _vädr, dgol, _roep_,
   {{0x78a2c623,0x61e66adb,0xdb1c06ed,0x3a2d815d}},	//   _muov, _eckl, barà, _soep_,
   {{0x200a6adc,0x7bc19bd4,0x78a2c051,0x6fe26add}},	//   _dabi_, _relu, _luov, _पारं,
   {{0x2906c232,0x7a35c01f,0x44e9aade,0xdb1c001f}},	//   _osoa_, _táti, tú_, sarã,
   {{0x518453ae,0xd009986f,0xbddb46ed,0xdb1a8018}},	//   _бура, деле_, _elèc, _detí,
   {{0xbddb5ad0,0x8d748c59,0x660d6adf,0x7bc72ae0}},	//   _flèc, داما, ldak, naju,
   {{0x2fc5d27d,0x48bdc079,0x69c62897,0x3a2d82a4}},	//   valg_, _আমের, yake, _toep_,
   {{0x200a4360,0x29020064,0xb8034079,0x7bc1aae1}},	//   _zabi_, ywka_, _উচিত_, _welu,
   {{0x98f48684,0x60c9c669,0x2906c018,0xf1b9c06c}},	//   _مثلا, usem, _csoa_, njši_,
   {{0x5d5485e4,0x200a6ae2,0xddcd4036,0x39a7c031}},	//   _скут, _xabi_, niał, _bísó_,
   {{0xb21b080d,0x6a7602b0,0x60cd2ae3,0x366a07dc}},	//   klæd, dáfr, _avam, дано_,
   {{0x2fc5d6a9,0x6289805c,0xbbd1aae4,0x60c9c09d}},	//   salg_, _jheo, _सयुक, psem,
   {{0x7e6940ab,0x6e3bc23c,0xa509eae5,0xa3dd0048}},	//   čepl, mkub, _цела_, डलं_,
   {{0x9f478531,0x661d6ae6,0xa879c009,0x28d30e95}},	//   zený_, _ansk, _קאַר, _तिरि,
   {{0x60cd2ae7,0x2056c009,0xbad500d7,0x629c81cb}},	//   _evam, _ביסל_, літы, _érot,
   {{0x6e3beae8,0xf2d28009,0x6e29e97a,0x244d02bc}},	//   nkub, יעל_, njeb, džmu_,
   {{0x9f47805b,0x03a646dc,0x76566ae9,0x7bc3d2cf}},	// [29c0] vený_, визо, riyy, _kenu,
   {{0x76446aea,0x44446aeb,0x14d4c08f,0x1c1c409d}},	//   shiy, uh_, _दिसण, नाइल_,
   {{0x69c40127,0x6e3beaec,0x62899335,0xb87b0018}},	//   _keie, kkub, _bheo, buíb,
   {{0xdb1c0319,0x7d162aed,0xed5a804c,0x78a4117f}},	//   cará, _krys, мое_, _kuiv,
   {{0x6aa3c46a,0xd83887ca,0x62658a1d,0x7d094018}},	//   _lunf, _liče_, دالق, _áesp,
   {{0xddcd4064,0xa3e94027,0x2d80c1b7,0x9f5c801e}},	//   ciał, _याय_, _ġie_, levé_,
   {{0x9f47aaee,0x661d44f5,0x7d046aef,0x6aa3c0e2}},	//   denó_, _ynsk, lwis, _nunf,
   {{0x2619c9b4,0xdb18c05b,0xfe6fc54c,0xb17b0041}},	//   भागी_, _nevá, يدي_, dgån,
   {{0x2ca64f35,0xf65343d4,0x57ea801d,0x660beaf0}},	//   íodh_, יצה_, _одам_, _dagk,
   {{0x660d6af1,0x6a789138,0x8af6c080,0x683480d2}},	//   zdak, rífu, _çəkd, _pàdu,
   {{0x200cc1f4,0x7d160b5e,0xc0154009,0xdb0ad871}},	//   rddi_, _arys, אַרק_, _refó,
   {{0x25a005f5,0x7bc7132b,0xdb1c003c,0x320dc1c8}},	//   _cgil_, waju, xará, cdey_,
   {{0x69c42af2,0x442eeaf3,0x78a42af4,0x9f5c8016}},	//   _deie, _tof_, _cuiv, devé_,
   {{0xd7f80e97,0x7d1620c6,0x7bc3eaf5,0xdb0ac0b6}},	//   кус_, _drys, _genu, _defò,
   {{0xf1bf8066,0x9f530004,0x67388107,0x6a760018}},	//   áška_, _raxó_, nyvj, ráfr,
   {{0x61e46af6,0x533408af,0x64588795,0x20d28742}},	//   ggil, шест, hivi, _सिंध,
   {{0x22591060,0x645764d5,0x660d50db,0xb21b0065}},	// [29d0] misk_, tixi, rdak, smæs,
   {{0x7bc8c933,0x201e812d,0x22591bcd,0x5fb71e85}},	//   nadu, _nnti_, lisk_, _अभिल,
   {{0xb87b4018,0x78a4015d,0xed59806f,0xbdb08112}},	//   _mpíx, _zuiv, _pežo_, _ịnọr,
   {{0x7bc8eaf7,0x645741c8,0xdb01c03c,0x201e9d80}},	//   hadu, sixi, nclá, _anti_,
   {{0xb87b04b3,0xdb1c5eab,0x7a35c086,0x947991b0}},	//   btít, _cerâ, _mátt, нску_,
   {{0x200c98da,0x2fc78022,0xab5cc017,0x29090321}},	//   _cadi_, uang_, taļl, _msaa_,
   {{0xb87b0016,0x7bc8eaf8,0x225904cf,0xed59c3aa}},	//   ltís, dadu, kisk_, maži_,
   {{0x2246821b,0x2909004c,0xd83882bc,0xe9df4004}},	//   chok_, _osaa_, _riče_, _flúe_,
   {{0x6e3beaf9,0x443143e2,0x200c8067,0xd8400066}},	//   rkub, _koz_, _fadi_, áčky_,
   {{0x6e29eafa,0x201e8033,0x78a4010b,0x200141aa}},	//   sjeb, _gnti_, _ruiv, nehi_,
   {{0x660be9a9,0x29090094,0x7d046afb,0xb5fb41c0}},	//   _tagk, _asaa_, zwis, _ajám,
   {{0xd83880ab,0x2fc58383,0x7d044036,0x7659802c}},	//   _viče_, _helg_, ywis, niwy,
   {{0x5156023d,0x69c42afc,0x61e9aafd,0x200c87f0}},	//   утну, _veie, _mcel, _yadi_,
   {{0x7bc8d849,0x25adc3e9,0x2a79405c,0x60cd6afe}},	//   cadu, lcel_, _aksb_, dsam,
   {{0x629d4e83,0xbb430651,0x660d0573,0x61e443ad}},	//   _biso, берк, _faak, tgil,
   {{0xdb18d8ac,0x7d044fd7,0x6e3d1b1d,0x96950ce8}},	//   _bevæ, twis, cksb, _крыш,
   {{0x765981f4,0xb5fb0019,0x629d6aff,0x45865948}},	// [29e0] diwy, onán, _diso, угав,
   {{0xc0061a39,0x629ec6ed,0x1615c834,0x5f7601aa}},	//   _спок, _èpoc, _दोसर_, _ماجر,
   {{0xdb1c6b00,0x91a92b01,0x28c681e7,0xb0c68064}},	//   _terí, _hoá_, रीनि, रीनग,
   {{0x7bc8eb02,0x9f582772,0xb87b0066,0x44228107}},	//   zadu, merà_, stít, _ők_,
   {{0x2fc59f26,0x9f5ec0fd,0x6fe24045,0x764402c0}},	//   _belg_, tetë_, _पाऊं, _mliy,
   {{0x80d72b03,0x6d484080,0x07ba4032,0xe8948589}},	//   _बिसे, _ədal, _سهرة_, шаль,
   {{0x7bc8eb04,0xd5e2c044,0x7d09800b,0x7ae1eb05}},	//   vadu, _nhọ, _eses, jult,
   {{0xdb1a819d,0x60dbeb06,0xb5fb41c0,0x2be08575}},	//   _cetá, frum, _ajáj, _नाका,
   {{0x216781bd,0x896687ea,0x9f5805f5,0xc486a9d7}},	//   _бити_, _скаж, herà_, _блак,
   {{0xe45f04d3,0x7a35c5e7,0x2619c08f,0x7c3e5013}},	//   rsök_, _sátt, _मोठी_, nkpr,
   {{0x3ea5864b,0x450a402a,0xb7db4052,0xdb1c4060}},	//   _gult_, রমিক_, עקטי, _jerà,
   {{0x60dbc085,0xd6d7c051,0x6ce70589,0x65620451}},	//   brum, ыть_, ліге, _žoha,
   {{0xb4c1008f,0xade6009d,0xd24fc1b4,0xe3afc1aa}},	//   ुळे_, _कारन_, _عنه_, غری_,
   {{0x25e112c2,0x2a79405c,0x629d6b07,0x3cf7854a}},	//   _काकी_, _sksb_, _siso, _एहसे_,
   {{0x3317c4cc,0xb87b02b0,0x213900fd,0x44316b08}},	//   _مزيد_, guía, sysh_, _roz_,
   {{0x7e644c05,0x7a35c107,0x3166006f,0x7bcaab09}},	//   gnip, _hátr, _žoze_, hafu,
   {{0xb9995df8,0x200ed6e6,0xad9b4004,0x26c1805f}},	// [29f0] твах_, _kafi_, _naút, ához_,
   {{0xb05b04d3,0x3dc6c05c,0x200ee44f,0x68e28007}},	//   gsät, _leow_, _jafi_, duod,
   {{0xdb0e40fa,0x61e98cfe,0x2be88b35,0x629f03bb}},	//   _gebü, _pcel, च्छू_, _épos,
   {{0x3915a8ab,0x44316b0a,0x200ec09c,0xf1bf0107}},	//   имер, _woz_, _lafi_, dják_,
   {{0x9f580070,0xfc3f4032,0x61e98089,0xb5fdc011}},	//   merá_, _dtír_, _vcel, jnša,
   {{0xdb18c04c,0x645540f7,0xee3f0066,0x1be90185}},	//   _kevä, _umzi, hký_, ञ्चल_,
   {{0xaa95811b,0xf625c09b,0x6a7882e3,0x6d4d40a8}},	//   _вивч, идко, rífr, lzaa,
   {{0xd1bb84e8,0xa2a2505d,0x61e991b4,0x7bc7400d}},	//   _سارا_, गदर्, _ucel, _heju,
   {{0x87e78446,0xdb1c401d,0x6d4d6b0b,0x2d99eb0c}},	//   _مثال, _terã, nzaa, äse_,
   {{0x28dc0e95,0xe29f4086,0x25adc912,0x2a7feb0d}},	//   _बिबि, _lið_, scel_, slub_,
   {{0xf62603bf,0x9e660698,0x20030347,0x60dbeb0e}},	//   адно, ивод, deji_, srum,
   {{0x443ec1d4,0x9f5805f5,0x7ae1d0b1,0x6fba07f6}},	//   akt_, verà_, rult, ्रभू,
   {{0x64894570,0xe82216ca,0x32020066,0x7ae38e6e}},	//   _džiz, माला_, reky_, lunt,
   {{0xafe2c0c1,0x2619cb05,0x5d84c032,0x6d4d415d}},	//   _дошл, _मोती_, _الهل, dzaa,
   {{0xb779c81b,0x4b79c009,0x366a1025,0x7e566159}},	//   _באַש, _באַו, _иако_, атац,
   {{0xb33c8283,0xfe434770,0x7649c498,0x7a3cc396}},	//   _jgħa, онсо, nhey, _céth,
   {{0x753bc00d,0x7bca9451,0x47c66549,0x9f58102f}},	// [2a00] nyuz, yafu, ибав, serà_,
   {{0x28ddce1a,0x2fc7e5be,0xf1bf400c,0xb05b4041}},	//   _मिनि, _jeng_, _soát_, _svär,
   {{0x2fc7eb0f,0xdb050065,0xaf06572b,0x0ef48048}},	//   _meng_, _afhæ, рпел, _आहेस_,
   {{0xdb1c4319,0x3ea7eb10,0x6448c0da,0x22496b11}},	//   _cerá, _munt_, zhdi, chak_,
   {{0x7e6dc0b3,0x0594401c,0xa3b5c49d,0x61f64086}},	//   čapl, _دادگ, जडा_, mfyl,
   {{0x2c1c4064,0x38ab836b,0x7e7b80f7,0xe7ead09f}},	//   नाओं_, _dør_, _ekup, ज्ञा_,
   {{0x7bcaab12,0x200ec0e2,0xaa58cbf8,0x23274d00}},	//   rafu, _rafi_, лику_, _кори_,
   {{0x60c2c3bc,0xb5fb0443,0x8cd70021,0x2fc7c396}},	//   _pwom, gnál, _बिलो, _aeng_,
   {{0x5186c12b,0x3ead40b3,0x7a35e6b8,0x673c00fd}},	//   шука, _četi_, _pátr, hyrj,
   {{0x7afe011b,0x443ec017,0x2fc7eb13,0xb5fb0032}},	//   _oppt, ukt_, _ceng_, anál,
   {{0xe8df400c,0x66044c38,0xb87b0070,0x3e720089}},	//   _tiệc_, keik, nríe, láty_,
   {{0x62518038,0x6448eb14,0xdb1c4004,0x2ca6db85}},	//   sťov, shdi, _xerá, _tuod_,
   {{0x200ec067,0x6445023b,0x9989006f,0x2246eb15}},	//   _tafi_, _plhi, _boaš_, _ilok_,
   {{0x5fe24b08,0x68e46b16,0xdb1e4016,0xcc89001c}},	//   _पागल, duid, capç, انسه_,
   {{0x629f0033,0x7bc74cc6,0x660f6b17,0xdb1e4f4c}},	//   _tiqo, _reju, _pack, napä,
   {{0xb87b0016,0x92b3c6b0,0x29196b18,0x9f5c8047}},	//   dríe, _بحوا, _prsa_, jeví_,
   {{0xf1bf1c15,0x20030bc2,0x95c8437b,0x6e2d6a69}},	// [2a10] mbá_, peji_, руса_, rjab,
   {{0x7ae380e1,0x62884016,0x98a2c007,0x6aa0805e}},	//   yunt, ïdor, škė_, _aimf,
   {{0x753d005f,0x92594f93,0xb05b16df,0x6d4d5ae9}},	//   lysz, _бант_, ssäs, szaa,
   {{0xf1ab401c,0x7a3cc5f6,0xf1c44089,0xbddb4141}},	//   _جاده_, _féti, ruší_, _klèm,
   {{0x753d0107,0x2fccc21b,0xe450005f,0xe3e9478a}},	//   nysz, kadg_, _رضی_, _مکان_,
   {{0x81ad002a,0xdb1e1b10,0x7bc8ab19,0xaca480eb}},	//   গরি_, _hepá, _cedu, chọr,
   {{0x53af0027,0x4cb0002a,0x9f5840d2,0x547a0052}},	//   जुएश, জীপু, _daró_, נְננ,
   {{0x7d0d0d87,0x394dc0fa,0x81cc0079,0x3e720066}},	//   _osas, tzes_, _লাভ_, báty_,
   {{0x645c2b1a,0x765d2b1b,0x7bc880c9,0x98a3c039}},	//   yiri, disy, _fedu, ąjį_,
   {{0x60cd80b3,0x7d1bab1c,0xdb1a9da9,0xddcd404f}},	//   šams, _irus, _betä, jlaž,
   {{0x4426000c,0x320fc066,0x7d1bab1d,0x765d03e2}},	//   _đo_, _tagy_, _hrus, fisy,
   {{0x645c2b1e,0xdb15034d,0xdb1e2b1f,0x3204c036}},	//   wiri, hazó, _nepá, cemy_,
   {{0x8e74c1b4,0xed59879b,0x753d005f,0x7d1b8018}},	//   _بالض, _beži_, gysz, _jrus,
   {{0x711ac093,0x261803b0,0xac0a06e0,0x628f4085}},	//   _תוספ, _बोरी_, ынга_, _ahco,
   {{0x61fbab20,0x6282ab21,0x7c23cfa0,0xbb430acf}},	//   _obul, yloo, _innr, перк,
   {{0xf8a581aa,0xb87b001f,0x442340b6,0x628f6b22}},	//   _يک_, quín, _anj_, _chco,
   {{0x66062b23,0x61f66b24,0xddcd4013,0x925a0de9}},	// [2a20] mekk, rfyl, blaž, _لشکر_,
   {{0x09d0808f,0x232a400e,0x32120034,0xa3be05da}},	//   हण्य, лози_, _hayy_, आरओ_,
   {{0x1fb542ae,0x7bce237e,0x2d80803f,0xa3ab8a3c}},	//   юстр, mabu, ļiem_, कुछ_,
   {{0x2005eb25,0x2ca9023b,0x61e9eb26,0x3e720066}},	//   heli_, _yuad_, jgel, táty_,
   {{0x51f740fe,0x2717c00c,0x9f586b27,0xda1d8374}},	//   _اسپر, _lăn_, _paró_, फाजत_,
   {{0x20116b28,0x7d1b9dec,0x6284580e,0x6282ab29}},	//   _gazi_, _drus, llio, sloo,
   {{0xd01180e2,0x290d8070,0x8c1b00c3,0x2619e81d}},	//   _dā_, _esea_, טוסי, _मोही_,
   {{0xbb3b4009,0xddcd47ca,0x7c23d7d1,0xbddb6b2a}},	//   _געלי, zlaž, _annr, _alèj,
   {{0x80d8c08f,0x66060b16,0x62846b2b,0x26c2db1a}},	//   _मिळे, dekk, ilio, ćkom_,
   {{0x9411403a,0xe0df023f,0x9f5a0016,0x61ed2b2c}},	//   _bizə_, vrò_, _japó_, _scal,
   {{0x2717c082,0xbb8681b4,0x6e3609ee,0x645aab2d}},	//   _căn_, _الاي, _boyb, _imti,
   {{0x78a181d4,0x6441cb45,0x3ea24064,0xe0df05f5}},	//   _zilv, akli, _nikt_, trò_,
   {{0x2ca9018a,0xd85141c0,0x9f5ec34d,0x7bce0f2d}},	//   _quad_, _bọ̀_, metí_, fabu,
   {{0xdb1e019d,0x4d7bc009,0x24444041,0x769f01c0}},	//   _sepá, _ערגע, _sömn_, _bàyì,
   {{0xce6b5d10,0x2bf7c3bd,0x644b40fd,0x7659c1f4}},	//   град_, _המון_, ëgim, _ymwy,
   {{0x6e240303,0xbddb4303,0xe0df00c4,0xddcd4011}},	//   _gnib, _ilèk, prò_, slaž,
   {{0xdd944026,0x645a817b,0xb87b0018,0x3ea24377}},	// [2a30] заты, _omti, quío, _dikt_,
   {{0x9f5a1e11,0x7bcac0cc,0x798d0f2d,0x734b43dc}},	//   _capó_, _jefu, _izaw, лчев_,
   {{0x61e9d5b3,0x6aaac7f5,0xb5fb0066,0x163540c5}},	//   ygel, _juff, piád, _деня,
   {{0xa5f982c3,0x9f5ec047,0x645aa8fc,0x61e9c149}},	//   реду_, jetí_, _amti, xgel,
   {{0xbcfb4c5a,0x7ae542ff,0x6441e881,0x7c87400a}},	//   _exér, suht, ykli, _гуве,
   {{0x7bcae336,0xdd314064,0xe7398b2c,0x4423407a}},	//   _nefu, zęśc, иел_, _unj_,
   {{0xd1bb8032,0x1a29c203,0x7ae70089,0x78a19a41}},	//   _ماذا_, ижки_, nujt, _vilv,
   {{0x7bce277f,0x61e9eb2e,0x6aa2c8e5,0x61fb8eb3}},	//   zabu, ugel, _ciof, _ubul,
   {{0x6aaac0fa,0xaca3800c,0xe9d98036,0x9411403a}},	//   _auff, _trốn, _idź_, _sizə_,
   {{0x66062b2f,0x7982c02f,0x99488032,0x25a6c303}},	//   wekk, _dyow, _الكل_, _egol_,
   {{0x764d4339,0x6aaade4b,0x2249173f,0x2005eb30}},	//   khay, _cuff, _blak_, reli_,
   {{0x28f9c04c,0x61eb8962,0x645e5ecb,0x28e0905d}},	//   _ведь_, nggl, zipi, _निमि,
   {{0x764d5033,0xfe42c11b,0xdb018065,0x6440010b}},	//   dhay, _іншо, _aflø, êmio,
   {{0x80b04028,0x7e7beb31,0x69cbeb32,0xbb45d09b}},	//   _अंबे, loup, _hege, _мелк,
   {{0xf21eca3c,0x2bfb8028,0xeb9a2b33,0x7ae72b34}},	//   _मोड़_, ल्यू_, рив_, gujt,
   {{0x69cf1c2d,0xb81a2851,0x764d5b74,0x7bc1d19e}},	//   cace, _फोरम_, ghay, lblu,
   {{0x75d341b4,0x78a3c0bb,0x80dba208,0x4425ab35}},	// [2a40] بيقا, _kinv, _निषे, _onl_,
   {{0x628441be,0xb5fb1792,0x765bab36,0x7e6d0451}},	//   slio, ciáb, _amuy, _zjap,
   {{0x2beb62cf,0xe7ed808f,0x764d4339,0xad9b4031}},	//   _चारू_, च्छा_, bhay, _abúd,
   {{0x2bb48a1b,0x4425ab37,0xdb1acaf3,0xd5b08228}},	//   ुर्थ, _anl_, ratø, رفت_,
   {{0x6b83db59,0x491d0285,0x7e7beb38,0x2007800b}},	//   _lyng, मियो_, doup, feni_,
   {{0x76446b39,0x69cf2b3a,0x69d9eb3b,0xdfd2401c}},	//   lkiy, zace, _adwe, _زير_,
   {{0x60cd806f,0xdca359f4,0x645c6b3c,0x81b00360}},	//   šamp, _цари, _imri, _zaɓe,
   {{0x27e089d7,0x3ea2c4d3,0x66166b3d,0x7bcaeb3e}},	//   şin_, ökt_, ndyk, _sefu,
   {{0x443862e2,0x3218c185,0x645c4033,0x4444418e}},	//   _kor_, ěry_, _kmri, ok_,
   {{0xdb1c4051,0x69c28713,0xb87b0018,0xa3e780b2}},	//   _terä, lboe, tuím, _भाए_,
   {{0x76444360,0x9ceac02a,0x683d8060,0xdd8fc05f}},	//   kkiy, কবেন_, _cèdu, _یوم_,
   {{0x69c28ef1,0x64a6c0d7,0x7e7beb3f,0x2fcc80b3}},	//   nboe, _дада, coup, _hedg_,
   {{0x22492b40,0x1a9b881b,0x2beb408f,0x62560066}},	//   _vlak_, ייטע, _चालू_, yšov,
   {{0xa5bb47c9,0x9f5a03bc,0x290b0036,0xb87b0019}},	//   _enól, _rapò_, rwca_, fría,
   {{0x644ac033,0x6d40c523,0x69c281b0,0x2ca3415d}},	//   _ilfi, lyma, kboe, _rijd_,
   {{0x68e2ab41,0x7c38c041,0x78bd0854,0x224900f8}},	//   krod, _hovr, ppsv, _ulak_,
   {{0x7c38c0e0,0xfbab409b,0x200780f7,0x7ae8df5d}},	// [2a50] _kovr, атей_, yeni_, ludt,
   {{0xf8bf0744,0xb87b02b0,0xd838806c,0x83fcc6f0}},	//   mpé_, bría, _noč_, biđe,
   {{0x29024011,0x764d40f7,0x62562b42,0xf99f4396}},	//   _epka_, phay, ršov, _paès_,
   {{0x6d40c039,0x645c6699,0x69c28353,0x5a358844}},	//   kyma, _emri, gboe, янет,
   {{0xb5fdc5c7,0x44444498,0x25a9811a,0x62560066}},	//   niše, bk_, žalo_, pšov,
   {{0x7d0d6b43,0xfaa59408,0xb33c8085,0x7c38c080}},	//   mwas, пако, _egħm, _novr,
   {{0x3ffc081b,0x28ddc834,0x78a3cbfd,0xdb188676}},	//   יפגע, _मिहि, _rinv, cavü,
   {{0x7d02c032,0xe68e403a,0x27e940b4,0xdbd70051}},	//   _bpos, _məşğ, şină_, lääk,
   {{0x6b83eb44,0x7e69c240,0x2919834d,0x69cbeb45}},	//   _syng, rnep, _ésa_, _vege,
   {{0x1bf28036,0xb5fdc158,0x2ca3c041,0xd8388077}},	//   _घायल_, diše, öjd_, _goč_,
   {{0xa5bb430d,0x3ce9424c,0x3b09d70f,0x60db041b}},	//   _anóm, huav_, щено_, šuml,
   {{0x80b30079,0xdb12405f,0xdb0740fd,0x6d40eb46}},	//   _জিজ্, égév, _agjë, byma,
   {{0x04b60844,0x6609eb47,0x80b06b48,0xbddb405e}},	//   ясня, meek, _अंधे, _glèi,
   {{0xe73a03d0,0x3af54041,0x61fbc253,0x31568052}},	//   бег_, kåp_, lful, לירן_,
   {{0x7d1be42d,0x60c985bc,0xdb1a801f,0xe29a03e1}},	//   lvus, _lwem, _setú, _лак_,
   {{0x673cc73b,0xb5fb131f,0x44386b49,0x2bd80185}},	//   ärje, riác, _sor_, _भएका,
   {{0xe51c41f9,0x78bb8024,0x66166b4a,0x6abb4247}},	// [2a60] निधि_, _ntuv, rdyk, _čufa,
   {{0x5ed34079,0xd91b0009,0x8b96442e,0x2a6041c8}},	//   _সহজে, _פויל, преч, siib_,
   {{0x7a3cc669,0xc43b0093,0x39464f56,0x291fab4b}},	//   _métr, _התיי, šos_, _arua_,
   {{0x78ad023b,0x60c98536,0x20181fb8,0x200a2b4c}},	//   _yuav, _bwem, ldri_, lebi_,
   {{0x66162b4d,0x69c28a26,0x1a9b4009,0xb05b054a}},	//   _mayk, rboe, _ליטע, späe,
   {{0x3d1d0314,0x2cbfc0f8,0x62998049,0xb17b03db}},	//   मिते_, dpud_, amwo, pgåv,
   {{0x7e60eb4e,0xa09b0052,0x69c28a26,0x60c987f2}},	//   timp, זיסט, pboe, _ewem,
   {{0x54b8cf36,0x7ae8d539,0x200a01d1,0x6ed5c874}},	//   огия_, vudt, hebi_, _भिजु,
   {{0x291f80fd,0x443a0afc,0xdd90c08c,0x4427eb4f}},	//   _grua_, _oop_, کوک_, _bnn_,
   {{0x7bce401c,0x200a07ef,0xaae041f9,0x9ed8cd0d}},	//   _jebu, jebi_, _पटाक, омот_,
   {{0x21200396,0x67bb80c3,0x6609c1ae,0x7d040398}},	//   _arih_, _המבק, beek, _apis,
   {{0x60d6616a,0x61ed41c8,0x7c3a80d1,0x8c3d80b4}},	//   ksym, xgal, _hotr, _ruşi,
   {{0x3ce9404d,0x81cc002a,0xbddb4053,0x66162b50}},	//   xuav_, _লাশ_, _klèv, _dayk,
   {{0xdca3c717,0xb4ba8185,0xbddb001e,0x3ced0027}},	//   _зачи, _अझै_, thès, _जमीं_,
   {{0x7c3aab51,0x443a276e,0x68e4454a,0x3ffbc093}},	//   _motr, _dop_, erid, _הפוע,
   {{0x6aa6405c,0x672149fa,0xaa584bf8,0x26df01be}},	//   _cikf, _šljo, пису_, čuo_,
   {{0xdbd70051,0xa3cc87f6,0x764d1523,0x26d84cc2}},	// [2a70] tääk, लरा_, _ilay, _avro_,
   {{0x80b20b35,0xbddb001e,0xe0df03e2,0xc879c0b4}},	//   _इंते, chèr, ryòd_, tuşi_,
   {{0x9f5ea75d,0x60c982a4,0xdb1aeb52,0x81b006df}},	//   _mató_, _swem, mató, _haɓa,
   {{0x3cddca3c,0x2cad8070,0x81b0009c,0x291f80c4}},	//   _खिले_, _pued_, _kaɓa, _prua_,
   {{0x3eaeeb53,0x6609eb54,0x69cf4017,0xdb154070}},	//   _luft_, veek, _iece, _pezó,
   {{0x6fbf0045,0xfaf8c017,0x81b000e2,0xe7bf0371}},	//   ्रिं, ktī_, _maɓa, ्रिप,
   {{0x7a3cc669,0x61fbc5b0,0x09bec02a,0xeb96843e}},	//   _rétr, tful, _ইয়া, миш_,
   {{0x7d1bc54a,0xb5fdc0b3,0xdb26408c,0x61fd015d}},	//   tvus, dišc, _توفی, jfsl,
   {{0x14ddc08f,0x81cc0079,0x3ea6c0fc,0xfbbf04fb}},	//   _मिळण, _লাল_, _diot_, ्राम,
   {{0x6e3bab55,0x69cf6b56,0x61fbc098,0xa3e78314}},	//   _houb, _lece, sful, _भाट_,
   {{0x49144b0d,0x764d0141,0xc7b28093,0x7d1bc134}},	//   _नैनो_, _blay, _סבא_, svus,
   {{0x645e0033,0x6e3b814b,0x68e441af,0x68e9c070}},	//   _smpi, _joub, yrid, pued,
   {{0xd1b8cde9,0x76ac406a,0xee78c3be,0x443a00c3}},	//   _رانا_, _işye, _عصمت_, _pop_,
   {{0x7c3a8018,0x68e44b44,0xe8df40d1,0x629bc007}},	//   _xotr, vrid, _chọc_, lmuo,
   {{0xb5fb0c1e,0x69c46b57,0x69cf69d5,0x63830c60}},	//   vnáv, tbie, _bece, вгра,
   {{0xb5fb4018,0xb87b01b4,0xbf280031,0x7bdc4047}},	//   _amáb, brío, _aṣòr, _sdru,
   {{0x81b00020,0x2ca7c378,0xb5fb0066,0x68e46b58}},	// [2a80] _gaɓa, _kind_, tnáv, urid,
   {{0x6d428150,0x6e298047,0x68e44aa1,0xb05b402d}},	//   vyoa, _aneb, rrid, _zväz,
   {{0x68e4405e,0x3cea4027,0x3ebcc05c,0xdfcf45a7}},	//   srid, _चमके_, _xtvt_, شين_,
   {{0x2a6deb59,0x5ee0cb35,0xdb03c032,0x38b40041}},	//   jneb_, _किस्_, _ngní, _kär_,
   {{0x15ff81f9,0x62840230,0x7c4945ca,0xf8bf4b87}},	//   ोज़र_, _mkio, ásró, _créd_,
   {{0x38b41582,0x2246ab5a,0x3ea6cbd7,0x672180ab}},	//   _mär_, skok_, _siot_, _brlj,
   {{0x212240c9,0xdb05000c,0xb5fb0512,0x2bc4515e}},	//   _hrkh_, _nghì, dián, _ल्या,
   {{0x3914d86f,0x672184f9,0xddc287ca,0x7c3c6b5b}},	//   емир, _drlj, bnoš, _horr,
   {{0x2ca7d462,0xd7e6c31e,0x5fb24036,0xb5fb0c1e}},	//   _bind_, міно, _जलाल, fián,
   {{0x7c3c40fc,0x7e6080f8,0xb5fdc0b3,0x6296017b}},	//   _jorr, _hmmp, tišc, _ahyo,
   {{0x81b006df,0xdb1ace79,0xd5ed035d,0xbddb40b6}},	//   _saɓa, vató, _nhạ, _klèt,
   {{0x6e3b8004,0xb33c8283,0xb87b0032,0x63addcdc}},	//   _xoub, _ngħi, trío, _şant,
   {{0x629600f8,0x58870051,0x2bbfc945,0xa194031e}},	//   _dhyo, дыва, _श्वा, каюч,
   {{0x36d4c11b,0xe167c01c,0x7d1d00b0,0x9c57c032}},	//   _зокр, _تضمی, rvss, _يجوز_,
   {{0xdb1aeb5c,0x7e6d4327,0x442d6b5d,0x78a8ab5e}},	//   rató, tnap, _đe_, _midv,
   {{0x200ceb5f,0xd5b8011b,0x3ce6ab60,0xdb170070}},	//   ledi_, _ось_, krov_, _sexó,
   {{0xfd1f4031,0x7c3c6b61,0x4fc7086c,0xd83b0c85}},	// [2a90] _eyìn_, _borr, _осна, _дэн_,
   {{0x2a64c156,0x200ceb62,0x6280ea27,0x3ce69ac6}},	//   himb_, nedi_, homo, drov_,
   {{0x78a7415d,0xdd9101aa,0x7bd5000b,0x6e3b9c2d}},	//   _vijv, _جوک_, mazu, _poub,
   {{0xddc2838f,0x7bd510bb,0x625600b3,0x7522eb63}},	//   tnoš, lazu, nšop, _oroz,
   {{0x442a42a4,0x2ab500b0,0xfce587be,0x38580de9}},	//   _fnb_, _håb_, холо, _رشید_,
   {{0x6e3b8141,0x64904051,0x442a6b64,0x443ceb65}},	//   _woub, läin, _gnb_, _nov_,
   {{0xdb1e0674,0x3d174549,0x6e3d42a4,0x68eb8105}},	//   _sepú, निके_, _kosb, sugd,
   {{0x7c2ac0fa,0x7c3c6b66,0x7f946a91,0x2ecb408f}},	//   _anfr, _zorr, _расх, ाठीत,
   {{0x25ad9846,0x6e3d46a6,0x11678107,0xc8f485f5}},	//   _igel_, _mosb, _غلطی_, _изтъ,
   {{0x2ca7c0da,0x672180e0,0x628bab67,0x200ceb68}},	//   _qind_, _trlj, llgo, gedi_,
   {{0x65694066,0x79898b0e,0x63adeb69,0x13a7c973}},	//   _žehl, _hyew, _şans, بندی_,
   {{0x60cd0536,0x76598189,0xd83886f0,0x38b404c9}},	//   _bwam, _çayı, _riči_, _pär_,
   {{0xddc4510f,0x660d4232,0xa49b41c0,0xc56bc425}},	//   jniš, deak, _apòm, _بحال_,
   {{0x44f9c3e2,0x661beb6a,0x6619eb6b,0x60cd00b6}},	//   mè_, lduk, _hawk, _dwam,
   {{0x38b400cb,0x68fbeb6c,0x6e3d40bf,0x7522cb75}},	//   _wär_, ltud, _bosb, _zroz,
   {{0x6e3d6b6d,0x8236001c,0x4ae10048,0xd05bc09c}},	//   _cosb, _سربا, _फिरव, ttuɗ,
   {{0x68fbcc5a,0x44f9c3bc,0xa5074f8d,0x7bd507f2}},	// [2aa0] ntud, nè_, нета_, bazu,
   {{0x4ad3c5db,0x628b911b,0x32194093,0x6723c0ab}},	//   _दबाव, elgo, _easy_, _krnj,
   {{0x68fbc09d,0x64e24048,0xd7764032,0x27e74359}},	//   htud, _पिवळ, رائع, ónna_,
   {{0xdb01eb6e,0x60c28199,0x81b0009c,0x201a00fd}},	//   lcló, tpom, _maɓo, _hapi_,
   {{0x69d66b6f,0x20186b70,0x2372003f,0x200cc05f}},	//   maye, _tari_, šajā_, yedi_,
   {{0xb87b0018,0x661bc286,0xb5fde652,0x69d66b71}},	//   buíu, eduk, viša, laye,
   {{0x201a06ab,0x60c28764,0x1bee0048,0x2bee054a}},	//   _mapi_, spom, _जाईल_, _जाईं_,
   {{0x75242b72,0xbea39198,0x3ce6ab73,0xfaa38823}},	//   _oriz, _баск, prov_, _басо,
   {{0x7bd5078f,0x200cc06a,0x3f8a402c,0xbddb4396}},	//   yazu, tedi_, _hybu_, _klèr,
   {{0x69d66b74,0x07a68187,0x443cc046,0x1bba81b4}},	//   haye, _зазн, _qov_, _رائع_,
   {{0x6723c81a,0xe80267c1,0x7bd52b75,0x38b64240}},	//   _crnj, र्या_, vazu, _lær_,
   {{0x442cab76,0x201a0340,0xa25ac280,0x7bd51549}},	//   _hnd_, _aapi_, _عشاء_, wazu,
   {{0x75240119,0x7bd51593,0xad9b41c0,0x8c46d450}},	//   _criz, tazu, _abún, _педе,
   {{0x66041415,0xe80240e6,0xb5fb2b77,0x7ae10107}},	//   _ebik, र्मा_, gnár, álto,
   {{0x7bc70c62,0x69d66b78,0xddc9ab79,0x442c9c81}},	//   rbju, faye, _lješ, _mnd_,
   {{0xdb0a8041,0x1fcd402a,0x38b65b59,0xbddb40d2}},	//   bbfö, _লাইস, _bær_, _alèr,
   {{0xc4c480fb,0x6e2d1e4f,0x067c03bd,0x22496b7a}},	// [2ab0] _دے_, _inab, _מנהל, rkak_,
   {{0x2bee0064,0x998dc38f,0x68ed48a6,0xb4dd0048}},	//   _जाएं_, nješ_, ruad, डळी_,
   {{0x5b24410e,0xc885c0fa,0x660d6b7b,0xdb1a8166}},	//   льца, äßig_, peak, _metó,
   {{0xddc98158,0x22b80f26,0xdb1a8019,0x3cea4048}},	//   _bješ, _učka_, _letó, _चमचे_,
   {{0xcc3411be,0x644804d3,0x661d07d3,0xdd948039}},	//   _شریع, ödig, idsk, гацы,
   {{0xd942865e,0x628d6b7c,0xdddd0062,0x6247c140}},	//   реши, llao, nisł, _iñoi,
   {{0x39468c47,0xf77382f0,0xe3b1c01c,0x13944025}},	//   ayos_, داش_, یرد_, _бирю,
   {{0xa2958039,0x6e2d2b7d,0xaca381c0,0xdb03c359}},	//   _рабі, _nnab, _ipọn, _ngná,
   {{0xdb1a8166,0x661bd029,0x6723c04f,0x1958823d}},	//   _betó, rduk, _srnj, _заты_,
   {{0x6723db1a,0x644aab7e,0xdb1a8018,0x443eab7f}},	//   _prnj, ckfi, _cetó, _got_,
   {{0x29090033,0xc7b243bd,0x44f9eb80,0x69d66b81}},	//   _apaa_, יבי_, sè_, yaye,
   {{0x443eab82,0x7d0980eb,0x3ce94e16,0x32040066}},	//   _zot_, _kpes, krav_, ýmy_,
   {{0xb33c80f6,0x6d59ab83,0x661bab84,0xbbbf02ea}},	//   _dgħu, nzwa, _mauk, ्रूक,
   {{0xc0e2e67d,0x2d8c003f,0x6723c6f0,0xa2e60051}},	//   _тошк, āde_, _trnj, когд,
   {{0x6b631269,0x6715c56c,0x7c3e0166,0x69d64d68}},	//   акра, _तनिक_, _vopr, taye,
   {{0x66042b85,0x3dc94105,0x3376c4e0,0xa8980017}},	//   _ubik, gbaw_, _בעצם_, _šķēr,
   {{0x23d18064,0x21676b86,0xa9675828,0x7e64262b}},	// [2ac0] हराद, вити_, вита_, _imip,
   {{0x64a61373,0x0715d32e,0x68e9c1ff,0x60c46b87}},	//   _шапа, _तनाव_, ired, rpim,
   {{0x661bab88,0xdb1a8060,0x5c3700c3,0xe29a4025}},	//   _bauk, _letò, _סרטן_, _оао_,
   {{0x91e680cc,0xdee3564d,0x60c44134,0xc332c4e0}},	//   тоде, роци, ppim, יוב_,
   {{0x3ea04663,0x69c9e3e7,0xee3740b4,0x7bd74140}},	//   mmit_, dbee, _рня_, baxu,
   {{0xb7d88032,0x76ac406a,0xdcf5c047,0x660f0089}},	//   روبا_, _eşya, ůběh, zeck,
   {{0xa3c18b35,0x200e81f4,0x81d9002a,0xe8040e64}},	//   ंड़_, refi_, ালত_, श्या_,
   {{0x2450805e,0x661bab89,0x5214d8f9,0xa194cf37}},	//   _dàma_, _gauk, удит, лайч,
   {{0x6602ab8a,0xb50587c3,0x60dbeb8b,0xb33c80f1}},	//   mfok, _مظلو, gsum, _agħt,
   {{0xad258701,0x63bc01be,0x28dc0048,0xb5fb0018}},	//   _حرفو, jcrn, _बिजि, riám,
   {{0xd34581aa,0x661ba02c,0x2ac881c0,0x8fa680b4}},	//   _میوه_, _yauk, _dìbò_, _раже,
   {{0x3ce9a6a9,0xdd0e046d,0xdb1c0086,0x22be8094}},	//   šave_, िबंध_, varð, _ọkwa_,
   {{0x661d0e16,0x764080f8,0x60dbc077,0x5fb2409d}},	//   rdsk, _momy, csum, जशाल,
   {{0x6486c10d,0xdb1c6b8c,0xaf37008c,0x3dc94006}},	//   rðis, _berü, پرست, wbaw_,
   {{0x9c13c0eb,0x3879c107,0x3d19846d,0x660f056e}},	//   _kọnv, ésre_, _मैने_, peck,
   {{0x3ce940b6,0x3ea04105,0xb87b0018,0xbddb4303}},	//   trav_, gmit_, guír, _clèp,
   {{0x1da70e1a,0xad9b41c0,0xdb0ac329,0x61e2eb8d}},	// [2ad0] _गणित, _gbúl, _affø, _mdol,
   {{0x44fb810b,0x7bd8802d,0x60ddc004,0xb4e34045}},	//   vê_, javu, ásmi, _नटी_,
   {{0x6ad1809d,0x201ceb8e,0xd3a7493d,0xd25145a7}},	//   _सबेर, _mavi_, трап, _هند_,
   {{0x7c2e4140,0x6d1e95a3,0x3ce6456e,0x60dbda04}},	//   _enbr, पिंग_, šova_, ysum,
   {{0x9f580560,0x99d48231,0x60c2c0c2,0x3a3f80b6}},	//   beró_, شتنا, _ntom, _voup_,
   {{0x3949402f,0xeb99816d,0x6d5991e6,0x661bab8f}},	//   myas_, нил_, rzwa, _wauk,
   {{0x39494d66,0x69c9c0bf,0xe1ff0019,0x02a7ab90}},	//   lyas_, tbee, vión_, _арам,
   {{0x80d28079,0x3a2d88c3,0x764d415e,0xa91d8166}},	//   _সমর্, _unep_, nkay, _lyži,
   {{0xe800ab91,0x8cbb81aa,0x2717803a,0x20110952}},	//   ल्हा_, _آدرس_, _mənə_, kezi_,
   {{0x442eeb92,0x2011221e,0x2ab88031,0x6353c080}},	//   _cnf_, jezi_, _féb_, lənə,
   {{0x798d2695,0xe1ff030d,0x60c2d8c2,0xdb1c40d2}},	//   _ayaw, rión_, _etom, _herò,
   {{0x661d53aa,0xddd6405b,0xdb0545b1,0x442ec0b6}},	//   _nask, chyň, lchó, _enf_,
   {{0x82768052,0x6486c397,0x2240014d,0x2fd80062}},	//   רערע_, rðir, _voik_, targ_,
   {{0x9f5800c4,0x39494d85,0x61e2cb81,0x201cc157}},	//   derò_, dyas_, _zdol, _gavi_,
   {{0x661d6b93,0x6aad0145,0x37d8802a,0xc8a8c0c5}},	//   _bask, _fiaf, _সামর, _ръце_,
   {{0x62898044,0x764d581f,0xdb054032,0x224dc107}},	//   _nkeo, gkay, hchó, nkek_,
   {{0x69d980f7,0x6d5be3c0,0xb87b0480,0xed57401d}},	// [2ae0] dawe, nzua, ruír, гот_,
   {{0xc1cc8ae7,0xdb1aeb94,0x69d62b95,0xf8bf0669}},	//   ार्ग, ratö, _heye, uvée_,
   {{0x3ead800c,0x7bd56210,0xf8bf001e,0x7bfb0009}},	//   _biet_, _dezu, rvée_, _אפיצ,
   {{0x629bab96,0x22164203,0x9f4100e1,0x3179c036}},	//   _chuo, _сфор, _echó_, ższy_,
   {{0xa06a84b6,0x6e3bc0b3,0x7e69c4a9,0x798d023b}},	//   нада_, djub, diep, _xyaw,
   {{0x26dc82bc,0x9873913b,0x661d6b97,0xddcd4036}},	//   tsvo_, бліц, _zask, chał,
   {{0x60c410ec,0xf1b9806f,0x59b84028,0x09da002a}},	//   _ltim, _saše_, _अलार, _থানা,
   {{0x61e42b98,0x2bc040e6,0x20112b99,0xe8040103}},	//   _ndil, शुरा, zezi_, श्ता_,
   {{0x6aad130e,0x295680c5,0xacb4c6b1,0x2ba58045}},	//   _riaf, _съвр, јбољ, गेबा,
   {{0x59cc8047,0x798d0449,0x224dc0b9,0xa0a6a029}},	//   ारकर, _ryaw, akek_, _сазд,
   {{0x9b94c156,0x69d6009e,0x61e40085,0x3394c007}},	//   ринц, _beye, _bdil, ранё,
   {{0xc3334093,0x61e4005e,0x67008044,0x442ec127}},	//   צור_, _cdil, _ịkwe, _wnf_,
   {{0x9f410396,0xd04d409c,0xb7b580d1,0x69d62b9a}},	//   _idhé_, craɗ, _mạn, _deye,
   {{0x9f58023f,0x3cf1c066,0x2717803a,0x44fd40c4}},	//   verò_, ňový_, _sənə_, vì_,
   {{0x66044283,0xa91d8194,0x69d62b0a,0x69d9ab9b}},	//   ffik, _vyži, _feye, yawe,
   {{0x7bd56b9c,0x9f5800c4,0x2449c397,0x20112b9d}},	//   _sezu, terò_, _rúmi_, sezi_,
   {{0x320900f8,0x7642c1c8,0xe6d1a32e,0x7bd5413b}},	// [2af0] _ibay_, _mooy, _सब्ज, _pezu,
   {{0x69d984fd,0x36d50ace,0x7d1dc065,0xd37b46e4}},	//   wawe, _коор, æssi, нче_,
   {{0x533501a9,0xd5b144cc,0x629b800c,0xb87b4019}},	//   _тент, _وفد_, _phuo, _avíc,
   {{0x9f5c4047,0x39494c47,0xd011005f,0x26deeb9e}},	//   ývá_, pyas_, _الگ_, isto_,
   {{0x6d5d11cc,0xb814ca3c,0x2919414d,0x65abc561}},	//   nzsa, तजाम_, _ussa_, _möhü,
   {{0xcb699401,0x6aaf4077,0xd0098bb4,0x201e80cc}},	//   кале_, _hicf, теке_, _cati_,
   {{0x7e69c4f1,0xe45443d0,0x6e3bc654,0x6286131d}},	//   tiep, _укры, tjub, yoko,
   {{0x6d5bc232,0x2129097c,0xfd4e825d,0xdb1e005f}},	//   tzua, _orah_, _jikọ, _repü,
   {{0x6ec1c03f,0x442144ff,0x7e69c51f,0xddd40283}},	//   _mēbe, odh_, riep, ħaża,
   {{0x320909c7,0x7e69e76e,0x40878051,0x68ed6b9f}},	//   _abay_, siep, _субб, irad,
   {{0x69d60acc,0x7f75cdce,0xe29a01bd,0x29004232}},	//   _peye, рупц, као_, ztia_,
   {{0x7e6b802f,0xc174409c,0x69ac85da,0xba3b40d2}},	//   nigp, haɗa_, ुँची, _xiït,
   {{0x201e8056,0x62460031,0x21290396,0xb5fdc04f}},	//   _yati_, _bóor, _crah_, hišk,
   {{0xb5fdc039,0x7e66405c,0x69d6017b,0x70190289}},	//   kišk, _smkp, _weye, ліст_,
   {{0x9f58010d,0xb5fde652,0x21290303,0x60c9c125}},	//   gerð_, jišk, _erah_, lpem,
   {{0x69dbc0fa,0xdb1c2ba0,0xb5fdeba1,0x7529aba2}},	//   naue, ncré, dišk, _orez,
   {{0x248a4033,0xb21b011b,0x60c414c4,0xa3dcc1f9}},	// [2b00] _pkbm_, plær, _utim, तृक_,
   {{0x7d164b45,0x6443c3a5,0x6609aba3,0x629d4140}},	//   rwys, _joni, _abek, _ehso,
   {{0xb5fdc039,0xe28680b4,0xe0024027,0xc7b88570}},	//   gišk, алжи, र्षद_, _nađa_,
   {{0x7bdaeba4,0x443141d4,0x62872b79,0x3a20005c}},	//   zatu, _enz_, čkog, _jaip_,
   {{0x7529aba5,0x7d0d005c,0x7bd70046,0xb87b010b}},	//   _crez, _xpas, _yexu, rrív,
   {{0xb5fdeba6,0x7642eba7,0x7bd70018,0x26de0066}},	//   bišk, _sooy, _xexu, štou_,
   {{0xe3e90009,0xdee3492e,0xfbcf8079,0xd5e2c112}},	//   אַפֿ, _мори, _রাখত, _nkọ,
   {{0x5a34c640,0x6d4baba8,0xe8144c63,0x67024112}},	//   снит, byga, ड़वा_, _ọkwe,
   {{0x6247c070,0xb4e50314,0xc05ac589,0x3ce24303}},	//   _años, _पटे_, він_, _jvkv_,
   {{0xa2e68ef7,0x3eb8517c,0xcfa6c4b6,0x57a6cc21}},	//   _вожд, _kurt_, ишни, ишна,
   {{0xa3d743b0,0x2fd84119,0x69dbc0fa,0xf99f40ce}},	//   सरत_, _merg_, baue, _abèl_,
   {{0xe4db8185,0xd186cbe0,0x2c6d00b3,0x2129011a}},	//   zšíř, _клей, džda_, _prah_,
   {{0x3eb840d9,0x38bbc2cd,0xc693c0c3,0x44214149}},	//   _lurt_, _gêr_, _ואף_, ydh_,
   {{0xea01c015,0x248c821b,0x68ed6ba9,0xe2f90026}},	//   _đẩy_, _jkdm_, vrad, легі_,
   {{0xb05b0051,0x8cb0409d,0x6e674da4,0xb346c080}},	//   npäi, _अंजो, атаж, _qaçı,
   {{0x200a6971,0xd378c06f,0x877b8052,0x6e228077}},	//   _abbi_, gaće_, דאלי, jdob,
   {{0x26c50007,0x2129006c,0x6443ebaa,0x6e229238}},	// [2b10] ūlo_, _urah_, _yoni, ddob,
   {{0xb5fdc039,0x6443ebab,0x270e803a,0x838703d0}},	//   tišk, _xoni, _kənd_, _выме,
   {{0x3eb84016,0xfbd20093,0x62584032,0x752980ab}},	//   _curt_, _מתי_, _díob, _srez,
   {{0xd378c077,0x245404c9,0x200a6bac,0x6d4b8824}},	//   caće_, _jämn_, _ebbi_, tyga,
   {{0x64450134,0x628d2bad,0x42e3802a,0x69dd00b9}},	//   _kohi, _mkao, _মহেশ, iase,
   {{0x1ed804e8,0x9f3544c5,0x58d449b0,0x2d8fc0b0}},	//   _حبیب_, _легі, _форт, _ryge_,
   {{0x3669ebae,0x2d8fc0b0,0x7d0f4396,0xeeab9065}},	//   лако_, _syge_, _hpcs, _атак_,
   {{0x7bdc2baf,0x75299e28,0x07d8405f,0x6609800b}},	//   zaru, _trez, _مذہب_, _ubek,
   {{0x4bd9c4c5,0x7d1babb0,0x69dd2bb1,0x7bd8ebb2}},	//   льня_, _usus, dase, _bevu,
   {{0x2ab74085,0x645aebb3,0xa3d74314,0x79968036}},	//   _aħbi_, ghti, सरि_, żywc,
   {{0x5f95849f,0x62580018,0xe1ff005f,0x33958a2c}},	//   _الائ, _nãoc, ciók_, _الاز,
   {{0x7a3f00da,0x22990a6e,0xb9208094,0x7bcec086}},	//   _këty, téka_, _narị_, ðbur,
   {{0x68e907ca,0x7e7ec107,0x81cd402a,0x6277406f}},	//   šedn, éppe, রণা_, rćol,
   {{0xb5fdc013,0x2a6dc02d,0xfbc30d9a,0x2a690053}},	//   diši, lieb_, збро, _emab_,
   {{0x69d9ebb4,0x394dc05f,0x2002c435,0x64450247}},	//   _kewe, lyes_, əki_, _dohi,
   {{0xe8e04015,0x69d9d424,0x26c7c09c,0x6ec4c032}},	//   _suốt_, _jewe, _itno_, _بتوق,
   {{0xe2975771,0xe8144a3c,0x69d9c07a,0xb87b0166}},	// [2b20] сат_, ड़ला_, _mewe, trít,
   {{0xa5bb2bb5,0x28b50045,0x44210f0e,0x3ce06bb6}},	//   ndón, ंदरि, _gah_, rsiv_,
   {{0x290fc498,0x3ea00340,0x648d8032,0xff260687}},	//   _lpga_, _khit_, húis, _умно,
   {{0xb21b40b0,0x6d4d5238,0x54e68032,0xf1b998ff}},	//   _skæv, byaa, مستق, _paša_,
   {{0x2d84401e,0x645ac051,0x395fc022,0x644503ad}},	//   _âme_, yhti, jzus_, _yohi,
   {{0x6e22a8cc,0x6e208d68,0x7e7babb7,0x7e698094}},	//   sdob, _wamb, _ejup, _emep,
   {{0x6b636bb8,0x09d78079,0x2bdbc036,0x0420c079}},	//   _екра, _হারা, _मज़ा, বামী_,
   {{0x68e42807,0x7d02abb9,0xddcd4077,0x69dd2bba}},	//   _ovid, ptos, onaš, xase,
   {{0x645c22d7,0xb6a386c5,0xb05b0051,0x026640d1}},	//   khri, _хитл, späi, _đến_,
   {{0x634ac435,0x7d046bbb,0x14b7c1b4,0xe1f9c007}},	//   yənd, itis, حديث_, agų_,
   {{0x9f4500b5,0x81b000e2,0xd7f8c0b4,0xbfaac051}},	//   ülü_, _maɓu, rgă_, ытие_,
   {{0x877b42a6,0x6d4d5e51,0xa5f90051,0x539b84e0}},	//   ראטי, yyaa, шему_, _גיבו,
   {{0x64452bbc,0x68e2abbd,0x68e40011,0xc05b00d9}},	//   _pohi, nsod, _cvid, гів_,
   {{0x7bda80fd,0x645d8007,0x9abc80f1,0x99895188}},	//   _jetu, _įsik, _arċi, tjaž_,
   {{0x7e6d6bbe,0xe3b8c165,0x7ac6c6b1,0xe81dc048}},	//   tiap, ndım_, _усле, _बघता_,
   {{0x3ea00018,0x224040fd,0x6aba83a6,0x62584032}},	//   _ghit_, gjik_, _mutf, _ríoc,
   {{0x3e72041b,0x660d10f4,0x44332bbf,0x6abaabc0}},	// [2b30] ušte_, _ibak, _tnx_, _lutf,
   {{0x5c7510f9,0x44d68036,0xddd48199,0x212b4089}},	//   _флот, dł_, _čašo, _vrch_,
   {{0x39be80eb,0x26de0077,0x20040080,0x68e40089}},	//   _ịsa_, štor_, əmi_, _zvid,
   {{0x6e22c199,0xb5fdc084,0x27fe8123,0x8afbc052}},	//   _naob, piši, _actn_, רלאז,
   {{0x68e42bc1,0x2a6dc02d,0x69df400b,0x69d9c46d}},	//   _xvid, vieb_, maqe, _rewe,
   {{0x394dc022,0xd8dc0323,0xa3d91087,0xe9d98062}},	//   vyes_, נקור, ारि_, _weź_,
   {{0x9f5f4051,0x7d02c073,0xeb9980d9,0xee39cdbf}},	//   ärän_, _aqos, шик_, инк_,
   {{0x81b000e2,0x64474870,0x08c5c417,0xef224036}},	//   _zaɓu, _hoji, обин, _dużą_,
   {{0x7c219215,0xe459c5a6,0x69db802c,0x6e22c10f}},	//   _talr, ижи_, _ieue, _daob,
   {{0x3ae3c138,0xa5bb0250,0x9477961e,0x69db917c}},	//   tıp_, udón, _ادرا, _heue,
   {{0x69d9ebc2,0x2c0b4314,0xbb45cfe8,0x244b8240}},	//   _tewe, स्यं_, ценк, _dømt_,
   {{0x7de6405f,0x7d044086,0x60c9807a,0xdb1c406a}},	//   _késő, ytis, _ktem, _terö,
   {{0x7bdaa8c3,0x28b56bc3,0xafe5c051,0x60cd438f}},	//   _yetu, _अंगि, _долл, jpam,
   {{0x69db82a4,0xdb0a05e5,0x628b919b,0x6490409d}},	//   _leue, žník, hogo, näit,
   {{0x7646555b,0x96ba2bc4,0x1faa0203,0xfd1f4031}},	//   _poky, ругу_, ркви_, _asì_,
   {{0x31afc189,0x316040fc,0x7d0463db,0xe1ff0036}},	//   _gözü_, tziz_, ttis, diów_,
   {{0xd378c0e0,0x68e407cb,0x66164057,0x1c4653c7}},	// [2b40] maća_, _uvid, reyk, онам,
   {{0x212005dc,0x8b964291,0xe3b8c526,0x7c23ebc5}},	//   _isih_, ореч, ydım_, _janr,
   {{0xe29a4fd2,0x752d0166,0x26054575,0x9f061546}},	//   _ван_, _zraz, _हॉकी_, _بوجو,
   {{0x634ac03a,0x7ff602cf,0x442340fc,0xd62a46b1}},	//   lənc, _اسکا, _eaj_, _томе_,
   {{0xcaa581b4,0xdca64c3f,0x69dba934,0x61e981f4}},	//   أصلي, _мами, _deue, _ddel,
   {{0xab2a56a8,0xe9f90015,0x7529c05f,0x2246c056}},	//   _кога_, _khả_, dvez, _sook_,
   {{0x7659c1f4,0x2bc688c5,0x7bdc6bc6,0x60c98b4e}},	//   _blwy, रुषा, _ieru, _etem,
   {{0x7c23c4e1,0x68ed8654,0x68e46bc7,0x7bda8a15}},	//   _aanr, šada, osid, _wetu,
   {{0x4974d702,0x212d8ee2,0x998dc06a,0xdb214025}},	//   ялис, _greh_, rdeş_, ätös,
   {{0xa7fcc165,0x61e9804f,0xc866c032,0x2906812c}},	//   lnız, _zdel, تطبي, mtoa_,
   {{0x212017a6,0x7659c0de,0xb5fb27ce,0x56950dc8}},	//   _asih_, _flwy, diár, зант,
   {{0x69c44036,0x7c2dc020,0x7c23c321,0x9999402d}},	//   jcie, _ɗari, _eanr, _hosť_,
   {{0xe3afc05f,0xddc2c0b4,0xd910005f,0x7eb58007}},	//   ٹری_, _emoţ, نیٹ_, _išpa,
   {{0x68e44a62,0x270e803a,0x09d34045,0x61e0c0b5}},	//   dsid, _gənc_, तर्य, laml,
   {{0x6e240669,0xcddb4267,0x9f5eebc8,0x628b8568}},	//   _faib, иња_, retó_, yogo,
   {{0xa3d91c79,0x6e2427a3,0x660d28e5,0xf1b98007}},	//   ारह_, _gaib, _ubak, _rašo_,
   {{0x64474185,0xb5fdc9fa,0xdb0e402e,0xa19443d0}},	// [2b50] _poji, mišt, _agbà, датч,
   {{0x69db8016,0x3f81023b,0xfbd04032,0x61e0ebc9}},	//   _seue, _txhu_, نتم_, haml,
   {{0x644758ca,0x2001002c,0x69dbabca,0xb87b0032}},	//   _voji, _ichi_, _peue, lsío,
   {{0x81d90079,0x6abc5c76,0x7bdc4031,0x3a2480c3}},	//   ালক_, _durf, _eeru, _camp_,
   {{0x69db8016,0xcfab008c,0x69dd40b4,0x823a4916}},	//   _veue, _حاکم_, _iese, _הערצ,
   {{0x94ba4093,0x44234022,0xbbb90185,0x628b99f1}},	//   _למשת, _uaj_, _आलोक, sogo,
   {{0x78bd5539,0x6284c732,0x7e6d0134,0x645dc13b}},	//   _husv, čion, _omap, ësim,
   {{0x7c23ebcb,0x22492bcc,0x212d806c,0x386c8498}},	//   _sanr, _noak_, _treh_, _emdr_,
   {{0x41b5ebcd,0x61fbebce,0x20182bcf,0x7c23c986}},	//   _ہمار, rgul, yeri_, _panr,
   {{0x98a90123,0x7bdc403c,0xa2a24374,0xd9b840e6}},	//   _brač_, _xeru, _कीन्, _अल्ट,
   {{0x69c10185,0xdce7c3a6,0x7ae540fd,0xb5fdc2bc}},	//   ělen, ğlık, nsht, fišt,
   {{0xfbcf84ae,0x7bc55335,0xdce7c3a6,0x6aa2c033}},	//   _स्तम, hchu, şlık, _ghof,
   {{0x625841b4,0xdddb806c,0x6aa9c240,0x55bac0c3}},	//   _bíon, _okuž, mmef, _המנו,
   {{0x8b080047,0x7e6d2bd0,0x7c2500b6,0x6e242bd1}},	//   jdří, _emap, _cahr, _waib,
   {{0x09b44389,0xfaa640d5,0x7c2500f6,0x26c14022}},	//   ंख्य, заво, _dahr, jqho_,
   {{0xb5fdc158,0xf1bf0019,0xa3b80b35,0x68e46bd2}},	//   cišt, ldán_, _छलक_, tsid,
   {{0x29120150,0x6abc6bd3,0xcaa5000f,0x14c841aa}},	// [2b60] _upya_, _surf, _تصوي, زهای_,
   {{0xc079c00c,0xe9f9000c,0xb87b097d,0xb5fb0018}},	//   _điệp_, _thả_, nsíl, cháb,
   {{0xe8024f8b,0x7bde00b4,0x1c024036,0xf99f40ce}},	//   र्गा_, _iepu, र्गल_, _ezè_,
   {{0x7bdc5b8e,0x7520805c,0xb5fb6bd4,0x29068051}},	//   _weru, _psmz, _aláf, ttoa_,
   {{0x20074016,0xe3b205d3,0xacf880d9,0x3a24922b}},	//   ònic_, _ترک_, інку_, _vamp_,
   {{0x6490404c,0x7c5a4032,0x29068d97,0xd90d801c}},	//   räis, _السر_, rtoa_, شیم_,
   {{0x69dd6bd5,0x64904051,0x61e0ebd6,0x98a480cc}},	//   _yese, säis, taml, _armă_,
   {{0x2bd1c285,0x6e264036,0xddc44036,0x76444dd6}},	//   _द्बा, _jakb, jniż, njiy,
   {{0x61e0ebd7,0x851b0027,0x645d8007,0xe80348c4}},	//   raml, _पैंट_, _įsiv, _लामा_,
   {{0x7e6d0010,0xd3e4801c,0x20c0c0d1,0xa5bb0086}},	//   _smap, _آقای, _vòi_, rdóm,
   {{0xcf8d801c,0x4f669546,0xe9ff80d1,0x8e0ace9d}},	//   _پژو_, _عاطف, _hoạn_, _гнев_,
   {{0x76bb80c3,0x7644409c,0x539b8323,0x7bde0230}},	//   _המאפ, jjiy, _פיאו, _aepu,
   {{0x32190750,0x7eb5c011,0x38a404c9,0x7bde014d}},	//   resy_, _ušpa, körd_, _bepu,
   {{0x98a92163,0x7522eb02,0x7bde0017,0x6abe0f2d}},	//   _trač_, _isoz, _cepu, _bupf,
   {{0x3ebe809d,0x7c38d7de,0x6aa4005e,0x9f3400d9}},	//   _jutt_, _invr, _fhif, нері,
   {{0x5eb447e1,0x61e2809d,0xeb97c0c3,0x2f97c0c3}},	//   ейст, jaol, _מדור_, _מכון_,
   {{0xad9b41c0,0x28b70028,0x44386bd8,0x6e266bd9}},	// [2b70] _abúr, _इंटि, _bnr_, _dakb,
   {{0x44384157,0x62808013,0xd49b4523,0x20010b29}},	//   _cnr_, _ajmo, ёра_, _uchi_,
   {{0x7f19471d,0xa13404e8,0x2c0ec048,0xb5fb05e5}},	//   تياز_, _قریش, त्यू_, chác,
   {{0x7ae540da,0x2fde8004,0x645c6bda,0x7bc88057}},	//   rsht, _aetg_, _elri, _afdu,
   {{0xf1b98011,0x7c38c078,0x08c484f5,0x69df013b}},	//   _hašk_, _onvr, ебін, _meqe,
   {{0x7ae540fd,0x60cd0150,0x69df075d,0x3a29402f}},	//   psht, _mtam, _leqe, ldap_,
   {{0x752d5af3,0x7afaebdb,0x61ed2bdc,0xab9540d9}},	//   lvaz, jutt, _odal, _циві,
   {{0x60cd2bdd,0xa294811b,0x7c28c0bf,0x65a2c0eb}},	//   _otam, _засі, eddr, _ọhan,
   {{0xa3a94185,0x6aa4002c,0x7c274c69,0xc21280c3}},	//   खेर_, _rhif, _kajr, _בהן_,
   {{0x6fb14048,0x4425abde,0x7afad317,0x224b6bdf}},	//   _जणां, _ual_, futt, _lock_,
   {{0x3ebe80d9,0x628f0bb2,0x588480d7,0x644aebe0}},	//   _gutt_, foco, _чыта, _dofi,
   {{0xdb1c00cb,0x81d3402a,0x29094025,0x6abe0449}},	//   rbrü, হৃত_, ktaa_, _rupf,
   {{0xb5fb4531,0x6e266be1,0x644aebe2,0x2bfe4103}},	//   _mlád, _rakb, _fofi, _लालू_,
   {{0x60cd2be3,0xed16c05f,0xb9060045,0x661be526}},	//   _dtam, _کہیں_, _पब_, leuk,
   {{0x92e8c1b4,0xe1ff2be4,0x4438405e,0x6aa40033}},	//   _فريق_, giós_, _rnr_, _thif,
   {{0xf1bf0485,0x6aa4012c,0x764bc44e,0x69c9840d}},	//   ndál_, _uhif, _jogy, _nfee,
   {{0x3cf54064,0x6e264353,0x1d07441a,0x7d09c193}},	// [2b80] एंगे_, _vakb, мети_, ntes,
   {{0x61ed1a16,0x752400f7,0xa3ba4032,0xb05b0c28}},	//   _zdal, _isiz, زائر_, spär,
   {{0xa0570009,0xe9ff8015,0xdb03c018,0xf2c546bc}},	//   _חסיד_, _soạn_, _ignó, есін,
   {{0xf8bf45b1,0x64920065,0x290941c8,0x60db8449}},	//   _fué_, pæis, btaa_, _bwum,
   {{0x60c9403a,0x7d09c0fd,0x3e774283,0x94aa940c}},	//   _çemp, jtes, għtu_, отка_,
   {{0x3e720007,0x68fbc1c8,0xf1a983a9,0x41ceabe5}},	//   kšto_, duud, سانه_, _ह्रस,
   {{0x69c981ae,0xeb97420d,0x09e2c02a,0x62808396}},	//   _ffee, _жир_, _যাবা, _tjmo,
   {{0x8fa3585e,0x6e29d064,0x7d09d671,0x03a35747}},	//   _расе, gdeb, ftes, _рисо,
   {{0xf50381bc,0xd7cf8945,0x7afc2be6,0x7eb5c007}},	//   _изто, _स्वच, hurt, _išpl,
   {{0x0c268187,0x60cd8070,0x6e39c17b,0x62584359}},	//   _імен, íame, _enwb, _síol,
   {{0xddc400e0,0xc7b8cfaf,0x2129c514,0x75240116}},	//   _smiš, jeđe_, _šaht_, _asiz,
   {{0xd9ad0079,0x201cabe7,0x61e0804f,0x2246842c}},	//   _ক্ষম, levi_, _jeml, njok_,
   {{0x7d09da8a,0xed5800d7,0x644aebe8,0xb956c01c}},	//   ctes, доў_, _tofi, _تئات,
   {{0x7afaebe9,0x3e7ac017,0x752d4570,0xddc9dda7}},	//   putt, dīti_, vvaz, mieš,
   {{0x752400f7,0x439403bf,0x7e6280c2,0x4cc7802a}},	//   _esiz, варс, khop, রীপু,
   {{0x7c2741aa,0x2cb84510,0xe1ff0016,0x3ce986f0}},	//   _sajr, _aird_, riós_, šavi_,
   {{0xd7d00959,0x1fab96c0,0xaca30112,0xddc9c03f}},	// [2b90] _त्वच, _चण्ड, _ajụg, nieš,
   {{0xcf9b41bd,0x443a14ad,0x2cbf9a41,0x4427ebea}},	//   оје_, _gnp_, _ruud_, _xan_,
   {{0x03d60093,0x61e4424f,0x3a290b45,0xb5fb4018}},	//   _אותם_, bail, _kaap_, _aláe,
   {{0x7c28854a,0xfe10000c,0x2c6d02bc,0xf8bf401e}},	//   _aadr, _lắng_, dždi_, _tué_,
   {{0x3a2915ce,0x7bcae5a8,0xcdf64323,0x51874375}},	//   _maap_, _offu, _אמרי_, _цуна,
   {{0x6282ebeb,0x68fbc051,0x3cfc0323,0x645d8026}},	//   _ajoo, vuud, קלונ, _įsis,
   {{0x3ea6c061,0x2bae4444,0x6e29d628,0xa5bb0359}},	//   _bhot_, झेदा, tdeb, adói,
   {{0xfbb80093,0xdd958c4e,0x68fbd845,0xa925dd91}},	//   ופות_, _забы, tuud, едил,
   {{0x4427ebec,0x6e3b802f,0x26c12bed,0x661bc0bf}},	//   _pan_, _inub, _luho_, reuk,
   {{0x6009cbb4,0x6e3b8022,0x6e29807a,0x68fbebee}},	//   чном_, _hnub, _haeb, ruud,
   {{0xd6ced1be,0x2d994240,0x3eb9402f,0x224dabef}},	//   یقی_, _lyse_, _oist_, _koek_,
   {{0x260506ff,0x68fbc09d,0x2d960c38,0x3e720026}},	//   _वाणी_, puud, ергс, ršto_,
   {{0x634ac080,0x7afc0020,0x19b90119,0x68fd0f43}},	//   lənl, wurt, дурь_, gusd,
   {{0x7860403a,0x61e4409c,0x7c28abf0,0x2bac8b5b}},	//   _mövc, wail, _xadr, टेवा,
   {{0x96961791,0xb5fb0032,0x6723c06c,0x601382d6}},	//   _приш, mhán, _usnj, mımı,
   {{0x64472bf1,0x49ba049f,0x3a2922fe,0x200145d4}},	//   ajji, _عابد_, _gaap_, eghi_,
   {{0x65b6859a,0x5f46405f,0x752400f7,0x7afc1620}},	// [2ba0] _mühü, کنال, _usiz, surt,
   {{0x6013838a,0xf1b98944,0x2a7fc022,0x3eb96bf2}},	//   nımı, _gaši_, hnub_, _eist_,
   {{0xb346c10b,0x7794078a,0x26c1002f,0x20c6000c}},	//   maçõ, _شیرا, _guho_, _hôi_,
   {{0x61e62bf3,0x320205b2,0x27e100fa,0x20059af5}},	//   nakl, ngky_, _zehn_, _acli_,
   {{0x224d911b,0x6e3b81d6,0xb4dec09d,0x645886f0}},	//   _doek_, _dnub, _तबे_, tkvi,
   {{0xdceb00e0,0xd4678ece,0xb346c10b,0xe8058758}},	//   šićn, ниче_, naçõ, _राणा_,
   {{0x20c6000c,0x53a357dd,0x61e62bf4,0x7c2a813a}},	//   _lôi_, _барб, kakl, rdfr,
   {{0x2005817a,0xf99f4031,0x8938da2b,0x6296040d}},	//   _ecli_, _gbès_, дпис_, _nkyo,
   {{0x60c0802f,0x7afe6bf5,0x201cabf6,0x60138165}},	//   _uumm, lupt, pevi_, fımı,
   {{0x3eadc8a1,0x442a6bf7,0x62962bf8,0xdb1c40fd}},	//   amet_, _jab_, _akyo, _ngrë,
   {{0xa5f91fa9,0xfe10000c,0x1c04039a,0x1eda81e3}},	//   мену_, _vắng_, श्छल_, _رباب_,
   {{0x5186c0b4,0x69c02bf9,0x26c10199,0xa3d304eb}},	//   _пула, žmen, _ruho_, हुन_,
   {{0x442a410b,0xf1b98017,0x75264011,0x20c600d1}},	//   _oab_, _paši_, _nskz, _côi_,
   {{0x20050107,0x7afe6bfa,0x62840031,0x6296031c}},	//   üli_, kupt, _ejio, _ekyo,
   {{0x8aa743bf,0x6280c14d,0x02a75efa,0x6d401368}},	//   ерад, onmo, ерам, ämar,
   {{0x442a6bfb,0x7c2aebfc,0x4b37c0c3,0x7e646bfd}},	//   _aab_, _hafr, _טרול_, ghip,
   {{0x59d401b4,0x67028048,0xb4dec54a,0x3f9e0086}},	// [2bb0] _صغير, रंडक_, _तबो_, ýtur_,
   {{0xaaa50d91,0x224d950e,0x3eb941d4,0x3eadc3a6}},	//   _गीतक, _soek_, _wist_, zmet_,
   {{0x7afe4085,0x7c2ac047,0x225f8713,0x629bc010}},	//   gupt, _mafr, _pluk_, yluo,
   {{0x6280c0a8,0xfbd0016a,0x63a2409c,0x68e9c15a}},	//   jnmo, _پتی_, ƙonn, ysed,
   {{0x85b842d5,0x20c600d1,0x88c880d9,0x78ba80a0}},	//   _плюс_, _xôi_, елів_, _bitv,
   {{0x80d38079,0xc7b880b3,0x443cc0b3,0x6e2d6bfe}},	//   _সিদ্, _lađu_, _nnv_, ldab,
   {{0x5c3800c3,0x626c5940,0x3eadebff,0xba778359}},	//   תרון_, rşov, tmet_, _كارت,
   {{0x443cec00,0xc7b885c7,0xcd42805f,0x68ed2c01}},	//   _anv_, _nađu_, _چھوٹ, _ovad,
   {{0x51879a2c,0x22848951,0x60138676,0xc485c11b}},	//   _чува, _сург, tımı, клик,
   {{0x201ed76c,0x3e7ac017,0x799b809c,0x629d014b}},	//   geti_, dītu_, _iyuw, elso,
   {{0x7d0d43ba,0x20c6000c,0xb346c10b,0xf1d2c578}},	//   htas, _sôi_, vaçõ, _ध्वन,
   {{0x443cd18e,0x6e2d4022,0x442cc1f4,0x7c2ac0f6}},	//   _env_, jdab, add_, _eafr,
   {{0x60c2c0e2,0x443cddb1,0x7ebed9b6,0xd009c31f}},	//   _guom, _fnv_, _rūpe, _желе_,
   {{0x31568052,0x10a62770,0x61e62c02,0x443cc1ff}},	//   דישן_, тигн, sakl, _gnv_,
   {{0xdee3000e,0xafe31cf8,0x38a40041,0x6e2bdb43}},	//   иори, росл, göra_, _kagb,
   {{0xdcf442bc,0x6d444232,0x765bd3e7,0xdbc9409d}},	//   žačk, txia, nkuy, _mõõd,
   {{0xa8064be0,0x7d0d4f74,0x80c84079,0x26d14232}},	// [2bc0] кзал, gtas, _লিঙ্, _atzo_,
   {{0xe3b8c59a,0x3f9a0750,0x446348b5,0x037a479d}},	//   mdır_, _typu_, авув, وحات_,
   {{0x09e6ac03,0xf1b98158,0x61e41cc6,0xe3b8c1df}},	//   воен, _mašu_, _keil, ldır_,
   {{0x90e681aa,0xd259811b,0x6abb8643,0xddcd40b4}},	//   نستن, нці_, _ciuf, riaţ,
   {{0x645ac300,0xa06a90f9,0x186a8f99,0x160a0045}},	//   ykti, мада_, мади_, _वानर_,
   {{0x61e422b5,0xc7b801be,0x66046c04,0x627c8047}},	//   _leil, žđu_, lgik, jčov,
   {{0x60c40359,0x78ba9633,0x6e2bec05,0x7c65801c}},	//   _luim, _vitv, _bagb, دانل,
   {{0x645c00fd,0x765bc105,0x6abb80c4,0x625cc96d}},	//   hkri, gkuy, _giuf, _géol,
   {{0x09068217,0x78bc64ca,0x6282ac06,0x443cec07}},	//   _шпан, _kirv, mnoo, _pnv_,
   {{0x61e2ec08,0x3ea9042b,0x22494ee2,0x26050027}},	//   _weol, _shat_, zjak_, _वाही_,
   {{0x2c144028,0x6e2bec09,0xb87b0e9a,0x5226c156}},	//   न्यू_, _fagb, príz, _афла,
   {{0xb87b010b,0x752441c6,0x201ed7a8,0x442ac06c}},	//   nsív, kwiz, seti_, žb_,
   {{0x290dc30d,0xd87701b4,0xda65c032,0x39468160}},	//   ctea_, ناسب, _حالي, nxos_,
   {{0x3946ac0a,0x7d00def0,0xe5a3cc35,0x5f73c01c}},	//   ixos_, mums, _тичи, اایر,
   {{0x200746ed,0xdddb80ab,0x443e809d,0x200300fd}},	//   ònim_, _ljuš, _mnt_, rgji_,
   {{0x80d38079,0x68ed82a3,0x32644366,0x17dac079}},	//   _সিস্, šadi, атув, _দায়ি,
   {{0x78bc42bc,0x60c40f02,0x29005323,0x75246c0b}},	// [2bd0] _birv, _guim, guia_, gwiz,
   {{0x6aa9ac0c,0xd37b4457,0x648b4017,0x21292c0d}},	//   _shef, мче_, kļie, _isah_,
   {{0x27e35d9a,0x9ed9427f,0x2ef5474d,0x78bc4c34}},	//   _vejn_, хмет_, узер, _dirv,
   {{0x41b4c0e4,0xe0df43bc,0x26c34654,0xa2cac8fb}},	//   ुशास, _twò_, _vujo_, _संन्,
   {{0xe9d880d7,0xee3f4038,0xed46c05f,0x3959005c}},	//   ткі_, _iný_, _اپ_, nyss_,
   {{0xc1b8412b,0x6e2d0057,0x68ed4b94,0xf1b9c514}},	//   _шлях_, _laab, msad, ješa_,
   {{0xe3b8c0b5,0x6282ac0e,0x9f4780fd,0xdbdcc086}},	//   zdır_, bnoo, manë_, _ráðu,
   {{0x3e7ac03f,0x6e2d2c0f,0xf1b98077,0x7e62ec10}},	//   dīts_, _naab, _sašu_, _clop,
   {{0x625cd302,0xe616d0df,0x26088048,0x9f45c089}},	//   _géom, уды_, _हाती_, malé_,
   {{0x68ed401d,0xd7aa4617,0xe3e3c02a,0x765bc010}},	//   isad, _करमच, _মাহব, skuy,
   {{0x6d5996d7,0xf1b98ff5,0x3ce003bc,0x8ff9c1aa}},	//   lywa, _vašu_, _swiv_, ورگر_,
   {{0x6e2d01c8,0x9f45c066,0x0135c61e,0x442cac11}},	//   _caab, nalé_, _معتد, _zad_,
   {{0x442c8080,0xb5fb0066,0x9f4780fd,0x7ea5c070}},	//   _yad_, chám, kanë_, cópa,
   {{0x7e62c9fa,0x8c42c02b,0x61e9c314,0x7d1b8f2d}},	//   _zlop, _геше, lael, _mpus,
   {{0x6abd43ad,0x399d0107,0x7c21c713,0x6e2d2c12}},	//   _bisf, tású_, melr, _faab,
   {{0x61e9c150,0x98a6c199,0x2baa409d,0x6f01c036}},	//   nael, _proć_, _करबा, mulc,
   {{0x2d8503a6,0x4c86527f,0x645c0039,0x68ed4057}},	// [2be0] şler_, глав, pkri, gsad,
   {{0x2bd003ae,0x68fbc05c,0x6e2d031c,0xa5bb0086}},	//   तुशा, irud, _zaab, rdót,
   {{0x6e2d0a6c,0xfba82c13,0xa5bb010d,0x7bdc2789}},	//   _yaab, _गरिम, sdót, mbru,
   {{0x6b7b0916,0x6606042c,0x6299c0eb,0x7bdc1bae}},	//   _טרינ, ngkk, _nkwo, lbru,
   {{0xf8c8c015,0x20c9c015,0x7e760018,0x62966c14}},	//   _mức_, _núi_, _mmyp, moyo,
   {{0xb4c044ae,0xf77280fb,0x6e20c7f2,0x442165be}},	//   ँदी_, یاں_, wemb, ceh_,
   {{0xb8eb86d6,0xd378c97c,0x443e8007,0x60c642c0}},	//   _रू_, paći_, _vnt_, _hukm,
   {{0x6d598036,0x7bc19c6b,0x82a6c051,0x20c9ec15}},	//   bywa, _eglu, ышле, _búi_,
   {{0x127b881b,0x270e803a,0xca758007,0xb927c112}},	//   _נאמע, _məni_, _туры, _ijuọ_,
   {{0x60c66c16,0xb909425d,0x3f14c2f1,0xad1b83bd}},	//   _mukm, _achị_, адос, _אומר,
   {{0x3606c83b,0x26c5ac17,0x7bdc06a9,0x7d02ac18}},	//   _مواف, _gulo_, dbru, luos,
   {{0x21b5011b,0xb5fb4b01,0xbfa7c051,0x32068d45}},	//   ийня, _alán, ытые_, ngoy_,
   {{0x7d028007,0x4a7bc009,0x69c2c0fc,0x290216de}},	//   nuos, _אראב, _igoe, guka_,
   {{0x69ba4036,0x62844036,0x3e67409d,0x5334c951}},	//   ्शनी, enio, _mõte_, _вект,
   {{0x634ac03a,0x6d598036,0x44214147,0x316b1a03}},	//   kəni, zywa, veh_, szcz_,
   {{0xddcd6c19,0x2bdd43a8,0x61e648ae,0x1fdd4632}},	//   snaž, यर्थ, _cekl, यर्ड,
   {{0x634ac435,0x442ee71f,0x62838669,0x229c8047}},	// [2bf0] dəni, _kaf_, énom, níku_,
   {{0x3ea04915,0x9f430047,0x3a3f80b0,0x61e640a8}},	//   alit_, lají_, _snup_, _eekl,
   {{0x44231048,0x3ea06c1a,0x7c2e6c1b,0x61e9c2c0}},	//   mej_, blit_, _dabr, yael,
   {{0x6d598064,0xcf9841bd,0xeb97c009,0x32068c47}},	//   tywa, ују_, נדאר_, ggoy_,
   {{0x61459854,0x9f4781aa,0x2d80c166,0x9f4582a4}},	//   рела, mané_, _žien_, _gelê_,
   {{0x2c146851,0x5fcf96c0,0x9f4781aa,0x61e9c150}},	//   न्दू_, _स्खल, lané_, wael,
   {{0x270e803a,0x9f430047,0x290f8247,0x7c21d9bf}},	//   _yəni_, kají_, stga_, velr,
   {{0x2baa529c,0x2902201d,0x764d6c1c,0x9f47ac1d}},	//   _करता, yuka_, njay, nané_,
   {{0xe664908b,0x0d6780c5,0xe40a0080,0x7bdc0b44}},	//   _утро, _съвм, _çiçə, ybru,
   {{0x69c2ce07,0x61ebac1e,0x9f47ac1d,0x29021ee6}},	//   _egoe, lagl, hané_, vuka_,
   {{0xfe46004c,0x2005c0c5,0x3ebf805c,0xae0a0028}},	//   анно, rgli_, _kiut_, _वादन_,
   {{0xb5fb41b4,0x37e20079,0x67b88183,0xcb1240c3}},	//   _slán, _বাইর, _صالح_, חלט_,
   {{0x8c45d924,0xd378c0ab,0x764d442c,0x7bdc0b44}},	//   _веле, daću_, djay, tbru,
   {{0x05a8c11b,0x3ebf805c,0x270e803a,0x7c23ac1f}},	//   _свій_, _liut_, _səni_, nenr,
   {{0xddcd0f3e,0x60c66c20,0xf66a071d,0x7ea5c10b}},	//   _ulaş, _sukm, _لحظه_, nópo,
   {{0x7e7bc12d,0x6aad2c21,0x3f8c0283,0x21298166}},	//   niup, _ghaf, ħdu_, ťahy_,

   {{0x61ebac22,0x249a005c,0x62844c38,0x60b64032}},	// [2c00] dagl, _tkpm_, rnio, لمرئ,
   {{0x6aa4c1b7,0x7c2e41c8,0x60c6441b,0xe45f4041}},	//   ċifi, _qabr, _vukm, _stör_,
   {{0x212b431d,0x634ac03a,0xf7460a49,0xd378c41b}},	//   _esch_, təni, _тено, baću_,
   {{0xeabf45f5,0x7d02ac23,0x61eb85f5,0x68e42c24}},	//   _giù_, tuos, gagl, _kwid,
   {{0xf99243be,0x2fd14011,0x634ac080,0x93bcc0b4}},	//   _ذبح_, _ffzg_, rəni, ndăr,
   {{0x5c73811b,0x18738589,0x68e406f3,0xb60280a0}},	//   оліт, огія, _mwid, _řádk,
   {{0x3266d61d,0x7d02959b,0xdc21c1d6,0x368ad64d}},	//   итив, suos, _eċċi, ксин_,
   {{0xd5768d9b,0xddcd041b,0x442eec25,0x64418663}},	//   _кузь, _omaš, _saf_, _enli,
   {{0x7d028157,0xdb240086,0x81e8c02a,0x27e7ca87}},	//   quos, _ósæm, _বাদ_, _benn_,
   {{0x6738c0b3,0x6e2440fa,0xb5fb402e,0xe806c048}},	//   _prvj, heib, _alál, _शाळा_,
   {{0xe807417e,0x4ea725b0,0x656d40f6,0xd43742a6}},	//   शलता_, ирма, zzah, בריק_,
   {{0x6d5bc022,0x4b7b8052,0xddc2c56e,0x26c7c127}},	//   byua, _באבו, _hmož, _duno_,
   {{0xac18c06f,0xd378c7ca,0xe4d4c973,0x4fc700c5}},	//   _болу_, vaću_, _اقتد, исва,
   {{0xdc08c017,0x62862c26,0x27e7e76b,0x69c40140}},	//   _rēķi, anko, _genn_, _egie,
   {{0xee87004c,0x2c1608b8,0x4df88260,0xf0b4011b}},	//   _выпо, द्धं_, ुलाई_, ійсь,
   {{0x8f9bc093,0xf99f43bc,0x656d40cb,0x9f458141}},	//   _שיהי, _pyè_, tzah, _delè_,
   {{0xa2cae7bb,0x61ebac27,0x611a803f,0xe9df2c28}},	// [2c10] _सूत्, vagl, nālā, mbú_,
   {{0x6f038530,0x7e7d2c29,0x38a98443,0x80dd002a}},	//   yunc, lisp, kúra_, _বিপ্,
   {{0x7bc52c2a,0x26c7e47d,0xbebcc017,0x7c238206}},	//   _ighu, _xuno_, _drīz, venr,
   {{0x3d074045,0x200c817b,0x7c238010,0xfe70801c}},	//   िंदे_, _acdi_, wenr, ودن_,
   {{0xa5da0009,0x7c2388cd,0x26088a3c,0xa194431e}},	//   אַצי, tenr, _हारी_, _маюч,
   {{0xbcfb0107,0x2bcb4887,0x2409822b,0x3ce48049}},	//   lzés, _шумо_, унки_, _dwmv_,
   {{0x443140fc,0x998696fd,0x62860036,0x660d2c2b}},	//   _iaz_, rdoš_, ynko, _ocak,
   {{0xc245cdef,0x3209616b,0x2904c17b,0x2d8d8022}},	//   сник, ngay_, fuma_, _txee_,
   {{0x225fd20e,0x6f0540b3,0xe939c2cf,0x7c238372}},	//   rkuk_, luhc, اسبت_, penr,
   {{0x224dc514,0x6d5d2c2c,0x2a66c0b3,0x660d007a}},	//   sjek_, dysa, _elob_, _acak,
   {{0x44316c2d,0xe8194e1a,0x27e7c11b,0x24982c2e}},	//   _maz_, न्या_, _venn_, vorm_,
   {{0x201a005c,0x628600fc,0x7688006a,0x61ed6c2f}},	//   _sbpi_, unko, rıyo, jaal,
   {{0x60c18007,0x2904ec30,0x7c2540cb,0x62862911}},	//   _kilm, cuma_, kehr, rnko,
   {{0xc0b2c015,0x768803a6,0x7529ec31,0x44316c32}},	//   _mười_, pıyo, mwez, _naz_,
   {{0xcaa641b4,0x61ed6c33,0x2608809d,0xe79ac047}},	//   مصري, faal, _हाली_, _těší,
   {{0x68e400f6,0x61e9ac34,0x2c13c063,0xe9f900d1}},	//   _twid, _neel, त्रं_, _khẽ_,
   {{0x291f804d,0xceb4403a,0xa3e7915e,0x614352de}},	// [2c20] _npua_, rmə_, परा_, пета,
   {{0x2a6040b0,0x7c2540cb,0x9f45c089,0x9f47c43e}},	//   skib_, gehr, halí_, _renê_,
   {{0xb113c25d,0x29126c35,0x9f458107,0xc5f44079}},	//   _bụkw, stya_, _felé_, ঙ্গা_,
   {{0x7d04594b,0x61ed41c8,0x7529c0f7,0x7c3b40e2}},	//   puis, caal, kwez, _ɗuri,
   {{0x753bac36,0x6443c04c,0x86374093,0x2baa4ef0}},	//   _cruz, _onni, _הרכב_, _करवा,
   {{0x60c18057,0x200a2c37,0x22920066,0x60c9823f}},	//   _cilm, ngbi_, ráky_, _duem,
   {{0xb5fb4031,0xb7db02a6,0xf487808c,0x7e79c0c4}},	//   _amáy, אקצי, حانی, _bmwp,
   {{0xb113c112,0xb5fb4171,0xa2c548b8,0x673a8043}},	//   _gụkw, _aláj, िदर्, _vrtj,
   {{0x753b9754,0x6d46ac38,0xc0e387bc,0xa3d80dc7}},	//   _gruz, _škaf, _нотк, ाडा_,
   {{0x76442c39,0x7e62ac3a,0x26ca40f7,0x61ed431c}},	//   _aniy, lkop, _kubo_, zaal,
   {{0x2904cd80,0x2129405c,0x9f45c070,0xab968032}},	//   suma_, zwah_, balí_, _الضغ,
   {{0xbddb4396,0xaa672471,0x61e981c8,0x2bd480aa}},	//   _anèn, сток, _xeel, ठुरा,
   {{0x61ed6c3b,0x2e37c0c3,0x2c6b84f5,0x63ad80e2}},	//   vaal, _לראש_, _fødd_, ƙanc,
   {{0x29006c3c,0x76441f18,0x61ed6c3d,0x656f0064}},	//   dria_, _eniy, waal, rzch,
   {{0x447bc0c3,0x9f4581ff,0x9c17c0c3,0x45d64112}},	//   _תנוע, _pelé_, _החוק_, _ọpụ_,
   {{0x29006c3e,0x38c940fb,0x7c2540cb,0x27ff0189}},	//   fria_, لائی_, wehr, şun_,
   {{0xbcfb005f,0x90554aba,0x463bc009,0xdb1c4016}},	// [2c30] rzés, овац, נעמע, _agrà,
   {{0x6299ac3f,0xba3d8047,0xe78713e4,0x91d96c40}},	//   wowo, _lhůt, _гумо, _फ्रै,
   {{0x0ec48b6d,0x99d781b4,0xfbab4026,0x44316c41}},	//   _लंगड, متشا, утай_, _vaz_,
   {{0x7e628c05,0x2c6b8065,0xf8c8c891,0xadfb27bb}},	//   gkop, _møde_, रदाय, ्लिन_,
   {{0x61e9ac42,0x4425ec43,0x212b01f4,0x62584032}},	//   _veel, yel_, nwch_, _tíor,
   {{0xb4db4031,0x26c24e1d,0xd3788011,0x351c00c3}},	//   _aràg, _ziko_, _leću_, טודנ,
   {{0x6609c4e1,0x61e9ac44,0xb4db4061,0x4dfb00e4}},	//   tgek, _teel, _bràg, ्लाई_,
   {{0x60dbec45,0x64570004,0x7e62ac46,0x6b7c021d}},	//   tpum, _loxi, ckop, טרונ,
   {{0xb5fb4083,0x2bdac8c5,0xb4db4061,0x60c9809d}},	//   _alák, _म्हा, _dràg, _uuem,
   {{0x63a18036,0x9f478c81,0x4425db39,0x2c6b80b0}},	//   _tyln, laní_, uel_, _bøde_,
   {{0xdb1f804c,0x6e260107,0xddc0806a,0x661d6c47}},	//   äväs, tekb, _komş, _obsk,
   {{0x2c6b927d,0xe8196c48,0x76560033,0x60dbc73b}},	//   _døde_, न्ता_, _qoyy, ppum,
   {{0x1c1e8036,0x9f47c1cb,0x7e698303,0x6e260107}},	//   _मॉडल_, _mené_, _mlep, rekb,
   {{0x81c1402a,0x2c6b87fb,0xb92700eb,0x7e6288f1}},	//   ুরা_, _føde_, letị_, zkop,
   {{0xa09ac052,0x42564ba0,0x61ebec49,0xbcfb0107}},	//   _דיסט, отат, _kegl, gyéb,
   {{0x7bd540a8,0x7e6d6c4a,0xaaa880b2,0x61ebec4b}},	//   _afzu, ghap, _छींक, _jegl,
   {{0xeac9c00c,0x394dec0a,0x44332c4c,0xa50a44c4}},	// [2c40] _kẹo_, nxes_, _fax_, реза_,
   {{0x60c3c09c,0xc4860ab2,0xa3eb1a7e,0xa3d30027}},	//   _jinm, _флок, मरण_, हुआ_,
   {{0x26c26c4d,0xd6cf4a2c,0x7e6d40f7,0x60c3ec4e}},	//   _tiko_, نقل_, bhap, _minm,
   {{0x6289c0ab,0xd9465e9b,0x61ebc193,0x290201c8}},	//   jneo, _деми, _negl, orka_,
   {{0x28c341e7,0xbc4a81bd,0x1c05854a,0x9f47c396}},	//   _वंचि, ичке_, _राखल_, _dené_,
   {{0x395fc02f,0x649a9654,0x653b0052,0x61ebc09d}},	//   dyus_, штер_, יענד, _aegl,
   {{0x60cbc649,0x9f4cc6a6,0x7d166b4a,0x61ef0561}},	//   _augm, radë_, ltys, yacl,
   {{0x27ee810d,0x20008119,0x7bc740fd,0x7e698231}},	//   safn_, şii_, _zgju, _glep,
   {{0xc7b8c0b3,0xf8af405f,0xf98fc05f,0xbe138183}},	//   međi_, _سکے_, ہبی_, _توقع,
   {{0x3ea6ac4f,0x61e28655,0x60c3e579,0x62839865}},	//   llot_, lbol, _cinm, énov,
   {{0x3ea00340,0x44332c50,0xe3b8c06a,0x29022c51}},	//   _bkit_, _rax_, ldız_, erka_,
   {{0x61ebec52,0x3ea0021b,0x63a3c02c,0x2902009c}},	//   _gegl, _ckit_, _dynn, frka_,
   {{0x5d850a2c,0x2246c140,0x6ecac0b2,0xa25b443e}},	//   سلسل, _inok_, _सूरु, _biôn,
   {{0x20d080d1,0x3de7402a,0xd7c90032,0xfb86c119}},	//   _mài_, _ফাইল, صوره_, _мыйн,
   {{0x7c28c02c,0x7e6d6c53,0x6458c157,0xdcc8c0d1}},	//   medr, thap, _iovi, _mỉm_,
   {{0x44f507d9,0x44330db2,0x63a780b0,0xc7b8c011}},	//   _епис, _wax_, _øjne, jeđi_,
   {{0x443300c3,0x3ea6ac54,0x20d0835d,0x661d6c55}},	// [2c50] _tax_, dlot_, _nài_, _vbsk,
   {{0x2a6dc639,0xa3a741bd,0xc8a9817e,0x2c60c0b6}},	//   zheb_, ојек, _चींट, _bòdi_,
   {{0x61ed012d,0x26ccac56,0x60cd2c57,0xf429c051}},	//   _keal, _nudo_, _huam, lmää_,
   {{0x60cd04fd,0xf1af0285,0x2a6dec58,0x98a00123}},	//   _kuam, _घरान, xheb_, _psić_,
   {{0x6d4b44d3,0x7127879e,0x60cd2c59,0xa3cac185}},	//   ågad, ترال, _juam, लखा_,
   {{0xd5e2c031,0x2bdac0aa,0x61e2ac5a,0xdced4089}},	//   _alò, _म्ला, abol, nzač,
   {{0x9a87823d,0x25a9c618,0xad9b4032,0x7c28c51f}},	//   _дуал, _šal_, _gcúr, dedr,
   {{0x98afc0e0,0xdb1c405f,0x7e7bac5b,0x28af4036}},	//   đače_, _ugrá, _umup, _जीति,
   {{0xb5fb2c5c,0x61ebec5d,0x9f584053,0x6560c02c}},	//   tkán, _vegl, _adrè_, gymh,
   {{0x394dec5e,0x9f4a68df,0x3dc91b85,0x61ebd8d0}},	//   rxes_, _bebè_, _agaw_, _wegl,
   {{0xb5fb4070,0xbddb4060,0xdced402d,0xfaa617dd}},	//   _tláh, _anèm, dzač, зано,
   {{0x628bac5f,0x66d780eb,0x7d164051,0xce38c032}},	//   nngo, _ụkwa, ytys, _وأنا_,
   {{0x61ed2c60,0x29020057,0x628bac61,0x6458c070}},	//   _deal, urka_, ingo, _fovi,
   {{0x63a3ec62,0x200cc05c,0x09a98036,0x9f47801f}},	//   _tynn, cgdi_, _औरैय, canã_,
   {{0xbbaa41b6,0x7d09ec63,0x61e28888,0xf7431884}},	//   _करेक, lues, ybol, неро,
   {{0x6446c03f,0x69c9ac64,0x786f86a9,0xe81b957c}},	//   ēkie, _ngee, _høvd, प्ता_,
   {{0xb4db4060,0x60db89dc,0x61e293f6,0x6458c0c7}},	// [2c60] _aràb, _ntum, vbol, _yovi,
   {{0xd3e402cf,0xeb9a443e,0x61ed12e9,0x7659ec65}},	//   _تقدی, биз_, _zeal, _lowy,
   {{0x20d08015,0x7d166c66,0x248640e0,0x213f888b}},	//   _sài_, stys, đom_, _aruh_,
   {{0x213f80b3,0x7d09c0da,0x2ab2005f,0x60cd0022}},	//   _bruh_, kues, lább_, _yuam,
   {{0x7d09c0fd,0x6e362c67,0x63a6c036,0x6d468123}},	//   jues, _mayb, ękni, _škab,
   {{0x213f805b,0x61fbac68,0x644747ca,0x628b8bfd}},	//   _druh_, _edul, _gnji, ango,
   {{0x629d254a,0xd9b902c8,0xd6d7909b,0x25c1c03a}},	//   yoso, _इण्ट, пты_, ərlə_,
   {{0x78700041,0x786b003a,0xb17b0240,0x38b444c9}},	//   _hävd, _müva, dbån, färg_,
   {{0x9f45c066,0xb5fdc017,0x6282873b,0xf64fc032}},	//   valá_, ukša, mioo, ائى_,
   {{0x61e4413a,0x9873c051,0xdfcf8032,0x25dc4048}},	//   hbil, ельц, _ميك_, गुती_,
   {{0x7d044057,0x75240070,0x7bdb80c3,0x2fd7801c}},	//   hris, _apiz, _הקבו, _روند_,
   {{0xad9b4004,0x39401bd6,0x7c28ec69,0xbddb43e2}},	//   _ocúp, _bris_, sedr, _enèj,
   {{0xe534c20d,0x442a015a,0xfd470039,0x386c80a0}},	//   _цель, feb_, чэнн, _kldr_,
   {{0x7c388a26,0x55bbc4e0,0xa3cc8314,0xd9180051}},	//   ndvr, _המדו, रखि_, чью_,
   {{0xec37c0c3,0x26c6c12c,0x15da425d,0xc5da4112}},	//   _מאגר_, _kioo_, _ọbụl, _ọrụb,
   {{0x39400101,0x7af50036,0x64488006,0xdb03c066}},	//   _fris_, rszt, _lndi, _uzná,
   {{0x7e6d2c6a,0x442a2c6b,0x823403a9,0x7c2a8b9a}},	// [2c70] _ilap, beb_, _سريا, kefr,
   {{0x7e6d1615,0x442a0149,0xb905409d,0xdb1c44c9}},	//   _hlap, ceb_, _नऽ_, _ogrä,
   {{0xaca4c0eb,0x7d09c0fd,0xb4db4321,0xde5940d9}},	//   _ngọz, zues, _bràc, _дані_,
   {{0x37e68079,0x628ba69f,0xb5fdc017,0xaacfc5da}},	//   _নাগর, ungo, ekšn, _संसक,
   {{0x20d3017e,0x3ea94041,0x7d09c0fd,0x9f434070}},	//   _धूमध, mlat_, xues, _dejá_,
   {{0x01380093,0x6e29c31c,0x998ddbee,0xc7a5811b}},	//   פרות_, weeb, jdeš_, милк,
   {{0x22492c6c,0x1dda4285,0x2a668340,0xdce44036}},	//   _onak_, युवत, bkob_, dzię,
   {{0x32d18015,0x61ef6c6d,0xae148027,0x7bcac05e}},	//   _váy_, _jecl, _डायन_, _agfu,
   {{0x61e4830d,0xb5fb401f,0x29192c6e,0xbddb40b6}},	//   ñile, _fláv, jtsa_, _anèk,
   {{0x61ef6c6f,0xb5fb0686,0x27eec1f4,0x290b029d}},	//   _lecl, skál, _cefn_, duca_,
   {{0xa22a2328,0x0403402a,0x04ffc02a,0x661d2c70}},	//   ожна_, র্থী_, ্বের_, ffsk,
   {{0x2a6d8033,0x290b00b3,0x1fc50079,0xd04d2c71}},	//   _jleb_, fuca_, ্রাস, _kwaɗ,
   {{0x6448a7a6,0x57aa4314,0x629f40fd,0x61e44854}},	//   _yndi, _कर्ह, doqo, vbil,
   {{0x60c4c3bb,0x3f69cdce,0xb5fb0107,0x2918c0b4}},	//   _éimp, _мило_, nkáj, ărat_,
   {{0x4f952c72,0x8fa311cd,0x442101a8,0x26cec0c4}},	//   ерту, варе, _dbh_, _gufo_,
   {{0x7e6d2c73,0x7649840d,0x765b83e2,0xe81f0047}},	//   _glap, _nney, _nouy, म्बा_,
   {{0x44210033,0x61ef6397,0xd838cf47,0x38b440cb}},	// [2c80] _fbh_, _decl, loča_, häre_,
   {{0x6562812c,0x26cec0e2,0x7ebf0007,0x69a24048}},	//   vyoh, _yufo_, _rūpi, _कुणी,
   {{0xee3a8bf8,0x69d9c15d,0x68e4c283,0xdb240051}},	//   жне_, _ofwe, _ħidm, äräs,
   {{0x64489eb5,0x26dc403f,0x2249021b,0x05aa8156}},	//   _sndi, īvo_, _xnak_, овей_,
   {{0xddc2c077,0xaac5801c,0x7c2a90a0,0xbdfb416a}},	//   _ološ, رتمن, tefr, _برپا_,
   {{0x656281c6,0xd467ac74,0x645a8e05,0x764987f2}},	//   ryoh, миче_, _qoti, _eney,
   {{0x7d0b8007,0x32d3c0d1,0x65645cc3,0xb87b4086}},	//   augs, _nãy_, lyih, _stíg,
   {{0xa534c00e,0x9f458669,0x786f98ac,0xc2438156}},	//   енич, _delà_, _røve, _инск,
   {{0x6280aa31,0x65644057,0xd71a0079,0x5c06c1a4}},	//   _immo, nyih, ডিয়া_, мяна,
   {{0x69cbca9f,0x22491a4f,0x2bc78374,0x6c8682cf}},	//   _egge, _snak_, _ललचा, _غلام,
   {{0xda0a03b0,0x25b21466,0x22490303,0x78bac7fb}},	//   वलंत_, _azyl_, _pnak_, rmtv,
   {{0x60c881d6,0x7864c0d2,0x787240b0,0x625cc1cb}},	//   _hidm, _mòvi, _hævd, _géop,
   {{0x8d73c1e3,0x394d0fc2,0x6e22cc66,0x39424125}},	//   _لاوا, ães_, _ibob, _nrks_,
   {{0x291927a0,0x9f430166,0xf77301aa,0x961dc017}},	//   rtsa_, majú_, ناز_, miņa,
   {{0xf2c7423d,0x628080f6,0x7e6d1312,0x290b0123}},	//   дсан, _ommo, _tlap, suca_,
   {{0x38a40041,0x44386c75,0xe5c700a9,0xd8388053}},	//   förs_, _aar_, _оспо, _chčz_,
   {{0x60c74570,0x38a42c76,0x9f43002d,0x865bc0c3}},	// [2c90] _pijm, görs_, najú_, קדמי,
   {{0x44384d3d,0xe616406c,0xb5fdc017,0x473504c5}},	//   _car_, čišč, ekšl, _знос,
   {{0x20138016,0x9f430931,0xb5fb6c77,0x6e22ec78}},	//   òxim_, hajú_, _blát, _obob,
   {{0x9f430166,0x22990066,0x0ea74027,0x6d42c041}},	//   kajú_, téky_, _कीचड, _oroa,
   {{0x442cec79,0xf1a50285,0x443862a5,0x6e2d4019}},	//   ked_, _गुमन, _far_, meab,
   {{0x7c38ec7a,0x9f430166,0x20112c7b,0x6e2d4311}},	//   _navr, dajú_, ngzi_, leab,
   {{0xb5fb4a5d,0x46a5cc21,0x63a8802c,0x7c3ac621}},	//   _coág, накв, _cydn, ddtr,
   {{0x68ed2c7c,0x69cd01b4,0xdd01c0b3,0x6d42ec7d}},	//   _owad, _ngae, žučk, _broa,
   {{0x442cec7e,0x2bc34b6d,0xb5fb4066,0x79a78748}},	//   fed_, _वृता, _hlás, _црве,
   {{0x442cec7f,0x3ea04033,0x7c38e1a3,0x70cb88c4}},	//   ged_, zoit_, _cavr, ादील,
   {{0xe28602d2,0x4423405c,0x38b60240,0x53a38036}},	//   елни, _mbj_, nære_, _ओडिश,
   {{0x6e22c02e,0x9f43271b,0x26d16c80,0x442cc0b2}},	//   _gbob, bajú_, _muzo_, aed_,
   {{0x442cec81,0x7e69c086,0x3ea05680,0x7c38d6dc}},	//   bed_, mkep, voit_, _favr,
   {{0xa06a0039,0x7e69c240,0x7d0d405c,0x7ea5c10d}},	//   чага_, lkep, duas, rópu,
   {{0xad9b0004,0x3ea05664,0x25a9017b,0xd5b740d1}},	//   ugúr, toit_, _eyal_, ếng_,
   {{0xda0a008f,0x645c6c82,0x6e2d6c83,0x7d0d4150}},	//   _वाटत_, _sori, geab, fuas,
   {{0x3ea06c84,0x765d6c85,0x7d0d56f3,0xb5fb4171}},	// [2ca0] roit_, _dosy, guas, _alás,
   {{0xfe0d83af,0x9f4cc5e5,0xf0a740b4,0x4438414e}},	//   _हाउस_, zadí_, екул_, _qar_,
   {{0x9f430166,0x961dc03f,0x7d1bc09d,0xb5fdc017}},	//   zajú_, ziņa, htus, ekšm,
   {{0x44386c86,0x6e39c022,0x6e3bc38f,0xe1f288a7}},	//   _war_, _nawb, jdub, اسا_,
   {{0xd83892b8,0xaca44044,0xb5fb45c5,0x442cc15c}},	//   _pač_, _arụs, _elás, yed_,
   {{0x442cc093,0x68fb001f,0x2c864031,0x764bec87}},	//   xed_, áudi, _dídè_, _angy,
   {{0x6e24025d,0xa3b40048,0x68fb840d,0x68e46c88}},	//   _obib, जेच_, _evud, lpid,
   {{0xdbc7054a,0x61f66c89,0x62808360,0x62862c8a}},	//   _töök, nayl, _ummo, jiko,
   {{0x645e06f1,0x85068425,0x6e39c0b6,0x7c2e0c72}},	//   _oopi, _سوان, _dawb, kebr,
   {{0xd250c4e8,0x6e242c8b,0xb97b4093,0x92cb002a}},	//   انک_, _abib, פניי, রীয়_,
   {{0xdb1c4004,0x25a9007a,0xdfcf8d9e,0x201ec10d}},	//   _agrú, _syal_, _ايم_, rfti_,
   {{0x7860403a,0x443a01b0,0x6458ab59,0xaca30112}},	//   _mövq, _aap_, ljvi, _mmụg,
   {{0x63a481df,0x2bdd8047,0x7ea5c018,0x765d42a8}},	//   şind, नुवा, rópt, _rosy,
   {{0x69dcc064,0x6e242b20,0x7c3a8b94,0x648900b3}},	//   śred, _ebib, _jatr, džic,
   {{0x3a3940b3,0x6d4414d3,0x27e0c00c,0xe0df423f}},	//   _pasp_, _eria, _đinh_, _stò_,
   {{0x7bdc6c8c,0x6286114e,0x7afac402,0x32c7402c}},	//   _afru, ciko, mstt, _gŵyl_,
   {{0x9f4a4070,0x2a696c8d,0x26d1409c,0x6d468eae}},	// [2cb0] _debí_, rkab_, _suzo_, _škan,
   {{0x21290033,0x38b60240,0x442e80d9,0x2497005f}},	//   _ipah_, tære_, jef_, _سمجھ_,
   {{0x9f4cc016,0x6d440166,0x7d0d4230,0x6d44c02d}},	//   nadà_, _zria, suas, _šial,
   {{0xb87b4031,0x61f641c8,0x61cb88bc,0xd7f1800c}},	//   _awít, cayl, िशेष, _sẽ_,
   {{0xddec0009,0x0ccb8c5c,0x764d012c,0x7d1d0c4b}},	//   פֿאָ, ादेम, _mnay, ntss,
   {{0x80074d4c,0x7d1d10a0,0xaca38112,0xc4d40052}},	//   _ячме, itss, kwụb, אגס_,
   {{0x394480d2,0x7afac0a8,0x7c25005e,0xa695c16f}},	//   _erms_, jstt, _mbhr, криј,
   {{0x7bdac0b4,0xf165002e,0x26d3184b,0xbf218027}},	//   ectu, _ayọ̀_, _muxo_, _महीन_,
   {{0x6e3bcafc,0x26cb66f9,0x58d5811b,0xdd94a4b4}},	//   rdub, _mico_, _розт, _баты,
   {{0x7886c01e,0x62862c8e,0x3ea6ec8f,0xf771c032}},	//   _révè, wiko, _ekot_, لاج_,
   {{0x63aac0de,0x21290033,0x225f80f8,0x38b44041}},	//   _cyfn, _apah_, _kouk_, nära_,
   {{0x7d1bec90,0xf772c08c,0x6e3b8140,0x7c250b87}},	//   ptus, شاپ_, _jaub, _abhr,
   {{0x7c3a8396,0x6e3bac91,0x290dc2b0,0x7c2e2c92}},	//   _yatr, _maub, quea_, tebr,
   {{0xcd76c052,0x764d07f2,0x61e9ec93,0x3d09ac94}},	//   _בענק_, _enay, lbel, _सिने_,
   {{0x2c7404d3,0x4425810d,0x03a607dc,0x6aa6405c}},	//   _rädd_, _mbl_, тиво, _pkkf,
   {{0x61e9c8cd,0x7c2e2c95,0x442ea58e,0x6d442c96}},	//   nbel, sebr, zef_, _tria,
   {{0x61e9c0f8,0x61f64526,0x442e809c,0x290fac97}},	// [2cc0] ibel, rayl, yef_, juga_,
   {{0x20040007,0x1f660fdf,0x9f4cc02d,0xdddbc013}},	//   ėmis_, _аком, ladá_, jnuž,
   {{0x68e46c98,0x7c3a8472,0x39ea44df,0x225f83e2}},	//   spid, _ratr, _одно_, _bouk_,
   {{0xfce68f1e,0x68e45ad3,0x61e9ec99,0x7afa0086}},	//   водо, ppid, jbel, áttu,
   {{0x7d09c0b0,0x6e3bac9a,0x2b45899e,0x9f4e80d2}},	//   jres, _daub, _arlc_, rafí_,
   {{0xdc08c03f,0xa7fc81df,0x6728805c,0x3a248010}},	//   _mēģi, _alır, _ppdj, _wbmp_,
   {{0x6d4640ab,0x229c8066,0x7afc441b,0x7d09d29b}},	//   _hrka, zíky_, _uvrt, eres,
   {{0x8c3cc38a,0x7c3c6390,0x3eadcdaf,0x2c70802e}},	//   doğa, _harr, glet_, _dàda_,
   {{0x44258498,0x442e823f,0x68fbd038,0x27e0c020}},	//   _fbl_, pef_, gsud, _ƙin_,
   {{0x25e2c028,0x4734d6f6,0x6e3bac9b,0x3eadec9c}},	//   _ट्री_, гнос, _zaub, alet_,
   {{0xa5bb4031,0xe7bd0079,0x27f8002c,0x64a3c01b}},	//   _aból, _অভ্য, darn_, раќа,
   {{0x6b7b8087,0xf76fcd72,0x26c0413f,0x7d1d0b11}},	//   _קראנ, تاً_, jmio_, ttss,
   {{0x27f8002c,0x29041361,0x6602ec9d,0x588713fa}},	//   farn_, šman_, _idok, выва,
   {{0x3e75411b,0xb5fb4171,0x27f82c9e,0x2584c017}},	//   _måte_, _aláp, garn_, rīlī_,
   {{0x6d466c9f,0xdef80156,0x3ce2414b,0x7e60aca0}},	//   _arka, кыт_, _atkv_, _oomp,
   {{0x2a600033,0x6d4640ab,0xa2cb0314,0x290faca1}},	//   _goib_, _brka, _सूच्, yuga_,
   {{0x6d4645c7,0x961dc03f,0x7c3c66f8,0xa5bb455d}},	// [2cd0] _crka, ziņo, _barr, _gból,
   {{0x6d466aa2,0x224da518,0x1a6581aa,0x2909551f}},	//   _drka, _snek_, گیری_, rraa_,
   {{0xb5fd8aa2,0x6d466ca2,0x6e3baca3,0x68fbc066}},	//   _loše, _erka, _paub, zsud,
   {{0x69dd005f,0x644e645a,0x7d09d27d,0x290faca4}},	//   ncse, _enbi, yres, tuga_,
   {{0x38b9c669,0x93c9005f,0x867c00c3,0x63a909bb}},	//   lère_, _تاکہ_, וראו, ƙens,
   {{0x7e6d6ca5,0x6602c8d7,0x7d09eca6,0xfc6441bc}},	//   lkap, _adok, vres, _късн,
   {{0x68e2c1f4,0x3ec780d7,0x291daca7,0x59a749fd}},	//   _atod, _асаб, stwa_, _कुतर,
   {{0x7c3c6ca8,0x7e60899e,0x68fbd00f,0xc1e316ca}},	//   _zarr, _gomp, tsud, _क्लब_,
   {{0x38b9c01e,0xaca34112,0x2d99c0fd,0xc0ab83be}},	//   hère_, _nrịb, çse_, _قائل_,
   {{0xd259803f,0x6602c044,0x68fbcba1,0x62840755}},	//   _viņu_, _edok, rsud, _smio,
   {{0xf7708200,0xba3b2ca9,0xf771c20c,0x61e9d7f1}},	//   _وام_, roïn, صاد_, pbel,
   {{0x6d034f76,0x9916031e,0x2d9e158d,0x38b444c9}},	//   _लिंग_, льгі, ştem_, järn_,
   {{0x69dac009,0xa683031e,0xfbc34185,0x224fc88b}},	//   _אַוו, сляд, वेतम, _ingk_,
   {{0xe73a0051,0x61f98d8c,0x6602c066,0x764f6caa}},	//   нег_, hawl, _zdok, _ancy,
   {{0x291fc04c,0x38b9c669,0xab2712de,0x3e6ac5ef}},	//   ltua_, gère_, лора_, _bùth_,
   {{0x26c04158,0xa3dfc9d5,0x69dd0107,0x443cc247}},	//   umio_, धुर_, ccse, _zav_,
   {{0x44312cab,0x6e3d4033,0x261bc103,0x6146159d}},	// [2ce0] bez_, _dasb, _यानी_, _сепа,
   {{0x9f4c8066,0xb4634c9d,0x6e3d45ef,0x9f58013b}},	//   _sedí_, бкул, _easb, narë_,
   {{0x645cc09d,0x7f864d9e,0xa5bb2cac,0x291fc051}},	//   örii, دلان, leóp, htua_,
   {{0x7c3c6cad,0x20d98303,0xb5fb00a0,0xc60b002a}},	//   _warr, _bèi_, skáv, ষ্ঠা_,
   {{0x0d834099,0x58868026,0xbddb4580,0x6d466a1f}},	//   _глян, лыка, _enès, _urka,
   {{0x398ac54a,0x22405929,0x20d980c4,0x6e244655}},	//   _हs_, ldik_, _dèi_, lfib,
   {{0x68e2ecae,0x25ad8303,0xbddb4060,0xfbb84d91}},	//   _stod, _eyel_, _inèr, _अरिम,
   {{0xfaa6921f,0x6f9341b4,0x68e402bc,0xb5fd8ac0}},	//   _сабо, _الفض, _otid, _poše,
   {{0xdd94c026,0xa2a18d20,0xd9438800,0x2ca5ecaf}},	//   рапы, गकर्, _лети, fold_,
   {{0x19b980d5,0x443ec4f1,0x44312cb0,0x7e6d4d80}},	//   _русь_, udt_, xez_, zkap,
   {{0x628642aa,0x2ba40578,0xa2e68409,0x291fc1a8}},	//   _omko, _खुला, _соед, atua_,
   {{0x3ea68101,0xb5fd8a93,0x539b82a6,0x291245b6}},	//   noot_, _toše, _איבו, kuya_,
   {{0xa06adffc,0x291fe807,0x9f510066,0x786b009d}},	//   _пада_, ctua_, razí_, _hüvi,
   {{0x60d60165,0xe0df429a,0x38b9c694,0xfd1f00c4}},	//   _duym, _bròn_, tère_, rtì_,
   {{0x7e6d6cb1,0x05a50374,0x3ea6acb2,0x7bdbc0c3}},	//   tkap, _गुरब, koot_, _אקוו,
   {{0x7640ecb3,0x6e3d5ec0,0x38bb814b,0x539bc0c3}},	//   ndmy, _qasb, mêre_, _ריהו,
   {{0x7c87074d,0x38bb814b,0x5d554b24,0x38b9c1cb}},	// [2cf0] _буне, lêre_, шкат, sère_,
   {{0x9ed9095c,0x7e62c361,0x8c08402a,0xd0110246}},	//   _имот_, _loop, র্সন_, _بلد_,
   {{0x998d0036,0x38bb814b,0x228b002e,0x9f47c060}},	//   żeń_, nêre_, _gòkè_, _venç_,
   {{0x2485821b,0x29126cb4,0x3cfd8022,0xbddb4060}},	//   _smlm_, buya_, tswv_, _enèr,
   {{0xddc99a5b,0xc27c0052,0xe3b88080,0xa3bf00e6}},	//   _bleš, ערדי, _azı_, ेशक_,
   {{0x752d09f3,0x8c4593ec,0x78724329,0xd0068ed5}},	//   _mpaz, реке, _hævn, аеше_,
   {{0x6289d7de,0xc3048032,0xb5fb05ca,0x4427c247}},	//   tieo, مبيو, nkás, _rbn_,
   {{0x60ddc019,0x443e80c3,0x9f4c81ff,0xaab56cb5}},	//   ísmo, _eat_, _sedã_, ंतिक,
   {{0x3949023b,0x7e62ecb6,0xb4c0c3ae,0x443e80c3}},	//   _nras_, _doop, ंगू_, _fat_,
   {{0x6d49acb7,0x753bacb8,0x66040450,0x4f25c31e}},	//   _irea, _isuz, _sdik, адоб,
   {{0xe1ff0064,0x224fc05c,0x6d4f8018,0x3a3facb9}},	//   nków_, _tngk_, _ácab, _kaup_,
   {{0x6146039d,0xa6dec015,0xa96a01bd,0x61ed4066}},	//   аема, _trưn, вима_, jbal,
   {{0x7ae52cba,0xe9cecdce,0x81cb4079,0x6967c01c}},	//   _atht, _фк_, রুত_, _حداق,
   {{0x61fbc8a1,0x4427c21b,0x6d44423f,0x26cfecbb}},	//   laul, _ubn_, vvia, _higo_,
   {{0xe8170e0f,0x26cfd6b4,0x6e244157,0x07d8c032}},	//   _तारा_, _kigo_, tfib, _إذهب_,
   {{0x6d44c039,0x5ed78079,0xe1ff0036,0xc7a3001b}},	//   _šiai, _সবাই, dków_, циск,
   {{0x26cfc070,0x22406cbc,0xa2c30314,0x9f458166}},	// [2d00] _migo_, rdik_, रगर्, _celú_,
   {{0xdb018051,0x61fbe8fc,0x290dc0b4,0xb5fb0e6f}},	//   _kylä, haul, irea_, skát,
   {{0x6441dad1,0xe29a4026,0x26cfc34d,0x5fabc549}},	//   idli, _аан_, _oigo_, _घुमल,
   {{0xe9a64210,0x9f58034d,0x7f8cc052,0x161d4ebe}},	//   _вамп, jaré_, ענאַ, _फायर_,
   {{0x61fbcf7c,0x3ea6acbd,0x6cc68fe8,0x9f43046a}},	//   daul, root_, айда, bajó_,
   {{0x443eacbe,0x2ca780ce,0x7afe405c,0x3eb24051}},	//   _qat_, gond_, pspt, llyt_,
   {{0xd46781bd,0x6d410017,0x290dc709,0xb5fb0107}},	//   рије_, ālai, erea_, rház,
   {{0xd838c06c,0x83fc806f,0xeb97411b,0x44e9c070}},	//   moči_, _dođa, _тис_, _bº_,
   {{0x29006cbf,0x1da5008f,0xb273c761,0xb5aa81b4}},	//   nsia_, _गुंत, ільш, _شارك_,
   {{0xc7c6ecc0,0x69b9408f,0x443e8061,0x2bc3409d}},	//   исни, ्धती, _uat_, वेवा,
   {{0x752d2cc1,0x29006cc2,0x290dc119,0xf8bf0669}},	//   _spaz, hsia_, area_, ntée_,
   {{0x7ebd005f,0x76428f2d,0xe818c14a,0x661b805c}},	//   képe, ndoy, _दावा_, _xcuk,
   {{0xf27bc21d,0xdb03c066,0xe9df14f2,0x7640acc3}},	//   _בראש, _vyná, rcú_, _mamy,
   {{0x628bacc4,0x7d0d6cc5,0x20cf0085,0x442a6cc6}},	//   zigo, vras, _eżin_, _nbb_,
   {{0x38abc7fb,0x29004c4b,0x3eb244f5,0x91fac0e9}},	//   rørt_, esia_, flyt_, _एजाज_,
   {{0x9f45c066,0xb87b4031,0x356b13a4,0x2a6480b6}},	//   nalý_, _etíl, _арон_, _nomb_,
   {{0x66d58007,0x7ebd0107,0x63a900cb,0xdb0740a0}},	// [2d10] _iške, gépe, ßenb, _vyjí,
   {{0x9f5805c5,0xa3aaecc7,0x9c392cc8,0x22402cc9}},	//   zaré_, _खडा_, _спот_, _zaik_,
   {{0x05a75928,0xd838c04f,0x41a749fd,0xeaca00d1}},	//   _कुरब, goči_, _कुरस, _kẹp_,
   {{0xdb1c430d,0x7e55408c,0xb5fdc007,0xdb07c107}},	//   _agró, _انحص, nkšt, ülék,
   {{0x6441ecca,0xd91b8051,0x4ad009fd,0x5fde1890}},	//   ydli, тье_, _संघव, _मलमल,
   {{0x61e2eccb,0xc484831e,0x26d86ccc,0x78a8c043}},	//   _afol, олік, _furo_, jodv,
   {{0x96f85450,0x49170314,0x61fbeccd,0x656d41c8}},	//   _вест_, भूतो_, taul, lyah,
   {{0x83fc8158,0xf8db4275,0x2ca782a4,0x61fd0017}},	//   _vođa, _बढाय, sond_, jasl,
   {{0x9f580560,0x98a90123,0xb4db429a,0xa3c9c4fb}},	//   raré_, _apač_, _brài, लेन_,
   {{0x61fbd60c,0xb4db4321,0x26d8602c,0x7640a407}},	//   saul, _crài, _yuro_, _zamy,
   {{0x07a5e532,0x141a82a6,0x26d84004,0x644180f8}},	//   санн, _תועב, _xuro_, _iali,
   {{0xb87b63a5,0x64419536,0x2d7fc036,0x15e3017e}},	//   _stíl, _hali, _płeć_, कुलर_,
   {{0xa059c6b0,0x6721ecce,0x63ad809c,0x394b414d}},	//   _مؤثر_, stlj, ƙans, _nrcs_,
   {{0x225fc05f,0xfd490112,0x00000000,0x00000000}},	//   ljuk_, lomọ, --, --,
   {{0x6d4bc011,0x753d4107,0x9f458157,0xdee622a6}},	//   _hrga, _assz, _pelù_, соби,
   {{0x7ebd0877,0xb5fb2c5c,0xeabf592a,0x6aad0303}},	//   tépe, skár, _chù_, _gkaf,
   {{0x69d60107,0xe09e8112,0x62964107,0xdb05056e}},	// [2d20] _igye, họọ_, rnyo, _vyhá,
   {{0xbddb19f3,0x6aa9c369,0x2f5652b0,0x290060db}},	//   ndèn, hoef, йтес, rsia_,
   {{0xdb1c4060,0x130a4119,0x5f460ec0,0x7e7bc00b}},	//   _agrò, уней_, _انجل, khup,
   {{0x2902c0d7,0x6441accf,0xd838d2b8,0x29004915}},	//   škai_, _aali, roči_, psia_,
   {{0x225fc05f,0x3ebf84ff,0xf8bf001e,0x92e3c079}},	//   djuk_, _dhut_, stée_, _ফটো_,
   {{0x442a4379,0x6a6a4066,0xf8bf001e,0x6e3668c9}},	//   _ubb_, _výfu, ptée_, leyb,
   {{0x5f438032,0x61e41f2e,0x68f6002c,0xe820017e}},	//   كنول, _ofil, _lwyd, _बाना_,
   {{0x261a02c8,0x26d22cd0,0x7e7bc006,0xceb4403a}},	//   _भाषी_, _niyo_, ghup, nlə_,
   {{0x7e666cd1,0xb5fdc03f,0x61fd0107,0x99928036}},	//   _mokp, ekšs, vasl, żył_,
   {{0x61e280c5,0x6aad0833,0x6d4bd425,0xfb1a85a7}},	//   lcol, _skaf, _drga, _مقطع_,
   {{0xd5b2c1aa,0x29022cd2,0x61e90018,0xcb0980d9}},	//   _کفش_, eska_, ñelo, _вхід_,
   {{0x75246cd3,0x06e7002a,0x7e7becd4,0x2724825d}},	//   ktiz, _ফিলি, chup, _ịnwe_,
   {{0x7d02acd5,0x9f47c5f5,0x05a74028,0x6d4bc011}},	//   nsos, _menù_, _कुंब, _grga,
   {{0x8c43ecd6,0x26da0031,0x61e42cd7,0x7c290054}},	//   _нече, _bupo_, _efil, đero,
   {{0x26da2cd8,0x61fd0c11,0x61e401f4,0x4fc40ae4}},	//   _cupo_, pasl, _ffil, зста,
   {{0xd6d81626,0x2902226d,0x76446aca,0x6aad012c}},	//   стр_, bska_, gdiy, _ukaf,
   {{0x68f601f4,0x7e7d0032,0x195841dc,0x644387fb}},	// [2d30] _gwyd, mhsp, баты_, ydni,
   {{0xf21f0374,0x764441c8,0x6d4d2cd9,0x9d184895}},	//   _भाड़_, adiy, _iraa, софт_,
   {{0x20cd4011,0x2c6b80b0,0x7d0401af,0x3ebf835d}},	//   _užim_, _mødt_, _zvis, _phut_,
   {{0x7d164010,0xdb1f45e7,0x66e1c017,0x27218019}},	//   buys, _ávís, _jēka, vón_,
   {{0x6e2d24c7,0x61ff403a,0x7d02917e,0xf1c5446d}},	//   _mbab, maql, gsos, लेशन,
   {{0x83fc82a3,0xc05b411b,0x2c6b8240,0xcb69800a}},	//   _dođo, _сім_, _nødt_, иале_,
   {{0x442c807a,0x39496cda,0x225fc05f,0x2242407a}},	//   _dbd_, lvas_, tjuk_, _yakk_,
   {{0x61e28193,0x6289812c,0x6d4bc6f0,0x61ff4080}},	//   ccol, _umeo, _prga, naql,
   {{0x3ce90046,0xa3a98027,0x225fc107,0x6aa9d8d0}},	//   _ntav_, _गुर_, rjuk_, roef,
   {{0x26c017a6,0x68ed57d9,0x4489c1a9,0x656f1203}},	//   _shio_, ipad, рбон_, dych,
   {{0xe7ef808f,0x644544ff,0x29020064,0x32090d6e}},	//   _घ्या_, idhi, wska_, _bday_,
   {{0x26da1036,0x62998c3e,0x5cf5c0d9,0xf1bf0070}},	//   _rupo_, nnwo, _дяку, rfán_,
   {{0xdea3c0fb,0x64556cdb,0x61fb9ea1,0x2904005f}},	//   _ویڈی, _onzi, _meul, éma_,
   {{0x9f478166,0x6ff98009,0x61fb8379,0x201e2500}},	//   zaný_, יפֿג, _leul, üti_,
   {{0x7e66402f,0xf7432595,0xe73a11cd,0x324640c5}},	//   _pokp, меро, шев_, оевг,
   {{0x2a66c046,0x7e7d2cdc,0xd040809c,0x2d804140}},	//   _xoob_, chsp, _yumɓ, tzie_,
   {{0x7fd61363,0xb46645e4,0xceb44435,0x645540b3}},	// [2d40] _міні, окал, rlə_, _bnzi,
   {{0x2d805b60,0x26da012c,0x6fde0045,0x6ee30112}},	//   rzie_, _tupo_, _मलिं, ọbat,
   {{0x9f416cdd,0xe9daa087,0xddc08185,0x201e97a6}},	//   nchè_, аке_, _pomů, _rcti_,
   {{0x9c874047,0x64455fcd,0x394dacde,0x61fbacde}},	//   _počá, adhi, _bres_, _ceul,
   {{0x9f5c805b,0xddc2ecdf,0x61fbace0,0xa3c9c048}},	//   mavé_, _slož, _deul, लेत_,
   {{0x3a2d8004,0xc1730093,0x3d12008f,0x2a66c046}},	//   _ebep_, וחד_, _तिने_, _soob_,
   {{0x66dec03f,0xd6d7a112,0x8b23420f,0x2a66c24c}},	//   _rīko, оты_, _одре, _poob_,
   {{0x6443ece1,0x2a66c04d,0xf4848646,0x395d8022}},	//   _aani, _qoob_, _کاری, bxws_,
   {{0x2c1b0b08,0x93bc8119,0xd49ac245,0x6eda8d91}},	//   _बालू_, _scăd, иро_, _पूरु,
   {{0xa25b001f,0x6609a26d,0x656f0089,0x80e1802a}},	//   rmôm, _zdek, vych, _নিচ্,
   {{0x656f0b5e,0x2a66ece2,0x9f5ec13b,0xee3ac025}},	//   wych, _toob_, matë_, _вне_,
   {{0xe292c646,0x7644009c,0x656f0036,0x4438068e}},	//   _غذا_, _caiy, tych, eer_,
   {{0xe1ff0e27,0x66d58007,0x8c46c42e,0xfe9bc323}},	//   raó_, _iška, _меде, _דיאמ,
   {{0x6a7cc669,0x95f54b08,0x3ea9c618,0xe821c75b}},	//   _défe, ेण्ट_, čate_, _माया_,
   {{0x6443410b,0x39400019,0x7d046ce3,0x224680f8}},	//   ônim, _esis_, esis, kdok_,
   {{0x1dca809d,0x6e2d1fa4,0x76440020,0x9f5c83e2}},	//   िधात, _ubab, _gaiy, ravè_,
   {{0x142b012b,0x3ce90673,0x394000f8,0x2904ece4}},	// [2d50] _кіно_, _utav_, _gsis_, nsma_,
   {{0x7af8c23b,0x2919018c,0xfc334032,0x6443c326}},	//   _kwvt, musa_, بحر_, _xani,
   {{0x6600ece5,0x291927ff,0xc6a78ace,0x25a24095}},	//   kamk, lusa_, орди, _exkl_,
   {{0x64450bc9,0xb5fd8077,0x2904ece6,0x61e44157}},	//   _hahi, _vošo, ksma_, ccil,
   {{0xd126cf35,0x981741aa,0x61fd4017,0x4a5a40c3}},	//   _ثم_, _وبسا, _iesl, _הדרו,
   {{0x644702a4,0x7c3880bf,0x2c798396,0xb5fd8123}},	//   ndji, gevr, _bèda_, _tošo,
   {{0x68e98064,0xb902854a,0x6d468be6,0x29192ce7}},	//   _wted, _नू_, _škat, husa_,
   {{0x60db8c99,0x6d4f40ab,0x442ed48d,0x26c94010}},	//   _tuum, _krca, _abf_, nmao_,
   {{0x61fd43a6,0x22648066,0x6d4f4010,0x27e9c09c}},	//   _mesl, žská_, _jrca, _ƙan_,
   {{0x6a7cece8,0x29192ce9,0x66dec03f,0x20016038}},	//   _réfe, dusa_, _tīkl, nahi_,
   {{0x66e8c260,0x9f5ec565,0xe739c76b,0x764400f8}},	//   _někd, natè_, щен_, _paiy,
   {{0x60dd53f1,0xb87b4070,0x2eb546ca,0x7d046cea}},	//   _ousm, _huíd, ंतोत, ysis,
   {{0x5ed2c079,0x29192ceb,0x69d9cc49,0xa7fc806a}},	//   _সবচে, gusa_, _igwe, _alıy,
   {{0x60c4c0c4,0x9f05c20c,0x38b44051,0x629bc1a4}},	//   _èimp, _فوتو, päri_, lnuo,
   {{0x64452cec,0x7e7baced,0x2001401c,0x76440396}},	//   _dahi, _olup, dahi_, _taiy,
   {{0x6d4f4908,0x60d5403f,0xada625ac,0x9f41423f}},	//   _brca, _aizm, _найл, cché_,
   {{0xe0d7412b,0x6d4f405e,0x7afb0077,0x98a05208}},	// [2d60] зву_, _crca, ćuta, stič_,
   {{0x61e46cee,0x60dd6cef,0x60d55d42,0x20016cf0}},	//   scil, _dusm, _cizm, gahi_,
   {{0x9f478089,0x60dd405e,0xbddb4396,0x7d0624e7}},	//   ybná_, _eusm, _kaèl, lsks,
   {{0x7e7b8018,0x7d04604e,0xf09f0016,0x7b2e8054}},	//   _clup, psis, bràs_, nđuš,
   {{0x41b94444,0x9f5ec0fd,0x2001514a,0x7d060588}},	//   _आरएस, tatë_, bahi_, nsks,
   {{0x81d54079,0x64450080,0x69d9c427,0x52a4c045}},	//   _সড়ক_, _xahi, _agwe, ऑक्स,
   {{0x9f5ec0da,0x443a6cf1,0x6600ecf2,0x79828036}},	//   ratë_, mep_, tamk, szow,
   {{0x6b57c112,0x2904d25f,0xb4db429a,0x139b40c3}},	//   _ọgb, tsma_, _gràs, _הבלע,
   {{0x48aac5b4,0xac868156,0x60dd40d2,0xc623002a}},	//   йтом_, _егал, _xusm, _বোঝা_,
   {{0x3ae1c00c,0x6600c52a,0xf806c11b,0x2904ecf3}},	//   _bóp_, samk, ччин, rsma_,
   {{0x2cacc1f4,0xddc9c2bc,0x3eadd932,0xddc4017a}},	//   rodd_, rkeš, boet_, _eliż,
   {{0x66028150,0xb5fb0107,0xf1be4759,0x59be4371}},	//   naok, aján, ्धान, ्धार,
   {{0x661d1013,0x9f5ec3bc,0x6f02c1c0,0x2906806f}},	//   rgsk, zatè_, _bíbá, nsoa_,
   {{0x61fd43a6,0x98bf80ab,0x9f5ec089,0x60dd6cf4}},	//   _sesl, _vruć_, haté_, _rusm,
   {{0x29191451,0x9f5806ed,0x671d0028,0x6447014b}},	//   susa_, garà_, बंधक_, rdji,
   {{0x179bc052,0xfd51c112,0xfd47005f,0x60dd59b6}},	//   _ליוב, _nkeọ, _ٹیسٹ_, _pusm,
   {{0x7e69911b,0x200c81f4,0xa5bb5d5b,0x443a42bc}},	// [2d70] _roep, _oddi_, _abór, fep_,
   {{0x7e6984f1,0x7e7b8a62,0x6d4f46f0,0x660d0303}},	//   _soep, _slup, _vrca, _hdak,
   {{0xb87b4c5a,0x6f1ac0ab,0x7e699016,0x7ebd0070}},	//   _ruíd, nutc, _poep, népo,
   {{0x6d42c232,0xb87b4004,0x6280c6ea,0x629d00d9}},	//   _osoa, _suíd, jhmo, nnso,
   {{0x63b54036,0x443a406a,0xd46996f6,0xa3b94045}},	//   _wyzn, bep_, жиле_, _चरक_,
   {{0x660bc056,0x6e22c0d2,0x764648f1,0x94014080}},	//   _sdgk, _acob, _zaky, yihə_,
   {{0x6d4d41b0,0x61e60041,0x47d08079,0x49194036}},	//   lvaa, yckl, _স্বী, यूरो_,
   {{0xa3c2d57c,0x26deacf5,0xd5ae805f,0x6448c02c}},	//   ्धन_, _duto_, اہے_, eddi,
   {{0xe821cc63,0x200c8018,0x9f580004,0x3eadd504}},	//   _मादा_, _fddi_, iará_, roet_,
   {{0x7d09acf6,0x629d17f1,0x2b434085,0x3ced8247}},	//   _ives, enso, _ksjc_, _itev_,
   {{0xaca34044,0xbea607bc,0x395fc04d,0x9f580016}},	//   _nnọc, данк, sxus_, xarà_,
   {{0x6448ecf7,0x68fb8112,0x4975d96d,0x660d0303}},	//   addi, _kwud, _олес, _cdak,
   {{0x5d69cf4b,0xaca34044,0x7c3aecf8,0xf8bf0e23}},	//   _филм_, _anọc, betr, rtén_,
   {{0x7d1bd904,0x6e2d415d,0x76466cf9,0x7649e898}},	//   muus, efab, _saky, ldey,
   {{0xdca2c077,0x6d4d66a8,0x2018c02d,0x7d1becfa}},	//   _шаши, evaa, órie_, luus,
   {{0x9f47ecfb,0x3ea000fd,0x61ed8018,0xf789c580}},	//   _menü_, _ujit_, ñall, _ençà_,
   {{0x7d1bcb34,0x9f5806ed,0xe8df800c,0x60d70303}},	// [2d80] nuus, sarà_, _trộn_, _fixm,
   {{0x61e99d6e,0xe73a06b1,0x28e18036,0x64476cfc}},	//   _afel, _део_, _पढ़ि, _caji,
   {{0xaca44112,0x22920908,0x366a4525,0x7e6bc078}},	//   _haịr, nško_, _дано_, _oogp,
   {{0xed5a5c98,0x7d1becfd,0x6f1c0f41,0xa5bb430d}},	//   _дом_, kuus, murc, _icón,
   {{0xaca44094,0xc0e3804c,0x443a46db,0x6280c022}},	//   _asụs, вочк, pep_, vhmo,
   {{0x3ead40e5,0x69c0804f,0x7d1bd65c,0x69db80fc}},	//   čete_, _vzme, duus, _egue,
   {{0x7e6bc0b0,0x2ac6c31f,0x68fb8073,0xa3e608b8}},	//   _bogp, мљив, _ewud, _फलन_,
   {{0x64474185,0x941e4d6c,0x44e46cfe,0x2a7dc1f4}},	//   _zaji, _पाँच_, _kö_, _clwb_,
   {{0x68e44080,0x66d5c026,0x26de8303,0x63ad891a}},	//   nqid, _iškl, _wuto_, ğana,
   {{0x1620c08f,0x660441a8,0x6448e46d,0xb4b8d1aa}},	//   _यावर_, haik, uddi, चते_,
   {{0x44e46cff,0x26de80f8,0x7bdc4011,0x6f1c0077}},	//   _lö_, _uuto_, _mgru, jurc,
   {{0xae1d439a,0x9f58050e,0xdddb8047,0x68e0ad00}},	//   _फाइन_, xará_, _bouř, _kumd,
   {{0x66046d01,0x6d42c119,0x44e462c1,0x7529c0b4}},	//   daik, _usoa, _nö_, ctez,
   {{0x443aed02,0xa3c048c5,0x7d166d03,0xe1ff4359}},	//   _úp_, ुधा_, drys, _seó_,
   {{0xf548c094,0x6f1c009c,0xb4cac048,0xf413c21d}},	//   _hụ_, gurc, लगी_, _ספק_,
   {{0x6d4d50d4,0x39522d04,0x20032d05,0x9f5c802d}},	//   tvaa, _frys_, saji_, javí_,
   {{0xf548c0eb,0x44314123,0x20030987,0x62829fcd}},	// [2d90] _jụ_, _pbz_, paji_, dhoo,
   {{0x3e71c10d,0x44e44041,0x60c500f8,0x22490b32}},	//   _hátt_, _dö_, _uhhm, _haak_,
   {{0x443cad06,0xb5fd80b3,0x38b444d3,0x52159978}},	//   dev_, _hoši, värt_, едет,
   {{0xb87b4031,0x442e8820,0x60d8c730,0x212940f8}},	//   _atít, eff_, _livm, ptah_,
   {{0x64475afe,0x3a248018,0xd90f8973,0xf548e7b6}},	//   _taji, _dcmp_, شیا_, _nụ_,
   {{0x660080b9,0x6aa2c0cc,0x64c988b8,0x22490127}},	//   _eemk, _ajof, िगेश, _laak_,
   {{0xd40480d9,0x6579891a,0x7d1d2d07,0x26d9417b}},	//   тячи, _şahı, huss, _kiso_,
   {{0x6282a2ec,0x05c34a3c,0x645a8e6e,0x7529ed08}},	//   choo, _शराब, _enti, ttez,
   {{0x765b8100,0x7d0980ab,0x81d7c079,0x68e080e2}},	//   _inuy, _uves, ়ুন_, _gumd,
   {{0xf548c015,0x3365c203,0x76498033,0xe8f6c10e}},	//   _dụ_, евог, _haey, эль_,
   {{0x291d9d8a,0xaca3c0eb,0x47d2c02a,0x61e480e5}},	//   luwa_, _nzụk, _দ্বী, žile,
   {{0x6e3d2d09,0x7e6d213f,0x22920084,0x70bd4ca7}},	//   gesb, _coap, rško_, ्गुल,
   {{0x61e9dff1,0xceb2c0c3,0xa3cb8185,0x6448994f}},	//   mcel, _גיא_, रेर_, _yadi,
   {{0x7d09c94f,0x38a9802d,0x6f1c2d0a,0xfe79c047}},	//   mses, túry_, turc, lků_,
   {{0x2a7f8435,0x66046d0b,0x291dad0c,0x26d9401c}},	//   _olub_, taik, huwa_, _biso_,
   {{0x2005ca06,0x443c8185,0x39520007,0x22154403}},	//   lali_, zev_, _trys_, кфур,
   {{0x7d1d0c2a,0xf2d2c009,0x61f65eed,0x66009a4a}},	// [2da0] cuss, רען_, rbyl, _remk,
   {{0xb21b0065,0x291d985a,0x69c421e7,0x683381df}},	//   nhæn, duwa_, _izie, nıdı,
   {{0x15f414e8,0xee3a9324,0x386c8018,0x7bde0010}},	//   _आभार_, зне_, _rodr_, _igpu,
   {{0x2a7f94ef,0x7d166d0d,0x3944807a,0xa3c2c048}},	//   _club_, prys, _psms_, ्धत_,
   {{0x629643a6,0x6284424f,0xdb0183a6,0x645a8056}},	//   miyo, mhio, _eylü, _pnti,
   {{0x6448ad0e,0x3ea06d0f,0xf548c044,0x26c6c2c0}},	//   _qadi, lnit_, _rụ_, _shoo_,
   {{0x66062d10,0x7ae18b40,0x442e80de,0xc60b0079}},	//   kakk, _cult, rff_, ষ্টা_,
   {{0x7bde005c,0x6448ad11,0x7d1d0033,0xfaa3c23d}},	//   _lgpu, _wadi, yuss, лшын,
   {{0x7d09ed12,0xb21b0065,0x2005ed13,0x44e600d1}},	//   gses, fhæn, fali_, _nô_,
   {{0x645aad14,0x6448812c,0x61e9c0b4,0x271e40eb}},	//   _unti, _uadi, acel, _ọnye_,
   {{0x7d1d1444,0x7ae18f56,0xe9df430d,0x26c6ed15}},	//   wuss, _gult, _baúl_, _thoo_,
   {{0x660605ba,0xb5fd8618,0x629644c8,0x877b8052}},	//   gakk, _poši, jiyo, _מאבי,
   {{0x69c2c150,0x7ae4d8ca,0x648902bc,0x7d1d0469}},	//   _uzoe, _čitu, džir, uuss,
   {{0x9f5ecc81,0x7c3e41e5,0x6602ed16,0xb4ab0314}},	//   latí_, jepr, _heok, गके_,
   {{0x9f3400d9,0x22490353,0x779301aa,0x6280ad17}},	//   лері, _taak_, ایجا, _olmo,
   {{0xba7705a7,0x3ea06d18,0x6d428112,0x44e60053}},	//   _ساعت, gnit_, kwoa, _fô_,
   {{0x61ed04d3,0xad9b4f84,0x4421405c,0x645c405e}},	// [2db0] _ifal, _adúr, tgh_, _bnri,
   {{0x6abd0621,0x6280ad19,0xfe79c047,0xad9dc036}},	//   llsf, _almo, zků_, kaźn,
   {{0x68e2c025,0xd7594032,0x291d8360,0xad9dc062}},	//   _luod, بلات_, wuwa_, jaźn,
   {{0xd99981b4,0x81ac0079,0x3ea06d1a,0x49758f27}},	//   ونات_, কেও_, cnit_, клес,
   {{0x61ed0150,0x27ec805c,0x60da90db,0x68e2c007}},	//   _mfal, _bfdn_, _bitm, _nuod,
   {{0x6280805f,0x2c1e4036,0xe73986bc,0x1d1640c3}},	//   _elmo, _पाएं_, дек_, _בקשר_,
   {{0x6602c077,0x9424c03a,0x61ed01f4,0xfe79c047}},	//   _beok, _ötən_, _ofal, tků_,
   {{0x291d85bb,0x291900ab,0xee39cb2c,0x6d46414b}},	//   puwa_, krsa_, фни_, _yska,
   {{0x4102c04c,0xdfe5456c,0xddc2c11f,0x7d09d213}},	//   азыв, _औलाद_, _pooš, uses,
   {{0xb4ab0185,0x752d5035,0x20036d1b,0x6abbc190}},	//   गको_, itaz, _jeji_, sluf,
   {{0x66062d1c,0x2018ed1d,0x7d0d0d98,0x2003455d}},	//   takk, ória_, _avas, _meji_,
   {{0x683381df,0x6386c01e,0x26f00079,0x2c7400cb}},	//   sıdı, _séné, _ছিলো_, _lädt_,
   {{0x9f5c8066,0x6484c5ef,0x6386c01e,0x66e54007}},	//   mavá_, _bòid, _péné, _sėkl,
   {{0x765d43bc,0x61ed00de,0x644aed1e,0x7eb8849a}},	//   _ansy, _efal, _gafi, lípt,
   {{0x29191caa,0xe5170fb2,0x2b1504df,0x23270d00}},	//   arsa_, _तिथि_, льтр, кори_,
   {{0x2bde2567,0x6a714211,0xd061c09c,0x5d860032}},	//   _मलका, _såfr, _ƙuɗa, _للبل,
   {{0xa5075201,0x644aed1f,0x5de34de7,0x1d075200}},	// [2dc0] кета_, _yafi, ржуа, кети_,
   {{0x2bc64a94,0x764bcc47,0xac834823,0xba3b01f4}},	//   _वरदा, _lagy, агул, mnïa,
   {{0x6d464064,0x7e7bed20,0x4033411b,0x660410df}},	//   _wska, kkup, реєс, _keik,
   {{0x7c3e6d21,0x6d46409c,0x66d841c0,0x66040140}},	//   sepr, _tska, _dúkì, _jeik,
   {{0x60da8396,0x7e69cded,0x3d194374,0x7ae3dccb}},	//   _pitm, djep, _पिये_, _lunt,
   {{0xb4cc86ca,0x22404fa0,0x443eed22,0x68ed8fc2}},	//   रगे_, leik_, xet_, íada,
   {{0x37d58079,0x6e94e345,0x68e42d23,0x68e2c025}},	//   _স্বর, лику, _luid, _suod,
   {{0x4427ed24,0x68e2c007,0x249800cb,0x66042d25}},	//   _acn_, _puod, hirm_, _neik,
   {{0xc6934093,0x4427ed26,0xc0e6811b,0x5cc6c0c5}},	//   יאה_, _bcn_, _розк, ксоз,
   {{0x4427c060,0x61ed0157,0xa0c98032,0xf8bf0107}},	//   _ccn_, _sfal, _كذلك_, rték_,
   {{0x441b4009,0x261bc08f,0xd6cfc18d,0xdc9b8093}},	//   וויס, _याची_, _вт_, _קיבל,
   {{0x7e69ccfe,0x3946c23b,0xddd60047,0xa3e6c4d8}},	//   cjep, _tsos_, _slyš, युज_,
   {{0x3e754041,0xddc407b4,0xe0df41c0,0xddd601dd}},	//   _mått_, _poiš, _asòn_, _plyš,
   {{0x68e40625,0x7ae3c232,0x8438c1b4,0x7414c05f}},	//   _duid, _funt, _أكثر_, _صوبا,
   {{0x6282db06,0xdee3c1bd,0x35c70036,0x442300fd}},	//   _kloo, _који, रेज़, rgj_,
   {{0x3e7544d3,0x61ed0150,0xaee3002e,0x2ebf505d}},	//   _nått_, _ufal, _aiṣe, ्षेत,
   {{0xead4409b,0x2120405c,0xb5fda1ad,0x5d554523}},	// [2dd0] роть, guih_, _mošt, ыкат,
   {{0x7ae3c09c,0x660400a8,0x09c34045,0x94078080}},	//   _yunt, _zeik, _शरीय, binə_,
   {{0x60dc489b,0x20cd4054,0xe1f9c007,0xa1f08112}},	//   _dirm, _džip_, ybų_, _ịhọt,
   {{0xb21b0065,0xf770420c,0xa49b40b6,0xa7fcc06a}},	//   skæf, غال_, _avòt, rkıy,
   {{0xa825478a,0x721a4942,0x25a9ad27,0x0d6445f5}},	//   _مکان, _אורח, çal_, _кърм,
   {{0x32096d28,0x61ed504c,0x03a59548,0xdb1a8107}},	//   laay_, lcal, лило, _sztá,
   {{0xaca380eb,0xeb35808c,0x6a784070,0xb5fd804f}},	//   _ntụn, ارتخ, _sífi, _bošt,
   {{0x7e7bc0e0,0x3949054a,0x9f510877,0xda1f09d5}},	//   ukup, _osas_, lazó_, _भागत_,
   {{0x2007ad29,0xdd12438a,0x9555c1b4,0xaca38044}},	//   pani_, _müşt, اخبا, _atụn,
   {{0x66041845,0x0dc8846c,0x212dc21b,0x6299a307}},	//   _seik, _руси_, rteh_, liwo,
   {{0x99c00079,0x7e7bc02f,0x660404f5,0x22920013}},	//   _ইলেক, pkup, _peik, lški_,
   {{0x39490070,0x9555cb3f,0x6d444b5e,0x6283813b}},	//   _bsas_, _مختا, ywia, ënoh,
   {{0x764d0057,0x61fdc086,0xceb28323,0xdb050089}},	//   _daay, ðslu, מיט_, _vyhý,
   {{0x9407803a,0x6846023d,0x20cf0085,0xb87b401f}},	//   tinə_, ынга, _bżiq_, _suín,
   {{0xa3abe567,0x66d5c011,0x26dded2a,0xeabf00c4}},	//   _कुच_, _aški, _kiwo_, blù_,
   {{0x61fbd929,0x6d49ad2b,0x61465301,0x753b8123}},	//   nbul, _osea, леба, _opuz,
   {{0xa81a40fb,0x6e244253,0x81b5c079,0xd2a74f93}},	// [2de0] فتار_, rgib, ছের_, укте_,
   {{0x2005809d,0x4425e36a,0x0efa00b4,0x7d1bd4ed}},	//   _neli_, ngl_, _пэмы_, irus,
   {{0x61e90be2,0x6441c119,0x200a2d2c,0x9f580359}},	//   žele, ieli, mabi_, harú_,
   {{0xaca44112,0xfce685bd,0xaaba878a,0x127a4032}},	//   _krịs, годо, ردار_, _أحدث_,
   {{0x6284012c,0x759a4031,0x63be2d2d,0x3e7544a0}},	//   _mlio, _fífẹ, _hypn, _vått_,
   {{0x26c06d2e,0x22420283,0x2005ad2f,0xc3064032}},	//   llio_, hekk_, _celi_, _مبرو,
   {{0x7640d24b,0x26ddc3bc,0xd8d70009,0x62842d30}},	//   temy, _biwo_, נוצט_, _olio,
   {{0x75d6820c,0x6441c4c0,0x66c5c107,0x851c8027}},	//   _ميزا, eeli, tóka, _निपट_,
   {{0x200a2d31,0xf8b40028,0x44e9ed32,0xb5fd8013}},	//   kabi_, ंकाय, _cú_, _vošt,
   {{0xdee68081,0x44e9ed33,0x9b58c8b5,0x644e6d34}},	//   _божи, _dú_, виот_, _jabi,
   {{0x44e9c166,0x26c04007,0x4ae7d43c,0x6284005e}},	//   _eú_, klio_, льям_, _blio,
   {{0x7d1bed35,0x39492d36,0xf127011e,0x44384033}},	//   brus, _psas_, льго, _lbr_,
   {{0x62840321,0x51840c85,0x9f4c8053,0xb7f645a8}},	//   _dlio, бура, _gedò_, ेराम_,
   {{0x20051608,0x62842d37,0xa3cb8945,0x44386d38}},	//   úli_, _elio, रेक_, _nbr_,
   {{0xc8794156,0x29024112,0xdfd505f1,0x78b50df0}},	//   _îşi_, _awka_, ровы, rozv,
   {{0x56944aec,0x7d0d6d39,0xf313c49f,0xe313c49f}},	//   баст, tsas, _ابوظ, _ابوب,
   {{0x39491b35,0x38c9416a,0x7642891a,0xd838856e}},	// [2df0] _usas_, نائی_, deoy, _obč_,
   {{0x37ab4c21,0x52ad809d,0x7d02c0bb,0x45b8559b}},	//   нтен_, टक्स, _mwos, угую_,
   {{0x7c2ac34d,0x9f510070,0xf8bf01cb,0x660640bc}},	//   _mcfr, razó_, guée_, _fekk,
   {{0xa3c9c5d5,0x61e49188,0x7c254032,0xdb1c413b}},	//   लेट_, žiln, sghr, _zyrë,
   {{0x7ae9404f,0x3ce6c157,0x95c86d3a,0xdb1c41af}},	//   _četu, _nuov_, _бура_, _vzrá,
   {{0xfc6740c5,0x764f4f2d,0x44386d3b,0x07158b57}},	//   _съмн, _hacy, _gbr_, афия,
   {{0xb5fb4032,0x764f5bdb,0x9f5e8031,0x59d50048}},	//   _gnác, _kacy, _fetí_, ठेतर,
   {{0xcee8849f,0x7d02c9dc,0x8e55c125,0xd8388053}},	//   درون_, _bwos, рткі, _ebč_,
   {{0xe8df800c,0x645a410b,0xb5fdc04f,0xada5d64e}},	//   _trốn_, _ótic, njši, рапл,
   {{0x644e6d3c,0x98a040ab,0x44e9c00c,0x3ea90051}},	//   _xabi, rtić_, _vú_, _ajat_,
   {{0xf771c78a,0xa3cb808f,0x290de4e3,0x7d02c303}},	//   زاد_, रेख_, ssea_, _ewos,
   {{0x200a2d3d,0x6d4f8004,0x7d1bed3e,0xeb96c051}},	//   wabi_, _ácas, prus, рию_,
   {{0xa3c9c5b9,0x660655d7,0x11390523,0x224204f5}},	//   लेज_, _rekk, ляры_, rekk_,
   {{0x61e2c06c,0xdb050018,0xceb90064,0x660b9b85}},	//   _zgol, _exhí, stęp_, hagk,
   {{0x6abb80c0,0x7ae74046,0xb8ce0027,0x68e66d3f}},	//   _okuf, _nujt, _कद_, _sukd,
   {{0x44384086,0x7e6d4033,0x442a642f,0x26c05c6b}},	//   _sbr_, gjap, _scb_, ulio_,
   {{0x3afc0031,0x66066d40,0x6aa442cd,0x2d8dc206}},	// [2e00] _bàpò_, _vekk, rnif, nzee_,
   {{0x6606565b,0x9c7c80b3,0x757b0942,0xc5d7c079}},	//   _wekk, _kiče, _סטיפ, _সভাপ,
   {{0x764f647d,0x0b4657e5,0xa3c9c048,0x3afc0031}},	//   _facy, рнен, लेच_, _dàpò_,
   {{0x644e6d41,0x26cdad42,0x1f36c052,0x798d4020}},	//   _wabi, _cheo_, ירער_, bzaw,
   {{0x11548099,0x201a801f,0x684693d0,0x61e48077}},	//   склю, ópio_, инда, žilo,
   {{0xed59ad43,0xaca44112,0x7d02c00d,0x57f39025}},	//   _drž_, _krọs, _rwos, општ,
   {{0x27318015,0xf8bf0669,0xa7b8a112,0x672397e0}},	//   _cơn_, quée_, ылку_, gunj,
   {{0x940a0080,0x66e34039,0xa2cc4045,0x629bc026}},	//   ribə_, _фота, _थीम्, giuo,
   {{0x635c8156,0xc866c827,0xd90dc4e8,0x25bf8033}},	//   _sănă, атни, فین_, _gyul_,
   {{0xd838c077,0x6a7cc1cb,0x656f81cb,0x6f03c99e}},	//   kiče_, _méfi, _àcha, _bwnc,
   {{0x7524511b,0xe4574009,0x6d4bdd9e,0xd838c077}},	//   huiz, בייט_, _esga, jiče_,
   {{0x3cfd8c5c,0x2282002e,0xd00b802a,0x75246d44}},	//   रीके_, _dóko_, _রায়_, kuiz,
   {{0x320b21dd,0x2cb812e9,0x7ae88588,0x442c888b}},	//   racy_, ford_, _hudt, _kcd_,
   {{0x7ae0ad45,0x8c43d35b,0x75244206,0xa5bb41c0}},	//   _limt, _мече, duiz, _gbóy,
   {{0xcebb46b1,0xddc44017,0x290f85ca,0x3a2b4085}},	//   вља_, ndiņ, zsga_, _pccp_,
   {{0xa3cb8e64,0x394b4033,0xf00b400c,0x6280c372}},	//   रेट_, _pscs_, _đằng_, nkmo,
   {{0x64439857,0x80c9c079,0x7d04002c,0x3eb900c3}},	// [2e10] yeni, রদর্, _gwis, most_,
   {{0x64439d94,0xd838c05b,0x442c805c,0x2cb82d46}},	//   xeni, biče_, _ncd_, cord_,
   {{0x44eb8240,0xb767473c,0x39f480eb,0x60ce4061}},	//   _sø_, штай, _ịzọ_, _dhbm,
   {{0x64438d71,0x7ebd030d,0x4fd9c009,0x4ea48039}},	//   weni, cépt, אַנד, орча,
   {{0x69c081f4,0x27ec0166,0x0a684119,0x067c0052}},	//   _cyme, ždne_, _трэи_, כנאל,
   {{0x20854dd8,0x7e62ed47,0x83f840b4,0x6d59c024}},	//   _السّ, _anop, _верс_, _rrwa,
   {{0xa3d70705,0x660b9b82,0xd6db8f75,0xe299c603}},	//   िधि_, pagk, _ата_, лак_,
   {{0xc3324093,0xe518c314,0x6abb8339,0x7ae08039}},	//   _מול_, _दिशि_, _ukuf, _gimt,
   {{0x2007da1c,0x69c081f4,0xa3cb84fb,0x39494049}},	//   _peni_, _gyme, रेज_, nwas_,
   {{0x61e42d48,0x200ce3ef,0x70748032,0x657d013b}},	//   _sgil, gadi_, _والذ, dysh,
   {{0xbb45dc27,0x908a80fb,0x7ae08022,0x75244150}},	//   щенк, _حملے_, _yimt, zuiz,
   {{0xff50808c,0x660d6beb,0xfd1f0157,0x6a784086}},	//   _زخم_, jaak, frì_, _lífr,
   {{0x0d9a059d,0x0d99010e,0x6e3b889a,0xaca380eb}},	//   утны_, атры_, _mbub, _ndịo,
   {{0x3ce9023b,0x69cbc0b3,0x44fbc018,0x200ce539}},	//   _duav_, _izge, _iª_, cadi_,
   {{0xa3b50027,0x6d4d01ae,0x637900b4,0x2cb805ce}},	//   _छुआ_, _esaa, астр_, rord_,
   {{0x7c3b097c,0x3eb902cd,0xe29743bf,0x681b8017}},	//   đura, cost_, бас_, lādē,
   {{0x21674af9,0xd838c066,0x39494c05,0x2b498036}},	// [2e20] бити_, siče_, gwas_, łach_,
   {{0x7e214028,0x39400340,0x315702a6,0x3a2d9f41}},	//   यलॉग_, _ipis_, _פיין_, _acep_,
   {{0x6299c31c,0x442cad49,0x547700c3,0x6d5b809d}},	//   _omwo, _rcd_, _הגיע_, _arua,
   {{0x200cc054,0x6b81036b,0x6d5bad4a,0x5fbac009}},	//   zadi_, ølge, _brua, אצענ,
   {{0x64455081,0x7ae08022,0xbcfb4031,0x3913811b}},	//   behi, _vimt, _aréf, змір,
   {{0x6d49c396,0x7afac05c,0xbcfb4086,0x68e1ad4b}},	//   dwea, yptt, _bréf, _cild,
   {{0xe7fb0f8b,0x660980eb,0x2731ed4c,0x39400033}},	//   ्रता_, _feek, ján_, _lpis_,
   {{0x994c8166,0xc3330093,0x77630ad6,0xf8bf2d4d}},	//   môže_, פוח_, _ánxe, ntér_,
   {{0xe1efcf4d,0x6d4f8018,0x200a409c,0xdb18c5e5}},	//   رسي_, _ácap, _kebi_, _vyví,
   {{0xb4b2139f,0x442cad4e,0x660d411c,0x2731c086}},	//   टको_, _ucd_, zaak, fán_,
   {{0x3eb903b9,0x7e762d4f,0x200a421b,0x6d4d031c}},	//   tost_, _boyp, _mebi_, _ssaa,
   {{0x660d41c8,0x8503c68b,0x7afc004f,0xb7db4052}},	//   xaak, _کوون, dprt, טקיי,
   {{0xc98411e8,0xc50ac032,0x6282ab29,0x2018416e}},	//   пури, _إتصل_, ikoo, _odri_,
   {{0xfd4d4015,0x660d6d50,0x68fb40fd,0x7c2a8d42}},	//   _thoả, waak, _çudi, ngfr,
   {{0x39402d51,0x660d6d52,0x66d5c007,0xe7f085cb}},	//   _epis_, taak, _iškr, _चलना_,
   {{0x6d408a26,0x3ce9024c,0xfd1f00c4,0x3d120048}},	//   _opma, _tuav_, prì_, _तिचे_,
   {{0x7ae2d15a,0x9fe741b4,0x200e8360,0x66e54007}},	// [2e30] _miot, مساه, kafi_, _lėkt,
   {{0xf8bf05f6,0xf80706b1,0x69cd00fc,0xb5fdc043}},	//   rtés_, _учин, _izae, ljšt,
   {{0xf8bf2d53,0x64470150,0x68e9ad54,0x7bda4066}},	//   stés_, meji, _sued, _útul,
   {{0x66f18279,0x4ac92d55,0xe29f010d,0x68e1ad56}},	//   _nāka, रतिव, nið_, _sild,
   {{0x21698f67,0x3ea96d57,0xa9698f67,0xe8d900eb}},	//   рили_, mnat_, рила_, _nrị_,
   {{0x7bc6c036,0x26c4c0c4,0x64472d58,0x6d4f6d59}},	//   ękuj, elmo_, neji, _isca,
   {{0xe8d900eb,0xf7718183,0xb7b3c02a,0x2731c03c}},	//   _arị_, ظات_, _ঘণ্ট, xán_,
   {{0x64550056,0xc7b24093,0x44ef054a,0x6e3b9dcb}},	//   hdzi, _חבל_, _oü_, _ubub,
   {{0x64472d5a,0x62898031,0x7ae2c232,0x68e18586}},	//   keji, _ileo, _diot, _tild,
   {{0x291fed5b,0x7e760070,0x7aeac0cc,0xb21b4329}},	//   rrua_, _soyp, _buft, _blæk,
   {{0x68fbc123,0x52aa05ac,0x7aeac011,0x443cc0b1}},	//   spud, ивом_, _cuft, _dbv_,
   {{0x7aeac70d,0x64552d5c,0x68fbed5d,0xbcfb6d5e}},	//   _duft, edzi, ppud, _grég,
   {{0x99ddc02d,0x3f83e47e,0x3cfd8048,0xf1b5409d}},	//   meňo, šju_, रीचे_, _अँगन,
   {{0x752600fc,0x6a7cc1cb,0xbcfb4303,0x6aa9c086}},	//   rukz, _défu, _mréd, lnef,
   {{0x869a401d,0x9358c0b4,0x629b817b,0xeb96d1a0}},	//   атат_, _грыу_, _omuo, _миш_,
   {{0x442a0010,0x6aa9ca62,0x3946401f,0xada61575}},	//   sgb_, nnef, çoso_, _майл,
   {{0x9f490166,0x0ffa4032,0xb5fb0107,0x6d5d405e}},	// [2e40] _škôl_, لعاب_, pjár, _crsa,
   {{0x03a64a23,0x67270212,0xb5fb430d,0xa7fc8165}},	//   оизо, bujj, _unán, _anın,
   {{0xf8bf017c,0x200e80b3,0xbddb4b94,0x68ebc177}},	//   ptér_, vafi_, _abèd, _lugd,
   {{0x200e9d0f,0x7bc3c14d,0xa2c9c8b8,0x56938125}},	//   wafi_, _mynu, _हील्, маєт,
   {{0x200ead5f,0x7ae42d60,0x68e3c140,0x2d5880d9}},	//   tafi_, _miit, _oind, силь_,
   {{0x6b57c112,0x66f18017,0x7bc3c138,0x20c98359}},	//   _ụgw, _sāka, _oynu, súin_,
   {{0xa3d48028,0x80b956ca,0xaff54107,0xa3dec6fc}},	//   सें_, ्तरे, _رہنا_, _दृढ_,
   {{0x645509ae,0x3ea06d61,0xd838ed62,0x6721c41b}},	//   zdzi, niit_, diča_, drlj,
   {{0x68e3daf2,0x6447012c,0x26db0157,0xdcea00a0}},	//   _bind, yeji, _èpoi_, čněj,
   {{0x26c69fe7,0x2bc004fb,0xc19b4052,0x0b1a8032}},	//   lloo_, _शुभा, ישפי, _نقطة_,
   {{0xa3cfc281,0x249eed63,0x9f5840c4,0x3ead813b}},	//   _शरण_, ritm_, _perù_, _yjet_,
   {{0x69c40053,0x443ea42f,0x6602ad64,0x81de802a}},	//   _byie, _hbt_, nbok, _দ্য_,
   {{0xfad7c009,0xb95b4031,0xd12fc032,0x95cb0522}},	//   _וואך_, _ayìn, _لمن_, руна_,
   {{0x38784041,0xee3f0066,0x6721c2a3,0x2bb60444}},	//   _norr_, mným_, brlj, _आँखा,
   {{0x4fc41729,0x628d6d65,0xee3f005b,0x7ae42d66}},	//   дста, thao, lným_, _fiit,
   {{0xd9e307f6,0x82f7c646,0xa3cfc09d,0x68fd0621}},	//   _गणपत_, _بروز_, _शरत_, ppsd,
   {{0x68e3d222,0xee3f0066,0xcbe6402a,0x64472d67}},	// [2e50] _yind, nným_, _পড়েছ, peji,
   {{0x29090112,0x6ef34283,0x3e7c45e7,0x78bc0157}},	//   _iwaa_, _aħba, _sítt_, corv,
   {{0xf8bf001e,0x628980cc,0x29090303,0x8c3cc06a}},	//   grée_, _pleo, _hwaa_, ciğe,
   {{0x290900eb,0x6448ce71,0x7ae42d68,0x628f035d}},	//   _kwaa_, hedi, _xiit, nhco,
   {{0x248c0039,0xee3f0066,0x224940fc,0x2c1f0027}},	//   šimų_, jným_, meak_, _बयां_,
   {{0xee3f0d01,0x69cf6d69,0x6d5d810d,0x6728c0b3}},	//   dným_, _izce, _ásam, kudj,
   {{0x68ed02d4,0xe8d90044,0xa5bb4032,0xf8bf001e}},	//   _luad, _nrọ_, _gcór, crée_,
   {{0xd838ed6a,0xa3dd0048,0x31358bf9,0x442cc0a8}},	//   viča_, तेय_, _небр, egd_,
   {{0x6448d594,0x6d4d4e1e,0x290900eb,0x6484c05e}},	//   fedi, nwaa, _nwaa_, _eòim,
   {{0xa3cfce64,0x200cad6b,0x660bd69b,0x64556d6c}},	//   _शरद_, _gedi_, _wegk, _jazi,
   {{0x660d141b,0xb5fb4031,0x317fc21b,0x6d4d4d31}},	//   _beak, _anám, syuz_, hwaa,
   {{0x6abd2d6d,0x85170048,0x6448c018,0x68ed029a}},	//   gosf, _तिखट_, aedi, _buad,
   {{0xaca3c25d,0x6f150064,0xdb18c066,0x648dc018}},	//   _ahụh, eszc, _vyvá, _púid,
   {{0x7649c057,0x6e2d528d,0xd576c4e0,0xb4fac0c3}},	//   leey, egab, _מתנה_, _הפסי,
   {{0x8704c032,0x7d0980f7,0x66f18017,0x94110080}},	//   _قبيل, _lwes, _māko, nizə_,
   {{0x88d18079,0x6d4d5ccf,0x7649d238,0x628f2d6e}},	//   াদিক, fwaa, neey, chco,
   {{0x18a6045e,0x9f5806ed,0x395f8022,0x290900eb}},	// [2e60] _наим, taró_, _nrus_, _gwaa_,
   {{0xf4218079,0x66f1803f,0x8236405f,0x90c3404c}},	//   প্তর_, _nāko, _کردا, ебуе,
   {{0x200c8472,0xa87b0093,0x6455507d,0x2d8202a4}},	//   _redi_, _האיר, _dazi, lyke_,
   {{0x200c8c1b,0xe7b341aa,0x7bce53ca,0x76562d6f}},	//   _sedi_, رمند, _vzbu, _jayy,
   {{0x9f582d70,0x26c24020,0x442cc377,0x6d5bc022}},	//   paró_, _ikko_, ygd_, jvua,
   {{0x7522ad71,0x653b0009,0x6d440230,0xee3f180a}},	//   rroz, מענד, _mpia, vným_,
   {{0xbb434846,0x6b66410e,0xa7378032,0x99dd8053}},	//   _перк, _эква, كثير_, _abňd,
   {{0x6604633a,0x75244e84,0x6448c1f4,0x32124010}},	//   nbik, oriz, wedi, nayy_,
   {{0x20112d72,0x7d0981f4,0xfe6fc032,0xc05ace8e}},	//   yazi_, _gwes, ادى_, бін_,
   {{0xf8be6d73,0x628bed74,0x7ae66d75,0xee3f0066}},	//   ्तिय, _elgo, _likt, rným_,
   {{0x741387c3,0x644aad76,0x3ea21127,0x6d4d415d}},	//   _سونا, mefi, fikt_, zwaa,
   {{0xd24fc01c,0xee3f0089,0x7649c149,0x6fa280e9}},	//   _منم_, pným_, ceey, _केयू,
   {{0xac18ed77,0xd627c0d9,0x629881cb,0x80be6b03}},	//   _долу_, _хоче_, évoy, ्ताइ,
   {{0x7d1643ad,0x176acacf,0xe3afc16a,0x39a3409d}},	//   dsys, _грип_, ئری_, _कs_,
   {{0x765606df,0x75280064,0x543bc009,0x643bc0c3}},	//   _fayy, ądza, _לעגא, _העונ,
   {{0x27354041,0xb4db41c0,0x66045636,0x8c09402a}},	//   vån_, _asàp, gbik, _লাইন_,
   {{0x31600013,0xbc794d9b,0x20110043,0xddcbc036}},	// [2e70] _griz_, обах_, pazi_, _zagł,
   {{0xed600007,0x6e3d0414,0xddc9c570,0x765606df}},	//   įžti_, lfsb, nješ, _zayy,
   {{0x1a6584fc,0x92598051,0x7d098073,0x76560020}},	//   ویسی_, жает_, _swes, _yayy,
   {{0x225904ca,0xfbd041b4,0x66f1803f,0xfd620112}},	//   ndsk_, اتك_, _sāko, _nkwọ,
   {{0x2d4d438f,0x81df0079,0xee47002d,0x69cf48c7}},	//   _uže_, দুর_, chýň_, _uzce,
   {{0xbcfb4781,0x660f692a,0x3ead4158,0x20c2c397}},	//   _eréc, _heck, četu_, iðis_,
   {{0x44f2c99e,0x66d182e9,0x629f0073,0x648dd29a}},	//   _aâ_, råkb, _omqo, _lúic,
   {{0x61e98157,0x661b89e8,0x64588206,0x77fb0c4b}},	//   _ugel, _uduk, advi, ्रुक_,
   {{0xdd94839d,0x3944821b,0x644aab83,0x6ba6803a}},	//   _заты, _gpms_, befi, _əsgə,
   {{0xdeff0283,0x7649d238,0xef19d198,0x6604413b}},	//   ċċju_, seey, омо_, zbik,
   {{0x765600f8,0x3ea20017,0xc5f4009c,0xdc384052}},	//   _payy, tikt_, _laɓe_, לאזט_,
   {{0x7e7b82fc,0x68e7415d,0xada60039,0xd016402a}},	//   _joup, _lijd, дамл, ালয়_,
   {{0x3ebfed78,0xddc9c06f,0x6b83ad79,0xea00435d}},	//   mout_, bješ, lyng, _ngạt_,
   {{0x6457010b,0x7e7b98c3,0x3ea20377,0x69c652f4}},	//   _caxi, _loup, sikt_, _ryke,
   {{0x2005e92c,0x76562d7a,0x7ae66d7b,0xfd56825d}},	//   mbli_, _tayy, _pikt, _babị,
   {{0x628d0510,0xad9b4066,0x7aee409c,0x92b60032}},	//   _glao, _neús, _rubt, _تحتا,
   {{0x61f66d7c,0x320fc05f,0x00e640d7,0xe8df8031}},	// [2e80] rcyl, _megy_, джан, _apọn_,
   {{0x7aee4022,0x79828150,0xd8388570,0x7d1663de}},	//   _pubt, vyow, _omča_, rsys,
   {{0x3eaded7d,0x443c805c,0x6490009d,0x644aad7e}},	//   knet_, vfv_, _väid, vefi,
   {{0x0dca8c38,0xd91044e8,0xd1caad7f,0x764bad80}},	//   олей_, _میر_, олее_, gegy,
   {{0x1fbac5a3,0x20c2c397,0x410340c5,0x66fac17a}},	//   _उड्ड, iðir_, _изяв, _iċke,
   {{0x61ebcfa3,0x6b8381f4,0xb87b449a,0x2013401f}},	//   _aggl, fyng, _quít, caxi_,
   {{0x2242405c,0x764bad81,0x6490009d,0xc5f40360}},	//   _kbkk_, begy, _käib, _zaɓe_,
   {{0x539b40c3,0x26c04157,0xdced4138,0x200eed82}},	//   _וילו, noio_, nyağ, _sefi_,
   {{0x321dc1f4,0xb97b4052,0x644a901e,0xfaa3831f}},	//   _ddwy_, ַנטי, pefi, _рато,
   {{0x7e698089,0xd7f7d612,0x61ebe356,0x3eaded83}},	//   _znep, мую_, _eggl, anet_,
   {{0x7e7bad84,0xd251020c,0xe8ca8048,0x201e843e}},	//   _youp, هند_, ितीच, _idti_,
   {{0x68e88db2,0x6d4640b0,0x0d86c22b,0x64418835}},	//   _hidd, _opka, _олен, _zbli,
   {{0x656fc0fa,0x26c0423f,0xb4e90743,0xeabf0181}},	//   ächt, doio_, यदे_, roù_,
   {{0x68e8ad85,0xf7730567,0x3ea4c588,0x6562c083}},	//   _jidd, پاس_, limt_, _iroh,
   {{0x1833c032,0xcc33d006,0x224240b9,0x6a7f013b}},	//   _شروح, _شروع, _bbkk_, _dëfr,
   {{0x2a690070,0x645aed86,0x85054280,0xc9875511}},	//   _unab_, ldti, فورن, музи,
   {{0x2242405c,0x7bca40fa,0xb8334031,0xbcfb4032}},	// [2e90] _dbkk_, üfun, _ajúṣ, _bréa,
   {{0x443ec600,0x68e896fa,0x2bc48a3c,0x7d0d12f5}},	//   nft_, _nidd, _लुभा, _iwas,
   {{0x78a38051,0x26c04018,0xbcfb4032,0x2489c09c}},	//   vinv, boio_, _dréa, _ɓam_,
   {{0x68e7415d,0x29190051,0x3ebfc010,0x05d3017e}},	//   _wijd, ossa_, xout_, _सराब,
   {{0x3eadc58a,0x1d0993a8,0x7659ad87,0x9f5c8066}},	//   vnet_, чели_, rdwy, ravý_,
   {{0x7ff58b66,0x3ebfd3a5,0x7642ed88,0xf53643bd}},	//   رستا, wout_, _aboy, _אנשי_,
   {{0xdbd6d3c6,0x3946c10b,0x28be5018,0x56958698}},	//   _jääk, _apos_, ्तरि, _завт,
   {{0xea9f81c0,0xe81b809d,0x6562ed89,0x7e7d6d8a}},	//   _daṣa_, _नयका_, _broh, _josp,
   {{0x752d423f,0x64804051,0x7e7d413b,0xd83880b6}},	//   nuaz, _töit, _mosp, _imčn_,
   {{0x6562c0cb,0x68e8a068,0x3ebfed8b,0x7e7d6d8c}},	//   _droh, _gidd, sout_, _losp,
   {{0x2738c49b,0x20079235,0x3d164285,0x3eadc98f}},	//   gén_, mbni_, _पौने_, pnet_,
   {{0xd7f8c0b4,0x63bb01df,0x7d0d09d9,0xa909c032}},	//   acă_, ğunl, _bwas, _فيصل_,
   {{0x2bd1c4ef,0x7e6bc396,0xb9150044,0xb80f442f}},	//   _हरवा, _ingp, madị_, िराम_,
   {{0x9f414070,0x317ac323,0xb9150044,0x7d0d00b1}},	//   nchó_, _מאנד, ladị_, _dwas,
   {{0x2919004c,0xfaa600d6,0x2ca5c086,0x44f40c4b}},	//   assa_, _пако, mild_, _wä_,
   {{0x2bfbc028,0x765bc00d,0xf7728052,0x61ed00bc}},	//   लुरू_, nduy, נקן_, _ggal,
   {{0xbcfb55b9,0x22b8804f,0x6aa44da0,0xe2974c1b}},	// [2ea0] _préa, nčke_, riif, хат_,
   {{0x224dc15d,0xb21b4065,0x79964036,0x61fbad8d}},	//   heek_, _blæs, rzyw, _aful,
   {{0xa09b0009,0x20114141,0x69c99238,0x320686b3}},	//   _זייט, _dezi_, _ayee, tboy_,
   {{0x83fc8654,0x26c22d8e,0x645c2d8f,0xe612808c}},	//   _inđi, noko_, ldri, اشا_,
   {{0xa3e28bfa,0x764405dc,0x3dc9004d,0x224dc0fc}},	//   नेन_, _mbiy, _xyaw_, deek_,
   {{0x644e2d90,0x2011406a,0x7d02ad91,0x6d5600f8}},	//   nebi, _gezi_, rpos, _msya,
   {{0x7d044b6f,0xce94c0c5,0x9c7c89bd,0x395241f4}},	//   lpis, какъ, _hičk, lwys_,
   {{0x09e44079,0xdee3842e,0x7d04404c,0x224dd437}},	//   _ফ্যা, _боси, opis, geek_,
   {{0x7d046d92,0x68e88283,0xe572c54c,0xe4a6d000}},	//   npis, _tidd, اطع_, ерно,
   {{0x9f4a41c0,0x4444018a,0x443ec0fa,0xddcd42bc}},	//   _agbé_, _nb_, uft_, njaš,
   {{0x6e950221,0x22950844,0x26c2017b,0x224dda42}},	//   вину, виня, foko_, beek_,
   {{0x645c2d93,0x9bb78093,0xf3ff800c,0x26c200fc}},	//   edri, _אהבה_, _đãi_, goko_,
   {{0x69c9823b,0xbcfb4df0,0x443eed94,0x3946c02f}},	//   _xyee, _arén, pft_, _upos_,
   {{0x644e2d95,0x81c50079,0x91e3cdd2,0x7644163e}},	//   gebi, ৌশল_, _соче, _ebiy,
   {{0x7e7d4120,0xd3240698,0x98a4c03f,0xf487c646}},	//   _posp, льти, cumā_, _ثانی,
   {{0x672106f0,0x201143e2,0x7af5005c,0x8aa45aca}},	//   šljo, _sezi_, rqzt, груд,
   {{0x648dc1b4,0x7d046d96,0xf1a401dc,0x65944119}},	// [2eb0] _múin, gpis, _брэн, гату,
   {{0x44440378,0x764f1b2d,0x68eac17a,0x387e8147}},	//   _gb_, lecy, _jifd, _notr_,
   {{0x6f1c40b3,0x4421029a,0xf3f1800c,0x6aa2cbfd}},	//   _cvrc, _idh_, _bạn_, _omof,
   {{0x25a60654,0x44442d97,0x228e4166,0xe521c314}},	//   _žoli_, _zb_, _týka_, _मिलि_,
   {{0x752d40c4,0x7e6d18e2,0xe3b88080,0xa3f50045}},	//   quaz, _mnap, _axı_, _आलाप_,
   {{0xaca34112,0x6aa2c1c0,0x26c20ce6,0xb4bb82ea}},	//   _kpọb, _amof, zoko_, घवे_,
   {{0x648dc10d,0x7e6d16ac,0xb8820047,0x9814801c}},	//   _búin, _onap, _říka, ابها,
   {{0x320945d1,0x7e6d00eb,0xd90c849b,0x59d54045}},	//   nbay_, _nnap, _کیو_, _दरार,
   {{0x64948321,0x28b84027,0x26c20140,0xb60400a0}},	//   _bàid, _आदमि, voko_, ndář,
   {{0x644e0232,0x395fed98,0x26c2000d,0xe7c54914}},	//   xebi, rvus_, woko_, _वडाप,
   {{0x26c22d99,0x212957b7,0x765b8067,0x29002d9a}},	//   toko_, hrah_, _kauy, _stia_,
   {{0x44211335,0x2ca7ad9b,0x98a4c03f,0x645c15b2}},	//   _adh_, lind_, rumā_, wdri,
   {{0x644e2d9c,0x645aad9d,0x32094149,0x61fbc5b6}},	//   tebi, _yati, dbay_, mcul,
   {{0x645a803a,0x765b8360,0x6aa61a25,0x60c380b6}},	//   _xati, _lauy, sikf, nonm,
   {{0xe3b8114f,0x6b8dc09c,0x661640f8,0x644e2d9e}},	//   çı_, _ƙagu, tayk, rebi,
   {{0x9c7c860f,0x44212d9f,0x765b8067,0x656942bc}},	//   _pičk, _edh_, _nauy, _šeha,
   {{0x95834974,0xa3df6da0,0x60c3ada1,0x273a80da}},	// [2ec0] алте, देस_, konm, zën_,
   {{0x225e003f,0x42c44079,0x2a6d8047,0x66ec403a}},	//   ētku_, ্দেশ, _aneb_, _aşka,
   {{0x21294853,0x50b54119,0x26cdc570,0xc5f40020}},	//   arah_, усту, kleo_, _zaɓa_,
   {{0x645a85cf,0x21296da2,0x0d868bf9,0x6b7ac052}},	//   _sati, brah_, клен, ורענ,
   {{0x60c38402,0x64580086,0x95538032,0x6609eda3}},	//   fonm, _óvis, لخوا, dbek,
   {{0xfc0349b0,0x399b02a6,0xb4cbc048,0x645aa239}},	//   _впро, וינד, लतो_, _qati,
   {{0x9f58410d,0x6d4980fc,0x8fa6487b,0x42568119}},	//   _gerð_, _epea, _раве, _итат,
   {{0x3eb2404c,0x9c7c89bd,0xab838409,0x44384f13}},	//   nnyt_, _miči, рушк, _hcr_,
   {{0xdd90c446,0xd94681bd,0x9c7c8084,0xa3e4c4fb}},	//   صود_, _јези, _liči, पेन_,
   {{0x9f988531,0x273a80fd,0x98e68032,0x013780c3}},	//   lším_, pën_, _شكاو, _ברמת_,
   {{0xc5f40020,0x273a813b,0x61488086,0x7d1bd664}},	//   _saɓa_, qën_, _félö, asus,
   {{0x20132da4,0x39490033,0x644500f8,0xa3d78549}},	//   _sexi_, _ppas_, _sbhi, _सरत_,
   {{0xa2b85d60,0x273c53c3,0x201819c7,0xf6534107}},	//   ्कन्, hín_, fari_, یئر_,
   {{0x26c4eda5,0xf366d828,0x64a3dc2e,0xe3b30107}},	//   lomo_, _атин, _кача, لرز_,
   {{0xd4982da6,0x78ad81cb,0xdbccc086,0xe8d940eb}},	//   тря_, éavi, _góði, nyụ_,
   {{0xe8028874,0x60c380ce,0xd838c113,0x38ad02bc}},	//   रुता_, zonm, diči_, džre_,
   {{0x645e40a8,0x61ed802d,0x32096da7,0x6ef340f6}},	// [2ed0] fdpi, žalk, rbay_, _iħbi,
   {{0x273c4d51,0x9418003a,0x634a803a,0xa49b41c0}},	//   fín_, kirə_, _kənd, _awòr,
   {{0x6d498093,0x27e74041,0x66d60512,0x2246c036}},	//   _spea, änn_, láka, _obok_,
   {{0xbebd0017,0x634a8080,0xb21b4086,0x3166c140}},	//   drīk, _zəng, _glæp, _oroz_,
   {{0x3ea96da8,0xf9908032,0x26c4eda9,0x1d348c35}},	//   miat_, يبه_, domo_, инця,
   {{0x7aed2daa,0x69cbc065,0x6490009d,0x7529edab}},	//   _liat, _ryge, _läin, vrez,
   {{0x7aebc0f8,0xfaa5ddc5,0x62808c5a,0xdd0382d6}},	//   _pigt, лако, _fomo, ırım,
   {{0x7aed1eb5,0x3af8800c,0xb5fb49a8,0x26c4dfa4}},	//   _niat, _dép_, _gnát, gomo_,
   {{0x645c6dac,0x6609edad,0x7d02c05c,0x5c15c5f1}},	//   _yari, rbek, _ctos, льну,
   {{0x6609edae,0x7d02c359,0xaca3c044,0xb5fb40a0}},	//   sbek, _dtos, mpịn, _znát,
   {{0x69cd0033,0x3af88107,0x7aebc006,0x634a803a}},	//   _ayae, _gép_, _tigt, _rəng,
   {{0xbcfb401e,0x7d1bc09d,0xfbd240c3,0x7af54140}},	//   _prél, psus, מתי_, _muzt,
   {{0x22b8806c,0xe8f7093d,0x6441c0cb,0x6484c321}},	//   nčka_, лля_, pfli, _còis,
   {{0x6e22c750,0x9c7c806f,0x291f8150,0x50b50f93}},	//   _zdob, _piči, _mvua_, ассу,
   {{0xb8dc02ea,0x3ea96daf,0x7c2ec018,0xd05c4561}},	//   _अद_, fiat_, óbre, _girə,
   {{0xb29546b1,0xd838c247,0xe3b0c7ce,0x41c5025d}},	//   ајућ, viči_, _بره_, ụsị_,
   {{0x7d04803f,0x799bedb0,0x44f9adb1,0x9f988185}},	// [2ee0] ģisk, nzuw, _nè_, vším_,
   {{0x66162db2,0x0717d57c,0x6296484f,0x219b01f2}},	//   _heyk, _दबाव_, shyo, _נביא,
   {{0x1bba4032,0xbcfb001e,0xe7f54027,0xa6e9835d}},	//   رائع_, nvén, ेड़ा_, _thự,
   {{0xdb1e82cb,0xa5bb42b0,0x7b204066,0x443a0449}},	//   _évén, _idón, _náuš, _hcp_,
   {{0x44f9823f,0x81a8c079,0x273c4ec2,0xe7b3001c}},	//   _cè_, _খুন_, sín_, _نمید,
   {{0x2a60454a,0x273c671b,0xd838edb3,0x39404007}},	//   ldib_, pín_, piči_, mtis_,
   {{0x9f988066,0x2ba78894,0x66198036,0x6e240112}},	//   pším_, _केदा, bawk, _odib,
   {{0x6f034016,0x6b8100d9,0x44235425,0x62808157}},	//   ínce, ølgi, _zdj_, _uomo,
   {{0x0caac495,0xbddb4031,0x9486c119,0x3f8a0066}},	//   етни_, _abèj, гынд, hybu_,
   {{0x68ee4283,0x39404007,0x7aed2db4,0x64948061}},	//   _jibd, itis_, _siat, _dàic,
   {{0x29120303,0x61ea0080,0x54774052,0x6d59e176}},	//   _awya_, əllə, אגיע_, _eswa,
   {{0x20c98359,0x7bce4177,0x7f5a81d6,0x6b814060}},	//   búis_, _mybu, _istq, _àlge,
   {{0x984b00c5,0x3ea6c0d9,0x2a6041c8,0x6da3cd37}},	//   нява_, _imot_, ddib_, _лица,
   {{0x859bc093,0x656941be,0x92b50079,0xa49b6db5}},	//   _אשדו, _šeho, ঝতে_, _atòn,
   {{0x7aed0031,0x32191e83,0x569503d0,0x439400a9}},	//   _tiat, pasy_, _вайт, барс,
   {{0x44446db6,0x2b5a00d2,0x6d40c68e,0x8c440080}},	//   ef_, _dspc_, otma, əşmi,
   {{0x25f64374,0x7c3aadb7,0xd6d845bf,0x99990026}},	// [2ef0] ौड़ी_, _octr, утр_, resų_,
   {{0x443a021b,0x6d4d2db8,0x634a803a,0xe3b88165}},	//   _gcp_, _ipaa, _mənb, _adım_,
   {{0x2a6045bb,0x20d4404c,0x60c56db9,0x3ea6c199}},	//   bdib_, päin_, rohm, _omot_,
   {{0xed598654,0x9c7c96fd,0x60c7013b,0x628f0127}},	//   _psž_, _miču, lojm, nkco,
   {{0x645e2a24,0x2b4c8060,0xe1f88039,0x6d40c0a0}},	//   _yapi, _apdc_, угі_, jtma,
   {{0x44f983e2,0x656d8166,0x64900051,0x3cfc0009}},	//   _vè_, ťaho, _näil, עלונ,
   {{0x7af72dba,0xe1f1c1b4,0x2eed80cb,0xe299c2db}},	//   _juxt, يسة_, _tief_, как_,
   {{0x7af70080,0x0685d2bf,0xa3dec0a0,0xdce2c247}},	//   _muxt, ргин, _běží_, _droč,
   {{0x225fedbb,0xc5f40020,0xdbe20109,0x0419c02a}},	//   rduk_, _saɓo_, _खण्ड_, _দাবী_,
   {{0xbcfb6dbc,0x22490303,0x752d4018,0x22b60017}},	//   _arék, _abak_, iraz, tāko_,
   {{0xbb45ed40,0x660d64af,0x7644403a,0x798b81f4}},	//   шенк, kbak, yfiy, lygw,
   {{0x7c250e89,0x39404111,0x9c7c8053,0x316901ff}},	//   _adhr, ytis_, _chčf, _braz_,
   {{0x19ba143c,0x660d4415,0xfd654112,0x7d0946a6}},	//   тунь_, dbak, rosọ, _çesh,
   {{0xa5bb4031,0x224900f8,0xc19ac0c3,0x37e5d702}},	//   _adóo, _ebak_, _בשני, _колг,
   {{0x2b4c821b,0x2abac017,0x93bc80b4,0x4425adbd}},	//   _xpdc_, lība_, _scăz, _mdl_,
   {{0x660d6dbe,0xcf928009,0x752d459b,0x98a4c007}},	//   gbak, קטן_, fraz, rumą_,
   {{0x66d62dbf,0x6e366dc0,0x31692dc1,0xe1f74f9d}},	// [2f00] láko, rgyb, _graz_, ргу_,
   {{0x6e3641f4,0x6490009d,0x764987f2,0xa494001c}},	//   sgyb, _käim, _abey, _ایست,
   {{0x752d6dc2,0x7ae2959a,0xf1aa1e85,0x225f8013}},	//   araz, tmot, _चेतन, _bauk_,
   {{0x7bce4066,0x6b8344d3,0x5506800e,0x83fc8011}},	//   _vybu, änga, ачка, _mađe,
   {{0x44fbedc3,0xdce2c451,0x7bce4036,0xc05a80d9}},	//   _nê_, _sroč, _wybu, вій_,
   {{0x7af70070,0x3afc00d1,0x394d2dc4,0xd007662e}},	//   _yuxt, _kíp_, çesi_, _вере_,
   {{0x44258c7c,0x92d84079,0xfdd30045,0x69d9c966}},	//   _ddl_, াদী_, _सर्फ, _azwe,
   {{0x6b8306ed,0x20186dc5,0x6284023f,0x6d40c9be}},	//   _ànge, _heri_, _noio, ttma,
   {{0x7d06405c,0x9f5e8580,0x44fbc1ff,0x66f18017}},	//   _jtks, _petó_, _cê_, _sākt,
   {{0xd8388077,0xdce2c7ca,0x6296011c,0x20c98359}},	//   _omči_, _troč, _alyo, súir_,
   {{0xa3e28a89,0x7e7d005c,0x69d9c0f7,0x7e038112}},	//   नेश_, tjsp, _ezwe, _ọsis,
   {{0x7ae4411a,0x7bdaadc6,0x2a600a5e,0x3869c360}},	//   jmit, _iztu, _caib_, _ɗari_,
   {{0xaae5c49f,0x6d42adc7,0xf8bf0107,0x3eab2dc8}},	//   _اسلو, ntoa, nség_, rict_,
   {{0x752d4487,0x6d429213,0x7c388a26,0xb5fb41ff}},	//   vraz, itoa, ngvr, _anáp,
   {{0x82a7410e,0x8aa76dc9,0x443cc6ed,0xd4c5c1b4}},	//   ашае, арад, _icv_, _اغني,
   {{0x60c700fd,0x442d22fc,0xf8bf001e,0x20184580}},	//   sojm, şe_, tués_, _aeri_,
   {{0x6b5c0300,0x7aef57ba,0x9f4a402e,0x7e62823f}},	// [2f10] _pågå, _vict, _agbà_, ddop,
   {{0xa3d78fb2,0x2906c150,0x4498410e,0x20184265}},	//   _सरल_, _mtoa_, авую_, _ceri_,
   {{0x64552dca,0x7e608ca0,0xb65a01c0,0x21204033}},	//   mezi, _bamp, _akẹ́, asih_,
   {{0xb87b443d,0x2ef84101,0x29094051,0x2018489f}},	//   _juíz, _durf_, ppaa_, _eeri_,
   {{0x63bb038a,0xbebd003f,0x66d60089,0x661bd3fa}},	//   ğunu, brīv, záko, vauk,
   {{0xbebd003f,0xaf37478a,0x58d440c5,0xe7875702}},	//   nsīb, _پرست, _моят, _кубо,
   {{0x661bedcb,0x20014789,0x661d2dcc,0xbb8541b4}},	//   tauk, mchi_, kask, _الزي,
   {{0xb5fdac38,0x13b80093,0x291fedcd,0x2001578b}},	//   _baše, יהול_, tsua_, lchi_,
   {{0x798d6dce,0x6d5b8e6e,0x64552dcf,0x6d428119}},	//   nyaw, _usua, kezi, ctoa,
   {{0x7ae44408,0x64552dd0,0x291fc056,0x7e60add1}},	//   zmit, jezi, rsua_, _zamp,
   {{0x7e60add2,0x66dd05ca,0xe643c2d6,0xbcfb4145}},	//   _yamp, zéke, şmış, _dréi,
   {{0xbebd003f,0x212dc0fd,0x24858ded,0x44fd14fd}},	//   esīb, preh_, _holm_, _bì_,
   {{0xe3b1c0fe,0x290d0119,0x6aa9add3,0xbcfb529a}},	//   ترک_, ţean_, _mmef, _fréi,
   {{0x66dd005f,0xf1b9c4d6,0x2120441b,0x3ea90396}},	//   véke, gaše_, vsih_, _emat_,
   {{0xf8bf0107,0xddc9c077,0x38610085,0x31668089}},	//   zség_, njež, _dahr_, zvoz_,
   {{0x86994a0b,0xb21b0065,0x629bc051,0x2a7fc077}},	//   атут_, skær, nhuo, njub_,
   {{0x64552dd4,0x3219442c,0x634a803a,0x66042dd5}},	// [2f20] bezi, _desy_, _məna, _ifik,
   {{0x645500c5,0xaa7b4166,0x7e108dd0,0x3eadedd6}},	//   cezi, _chýb, ार्ग_, hiet_,
   {{0x69db8070,0x3eadedd7,0x41cec185,0xa2c4a00d}},	//   _azue, kiet_, _हुनस, िकल्,
   {{0x7e628303,0xb4db0016,0x2120411f,0x8c14802a}},	//   udop, ntàn, psih_, _সাইন_,
   {{0x2723c59a,0x44fd0015,0x763b0009,0x98a04639}},	//   hın_, _xì_, רענג, jrić_,
   {{0x6ab2ce18,0x98a04a11,0x6d444022,0x9f4a4031}},	//   ुक्र, drić_, mtia, _egbá_,
   {{0x66042dd8,0xb8ff82ea,0x3f418018,0x321d8036}},	//   _ofik, _धी_, góu_, bawy_,
   {{0x6d428709,0x68f9c17b,0xb5fd87b3,0x634a8080}},	//   ptoa, _buwd, _paše, _cəna,
   {{0xdee38051,0xb5fd8c9c,0x66d88066,0x9098ea1b}},	//   _хоти, _inšp, líko, ивит_,
   {{0x661d0782,0x0907c079,0x3ea912be,0x415b4009}},	//   wask, _শিশু_, _smat_, נדיג,
   {{0x7bda803f,0x75242dd9,0xf1b9c1be,0x2723c06a}},	//   _uztu, _aviz, vaše_, gın_,
   {{0x98a049fa,0x628644f5,0x05dc89cb,0x629bedda}},	//   brić_, _noko, _बराब, chuo,
   {{0x66dd0107,0xe29800d7,0xdceb002d,0x443e81ff}},	//   tékb, саў_, žičo, _kct_,
   {{0x661d2ddb,0x2723c2d6,0x98a940ab,0x7afaaddc}},	//   sask, bın_, trač_, _kutt,
   {{0x66028033,0xd2d74032,0xf8bfc01e,0xdce2806f}},	//   kcok, مغرب, éée_, jvoč,
   {{0x645500f7,0x7d79005f,0x66d88574,0x7c2d809c}},	//   sezi, _نمبر_, díko, ɗaru,
   {{0xe1f04032,0x764d1e6e,0x3a290031,0xdddbc0e5}},	// [2f30] فسك_, _ibay, _idap_, zkuž,
   {{0x64900025,0x6d5f1ec0,0x443eaddd,0x7b1900b4}},	//   _näih, _isqa, _nct_, _коор_,
   {{0x6286405f,0x752400ab,0x9df9a7aa,0xadfd0027}},	//   _foko, _zviz, анет_, _एलान_,
   {{0x7c288093,0x443e80c3,0x316b4011,0x7ddf002e}},	//   _addr, _act_, _trcz_, _gàsí,
   {{0x764d2b98,0x7afa804c,0xa2c7c281,0x3eb90093}},	//   _mbay, _autt, ावस्, inst_,
   {{0x0f1b405f,0x1869a0a6,0x3eadedde,0x2bd9408c}},	//   _مغرب_, раки_, wiet_, _نازک_,
   {{0x28abc260,0xa5c38064,0x543c0009,0xa3dd0048}},	//   टोफि, _łódz, טעגא, तेच_,
   {{0x22494056,0x6490054a,0x98a0491c,0xf78ac06a}},	//   nfak_, _päik, trić_, _maçı_,
   {{0x2ee001f4,0xc985c032,0x3a3f80d2,0x7ce00dd1}},	//   _rhif_, تشغي, _icup_, löre,
   {{0x2ed2042f,0x64900834,0x7d0983e0,0x764d026d}},	//   सत्त, _väik, _ites, _abay,
   {{0x6d5f22d7,0x7afa84f5,0x22494033,0x7ce00041}},	//   _asqa, _gutt, kfak_, nöre,
   {{0x395dc022,0x68fb9a69,0x3eafaddf,0x645759da}},	//   _tsws_, _kuud, nigt_, hexi,
   {{0xb4db06ed,0x7c3e0077,0xdce280e5,0x6e298398}},	//   rtàn, _pcpr, zvoč, _mdeb,
   {{0xb4db06ed,0x7ce00d88,0x661b9e2e,0xb87b4580}},	//   stàn, köre, _leuk, _guíx,
   {{0x290dede0,0x656d2de1,0x3eaf84c9,0xe739c0b4}},	//   lpea_, _erah, kigt_, _тей_,
   {{0xa3a9008f,0x660420b4,0x26cb2de2,0x7d098066}},	//   _खेळ_, _ufik, coco_, _otes,
   {{0x7e646de3,0x7ce02110,0x83fc8451,0x6494829a}},	// [2f40] rdip, törd, _lađa, _bàil,
   {{0x62866de4,0x6494829a,0x40960b0c,0xec774ecc}},	//   _woko, _càil, _фрит, опу_,
   {{0x7ce02cfe,0xc815411b,0x160a8032,0x66dd2de5}},	//   göre, яєть, لياً_, léka,
   {{0xf8bf001e,0x7c2dc020,0x443eade6,0x62866de7}},	//   rsée_, _ɓara, _sct_, _uoko,
   {{0xc9838051,0x7649c02c,0x7d0980d2,0xddcd00b5}},	//   дущи, dfey, _ctes, _maaş,
   {{0x67238639,0x6c7a0009,0x752445b6,0x2bcfc7ec}},	//   fsnj, שאַפ, msiz, _सुभा,
   {{0x179a0052,0x75244a1f,0x0eca14f7,0x66dd0396}},	//   ייַב, lsiz, रवाड, héka,
   {{0x6d46159a,0x2240005c,0x6496c0b4,0x6e3bede8}},	//   ktka, _ncik_, _câin, ggub,
   {{0x2487c141,0x9c7c8141,0x7afc6de9,0xa50794cf}},	//   _bonm_, _chčc, _hurt, _мета_,
   {{0xa49b03bc,0xb87b4018,0x75245c8a,0x656d00fd}},	//   npòt, _quíx, isiz, _rrah,
   {{0x7e640112,0xe3e881aa,0xa2c7ecc7,0x0206c0d7}},	//   _baip, _اکشن_, ावश्, _дзен,
   {{0x7e642dea,0xc5f406df,0xeeab2deb,0xc6a700d9}},	//   _caip, _zaɓi_, рток_, ірни,
   {{0x28df8109,0x7afc5702,0xfd4e40eb,0xc86703dc}},	//   _पीडि, _lurt, rikọ, отви,
   {{0xf8ca8027,0xe7e18185,0x769cc031,0x656d0089}},	//   ाकिय, गेका_, _déye, _vrah,
   {{0x7ce004d3,0x6e951bb0,0x2249406a,0x69d6c0d9}},	//   förb, _нику, tfak_, _øyeb,
   {{0x539bc0c3,0xdea8c09c,0x9df9495c,0x8ca6c045}},	//   _כיוו, _ƙoƙo, снат_, टोरो,
   {{0xb5fb090a,0x550740c5,0x3ebe4086,0x7a440107}},	// [2f50] ndám, ючва, étta_, sító,
   {{0xfd62c0eb,0xb92040eb,0xe4d9001c,0xb5fb0107}},	//   _satị, larị_, _دوخت_, zdál,
   {{0x67388011,0x7e6402c0,0xd37b4039,0x39b800eb}},	//   juvj, _yaip, шча_, ọst_,
   {{0x67388514,0x7ce01e9d,0x7ae2c112,0xe0df43e2}},	//   duvj, röre, _nhot, _apòt_,
   {{0xc6174705,0x6e20edec,0x2a6480d2,0xd0098f29}},	//   तरीय_, damb, _damb_, беле_,
   {{0xb5fd8199,0x22b60017,0x80a880d9,0xb9204094}},	//   _daša, rāki_, овів_, harị_,
   {{0x8cba48b8,0x6496c0b4,0xf1b9c011,0xb18644c9}},	//   ्वरो, _pâin, daša_, _tvåå,
   {{0xa5bb5792,0xba77800f,0x395f8022,0x224d807a}},	//   _adói, _باست, _tsus_, _ubek_,
   {{0xf1b998ca,0xaca3800c,0xc7b88a93,0xa3d78374}},	//   _beše_, _quỳn, _ređe_, _सरक_,
   {{0x201ccbe2,0xa5bb47c9,0xfd648044,0x68f56ded}},	//   _cevi_, _teóf, _larị, _jizd,
   {{0x6490054a,0x5f05c0d7,0xb5fd8011,0x61f10080}},	//   _käiv, язна, _zaša, ədlə,
   {{0xa5bb4070,0xa7fcc696,0x869a001d,0x6d46056d}},	//   _geóg, ldıl, стот_, ttka,
   {{0xc7b8c7ca,0x27084138,0x7e641139,0xdd1501af}},	//   rađa_, _iğne_, _vaip, _púšt,
   {{0x2bc6c027,0xe0d8c0d9,0x7e6402c0,0xdf944031}},	//   _रुका, _дві_, _waip, _bọ́s_,
   {{0x96965b04,0x09b88048,0x66dec0fd,0xf1afc54a}},	//   праш, _अश्य, lëka, _जेतन,
   {{0x6abbedee,0xd5ad005f,0x3ebf8bdb,0x67255b31}},	//   nnuf, اہی_, _njut_, dshj,
   {{0xf539c166,0x67388514,0xd00f005f,0x3a204032}},	// [2f60] nuť_, zuvj, ئلہ_, raip_,
   {{0xc17302a6,0xe1ff066c,0x244f8530,0x66044494}},	//   _נחת_, ndón_, nımı_, scik,
   {{0x3ebf80f6,0xdb2402f0,0x22b8804f,0x0af9c02a}},	//   _bjut_, _توجی, lčki_, _আবুল_,
   {{0x7659814b,0x7b05002d,0x6441adef,0xf8bf0fda}},	//   gewy, žuté, _acli, brés_,
   {{0xf8bf01cb,0x3946adf0,0x7c21cb44,0x7ae414f9}},	//   crés_, utos_, kalr, _mhit,
   {{0x644e6df1,0x3ead8580,0x68f54011,0x7ae9c4f1}},	//   _ubbi, _emet_, _gizd, emet,
   {{0x7afc415d,0xf1b98a93,0x2a64adf2,0x644a802c}},	//   _uurt, _reše_, _tamb_, rffi,
   {{0xb9028079,0xbddb6df3,0xdb1c4036,0x9c7c805e}},	//   _নং_, _ibèr, _wyró, _dhča,
   {{0x22b8804f,0xf7f685ca,0xe5a380b4,0x7c2ac0b9}},	//   jčki_, _فساد, _зити, _pdfr,
   {{0x27f8c36b,0xf8cc4064,0x7ae9edf4,0x5f94c0a7}},	//   ørn_, ़किय, amet, диот,
   {{0xb5fda163,0x7ae9d343,0xf1b9c084,0x0f23d269}},	//   _mašn, bmet, raša_, ньям,
   {{0xfaa3c039,0xba17c032,0x7b978323,0xcfa9849f}},	//   _пахо, _فيما_, _מכבד_, _ظالم_,
   {{0x661d43bc,0x22592df5,0x7ae42df6,0x61fb09fa}},	//   _resk, resk_, _dhit, žulo,
   {{0x6562edf7,0x7c21c060,0xf8bf001e,0x5c73c589}},	//   _isoh, calr, vrés_, _пліт,
   {{0x7ae40755,0xb92040eb,0x6e228230,0x2a66c0b2}},	//   _fhit, parị_, kaob, _kaob_,
   {{0xf8bf030d,0x326440d9,0x7ae42df8,0x9ed94589}},	//   trés_, нтув, _ghit, імат_,
   {{0x443ec15d,0x64480016,0xf8b144e8,0x66dd0107}},	// [2f70] ogt_, òdic, نکس_, léko,
   {{0xa2c50444,0x3ea04010,0x661d6df9,0xf8bf1397}},	//   रवक्, ahit_, _wesk, rrés_,
   {{0x7ae9edfa,0xb5fd80b3,0x7afe0126,0x6e2d005c}},	//   ymet, _dašn, _gupt, _kdab,
   {{0x02a76151,0xddcd006c,0x35b59828,0xa3bc0048}},	//   _хром, _znaš, мбер, ेअर_,
   {{0xd126c0a3,0x67028044,0xbddb40ce,0xf19480d9}},	//   _جم_, _ọkpa, _ebèr, ниць,
   {{0x66dd0047,0xddcd017b,0x442c801e,0x69c04011}},	//   kéko, _abaŋ, _cdd_, _žmeg,
   {{0x66dd005f,0xa7fcc696,0x2298c303,0x673ad1ae}},	//   jéko, rdıl, _céko_, jutj,
   {{0xb3aa0079,0x39494039,0x6e2d0491,0xe7d0c285}},	//   _খুঁজ, otas_, _ndab, _हड़प,
   {{0x6efa4185,0x6490054a,0x9f5840ce,0x7ce00041}},	//   _vůbe, _käit, _agrè_, höra,
   {{0xb0bf47f6,0x290bc03f,0x648dc032,0x3ea040fd}},	//   ्विग, īca_, _rúis, zhit_,
   {{0x09ba4028,0x39496dfb,0x26cf806f,0x629d522b}},	//   _इश्य, htas_, oogo_, _olso,
   {{0x7d1b8044,0x2a694022,0x49148185,0x656d802d}},	//   _kwus, jdab_, नीको_, ťahu,
   {{0xe0ceedfc,0x44232dfd,0x81b0009c,0x244f806a}},	//   _ав_, faj_, _keɓi, pımı_,
   {{0x673aedfe,0x26cf9a59,0x7e69dbae,0xd84ec0d1}},	//   butj, hogo_, ldep, _họng_,
   {{0x7ce004d3,0x39496dff,0xcb670156,0x9f43c04c}},	//   göra, etas_, маре_, äjä_,
   {{0x39496e00,0x7996c036,0x26c0012c,0x68f70060}},	//   ftas_, _żywi, _ujio_, _eixd,
   {{0x76442e01,0x05630119,0xd84ec35d,0x00000000}},	// [2f80] _iciy, _авын, _mọng_, --,
   {{0x6d49cb90,0x3ea040da,0xb21b0065,0xb9370009}},	//   itea, shit_, hjæl, _קריג_,
   {{0xf99201aa,0x04434179,0x290d8320,0xb4da0036}},	//   _سبک_, техн, _atea_, ़ती_,
   {{0x7e69c329,0xe0cf857a,0x7bdc8061,0x3a2d901e}},	//   jdep, یزو_, _ùrui, _cdep_,
   {{0xfe798185,0x7e69c0f1,0xb5fd8590,0x6e245d64}},	//   _dnů_, ddep, _tašn, maib,
   {{0x6e2445ef,0x61fba176,0x645adc52,0x96f891d7}},	//   laib, _egul, xeti, пект_,
   {{0x26cf8ca0,0x66d182e9,0x660980bc,0x22b60017}},	//   bogo_, råkr, _ffek, nāks_,
   {{0xafe3411b,0x6490009d,0x2ec980c6,0x26c30077}},	//   _росл, _käis, िकृत, čkok_,
   {{0x442c80b6,0xdd8f8646,0x2bbe4185,0x6d49c032}},	//   _tdd_, _پول_, ्थवा, gtea,
   {{0xb17b4052,0x84e7c032,0xf74ac0d9,0x00e38156}},	//   קטיר, وفيق_, оїми_, _ажун,
   {{0xf8374093,0x7d00ae02,0x628bee03,0xdeb5004c}},	//   ונית_, _hums, _fogo, ебны,
   {{0x39494039,0x7d00ae04,0x6d49ee05,0x6b834f55}},	//   ytas_, _kums, btea, ängi,
   {{0x645c0e83,0x6490004c,0x6e246e06,0x1de2e9ca}},	//   feri, _näis, daib, _परित,
   {{0x7d00ae07,0x7ce01368,0xfb19c05f,0x673ac13b}},	//   _mums, töra, _کروں_, putj,
   {{0x1bd411f5,0x67d40c35,0x2a79405c,0xdfd800c5}},	//   воря, вору, _pnsb_, дът_,
   {{0x6e20ae08,0x2eca0707,0xdced05c7,0xf1b98158}},	//   _nemb, रवृत, _irač, _leša_,
   {{0x39495754,0x7d0d2e09,0xb5fd8077,0x3d950e13}},	// [2f90] utas_, _utas, _sašo, _чипр,
   {{0x673c0147,0x22b608c7,0x656d5664,0xb5fd9754}},	//   burj, sākt_, rvah, _pašo,
   {{0xb4bd0d46,0x649013c6,0x8704411b,0x753d0096}},	//   ेकी_, _väit, вяче, lusz,
   {{0x765d01f4,0xa3e28185,0x61e2ee0a,0x628d01ff}},	//   nesy, नेछ_, _ozol, _joao,
   {{0x61ad4079,0x6abd41f9,0xdd32003a,0xd90f44e8}},	//   _কুরআ, ्कीर, _məşq, _ضیا_,
   {{0x6e20802f,0xb5fd9763,0x32094573,0x765d00f8}},	//   _eemb, _zašl, lcay_, hesy,
   {{0xc7b88242,0xff519094,0xf1b98011,0x6445012c}},	//   _peđa_, اخت_, _deša_, _mchi,
   {{0x7c238f84,0x7ce0010d,0x26d9803c,0xc33400c3}},	//   sanr, jörn, _óso_, דוק_,
   {{0xd84ec015,0x645c2e0b,0x212941aa,0x7529ae0c}},	//   _vọng_, yeri, nsah_, _uvez,
   {{0x93bc8119,0x316dc0dd,0x7e698033,0x6e2090bb}},	//   _adău, rvez_, _haep, _zemb,
   {{0x628becf0,0x7e698a92,0x2d4984f2,0xe800c036}},	//   _togo, _kaep, lúe_, ोड़ा_,
   {{0x753bc150,0x442ecd4a,0xed5a13fb,0xe80b85da}},	//   puuz, _edf_, пом_, सुरा_,
   {{0xdb0a0185,0x2d4988ee,0xb5fd8242,0x26de0017}},	//   čníh, núe_, _našm, ēto_,
   {{0x62860011,0xddc400f6,0x2a6900b9,0x66d88086}},	//   sjko, _iniż, _eaab_, ríki,
   {{0xdced0aa2,0xd874ce40,0x25a6805c,0xb5fd8017}},	//   _grač, _جانب, zzol_, _pašl,
   {{0xdce2ca11,0x6441db39,0xdb1a8051,0x2129405c}},	//   _proć, lgli, _tytö, fsah_,
   {{0x6441ee0d,0x00e64e5a,0xee374007,0x6da34f4b}},	// [2fa0] ogli, ежан, энт_, гита,
   {{0x69d9ee0e,0x7d008d4d,0x645c00fd,0x44442e0f}},	//   _mywe, _rums, qeri, _uc_,
   {{0xf484416a,0x3ea0174d,0x2ef9405e,0xecc38036}},	//   _یاسی, _klit_, _fisf_, वचनफ,
   {{0x2a690022,0xa683420d,0x629d0007,0x1ea98032}},	//   _xaab_, _блюд, ūrov, واني_,
   {{0x3ebfc67d,0x26c06e10,0x7bc74560,0x3a24c4aa}},	//   dnut_, mnio_, _exju, vamp_,
   {{0x6e208fee,0x3ea00016,0x6e262e11,0x7c218580}},	//   _wemb, _llit_, hakb, _celr,
   {{0x645e6e12,0xf0930093,0x6f01ae13,0xcc3b0052}},	//   mepi, רנו_, _culc, לעסט,
   {{0x26c045f5,0x4425dcbe,0x6441d331,0x7d094480}},	//   nnio_, eal_, egli, _éesc,
   {{0x75f68561,0x7c21ae14,0x7646414d,0x69d9c32a}},	//   _düzü, _felr, _mcky, _cywe,
   {{0x182881aa,0x6f0180c4,0xb5fb2e15,0xdced0224}},	//   _آقای_, _fulc, ndáv, _prač,
   {{0x7ce0179d,0x765d014d,0xdfd0c032,0xda2044ef}},	//   törn, tesy, شيح_, बरात_,
   {{0x6441ee16,0x764289f4,0x2a692c0e,0x81b0009c}},	//   agli, ngoy, _qaab_, _leɓu,
   {{0x6aa46e17,0x3cfa0053,0x99c4402a,0x66dd0107}},	//   dhif, _bipv_, ্ধুক, lékk,
   {{0x765d1a27,0x7eb62d43,0x673e6e18,0xb866cc31}},	//   sesy, ršpa, kupj, _ساتو,
   {{0xbcfb4107,0x29024ae6,0x420e4094,0xdc7401dc}},	//   _esél, _auka_, _ọsọ_, ыгры,
   {{0x44212e19,0x4975058f,0xb5fd8017,0x6aa44157}},	//   _weh_, _алис, _pašm, ghif,
   {{0x19584efa,0x2902618a,0x634a803a,0x25b700fb}},	// [2fb0] наты_, _cuka_, _dəni, _سندھ_,
   {{0x64451ae2,0x7e69ae1a,0x2abac017,0xa8020189}},	//   _uchi, _saep, mību_, şırd,
   {{0x7aed4314,0x7aedc1af,0x2129406d,0x7e699021}},	//   pmat, ňati, ssah_, _paep,
   {{0xa2c24185,0xdce400ab,0x2902601d,0xb5fd806f}},	//   रचण्, _prić, _fuka_, _tašm,
   {{0x4425ee1b,0x8d658025,0x645e6e1c,0xf61800c3}},	//   yal_, твле, bepi, תחדש_,
   {{0x212b00fa,0x2d498004,0xdce40011,0x75f6850c}},	//   isch_, rúe_, _vrić, _süzü,
   {{0x9f47404c,0x6e22c0fa,0x753c803f,0x4c9286b1}},	//   änä_, _beob, _ārze, ријс,
   {{0x628f6e1d,0x6f094347,0x2246c303,0x3959406a}},	//   _joco, _čech, _ccok_, _kpss_,
   {{0x44234d57,0x0682c0b4,0x50f58887,0x6609e9d5}},	//   _kej_, ргын, _азат, rcek,
   {{0x26c041be,0x2ebc05de,0x97a78b73,0x7529ee1e}},	//   znio_, ोक्त, _прел, rsez,
   {{0x6d4d404c,0x6441eca4,0x61e4005f,0x7afbae1f}},	//   htaa, rgli, _szil, _kiut,
   {{0x6d4d6e20,0x7afb8070,0xe29a0768,0x5a960f99}},	//   ktaa, _jiut, фам_, троф,
   {{0x442780fc,0xb5fb0066,0x291dc112,0x645e4230}},	//   oan_, zdáv, _uwwa_, yepi,
   {{0x26d2431c,0xf1b98451,0xe8f70749,0xf770c01c}},	//   woyo_, _lešo_, кля_, _گاه_,
   {{0x6443ae21,0x628f4a98,0x752d2b99,0xadc34031}},	//   igni, _boco, _evaz, _ibẹb,
   {{0x38ad02bc,0x2a6dc1f4,0xf65f03e2,0x7e6d4105}},	//   džru_, ndeb_, ceæ_, gdap,
   {{0x6f03d82f,0x443142bc,0x44236e22,0x645e6e23}},	// [2fc0] _hunc, _bdz_, _bej_, tepi,
   {{0x7e6bc340,0x7c3b40e2,0x7ae9ab02,0xdd8f561e}},	//   _lagp, _ɓurg, _ahet, غول_,
   {{0x7c23c056,0x26c31684,0xc7a6011b,0x3f9c4066}},	//   _menr, čkov_, _ринк, ávu_,
   {{0x78a18e62,0x6d4d4057,0x63bc8f26,0x7bda9286}},	//   _allv, btaa, _žrno, _rytu,
   {{0xa027c02a,0xb5fd8089,0x394dee24,0x83fcc0ab}},	//   _মানব_, _zašk, jtes_, leđe,
   {{0x61e64c09,0xdd938007,0x66d8810d,0x659383fe}},	//   _izkl, рашы, víku, рашу,
   {{0x39406e25,0xf2c6ce97,0x7afbae26,0x2abac017}},	//   luis_, ксин, _fiut, zību_,
   {{0x628f46ed,0xdce28458,0x83fc87ca,0x4423404d}},	//   _xoco, kvoć, _mađi, _zej_,
   {{0xa5bb4004,0x7e6bee27,0xe9d78798,0x44234022}},	//   _león, _dagp, _акт_, _yej_,
   {{0xc7b8c5c7,0x7ce014a6,0x2ee90056,0x9873cbe0}},	//   lađi_, förm, _shaf_, альц,
   {{0x2904a107,0x83fcc539,0x39406e28,0x29122e29}},	//   _huma_, jeđe, huis_, _atya_,
   {{0x394dee2a,0xb5fd8054,0x7d042e2b,0x83fc82a3}},	//   btes_, _rašk, _buis, _nađi,
   {{0xaca46e2c,0x212b00cb,0xe29800d7,0x7e60c627}},	//   _apọs, usch_, таў_, memp,
   {{0x6abd45a3,0x2abac017,0xd197c21d,0x394047b0}},	//   ्क्र, rību_, _בכדי_, duis_,
   {{0xff04123a,0x644880b3,0xb6076e2d,0x28f80441}},	//   иятн, _mcdi, вязк, терь_,
   {{0xa3ca854a,0x44236e2e,0x5f94161d,0x290482a4}},	//   _लखन_, _sej_, шист, _ouma_,
   {{0x2904801b,0x7afbae2f,0x644381e5,0xf1b98077}},	// [2fd0] _numa_, _riut, ygni, _rešo_,
   {{0x7afb91f9,0x7e6d0c99,0xb4bf603c,0x34bf4945}},	//   _siut, _haap, ुके_, ्वेद,
   {{0x7e60ee30,0x7afbae31,0x5f950651,0x439503bf}},	//   kemp, _piut, _синт, _санс,
   {{0x1de2d06a,0x7c28ee32,0x83fcc077,0xa3d68374}},	//   _परंत, hadr, ceđe, _सड़_,
   {{0x394dc2cb,0x44444077,0x298453fa,0x05844119}},	//   xtes_, bg_, _кырг, _курм,
   {{0xb5fb005f,0x9f05438b,0x7ae98093,0xed598011}},	//   ldás, _موسو, _whet, _vpž_,
   {{0x3a248018,0x6443aa0e,0x6aa2ee33,0xc4d24916}},	//   _femp_, rgni, _blof, _הגם_,
   {{0x69dd6e34,0x6f03ee35,0x7afd6e36,0x7c250600}},	//   _kyse, _runc, _jist, _lehr,
   {{0x6e242e37,0x7c23c02c,0x673ad11b,0xf1b79527}},	//   _reib, _penr, ertj, _अधिन,
   {{0x20010015,0x7c2500be,0x6e242e38,0x98a00b1b}},	//   _nghi_, _nehr, _seib, _ivić_,
   {{0x7d041ee8,0x7ce004d3,0x2d82c041,0x6f030004}},	//   _suis, börj, äker_, _énch,
   {{0x6d4f1c6a,0x634a803a,0x4433248d,0x66f58e64}},	//   ftca, _cənu, _adx_, ेदिक_,
   {{0x673ac0bf,0x6d40ee39,0x83fcc077,0x6e240125}},	//   artj, cuma, veđe, _veib,
   {{0x55bac093,0x65760b45,0x661bc09e,0xa5bb403c}},	//   _אמנו, _vryh, lbuk, _peón,
   {{0x4f952e3a,0xf8b28093,0xc7950007,0x83fcc2a3}},	//   арту, משך_, арты, teđe,
   {{0xc61e0079,0x86460051,0x64454157,0x2aa20031}},	//   _থাকা_, _сниж, eghi, _fóba_,
   {{0x7644409e,0xee3703d0,0x661bc12c,0xecea64a0}},	// [2fe0] rgiy, _сны_, ibuk, едал_,
   {{0xb46607de,0xf1b9ee3b,0x2a7f80f8,0xb5fd80ab}},	//   _скол, gaši_, _anub_, _gaši,
   {{0xef1a41bc,0x3ea697fb,0xe29a406f,0x65699443}},	//   хме_, thot_, _зан_, _aseh,
   {{0xb4db0016,0xfbd30093,0x7e60cfd0,0x753bc2a3}},	//   gràf, _לתת_, xemp, kruz,
   {{0x61e64017,0x82d70052,0x26138027,0x753bc570}},	//   _uzkl, נונג_, दड़ी_, jruz,
   {{0x6accc9fd,0x40954217,0x6aa4002c,0x6d40ee3c}},	//   ाव्र, _крст, _llif, vuma,
   {{0x649485ef,0x6aa2c078,0x20075a5b,0x07d8401c}},	//   _bàir, _plof, žnic_, _شهرک_,
   {{0x2904ae3d,0x3942054a,0x60c381b4,0x7c28ee3e}},	//   _tuma_, kuks_, annm, wadr,
   {{0x5e9381b4,0x6e26406f,0xb4c1d08d,0x91e3811b}},	//   _القط, _mekb, ्कू_, _готе,
   {{0xfc46c047,0x7e6282aa,0x3b54c59d,0x64948061}},	//   _číst_, leop, акор, _eàir,
   {{0x44330498,0xda6fde4d,0xb5fd8e5a,0x2d9902a4}},	//   _rdx_, _ля_, _raši, wyse_,
   {{0xb5fd8199,0x7c252e3f,0x2d990007,0x649485ef}},	//   _saši, _sehr, tyse_, _gàir,
   {{0x3eb92e40,0xa2d3c01c,0x6602ee41,0xe1ff0036}},	//   rist_, _اينت, _igok, zdów_,
   {{0x44250032,0x200ec5d4,0x69dd6e42,0x3076c6b1}},	//   úl_, _uffi_, _ryse, _људс,
   {{0xe7841562,0x81b8802a,0xfb840523,0xf1b9c011}},	//   буто, _ঘুম_, бытн, vaši_,
   {{0x7c2500cb,0xc98763ed,0x2906c12c,0xa3d84045}},	//   _wehr, лузи, _kuoa_, ाथन_,
   {{0x7c252e43,0xbbe18185,0x44330016,0xb5fdc04f}},	// [2ff0] _tehr, _फर्क, _tdx_, peše,
   {{0x7afd6e44,0x26155527,0xe8d90112,0x7d0640fd}},	//   _wist, _फ्री_, _mpị_, _duks,
   {{0xdce44570,0x04c84032,0x7ced85c5,0x00d85006}},	//   zvić, دولي_, lúrg, ابقت_,
   {{0x6d5b805c,0xb4db0016,0x6447013b,0xd246c7d8}},	//   _ppua, ctàr, lgji, _ظن_,
   {{0x070bc2f6,0x7aff00fd,0x7ce00041,0x7ceb4189}},	//   _संभव_, _miqt, förh, türd,
   {{0x6602c40d,0xd49180d1,0x7c2a8397,0xddc980f6}},	//   _agok, _tìm_, gafr, _ineż,
   {{0xddc40007,0xdb2182d6,0x98a04007,0x25dc13a2}},	//   _maiš, _ötür, usią_, _गुनी_,
   {{0x6d428340,0x3ea96e45,0x7522ee46,0x6595917a}},	//   buoa, nhat_, _bwoz, _кабу,
   {{0x77670046,0x67248570,0x95cb80a9,0xca4883a9}},	//   hwjx, ćija, _чува_, _حلقه_,
   {{0xddc40068,0x4095c051,0x26c901c0,0x7aed2e47}},	//   _naiš, ррит, _ajao_, _ahat,
   {{0x6a860445,0x2bcfee48,0xfbcfee49,0x7522c0b6}},	//   ална, _सुखा, _सुखम, _ewoz,
   {{0x6d5d6e4a,0x644ac0f6,0x7c2740b0,0x291d4112}},	//   _opsa, _ecfi, _lejr, ̣waa_,
   {{0x6fdb0021,0x3ea96e4b,0xee37022b,0x2d8f4136}},	//   _मुबं, dhat_, шня_, ägel_,
   {{0x5c07c1a4,0xdbcf80a0,0x74160ec0,0x913ac323}},	//   _сяда, _lžíc, شورا, _יענק,
   {{0x4cbac093,0xbcfb4066,0x7aed04ff,0x3942009d}},	//   _במסג, _fréz, _fhat, suks_,
   {{0x6d5d4639,0x7c35405c,0xee376e4c,0x3942054a}},	//   _bpsa, _adzr, инс_, puks_,

   {{0x6604000d,0xec4a40d5,0x386300b3,0x61465133}},	// [3000] _igik, кзал_, bejr_, реза,
   {{0xbcfb4053,0x7524c138,0x659b01f2,0x4c83401d}},	//   _kréy, _çize, _סייק, олув,
   {{0x80a604e8,0xadffc027,0x14594026,0xa06742a5}},	//   _ممکن, _उलझन_, ышты_, раха_,
   {{0x61464119,0x1756c009,0xc756c0c3,0x250845d3}},	//   _кема, יסער_, ייעץ_, _مرسی_,
   {{0x7ce02e4d,0x8e570323,0x7e6442c0,0x7e6293ec}},	//   törh, שינג_, meip, reop,
   {{0xa0a6423d,0x26125337,0x7ceb6e4e,0x7e64630d}},	//   _тагд, धुरी_, türe, leip,
   {{0xfaa6c2b3,0xe787c066,0x8aa6c4c4,0x9f4a402e}},	//   ишин, yšší, ирид, _egbò_,
   {{0xdc2e403a,0x6280ae4f,0x634a8080,0x6447013b}},	//   _yığm, _unmo, _səns, zgji,
   {{0x6d444379,0xf8af8107,0x75240141,0x4efb80c3}},	//   nuia, سکے_, _nwiz, _יהלו,
   {{0x66042538,0x3ea94107,0xa3eac09d,0xed5740c3}},	//   _agik, zhat_, _मरद_, סביר_,
   {{0xe4794009,0x75242125,0x63adc6df,0x78bc2e50}},	//   אָרש, _awiz, _ƙana, dirv,
   {{0x7524000d,0x78baee51,0x6abbc157,0x7c28ae52}},	//   _bwiz, sitv, ciuf, _hedr,
   {{0x6f088655,0x91e3c858,0x65764089,0x661d114e}},	//   _hudc, _доце, jvyh, rbsk,
   {{0x3944c03f,0x7cedae53,0xfa234079,0xf1b9c06f}},	//   mums_, rúrg, _ফাইল_, gašu_,
   {{0xd6db5aec,0x787c04d3,0x6282d11b,0xb5fb0032}},	//   вта_, _såvä, _knoo, ceán,
   {{0x38a44041,0x26c90150,0x6e360036,0x27e38065}},	//   _röra_, _ujao_, _gdyb, _øjne_,
   {{0xb4db0016,0xc7b8c7ca,0xe4e70289,0x7c28802c}},	// [3010] tràd, rađu_, _вінн, _oedr,
   {{0x78bc0018,0x3d1d4031,0xa9c4431e,0xf53f0041}},	//   cirv, _aáwò_, істк, mrå_,
   {{0x29090033,0x3d1d41c0,0x25adee54,0x81e9002a}},	//   _huaa_, _báwò_, zzel_, _বলি_,
   {{0xdb038066,0x7ea60086,0x7ae2853e,0x7f4380c4}},	//   jzná, _kópa, glot, vunq,
   {{0x6e2b8b51,0xee38893d,0x2bdb0064,0x66c803a6}},	//   ragb, рні_, _मुता, dıkl,
   {{0x2bcfd32e,0x81e90079,0xb4d0c185,0xd83b8097}},	//   _सुझा, _বলা_, वको_, тэд_,
   {{0x6aa9ee55,0x3d0cca3c,0xddc400b4,0xa7fcc0b5}},	//   thef, _डूबे_, _obiş, zdır,
   {{0x1e85c217,0x29010c99,0x25adee56,0x442cc99e}},	//   слим, _liha_, tzel_, ead_,
   {{0x6abd0283,0x77e40021,0x2bcfc42f,0xcfe404fb}},	//   disf, _गर्क_, _सुजा, _गर्भ_,
   {{0x3ea041a8,0x25adee57,0x1287c01c,0xf65f4211}},	//   zkit_, rzel_, امکی_, _sjæl_,
   {{0x6e2d6e58,0x7ced80e1,0x25add8d3,0xa22a0051}},	//   kaab, gúre, szel_, лжна_,
   {{0x26d92422,0x39524051,0x6448ca26,0x6e298149}},	//   goso_, ytys_, agdi, _jeeb,
   {{0x6e298b32,0xf1bf4032,0x7d01ae59,0x29012e5a}},	//   _meeb, _seán_, _kils, _biha_,
   {{0x395f8303,0x7649c138,0x1d07042e,0x29090398}},	//   _mpus_, lgey, сери_, _duaa_,
   {{0x03a30051,0x765b831c,0x23d22e5b,0xb5fb0032}},	//   пиро, _obuy, _दुखद, leál,
   {{0x752401c6,0x598600d9,0x6e2d6e5c,0x3ea0535f}},	//   _twiz, _глиб, gaab, ukit_,
   {{0xf1b9c0b3,0x213fee5d,0x7e6600eb,0xb1138044}},	// [3020] pašu_, nruh_, mekp, wụnw,
   {{0x6d4453f3,0x29010f2d,0x673e4451,0x20074011}},	//   ruia, _giha_, trpj, žnin_,
   {{0xe61a9fa6,0x7ce00041,0x3a29005c,0xc815411b}},	//   где_, förv, _yeap_, юєть,
   {{0x6b834041,0xcf254032,0x7d01ae5e,0x629619da}},	//   ånga, تركي, _ails, _joyo,
   {{0x6f08802d,0x7cf0409d,0xb95686b1,0xc213421d}},	//   _sudc, järg, стећ, _מהר_,
   {{0x224d842c,0x307a0009,0x442cc1c8,0x3944c017}},	//   _ecek_, ראַנ, xad_, vums_,
   {{0x7d01ae5f,0x7ae440b2,0x6e29ae60,0xf7434293}},	//   _dils, olit, _feeb, _неро,
   {{0x7d098815,0x7ae46e61,0x629607f2,0x7cf04041}},	//   _fues, nlit, _noyo, färg,
   {{0x7c2e082d,0x95ca883c,0x7d09ae62,0x657b8590}},	//   kabr, _слаб_, _gues, _gruh,
   {{0x3944ee63,0x4734d8ed,0xa2c0809d,0x3a292e64}},	//   rums_, онос, लचक्, _seap_,
   {{0x629605b2,0xdbe64185,0x741385a7,0x7ae46e65}},	//   _boyo, _करोड_, _رونا, klit,
   {{0xb5fdc013,0x39406e66,0x7cf04402,0xb5fb051e}},	//   mešn, kris_, lärd, beál,
   {{0x44384043,0x6abd1f20,0x62960396,0xdc3cc02d}},	//   _odr_, risf, _doyo, láči,
   {{0x60c481b4,0xa3d85146,0x2d99c051,0xac18df0c}},	//   éimh, ाथा_, äsee_, _току_,
   {{0x7ae45825,0x8aa74e32,0xe457c009,0x39406e67}},	//   flit, брад, _ליגט_, eris_,
   {{0x3da707e3,0x7ae46e68,0x656d0b71,0x764d0070}},	//   _гроб, glit, _tsah, _ucay,
   {{0x6d460aef,0x26c78669,0x6e2d4a6c,0x998d80e0}},	// [3030] cuka, énom_, raab, _odeš_,
   {{0xf99f03bc,0x7c2aee69,0x61ed1216,0x6f0ac0e2}},	//   myè_, _jefr, _izal, _kufc,
   {{0x7d1bc65a,0xde198d6b,0xce9541bc,0xb65a0031}},	//   zpus, لقات_, _данъ, _ajẹ́,
   {{0x518748a9,0x7cefc7fb,0xdb084107,0xab68c085}},	//   _луга, pørg, álás, _gażż,
   {{0x7d0d4a16,0xb4db06ed,0x7cf04041,0x442a6e6a}},	//   qqas, cràc, färd, _feb_,
   {{0x3206c010,0x657d56ae,0x83398051,0x29194498}},	//   _agoy_, _irsh, ачит_, _itsa_,
   {{0x61fec080,0x6d462e6b,0xf8bf07b0,0xb5fd88c7}},	//   əzlə, zuka, lsés_, _pašs,
   {{0xf99f06ed,0xdce996a6,0x3f77c119,0xe299d07a}},	//   ncès_, _iseč, _rău_, раи_,
   {{0x7c2aee6c,0x3f77c119,0x5fdb014a,0xf99381b4}},	//   _befr, _său_, _मुसल, _عبر_,
   {{0x442e802c,0xa3e9008f,0xb5fdc077,0x2ba5c285}},	//   caf_, _बरं_, bešn, खनला,
   {{0xe9a8d1be,0x61ebc064,0x6f02ee6d,0x213fc42c}},	//   لدین_, _wzgl, _fioc, sruh_,
   {{0x7d1bee6e,0x4fd68052,0x60c8c09d,0xaabdc891}},	//   ppus, _וועב_, andm, _ऋषिक,
   {{0x7c2e2e6f,0x7ae442bc,0x26190027,0x3ebfee70}},	//   tabr, vlit, पड़ी_, miut_,
   {{0x5fdb056c,0xdce404f9,0x61ed0033,0x6ae244eb}},	//   _मुहल, _priđ, _dzal, पत्र,
   {{0x7cefc9ca,0x657d6e71,0x61ed2e72,0x44384f2d}},	//   gøre, _arsh, _ezal, _rdr_,
   {{0x4438412d,0x645c489b,0x6f1c02bc,0xb5fdee73}},	//   _sdr_, _sbri, rprc, nešo,
   {{0x7d04c1b4,0x290b58a1,0xa96a1051,0x85f6c009}},	// [3040] _éist, _cuca_, _типа_, ַמעס_,
   {{0x25de408f,0x290b409f,0x61e4006a,0x6abba538}},	//   _कुणी_, _duca_, _iyil, _amuf,
   {{0x442a6e74,0x656f5b29,0x643ac009,0x3eadc2e9}},	//   _veb_, _esch, שעענ, khet_,
   {{0x7d771971,0xb5fdc06c,0x4b4cc009,0x443a0fc5}},	//   _امیر_, ješo, רגאַ, _hdp_,
   {{0xe8fa82f1,0x6f02c92c,0x290b41c6,0x601887ad}},	//   алд_, _rioc, _guca_, боля_,
   {{0x25f18027,0xccb7811b,0x6f041656,0x2d54454a}},	//   ेशजी_, огії_, _liic, mäe_,
   {{0xf99f0565,0x59a88185,0x6f02e902,0x7cf04402}},	//   zyè_, कनहर, _pioc, gäre,
   {{0x9634ddfa,0xb5fdee75,0x29036df5,0x63a34586}},	//   чниц, rešn, _zija_, ønne,
   {{0xdddd0036,0xa3d68185,0xc866d000,0x6e2bee76}},	//   zesł, _सडक_, отни, _degb,
   {{0x7d0bc057,0x6d40c851,0x3a2f00b3,0x442e80f1}},	//   _dugs, rrma, _žgp_, qaf_,
   {{0x60dc2e77,0xf41340c3,0x7d0bc29a,0xddc9c011}},	//   dorm, ופת_, _eugs, rdeš,
   {{0x442c8329,0x3206c02f,0x7eb60017,0x61e40024}},	//   _hed_, _ugoy_, kšpu, _byil,
   {{0x6d42aa9f,0x66090011,0x2126c396,0x2ee680b1}},	//   nroa, žeko, _uwoh_, ilof_,
   {{0x60dc00e2,0xf99f03bc,0x6ab784eb,0x61ed0066}},	//   gorm, ryè_, _आग्र, _vzal,
   {{0x290b6e78,0x443a0856,0xd259c017,0x61e42e79}},	//   _suca_, _ddp_, liņa_, _eyil,
   {{0x7d1d0621,0x798d4046,0x442c904f,0x645ac5e7}},	//   ppss, txaw, _led_, lfti,
   {{0x29036e7a,0x255e803f,0x2bdb0298,0x35b400c5}},	// [3050] _pija_, nālā_, _मुरा, _обър,
   {{0xab870363,0x645ade00,0x26cd8514,0x442c980e}},	//   _думк, nfti, _sjeo_, _ned_,
   {{0xe9ffc00c,0x25fc4b5b,0x656f4036,0x7d0d2e7b}},	//   _trầm_, लेबी_, _wsch, _huas,
   {{0x4f08459d,0xe81b515e,0x6e22ae7c,0x2ee68b1b}},	//   інін_, _प्रा_, gbob, glof_,
   {{0x443a021b,0x0dc8401b,0x4421405c,0x672880f1}},	//   _ydp_, _дури_, pbh_, _awdj,
   {{0xccf8c185,0x25f0506a,0x279597e5,0x39494056}},	//   jmě_, _आरती_, зшир, muas_,
   {{0x7d03ee7d,0xd04ec03a,0x38678240,0x2d9286a9}},	//   _rins, _ödən, renr_, øyer_,
   {{0x26cb00e1,0xa3b46e7e,0x9fbf002d,0x645adf26}},	//   ébol_, _जेट_, jčím_, efti,
   {{0x3949430d,0x7cf20240,0x60dc006a,0x22b88047}},	//   nuas_, lære, yorm, jčky_,
   {{0x7fd5c007,0xa3b68707,0x2903cabf,0xdddb8158}},	//   зімі, _चेक_, öja_, _gnuš,
   {{0xbb4881b4,0x6562c4f9,0x66e61510,0x44312e7f}},	//   _ولكن_, _epoh, зона, daz_,
   {{0x9980c166,0x216a00c5,0x2905ae80,0x64410086}},	//   _žiť_, бими_, _hila_, ólin,
   {{0x6e2d2e81,0x290f01cb,0x5fdfae82,0x7ce00fb7}},	//   _deab, _égal_, _पुतल, dörr,
   {{0x7ce48315,0x442c0877,0x3ae1ee83,0xdce40036}},	//   tòri, úd_, rópu_, _osią,
   {{0x6b834041,0x46db8036,0xafe2ea91,0xb4bc09d5}},	//   ångl, यकाह, _пошл, _आगी_,
   {{0x78bc46f0,0x8f9ac4e0,0x6299c88b,0x6e2d0820}},	//   _smrv, _ליצי, _jowo, _geab,
   {{0x443a007a,0x4431245a,0x7d0d2e84,0xf709c00c}},	// [3060] _tdp_, baz_, _guas, _mầm_,
   {{0x4d7b0009,0x6609a3ab,0xf709c00c,0x7e69d11b}},	//   _פריע, _agek, _lầm_, heep,
   {{0x442c8093,0x7529ae85,0x35fa41aa,0x37e62029}},	//   _red_, _awez, _گردد_, _хонг,
   {{0x26ddae86,0x690942bc,0x69c4c039,0x645c291d}},	//   gowo_, _džeb, _žiem, lfri,
   {{0x60c1ee87,0x442cae88,0x2ee69f29,0x9a12c112}},	//   kilm, _ped_, rlof_, _mọtụ,
   {{0x7cf20240,0x38a440e8,0x6e3bae89,0x645c08d2}},	//   bære, _mörk_, _edub, nfri,
   {{0x60c1c676,0x75298044,0x5694c4ce,0x629b4018}},	//   dilm, _ewez, дайт, _écoñ,
   {{0x44312e8a,0x60de6e8b,0xb53a01c0,0x7c238022}},	//   zaz_, lopm, _arọ́, abnr,
   {{0x44310530,0x6e2d0de0,0x6299c064,0x777ac022}},	//   yaz_, _reab, _dowo, wvtx,
   {{0x2f118032,0x2009c696,0x3a2d80a8,0x691c806a}},	//   _fág_, _şair_, _zeep_, rçeğ,
   {{0xf98fc78a,0x672d8077,0x645ac98a,0x6299eb2a}},	//   نبی_, ćajc, rfti, _fowo,
   {{0xb5fb01b4,0x26c20232,0x38c2c031,0x39494022}},	//   leái, giko_, _bérè_, yuas_,
   {{0x44312e8c,0x201843bc,0x3ea6ae8d,0x200a425d}},	//   taz_, _ofri_, ikot_, _ogbi_,
   {{0xde8fc015,0xbcfb430d,0x7ceb406a,0xb9250112}},	//   _tịch_, _apén, gürl, _zipụ_,
   {{0x24c4402a,0x905bc0c3,0x6d95c0f6,0x442ec085}},	//   ্তাহ, _הכות, _eżaġ, _ief_,
   {{0xe8d90015,0x2d80036b,0x44312e8e,0x929445dd}},	//   _trữ_, _frie_, saz_, насц,
   {{0x6d446e8f,0x443cc138,0x26c746f0,0xb113825d}},	// [3070] gria, _kdv_, đno_, rụkw,
   {{0x442eee90,0x7eaa4066,0x3a2dae91,0x6ee5c5f4}},	//   _jef_, _výpa, _seep_, róbi,
   {{0x6e2441ae,0x29058303,0x3a2dae92,0x7c2958ca}},	//   bbib, _rila_, _peep_, _đerd,
   {{0xddd4c0a0,0x7ae2ee93,0x7cf20329,0x20184397}},	//   žařs, _nkot, rære, _efri_,
   {{0xf709c35d,0xcbfe802a,0xca9640c3,0x20d58589}},	//   _rầm_, ুরোধ_, _חדרי_, мікс,
   {{0x6299c0fa,0x2f11a2ef,0x2ee96e94,0xf709c35d}},	//   _sowo, _pág_, llaf_, _sầm_,
   {{0x6702c0eb,0x6b8340b0,0xb6098017,0x60c1d929}},	//   _ọkaa, ængd, tišķ, vilm,
   {{0x7c254032,0xaa5881bd,0x7c24c011,0x7d075172}},	//   lbhr, _нису_, _đira, _hijs,
   {{0x60c1ee95,0x7e69ca26,0xdb08c066,0x6738c085}},	//   tilm, reep, vzdá, _avvj,
   {{0x7ae2e2c6,0x7e7600f8,0x7c220077,0x2ac3e494}},	//   _ekot, _sayp, _đoro, _bèbè_,
   {{0xeb99d854,0x765bc00d,0x6aad053d,0xa91d8ebc}},	//   цин_, pfuy, _blaf, _drže,
   {{0x7ceb42d6,0x6d446e96,0x442ec206,0xddcd406f}},	//   dürm, yria, _eef_, zdaš,
   {{0x6f06409c,0xb4db06ed,0x443341d6,0x7cf05368}},	//   _rikc, rràn, kax_, hära,
   {{0x44335876,0x7d074127,0x98b0c011,0x6d599435}},	//   jax_, _nijs, _ćaći_, itwa,
   {{0x61e6411b,0x48070ab2,0x91030afa,0xd0070156}},	//   _sykl, дерн_, тпре, дере_,
   {{0xf212c112,0x2d80029a,0x66ec8374,0x6d59ae97}},	//   _họrọ, _trie_, _छींक_, ktwa,
   {{0x66166e98,0x7ae42e99,0x7d0741d4,0xd00f005f}},	// [3080] rcyk, _ikit, _bijs, الہ_,
   {{0xbddb06ed,0x7e60807a,0x290fee9a,0x61e64066}},	//   rgèt, _sbmp, _muga_, _vykl,
   {{0x9a12c112,0x212045cd,0x6d59817b,0x212b41f4}},	//   _mọrụ, spih_, etwa, _ewch_,
   {{0xddcd2e9b,0x2d80c017,0x2902c066,0x63a3ae9c}},	//   _haaš, _šiem_, íkaz_, dynn,
   {{0x7c2e4a1f,0x2d8f44c9,0x60c38382,0x7ae41e4f}},	//   _tebr, äget_, finm, _mkit,
   {{0xf212c0eb,0x7ae9eac4,0x5fd94c4b,0x7d0744f1}},	//   _nọrọ, elet, _बुकल, _gijs,
   {{0x63a3811b,0x6f1c4514,0x38785440,0xbddb1302}},	//   gynn, _utrc, _iarr_, ngèr,
   {{0x6d4bae9d,0x38786e9e,0x7ae42e9f,0x7afbc107}},	//   buga, _harr_, _nkit, gmut,
   {{0x81e04079,0x6d4b8580,0x3a3dc053,0xdcfb8574}},	//   ধের_, cuga, _ddwp_, _zruč,
   {{0x38a9c031,0x6d460013,0x83fcc0ab,0xdced4011}},	//   _dúro_, drka, leđi, rvać,
   {{0x387844ec,0xa7fcc06a,0x6d462ea0,0x63a3802c}},	//   _marr_, ldız, erka, cynn,
   {{0xf8bf001e,0x9c7ceea1,0x38ab8240,0xd12fc08c}},	//   ipée_, doče, _jørn_, _چمن_,
   {{0x6aa340b4,0x7e62de2f,0x6ce700d9,0xbefa4185}},	//   _înfi, _ibop, діве, ्दैन_,
   {{0x7ceb6ea2,0xdfd4c10e,0x25b0c0b5,0x7d0f40b4}},	//   türm, _полы, ıllı_, _rucs,
   {{0x290fc020,0x6721c011,0xbddb01cb,0x4fc42ea3}},	//   _zuga_, cplj, ggèr, вста,
   {{0x3f572ea4,0x39469a6f,0x816b047f,0xbebcc017}},	//   rçu_, kros_, _дроб_, _avīz,
   {{0xb5fdc06c,0x7afd1d92,0x645a0016,0x50f5487b}},	// [3090] vešk, mmst, òtic, езат,
   {{0xa775081e,0x26cdeea5,0x9c7cda5b,0x6d4b96b4}},	//   _злоч, zneo_, ločb, vuga,
   {{0x92c30079,0x6566405c,0xca4801aa,0x7d074022}},	//   ্তী_, _epkh, _علیه_, _vijs,
   {{0x7d07415d,0x199558c8,0x7d08aea6,0xdd95559b}},	//   _wijs, _замя, _aids, _замы,
   {{0xc8788189,0x3878499e,0x2a794085,0x7e6d6ea7}},	//   _bağ_, _farr_, _iasb_, meap,
   {{0xa3c0c84d,0x66c8006a,0x7d088321,0x48bf802a}},	//   ूपा_, lıkt, _cids, েত্র,
   {{0x290feea8,0x7982eea9,0x25a9806c,0x7d08829a}},	//   _suga_, _arow, šal_, _dids,
   {{0x63b140e0,0xb5fdc451,0x62898953,0x26c4c007}},	//   đenč, leši, _uneo, gimo_,
   {{0xc05b893d,0x2f1504a0,0x629d4973,0x2907eeaa}},	//   _між_, _låg_, _moso, _pina_,
   {{0x26cdc2d8,0x0325c53a,0x3a3f8056,0xd83882a3}},	//   sneo_, ндон, _hdup_, _poče_,
   {{0x61e98033,0x7cf04041,0x27180013,0x5fdb15be}},	//   _hyel, kärn, _očna_, _मँगल,
   {{0x44316623,0xe7e30a3c,0xfb24c1aa,0x6f09a02c}},	//   _lez_, _गड़ा_, کریپ, _jiec,
   {{0x661b8150,0x26cf80fc,0x38a0c05e,0x66c8006a}},	//   _mfuk, ingo_, _còrs_, dıkt,
   {{0x7afd075a,0x7af60061,0x6d5bd3d8,0x6ef6003c}},	//   amst, _whyt, mtua, dábe,
   {{0xb4cbc08f,0x6d5be0db,0x394deeab,0xd8388013}},	//   रची_, ltua, lues_, _uoče_,
   {{0x9c7ceeac,0x81da8079,0x7ae42ead,0x8a065025}},	//   roče, ডেট_, _ukit, езбе,
   {{0x6ef60004,0x21674ec5,0x3f834085,0xf1bf0019}},	// [30a0] gábe, нити_, _arju_, lbán_,
   {{0x39468afa,0xb9db0093,0x6d5beeae,0x23db2eaf}},	//   vros_, _מחפש, itua, _मुकद,
   {{0x2367c05c,0x2d8f5456,0x03a341cc,0x6aa9c240}},	//   _jpnj_, äger_, лифо, kkef,
   {{0x26c4ec36,0x3ea96eb0,0xc8788676,0x2d824a18}},	//   ximo_, ckat_, _sağ_, _trke_,
   {{0x6d5bc0da,0x7ea6001d,0xada34097,0x29120067}},	//   jtua, _cópi, _баял, _juya_,
   {{0xd00f820c,0x80bc8045,0x6d5bc105,0x7eb140d9}},	//   مله_, ्चें, dtua, _våpe,
   {{0x6205c03a,0x290a4340,0x232a4c21,0x7524434d}},	//   ərlə, _iiba_, _хоби_, lpiz,
   {{0xe60a801c,0x6ee3809d,0x2240088b,0xa3e3017e}},	//   _رزرو_, sõbr, _ndik_, _फँस_,
   {{0x443e8616,0xde8fc0d1,0x394ded46,0x6d400019}},	//   _tdt_, _tịnh_, gues_, ámal,
   {{0x6b83c033,0x290a5336,0xe5068032,0xe0858032}},	//   _brng, _jiba_, _أبري, _لجمي,
   {{0xf8b344e0,0x6ef60018,0xd6cfc59d,0x7ae0c2c0}},	//   רשת_, zábe, _бт_, pomt,
   {{0x7982eeb1,0x932584e8,0x26c68070,0x38a0c5ef}},	//   _trow, _شرمن, nioo_, _còrr_,
   {{0x2f1504a0,0x7eaa4066,0xb5fb402e,0x2a64805c}},	//   _såg_, _výpl, _abán, _mbmb_,
   {{0x2bd9539f,0x92c30079,0x3f58c10b,0x68e1c077}},	//   _बुझा, ্তে_, péu_, cold,
   {{0x7ae28922,0x30a400c5,0x7c28c05c,0x3ea96eb2}},	//   koot, уряв, mbdr, tkat_,
   {{0x6ef6003c,0x2f150621,0x660d0449,0x6d5a00cc}},	//   tábe, _våg_, _ugak, ătar,
   {{0x54554457,0x998401b4,0x673aceb8,0xb5fdeeb3}},	// [30b0] кват, _مليو, lstj, teši,
   {{0x6d4f2eb4,0xc326802a,0x629d47f2,0x5fb08db4}},	//   muca, _যিনি_, _woso, जनाल,
   {{0x6d5bc232,0x6d5d0771,0x629d57e0,0x44278639}},	//   ztua, ltsa, _toso, vbn_,
   {{0x7ec7c303,0x60c70206,0x629f01d6,0x31690085}},	//   _mèpè, lijm, _joqo, _kpaz_,
   {{0x7ec7c01c,0x443304c9,0x6f09aeb5,0x6d4d4206}},	//   _lèpè, _kex_, _viec, quaa,
   {{0xe5a28982,0x628bc010,0x394ddc24,0x39494041}},	//   риши, _sngo, vues_, mras_,
   {{0x673ac1d4,0x68e1d8c1,0x7aed6e26,0x44332eb6}},	//   jstj, vold, olat, _mex_,
   {{0x6d4f2eb7,0x394deeb8,0x673ada5e,0x290a426d}},	//   kuca, tues_, dstj, _ziba_,
   {{0x673c4077,0x6d5d1fb2,0x7aed5ab9,0x673ac0a8}},	//   _zvrj, jtsa, ilat, estj,
   {{0x394deeb9,0x6c748e5f,0x6aa9c240,0x2a6dc022}},	//   rues_, _مطمئ, skef, seeb_,
   {{0x68e1d9c6,0x798417a6,0x394deeba,0x628bc05c}},	//   rold, _sriw, sues_, _tngo,
   {{0x7cf680b4,0x443300a8,0x6d5d08d2,0xe3b08032}},	//   râre, _aex_, ftsa, _ارك_,
   {{0x68e1e0a7,0x6d4f0158,0x38a4597d,0x2d842056}},	//   pold, guca, _kört_, íme_,
   {{0x6d49eebb,0x68e38dc0,0x7c28c05e,0x7cf04402}},	//   mrea, nond, cbdr, gärl,
   {{0x42564b0f,0xe29f4397,0xa5072188,0x44332616}},	//   ктат, _boð_, тера_, _dex_,
   {{0x798409ee,0xe7e54a3c,0x6d4f2e79,0x22400033}},	//   _triw, _कड़ा_, buca, _udik_,
   {{0x2120005c,0xada34097,0x753bccb1,0x6ef88018}},	// [30c0] _utih_, аатл, nsuz, níbe,
   {{0x7ebec007,0x3f8580eb,0x2d804753,0x68e3aebc}},	//   rūpi, _orlu_, rvie_, jond,
   {{0xe0d5411b,0x7ae2aebd,0x320fc396,0x39496ebe}},	//   ують, toot, _oggy_, aras_,
   {{0x7e7b8070,0xa2c148b8,0x6441aebf,0x290a4024}},	//   _caup, रोद्, _adli, _wiba_,
   {{0xdce2c3d1,0xaa7b0574,0x3865aec0,0x394352cd}},	//   _spoč, plýv, _bblr_, _княг,
   {{0x7524c06a,0xb5fdd0aa,0x7d0941ff,0x237f0062}},	//   _çizi, nešu, _éesp, łuje_,
   {{0x7ae286c8,0x44382ec1,0x6d5baec2,0x7ea60086}},	//   poot, iar_, _equa, _hópu,
   {{0x6e29c5bb,0x7d1b403c,0xb6a3a159,0xb5fb4066}},	//   gbeb, _éusc, _кисл, _obál,
   {{0xdc5485d3,0x2d8480b4,0x6d40006f,0x3f5c4086}},	//   _مراک, _urme_, šmaj, líu_,
   {{0x673ac10d,0x7cf04041,0xf70a00d1,0x6d5d0022}},	//   tstj, kärm, _mầu_, vtsa,
   {{0x62350da4,0xee3f0066,0x26d24033,0x9e352d77}},	//   лену, ským_, knyo_, ленч,
   {{0x6d5d2ec3,0x4438002c,0xf8d280e9,0x3ea00061}},	//   ttsa, ear_, _तदुप, _coit_,
   {{0x7e7d0098,0xc649c032,0x6d5d2ec4,0x6ef8830d}},	//   rdsp, _أجمل_, utsa, cíbe,
   {{0x6d5d15db,0x7d1d86ed,0x673adef0,0x63adc09c}},	//   rtsa, _ésse, pstj, _ƙant,
   {{0x6d5d0253,0x26c48033,0x57a42ec5,0x3eb2051f}},	//   stsa, _ommo_, ашта, _flyt_,
   {{0x32550495,0x49752ec6,0x7ae46ec7,0x3f5c59a9}},	//   _свир, _блис, goit, díu_,
   {{0x7e7baec8,0x63a70036,0xb5fb402e,0x6f0d005e}},	// [30d0] _raup, syjn, _gbál, _iiac,
   {{0x6ef61a6d,0xd838eb42,0x4fc7059d,0x51f84ce8}},	//   mába, nač_, _асма, тную_,
   {{0x7bceaec9,0x6ef6005f,0x645786ed,0x6d5ba2a5}},	//   _žbun, lába, òxim, _squa,
   {{0x92954768,0x7c220077,0x6aa0aeca,0xa5bb0018}},	//   _самц, _đori, _comf, rcóf,
   {{0x628f6ecb,0x7522c044,0x6ef60107,0x7abc00c3}},	//   _inco, _ntoz, nába, וצאו,
   {{0x6f0bc00b,0x6d5d417a,0x69da00cb,0x394f96dc}},	//   _sigc, _iqsa, ßtei, rugs_,
   {{0x289c0009,0x2eedd7f0,0x25a96ecc,0x2f188107}},	//   ויגא, tlef_, lyal_, _cég_,
   {{0x9c7cc04f,0x6d49eecd,0x26c9401f,0x38a444c9}},	//   voča, trea, niao_, _förs_,
   {{0xa3b5eda0,0x6468410d,0x7e7d6ece,0x6ef6005f}},	//   चैन_, _þrið, _masp, jába,
   {{0xe45387d8,0x2d84441b,0xd838c11a,0x7522401f}},	//   _خضر_, _šmek_, gač_, ãozi,
   {{0xa6ca02fd,0xbea60eb2,0x7e7d40b4,0x7ae4412c}},	//   елна_, ганк, _oasp, yoit,
   {{0x7cf04041,0x61ed011c,0x38af2ecf,0x6d5cc0b4}},	//   värm, _byal, _büro_, ărar,
   {{0x4a9ac2a6,0x20cd0639,0xd838c013,0xd945c19e}},	//   _רינג, džib_, bač_, _сели,
   {{0x290c183c,0x38b64065,0xe1f0c183,0x6e398046}},	//   öda_, _kære_, _بسم_, hawb,
   {{0xa3c98b35,0xcb670156,0x7afb8f4c,0x6d5d41d6}},	//   _लेम_, ларе_, _ohut, _aqsa,
   {{0x2a7fc54a,0x3eadcc40,0x387cc6f0,0x2d960051}},	//   ndub_, nket_, _zavr_, _брос,
   {{0x395fc645,0x7ae46ed0,0x2a7dc022,0xaca38171}},	// [30e0] ntus_, roit, _mawb_, _akọl,
   {{0x395fc04c,0x44382ed1,0x7ae44051,0xb4dd8185}},	//   itus_, qar_, soit, णको_,
   {{0xa91d8011,0x07a6028a,0x7ae46ed2,0x5f7603a9}},	//   _bržo, _санн, poit, _صادر,
   {{0x26c940c4,0xbcfb001e,0x38b08321,0xbddb4580}},	//   ciao_, rtée, _càrn_, _idèn,
   {{0x629bc0b3,0x38a44041,0x395fc046,0xc6934323}},	//   djuo, _dörr_, jtus_, _האר_,
   {{0xbcfb001e,0x752402c0,0x7afb80b9,0xfce380d9}},	//   ptée, _mtiz, _ehut, бочо,
   {{0x764400eb,0x430ac06f,0xf6e6cc21,0x7ae62ed3}},	//   _odiy, нхим_, лцин, kokt,
   {{0x3eadc07a,0x387ceed4,0x57e7401b,0x2bc38048}},	//   gket_, _savr_, _сдсм_, _वेळा,
   {{0xd838d487,0x6f029a8a,0x68fc5bdd,0x395feed5}},	//   tač_, mmoc, _khrd, gtus_,
   {{0x63a8c36b,0x7ea3454a,0xb8658973,0x7eb5c018}},	//   tydn, _lõpp, _نامو, _rápe,
   {{0x645a92f6,0x2a7dc04d,0x75242ed6,0x2a7fc022}},	//   _icti, _fawb_, _atiz, bdub_,
   {{0x6f02830d,0x6ef62ed7,0x6360825d,0x6443c247}},	//   nmoc, tába, _ịnwe, _edni,
   {{0x1c19084d,0x7644032a,0xdd92d755,0xe5c72012}},	//   _दलदल_, _ddiy, _دوش_, усно,
   {{0x6ef6129d,0xb5fdc013,0x44440438,0xaca34112}},	//   rába, rešt, _cd_, _kwụb,
   {{0xa3cbc036,0x3ea240a8,0xb5fb4171,0x387e8b44}},	//   _रेप_, _bokt_, _gbáj, _matr_,
   {{0x290edfbe,0x8aa45df0,0xd259c8c7,0x6ef62ed8}},	//   _hifa_, бруд, tiņi_, pába,
   {{0xdd944051,0x344b4c21,0x61ed000b,0x290eeed9}},	// [30f0] баты, ечен_, _uyal, _kifa_,
   {{0x9c7ccf26,0x656d029e,0x80d30079,0x6d4b82a3}},	//   zočn, _ipah, _দীর্, vrga,
   {{0xe7872eda,0x5215a37b,0x672d8054,0xdc3bc052}},	//   _супо, адет, ćajk, געבר,
   {{0xa3c3c047,0xf8bf4303,0x2f0b402e,0x6d4b8618}},	//   náší_, _awét_, _dògì_, trga,
   {{0xaca34112,0x2244805c,0x7bdc405c,0x763a4009}},	//   _awụb, _ddmk_, _exru, _בערג,
   {{0x6b8344d3,0x64dec08f,0x38b4020b,0x26c6c031}},	//   ångs, नकोश, _kära_, _amoo_,
   {{0x7ae6142d,0x6447c34d,0x3eadc025,0x6d4d4049}},	//   yokt, ójim, tket_, lraa,
   {{0x290eeedb,0x6aa2e275,0x395feedc,0x6723c077}},	//   _aifa_, _coof, ttus_, _rtnj,
   {{0x7c3ac2cd,0x6d46cf9e,0x290eeedd,0x6aa2eede}},	//   fatr, škan, _bifa_, _doof,
   {{0xa2a191f1,0xe765d324,0x3365d045,0x2d80c283}},	//   कॉर्, авоп, авог, _ġiet_,
   {{0x6e3600f8,0xdfd189ab,0xd62a142f,0x24814359}},	//   _peyb, _بيا_, коне_, idhm_,
   {{0x395feedf,0x2d890321,0x9c7cc0e5,0x1fa494e9}},	//   ptus_, _brae_, ločl, _уруг,
   {{0xa3c9809d,0x6e2d5350,0xb2768052,0x7ceb450c}},	//   _लेत_, dbab, בערג_, nürs,
   {{0x38b40041,0xa3e649d5,0x44442ac4,0x394dc13b}},	//   _bära_, _पडल_, _qd_, mres_,
   {{0xe7371771,0x7cefc0d9,0xea5a401b,0x64450303}},	//   иер_, jøri, крај_, _ddhi,
   {{0x798980e2,0x6445088b,0x6e3bd636,0x4226423d}},	//   _orew, _edhi, naub, рдав,
   {{0xa96a4183,0x61ef6ee0,0xe6174740,0x80d6aee1}},	// [3100] ضمام_, _cycl, рду_, _बदले,
   {{0x6aa40032,0xdb188107,0x3d0f8036,0x394d0018}},	//   _hoif, szvé, ादों_, áese_,
   {{0x394dc0fa,0x6e3beee2,0xa3cd0045,0x6d4d4149}},	//   hres_, kaub, _शेप_, araa,
   {{0x95ca8039,0x7d068107,0xe9f900d1,0x394deee3}},	//   кула_, _éksz, _hoạ_, kres_,
   {{0x7d0e4046,0x7c3ae3ec,0x82d7021d,0x2d8441cb}},	//   _tibs, yatr, סונג_, _éme_,
   {{0x2ab1eee4,0x8c3c81df,0x2ee6978e,0x7cf04051}},	//   _bábo_, _boğa, soof_, käri,
   {{0x7989814d,0xdfcf81b4,0x645c423f,0x39406ee5}},	//   _erew, ويه_, _icri, lsis_,
   {{0x394deee6,0x8c3c8f3e,0x290ec4fd,0x3a206ee7}},	//   fres_, _doğa, _sifa_, ncip_,
   {{0xf50aaee8,0xb113c051,0x9997c0c5,0xbddb4396}},	//   _анал_, омыш, икът_, _ndèl,
   {{0xd406c623,0x2ab1c02e,0x6562813b,0x273c4031}},	//   ияни, _fábo_, mtoh, _gáná_,
   {{0x394dc716,0xdddd403f,0x80c8c079,0x7eb8410b}},	//   ares_, _pasū, রকল্, _zípe,
   {{0x6aa40c43,0x6f0444f9,0x2a7f8022,0x6efd0107}},	//   _coif, jmic, _xaub_, kébe,
   {{0x6562aee9,0x6280aeea,0x442cc033,0x290300fd}},	//   ntoh, _mamo, pbd_, tmja_,
   {{0x6d40eeeb,0xd83880b6,0x6ce70176,0xba3b41cb}},	//   msma, _alčz_, ріме, _coïn,
   {{0xf2c748b7,0xb17b4854,0x6ab6122b,0x6aa4005e}},	//   асан, _nyår, _flyf, _foif,
   {{0x5a350156,0xdced00b3,0x656280fd,0x6f044570}},	//   _унит, _osać, ktoh, gmic,
   {{0x2a7faeec,0x656280da,0x92016869,0x656d2eed}},	// [3110] _raub_, jtoh, लेंज_, _upah,
   {{0x2a7f804d,0x443c8eae,0x68e8c1f4,0x6445212d}},	//   _saub_, jav_, nodd, _udhi,
   {{0x7c38d11b,0x628087f2,0x39406eee,0x2cac04c9}},	//   _mevr, _bamo, asis_, ödde_,
   {{0x38b98669,0x6d40eeef,0x44386ef0,0x2a7f823b}},	//   _mère_, ksma, _eer_, _qaub_,
   {{0x7aed04fd,0x78a5054a,0x6d4d41c8,0x6d40c2a0}},	//   _mkat, _kohv, qraa, jsma,
   {{0x443caef1,0xeac9c0d1,0x628084e7,0x3e71c35d}},	//   gav_, hẹt_, _eamo, _ạt_,
   {{0x7aed2ef2,0x6d40eef3,0x9c7cc618,0x3f85401e}},	//   _okat, esma, ročl, _élu_,
   {{0x2b498cfe,0x6d4f0199,0x62828057,0x7cf218ac}},	//   čac_, krca, cdoo, tærk,
   {{0x44215440,0x6e3bc0fa,0xdc088017,0x7cfdc1cb}},	//   och_, raub, tēģi, hère,
   {{0x8b088047,0x7eb5c031,0x248100cb,0x7c3c2ef4}},	//   pořá, _dápa, _nahm_, xarr,
   {{0x6e3bca92,0x690b00f1,0x130a0051,0x7529eef5}},	//   paub, _eżek, лной_, spez,
   {{0x66000166,0x7b158047,0x34d4417e,0x7ea60060}},	//   ýmko, _všud, _दद्द, _cópp,
   {{0xe807425c,0xa069e67d,0x7cf2058a,0x7ae9eef6}},	//   वेता_, _бала_, læri, moet,
   {{0x3a394303,0x7ae9eef7,0x7cfdc1cb,0xd259c8c7}},	//   _aesp_, loet, fère, riņu_,
   {{0x7cfdc669,0x44386ef8,0x7cf2127d,0x6e3d0327}},	//   gère, _rer_, næri, basb,
   {{0x7bce8f26,0x443caef9,0x7ae9c6e7,0x29116efa}},	//   _žbuk, zav_, noet, _aiza_,
   {{0x7c38ce05,0xdce6403f,0x291946df,0x3a394070}},	// [3120] _yevr, _apkā, _cusa_, _desp_,
   {{0x6efd0107,0x29115e5b,0x644740b1,0x6d449492}},	//   rébe, _ciza_, _cdji, šiak,
   {{0x61fbaefb,0xb5fb4018,0x443a00b6,0x3a394004}},	//   _azul, _acád, _iep_, _fesp_,
   {{0xba168079,0x6b9cc54a,0x7cf042f7,0x29114070}},	//   ার্ড_, ärgi, järv, _eiza_,
   {{0x2fd704e8,0x6bd702f0,0xd838804f,0xa3a9c048}},	//   _نوید_, _نویس_, _peč_, _गॅस_,
   {{0x48e381bc,0x61fba5be,0x3ea04043,0x6d566efc}},	//   почв, _dzul, ljit_, muya,
   {{0x6d566efd,0x7c3e6efe,0x501b00c3,0x7ae9c02c}},	//   luya, mapr, נוקו, foet,
   {{0x291149f3,0x961d8017,0x29194303,0x6abbc230}},	//   _ziza_, _paņe, _yusa_, ghuf,
   {{0x6e3d06e3,0xe29b4052,0x63ae0089,0xe8fa9e9b}},	//   vasb, רשפר, hybn, _бла_,
   {{0x757b42a6,0x4438e6d2,0xad1b80c3,0x6d4f0011}},	//   נטיפ, úr_, _עובר, vrca,
   {{0x2cb86eff,0x7ae9ef00,0x7e76469a,0x2481013a}},	//   _mlrd_, boet, keyp, _rahm_,
   {{0x6d4f02a3,0xdcfb8077,0xeb9784e0,0x15fa4371}},	//   trca, _pruć, _לדבר_, ्धार_,
   {{0x7cf040fa,0x984b00c5,0xe919031e,0x6d42af01}},	//   läru, лява_, рогі_, nsoa,
   {{0xf8bf6231,0x66160107,0x9f34c0d9,0xd90f001c}},	//   _atén_, _egyk, _декі, ژیک_,
   {{0xdddd0107,0x5726ce5f,0x6e3d0206,0x6d442022}},	//   reső, _ارتق, pasb, _evia,
   {{0x3ea040fd,0xff074e99,0x9c7cd350,0x8c358031}},	//   gjit_, сягн, kočk, _fo̟w,
   {{0xdd94459d,0x3ea6c126,0x99994e13,0x51875132}},	// [3130] паты, _moot_, шкат_, щува,
   {{0x9d1bc093,0xb5fb4066,0xbcfb6f02,0x7cfdef03}},	//   טומט, _obáv, _apér, père,
   {{0x29194303,0x61fb9a1d,0xea198f99,0x00000000}},	//   _wusa_, _szul, ажеш_, --,
   {{0x6d566f04,0xa91d8011,0x3ea6c0bf,0x443a0024}},	//   buya, _hrži, _noot_, _zep_,
   {{0xdca58d9a,0x7ae9d11b,0x9c7cc04f,0xd567a012}},	//   жали, voet, ročj, степ,
   {{0x1fa9996d,0x69c0ca93,0x2eb1c185,0xac185892}},	//   икли_, dzme, जस्त, _гору_,
   {{0x5c5c0052,0x2bcf0048,0x3ea6e6b1,0x3eb94086}},	//   אדוק, _हेमा, _boot_, _klst_,
   {{0x29130fc2,0x1d25c1bb,0xbddb4396,0x4ea79d5e}},	//   _lixa_, омим, _ndèk, _урга,
   {{0x2ca5af05,0x7c3a9207,0xb5fd9d0c,0x61fba660}},	//   _told_, _fetr, _obši, _uzul,
   {{0x6e3b882e,0x7e6d0e3e,0x98adc02d,0x6e240157}},	//   _heub, _abap, steľ_, _sfib,
   {{0x443a0193,0xb4e584c7,0x3ea6dd80,0x3f69de9b}},	//   _rep_, नवी_, _foot_, шино_,
   {{0x2901005c,0x248340fd,0x7c3e68f9,0x91a00044}},	//   _ahha_, _lajm_, zapr, _ndị_,
   {{0x7d1b8c99,0x6e248ad6,0x7c3e40f8,0xe29fc10d}},	//   _juus, ñibi, yapr, öðu_,
   {{0x69dcc06a,0x6ab58027,0x291b0149,0x6e3baf06}},	//   ğret, ंसुर, _duqa_, _leub,
   {{0x798d297a,0x224900f6,0x6d4b6203,0x6d564360}},	//   _eraw, _fdak_, ágan, wuya,
   {{0x3a3fc010,0x62846f07,0x291b0085,0x29130580}},	//   naup_, udio, _fuqa_, _eixa_,
   {{0xb5fb4004,0x3ea0405c,0x75298bc9,0x7cf043ad}},	// [3140] _acáb, rjit_, _ntez, kärt,
   {{0xb4c7c374,0x62842f08,0x3eb2456e,0x93bcc0b4}},	//   _ईगो_, _haio, skyt_, mbăr,
   {{0x3e4cc039,0xf7724a10,0xa3c9854a,0x2a694046}},	//   lėtų_, باء_, _लेल_, bfab_,
   {{0x2ca7ef09,0xed5a55a2,0xd838806c,0x2249005c}},	//   _lond_, _ком_, _točk_, _xdak_,
   {{0x7c3e6f0a,0x2ca7c2a4,0x6296012c,0x3ce68549}},	//   papr, _oond_, _mnyo, टवले_,
   {{0x2d800141,0x7af6404c,0x7ae9406c,0xddcf0119}},	//   _msie_, llyt, čete, lecţ,
   {{0x26cfaf0b,0x3ea6ef0c,0x2d8d8112,0xa09b02a6}},	//   bigo_, _poot_, _eree_, ייסט,
   {{0xd838af0d,0xbe8ae087,0x3e4cc007,0x2bed0027}},	//   _moči_, рске_, kėtų_, _आँसू_,
   {{0xeeb7c11b,0x7cff814b,0x7ebcc107,0x2ca7d05f}},	//   ільш_, wêre, _népe, _bond_,
   {{0xc9d5801c,0x6aa28077,0x387800fd,0xa3c3c0a0}},	//   _عملک, ljof, jerr_, láří_,
   {{0x3ea6c02f,0x2ca7c019,0xaca4425d,0xd838804f}},	//   _toot_, _dond_, _ndọr, _noči_,
   {{0x29130018,0xe297c077,0x212900f8,0x7cefc7fb}},	//   _sixa_, _мах_, _ptah_, førs,
   {{0x6594eb90,0xa91d80e0,0x69c2815d,0x7eb5ca6e}},	//   _халу, _prži, nzoe, _zápo,
   {{0x62962f0e,0x69c2815d,0x2ca7c107,0x6d44402d}},	//   _enyo, izoe, _gond_, dsia,
   {{0x02a74099,0xb065c051,0x8aa74ecc,0x6d402f0f}},	//   орам, slää, орад, ámar,
   {{0x7640c568,0x6284050e,0xd8388043,0x99848085}},	//   namy, _gaio, _doči_, _bemż_,
   {{0x6d44535f,0x65154280,0x6f02cb1a,0xdbc75139}},	// [3150] gsia, سوائ, _mhoc, nöör,
   {{0xd8389ec5,0x7640c91f,0x752d4070,0x628400fc}},	//   _foči_, hamy, rpaz, _zaio,
   {{0xddc4011f,0xa3c98ef0,0x7d1b8c99,0x6f1c6f10}},	//   _ibiš, _लें_, _suus, _curc,
   {{0x3946cc5a,0x7d1baf11,0xf8c9c02e,0x6d444022}},	//   _ovos_, _puus, _alẹ́_, bsia,
   {{0x27fe8011,0x7640ef12,0xdb058107,0x39592f13}},	//   _aztn_, damy, gyhá, nuss_,
   {{0xc17242a6,0x3b094080,0xdd8e9137,0x6f1c6f14}},	//   _רחם_, lmaq_, اوو_, _furc,
   {{0x6f02d335,0xdddbc077,0x61e2ef15,0x26cf9c9e}},	//   _bhoc, dduš, _axol, pigo_,
   {{0x644ac123,0x6f02d9c2,0x3eb9c10d,0x66dec017}},	//   _adfi, _choc, óst_, tīka,
   {{0x386101f4,0x31668070,0x4429c6df,0xb5fb41c0}},	//   _ochr_, ctoz_, _ƙa_, _gbát,
   {{0x62840232,0x7ebcc669,0xdce2c283,0x6499cff8}},	//   _saio, _répe, _proġ, стир_,
   {{0x212dcc14,0xf1a8c1aa,0x7aed40b9,0x6d446f16}},	//   speh_, مایه_, koat, zsia,
   {{0x6e3d46bc,0xa3c10047,0x7aed443e,0x3952499e}},	//   _nesb, ्छन_, joat, yrys_,
   {{0x62840498,0x62862f17,0x9c7cc458,0xfd48c112}},	//   _vaio, rdko, zoči, _momọ,
   {{0x6f09ef18,0x6abb80d2,0x25ef45da,0x62840230}},	//   lmec, _lluf, _आड़ी_, _waio,
   {{0x6abb9ad6,0xe29a4081,0xa09ac052,0x6e3d40f8}},	//   _oluf, бав_, _ליסט, _besb,
   {{0x6441ef19,0x645c01f4,0xaa7b410d,0x6f1ea310}},	//   lali, sgri, _skýr, ípci,
   {{0xcb130093,0x443cef1a,0xddcf0119,0x291de02c}},	// [3160] _אלה_, _yev_, recţ, _juwa_,
   {{0x6f09c0fa,0xf8e002f6,0xab6609a4,0x6d444129}},	//   hmec, _नदिय, _евол, rsia,
   {{0x2721c10d,0x7aed6f1b,0xdbd78134,0xaca380d1}},	//   _jón_, boat, näär, _luồn,
   {{0x7cf4c315,0x7c3c40f1,0x7d1d6f1c,0xa3e68b26}},	//   ràri, _werr, _fuss, _युग_,
   {{0x9c7cef1d,0x4427ef1e,0x2721d3c3,0x6f041335}},	//   soči, _ofn_, _lón_, _mhic,
   {{0x81be0079,0x7c3e09ee,0x2d826f1f,0x7640c0bb}},	//   _আশা_, _jepr, _iske_, wamy,
   {{0x7640eaad,0x6f02ef20,0x291de02c,0x7c3e0141}},	//   tamy, _phoc, _auwa_, _mepr,
   {{0x1c1e8036,0x3afac0fd,0x6266c1b4,0x6f040044}},	//   _पलवल_, rëpo_, سابق, _nhic,
   {{0xaca3800c,0x291dec0d,0xdee3811b,0x7c86c02b}},	//   _cuồn, _cuwa_, _чоти, пуне,
   {{0xdb1ac05f,0x16014028,0x443cc23b,0xc1bb8093}},	//   sztí, लेटर_, _qev_, _הממש,
   {{0x7cefc36b,0x7640c449,0x2d8fef21,0x4427c0b9}},	//   tørr, pamy, _erge_, _dfn_,
   {{0x443cc022,0x291dc09c,0x45d519b1,0x248580a8}},	//   _wev_, _fuwa_, домс, _zalm_,
   {{0x6f040057,0x2721c018,0xf1bf42b0,0x7c3e2f22}},	//   _dhic, _eón_, _afán_, _bepr,
   {{0xd041c03a,0x7c3e0147,0x7982ef23,0x443e94fb}},	//   kilə, _cepr, _isow, _jet_,
   {{0xe1ff405f,0x6d598ec7,0xb4bd0064,0x3b09403a}},	//   _szó_, zuwa, _आती_, tmaq_,
   {{0x2903405c,0x6f0400b4,0x291dc6df,0x33dbc0c3}},	//   _shja_, _ghic, _yuwa_, _לחוד,
   {{0x20c0c5ef,0x7cf044c9,0x27ed0036,0x62d4401c}},	// [3170] _còig_, värr, łen_, رآفر,
   {{0xddc400b3,0x752d0bc9,0x55bc00c3,0x5ce44466}},	//   _ubiš, _itaz, _למחו, нюха,
   {{0x26d241c8,0x6f1e0011,0x7c256f24,0x7d1d40cb}},	//   biyo_, _gupc, rchr, _wuss,
   {{0xc333c093,0x62866f25,0xf8ae808c,0xd9f98c85}},	//   תוף_, _gako, یکل_, онец_,
   {{0xdce281af,0x98b908c7,0x00000000,0x00000000}},	//   atoč, jusī_, --, --,
   {{0xeb999575,0x69094007,0x20cd006f,0x6aa9a2fe}},	//   жик_, _ežer, džik_, _woef,
   {{0x6d46094c,0x68f84107,0xd041c03a,0x7982c0bb}},	//   zska, őadá, cilə, _asow,
   {{0xdbd78c99,0xa2c14045,0x752d0066,0x26cd806f}},	//   väär, रोच्, _otaz, _umeo_,
   {{0xc648c032,0x752d01c6,0x0c79c59d,0x7d094157}},	//   سجيل_, _ntaz, осны_, _èess,
   {{0x5749cef7,0x6d4980cc,0x4990c01c,0x2ef20177}},	//   озом_, _ivea, ایور, _skyf_,
   {{0x69c46f26,0x98a04f26,0x291dc09c,0x6f042f27}},	//   zzie, spić_, _wuwa_, _phic,
   {{0x35b5c203,0x291def28,0x26d241c8,0x5f7483be}},	//   _обер, _tuwa_, xiyo_, _سامر,
   {{0x6d462f29,0xd041c03a,0x443e8093,0x7c3e1371}},	//   uska, zilə, _yet_, _pepr,
   {{0x6289dc00,0xe739e35b,0xfd5f0015,0xb4e80028}},	//   ldeo, _дек_, _huyệ, यके_,
   {{0x26d268ff,0x64438157,0x6f042f2a,0xbef94048}},	//   tiyo_, iani, _thic, ंतून_,
   {{0x225fe802,0x6e2d830d,0xdb248107,0x661baf2b}},	//   nguk_, ñabl, éséh, _nguk,
   {{0xe9da4603,0xda6541b4,0x6143532d,0x7c3e2f2c}},	// [3180] цка_, عافي, кета, _tepr,
   {{0x224d8853,0x3f9145c7,0x26c06f2d,0x661b924b}},	//   _adek_, _brzu_, shio_, _aguk,
   {{0x730652d9,0x6d4d80b3,0x6299d228,0x9e669cf8}},	//   _опоз, šaal, _onwo, двед,
   {{0xdb1ac107,0x753b8449,0x917a40d1,0x2487c0ce}},	//   nztá, _bwuz, _cập_, _lanm_,
   {{0x76446f2e,0x6569c077,0xdce44242,0x3946af2f}},	//   maiy, jteh, ltič, usos_,
   {{0x628f8018,0x7984012c,0xdd93859d,0x6e2980c7}},	//   _ócon, _msiw, ташы, _efeb,
   {{0x6aabc0b0,0xff2340b4,0x752446a6,0x753b80c7}},	//   _bogf, _амсо, lqiz, _ewuz,
   {{0x38c8878a,0xf526cfdf,0x66dec03f,0x6569e492}},	//   _کاری_, мфон, rīko, fteh,
   {{0x6aabc1f4,0x64438d6a,0x9a12c0eb,0x4427af30}},	//   _dogf, bani, _sọbụ, bcn_,
   {{0xb4bd0064,0xbcfb005f,0x7b15c077,0x6299c1f4}},	//   _आते_, rték, _ušun, _enwo,
   {{0x7aef0157,0x2487c053,0x76446f31,0xc05740c3}},	//   toct, _danm_, kaiy, וביץ_,
   {{0x76444056,0x2293c032,0x7982c09c,0x75209549}},	//   jaiy, _للمس, _tsow, _kumz,
   {{0x21200303,0x7aef0799,0x29184085,0x76444303}},	//   _cuih_, roct, _oira_, daiy,
   {{0x2d804062,0x79840181,0x00000000,0x00000000}},	//   dwie_, _dsiw, --, --,
   {{0x2fc9c09c,0x2d9200bb,0x46b2ef32,0x7c2ac1d6}},	//   _ƙage_, _erye_, _जवाह, _iffr,
   {{0x6a154708,0x260c0048,0xb5fb062a,0x764d00c7}},	//   ембу, ठेही_, rgáb, _uday,
   {{0x98b950fc,0xf70a00d1,0x75d50032,0x7cf04d4d}},	// [3190] плат_, _nầy_, _سيدا, tärp,
   {{0x2244c639,0x29186f33,0x6289c0b3,0x690b00f1}},	//   hamk_, _cira_, zdeo, _eżer,
   {{0x316940fc,0x6d4987c1,0x50d40032,0xf429c025}},	//   staz_, _svea, _جزير, lkää_,
   {{0x29186f34,0xa3c98045,0x867c0052,0xf70a00d1}},	//   _eira_, _लेग_, ַרוו, _bầy_,
   {{0x394981b4,0xda0101f9,0x2cacaf35,0xb5fb4031}},	//   éas_, ोधित_, _bodd_, _gbáp,
   {{0xc1048032,0xb0660051,0x644a4004,0x6b8340b0}},	//   نوني, _ikää, ófit, ængs,
   {{0x76408053,0x20cd06f0,0x917a40d1,0x2d84af36}},	//   _femy, ržih_, _tập_, _esme_,
   {{0xbcfb0089,0x0d85c3e1,0x6569c407,0x38b40051}},	//   stéh, елин, tteh, _väri_,
   {{0xf70a00d1,0x7520812c,0x78888017,0x661dc089}},	//   _gầy_, _gumz, _būvē, žsko,
   {{0x6d5d2c97,0x80b9c036,0xf0bb84e8,0x6443af37}},	//   dusa, इसें, _بارش_, qani,
   {{0x7eb5ef38,0xc6a7c00a,0x4ea7d32d,0x628b8011}},	//   _lápi, _орди, _орда, odgo,
   {{0x628b875a,0x7ebcc018,0x2487c05c,0xddc08053}},	//   ndgo, _tépa, _wanm_, _bemň,
   {{0xf1bf0032,0xd0a8c4e8,0x20d5c31e,0x67218011}},	//   scán_, سطین_, _пікс, _hulj,
   {{0x6721af39,0x3075004c,0x6d49d440,0x38b640b0}},	//   _kulj, кусс, msea, _værk_,
   {{0x21200b0e,0x67220570,0x69c60107,0x629b809c}},	//   _wuih_, _čojs, szke, _onuo,
   {{0xdce45487,0x7984009c,0xeabf405e,0x442a4f2d}},	//   rtič, _tsiw, _clù_, _sfb_,
   {{0x9c7cc05b,0xf389c00c,0x442a421b,0xaadb00c3}},	// [31a0] počt, _hả_, _pfb_, _מחקר,
   {{0x76460aee,0x6f0d6f3a,0xb4634846,0xe8f759b9}},	//   laky, amac, лкул, елу_,
   {{0x395d815d,0x103b00c3,0xf0b6c052,0x3ebf80cb}},	//   euws_, _מגיע, עלער_, _blut_,
   {{0x7ae4cc90,0x92b64032,0x6da6495c,0xd252801c}},	//   čitk, _أحدا, _зима, انش_,
   {{0x7ae3af3b,0xb0d712c2,0x291a2bad,0xa2b1af3c}},	//   énta, _डगमग, _kipa_, _अकर्,
   {{0x6445401c,0x644e4a14,0x7ebf00fd,0x6604012c}},	//   cahi, _udbi, _mëpa, _mzik,
   {{0x7ae42f3d,0xfce34e46,0x3dc6af3e,0x6d4bef3f}},	//   _ojit, _соро, szow_, _avga,
   {{0x2907e252,0x6441854a,0x68e3c06f,0x7b15c011}},	//   _ahna_, _eeli, _ajnd, _ušul,
   {{0xc866cace,0x63a344c9,0x66042f40,0xe8ca8156}},	//   нтни, ännv, _nzik, _егал_,
   {{0x6d5d009d,0x3ead80a8,0x26c02f41,0x672181d6}},	//   vusa, _zoet_, _alio_, _fulj,
   {{0x66042897,0x46dc0048,0x3202c089,0x38b08061}},	//   _azik, मचंह, ťky_, _fàrr_,
   {{0x8289c11b,0x7ae4005e,0x26dfc6f0,0x9a83c59d}},	//   _осіб_, _cjit, cnuo_, _бушл,
   {{0x6aad0398,0xcb67c01c,0xddeac01c,0xe0df0580}},	//   _voaf, ومیه_, _عرصه_, bsòl_,
   {{0x271e8044,0x645cc1ff,0x13f4c0c5,0x38b64086}},	//   _ọnya_, órid, _изля, _færi_,
   {{0x66042f42,0x27f3c066,0x224246eb,0xdce98085}},	//   _ezik, čané_, _bekk_, _jreġ,
   {{0x26c0005e,0x7522c2c0,0xa5bb0359,0x539b80c3}},	//   _glio_, _kuoz, hcói, הילו,
   {{0x26d90066,0x291a2f43,0x3eadaf44,0xf8bf01cb}},	// [31b0] érou_, _fipa_, _roet_, upés_,
   {{0x26dfc0ab,0xa3bd532e,0xa8a406d8,0x3ead814b}},	//   znuo_, इनल_, _брюк, _soet_,
   {{0xaa7b0066,0xf389c00c,0x3ead9f96,0x09d4c02a}},	//   cnýc, _xả_, _poet_, _হুমা,
   {{0x672187ca,0x7642c0e1,0x48fb0185,0xf1d2809d}},	//   _rulj, _neoy, ोगको_, _देहन,
   {{0xa2a4c42f,0x7982802f,0x09b5c02a,0x63bb4360}},	//   कान्, gwow, _জেনা, _ƙuns,
   {{0xb91280eb,0x656d4398,0xdb074025,0xbcfb07b0}},	//   monụ_, mtah, syjä, buée,
   {{0xf0940916,0xb8d98048,0x6d49c127,0x2d8c08c7}},	//   טנס_, _चव_, wsea, ādei_,
   {{0x6d49ef45,0x59d29001,0xf1b30028,0x67218013}},	//   tsea, _देवर, ुनान, _vulj,
   {{0x64472f46,0xc6928009,0xaa7b0185,0x2d588051}},	//   kaji, _דאן_, znýc, _пить_,
   {{0x22460242,0x61fb8080,0x6e2d00d2,0x64472f47}},	//   _žok_, _iyul, _afab, jaji,
   {{0x7afbef48,0x6009c051,0x64472f49,0x628d4010}},	//   plut, ьном_, daji, kdao,
   {{0x656d616b,0xe61f400c,0x38b40041,0xf389c00c}},	//   ktah, _ngô_, _lärt_, _vả_,
   {{0x6d4b8655,0x628bc018,0x9583039d,0x41d042b8}},	//   nsga, _iago, аляе, _सेंस,
   {{0x64472f4a,0x6d4b86a0,0x69c9e043,0xa156c0c3}},	//   gaji, isga, mzee, _יבנה_,
   {{0x76462f4b,0x99804007,0xcb670156,0x656d414b}},	//   paky, ybių_, каре_, etah,
   {{0x628d471c,0x26c0012c,0xcebb00e2,0x316dc070}},	//   gdao, _ulio_, _tuƙa_, otez_,
   {{0x7c24c2d6,0xceb2c626,0x614649f0,0x395fe1ae}},	// [31c0] _şiri, בין_, теза, nuus_,
   {{0xed590531,0x8c3c83a6,0x888cc009,0x1fb654de}},	//   áže_, _yoğu, ּראַ, ксер,
   {{0x44441aad,0xd83e804f,0x3eafc0a8,0x395fef4c}},	//   _ie_, ščka_, _oogt_, huus_,
   {{0x395fc134,0x75242f4d,0x61fb8024,0x76440053}},	//   kuus_, _kuiz, _byul, _jeiy,
   {{0x20cd0158,0xf1d281f9,0x2bb202ea,0x75242f4e}},	//   rživ_, _देशन, ीनवा, _juiz,
   {{0x61fb8396,0x6abd8045,0x69090086,0x2d924f2d}},	//   _dyul, ्फॉर, rþeg, mvye_,
   {{0x6d59af4f,0x8cb3905d,0x75241f9b,0x7d1aaf50}},	//   arwa, _अवरो, _luiz, _vits,
   {{0x7d1a8f8c,0x99990166,0x91bf905d,0xf65f40b0}},	//   _wits, lasť_, वनशै, _glæd_,
   {{0x66d60039,0x7d1aaf51,0x8c3c83a6,0x7522c157}},	//   eško, _tits, _soğu, _quoz,
   {{0xf548825d,0xf507800a,0x98b90026,0x7d1c6f52}},	//   mụ_, _анул_, vusį_, _jirs,
   {{0x39400231,0x645cc016,0x261502ea,0xf5488044}},	//   _awis_, òriq, नेनी_, lụ_,
   {{0x69c9c022,0x752400a8,0x7d1c46a6,0x6443ef53}},	//   bzee, _buiz, _lirs, _eeni,
   {{0x6723d3e1,0x59d9c50b,0xd130cde9,0x395fc0a8}},	//   _eunj, _बेपर, _امت_, cuus_,
   {{0x9f584018,0x63608044,0x38b64397,0x00000000}},	//   _eyré_, _ịnye, _kæru_, --,
   {{0x3ea96f54,0x97250d72,0xbddb4031,0xbff807ea}},	//   tjat_, افرو, _adèp, верх_,
   {{0x442cc396,0x656d4ba9,0x6e22402d,0x41b50107}},	//   lcd_, ttah, žobn, _ممبر,
   {{0x7ebcef55,0x628d424f,0xe2f840d9,0x291cef56}},	// [31d0] _répl, rdao, теті_, _kiva_,
   {{0xa5bb462a,0x27e980b4,0x6448ef57,0x2ab8c02e}},	//   _agóc, şani_, nadi, _débi_,
   {{0x68f51c6d,0x7d1c516b,0x442ec3ad,0xaca34112}},	//   mozd, _dirs, _mff_, _ntụb,
   {{0x7ced8004,0x62a54089,0xf5488112,0xa5c70086}},	//   lúrx, ároč, fụ_, _gróð,
   {{0x628bef58,0xd5a6c83b,0xee38893d,0x75240004}},	//   _rago, _اف_, тні_, _xuiz,
   {{0x6d4b851f,0xb4b1c021,0x6560c0f8,0xe057801c}},	//   rsga, _टके_, dumh, ئیات_,
   {{0xbcfb005f,0x26d9018c,0x442100b6,0xab8458d5}},	//   ltés, kiso_, _mgh_, _кутк,
   {{0x61fd4066,0x6723c123,0x6a85cb6f,0x395fc051}},	//   _kysl, _runj, улиа, tuus_,
   {{0x316dc669,0x987ec03a,0x99ddc066,0x6d408020}},	//   utez_, _açıq_, raňo, _gwma,
   {{0xaba9e3ed,0x248140cb,0x7d1c41c8,0xe0df43e2}},	//   евоз_, nehm_, _xirs, _dwòg_,
   {{0x395fef59,0x75241de1,0x316def5a,0xd048c03a}},	//   suus_, _suiz, stez_, nidə,
   {{0x442ed00b,0x6d4f44f9,0x66d6013f,0x291cc018}},	//   _eff_, _ovca, rško, _eiva_,
   {{0x44212f5b,0x798980f6,0xd048c080,0x7c3ad2e2}},	//   _bgh_, _jsew, hidə, bbtr,
   {{0xdce9c570,0x799602a4,0xd6d9c036,0x644528d5}},	//   oteč, _vryw, lił_, _cehi,
   {{0xd5e400eb,0x3f87c158,0x26d92591,0xd3b5020d}},	//   _baị, _usnu_, biso_, асть,
   {{0x290a40da,0x291cc568,0x3a2de010,0x9e660623}},	//   _shba_, _ziva_, ncep_, _свид,
   {{0x7e646f5c,0x68f5006c,0x6da355a4,0x6d4d6f5d}},	// [31e0] rgip, bozd, бита, gsaa,
   {{0x6280ef5e,0x291cc0d2,0x7649c07a,0x291c4041}},	//   zemo, _xiva_, haey, öva_,
   {{0x798983e0,0x80b9809d,0xf425c02a,0x9cd6c0c3}},	//   _asew, ्सने, _মজার_, נועה_,
   {{0x7d1c40fa,0xeafa85a7,0x1dd54048,0xbcfb2f5f}},	//   _wirs, ررات_, _ठेवत, stét,
   {{0x99dd8166,0x6e3bc41b,0x60d88141,0x35fa405f}},	//   _peňa, dbub, tivm, _سرحد_,
   {{0x26d9000b,0xf548825d,0x7d1e03f3,0x38a9c56e}},	//   ziso_, rụ_, _jips, _túry_,
   {{0x291cdbf7,0x2611c027,0xbcfb0086,0xf1c2004f}},	//   _riva_, देसी_, bréf, lišč_,
   {{0xd12f405f,0x7761c018,0x38b64086,0x7d54c0c5}},	//   _ذمہ_, dulx, _væru_, авих,
   {{0x6280caa1,0x38b64397,0xe0df4053,0x26c48149}},	//   remo, _fært_, _fwòd_, _ilmo_,
   {{0x2a69017b,0x26d905d1,0x3d000062,0x00000000}},	//   _scab_, wiso_, ोगों_, --,
   {{0x26d90060,0x2018c2f7,0xd6d9c036,0x68f504f2}},	//   tiso_, äri_, bił_, vozd,
   {{0xd6d9c036,0x442cc09c,0xd542c1c0,0x49cac93e}},	//   cił_, scd_, _gé̟g, _плен_,
   {{0x7526405c,0x20cd00b3,0x442eef60,0x64452f61}},	//   _nukz, džir_, _tff_, _pehi,
   {{0x26d900f7,0xf1c2004f,0x32dac1c0,0xab8705bf}},	//   siso_, dišč_, _fàyè_, лубк,
   {{0xbcfb030d,0x26d9040d,0x64452397,0x7ced803c}},	//   guéa, piso_, _vehi, rúrx,
   {{0x644a8f0e,0x7ae46f62,0x59c4884d,0x79a7047f}},	//   hafi, gnit, वनार, _брое,
   {{0x60f94051,0x3f854018,0x195845f1,0xa1584293}},	// [31f0] вная_, _áluz_, латы_, лату_,
   {{0x21294056,0xbcfb0107,0xdce9c047,0x38784061}},	//   rqah_, rtés, yteč, _cbrr_,
   {{0x711a021d,0x6d4f2f63,0x6f0d00d1,0x63bac240}},	//   _שותפ, lsca, _khac, nytn,
   {{0x4fd60093,0x224b0041,0x69cbaf64,0x764642a4}},	//   _כותב_, nack_, tzge, _geky,
   {{0x291eaf65,0xd04a803a,0x6f0d02d4,0x644a86df}},	//   _bita_, lifə, _mhac, fafi,
   {{0xd6d9c036,0x6e22ef66,0xdcebc085,0x26c941ff}},	//   wił_, _agob, _irgħ, lhao_,
   {{0x64554036,0xd49840c5,0xa3d4d337,0x30c98107}},	//   _idzi, _сря_, _सेल_, _یورپ_,
   {{0x26c941ff,0x272aaf67,0x291eaf68,0x2b5c40a0}},	//   nhao_, _dùn_, _eita_, ávce_,
   {{0x256f4ebb,0xd04a8435,0xdd94810e,0x2246c033}},	//   nül_, hifə, _латы, _deok_,
   {{0x6e22de81,0x6609af69,0x272a81c0,0x3ea01a4f}},	//   _egob, _izek, _fùn_, _snit_,
   {{0xb8edc045,0xeaaec05f,0xfd4a00eb,0x46b98048}},	//   _रत_, سٹی_, balị, _आवाह,
   {{0x95d9c051,0x6d5bc0fd,0xef170156,0x8c1a40c3}},	//   _идет_, prua, имэ_, כותי,
   {{0x64554fa1,0x3eadc0fd,0x764654c8,0xdca5c604}},	//   _odzi, mjet_, _reky, _вали,
   {{0xaca4425d,0x291e2f6a,0x63bac329,0x256f6f6b}},	//   _kwụs, öta_, bytn, dül_,
   {{0xe1ff402e,0x32334044,0x2d996616,0x32090053}},	//   _ayó_, _ụnụ_, _arse_, _ezay_,
   {{0xf1c200e5,0x7afb9e3f,0xd5e645f5,0xb605c0e5}},	//   tišč_, _nkut, ажби, _tišč,
   {{0x644a98c2,0x20c9c032,0x225d4036,0x2bd60e95}},	// [3200] yafi, _cúig_, ówka_, _डेरा,
   {{0x628f468a,0xbebd8007,0xe8c748de,0x644a8149}},	//   _eaco, _liūd, агул_, xafi,
   {{0x644a803a,0x7d01c4ff,0x7e268b24,0x3eadd9a5}},	//   vafi, ills, адеж, kjet_,
   {{0x2776c009,0x60dc0165,0x65628498,0xbcfb0004}},	//   יגען_, lirm, tuoh, trég,
   {{0xf194809b,0xa2c70063,0xed5740c5,0x69000051}},	//   силь, ासत्, _коя_, töeh,
   {{0xd90d808c,0x60f7893d,0xd8434066,0x3f9a00ab}},	//   فیق_, анія_, ručí_, _krpu_,
   {{0xadc3c02e,0x6e24240b,0x798bc32a,0x3f9840b9}},	//   _ilẹk, _ogib, _asgw, _urru_,
   {{0x3ebfef6c,0x7eb8405f,0xb5fb49a8,0x291eaf6d}},	//   gkut_, _típu, _abáy, _wita_,
   {{0x25a0c654,0x3cf8028c,0x7c294165,0x7ae14018}},	//   _šilb_, korv_, _şeri, élti,
   {{0x9873cbe0,0x6e242f6e,0x20074036,0xc7bac523}},	//   ольц, _agib, żnie_, вём_,
   {{0xf99f4053,0x4386801c,0x224b2d2d,0x48a7c030}},	//   _azèl_, _خلاق, tack_, ртым_,
   {{0xbcfb0018,0xfaa3d707,0xe8d94044,0x2b474379}},	//   guén, _махо, trị_, ânci_,
   {{0xa3dd4459,0x6d5d2f6f,0x3a248469,0x3cf32073}},	//   _तेन_, ursa, _mgmp_, ंकले_,
   {{0xe7f20444,0x6f028fcb,0x224b0414,0xaa7b0089}},	//   _आँखा_, hloc, sack_, mným,
   {{0xd437c009,0x6f02af70,0xaa7b0066,0xf99f4053}},	//   _דרוק_, kloc, lným, _ezèl_,
   {{0xbcfb034d,0x442340e2,0x4733c01c,0x67288303}},	//   cuén, _sgj_, _بروز, _mudj,
   {{0x67288043,0xaa7b0066,0x672740e2,0x7e6d09f3}},	// [3210] _ludj, nným, _sujj, _icap,
   {{0x2d9941be,0x7bce0570,0xa7fcc06a,0x7ebcc01e}},	//   _vrse_, bzbu, ygıl, _dépi,
   {{0x77638018,0x69cf0017,0x7ae9af71,0x67288303}},	//   xunx, lzce, _pjet, _nudj,
   {{0x8f9a00c3,0x64474149,0x64554062,0x179a01f2}},	//   _עירי, _weji, _wdzi, _עירב,
   {{0x3a248018,0x50b58768,0xd4d985dd,0x2d8b4077}},	//   _dgmp_, йску, лькі_, _usce_,
   {{0x6728894e,0xb4d5c027,0x26d95c61,0x6aa2c379}},	//   _budj, _सगे_, _hmso_, _anof,
   {{0x987c0009,0x26c6c0f8,0xdced4066,0x3ebfc051}},	//   דרוק, _bloo_, ntač, tkut_,
   {{0x212b81cb,0x443ee15c,0x645cc086,0xe8df8083}},	//   _écho_, ebt_, órin, _iwọn_,
   {{0x60dc0080,0x798d00bc,0x2d99e2de,0x2eaa4052}},	//   yirm, _nsaw, íse_, רשפּ,
   {{0xd7020285,0x2d8d80c4,0x60dc0018,0x3ebfef72}},	//   ोष्ठ_, _isee_, xirm, skut_,
   {{0x2cb8c041,0xdced406f,0x5f958107,0x6728af73}},	//   örda_, jtač, _دلائ, _gudj,
   {{0x64489fdd,0x66e60bf3,0xd491835d,0x752180b9}},	//   _zedi, сома, _hà_, _hilz,
   {{0xfe70c005,0xd36ec1aa,0x2ba9c374,0x21290303}},	//   _آدم_, وهی_, _छपवा, _cuah_,
   {{0xa2d3e32e,0x3a3fc033,0x44258011,0x63bc04c9}},	//   बोर्, lbup_, _jgl_, tyrn,
   {{0xd491800c,0x764d411c,0x75218017,0x4f9509a4}},	//   _mà_, faay, _milz, орту,
   {{0xf8bf403c,0x7e7b80eb,0x60c74011,0x2d8d8044}},	//   _quén_, _nbup, _aljm, _osee_,
   {{0x6aa42f74,0x93bcc0b4,0xbcfb4396,0x62862f75}},	// [3220] _inif, scăt, _aqéq, meko,
   {{0xbcfb0669,0xb46606b1,0x62846f76,0xf8b9c705}},	//   trée, _укол, seio, ेसिय,
   {{0x0eba8097,0xdb1c40fd,0x76499494,0xb69b41cb}},	//   луды_, nyrë, _beey, _châs,
   {{0x91e64a67,0x6efd2f77,0xbcfb01cb,0x395fef78}},	//   _гоме, lébr, rrée, krus_,
   {{0x7ebcc05f,0xa3d9cb08,0x9dba43d0,0x2365c2bc}},	//   _képv, _ठेस_, _сыну_, hulj_,
   {{0x8fa64ec4,0x395fef79,0xdb09c166,0x361b0052}},	//   _лаге, drus_, ľnýc, אונד,
   {{0x67208dd1,0x799b817b,0xf1d0cf4a,0xdb1c413b}},	//   _timj, _eruw, _तेजन, jyrë,
   {{0xa5bb4064,0xaa7b180a,0x7e69c6a1,0x9f5f001e}},	//   _ogól, tným, ggep, érée_,
   {{0xc6934093,0x799b80bf,0xceb4403a,0xdddb9498}},	//   לאה_, _gruw, mməd_, _zauž,
   {{0xbcfb0018,0x443ec0cb,0xaa7b0089,0x26c20051}},	//   guél, ubt_, rným, ekko_,
   {{0xaa7b0089,0xb4fb4052,0x22491433,0x21290303}},	//   sným, רליר, _peak_, _suah_,
   {{0x635c40b4,0xbc1b4052,0x8afec0e2,0x7521af7a}},	//   mănă, טויש, buƙa, _zilz,
   {{0x6f16456e,0x7af3c5ca,0x7792c231,0x00000000}},	//   dmyc, űjtö, زیکا, --,
   {{0x2418c823,0x97a6c179,0x6aa4075d,0xb5fb2e7b}},	//   _колы_, _грил, _enif, ngái,
   {{0xf487c2f0,0xb6c74525,0x3a36425d,0x5fa882ea}},	//   _دانی, бсай, _ọgụ_, कमिल,
   {{0x21291514,0x6602c31c,0x62862f7b,0xbb3bc009}},	//   _tuah_, _kyok, ceko, _געהי,
   {{0x58d50b24,0xd04e0080,0x22640089,0x31604013}},	// [3230] _моит, hibə, šské_, griz_,
   {{0x764985d1,0x00000000,0x00000000,0x00000000}},	//   _seey, --, --, --,
   {{0x6d4640f1,0xdea1801c,0x56958051,0x799b8396}},	//   _ewka, ویسی, жает, _sruw,
   {{0x57fbc0c3,0x31604080,0xd7fbc052,0x2b458f2d}},	//   נלאו, briz_, נהאל, _rwlc_,
   {{0x7521af7c,0x9cf580d9,0x66d60026,0x00000000}},	//   _pilz, озді, uški, --,
   {{0x90c5809b,0xdce44077,0x66e54007,0xe359865e}},	//   юбле, vtić, dėki, ашиш_,
   {{0xa3df00b2,0x3ec48107,0x16a9cd37,0xaa7b0086}},	//   _देम_, ártó_, ивки_, rnýj,
   {{0x212b48f1,0xd299c097,0x660d20d4,0xb5fb0032}},	//   _kuch_, рткі_, _ozak, agái,
   {{0x3f9cc09d,0x785b8017,0x6602c449,0x395fef7d}},	//   _arvu_, tāvē, _cyok, urus_,
   {{0x4425af7e,0xdb1c40fd,0xb80dcc63,0x26c92ccb}},	//   _ugl_, tyrë, _हरदम_, _alao_,
   {{0xbef7008f,0x248783bc,0x3f9cc011,0xe9df4019}},	//   ीतून_, menm_, _crvu_, _seúl_,
   {{0x6458ef7f,0xdce44011,0x6e2900a0,0x09e8c02a}},	//   _edvi, ptić, žebn, _পররা,
   {{0x2365c06f,0x3495c42e,0x7ae9ef80,0x26c2073b}},	//   sulj_, _мадр, mnet, rkko_,
   {{0xa315808f,0x7e7d40fa,0x7ebcc01e,0x764bc107}},	//   तगुज_, _absp, _dépu, _hegy,
   {{0xead28031,0xd7f20032,0x6efd01cb,0x62862f81}},	//   _bẹ̀_, ذكر_, rébr, peko,
   {{0xb6a345a6,0x764bc05f,0x78a5127d,0x6458c066}},	//   мисл, _jegy, _enhv, _zdvi,
   {{0xdce400f6,0xa96a406f,0xcee9001c,0x2905d738}},	// [3240] _esiġ, риза_, _درون_, olla_,
   {{0x2905ef82,0x7c654032,0x7ae9cb83,0x3952415a}},	//   nlla_, كامل, hnet, rsys_,
   {{0x25bfc21b,0x2f01c166,0xb5fb4032,0x987b0052}},	//   hyul_, lógu_, _scát, _דריק,
   {{0x7afbcc43,0x31606f83,0x4427c033,0x764bef84}},	//   jout, priz_, _lgn_, _negy,
   {{0x0caa9c53,0x3f86402d,0x2d8f40b0,0xddc88036}},	//   итки_, ňou_, æget_, _żołn,
   {{0x25bfc29e,0x9c134112,0x25fdc027,0x7bcdc09c}},	//   dyul_, _nọwo, _लड़ी_, _ƙaul,
   {{0x68ed8032,0x6441ef85,0xb5fb0359,0xdb154c1e}},	//   éada, dbli, rgái, lyzá,
   {{0x386081df,0xd04e0080,0x644ad0c7,0x02b841f9}},	//   şir_, ribə, _sefi, _इकोन,
   {{0x2cb8454a,0x2db74009,0x30768051,0x7659c1f4}},	//   _kord_, ַלטן_, _мужс, _ddwy,
   {{0x68fc0e7c,0x7c3b411f,0x6441cb32,0x764f2f86}},	//   jord, _đurk, gbli, wacy,
   {{0x6d5600b6,0x764bc107,0xd1b7c05f,0x6d4fc01f}},	//   _avya, _fegy, مایا_, ácar,
   {{0x8afd0036,0x4427cdf2,0x26cdef87,0x2cb86f88}},	//   dręc, _egn_, cheo_, _lord_,
   {{0xae16cd6c,0x68fc0ab5,0x7523c5d4,0x171b8009}},	//   देशन_, ford, _finz, יוטע,
   {{0xd5b800d7,0x6724017b,0x212b6f89,0xbb2ac119}},	//   іся_, _eiij, _ruch_, _кцие_,
   {{0x4394161d,0xbcfb2f8a,0x66042185,0x80a3c231}},	//   марс, quém, _eyik, _زمين,
   {{0x629640f8,0x660d0545,0xdce28026,0x672405d1}},	//   gdyo, _tzak, duoč, _giij,
   {{0xb427154f,0x59de4430,0x00000000,0x00000000}},	// [3250] _وعدو, _नेदर, --, --,
   {{0x7afbc4c1,0x39490c47,0x9c7cef8b,0x6562a3f2}},	//   zout, _iwas_, biče, droh,
   {{0x602dc107,0x7ae0ef8c,0xbcfb01cb,0x224b6f8d}},	//   _hőmé, kimt, créa, _teck_,
   {{0x23fa00c3,0xeabf45ef,0x752d2303,0x7ae0dc42}},	//   _להתא, _diùc_, _kuaz, jimt,
   {{0xaaa9c185,0x7ae9ef8e,0x64a5af8f,0x752d001f}},	//   कासक, vnet, зала, _juaz,
   {{0x3ea6c007,0x3eb95433,0x645a80b9,0x78b8c0bb}},	//   _anot_, _host_, _cdti, _novv,
   {{0x387c0041,0x26cdc2c0,0x7e648032,0x4427c14d}},	//   _övre_, theo_, óipc, _rgn_,
   {{0x2d84006a,0x7ebf013b,0xee39c0c5,0x68fc2f90}},	//   çmek_, _këpu, щни_, zord,
   {{0x4427c07a,0x764bc05f,0x7afbedb7,0x2d99af91}},	//   _pgn_, _vegy, rout, _ése_,
   {{0x3ea6c04f,0x3eb940c3,0x26cdc070,0x753baf92}},	//   _enot_, _lost_, sheo_, _ituz,
   {{0x39490f7c,0x01bd8079,0x3eb941d4,0x7ebcd0ec}},	//   _awas_, _অধিদ, _oost_, _pépt,
   {{0xef0ec11b,0x7523ef93,0x68fc147e,0x6441ef94}},	//   _їм_, _winz, word, sbli,
   {{0x59bd842f,0x2731a7b9,0x7aeb8032,0x6da5d5a4}},	//   ्निर, _hán_, ingt, _хила,
   {{0x9c7cc618,0x3a292f95,0x224d815d,0x2012803a}},	//   tiče, _egap_, _leek_, əyib_,
   {{0x8fa30b8e,0x03a30051,0x7aeb80f8,0x7cf680b4}},	//   наре, ниро, kngt, târz,
   {{0x27318086,0x3eb96f96,0xa3d4c045,0x68fc180e}},	//   _mán_, _cost_, _सेट_, sord,
   {{0x2ee04057,0x62961b85,0xc56640c5,0xdb0ac107}},	// [3260] riif_, _iayo, якак, ínés,
   {{0x3ce08048,0x2d9200b6,0x7ae0dd0f,0x8ca1c8b8}},	//   _औषधे_, _isye_, zimt, _कोमो,
   {{0x224d80a8,0x6569c1ff,0x7ebcc1cb,0x2d8f40b0}},	//   _beek_, hueh, _mépr, æger_,
   {{0x6562af97,0xb4c8c314,0xaacc0759,0x2d9f814d}},	//   troh, _ईत्_, ासिक, _brue_,
   {{0x200e07ef,0x765b80bb,0x62960aa1,0xa53398d5}},	//   šlić_, _dduy, _mayo, еніч,
   {{0x92c8c02a,0xfd07d54f,0x7644516b,0x3ea6ef98}},	//   _ঈদে_, _سج_, lbiy, _snot_,
   {{0x7afd2f99,0xf65f00b0,0xe29a841a,0x753b80bb}},	//   yost, mhæv_, _лав_, _etuz,
   {{0x629619e7,0x2731af9a,0x3f9eaf9b,0xd566cf7f}},	//   _nayo, _dán_, _vrtu_, птоп,
   {{0x7ae2a246,0xb5fb4018,0xa3d4e418,0x3914c025}},	//   miot, _edáf, _सेज_, ммир,
   {{0x68e1ef9c,0x4734d707,0x02c9505d,0x48aac1f6}},	//   gild, мнос, _रत्न, стим_,
   {{0x644e425d,0x78a8880d,0x6606458a,0x28b004d0}},	//   _mebi, _indv, _lykk, ञानि,
   {{0x7ae28e5a,0x4438417b,0x6726404f,0x69c0c070}},	//   niot, _lfr_, _nikj, pyme,
   {{0x2b40838f,0x3eb96f9d,0x18a6d924,0x764441c8}},	//   ćicu_, _rost_, _надм, dbiy,
   {{0x645c40fd,0xc8bea7bb,0x3eb94157,0x65600359}},	//   _ndri, ्सिट, _sost_, ámha,
   {{0x6c7bc093,0xe78427ee,0x20050086,0x25a000d2}},	//   _האופ, нуто, æli_, _eril_,
   {{0x6606405c,0x96d84036,0x764442a7,0x443840b1}},	//   _bykk, नोलॉ, gbiy, _afr_,
   {{0x645c6f9e,0x442a5e00,0x6aac4c81,0x3ea92f9f}},	// [3270] _bdri, _bgb_, _šofé, _inat_,
   {{0x644e6fa0,0xfaff014b,0xf8d10047,0x76444149}},	//   _cebi, loë_, _हतिय, abiy,
   {{0x29078066,0xdb0e8089,0x645c475e,0x7ae28439}},	//   vlna_, ždýc, _ddri, fiot,
   {{0x6d56421b,0x65646fa1,0xd8388141,0x3cf0c048}},	//   bsya, brih, _afč_, ीकडे_,
   {{0xc984440a,0x68e1c080,0x7e878007,0x644e5312}},	//   _пури, yild, _įspė, _febi,
   {{0x44444321,0x2eba1a7e,0xf771861e,0xe5a28157}},	//   cb_, _उक्त, ناب_, тиши,
   {{0x78ba8089,0xfc4680a0,0xbcfb2fa2,0x32e3c053}},	//   _dotv, _říci_, guéi, _nèyè_,
   {{0x68e1c2a4,0x2d9f8093,0x7e7d015d,0x2326ca23}},	//   wild, _true_, jfsp, мощи_,
   {{0x7aed47f3,0x2f188051,0x7c878a23,0x6b9c0123}},	//   inat, _хоть_, _нуже, zvrg,
   {{0x78ba8fe7,0xf65f4065,0x5c748522,0x2d8dc14d}},	//   _gotv, _blæk_, _плут, rwee_,
   {{0x7aed5629,0x64454269,0xc05240c3,0xdbcc0086}},	//   knat, ibhi, כזי_, jóða,
   {{0xabfa80c3,0xc4c900c3,0x6d564149,0xddc9817a}},	//   _והער, _דג_, ysya, _obeż,
   {{0x444445d1,0x6abb9c2d,0x67265894,0x62998127}},	//   yb_, _mouf, _rikj, idwo,
   {{0x62962fa3,0x38730303,0x2f1bc25d,0x6d59c0b6}},	//   _wayo, _ccxr_, _ụgha_, _ivwa,
   {{0x1d0705e4,0x46f605a6,0xe7370221,0x4444404f}},	//   фери_, _очит, дес_, vb_,
   {{0x6d564303,0x443848c2,0x65644dec,0x69d9454a}},	//   tsya, _sfr_, trih, _नइखी,
   {{0x628bafa4,0x7bc3afa5,0x44384085,0x6f042fa6}},	// [3280] dego, hynu, _pfr_, _ikic,
   {{0x3cfa4064,0x6d9208c9,0xa3bf93c4,0x39406fa7}},	//   ्तें_, ržać, ुना_, rpis_,
   {{0x644e40fa,0xb4fac009,0x6abb801e,0x7ae2afa8}},	//   _vebi, קלער, _bouf, tiot,
   {{0x6e2d806c,0x656b823f,0x443a0011,0x78ba8089}},	//   žabn, fugh, _hfp_, _sotv,
   {{0xe8fa9654,0x6d564056,0x44384157,0x6abb8047}},	//   олд_, qsya, _tfr_, _douf,
   {{0xdca38b8e,0x64a38210,0x3f9c806f,0x23650147}},	//   качи, кача, tvvu_, šlje_,
   {{0x6d59c053,0x28b1c1f9,0x6f09efa9,0xd9b8c371}},	//   _avwa, जानि, flec, ेन्ट,
   {{0x44381e33,0x2360804f,0x7ae46faa,0x656ba093}},	//   hcr_, čij_, niit, bugh,
   {{0xadba8032,0x225d4036,0x2007c138,0x69d68185}},	//   _بهذا_, ówki_, _ayni_, _मेची,
   {{0x673e0514,0x2246a6c2,0xb5fb0107,0x66f20017}},	//   _otpj, lbok_, zgás, vāka,
   {{0x7ae46fab,0xda6fcbc1,0x1bf296e2,0xbfec402a}},	//   kiit, _ия_, _अखिल_, _করুণ_,
   {{0x443a018a,0x2733c00c,0x4ea3c1dc,0x03574052}},	//   _afp_, _dãn_, _арша, ויטש_,
   {{0x7ae46fac,0x6d4280fc,0x2b5a00d2,0x3e0405f5}},	//   diit, npoa, _avpc_, вярв,
   {{0x7c840437,0xbcfb0018,0x3cfa4036,0x3166afad}},	//   кусе, ntéx, ्तों_, iroz_,
   {{0x67d500d9,0xdfd5159b,0x261ac8b8,0x75274206}},	//   хову, ховы, मेरी_, _rijz,
   {{0x2ee4c0d2,0x7528afae,0x628bafaf,0x20c9cb87}},	//   nimf_, _lidz, xego, _lúil_,
   {{0x6282c40d,0x02df4374,0xb5fb0107,0x229f0031}},	// [3290] _mboo, _नगीन, rgás, _ẹkú_,
   {{0x24984085,0xddc44007,0x4395161d,0x6aa9afb0}},	//   _carm_, ugiš, _заос, _snef,
   {{0xf09200c3,0x6f1d00a8,0x249851fd,0x656b8044}},	//   _גני_, omsc, _darm_, wugh,
   {{0x2246afb1,0xa25b401e,0x217580d9,0x996740c5}},	//   gbok_, _clôt, еукр, _отгл,
   {{0x2d4d0347,0x690d8018,0x463a4052,0x24986fb2}},	//   nže_, búel, _מערע, _farm_,
   {{0x656bae16,0xe05744e8,0x6d4d055e,0xd13e4062}},	//   rugh, _آیات_, _mwaa, żące_,
   {{0x98a480cc,0x20c9c359,0x201140bb,0x6e2d2fb3}},	//   _sumă_, _dúil_, _uzzi_, _ogab,
   {{0x64552fb4,0x26c94011,0x7d1c00b3,0x78aac053}},	//   hazi, nkao_, zmrs, _anfv,
   {{0x320900f8,0x7bce80cb,0x6d4d025d,0x656d5367}},	//   _nyay_, _übun, _nwaa, nuah,
   {{0xb881c066,0x6f09e1eb,0x68e3afb5,0x6d598fee}},	//   _číse, slec, qind, mswa,
   {{0x656d6fb6,0x6d5983b3,0xa3df009d,0xdcfb80ab}},	//   huah, lswa, _देल_, _usuđ,
   {{0x6d4d01ae,0x5fd88048,0x26c94123,0x6609811c}},	//   _bwaa, _भेटल, jkao_, _kyek,
   {{0x2bc80109,0x2901409d,0x6aabc0c4,0xe8eec7d5}},	//   रन्थ, koha_, _ingf, _бл_,
   {{0x2bb681f9,0x6e2d2176,0x6299c573,0x67298026}},	//   _अपमा, _egab, _hawo, _liej,
   {{0x316defb7,0x63832fb8,0x6d4d01ae,0x7ae46fb9}},	//   luez_, лгра, _ewaa, tiit,
   {{0x6d59afba,0x3f87c033,0xe814c028,0x2d96011b}},	//   kswa, _ipnu_, _डरता_, _зрос,
   {{0x6609afbb,0xe04651fb,0x7ae44c3f,0x213fa891}},	// [32a0] _nyek, ензи, riit, _ntuh_,
   {{0x26d241c6,0x6e3b840d,0xca4a001c,0x6d598fd7}},	//   shyo_, _afub, _بلکه_, dswa,
   {{0x22520340,0xb4cc02f6,0x0b4640c5,0x6d598206}},	//   _keyk_, लसी_, хнен, eswa,
   {{0x66c60086,0xddc08047,0x660980bc,0x8ca1c84d}},	//   _bóki, _zemř, _byek, _कोसो,
   {{0x199490f2,0x6da385a6,0x78bc4253,0x29016fbc}},	//   таля, лица, _torv, boha_,
   {{0x765646df,0x7ae62fbd,0x657bc010,0x2246afbe}},	//   layy, hikt, dtuh, sbok_,
   {{0x6625c080,0xa3ca825c,0x442c8125,0x66098d2d}},	//   ərkə, रैं_, _vgd_, _eyek,
   {{0x42538c59,0xe29783bf,0x290580ce,0x213f8085}},	//   _منفر, _пас_, _ekla_, _ftuh_,
   {{0x6d445efd,0x6f00efbf,0x1637c032,0x660980bc}},	//   npia, romc, رسية_, _gyek,
   {{0x442c807a,0x6e2d2fc0,0xddc98654,0xdbd68051}},	//   _ugd_, _sgab, _uceš, _pääo,
   {{0xa803003a,0x6284005e,0x7b05c018,0x3d16854a}},	//   _çıxm, _bbio, góus, _पीये_,
   {{0x20c0c5ef,0xbcfb01cb,0x212a4359,0x316dc7b0}},	//   _còir_, rrém, _libh_, buez_,
   {{0x212b815d,0x6ce6c4c5,0x3d0bc0b2,0x69c60107}},	//   _écht_, _піке, _ठीके_, gyke,
   {{0xab648600,0x212a42cd,0x6280c7f5,0xe81781f9}},	//   _grüß, _nibh_, lfmo, धेका_,
   {{0x7ae6181f,0x2f120107,0x25a04011,0xe804017e}},	//   bikt, sága_, evil_, _शुदा_,
   {{0x6d4d13ff,0x7c25c066,0x442ec303,0x212a4321}},	//   _twaa, _úhra, _hgf_, _aibh_,
   {{0x69c62fc1,0x26c94158,0xdce9c0b4,0x442ec1ff}},	// [32b0] cyke, rkao_, _înăl, _kgf_,
   {{0x3a2d8018,0x62840036,0x656d405c,0x765640f8}},	//   _sgep_, _zbio, ruah, aayy,
   {{0x29016fc2,0x69104134,0x69c14080,0x6d59875d}},	//   roha_, mäel, _əley, wswa,
   {{0x29058066,0x394d802f,0x59b0c564,0x68e700a8}},	//   _skla_, _pwes_, जमार, lijd,
   {{0x22496fc3,0x6d59afc4,0x2cbe821b,0x6d40805c}},	//   mbak_, uswa, _botd_, _ctma,
   {{0x68e71125,0x22494127,0x2cac8f2d,0x29184061}},	//   nijd, lbak_, _cndd_, _ghra_,
   {{0x973c8011,0xdb18c051,0x656f2fc5,0x7d01efc6}},	//   _prća, kyvä, huch, vols,
   {{0x656482bc,0x22496fc7,0xddcd0283,0xd0550080}},	//   šiha, nbak_, _bbaż, rizə,
   {{0x629d01f4,0x7d01d230,0x657d2fc8,0x98a48026}},	//   ddso, tols, jtsh, _sumą_,
   {{0x2579c3bc,0x29030523,0xa2bd8045,0x66e7c053}},	//   rèl_, joja_, वॉर्, _bèkè,
   {{0x3a75cacf,0x6f0d6fc9,0x6299ddea,0x29032c4d}},	//   _алер, klac, _tawo, doja_,
   {{0x628f25ea,0xdb01c01e,0x81dd002a,0x28a6c5a8}},	//   geco, _orlé, _তুই_, _कोठि,
   {{0xe778c107,0x3a2fc0c7,0x7bc70397,0x645740b9}},	//   ولیں_, _iggp_, eyju, kaxi,
   {{0x6f0d4359,0x6aad017b,0x69c6202b,0x394000e5}},	//   elac, _enaf, ryke, _vtis_,
   {{0xb4bfcb26,0x2fc780f8,0x48070156,0x6d5d44a0}},	//   ीसी_, nyng_, верн_, _avsa,
   {{0x7649c94a,0x7d03a413,0x629b809c,0x23650107}},	//   nbey, hons, _nauo, álja_,
   {{0x78be0820,0x6569db85,0x64576fca,0x452a474a}},	// [32c0] _topv, nreh, faxi, джан_,
   {{0x29032fcb,0x6d446fcc,0xa44344b6,0x48bc802a}},	//   coja_, rpia, инуд, _অগ্র,
   {{0x6d446fcd,0xc00fc0d1,0x22494107,0xbcfb056e}},	//   spia, _đuối_, bbak_, dréh,
   {{0x25ad406c,0xd94691c0,0x0ea947c6,0x6f0d4e94}},	//   _šele_, веди, _चोपड, clac,
   {{0x290cc086,0x916d40d1,0x19f940b4,0x2cac8085}},	//   ylda_, _tốt_, _зэрь_, _pndd_,
   {{0x25a48010,0xf8bf400c,0x7d074303,0x3cdd8047}},	//   _vrml_, _quét_, _gkjs, कोले_,
   {{0xfce358f9,0x84e35133,0x3ead843e,0xfe7f00d2}},	//   _торо, _торж, _fnet_, diïn_,
   {{0x628f0018,0xb998cec5,0x16cc0048,0x2907efce}},	//   xeco, евих_, ासोब, _akna_,
   {{0x57cac49d,0xbcfb0066,0x6282afcf,0xaca9c05f}},	//   ान्ह, bréh, mfoo, کھنے_,
   {{0x934687d4,0x3ebf815d,0x2617408f,0x26d2017b}},	//   _анже, _zout_, पेटी_, _alyo_,
   {{0x6f0d6fd0,0x6910409d,0xdb18c051,0xadc4002e}},	//   ylac, väel, tyvä, _ibẹw,
   {{0x7ae2efd1,0x7c278107,0x7c3e00b0,0x657d02e9}},	//   _umot, _újra, _afpr, ttsh,
   {{0x629d098f,0x291a0321,0xc6938323,0x656f0070}},	//   rdso, _bhpa_, באר_, uuch,
   {{0xdb18c025,0x645a0e79,0xa3df2fd2,0x2738afd3}},	//   syvä, ótip, _देउ_, _kén_,
   {{0x03c40a74,0xd8388011,0x628f01ff,0xf093c0c3}},	//   астм, _gače_, peco, _כנס_,
   {{0xbcfb2fd4,0xb2750051,0x6458afd5,0x66d901c0}},	//   guér, _слиш, havi, _dúkù,
   {{0x2738a941,0x29032a39,0xdced00f6,0x443eafd6}},	// [32d0] _lén_, poja_, _esaġ, _oft_,
   {{0x31696eae,0x68e8c11c,0x22494b32,0x8afec09c}},	//   rraz_, nidd, sbak_, muƙu,
   {{0x44274051,0x09bd8db4,0x68e50061,0x1fe1002a}},	//   än_, ्न्य, _imhd, _মুরস,
   {{0x26c00018,0xdea406df,0xf8bf4070,0x4615801c}},	//   _xoio_, _bunƙ, _pués_, هوار,
   {{0xdea4009c,0x68e8c11c,0x443eafd7,0x64588026}},	//   _cunƙ, kidd, _bft_, favi,
   {{0xf77340fb,0x3ebf83bc,0x660d0502,0x3ead862e}},	//   _پاس_, _wout_, _myak, _wnet_,
   {{0x6d42c545,0x443e8c2a,0x3dc940f8,0x212c8061}},	//   _atoa, _dft_, lyaw_, _didh_,
   {{0xe3a681aa,0x6d5f11a5,0x39468022,0x6569c107}},	//   اشوی, _ovqa, bpos_, treh,
   {{0xdd948c38,0x6d5bc046,0x1be38036,0xbcfb01cb}},	//   _каты, usua, _केरल_, préh,
   {{0xb4bfc09d,0x6acc0045,0x25a6c053,0xbcfb276d}},	//   ीसे_, ास्र, _drol_, bréi,
   {{0x6d42efd8,0x64556fd9,0x4b2616a8,0x03260077}},	//   _etoa, _mezi, лмов, лдон,
   {{0x6146132d,0x60c18e7c,0x25a6c018,0x673544f9}},	//   лема, _holm, _frol_, _muzj,
   {{0x9583010e,0x7afb406c,0xa069c4e9,0x6d490119}},	//   бляе, čutl, _зала_, ţean,
   {{0xdce46fda,0x8b95cdd3,0x19b680c3,0xa3ca8062}},	//   trič, _брич, אפשר_, रैक_,
   {{0x6b63011b,0x660d0f12,0x8c4305af,0xac09c2ae}},	//   йкра, _eyak, сесе, _янка_,
   {{0x6abbc1d0,0xa3d4afdb,0xbcfb0107,0x6d461898}},	//   njuf, हनत_, ység, ppka,
   {{0x2167481e,0x69dbc0e1,0x69c9efdc,0x98a7c41b}},	// [32e0] лити_, nzue, nyee, _linč_,
   {{0x7b134080,0x765606e2,0xbf0fc063,0xa90a4359}},	//   lçul, _heyy, ातुन_, ريال_,
   {{0x320d8057,0x443140eb,0x645889b8,0x160ac027}},	//   _ayey_, _dgz_, vavi, _हुनर_,
   {{0xdd12403f,0xc878c06a,0xf8be8e1a,0xe1faa8ab}},	//   _kļūs, riği_, ्स्प, нге_,
   {{0x20d085ef,0x3946afdd,0x212c813b,0x54a51006}},	//   _dàin_, upos_, _pidh_, _صحیف,
   {{0xbcfb2fde,0x3f51c017,0x443140a8,0x6282afdf}},	//   tréi, kšu_, _ggz_, sfoo,
   {{0xf72ac156,0x7ae9e322,0x60c18a1f,0xb8eca202}},	//   нций_, fiet, _dolm, _लव_,
   {{0x5a34daec,0x26c26fe0,0x28a487f6,0x9634c19b}},	//   шнит, _joko_, _गोरि, шниц,
   {{0x50468748,0x64554339,0x3d26c11b,0xe8fa83bf}},	//   _безб, _yezi, льов, _зла_,
   {{0x27388004,0xf99340c3,0x3ea06fe1,0x672d0398}},	//   _tén_, צרת_, hdit_, _siaj,
   {{0x69c9c057,0x660d1eb5,0x33f6804c,0x2ef5202a}},	//   ayee, _syak, _счас, изор,
   {{0x81e60079,0xdfcf8032,0x26cdc070,0x7bcdc6df}},	//   _বুধ_, _عين_, ckeo_, _ƙaur,
   {{0x22590026,0xdc3cc0e5,0xdced01d6,0x7bcaafe2}},	//   rask_, lšči, _jsaħ, lyfu,
   {{0x63bccb9a,0xa3c20063,0x940c8080,0xa7d6caaa}},	//   ørns, ्नं_, _sadə_, _متعص,
   {{0xb2ab4a74,0x672d0022,0xe4e4031e,0xcb1b401b}},	//   нтаж_, _tiaj, сіян, еќа_,
   {{0x660d0053,0x00000000,0x00000000,0x00000000}},	//   _tyak, --, --, --,
   {{0xa85542d3,0x660d00f7,0x7d1c405e,0xb5fb41c0}},	// [32f0] икач, _uyak, _bhrs, _edán,
   {{0xdc3cc039,0x25a90c47,0x95840036,0x7d1c405e}},	//   kšči, _iral_, żący, _chrs,
   {{0x25e6c021,0x26c240b9,0x5c37c052,0x8c9f8045}},	//   _जेसी_, _foko_, ארבן_, _गोगो,
   {{0xdced00f6,0x25a900b5,0x3dc9402f,0x9948016a}},	//   _bsaħ, _kral_, pyaw_, _جلیل_,
   {{0x60c1a971,0x69c6c11b,0x286b4748,0xee38831e}},	//   _polm, økel, _прво_, уні_,
   {{0x656d6fe3,0x25a9c04f,0x69c9c046,0x4c8484c5}},	//   mrah, _šalo_, vyee, йлів,
   {{0x2905e1fc,0x2fc744d3,0x6f1b992a,0x32d5c6e4}},	//   vola_, ängd_, _thuc, ицис,
   {{0x44330b64,0x2905efe4,0x8d65c2b1,0x764d6fe5}},	//   _lgx_, wola_, авие, nbay,
   {{0x60c1afe6,0x39494713,0xc5f40020,0x9c7cc089}},	//   _tolm, npas_, _keɓe_, cičk,
   {{0x645aefe7,0x2ed254f7,0x656d40c9,0x69c9c1c8}},	//   gati, _सत्त, irah, ryee,
   {{0x7afb406c,0x2002c06a,0xf0924093,0x69cb8786}},	//   čutj, şkin_, חני_, lyge,
   {{0x20238283,0xd5b1cc59,0x656d6fe8,0x3f81402c}},	//   ħriġ_, _وفا_, krah, ithu_,
   {{0x64572fe9,0x8234c1f7,0xe0cec6dc,0x764d4149}},	//   _bexi, _ارما, _дв_, dbay,
   {{0x26c26b98,0xa069dc21,0x7ae6421b,0x656d4d4d}},	//   _soko_, _рака_, _smkt, drah,
   {{0x6d49eb63,0x7aeb8105,0x64572fea,0xd763cde9}},	//   lpea, kigt, _dexi, _انبی,
   {{0xd7fac093,0x765bc105,0x443300f6,0xdce2c1d6}},	//   _בהצל, nauy, _egx_, _ipoġ,
   {{0x6284402c,0xee374bf8,0x23274366,0x6b814041}},	// [3300] rfio, рну_, роти_, _älgj,
   {{0x62899b90,0x2ed2d05d,0xe3e700fb,0x3865afeb}},	//   _abeo, _तत्त, اکین_, _ndlr_,
   {{0xad9b403c,0xb4db46ed,0x799bafec,0x656d6fed}},	//   _axúd, _itàl, _asuw, arah,
   {{0xdc3cc06c,0x6441afee,0xfaa65941,0xe0df40b6}},	//   všči, _afli, _тамо, _bwòs_,
   {{0x660fc0fa,0xe2975129,0xa5da8032,0x2d821498}},	//   ückl, _тая_, خبار_, ntke_,
   {{0x316dc5f4,0x5334823f,0x32d1c031,0x67228017}},	//   drez_, бект, _báyo_, smoj,
   {{0x6d49cb87,0x7e7b8206,0x273c0031,0x2f01c1af}},	//   epea, _fcup, _jín_, lógy_,
   {{0x7af6404c,0xdb1c5539,0x248987ca,0x63a8806f}},	//   nnyt, byrå, đama_, _vrdn,
   {{0x644181f4,0x60c3c905,0xbcfb01cb,0xe0df40b6}},	//   _ffli, _bonm, nséc, _gwòs_,
   {{0xdbdc8066,0x25a6afef,0x2bc90048,0x63a8806c}},	//   lším, mvol_, रहमा, _trdn,
   {{0x6aa08813,0xa3d65890,0x03a3acd6,0x7d0700fd}},	//   _kamf, िनि_, _мифо, vojs,
   {{0x7afb404f,0x91b7c01c,0x26c4aff0,0xd05c0080}},	//   čutk, _چطور_, _jomo_, mirə,
   {{0x6aa08033,0xf1020444,0xc6f80fe8,0x201a0545}},	//   _mamf, लकूद_, рнях_, _azpi_,
   {{0x629f2ff1,0x66d14621,0x5507023d,0xf99f4053}},	//   _waqo, _påko, рчма, _kyèv_,
   {{0x629f0033,0x9c7cc242,0x5ba41c27,0x7982ac64}},	//   _taqo, jiči, ортз, htow,
   {{0x9c7cc166,0x273c2ff2,0x764d4340,0x3946c036}},	//   diči, _dín_, ubay, _ktos_,
   {{0x656d4149,0x040bc02a,0x6f0d0230,0x94870119}},	// [3310] urah, হেদী_, _ikac, _кынд,
   {{0xd05c003a,0x2e3d4031,0x97a740b4,0xe8731006}},	//   kirə, _báfó_, ирел, _بندگ,
   {{0x7aebaff3,0x66d5e889,0x32074036,0xd5a6c01c}},	//   tigt, _láka, łny_, _کف_,
   {{0x3f8141f4,0xd05c003a,0x25a6006c,0x68e881f4}},	//   rthu_, dirə, _šoli_, _amdd,
   {{0x26c48150,0x3946c022,0x644180fa,0xe5a598f9}},	//   _domo_, _ntos_, _pfli, сили,
   {{0x270fce18,0x5887823d,0xe9d88007,0x66f20017}},	//   ात्र_, рыда, шкі_, rāki,
   {{0x26c481c0,0x69cb854e,0x60c50573,0x00000000}},	//   _fomo_, syge, _mohm, --,
   {{0x765d005c,0x316dc669,0x04e78079,0xc3340093}},	//   jasy, trez_, খকের_, חוק_,
   {{0x765d2ff4,0x3946c21b,0x213940fd,0x81b5402a}},	//   dasy, _ctos_, _jush_, জনক_,
   {{0x71d84093,0x3ea019e0,0x8387804c,0x6d49d0f5}},	//   יוחד_, _sait_, _выде, rpea,
   {{0x3946eff5,0xedd008c4,0xd6dbc31f,0x6560c6d3}},	//   _etos_, हन्छ, _итд_, asmh,
   {{0x316dc062,0xa3e81f38,0x799d4085,0xb4db4321}},	//   prez_, _मेष_, _ossw, _stàl,
   {{0x273c11fc,0xdca5dc31,0x2bba0ebe,0xfe70c1aa}},	//   _sín_, _гали, _उपहा, _زدن_,
   {{0xdddd4036,0x3ea000c3,0x7b33c0b4,0xdb08d03c}},	//   _odsł, _wait_, _băut, _ardè,
   {{0x7ae9aff6,0xdc12c03a,0x690d8018,0xe9df0070}},	//   _omet, _işğa, lúes, azú_,
   {{0x3d09808f,0x273c2ff7,0x79828036,0x1ee80646}},	//   ाकडे_, _vín_, ytow, _خوبی_,
   {{0x661b825d,0x645c2ff8,0x2bba0945,0x644e00c4}},	// [3320] _nzuk, pari, _उपवा, pbbi,
   {{0x273c0015,0x6441eff9,0x2eeddd2c,0x7659cb5e}},	//   _tín_, ncli, hief_, _lewy,
   {{0x661b81a8,0x799d40bc,0x26c4affa,0x31604526}},	//   _azuk, _essw, _pomo_, ssiz_,
   {{0x291e96a6,0x63bcc4c9,0x68ee06e2,0x79828127}},	//   _shta_, ärni, libd, ttow,
   {{0x19b940b4,0xdbdc856e,0x332000f1,0x2eedc1b0}},	//   _курь_, rším, _mhix_, dief_,
   {{0x290a15ca,0x6cd64183,0x398086ed,0xd05c003a}},	//   noba_, _اقسا, ròs_, tirə,
   {{0x7659cb45,0x60c1010d,0x78a18397,0xfaa69e9b}},	//   _bewy, ölmi, _dalv, _лаво,
   {{0x3ea24383,0xe81e8036,0x7afb8041,0xd6d7cce8}},	//   _jakt_, येगा_, _gjut, йты_,
   {{0x79846ffb,0xb5fb402e,0x7bce0066,0x3ea24377}},	//   ntiw, _adáj, hybu, _makt_,
   {{0x7afb806c,0xe1ff4019,0x7642834d,0xe73a80b4}},	//   _zjut, _odón_, lcoy, _беж_,
   {{0xac18cfe8,0x290a0b6b,0x20d40051,0x68ee00f8}},	//   рону_, doba_, _päin_, dibd,
   {{0xdb08c018,0x690d8004,0x539b80c3,0xb5fd804f}},	//   _ordé, búes, _תיאו, _odšl,
   {{0x3946c5bb,0x62965a27,0x6aa441f4,0x2d99015d}},	//   _utos_, deyo, ddif, uwse_,
   {{0x6e360107,0x673aaffc,0x1bd4c7ad,0x645aaffd}},	//   _egyb, _kutj, _моля, _jeti,
   {{0x67d413b9,0xccf8c047,0xb9010c5c,0xfd5d40eb}},	//   пору, mně_, _दत_, bazị,
   {{0x6d5601f4,0x2ba98045,0x2f44c044,0xa3ac409d}},	//   _fwya, किता, _ịgwa_, कटन_,
   {{0x290a2ffe,0xdcdcc185,0xe1670ba8,0xfaf8001c}},	// [3330] boba_, यसपछ, _ادبي, _دروغ_,
   {{0xadebc834,0x2738800c,0xccf8c047,0xbcfb401e}},	//   _जइसन_, _tĩnh_, nně_, _evén,
   {{0xdb08c107,0x6235401d,0x7799564d,0x2d84c0b2}},	//   _erdé, _мену, ркер_, htme_,
   {{0x6441c070,0xe0df43e2,0x1b17402a,0xdce9c16e}},	//   zcli, _ewòp_, _দূরে_, vreč,
   {{0x3f9eafff,0x5d794052,0x628d0359,0xa69c0d89}},	//   _astu_, _דאָק, _mbao, טשאפ,
   {{0x3ea27000,0x9fc996ea,0xe8f88289,0x17c996ea}},	//   _zakt_, игла_, блі_, игли_,
   {{0x9405c080,0x3ebfc025,0x6d4d66d5,0x69cf00a0}},	//   belə_, tjut_, lpaa, hyce,
   {{0x2ca34639,0x63b44066,0x78a180bf,0x690d803c}},	//   _hajd_, šený, _walv, túes,
   {{0xdce9d2b8,0x39490022,0x3f9e827c,0x6d4d431d}},	//   sreč, _ntas_, _estu_, npaa,
   {{0xdce9f001,0x98f784fc,0xab65c7e1,0x2d9f8033}},	//   preč, _اثرا, овол, _isue_,
   {{0xb4db4031,0x6441f002,0xeaba2471,0x6d4480b4}},	//   _atàk, rcli, айн_, ţiat,
   {{0x6b8541f4,0x290a000d,0xc9aa001d,0x25a94a84}},	//   ithg, woba_, авме_, kval_,
   {{0x6458410d,0xdd94c0d7,0x628d005e,0x7afd0019}},	//   ðvik, _нацы, _dbao, érta,
   {{0x92d5802a,0x64438ac0,0x2731c247,0x3ea27003}},	//   িচয়_, ncni, _kšno_, _sakt_,
   {{0x2738800c,0x07a312cd,0x68ee06e2,0x645e7004}},	//   _vũng_, марн, ribd, vapi,
   {{0x25adb005,0x7e69825d,0x6fc6c185,0x7bce0036}},	//   _orel_, _ndep, ाहरू, rybu,
   {{0x27060b6d,0x394dc07a,0x753b8112,0x2ca341d6}},	// [3340] रवीर_, npes_, _nuuz, _bajd_,
   {{0x79846eb1,0x66f20017,0xe8e0c0d1,0x186a4b8e}},	//   rtiw, rāku, _thụy_, ражи_,
   {{0x645ab006,0x6d49b007,0xf99f6494,0x73064119}},	//   _reti, _atea, _esè_, _мпоз,
   {{0x41aaa37b,0xccf8c185,0xb7c04031,0x753b840d}},	//   ивен_, zně_, _aṣá, _buuz,
   {{0xdd0e8e05,0x7e6986db,0x26d9013b,0x76447008}},	//   gışl, _ddep, ëroi_, mciy,
   {{0x765dc10d,0xdb6a8a23,0x8f348f37,0xafe640d9}},	//   ðsyn, арил_, пекц, _догл,
   {{0x645c48c7,0x6d400089,0x66f208c7,0xb4db0580}},	//   _ieri, ímaj, nāks, mpàt,
   {{0xeeb8c652,0x8bfc002a,0x32d8c88b,0x39843009}},	//   слиш_, _ইরান_, _béya_, kös_,
   {{0x6564700a,0xdd90c228,0x66fc80e5,0x27ea4026}},	//   nsih, رود_, lčko, žinė_,
   {{0xd90dc1aa,0x249800d9,0x3982c086,0x3ea688c7}},	//   هین_, jerm_, rðs_, ldot_,
   {{0x66fc804f,0x6aa4005e,0x2d9200ce,0x25a95bee}},	//   nčko, _baif, _apye_, zval_,
   {{0x645c700b,0x39490019,0xadebc549,0x9c7cc04f}},	//   _leri, _ptas_, _जेवन_, viču,
   {{0xccf8c185,0x6aa40085,0x7aef300c,0x645c499e}},	//   pně_, _daif, rict, _oeri,
   {{0x8c3c850c,0x44444147,0x98aec0b6,0x764640b1}},	//   _yağa, jc_, _kifč_, _afky,
   {{0x7644409c,0xdefb0523,0x673c44ef,0xadc4402e}},	//   fciy, _вып_, _nurj, _ifẹs,
   {{0x4444700d,0xdd0e8189,0xdce280ab,0x98854047}},	//   ec_, yışl, broć, _vůči_,
   {{0x3949c13b,0xb33c81d6,0x3f9e0086,0xdce64138}},	// [3350] _çast_, _irħu, ætur_, _askı,
   {{0x6d4d604e,0x63ae405e,0x76444149,0x7aed0089}},	//   rpaa, _brbn, aciy, _hmat,
   {{0x66ca4089,0x27e60020,0x3ce2c09d,0x764444c8}},	//   _výkr, _ƙone_, _ओतने_, bciy,
   {{0x673c4472,0x394ddd26,0x26c901ff,0x7e60c007}},	//   _durj, ypes_, _joao_, jamp,
   {{0xdce74189,0x31791a1d,0x201e8545,0xd49b416f}},	//   şlıc, nusz_, _azti_, _крв_,
   {{0xe739b00e,0x6722f00f,0x9d1840c5,0xed564323}},	//   бек_, _ahoj, _моят_, _מבשר_,
   {{0xd378c0ab,0x39840107,0x7b644115,0x7aed3010}},	//   juć_, zös_, _отте, _omat,
   {{0xadc4402e,0x3a394077,0xe9df0018,0x753b80eb}},	//   _afẹs, _jgsp_, nbús_, _tuuz,
   {{0xc8ff402a,0x78a3c7a7,0x7afec018,0x225ff011}},	//   ্গীত_, _panv, épta, rauk_,
   {{0x7aed0ddb,0x6efec03f,0x753d621c,0x6f0d4498}},	//   _amat, rība, _musz, hoac,
   {{0x753d7012,0x75357013,0x9f58c086,0xfaa613d0}},	//   _lusz, _mizz, ærð_, пано,
   {{0xbddb40ce,0x64454b87,0x2a604022,0x2ca5afb0}},	//   _afèm, hchi, xaib_, _hald_,
   {{0x7aed10ce,0x2498230c,0x213fc05c,0xe29705f1}},	//   _dmat, term_, qquh_, чая_,
   {{0x765d421b,0xb5fdc2bc,0x64454c6d,0x398427b5}},	//   _aesy, gaše, jchi, rös_,
   {{0x44384303,0x2467c107,0x60230ff8,0x44447014}},	//   _rgr_, _című_, едра, vc_,
   {{0xa3e6484d,0x27f8c02d,0x64454ad0,0x753d58d3}},	//   _बेग_, úrne_, echi, _busz,
   {{0x7ce07015,0x76447016,0x66034156,0x6299b017}},	// [3360] _jörg, rciy, епта, dewo,
   {{0xb5fd80b3,0x83fcc7ca,0x7ce0410d,0xdced456e}},	//   _kešf, sađe, _mörg, brač,
   {{0x765d44a7,0x7aed00de,0x2baecfb2,0x3f67c013}},	//   _fesy, _ymat, टिया, nđu_,
   {{0x6299969b,0x64456f99,0x7e60c6ed,0x645c47ff}},	//   gewo, achi, xamp, _weri,
   {{0x673c40e2,0x7ae38b32,0xa9280007,0x290ce114}},	//   _wurj, ënta, pažį, yoda_,
   {{0x2b58401f,0x98790158,0x2ca580b4,0x44384070}},	//   _twrc_, ršću_, _cald_, _ugr_,
   {{0x6d59f018,0x629983b3,0x2721c166,0xa09b0323}},	//   _awwa, bewo, zóne_, מיסט,
   {{0xe3af8e40,0x46a38ab1,0xd378c123,0xfaa3b019}},	//   ارو_, _пасв, vuć_, _пасо,
   {{0xe166c032,0x6f038018,0x54368e40,0xb4db468a}},	//   أدبي, énce, _فرار, _stài,
   {{0xaa7b4166,0x07a6940c,0x03a6841a,0xa0c981b4}},	//   _umýv, _назн, _низо, _وذلك_,
   {{0xf1f7c1aa,0x6722f01a,0x7afbc5e5,0x224d01a8}},	//   قعیت_, _thoj, bnut, ñeko_,
   {{0xda208374,0xdce446f0,0xdee3c179,0x66e3db3e}},	//   _बरात_, brić, _похи, _поха,
   {{0xbcfb4047,0x6f0d40b4,0xdb0e813b,0x765d415a}},	//   _svém, voac, _arbë, _resy,
   {{0x3a200570,0x753d5243,0x2012803a,0x63bcc041}},	//   _dzip_, _rusz, əyir_, ärns,
   {{0x75356bf6,0x0f1b41b4,0x22468033,0x9c7cc066}},	//   _rizz, مغرب_, kcok_, sičs,
   {{0x290e8031,0x753d4096,0x80c10045,0xba3dc0a0}},	//   hofa_, _pusz, रॉजे, jdůl,
   {{0x75354e83,0x3a200104,0xa5bb4107,0xaf340231}},	// [3370] _pizz, _gzip_, _szób, _ثروت,
   {{0x7c3a80f8,0x66d3850c,0xda07001c,0xbcfb42f4}},	//   _ngtr, _içki, _ويژه_, _tvém,
   {{0x6ce440d9,0xaa7b0089,0x7afe0c81,0x6f0d589e}},	//   хіте, chýc, čstv, poac,
   {{0x646347ca,0xdb040240,0x38630283,0xdcc8c185}},	//   _štić, _ernæ, lajr_, ाउँछ,
   {{0x6d4d0033,0x290eb01b,0x6ec0cbc0,0x69c6c025}},	//   _jtaa, fofa_, वानु, äkel,
   {{0x7ff4001c,0xb4db40d2,0x6d59c024,0xa8a459ad}},	//   _آسیا, _quàd, _rwwa, _прск,
   {{0xf8b2421d,0x6282c085,0x6e2080c7,0x29010085}},	//   _בשם_, _bcoo, _ezmb, _mjha_,
   {{0xdce2c077,0xdce4413f,0x7afd015d,0xfe6e801c}},	//   _dvoč, trić, jnst, _نگه_,
   {{0x26cb4231,0x2d89701c,0x6f0f00c4,0xe8d9425d}},	//   _moco_, ntae_, docc, atụ_,
   {{0x7ce049d7,0xbddb4053,0x3ea9701d,0x26dfc09c}},	//   _görd, _afèk, hdat_, shuo_,
   {{0x5f06011b,0x443a0007,0x3d168b35,0x7d048359}},	//   дзна, _rgp_, _पीटे_, éise,
   {{0x7afd1044,0x673e0017,0x225f8b32,0xeb908032}},	//   gnst, _rupj, _jeuk_, _حظك_,
   {{0x823602f0,0xad88c3be,0x917a00d1,0xe5a5d40c}},	//   بردا, _فضول_, _bất_, _цили,
   {{0x6aa9f01e,0x2a7fe2cf,0x224900d2,0x7c87c051}},	//   ldef, lgub_, _efak_, _худе,
   {{0x6724301f,0x6d4d01ae,0x6e3b80bc,0x28a6de85}},	//   _thij, _etaa, _ogub, _कोटि,
   {{0x225f9fad,0x6e3bb020,0x26cb418a,0x3f680080}},	//   _neuk_, _ngub, _coco_, rğu_,
   {{0x2d8940f8,0x25adc206,0x213f8398,0x61248580}},	// [3380] gtae_, nvel_, _nuuh_, lòle,
   {{0x2f1c8018,0xb4e8409d,0x25adc5ca,0xf99f40b6}},	//   tígo_, यफे_, ivel_, _vyèp_,
   {{0x26cb7021,0xe9df034d,0x7bcdc020,0x7ce044c9}},	//   _foco_, ncún_, _ƙauy, _rörd,
   {{0x3986401f,0x657bc025,0xaca44171,0x7989c3b3}},	//   pôs_, kuuh, _ifọr, ktew,
   {{0x290e91c1,0xe8948698,0xd943a497,0x777c0004}},	//   tofa_, еаль, вечи, lurx,
   {{0x7ce04138,0x213fb022,0x7e647023,0x657bc303}},	//   _böre, _duuh_, laip, duuh,
   {{0x778a8080,0x7afd3024,0x8f7540d9,0x09c6802a}},	//   _təxm, ynst, _путі, _শেখা,
   {{0x932687ce,0xbd6ac025,0x657bc40d,0x6aa9c125}},	//   _آرسن, орое_, fuuh, gdef,
   {{0x2018413b,0x7989c14b,0xa534d702,0xdc3cc011}},	//   _hyri_, gtew, ннич, nšći,
   {{0xe0df0565,0x7ae2b025,0x628403bb,0x225f80fc}},	//   npòt_, lhot, _acio, _zeuk_,
   {{0xa0a3c23d,0x6f0f023f,0xc47744e0,0xc1c71d60}},	//   тшыл, tocc, ותיו_, रङ्ग,
   {{0x25a07026,0x83fc806f,0x7ae29564,0x39401ea1}},	//   kwil_, _ceđe, nhot, _buis_,
   {{0xb5fb4032,0x6d44423b,0x3940029a,0x660fc0cb}},	//   _meác, jqia, _cuis_, ückt,
   {{0x2ca7d38f,0x7ce04138,0x3e8805ca,0x46af08b8}},	//   _gand_, _yöre, tító_, _जोरह,
   {{0x5ba3c23d,0x644ac0f1,0xe5340051,0x443cc070}},	//   _арыз, _iffi, терь, _igv_,
   {{0x2249006a,0x6d4d01ae,0x5fcbc330,0x2bcbc0e9}},	//   _ufak_, _ttaa, ाहरल, ाहरा,
   {{0x3e880107,0x6d4d1996,0xdbdec018,0x628d402c}},	// [3390] sító_, _utaa, míña, rfao,
   {{0xa3c092c7,0x60c5423b,0xd1388036,0x213840ce}},	//   ुहा_, ujhm, _nią_, _cirh_,
   {{0x25a48127,0x69120329,0x3ea90127,0xd3414107}},	//   _asml_, pæer, _kaat_, اہری,
   {{0xdbdc4397,0x501bc0c3,0x394d80d2,0xdb078397}},	//   ráða, חובו, _ptes_, _brjá,
   {{0xbdf885a7,0x7e6087d0,0x6e22c84f,0x2721c086}},	//   ورها_, _demp, _nzob, jóna_,
   {{0x6458410d,0x443cf027,0x672d7028,0xf7718032}},	//   ðvit, _ngv_, lmaj, هاب_,
   {{0x7ae2b029,0x6e22f02a,0x22408077,0xb5fdc011}},	//   bhot, _azob, žika_, daša,
   {{0x7b161b4d,0xbcfb4185,0x6d5d405c,0x213f8033}},	//   náut, _svéh, _kwsa, _tuuh_,
   {{0x83fc8123,0x629bc02c,0xddc4002d,0xf53f41e5}},	//   _ređe, reuo, _odiš, _gråt_,
   {{0x39402113,0x8c3c80b5,0xa3df0945,0x46dbcb35}},	//   _ruis_, _yağm, थना_, _बतकह,
   {{0x3ea900bf,0x3989b02b,0x2b4ec060,0x2af3809d}},	//   _baat_, lús_, _ctfc_, _आगाँ_,
   {{0x672d4077,0x78a88011,0x2ca7f02c,0x25b204c9}},	//   jmaj, _zadv, _wand_, _pryl_,
   {{0x83fcc158,0xd0d5cdd2,0x443cf02d,0xd838eb34}},	//   rađa, _подъ, _fgv_, veče_,
   {{0xbebb40fd,0x64a2e17b,0x6f02c011,0x777c003c}},	//   _dhëm, _баша, _zjoc, turx,
   {{0x6569f02e,0x7a368138,0x7a2a45ca,0x6f02c303}},	//   lseh, _kütü, köté, _yjoc,
   {{0x2903431c,0x63a24036,0x672d4077,0xfaa34039}},	//   _ajja_, łonk, gmaj, ласо,
   {{0x09e3439d,0xa9264b62,0xd335702f,0x6f1bc070}},	// [33a0] готн, едал, тэры, iluc,
   {{0x6e2400f7,0xd838d0b4,0x31570052,0x26df8247}},	//   _izib, seče_, _ריין_, _aluo_,
   {{0x78a88007,0x6aa9817b,0x25a04372,0xeabf41c0}},	//   _radv, _baef, swil_, _ihùn_,
   {{0x66e398d5,0x7e660340,0x29037030,0x0166a044}},	//   лоха, nakp, _ejja_, екдо,
   {{0xfd48c031,0x78a8b031,0xd1388062,0x00000000}},	//   _damọ, _padv, _pią_, --,
   {{0x3d1840b2,0x34948097,0x7f418b39,0xf1bf435d}},	//   _बीचे_, такр, _bulq, _ngáy_,
   {{0x6e22c05f,0x6adbc064,0xdb08c032,0xd90d408c}},	//   _szob, बसूर, _ardá, _بیل_,
   {{0xa3c10048,0x31c6d8ed,0x7d03e200,0x7c3a01af}},	//   ंमत_, есов, _ajns, ľtrh,
   {{0x1a9b8052,0x2a6680f8,0x69d6409c,0x343a961e}},	//   _צימע, maob_, nyye, _فساد_,
   {{0x60ce501c,0x657d3032,0x4973c007,0x6f040398}},	//   _jobm, vush, ыльс, _ajic,
   {{0x68f53033,0x2018c086,0xdbdec018,0xbebb413b}},	//   vizd, æri_, tíña, _shëm,
   {{0x1db24048,0x7ae4404f,0x20d08061,0x92580051}},	//   ीमात, jhit, _gàir_, нают_,
   {{0x4dd3c38b,0x7f41805c,0xba3b0016,0x443ccfda}},	//   _متوس, _zulq, veïd, _tgv_,
   {{0x80c44045,0x62867034,0x2ee00a1f,0x7ae440b2}},	//   राफे, _acko, _elif_, ehit,
   {{0xbcfb0359,0x6fe6c01e,0x753ab035,0xeabf45ef}},	//   nséi, _décé, _mitz, _dhùn_,
   {{0x7cd801df,0x7ae47036,0x3f8bc0b4,0x2ee00141}},	//   _ağrı, ghit, ăcut_, _glif_,
   {{0xb2740051,0x95cb4afa,0x781d9561,0x29110398}},	// [33b0] _слыш, чува_, _फर्क_, poza_,
   {{0xd56401bc,0x39427037,0x443e8041,0xddc400ab}},	//   _стъп, _duks_, _ngt_, _udiš,
   {{0x7ce4c321,0x9f4b0025,0xe0df00d2,0x00000000}},	//   _iòrd, ömät_, spòs_, --,
   {{0x518746fe,0x6282a2c3,0xf653913d,0xe8d1025c}},	//   _пуга, ggoo, ائض_, _सकुच,
   {{0xe5a5b038,0x00000000,0x00000000,0x00000000}},	//   тили, --, --, --,
   {{0x798d7039,0x6f1d00cb,0xdb1c4086,0x7e660570}},	//   mtaw, hlsc, lyrð, zakp,
   {{0xdb054041,0xc4d240c3,0x7f418149,0x798d6e44}},	//   _erhå, _דגם_, _qulq, ltaw,
   {{0x656d014d,0x6abb8398,0x60ce4147,0x798d4398}},	//   _ovah, _unuf, _zobm, otaw,
   {{0x67299f09,0x26dc8017,0xf40000b4,0x2f1584c9}},	//   _ihej, īvot_, ăţii_, sågs_,
   {{0x83fcc077,0x66d5c086,0xb5fdc199,0x6f1d1f84}},	//   rađn, _nákv, bašn, elsc,
   {{0x2295c032,0x25a6c0b6,0x673b82c0,0x5e95c032}},	//   _للاس, _esol_, _kiuj, _للاط,
   {{0x9d21c079,0x0521c079,0x7c3a4397,0x657f400b}},	//   নদেন_, নদের_, _útre, kuqh,
   {{0x798d4022,0x753a90ea,0x673b812c,0x69cb4fd0}},	//   jtaw, _yitz, _miuj, ägel,
   {{0xfd66400c,0xb21b0963,0x7ce4c5ef,0x5fa58047}},	//   _thuầ, tfær, _còrd, _खनाल,
   {{0x291351f7,0x7e6600f8,0x764d017b,0x6b6300d9}},	//   doxa_, pakp, _ffay, икра,
   {{0xfd62c044,0xb21b093b,0x332900f1,0x798d4020}},	//   _netị, rfær, _ghax_, ftaw,
   {{0x661bae3d,0xbedc4031,0x798d429e,0x83fc86f0}},	// [33c0] _nyuk, _aṣàw, gtaw, _međa,
   {{0xb21b010d,0x6f04c077,0x67298024,0x6aabcc83}},	//   pfær, čici, _ahej, _lagf,
   {{0x753a901c,0x661b86df,0xaa1ec185,0x3eab4093}},	//   _ritz, _ayuk, _पर्छ_, _fact_,
   {{0xdb0400d2,0x63b540e5,0x661b8449,0x2bc2c0e6}},	//   _arnú, _drzn, _byuk, षमता,
   {{0x7afa410d,0x661b8f2d,0x629600bb,0x7f43c073}},	//   éttu, _cyuk, _mbyo, _lunq,
   {{0x3f9a0033,0xdce2c166,0x6d42c051,0xbcfb4031}},	//   _kppu_, _spoľ, _ruoa, _ewéb,
   {{0xa3c3cd04,0x673b4574,0x2d8040cc,0x5694cb5d}},	//   yšší_, ňuje, luie_, гайт,
   {{0xb5fb4032,0x20d4009d,0x2b55801c,0x66dcc107}},	//   _meán, _käis_, ایند_, _véko,
   {{0x6f02b03a,0x7ae340b4,0xada385d7,0x2d80538f}},	//   mnoc, _înte, _катл, nuie_,
   {{0x80d10036,0x2ee68572,0x6296040d,0x6f02b03b}},	//   _सकें, lhof_, _abyo, lnoc,
   {{0x6aabd8eb,0x656d303c,0x61e9c0b9,0x287b43bd}},	//   _fagf, _svah, azel, ונימ,
   {{0x6f0280fa,0x2ee691fd,0xeabf45ef,0x9c7c80b6}},	//   nnoc, nhof_, _chùl_, _flčc,
   {{0x2a648033,0x6f0282e3,0x61e9c036,0x91e3c8d3}},	//   _memb_, inoc, czel, _коце,
   {{0x66d5c02e,0x2d80703d,0x291340f7,0x224000b9}},	//   _dáku, duie_, xoxa_, _egik_,
   {{0xd7f80051,0xdb0e843e,0x9c7cc56e,0xdd31c561}},	//   вут_, _arbí, lhčo, ləşi,
   {{0xf837c0c3,0x69d6c06a,0x2cac815a,0x248d0047}},	//   _בנות_, _üyes, _ladd_, řem_,
   {{0xc1054032,0x09d6402a,0xa4a6c02e,0x798d4020}},	// [33d0] هوري, _সেবা, _gbòò, utaw,
   {{0x672980fd,0x7f43c34d,0xef1f00b5,0x62844157}},	//   _shej, _yunq, llü_, agio,
   {{0x7f43c03c,0x3eadf03e,0x316d8077,0x386340b0}},	//   _xunq, ydet_, _svez_, _vejr_,
   {{0x7980eb43,0x612b409d,0xdce9c06f,0x2918405e}},	//   kumw, külg, preć, _ekra_,
   {{0x26cff03f,0xeab086b0,0x3eadc6bc,0x798d0085}},	//   _rogo_, تعل_, vdet_, _jqaw,
   {{0x61e9c04f,0x656d7040,0x6f028157,0x4ddc00c3}},	//   vzel, msah, anoc, וחדו,
   {{0xef1f0676,0x70dcc185,0xa6db4397,0x7c8492d9}},	//   klü_, यसैल, _viðf, руче,
   {{0x7ae2d227,0x39448060,0x2d8dc0c3,0x3eadc025}},	//   _clot, _fums_, ttee_, udet_,
   {{0xeb1f8048,0x316d8451,0x661d7041,0x7e643042}},	//   बतीत_, _uvez_, _jysk, _reip,
   {{0x656d607c,0x2d8ddb62,0x70d21561,0x398bc7fb}},	//   isah, rtee_, _हवेल, røs_,
   {{0x656d60a4,0x61e9f043,0x7b188018,0x3ebfaaf7}},	//   hsah, szel, cíus, _knut_,
   {{0xe1ff030d,0x673d4721,0x2ede0045,0x26dd9228}},	//   raón_, _nisj, मसेत, nkwo_,
   {{0xeabf7044,0x3ea07045,0x2cac809c,0xcb128323}},	//   _chùm_, veit_, _yadd_, מלט_,
   {{0x3b1fc080,0x6143146b,0x612b4776,0x9d431702}},	//   lluq_, сера, nüld, серд,
   {{0xba2081e7,0x7ce0410d,0xafe313a4,0x6aad01c8}},	//   _बर्फ_, _börn, борл, _faaf,
   {{0x6da64ce0,0xadf04048,0x6aad3046,0x224df047}},	//   либа, _घेउन_, _gaaf, ncek_,
   {{0x2d8d8022,0x6b9b0119,0x644190a2,0x656d7048}},	// [33e0] _nqee_, ăuga, _ogli, gsah,
   {{0x3ebf844e,0xbd5b00c3,0xb5fdc570,0x69d9a546}},	//   _anut_, _רכיש, vašl, dywe,
   {{0x291a00eb,0x78ae810b,0xfa6a4d06,0x69cb40b0}},	//   _ikpa_, _óbvi, _панк_, øger,
   {{0x657bf049,0x298a8477,0x20d4009d,0x7980c00d}},	//   kruh, еско_, _täis_, yumw,
   {{0x80c4463c,0x645ac1c8,0xf53f171a,0x6b81f04a}},	//   रादे, ybti, lvår_, hulg,
   {{0x2ee68e24,0x332041d6,0x7bd88007,0x2918704b}},	//   shof_, llix_, tyvu, _ukra_,
   {{0x291a0efc,0x661d616a,0x2d82304c,0x6d46704d}},	//   _mkpa_, _zysk, huke_, _huka,
   {{0xa6db4397,0x7ae40396,0x34d10185,0x39449e7a}},	//   _viðg, _nlit, _सक्द, _tums_,
   {{0x386a304e,0x7ae2dd50,0x638a801f,0xf1a9801c}},	//   kabr_, _vlot, _bênç, _لاله_,
   {{0x44f4c11b,0x291a0044,0x90d5800c,0x7980c4db}},	//   рпос, _nkpa_, _hìn, rumw,
   {{0x6f044043,0x656d405b,0x9259029d,0x4438c4d3}},	//   knic, zsah, кант_, är_,
   {{0x753d8107,0x78ae48c7,0x62860621,0x6aa2a0dc}},	//   _észr, _labv, ggko, neof,
   {{0x26d2088b,0x2d821e6b,0xd7c7c01c,0x7ae40359}},	//   _doyo_, guke_, نویه_, _dlit,
   {{0x2a6941c8,0x6b81e416,0x7ae42205,0x3ead0047}},	//   waab_, bulg, _elit, žet_,
   {{0x6d464ae6,0x765240eb,0x66d84086,0xc7c400b4}},	//   _auka, _ọkọw, _líku, бсти,
   {{0x26d215ca,0xf548c0d1,0xdce0c017,0x213e8303}},	//   _goyo_, _gục_, kumī, _lith_,
   {{0x656d704f,0x705500fb,0x612b40fa,0xbddb4031}},	// [33f0] usah, _پنجا, hüle, _afèr,
   {{0xeb0d8191,0xe816008f,0x6f0440c4,0x3e7b4171}},	//   िक्त_, _दुवा_, anic, _bàtà_,
   {{0x7ce04d88,0x7f5904ce,0x799b88a5,0x7ae40051}},	//   _törn, _шанс_, _spuw, _ylit,
   {{0x3f83001c,0xbd05c031,0x213e8755,0x656f00c4}},	//   muju_, _amẹ́, _aith_, osch,
   {{0x39494283,0xb5fdc0b3,0x9e64811b,0x6d4656b4}},	//   qqas_, tašm, свід, _guka,
   {{0x69d9950e,0xe9b880fb,0x612000cb,0xdddbc41b}},	//   rywe, انوں_, völk, jguš,
   {{0x672d03bf,0x612b42d6,0x61ed7050,0x213e8321}},	//   _ohaj, rüld, lzal, _dith_,
   {{0x201e813b,0x2b4d40a0,0x657bc8f1,0x6562c84f}},	//   _dyti_, _čech_, truh, _bwoh,
   {{0x656f015d,0xa3e5009d,0x7e6b802f,0x201e8031}},	//   jsch, बैत_, magp, _eyti_,
   {{0x7ae43051,0x7e6b9348,0xd12ec51b,0xee36c523}},	//   _slit, lagp, ومي_, шны_,
   {{0x657bf052,0x6d598010,0x656f3053,0xa6db4086}},	//   sruh, lpwa, esch, _miðb,
   {{0x656f143b,0x6126c10d,0xf1b98199,0x657bdc4b}},	//   fsch, rðla, _krš_, pruh,
   {{0x61ed40b3,0x656f1c76,0x95830051,0xa158c31e}},	//   jzal, gsch, оляе, _бачу_,
   {{0x271e4e18,0x7afbc007,0x7ff5c1aa,0x69c9c022}},	//   पत्र_, liut, _پستا, mxee,
   {{0x25e8456c,0x7e667054,0xb5fdc06c,0x3ea23055}},	//   चैनी_, _pekp, kašk, pekt_,
   {{0x7ae40f04,0x66d5c066,0x3eafc065,0x26cdc2bc}},	//   _ulit, _zákr, _jagt_, njeo_,

   {{0x5d6a5548,0x5fab4036,0x656f00b6,0x3eafc0b0}},	// [3400] тизм_, _टैबल, csch, _magt_,
   {{0xccc34051,0x1fb65512,0x2e4ec1c0,0x6f1b80c2}},	//   обуй, исер, _fọwọ_, _akuc,
   {{0x6f047056,0x7d048744,0x287b021d,0x6c7b0916}},	//   pnic, éism, _בנימ, _בריד,
   {{0xe9da99a2,0x41b30646,0x96964267,0x2ee97057}},	//   кке_, _امیر, _трош, chaf_,
   {{0x6aa2a0dc,0x61ed4036,0xc7b88123,0x6443c036}},	//   reof, czal, _srđ_, _ogni,
   {{0x249a005c,0x6299c17b,0x6aa47058,0x612b4138}},	//   _jbpm_, _abwo, leif, tüle,
   {{0x2fc754a6,0x2727809d,0x2d9dc0ce,0xbddb001e}},	//   ängt_, sõna_, _apwe_, ncèr,
   {{0xbcfb3059,0x61fb42bc,0x76441de7,0x442a402d}},	//   nsér, _žuli, _ngiy, _izb_,
   {{0x6d5607b8,0x91e39089,0x645ec0b2,0x0c768231}},	//   _ntya, _доте, _õpik, _نداد,
   {{0x6722b05a,0x6b9e0761,0x83fcc0e0,0x612b406a}},	//   lloj, _oppg, lađi, püle,
   {{0x3867c0f8,0x7ce04041,0xe1ff4019,0x92e4c079}},	//   _denr_, _rörl, _neón_, _নদী_,
   {{0x3946c007,0x69c9c022,0xc4d349fd,0x96bac107}},	//   _tuos_, bxee, _दक्ख, _جائز_,
   {{0xf8c94314,0x656f00fa,0x7ceb0175,0xb5fd8066}},	//   रामय, usch, _jürg, _nešl,
   {{0x2d84f05b,0x3d104036,0x765d0010,0xdca3dedf}},	//   mume_, ़कों_, sbsy, _мачи,
   {{0x644fc064,0x8f351407,0x3cee854a,0x6d56017b}},	//   ścic, _лекц, _अतने_, _etya,
   {{0x7ce20018,0xb5fd8cfe,0x656f119e,0x660d00fc}},	//   _fôro, _bešl, psch, _txak,
   {{0xb5fdd2b8,0xb99501b4,0x7ce04107,0x2ca3006f}},	// [3410] vašk, _الخب, _törl, pejd_,
   {{0x386cc0b3,0xdced011a,0xa2bf01f9,0x26c249a3}},	//   nadr_, _kvač, षाक्, _enko_,
   {{0xa6db410d,0x9259804c,0xf773479d,0x2ee6d633}},	//   _viðb, гает_, تاذ_, _olof_,
   {{0xdb01c02d,0x6722b05c,0xb0628025,0xdc560fdd}},	//   _oslá, gloj, äänk, _پریک,
   {{0x442a4918,0x3949305d,0x59a70045,0x02c5c047}},	//   _ezb_, _juas_, गबिर, वासभ,
   {{0x69c9c022,0x2d84f05e,0xd0099854,0x7e6d41b0}},	//   vxee, dume_, леле_, laap,
   {{0xb5fdc0ab,0x78a39f8e,0xc446408c,0x6d4d41c8}},	//   maši, renv, _ایمن_, lqaa,
   {{0xfc4a4032,0xa3bacb35,0x68fc305f,0x291cf060}},	//   _tríú_, घिन_, zird, _akva_,
   {{0x7e698070,0x6d4d41c8,0x7ceb0189,0x78a3b061}},	//   _ieep, nqaa, _kürd, penv,
   {{0x2b47f062,0xba3b3063,0x6444c06a,0x25ad802c}},	//   _punc_, teïn, _şiir, _isel_,
   {{0x7a6a01fa,0x26cdc0b3,0x68fc009e,0x7f848032}},	//   линг_, pjeo_, vird, _ولكن,
   {{0x7ce20166,0x4735c7d9,0xe5a600c5,0x6da62549}},	//   _pôro, _унес, бими, бима,
   {{0x64450077,0x3990c016,0x7ce04041,0x2907915a}},	//   _bghi, càs_, _sörm, onna_,
   {{0xaa7b0038,0x2b47c09e,0x7d76c78a,0x7afd2529}},	//   tkýc, _tunc_, _امور_, aist,
   {{0xa355c71d,0x1fb511e1,0x68fc3064,0x6755c865}},	//   _اختص, остр, rird, _اختر,
   {{0x628d0032,0x6b9caa48,0x68fc3065,0x7e6d40f8}},	//   _gcao, _ärge, sird, gaap,
   {{0xf1aa41aa,0x6aa47066,0xc332c3bd,0xceb2c052}},	// [3420] دازه_, reif, לול_, הין_,
   {{0xf48441aa,0x5e5700fe,0x68fc017a,0x7ce04051}},	//   تاری, _پلیس_, qird, _törm,
   {{0xdb154066,0x7d1c4011,0x3f85f067,0xb9004abd}},	//   žbác, _vkrs, nulu_, _तव_,
   {{0x39490046,0xa294811b,0x2618c048,0xd54a41e3}},	//   _yuas_, іалі, _पडली_, _مجسم_,
   {{0x7ceb005f,0x3949004d,0xceb4403a,0x60c3c032}},	//   _fürd, _xuas_, mdə_, _onnm,
   {{0x83fcc7ca,0x3d11c064,0x7d1c4054,0x9fa28086}},	//   sađi, ठकों_, _ukrs, _bíða_,
   {{0x7afd07b2,0x6ecc48c5,0x24e7443e,0x67244025}},	//   yist, हापु, _умри_, olij,
   {{0x67244ef1,0x973cc539,0xa3c98474,0x63bab068}},	//   nlij, _opće, _ऊपर_, _vrtn,
   {{0x3ea4eb05,0x2d804070,0x7c96809b,0x2cb1409c}},	//   remt_, nrie_, _грец, _yazd_,
   {{0xa6db410d,0x628d01b4,0x2d807069,0x92c50079}},	//   _miða, _scao, irie_, _এতে_,
   {{0x25a0071c,0x533505ed,0x3cf04036,0xd6cff06a}},	//   _apil_, жент, _इतने_, _ет_,
   {{0x612d810d,0x291a44c9,0xf1bf4107,0x1dc846fc}},	//   rúle, hopa_, _szám_, रमात,
   {{0x644fc064,0x2ca5c15d,0x6d4180f7,0x291a46ce}},	//   ścia, beld_, _yila, kopa_,
   {{0x3f85f06b,0xa2c0c048,0x6e22cd08,0x38c8c2cf}},	//   bulu_, वाक्, _iyob, _خاصی_,
   {{0xb5fdc6a4,0x25a9706c,0x67246644,0x2a69009d}},	//   vaši, wwal_, flij, _teab_,
   {{0x25a9706d,0x25ecc027,0x6724706e,0x7d1ac0f7}},	//   twal_, आईपी_, glij, lots,
   {{0xb8ef002a,0x7e6d706f,0x84474032,0xa3ce144e}},	// [3430] _শত_, raap, مخال, _शपथ_,
   {{0x6e22e472,0x7d1aef81,0xb33cc085,0x6d5d3070}},	//   _myob, nots, _isħu, mpsa,
   {{0xb5fb4032,0xfb844039,0x2fc7400c,0x25a95b85}},	//   _meái, зычн, ãng_, swal_,
   {{0x7d1ad356,0x7ae28033,0x2712c09d,0x2bb0c1f9}},	//   hots, gkot, डकोर_, _जनना,
   {{0x6f198064,0xb5fdc639,0x7ae800fd,0x28c95337}},	//   rowc, paši, ëjti, रादि,
   {{0x83fcd8ca,0xfe73405f,0x92c5002a,0x317fd14f}},	//   lađu, _بدھ_, _এতো_, vruz_,
   {{0x28da8275,0x6e22cd08,0x2aa08053,0xddc44007}},	//   _बकरि, _ayob, _bčbč_, maiš,
   {{0x83fcc0e0,0x290c8077,0x7883c107,0xb5fd86f9}},	//   nađu, _ejda_, kívü, _ješk,
   {{0xe5c78f34,0x6e2d043a,0x3f85c339,0x442c8011}},	//   _усво, _nzab, wulu_, _ezd_,
   {{0x7ceb006a,0x6f0d0e5d,0x7d1af071,0x98b94007}},	//   _yüre, _ajac, gots, _pusę_,
   {{0xed598a11,0x628f40c5,0xeaaec0fb,0x3255f072}},	//   _drže_, _occo, رٹی_, _двер,
   {{0x8234c1aa,0xb5fd89a2,0x6130531e,0x3f85c06a}},	//   _کرما, _nešk, mäle, rulu_,
   {{0x7afb8d0b,0x6f1bc047,0x672440b3,0x6353c0b4}},	//   _mmut, mouc, vlij, _bănc,
   {{0x39434127,0xdb1acb31,0x6f0d09a5,0xa0673073}},	//   _nijs_, _artè, _ejac, жара_,
   {{0xceb4403a,0xfaff0b45,0x7afb9415,0x3f8798e0}},	//   tdə_, bië_, _omut, nunu_,
   {{0x7c3ecd01,0x7c2bc31f,0x2d807074,0x2e4ec094}},	//   _úpra, đorđ, trie_, _họrọ_,
   {{0x1636c009,0x2e4ec044,0x3f87b075,0x291a4147}},	// [3440] ַנער_, _kọrọ_, hunu_, topa_,
   {{0x2ea6c3b0,0x3f87b076,0xd83e8066,0x2e4ec0eb}},	//   _खस्त, kunu_, íčka_, _jọrọ_,
   {{0x2ca781b0,0x68fe405c,0x389b0009,0xe29a4a0b}},	//   dend_, ripd, _דיינ, _кан_,
   {{0x2d8062f8,0x644740da,0x6d59da94,0xdce445c7}},	//   prie_, _egji, _otwa, ksić,
   {{0xa5bb405f,0x6f09c56e,0xbebb40fd,0x7ce4c061}},	//   _szóv, dnec, _thër, _bòrl,
   {{0x2e4ec25d,0x99bb0052,0xcbc9c185,0xda1dc54a}},	//   _nọrọ_, יזנט, िमाञ, _पड़त_,
   {{0xa6db4397,0x44234070,0xd00749cd,0x7ae443fb}},	//   _miðn, _gyj_, _дере_, okit,
   {{0xdce9c068,0xb7db00c3,0xf1aa8231,0xa6db4397}},	//   dređ, יקצי, _پاره_, _liðn,
   {{0x7ae440fc,0x2ca7b077,0x7e628bd3,0x7d1af078}},	//   ikit, bend_, mbop, tots,
   {{0x7d08c0cb,0x07a68463,0x7982b079,0xd838d10f}},	//   unds, _мазн, mrow, leči_,
   {{0xd6dac1aa,0x7c23c1f4,0xb5fb4070,0x6f1bf07a}},	//   _پوشش_, _cynr, _veái, bouc,
   {{0x70da8632,0x7d1ad4ed,0x39944051,0xfc464047}},	//   _बकुल, sots, käs_, šího_,
   {{0x26c6c057,0x80ad802a,0x6e22dfb5,0xdd8fca2c}},	//   _inoo_, চার্, _uyob, _لون_,
   {{0x7ce050e8,0xbcfb41c0,0x394b4060,0xa91dc0a0}},	//   _föri, _ewéj, _rucs_, trže,
   {{0x628f4070,0xdb1acfda,0x6f0d04c9,0x394b4060}},	//   _pcco, _arté, _tjac, _sucs_,
   {{0x2ca7b07b,0x3f814066,0x6d5d159a,0x290a01c8}},	//   zend_, vrhu_, ppsa, anba_,
   {{0x3d94527f,0xdb1c80fd,0x2367c09c,0xe9df41c0}},	// [3450] митр, _errë, _zwnj_, _egún_,
   {{0xb9a4005f,0x83fcc41b,0xe9df2275,0x79828036}},	//   _کمیٹ, sađu, scús_, drow,
   {{0x6d4d0b0e,0x6d450c05,0xb4e70036,0xa5bb4107}},	//   _huaa, _iiha, पसी_, _azót,
   {{0x28c94384,0x394340a8,0x7ceb00cb,0x6d4d0230}},	//   राहि, _wijs_, _fürc, _kuaa,
   {{0x499344fc,0xa3b90444,0x6d450ecf,0x2ca7b07c}},	//   _زیار, चिव_, _kiha, tend_,
   {{0xe8f88187,0xdcfbc0ab,0xf548c00c,0x7cedc166}},	//   олі_, truč, _cụm_, _kúre,
   {{0x7ae980f1,0x612d8004,0x81ad402a,0x2e4ec112}},	//   _tlet, gúla, _কপি_, _rọrọ_,
   {{0x2d82036b,0x6d4be93a,0x3f87a805,0x53348a9e}},	//   yrke_, _puga, runu_, _жест,
   {{0x3f87838a,0xe81b87a5,0x26d943bc,0xb5fdc2bc}},	//   sunu_, _पुरा_, _moso_, jašt,
   {{0x5c15cde7,0x6d4bf07d,0x6f09f07e,0xb5fdc570}},	//   зьму, _vuga, snec, dašt,
   {{0xdce9ccfe,0x66df00fd,0x25ff8048,0x612d97fa}},	//   uređ, _lëku, _शेती_, cúla,
   {{0x387a0077,0xfeb8c20c,0x03d641f2,0xa3c1017e}},	//   _sdpr_, _وانت_, לותם_, ूमन_,
   {{0x6d4be780,0x2e4ec21f,0x7aebc017,0x213300d1}},	//   _uuga, _tọrọ_, _ilgt, _bhxh_,
   {{0x7cf0054a,0xeab240fb,0xa879c009,0x6aa9f07f}},	//   _märg, کٹر_, _האַר, leef,
   {{0x7e7b85c7,0x20130018,0xb8e40707,0x7e6d0004}},	//   _odup, _cxxi_, _एफ_, _feap,
   {{0x2bb0c185,0x20050016,0x7e6d2c01,0x26d97080}},	//   _जनता, úlia_, _geap, _coso_,
   {{0xe5a36ec6,0x394d903c,0xbebb013b,0x84eb81f9}},	// [3460] нити, _nues_, ymëz, जघाट_,
   {{0x39945368,0xdb1c801e,0x2901471c,0x7649817b}},	//   räs_, _irré, giha_, _agey,
   {{0x69cb5da9,0x7c2580cb,0x70a9c185,0xa5bb4107}},	//   äger, ührl, _कसैल, _szót,
   {{0xd9464b73,0x6d453081,0x395fc07a,0x2fc74041}},	//   _неми, _ziha, kpus_, ånga_,
   {{0xa6db4086,0x3ea002ad,0x2721c018,0x6d4501c6}},	//   _miðl, _mbit_, hóns_, _yiha,
   {{0x3f5180d1,0xddcd4138,0x963398d5,0xbcfb01cb}},	//   _báu_, lbaş, хніц, ppée,
   {{0x03a358f9,0x386c8211,0x8fa36024,0x78a8c7fb}},	//   _пиро, _vedr_, _паре, vedv,
   {{0x74c4485a,0x4ad08371,0x044349b0,0x2721c004}},	//   राकृ, _सचिव, _чесн, dóns_,
   {{0x612db082,0xa534d4e9,0x4425b083,0x7cf000b2}},	//   súla, мнич, _eyl_, _kärd,
   {{0x3b54c157,0xddc400f6,0x2019c080,0x629bc157}},	//   мкор, _ddiż, əsiz_, afuo,
   {{0x7cef927d,0x3f784017,0x2721c03c,0xc1c84045}},	//   _sørg, nču_, góns_, रमुग,
   {{0xd138c007,0xb6068043,0x2f45025d,0xb5fdb084}},	//   smą_, _tršć, _ịgba_, _seši,
   {{0x37ae8079,0x4425814b,0x7cef811b,0x255800a0}},	//   _কপির, _zyl_, _førd, vělý_,
   {{0x7d1e40b3,0x2721c004,0x2347c01c,0x3a26c024}},	//   jops, bóns_, _کليپ_, _iyop_,
   {{0x225a4094,0x7e6d3085,0x6722c40d,0x37de802a}},	//   _ọfụm, _teap, _kkoj, _ভেতর,
   {{0x25a481a8,0x6ab600b9,0xdc3c8089,0x929dc062}},	//   _opml_, _gayf, _náči, piłe,
   {{0x2b46c011,0x44b548b7,0x6348c0a0,0x3f7780b4}},	// [3470] _mioc_, мбас, _věnu, zău_,
   {{0x290cf086,0x63ad8036,0x629d0372,0x61ef0165}},	//   nnda_, łani, lfso, ınlı,
   {{0x6f028157,0x56958051,0x81444de9,0x7cf000b2}},	//   fioc, дает, رنمن, _särg,
   {{0x7afd40fa,0x29016a14,0xf1bf7087,0x629e805f}},	//   _umst, siha_, _trá_, őpon,
   {{0x39458017,0xed598199,0xe8d90094,0x44258149}},	//   _pils_, _brža_, _ntị_, _syl_,
   {{0x6d5d4232,0x7aed0499,0x6d4f4018,0x6722c083}},	//   _itsa, _llat, _iuca, _akoj,
   {{0xbcfb41c0,0x7aed3088,0x2d84c019,0xdb0b0060}},	//   _atég, _olat, erme_, _asfí,
   {{0x6f029d5c,0x6d4f7089,0xdce98043,0x7e7bb08a}},	//   cioc, _kuca, _oveć, _udup,
   {{0x44314458,0x69c087dd,0xbeedc4ef,0x394d80b2}},	//   _hzz_, _grme, _जतीन_, _uues_,
   {{0xceb44435,0x6f0d708b,0x6009c2f8,0x6d5d40e2}},	//   nlər_, hnac, жном_, _mtsa,
   {{0x9eaa17dd,0xb905ca94,0x7d01f08c,0xdb0b0019}},	//   овна_, _नव_, rils, _esfí,
   {{0xb5fb0877,0x141a8009,0xdced42d6,0x6f0d4e19}},	//   rbán, _וועב, yrağ, jnac,
   {{0xaa7b005b,0x7aed0064,0x6d5d404d,0x7ae50283}},	//   ckým, _dlat, _ntsa, _ċitt,
   {{0xc172c093,0x3f9800f1,0x6f028157,0x6f0d708d}},	//   _יחד_, ttru_, zioc, enac,
   {{0xceb4403a,0x2d9901ea,0x6ab60189,0x2ca1005e}},	//   dlər_, atse_, _tayf, _dbhd_,
   {{0x3947c10d,0x3ea01ca5,0x41d1c048,0x6f028018}},	//   _hins_, _ubit_, _तपास, xioc,
   {{0x6d47708e,0xe57a5c57,0xa5bb405f,0x63a940b3}},	// [3480] _bija, юза_, _szór, _ćena,
   {{0x6e2b4600,0x4427f08f,0x6d474e73,0xb606006c}},	//   ügba, _kyn_, _cija, rošč,
   {{0x6d5d41a8,0xeb9757e5,0xdc3c8166,0x9986c011}},	//   _etsa, дих_, _páči, _mzoš_,
   {{0x2eed801e,0x0500402a,0xdced406a,0x44314f2d}},	//   _clef_, ্তের_, prağ, _dzz_,
   {{0x2458884e,0x6729f090,0xa91dd1ae,0x6d4f4449}},	//   паль_, dlej, ružj, _guca,
   {{0x291ec01f,0x2eed80f6,0x3f7847ef,0x3947c912}},	//   xota_, _elef_, pču_, _nins_,
   {{0xe2aa8567,0x98be8017,0x96968156,0x60dc405e}},	//   _وارن_, _citā_, _ораш, _iorm,
   {{0x2cb846ba,0x7ce0410d,0xe8df800c,0x0ec4409d}},	//   _hard_, _vöru, _muộn_, _लोमड,
   {{0x9486c0b4,0x2cb87091,0x69c08156,0xdb158018}},	//   мынд, _kard_, _urme, _urzá,
   {{0x54369094,0xd4c681b4,0x643681b4,0xfbc68a23}},	//   _قرار, _تغري, _قراء, _обзо,
   {{0xddc40007,0x27358240,0x6d4881c8,0x92951edf}},	//   _reiš, bånd_, _iida, нанц,
   {{0x2d8b3092,0x7ce04041,0x9663e145,0xceb4403a}},	//   tuce_, _körs, _акце, zlər_,
   {{0x7ae340b4,0x60dc414b,0x80dac02a,0x290e80c4}},	//   _înti, _oorm, যোগ্, onfa_,
   {{0x2d8b3093,0x98bcc0cc,0x3cf7c359,0x612b4a1f}},	//   ruce_, _divă_, _يعود_, tülm,
   {{0x3cf9c0fd,0xe8df80d1,0x3eab00c3,0x6f0441c8}},	//   ësve_, _cuộn_, pect_, fiic,
   {{0xe8d90112,0x7aed009d,0xdb1ac070,0x3f8cd919}},	//   _itọ_, _ulat, _ortí, mudu_,
   {{0x3f8cc283,0xd838daa5,0xde8f800c,0x332941a8}},	// [3490] ludu_, reču_, hịch_, rlax_,
   {{0x798b800d,0xf548c00c,0xaee3402e,0x27320032}},	//   vugw, _bụi_, _boṣe, mána_,
   {{0x80c448b8,0x6f044149,0x78b8c0bb,0x798ba6ff}},	//   राजे, biic, _mavv, wugw,
   {{0x80cd4048,0xceb4403a,0x7e7d40b0,0x7ce4f094}},	//   साहे, slər_, _udsp, _dòri,
   {{0x6d5d4383,0x61305478,0x6d477095,0x2d86842c}},	//   _utsa, mäln, _tija, groe_,
   {{0x7c288b45,0x6aa2c018,0x98c4404c,0x6aad7096}},	//   _bydr, _abof, _иссл, leaf,
   {{0x8c3cc06a,0x25a6c060,0x7c28802c,0xb5fd804f}},	//   beği, _apol_, _cydr, _rešu,
   {{0xb5fd92bb,0x6d48b097,0x3f8cf098,0xe9d9d585}},	//   _bešt, _eida, dudu_, зки_,
   {{0x673bc750,0x6729c065,0xb5fd8043,0x78b8c0bb}},	//   rmuj, rlej, _pešu, _bavv,
   {{0xddc43099,0x1f65db24,0x69c2d7a3,0x4427c2a4}},	//   _afiş, нком, _droe, _pyn_,
   {{0xddc640ab,0x232a15d3,0x25a6f09a,0xf7708e40}},	//   _mekš, зони_, _epol_, _نان_,
   {{0x394fe016,0x656d1e6e,0x3275c052,0xbbbd8db4}},	//   _tugs_, _bwah, _װײַל_, ्मीक,
   {{0x690902bc,0x7cf24586,0x35a5c5f5,0x2cacf09b}},	//   džeb, _hære, _чалг, bedd_,
   {{0x6134c6ed,0xddc98077,0x6abbf09c,0x764d017b}},	//   tàle, _odež, lduf, _egay,
   {{0x25fc009d,0x799bc0e2,0x6e29840d,0x765b80bb}},	//   _लइकी_, ltuw, _lyeb, _ofuy,
   {{0x6604d0ce,0xe1ff030d,0x67240e1d,0x3eb9709d}},	//   _žiki, mbón_, _ukij, _cast_,
   {{0x656d00de,0x27189684,0xd5a40834,0x799bc067}},	// [34a0] _gwah, nčne_, _ओहिज, ntuw,
   {{0x3c660363,0x3eadf09e,0x7aef4070,0x224d8303}},	//   _яког, heet_, _elct, _agek_,
   {{0xd00f41b4,0x0686843e,0xc6a69bb0,0x395f8231}},	//   ملك_, еген, ерли, _atus_,
   {{0x2905f09f,0x7cf24240,0x395fb0a0,0x6ef14240}},	//   hila_, _særd, _btus_, _påbe,
   {{0xaca44044,0xda639510,0x3ea04077,0x8c3cc06a}},	//   _azụr, увчи, mfit_, reği,
   {{0xf548c0d1,0x7ae9f0a1,0xab68c085,0x6d488080}},	//   _tụi_, eket, _heżż, _qida,
   {{0x3eadc75a,0x6720c0fd,0x78b8c23f,0x57c9c25c}},	//   feet_, tomj, _ravv, िमोह,
   {{0x2cacc0de,0xbb4391fb,0x81af8079,0x78b8f0a2}},	//   wedd_, _беск, _ওপর_, _savv,
   {{0xd251001c,0x799bc02f,0x26ddc231,0xcd06cace}},	//   یند_, gtuw, _dowo_, ечни,
   {{0x27320185,0x3f8787ca,0x644dc2d6,0x9b58c01b}},	//   vána_, brnu_, _şair, миот_,
   {{0xad1b8916,0xa3ca8374,0x7ceb0e05,0x26ddc1c0}},	//   _צובר, _लपट_, _dürl, _fowo_,
   {{0x290403bc,0x69c42408,0x26ddc88b,0x27320089}},	//   èman_, _brie, _gowo_, tána_,
   {{0x48e6e8ab,0xceb38009,0x7ce6810d,0xb95b402e}},	//   _подв, ניש_, _aðri, _arìn,
   {{0x6aa4011c,0x273200b7,0xf1bf043e,0x69c4054f}},	//   _ebif, rána_, rvá_, _drie,
   {{0x3eb94093,0x8ccdcfb2,0x69c430a3,0xab68c085}},	//   _past_, तारो, _erie, _beżż,
   {{0x78ba85cf,0xb0638166,0x61e604c2,0x7cf26fb0}},	//   _latv, _zväč, bykl, _nærb,
   {{0x612b70a4,0x656d05ff,0x39521aad,0xdcf6002d}},	// [34b0] lüli, _uwah, _guys_, _zvyč,
   {{0x6abd1b59,0x799d0022,0x2ee94aa4,0x3f878086}},	//   ldsf, mtsw, skaf_, yrnu_,
   {{0x5f9540c5,0x65608061,0x9d1bc0c3,0x6f02c157}},	//   тиет, _atmh, לומט, _omoc,
   {{0xc01c0015,0x6d4af0a5,0xbebdc017,0x6441434d}},	//   _lược_, _lifa, rlūk, _úlim,
   {{0x672d50b4,0x7cf24586,0x26ddc44e,0x7538c104}},	//   mlaj, _sære, _rowo_, _ohvz,
   {{0x3999c3bc,0x64a59fa9,0x7cf24240,0x2718b0a6}},	//   vès_, така, _pære, včne_,
   {{0x3f8e800d,0x02a780d7,0xac184ec5,0x290346a6}},	//   gufu_, _прам, _зору_, _imja_,
   {{0x2a7f8057,0xb4ac4374,0x7ce070a7,0x6abd00b0}},	//   _udub_, कड़ी_, _hörp, jdsf,
   {{0x3eadf0a8,0x7bdcc0fa,0xa6db4086,0x3f8780b3}},	//   reet_, ärun, _viðh, srnu_,
   {{0x61e630a9,0x3eadc7d2,0x6f07c7e0,0x25bfc14b}},	//   vykl, seet_, _bèbè, rvul_,
   {{0x4ac681e7,0xc01c0015,0x8ae7c11b,0x2d8284a0}},	//   _रोडव, _dược_, _підл, _åker_,
   {{0x2a720057,0x7c2ac02c,0x6d4fcad6,0x61e60026}},	//   _qeyb_, _dyfr, ícas, tykl,
   {{0x7d072710,0x7ceb03a6,0xc8f5c0c5,0x3ebb0085}},	//   fijs, _türl, _издъ, _daqt_,
   {{0x61e60026,0x765d5932,0xb4e048b8,0x2b4b70aa}},	//   rykl, _afsy, _तवे_, _aicc_,
   {{0xeb970ba5,0x5a96410e,0xddc980f1,0xe29a51e5}},	//   кир_, краф, _adeż, мав_,
   {{0x3f8407ca,0x6d4add96,0x799d0022,0xa2c18185}},	//   čmu_, _zifa, btsw, _रोल्,
   {{0xdddb8119,0x6f041d96,0xbb434ff8,0x43434ec5}},	// [34c0] _reuş, _imic, ретк, ретв,
   {{0x98be8039,0xb4634b7d,0xa3d5c036,0xee374bf8}},	//   _kitą_, икул, _सपा_, тну_,
   {{0xe29a8039,0x7e7670ab,0x6abb8b4c,0x25b2402c}},	//   дае_, payp, _bauf, swyl_,
   {{0x2739088b,0x3f8e80b3,0x6d4b0c43,0x78ba8017}},	//   réng_, vufu_, _égar, _satv,
   {{0x6f040077,0xd9978107,0x2d9682d2,0x0d8345bf}},	//   _mmic, نخوا_, трес, _клян,
   {{0x2b4070ac,0x69c64085,0x2739002d,0x6722b0ad}},	//   lmic_, _irke, méne_, sooj,
   {{0x09dfc02a,0x404740b4,0x2ef200b1,0xc29a831f}},	//   _বেলা, _апро_, _olyf_, _отац_,
   {{0x8c1b43bd,0x78bc70ae,0xf6e3c0b4,0xdb0f4107}},	//   _חולי, _harv, ицын, ődöt,
   {{0x7ceb00b5,0x78ba9f9a,0x645c1c17,0xe1ff0107}},	//   _sürm, _tatv, kcri, gból_,
   {{0x69c670af,0x7bdcd05e,0x00000000,0x00000000}},	//   _mrke, äruo, --, --,
   {{0x2b9c402d,0x3af54125,0x7cf480d2,0x78bc70b0}},	//   níc_, _håpe_, _vàrd, _marv,
   {{0xcf9340c3,0x4bfb821d,0x442c8398,0x645c0127}},	//   סטר_, _קלאס, _iyd_, ecri,
   {{0x213a005e,0x6d4af0b1,0x7cf0028c,0x5963c0c5}},	//   _bhph_, _tifa, _sära, _къща,
   {{0x48bd4079,0x6018d4ea,0x7bc50123,0x7ceb30b2}},	//   _আক্র, _поля_, _prhu, _türm,
   {{0xbddb4396,0x8ca4817e,0x68e7c4c9,0x06ae002a}},	//   _ngèr, च्यो, öjde, গাজি,
   {{0x7d071ca5,0x3f574283,0x200c0166,0x1db6c8b8}},	//   sijs, _dħul_, údia_, _अनात,
   {{0x291c4077,0x6abbb0b3,0x69c280a8,0x3ea6c303}},	// [34d0] čvan_, _rauf, jvoe, _mbot_,
   {{0xcc0b43a9,0x270cc0a0,0xb5dfc02a,0x25fc017e}},	//   وزان_, měnu_, _বেঁচ, _लेटी_,
   {{0xf7704246,0x442c80b0,0x99d4801c,0xd49840c5}},	//   قان_, _nyd_, یتها, ърт_,
   {{0x24984010,0x6ef5ccec,0xbcfb4032,0x3f9130b4}},	//   _ecrm_, _kábe, _dtéa, muzu_,
   {{0x2907a670,0xbebb00fd,0x75238536,0x69c282a4}},	//   tina_, llës, tonz, gvoe,
   {{0x6282f0b5,0xf075805f,0x613200b0,0x7ce4c05e}},	//   _adoo, ایاں_, jæll, _mòrs,
   {{0x442c81f4,0xc878c0b5,0x7cf4b0b6,0x63b840b0}},	//   _cyd_, dağ_, _bàrb, ævnt,
   {{0x27320185,0xe1ff0107,0x26cd806f,0xe3b083a9}},	//   váno_, tból_, _uneo_, تره_,
   {{0x442c844e,0x673b884f,0xa6159ed6,0x6729b0b7}},	//   _eyd_, _ihuj, _смач, _ikej,
   {{0x2cb10047,0x6282c17b,0x7989c1b0,0x6f0430b8}},	//   jezd_, _edoo, rrew, _smic,
   {{0x6e2d30b9,0x442c81f4,0x3b09405c,0xdea980e2}},	//   _ayab, _gyd_, kiaq_, _sheƙ,
   {{0x9407403a,0x3f9130ba,0xa3b64027,0x7e798010}},	//   ünə_, duzu_, ड़ित_, nawp,
   {{0x6e2d000d,0x7cf2411b,0x69cf8018,0x3878201e}},	//   _cyab, _læra, _áced, tarr_,
   {{0x3f9130bb,0xa6db4086,0x394c04c9,0x97c5c3be}},	//   fuzu_, _miðu, öds_, _مقتو,
   {{0xdc9ac21d,0x9d1ac4e0,0x3439c052,0x9a128094}},	//   _ניקל, _אוסט, _אײַע, họpụ,
   {{0x3ebff0bc,0xa91dc11a,0x67298094,0x69c68011}},	//   ndut_, ružu, _nkej, _škem,
   {{0x2b406daf,0xddcf00b4,0x7ae08c35,0x20b7e64d}},	// [34e0] rmic_, racţ, _romt, _असाध,
   {{0x673b884f,0xa91df0bd,0x672630be,0x6729b0bf}},	//   _ahuj, držk, lokj, _akej,
   {{0x409b0009,0x6f09c9ae,0x6abd4020,0x6ef5c166}},	//   _אביס, kiec, _fasf, _zábe,
   {{0x61fbc033,0x6abd5dda,0x80a7c079,0xe57a85f1}},	//   kzul, _gasf, _কোম্, езд_,
   {{0x3f58810d,0x442cb0c0,0xfce68698,0x597543d0}},	//   _séu_, _syd_, лодо, _высу,
   {{0x6d5604db,0x69c470c1,0xa2a1c4fb,0x67298171}},	//   _muya, mvie, क्स्, _ekej,
   {{0x2d92446a,0x68e1b0c2,0xa6db4397,0x69c28101}},	//   luye_, _dold, _viðv, svoe,
   {{0x7176801c,0x290a30c3,0x3f5881ff,0x69c2875a}},	//   _مهرا, hiba_, _véu_, pvoe,
   {{0x2d92400d,0x6130454a,0x29058141,0x290a24a9}},	//   nuye_, välj, _fmla_, kiba_,
   {{0x2d8b00e0,0x7aed4232,0x6e2d01c6,0xdced4077}},	//   vrce_, zkat, _ryab, rsać,
   {{0x4034cff8,0x6ef5c03c,0x59b6c285,0x2d9241c6}},	//   ренс, _sábe, _अनवर, huye_,
   {{0x28d2d05d,0x6f09c036,0x2d924d08,0x3860c011}},	//   ताहि, ciec, kuye_, _điru_,
   {{0x5887039d,0x628401f4,0x7c2e70c4,0x291846f0}},	//   лыва, _ddio, _lybr, _ojra_,
   {{0xac97c1b4,0x6d4e537c,0x290a30c5,0x3f9100fc}},	//   _منها_, _niba, giba_, tuzu_,
   {{0x2d8b0639,0x6ff3c03a,0x7cf01e7a,0x69c470c6}},	//   srce_, yəcə, _tärn, evie,
   {{0x7ceb30c7,0x7ae2c0b2,0xaf374248,0x6d5630c8}},	//   _müri, _joot, ارست, _fuya,
   {{0x7ae2d17f,0x290a30c9,0x65954604,0x3ea90c47}},	// [34f0] _moot, biba_, разу, _ibat_,
   {{0x7ae2f0ca,0x2718804f,0x673b8f96,0x2b4d8b5e}},	//   _loot, včna_, _shuj, _siec_,
   {{0x53354c93,0x8bc7423d,0x29d8002d,0xcc7600c3}},	//   _вент, ысад, ržať_, _דעתה_,
   {{0xdd954441,0x69c470cb,0xdb01c089,0xf1ca402d}},	//   _камы, bvie, _oplá, _stáť_,
   {{0x867a40c3,0x7cef9230,0x69c470cc,0x6abf00f6}},	//   _שרשו, _førl, cvie, _maqf,
   {{0xc05b811b,0xdd01c166,0x2b4d8036,0x81bc402a}},	//   хід_, _ľuďo, _wiec_, _অথচ_,
   {{0xa2d80185,0x3ebfc010,0x7fd586bc,0xf651c032}},	//   याम्, tdut_, рілі, يئة_,
   {{0xa91dc077,0x661b81a8,0x68e1b0cd,0x0d85e012}},	//   mrži, _txuk, _wold, алин,
   {{0xf1ca8066,0xa15988a9,0x6d4e4d08,0x63ba8402}},	//   _pláž_, _разу_, _yiba, _estn,
   {{0xfd13849f,0x61fbf0ce,0x26c04043,0x7cedc0d2}},	//   _اجر_, rzul, zdio_, _túrm,
   {{0x7ae2f0cf,0x798d41f4,0xb4e5c048,0x61fbf0d0}},	//   _foot, hraw, _नवी_, szul,
   {{0x7cf004c9,0xa6db4397,0x25a04089,0xdb01c060}},	//   _päro, _miðs, ytil_, _eslò,
   {{0x9967f0d1,0x7ceb00cb,0xe8eed614,0x0d67c051}},	//   _стел, _züri, _дл_, _съем,
   {{0x2d92400d,0x6d5bc104,0x200c002d,0xa96702fd}},	//   vuye_, mqua, údio_, рира_,
   {{0x7cef80d9,0x273cb082,0x2907e12a,0x68e3f0d2}},	//   _rørl, líne_, _imna_, _iond,
   {{0x290a140a,0x225ff0d3,0x6d4e653c,0x2d92400d}},	//   siba_, ncuk_, _siba, tuye_,
   {{0xa2b8c0e6,0x8be98079,0x7cf4b0d4,0x798d42a4}},	// [3500] ्यत्, _কেমন_, _làra, graw,
   {{0x629b830d,0x7e7bf0d5,0x2d926f92,0xf4874de9}},	//   _acuo, haup, ruye_, لامی,
   {{0x4ada04b2,0x6d4e44fd,0x7ae40051,0x798d4157}},	//   _बचाव, _viba, _koit, araw,
   {{0x877b0052,0x6d4e5b98,0x25a0503a,0x7cedc02d}},	//   _באטי, _wiba, ptil_, _búrk,
   {{0xb146823d,0x2a6982b0,0xa6db410d,0xe29782f1}},	//   андл, ñaba_, _viðt, рач_,
   {{0x69c983b3,0x6b5ec017,0x7af601f4,0xa3b28185}},	//   _dree, _līga, _llyt, टबल_,
   {{0x7d0a810d,0x26d230d6,0x3af8c047,0x612b61af}},	//   rifs, _onyo_, _lépe_, rült,
   {{0x68e3f0d7,0x26d21415,0x69c04018,0x6b834119}},	//   _aond, _nnyo_, _ámes, ânge,
   {{0x7ae2f0d8,0x2d8dd433,0xdb01c0b0,0xed5a822b}},	//   _voot, gree_, _oplæ, _роз_,
   {{0x387870d9,0xb4d50314,0x5f94cb8e,0x4fc6dfeb}},	//   _jerr_, _सचे_, биот, асма,
   {{0x387840da,0x271892b8,0x26c0003c,0x08574093}},	//   _merr_, nčno_, _baio_, יבים_,
   {{0x6f164064,0x442ecb45,0xed5980ab,0x6d58013f}},	//   jnyc, _vyf_, _srži_, _čvar,
   {{0x442ec1f4,0x7ae40140,0xa5dac61e,0xc1b80f37}},	//   _wyf_, _doit, _جبار_, алях_,
   {{0xd943c747,0x7cf0020b,0x3e7500d1,0x248d00cb}},	//   _дечи, _härj, ất_, ßem_,
   {{0x7d1df0da,0x7528c036,0x612d8674,0x38cbcde9}},	//   ésse, modz, púlv, _جانی_,
   {{0x248d0165,0x8c1b84e0,0x2fcd4011,0x32554645}},	//   şem_, דולי, _čeg_, свар,
   {{0x7e7d30db,0x3878499e,0x6b558007,0x13af802a}},	// [3510] masp, _berr_, _išge, কিয়,
   {{0x7e7d30dc,0xe04b401c,0xdb18c041,0x3ebf9d05}},	//   lasp, نشاه_, lvvä, _saut_,
   {{0xddc2c6f0,0x3b090396,0x6ef5c107,0x8319504e}},	//   _neož, _kmaq_, _lába, _مقدر_,
   {{0x9c7c804f,0x2b5840c4,0x6f1670dd,0x940ac561}},	//   _roča, _durc_, cnyc, übə_,
   {{0x7f3a4093,0x6f0d70de,0x929dc036,0x9c7c8084}},	//   _תערו, miac, siłk, _soča,
   {{0x61eb81f4,0x290cf0df,0x6d5dc30d,0x6ed58045}},	//   rygl, jida_, ísam, णाहु,
   {{0xdcfb80ab,0x69c9868e,0x6d438206,0x61ed70e0}},	//   _uvuč, _wree, rmna, lyal,
   {{0x613042ff,0x387840b3,0x2bb0c758,0xce948157}},	//   väli, _zerr_, _जनजा, _масъ,
   {{0xc6928052,0x26c0050e,0x3878405c,0x5ac6c3d0}},	//   _מאן_, _raio_, _yerr_, слым_,
   {{0x7cef836b,0x9c7c891c,0x6ef5c004,0x6f0d70e1}},	//   _mørk, _toča, _dába, hiac,
   {{0x60c18018,0x2721c066,0x7cf00041,0x7af630e2}},	//   _ialm, zóny_, _färj, _plyt,
   {{0x81ae4079,0x61ed431c,0x8a14805f,0x6132010d}},	//   কিত_, kyal, _اظہا, mæli,
   {{0x78a91530,0x6ef5c018,0x6f098044,0xdce40036}},	//   đevn, _gába, _mmec, _zwię,
   {{0x2a7da98e,0x612d8004,0x6f1b8043,0xed570cfc}},	//   hawb_, cúlt, _ljuc, сор_,
   {{0x7ae430e3,0x3395d1e0,0x7cedc6ed,0xc2ea00a3}},	//   _toit, _العز, _núri, _معظم_,
   {{0xfb86c4e8,0x8364c6b0,0x6eeec061,0xaa7b0086}},	//   _ادوی, _بدول, _cùbh, skýr,
   {{0x82970093,0x7f445397,0x2d80405e,0x6f165dd5}},	// [3520] _הדפס_, rmiq, usie_, rnyc,
   {{0x23b7808f,0xdb1ac6ed,0xc8d24285,0x23a18036}},	//   _आनंद, _estè, साइट, kój_,
   {{0xf536c052,0xcc7ac009,0x6f0d70e4,0x27ff40e2}},	//   צטער_, רװער, biac, _ƙuna_,
   {{0x6d45424f,0xe9f90171,0x918681b4,0xe9a647e1}},	//   amha, _abẹ_, مجتم, _ламп,
   {{0x085480d9,0x3878413b,0x7cf485ef,0xfbc7c01c}},	//   овлю, _terr_, _dàrn, _کت_,
   {{0x6d454510,0x7cede187,0x2b5870e5,0x6ab64086}},	//   cmha, _fúri, _turc_, leyf,
   {{0x9c7cc011,0x7cf0073b,0x9bc68007,0x3706c623}},	//   njče, _pärj, сёлк, йчив,
   {{0x5f068097,0x7528c036,0x7c3a806c,0xfb1682cf}},	//   _узба, wodz, _vztr, _اورج,
   {{0x63b88022,0xa2d5905d,0xe45285d3,0x25afc024}},	//   swvn, णार्, _فضا_, _cpgl_,
   {{0x610f4007,0x3ae7409d,0x2d8bc7c9,0x6d4f9412}},	//   _gėlė, _lõpp_, ácea_, _écap,
   {{0xda6fc0d7,0x290cf0e6,0xd8db4009,0x7e7d30e7}},	//   _ня_, rida_, אקיר, tasp,
   {{0xdc3b8009,0x7e62b0e8,0xa91df0e9,0x80d6cae7}},	//   _געבר, ncop, držu, बाहे,
   {{0x6f0d70ea,0x290a42c0,0xa1591151,0x5162c02e}},	//   viac, _omba_, рагу_, _fọọm,
   {{0x555805af,0xa99bc0c3,0x290eb0eb,0x02cf8036}},	//   саря_, _עבור, nifa_, _सोनभ,
   {{0x6f0d70ec,0xff294032,0x387a0024,0x7ae6498f}},	//   tiac, لكسي_, _depr_, _bokt,
   {{0x79828036,0x443cc011,0x8c00402a,0x2d820084}},	//   ksow, _izv_, ্থান_, bske_,
   {{0x290e9d0f,0x75b6c048,0x6aad04da,0x7cedf0ed}},	// [3530] kifa_, _अनोळ, _ibaf, _súri,
   {{0x3b0dc033,0x6f09b0ee,0x6b4f4031,0x273200a0}},	//   zieq_, _smec, _bògì, váni_,
   {{0x25a4f0ef,0x96eb8660,0x3e5e8044,0x3ce58ded}},	//   html_, льда_, _ịta_, _rolv_,
   {{0x41a9c54a,0x61ed406a,0x5a358d54,0xfe7f29f8}},	//   _कहलस, pyal, онет, naï_,
   {{0xb4c488b8,0x443cc127,0x7faa8561,0x2d768062}},	//   एयू_, _lzv_, _rəqa, głe_,
   {{0x2a7d8022,0x70b384ef,0x9a29435d,0x7cedf0f0}},	//   sawb_, ंजेल, _gươm_, _túri,
   {{0xfe71c032,0xfe57c05f,0x7cf01ced,0x70b98036}},	//   ودة_, میاب_, _särk, _इसील,
   {{0x6d59c274,0xfd4c4044,0x68e7402d,0x6f0982c0}},	//   _puwa, _obiọ, _hojd, _umec,
   {{0x0edd0260,0x3ce5b0f1,0xc8b5c10e,0x6e3bae32}},	//   यानड, _tolv_, осны, _uzub,
   {{0x1fe4c079,0x63a55a6c,0x7cf030f2,0xa3ba054a}},	//   _ফেইস, othn, _värk, _आईल_,
   {{0x60c541b4,0x273cb0f3,0x6f0f01d6,0x7afbc0f7}},	//   idhm, lína_, ficc, phut,
   {{0x2b83c03a,0x7afd30f4,0x656d4033,0xe29a1509}},	//   rıc_, ghst, kpah, шам_,
   {{0x69cbd2c5,0x6f1d0019,0x7c2d891a,0x7e7b8230}},	//   _urge, érca, şard, _meup,
   {{0x6d5b9572,0x63be0033,0x1869c698,0x80a7c079}},	//   _muua, _pspn, _таки_, _কোর্,
   {{0x6f0f00c4,0xfbc3073c,0xc623802a,0x60c3c061}},	//   bicc, мбро, বেচা_, _ianm,
   {{0x613040fa,0x672b8b0e,0x6f0f08e5,0x629befa7}},	//   hält, jogj, cicc, nguo,
   {{0x82fa1971,0x656d42d7,0xe5a34c35,0x64434086}},	// [3540] _مرکز_, gpah, мити, ýnin,
   {{0x6d41800b,0x614640a7,0x7cf48061,0x6130581b}},	//   _nhla, цеза, _càrl, jält,
   {{0x656980da,0x25bf829e,0x68e770f5,0x31b6c705}},	//   _ateh, _asul_, _dojd, _अन्ध,
   {{0x4c3b0093,0x7c3e0c09,0x7c9602f0,0x7cf48061}},	//   _כתיב, _izpr, _اشکا, _eàrl,
   {{0x2c4ec080,0x3a208138,0x6d268039,0x0cd495ff}},	//   zəd_, çip_, оддз, золю,
   {{0xdce406f0,0xc5f300c3,0x7ceb0165,0x290a412c}},	//   _otič, ודד_, _hürr, _umba_,
   {{0xaaca0444,0x31a40107,0xa3cde32e,0x7cf24329}},	//   ियाक, höz_, रिफ_, _lærk,
   {{0xa3cde7d7,0xddaac0b4,0x7e7b9078,0x9ed8c0b4}},	//   रिन_, атол_, _geup, смит_,
   {{0x798441f4,0x6f0f0c10,0x273c8066,0x6d41873f}},	//   nsiw, vicc, cína_, _fhla,
   {{0x26c4b0f6,0x9980c039,0x97a6d2b0,0xd8f8c11b}},	//   _hamo_, _šių_, ормл, сної_,
   {{0xb4b68036,0x6ef5ccec,0x6f0f00c4,0x2cb80b43}},	//   ज़ी_, _kábl, ticc, derd_,
   {{0x3f980dcc,0x46d1c036,0xf76fc01c,0x443cc8f1}},	//   duru_, _दोपह, کای_, _vzv_,
   {{0x6f0f102f,0x26c4b0f7,0xe3b80189,0x6b558007}},	//   ricc, _mamo_, çın_, _išga,
   {{0x63a5402c,0x6367891a,0x7c2d958d,0x443e8398}},	//   ythn, _fınd, şare, _kzt_,
   {{0x9455809c,0xf1bf4107,0xe4540c38,0x44210303}},	//   _sāk, _nyár_, дкры, _qxh_,
   {{0xae1ec275,0x25a68327,0x443e806f,0x656d4d76}},	//   _बखान_, ktol_, _mzt_, tpah,
   {{0x78b74018,0x27320089,0x60c3f0f8,0xe80b09fd}},	// [3550] texv, gánu_, _yanm, _हेरा_,
   {{0xd13147c3,0x68e8802c,0x7f5c70f9,0x6d5b8051}},	//   رما_, _nodd, _burq, _ruua,
   {{0x7e7b8669,0x4427000c,0x3f9801c6,0x5335434a}},	//   _peup, _ân_, curu_, _неот,
   {{0x6d41b0fa,0x7bce490c,0x95d98051,0x7cfd896d}},	//   _shla, _drbu, йдет_, _mère,
   {{0x6d41b0fb,0x2d99054a,0x6f0d00eb,0xf1bf401f}},	//   _phla, nuse_, _mmac, _usá_,
   {{0x61e00041,0x6d5d70fc,0x7d1ac046,0xa3cdc6c1}},	//   ämli, _iusa, jnts, रिम_,
   {{0x0ec687f6,0xf771883b,0x26c48157,0x6d4f8157}},	//   _रोकड, راث_, _famo_, _ècam,
   {{0x66b4804c,0x7cf002ff,0x85bb81aa,0xb065c051}},	//   _обсу, _väri, _پارس_, kkää,
   {{0xdd9184cc,0xc3344093,0xf991c1b4,0x65698590}},	//   _سوا_, ווק_, ربة_, _uteh,
   {{0x69c9f0fd,0x4805c11b,0x3d948dae,0x6d4180f7}},	//   rvee, зпов, _цифр, _uhla,
   {{0x2cb830fe,0x60c3f0ff,0x2d99286e,0x7cfd8303}},	//   verd_, _vanm, euse_, _cère,
   {{0xdce4004f,0x316dc01e,0xa25b401e,0x2cb83100}},	//   _vtič, ppez_, _saôn, werd_,
   {{0x2cb80b43,0xf2d2c052,0x6f1bc25d,0x6f0d00b9}},	//   terd_, _רעד_, mnuc, _dmac,
   {{0x18671027,0x7ae9854a,0x2d9263a2,0xa0670dbf}},	//   зари_, _loet, vrye_, зара_,
   {{0x7faa803a,0x2fc10070,0xfdb884fb,0x32022921}},	//   _nəql, _cshg_, _इन्फ, szky_,
   {{0x6f1bf101,0x6d557102,0x7ae9832a,0x9f568107}},	//   nnuc, _aiza, _noet, ógép_,
   {{0xae0c4028,0x6d5d7103,0x3f983104,0x7f5c4070}},	// [3560] _सेशन_, _cusa, suru_, _surq,
   {{0x8c4619c4,0x7e7d40b2,0x38af8138,0x7cedd3ab}},	//   _непе, _eesp, nırı_, _túru,
   {{0xdb058669,0x54770093,0x9c7cf105,0xbcfb1adf}},	//   othè, _מגיע_, njča, rpét,
   {{0x7ae98290,0xdb05877c,0x794dc036,0x7bce406f}},	//   _coet, nthè, _dźwi, _vrbu,
   {{0x2718806c,0x6280ca4d,0x443e8036,0x7ae9993e}},	//   nčni_, vamo, _szt_, _doet,
   {{0x7afba500,0x66044150,0xd1324032,0x61304041}},	//   _elut, mzik, _أمس_, räls,
   {{0x25a6b106,0xf76f81aa,0x9c7c8077,0x2560f107}},	//   stol_, هاي_, _hočk, _sòl_,
   {{0x9c7c8047,0xfbcfa34e,0xdb08c0ce,0x29110568}},	//   _kočk, اتو_, _asdò, ziza_,
   {{0x29112912,0x20568846,0xbcfb44e7,0x7cf340b5}},	//   yiza_, _етер, _stéi, _fırı,
   {{0x3eb900c3,0x7cfd81cb,0x7659c02c,0x798604f1}},	//   west_, _père, _egwy, dskw,
   {{0x645ab108,0x6e950cf0,0xa3b0854a,0xe69500b4}},	//   _igti, мину, _ओहि_, мины,
   {{0x7bdb80c3,0xbebb013b,0x6b654007,0xd00f8032}},	//   _לקבו, llëz, _jėga, _حلم_,
   {{0xa5bb4004,0xc8c8009d,0x684281c0,0x6b654026}},	//   _axón, िएंट, _fídí, _mėga,
   {{0x656f005c,0xc2fa8079,0x6d43ce89,0x66047109}},	//   rpch, েকটি_, _ghna, dzik,
   {{0x368b4887,0x387eb10a,0x7e7d578d,0x8ca1c028}},	//   йсан_, _metr_, _pesp, _खातो,
   {{0x539bc093,0x6d55710b,0xf4080032,0x7cef8240}},	//   _היהו, _siza, سيقى_, _hørt,
   {{0xa5bb4018,0x690901be,0x7ae982a4,0x26c6c010}},	// [3570] _exón, džev, _roet, _maoo_,
   {{0x27320018,0x98b84007,0xdb03c4e4,0x81fc00c3}},	//   báns_, _mirė_, rtné, _להחז,
   {{0x7ae98d6a,0x3f8740b7,0xfe70405f,0x656d0085}},	//   _poet, énu_, ئدہ_, _htah,
   {{0xe8d9310c,0xd251835c,0x69cb4041,0x7afd013b}},	//   _muọ_, ننا_, åges, ërth,
   {{0x99898038,0x6f00c032,0x6ea51283,0xe5a59707}},	//   ťaž_, dhmc, _कानु, фили,
   {{0x6847001e,0x7cf34080,0xe5708032,0x78ad806f}},	//   cédé, _qırı, اطن_, đavo,
   {{0xa2e5c025,0x6feac561,0x00000000,0x00000000}},	//   дойд, yəca, --, --,
   {{0xa2a2c8c5,0x6d572b9f,0x7cf000cb,0x3eb98089}},	//   _गाण्, _lixa, _härt, _úst_,
   {{0x7cfd80d2,0x635c00b6,0x764b0107,0x69cd4025}},	//   _cèrc, _fčnw, _úgyh, nvae,
   {{0x8389c5b4,0x657b9187,0xb11493e4,0xf87081af}},	//   обов_, _iwuh, _змуш, čším_,
   {{0xdb01c065,0xb5fb0032,0x27320018,0xaca3c0eb}},	//   _oplø, scál, xáns_, jiụl,
   {{0x6d45310d,0x3f85c10d,0x6d570060,0x635c006c}},	//   _ahha, rslu_, _aixa, _učni,
   {{0x0607143c,0x6d570140,0xf548c35d,0x6d5f0149}},	//   дняк_, _bixa, _lụy_, _cuqa,
   {{0xf1bccd6c,0x613044c9,0x6f1d11ce,0x9c7c8618}},	//   ्टरन, jälp, ansc, _ročk,
   {{0x25a944f1,0x260e0428,0x7cef8240,0xfe7f414d}},	//   etal_, _ढेरी_, _hørs, _beï_,
   {{0x9c7c8574,0x7cef80b0,0x29136275,0x656d0085}},	//   _počk, _kørs, eixa_, _ftah,
   {{0xdb0b0018,0xe8d90112,0x6aa40024,0x25a957f1}},	// [3580] _esfó, _zuọ_, _icif, gtal_,
   {{0x6fb1c028,0x61eb4041,0xbcfb01cb,0x27320018}},	//   _जहां, ägla, spér, páns_,
   {{0x7cf004c9,0x316d81a8,0xd12f4032,0x657ba99d}},	//   _därt, _atez_, جمل_, _awuh,
   {{0x2d868073,0x200c002d,0xfe7f414d,0xb95b4031}},	//   tsoe_, údiu_, _geï_, _isìn,
   {{0x656d005c,0x094a9000,0x914aa044,0x8c11c02a}},	//   _xtah, очки_, очка_, _সুমন_,
   {{0x229481c0,0x6ef5c032,0x8b66529a,0x81e3c02a}},	//   _búkà_, _hábh, _يازم, ননা_,
   {{0x3160310e,0x2f1ac017,0x4425b0a0,0xec360052}},	//   _luiz_, līgi_, _cxl_, ואַר_,
   {{0x6efcc1aa,0x78bc06e3,0x69c4310f,0x4420c6f0}},	//   _béba, herv, _osie, _ći_,
   {{0x5d54cb24,0x395fb110,0xd2528032,0x7cf000b2}},	//   нкит, _guus_, _شنط_, _järs,
   {{0x3374c3fe,0x20044080,0xd83ec02d,0x6d5f19ba}},	//   нгор, _əmin_, áčom_, _ruqa,
   {{0x6560b111,0xa7153112,0x69ddf113,0x7aebc5ca}},	//   _humh, емні, äser, _fogt,
   {{0x6f0286af,0x6f1d00cb,0x6d573114,0x6b9ac125}},	//   nhoc, unsc, _sixa, rutg,
   {{0xb95b4031,0x3f9cb115,0x62847116,0x7cfd80d2}},	//   _asìn, luvu_, daio, _hèra,
   {{0x78bc0e3b,0xdb059e66,0x61e28018,0x7cf24086}},	//   gerv, rthé, ixol, _kæru,
   {{0x672f0451,0xf2c7459d,0x289bc323,0x7cf48580}},	//   pocj, мсан, _ויוא, _càri,
   {{0x7cf004c9,0x62844f02,0x9f47802d,0x7aebc149}},	//   _bärs, gaio, šnú_, _xogt,
   {{0x4438405e,0x6d58f117,0x3f8e40b3,0x79964036}},	// [3590] _ayr_, _kiva, šful_, gryw,
   {{0x3eb20036,0x80c9454a,0x3ea48011,0x291ef118}},	//   _zbyt_, _होखे, _acmt_, nnta_,
   {{0x6560805e,0xf1c8c00c,0x6b9c00cc,0x395f925f}},	//   _aumh, _lỡ_, curg, _suus_,
   {{0x628086f2,0x7aed0232,0x645c4073,0x25a97119}},	//   _cemo, _joat, _egri, ptal_,
   {{0x38c48007,0x2f1ac017,0xd8388053,0xd5c8c0d1}},	//   kūrė_, cīgi_, _ayč_, _nề_,
   {{0x98c602a3,0x7f4d4080,0xdb0784c9,0x6560b11a}},	//   ćući_, lmaq, _spjä, _dumh,
   {{0x29114676,0x2b46c061,0xa2958039,0x60c8b11b}},	//   _imza_, _bhoc_, _паві, _dadm,
   {{0xd5c8c00c,0x7c22403a,0x645c4043,0x3f878077}},	//   _bề_, ğort, _zgri, rsnu_,
   {{0xc8ab80c5,0x3eadf11c,0xe619d70f,0x6722c44e}},	//   _мъже_, rfet_, яди_, _djoj,
   {{0xa3cf8045,0x628441a8,0x6280b11d,0xf485805f}},	//   शिद_, zaio, _zemo, _سائی,
   {{0x260fc5b9,0xa3c140e4,0x2d9db11e,0x7bc501c6}},	//   _तेरी_, ्टि_, luwe_, _nshu,
   {{0x6abd0ad3,0x6722c13b,0xa2a50109,0x3af8c107}},	//   gesf, _gjoj, _काण्, _lépj_,
   {{0x799d2d76,0x6e92c200,0x3afa8052,0x7aed00b9}},	//   gusw, _صلوا, פּטע, _doat,
   {{0xdce44011,0x20078013,0xdbd75139,0x61e48025}},	//   mpić, ozni_, _käär, äili,
   {{0x1c3900d9,0x6d4b4026,0xd5e2c031,0xdbd748a1}},	//   дять_, įgal, _ifó, _jäär,
   {{0x645c711f,0xa3bed4aa,0x6d477120,0x2f1ac017}},	//   _sgri, ुटर_, _ahja, tīgi_,
   {{0xf98a01b4,0xa2a50e18,0xdce64017,0x531b02a6}},	// [35a0] _عندي_, _कात्, _atkā, _מוקצ,
   {{0xaaac0281,0x62847121,0xa2d80185,0xe4f48fb2}},	//   ट्रक, saio, याक्, _अवधि_,
   {{0x62847122,0x395850aa,0x2b597123,0xeafa513d}},	//   paio, _virs_, _fisc_, _فرحت_,
   {{0x60c8b124,0x4427c34d,0x6ef5f125,0xeda6841a}},	//   _sadm, _mxn_, _fábi, ешко,
   {{0xddcd4119,0xfa364107,0x6d4e3126,0xbbdbc8b8}},	//   rbaţ, _سرحد, omba, यमुक,
   {{0x2eff80f1,0x98a44026,0x6f047127,0xa3c4025c}},	//   _eluf_, _ėmė_, lhic, _एना_,
   {{0x0443615e,0x272400b5,0x673bc34d,0x629a0007}},	//   _берн, zına_, fluj, ėtoj,
   {{0x444402ad,0x3dc20b0e,0x7d1500b3,0xcf9300c3}},	//   _mz_, kwkw_, zizs, אטה_,
   {{0xa9268589,0x69cdc062,0xe56fc231,0x443a06a6}},	//   _здал, तिषी, یطی_, _lyp_,
   {{0x67243128,0x291ecf0b,0xdbdbc031,0x753ac0fc}},	//   _ajij, unta_, _bààr, ultz,
   {{0xed4f81aa,0x2018809d,0x7d153129,0x7c3b009c}},	//   _اپل_, _äri_, vizs, ƙuri,
   {{0xa2d80185,0x6b45f12a,0x7c38c066,0x28d0d6da}},	//   याग्, tóge, _vyvr, _थोरि,
   {{0x7a49c01e,0x9df800c5,0x2903013b,0x394e8060}},	//   rêté, енят_, thja_, omfs_,
   {{0x2bc588c5,0x656ff12b,0x6b45c070,0x6d5a953f}},	//   विचा, íche, róge, _jita,
   {{0x76441c06,0x4427c00c,0x7a49003f,0x69c6712c}},	//   _eziy, _gxn_, _sūtī, _aske,
   {{0x69dd8018,0x9f600fc1,0x4444312d,0x6d4e1e4f}},	//   _áseg, árás_, _dz_, amba,
   {{0x7e6d0bc2,0x7cf004d3,0x7afd00fd,0xf19444df}},	// [35b0] _ifap, _värr, ërtu, лить,
   {{0xbebb413b,0x55ac0052,0x78a50089,0xa3e08047}},	//   _gjën, _צייַ, _uchv, दमा_,
   {{0x7bc5132b,0xd4984007,0x6f0445ef,0x2b49000c}},	//   _ushu, эрт_, bhic, _khac_,
   {{0x395a002d,0x29010303,0xfe71801c,0x8bc44007}},	//   _zips_, _hlha_, شگر_, ысуд,
   {{0x261181e7,0xdca59cf8,0xdbd74134,0xab644036}},	//   _देशी_, вали, _säär, ężar,
   {{0x2d990032,0x2d8b312e,0x2d9db12f,0x27390089}},	//   irse_, isce_, ruwe_, ménu_,
   {{0x7c2900cb,0x6d488321,0x7faa8080,0x7c3a8062}},	//   ßerh, _dhda, _yəqi, _cytr,
   {{0x6efcf130,0x26cb7131,0x98b68017,0x2ebdda7e}},	//   _débo, _jaco_, īgās_, ्येत,
   {{0x7aef4070,0xf2d28009,0xdb0e8060,0x2e4ec1c0}},	//   _moct, _דען_, _esbó, _fọmọ_,
   {{0xfc3fc047,0x7cf24086,0xf8dbc25c,0x2566002c}},	//   řím_, _hærr, बाइय, _rôl_,
   {{0x8cd6c036,0x2b490e89,0x4add0048,0xab2a042e}},	//   बाजो, _bhac_, यांव, дона_,
   {{0x6282c078,0x4444117c,0x443a014b,0x66da00c5}},	//   _geoo, _rz_, _ryp_, фьор_,
   {{0x7afbcfe2,0x6562c09c,0x2b4901c8,0x78b54066}},	//   mkut, _guoh, _dhac_, _obzv,
   {{0x81e74079,0x6d5ab132,0xed570ec4,0x2901005e}},	//   বনা_, _xita, коя_, _clha_,
   {{0x2905c4ff,0x395a197a,0xdbdbc031,0x2b490061}},	//   mhla_, _vips_, _fàár, _fhac_,
   {{0xb5fb0070,0x2b4900f6,0x097a4523,0xc3234da6}},	//   zcái, _ghac_, дёжь_, амск,
   {{0x2a601bdd,0x395a0093,0x3320431d,0x6e3bb133}},	// [35c0] _igib_, _tips_, rnix_, _nyub,
   {{0x7bd54036,0x7ae9e0db,0x42554896,0x5eaa402a}},	//   _brzu, hjet, утст, _চোখে,
   {{0x7fd5411b,0x7cf4b134,0x6f047135,0x7cf24af3}},	//   ліці, _màrt, phic, _særs,
   {{0x7afbc0b3,0x65640150,0xdbe4c031,0x6e3b81c6}},	//   jkut, _kuih, _dèèr, _byub,
   {{0xbea383c6,0x68ee4170,0x6efcc01e,0x2ae0c314}},	//   рачк, _tobd, _débl, कासु_,
   {{0x7cf256a9,0x26ddc3bc,0x628400fc,0x3ea6e4e4}},	//   _værs, _anwo_, _leio, _scot_,
   {{0x26cb4070,0x73e347de,0x60cac086,0x25adf136}},	//   _yaco_, _корз, _rafm, etel_,
   {{0x4cc88079,0xab27c8b5,0x7c3a8066,0x3ea2811b}},	//   লাধু, која_, _vytr, _økt_,
   {{0x7c29006a,0x973d006f,0x1d34c0c5,0xa534cca1}},	//   ğeri, nuće, лния, лнич,
   {{0xc7968097,0x67228039,0x3f9ef137,0x60cac05c}},	//   _арды, lnoj, tutu_, _qafm,
   {{0x7ae9d138,0x69090054,0x25a07138,0x853040e2}},	//   bjet, džep, huil_, guɗi,
   {{0x7c3c469a,0x2f1ac8c7,0x3b540119,0x25a07139}},	//   _myrr, tīgu_, икэр, kuil_,
   {{0x62840140,0x7bd7c004,0x6f02ce19,0x6609c036}},	//   _deio, _áxun, _iloc, czek,
   {{0x2905d80a,0xdb1e4061,0x6564005e,0x2f1ac017}},	//   chla_, _aspà, _duih, rīgu_,
   {{0xa1580b0f,0x7aef4066,0xa438c11b,0x5558000a}},	//   тару_, _poct, _язку_, таря_,
   {{0xbcfb446a,0x21670051,0x78ad80b3,0x37046deb}},	//   _cuén, _итог, đavi, ачув,
   {{0x3ea9313a,0x44b5632c,0x7d1895db,0x690b4062}},	// [35d0] _icat_, лбас, kivs, dżer,
   {{0x6360c0eb,0xdb1e4580,0x26cb6e60,0xdb05a54e}},	//   _ịnya, _espà, _waco_, rthí,
   {{0xaaaa0bfa,0xf2b18079,0x7d1df13b,0x7c3c41f4}},	//   _कामक, _ঘোষণ, éssi, _cyrr,
   {{0xf2df435d,0x9c828123,0x443cc141,0xd25908c7}},	//   _khâm_, ščla, _myv_, žņu_,
   {{0xf773405f,0xf1a7a8ab,0x25a0407a,0xa3c88027}},	//   _چار_, трен, cuil_, _लैब_,
   {{0x80cd8b35,0x2bd5e624,0x7ae9f13c,0x403540bd}},	//   _धोखे, धिमा, wjet, _бегс,
   {{0x4fc44051,0x28e0425c,0x98a79497,0x2618c8fb}},	//   _кста, नारि, joną_, _बेबी_,
   {{0x27e9b13d,0x6d5c713e,0x7afd01d4,0x7fb681b4}},	//   ćan_, _zira, jkst, اهير_,
   {{0x26cdc019,0x25fed05d,0x78884017,0x7cf4b13f}},	//   rdeo_, शैली_, būvē, _càrs,
   {{0x6d5c480c,0x7e6d40c9,0x62843140,0x69c9b141}},	//   _xira, hcap, _seio, _isee,
   {{0xd7c8801c,0xa2a50a89,0x7cfd8396,0x6e3d4b9a}},	//   _لوله_, _काश्, _jèrm, _lysb,
   {{0x38610024,0x6eff013b,0x139a4052,0xddc408c7}},	//   _aghr_, _dëbo, עברע, _afiš,
   {{0x333fc17a,0xc332c2a6,0xf2df400c,0x2919c018}},	//   mlux_, _פוד_, _châm_, ésas_,
   {{0x2569c1b4,0xf592c79d,0xa2d80185,0x8fa60e32}},	//   _iúl_, _الوج, याङ्, лаге,
   {{0x81e9802a,0x26c0401f,0x31568052,0x69c9805e}},	//   মনি_, teio_, טישן_, _lsee,
   {{0xf2a340b4,0x69d6013b,0x2b4b7142,0x7e6d7143}},	//   йисп, _trye, _chcc_, gcap,
   {{0xa06a16f8,0x26c22413,0xd7f88015,0x394a4033}},	// [35e0] _папа_, meko_, _ngăn_, _phbs_,
   {{0xcc3608a7,0x81e9802a,0x2907804f,0x25a04078}},	//   _مرجع, মনা_, jhna_, ruil_,
   {{0x9f47805b,0xb8cc5087,0x2739003c,0xdb1e4e84}},	//   šný_, _गा_, céns_, _espá,
   {{0xbc1b0009,0x798d4022,0x387f46f0,0xaadd0047}},	//   _טויש, bsaw, _đure_, याएक,
   {{0xa3cac027,0xaefb405e,0xe61f499e,0x6722859d}},	//   _रैन_, _siùg, _ddôs_, rnoj,
   {{0x63a1da6f,0x290780f1,0x8aff06df,0x26c201a8}},	//   kuln, ghna_, _muƙa, heko_,
   {{0x69c9a8c3,0xdfd081b4,0x26c23144,0x9f58413b}},	//   _esee, زية_, keko_, jyrë_,
   {{0xaa7b4038,0x6f1981f4,0xa2d40fb2,0x62867145}},	//   _inýc, ciwc, _बोल्, _jeko,
   {{0x8af0403a,0x171b8009,0xbef78093,0xfaf780c3}},	//   mməd, _נומע, _עצמו_, _עצמי_,
   {{0xd90dc78a,0x8af0403a,0x291a7146,0x2f1af147}},	//   وین_, lməd, nipa_, _bàgè_,
   {{0x59d2c185,0x62864f42,0x753500f1,0x2b40404f}},	//   तिहर, _oeko, vozz, klic_,
   {{0x69dd8018,0x9f3500d9,0x6d4f8157,0x2b404043}},	//   _ásec, ремі, _ècar, jlic_,
   {{0xadf9817e,0x443e92e7,0x395e8dc5,0x00000000}},	//   ्नयन_, _hyt_, _kits_, --,
   {{0x291a42c0,0x443cd9c0,0x7f5d40d2,0x7b16056e}},	//   jipa_, _tyv_, _sisq, nšuj,
   {{0x6f043148,0x9947c032,0x798d402f,0xa3cc0036}},	//   _flic, _حلول_, wsaw, लिग_,
   {{0x427545f5,0xf2df400c,0xb275401f,0x7f5d46e2}},	//   ргас, _thâm_, рлаш, _qisq,
   {{0x7f5d5ea2,0xb4c2475b,0x9d154c33,0x39154e5a}},	// [35f0] _visq, ्यू_, адач, амар,
   {{0x6f043149,0x798d444e,0xb69b41ff,0x10075da5}},	//   _zlic, rsaw, _glân, ляем,
   {{0x798d714a,0x7f4d0303,0x201a802d,0xa3cdcd6c}},	//   ssaw, _khaq, úpil_, रिए_,
   {{0x6d5e314b,0x60c1e1af,0x0c74001c,0x7c2900cb}},	//   _zipa, zelm, _پدید, ßeru,
   {{0x91e58259,0x7d1ad664,0x6b654007,0x9ad4c0eb}},	//   роле, kits, _mėgi, _pịny,
   {{0xe3b004fc,0x291a714c,0xeb999148,0x7cfd8acd}},	//   _بری_, cipa_, вик_, _tèrm,
   {{0x660d6a6f,0x2569c359,0xdb058359,0x7cf4805e}},	//   lzak, _súl_, athá, _pàrr,
   {{0x6ef84018,0x395e807a,0x2907ad76,0xdb23808c}},	//   _fíbu, _eits_, shna_, _اوری,
   {{0x290780b3,0x7d1af14d,0x7bcac05e,0xdcebc017}},	//   phna_, fits, _asfu, _atgā,
   {{0x63a1ce8b,0x9f5840fd,0xe787811e,0x3eab421b}},	//   tuln, tyrë_, _будо, _lcct_,
   {{0x60c3b14e,0x8c45c179,0x28e28e0f,0x6f04314f}},	//   menm, рене, पारि, _plic,
   {{0x28d98959,0x81d88079,0x660d4360,0x7b060018}},	//   _योति, াহর_, kzak, _sóub,
   {{0x7aed7150,0x63a1f151,0x7f5f003a,0x26cfef82}},	//   djat, suln, _diqq, _iago_,
   {{0x8467c0c5,0xd618c1aa,0x22490077,0x6f09c10b}},	//   _съде, _حتما_, _dzak_, lhec,
   {{0x673b831c,0x61fbc105,0xdb020851,0x26c200fc}},	//   _okuj, lyul, ttlä, peko_,
   {{0x6724403f,0x056609a5,0xb2264fe8,0x8236001c}},	//   unij, _квин, амбл, _پربا,
   {{0x60c3b152,0x7c3e0064,0x21a64858,0x7b160066}},	// [3600] kenm, _wypr, ризм, yšuj,
   {{0xe0464b73,0xef863153,0x6729b154,0x673b878f}},	//   анзи, _клоп, _ajej, _akuj,
   {{0x8ca74742,0xcd29021a,0xc059411b,0x28a98fb2}},	//   _चारो, _حسين_, гії_, च्छि,
   {{0x291a40ab,0x69d9f155,0xa5bb403c,0x26cfe251}},	//   sipa_, _orwe, _axóu, _nago_,
   {{0x60ce4022,0x88bcc047,0xfb374009,0x7b17c0b4}},	//   _tabm, dněn, _כאטש_, rţul,
   {{0x60c3b156,0x3ea68105,0xdb058359,0x2fc7802c}},	//   genm, sgot_, rthá, fwng_,
   {{0x21208068,0xfbc7c8a7,0x7d1af157,0x69cbf158}},	//   đih_, _بت_, vits, _asge,
   {{0x64488166,0x8f9b0087,0x7d1adf11,0x395e9c85}},	//   _vzdi, דיקי, wits, _wits_,
   {{0x7b160066,0x7d1c274b,0xdb022572,0xa0a686b1}},	//   pšuj, kirs, pulê, _вазд,
   {{0x443e805c,0x7aed4283,0x27320804,0x7f42ae77}},	//   _tyt_, zjat, mány_, lloq,
   {{0x30d94009,0xda6fc156,0x60d94009,0x22400396}},	//   אַרע, _мя_, אַרג, _ayik_,
   {{0xe61ac7e3,0x2367c011,0x6f1bc02b,0x79840f2d}},	//   _иде_, _dunj_, ciuc, _bwiw,
   {{0x80a740ba,0xa3c90036,0x96470007,0x506700c5}},	//   _चाले, लौन_, рэнд, итва,
   {{0x26c4d647,0x628bb159,0x26cfd07d,0x79840303}},	//   lemo_, zago, _zago_, _dwiw,
   {{0x5f9407d4,0x628bb15a,0xa954073c,0x5fc68021}},	//   жист, yago, іксі, लबिल,
   {{0x5f73ce40,0x60c3b15b,0x2cba0053,0xa3cc0db4}},	//   _باور, zenm, _ebpd_, लिज_,
   {{0x33584119,0x9f530036,0x2067431f,0x04675934}},	// [3610] ратэ_, ńców_, ађев, атем,
   {{0xd657c093,0x5fc68185,0x26118036,0x69cd0157}},	//   שימת_, लबाल, _देगी_, _isae,
   {{0x7055001c,0xdce9c242,0x5238008c,0xdb020588}},	//   _دندا, speć, _مسیح_, stlå,
   {{0xb60680b3,0xf8c9c1c0,0xdb1ac1f1,0xa857c093}},	//   _opšć, _abẹ́_, _estú, ביבה_,
   {{0x6b6a8036,0x2732315c,0x7640802c,0x588740d7}},	//   _węgl, gány_, _cymy, _выба,
   {{0x6f1d315d,0xd006cdd8,0x3ea9629a,0x672dc011}},	//   hisc, _فل_, lgat_, čajm,
   {{0xb3a9c435,0x4394510d,0x60c387ba,0x7fd58097}},	//   _çıxı, _марс, renm, сілі,
   {{0xdb03c0fd,0x656fc5e5,0xaacf8285,0x61e9f15e}},	//   munë, ícho, _सोचक, txel,
   {{0x6d41f15f,0x63a54056,0x6abb80eb,0x7640802c}},	//   tlla, luhn, _ibuf, _gymy,
   {{0x628d4010,0xf99f00c4,0x2eedc0d9,0x5fc2a64d}},	//   haao, drè_, sjef_, _वैकल,
   {{0x7d1c3160,0xdab9c0d7,0x6d41c02c,0x88bcc047}},	//   virs, _былі_, rlla, mněl,
   {{0x7c38127d,0x7ae2c68a,0x6ef84019,0x7980c112}},	//   _øvri, _gnot, _líbr, _ịwec,
   {{0x7d1c3161,0x69d9c00d,0x290169d4,0x7cfd8016}},	//   tirs, _urwe, kkha_, _aèri,
   {{0x973d0570,0x463ac052,0xa3ab846d,0xdb03c4c9}},	//   ruća, _גענע, कंप_, stnä,
   {{0x3f9ec5c7,0xf1bf455d,0x69c9eb2f,0x2907c17a}},	//   crtu_, _apá_, lwee, _ilna_,
   {{0x0e664bd9,0x33393162,0x387f406f,0x62961f6a}},	//   скан, cosx_, _đura_, _udyo,
   {{0x9c828039,0x69c9e224,0x6fd5c09d,0x68f54138}},	// [3620] ščia, nwee, धिवं, _bozd,
   {{0x6aa9c0fa,0x7cfd8303,0xdb074107,0x291c04c9}},	//   hgef, _fèri, rtjá, _öva_,
   {{0x69db8303,0xdb1ac166,0x4aa7c103,0x33d500d9}},	//   _arue, _vstú, _गांव, _діят,
   {{0x273c99a9,0xbea681c3,0xa3ab81f9,0x6561b163}},	//   víns_, садк, कंन_, _ailh,
   {{0xe5a38b65,0x6b45c018,0xd041c080,0x7f42843e}},	//   зичи, rógl, rdlə, rloq,
   {{0x2fcc8004,0x76408066,0x7f447164,0x973d0158}},	//   _psdg_, _vymy, lliq, mrće,
   {{0x6aa9e026,0x07a353f4,0x69c9c14d,0x2a698011}},	//   fgef, _нарн, ewee, žaba_,
   {{0x7bda8066,0x7986442c,0x79a6d8c8,0x273c8004}},	//   _vrtu, _kwkw, брое, ríns_,
   {{0xb606004f,0xa20683bf,0xdb02001e,0x3eb38080}},	//   nišč, _упад, culé, əxt_,
   {{0xd8e6c858,0x6f1d117b,0x2d498004,0x69c08085}},	//   сцип, wisc, lúen_, _ipme,
   {{0x26d21d96,0x248e8010,0x7bda4043,0x201e3165}},	//   _bayo_, mafm_, _štuj, útil_,
   {{0x7ae2c073,0x68e3c17b,0x6f02b166,0x25a040e5}},	//   _unot, _ennd, nkoc, kril_,
   {{0x644180cb,0x644d8020,0x66e5ce1a,0x26d23167}},	//   _zyli, ƙaic, कारक_, _dayo_,
   {{0xee37c0b4,0xf99f0157,0x4ad90045,0x6b73c0cc}},	//   _унч_, rrè_, _बोरव, _săge,
   {{0x26c680b3,0x0eb1281d,0xf1bf5e6f,0xa2d40926}},	//   keoo_, _झापड, _spá_, _बोक्,
   {{0x7af601ff,0x7ae43168,0x798200eb,0x249f091a}},	//   _goyt, _gnit, ọwag, şum_,
   {{0xa3d6c17e,0x644fc036,0x7bce7169,0xa3ce00a0}},	// [3630] सिव_, ęcie, _asbu, _míří_,
   {{0x8319401c,0x25a6b16a,0xd3788123,0x6abb8157}},	//   _چقدر_, duol_, _zrće_, _sbuf,
   {{0x25bfb16b,0x6f0340b4,0xaca340eb,0x2c194926}},	//   _spul_, _înco, _nyục, _येशू_,
   {{0x25a06e1a,0xe81206ff,0x753ac0fc,0x141a00c3}},	//   bril_, _डेटा_, hotz, _כותב,
   {{0x2bd10b6d,0x6569834d,0x14de0048,0x753ac0fc}},	//   हिका, _queh, _फोडण, kotz,
   {{0x4fb4016a,0x20110157,0x7bce405e,0xd366c7ce}},	//   _بصیر, ozzi_, _fsbu, _يه_,
   {{0xf53f1127,0x2d49803c,0x46aa04ef,0xaaaa0d22}},	//   mråd_, búen_, _कालह, _कालक,
   {{0xdb021305,0x65618d7f,0x6f0d716c,0x69dd4570}},	//   pulé, _wilh, nhac, _krse,
   {{0x26d200e1,0x2d9e0064,0xae16808f,0x9c7c8013}},	//   _rayo_, ątek_, _देऊन_, _inčn,
   {{0x161f8285,0x34948887,0xdb074041,0x88bcc047}},	//   _मेयर_, _наур, ltjä, lněj,
   {{0x2907c089,0xb606004f,0x657bd664,0x764d316d}},	//   _vlna_, zišč, spuh, _azay,
   {{0xc7d640c3,0x25a09dd6,0xf2df40d1,0xbdf8c08c}},	//   קורי_, šile_, _khâu_, _گرما_,
   {{0x7ae40185,0x6729c7a7,0x753ac140,0x7642c0bc}},	//   _vnit, mnej, botz, _gyoy,
   {{0xb606004f,0x6b57c044,0x6f09802c,0x6f0287a7}},	//   višč, _ụgha, _llec, zkoc,
   {{0x614319b1,0x4421cd4d,0x6d454040,0x46f640d9}},	//   фера, _äh_, dlha, очат,
   {{0x69dd4011,0x98acc007,0xb4e68036,0x25a0716e}},	//   _brse, rodą_, _बच्_, tril_,
   {{0x88bcc047,0x13a68705,0x6f029775,0x8d760e5f}},	// [3640] dněj, _गम्भ, vkoc, _بابا,
   {{0xb60612b8,0x6f0989a5,0x98a34156,0x7bc1b16f}},	//   rišč, _alec, дифе, _oplu,
   {{0x6f0d44f8,0x0b5a81f0,0x9f4c6bd4,0x6299c036}},	//   bhac, арды_, ádó_, _odwo,
   {{0x290cf170,0xb6038066,0xe73a8051,0x09e64119}},	//   zhda_, _omáč, шее_, _домн,
   {{0xdce08156,0x291ed1a4,0x7ae640a8,0x6445809d}},	//   _numă, yita_, _inkt, ühin,
   {{0x6ea7c185,0x6563f10e,0x628bdae9,0x9c874089}},	//   _गाउँ, _ninh, _aego, ručí,
   {{0x7bdc4232,0x6f09b171,0x656bc05e,0x95f4c564}},	//   _urru, _flec, _augh, ेन्ट_,
   {{0x76441ca7,0x6563c1a8,0xe7378f27,0x628bc50e}},	//   _oyiy, _ainh, _дес_, _cego,
   {{0x80d3c02a,0x628f3172,0xd1328183,0x76440396}},	//   তান্, vaco, _قمر_, _nyiy,
   {{0x628284d2,0xe8d90044,0x6563c09c,0x7d1a80c2}},	//   lboo, _kwụ_, _cinh, _umts,
   {{0xbcfb4004,0x3959c016,0x753ac0fc,0xa2d5c163}},	//   _quéi, ïssa_, rotz, _मोक्,
   {{0x62829e52,0x61e2006c,0x656bc0c4,0x539b40c3}},	//   nboo, _šola, _fugh, סיכו,
   {{0x3eb9143b,0xdb03c02d,0x7644084f,0xdce6456e}},	//   rfst_, ytnú, _cyiy, _aukč,
   {{0x7ae640fd,0x81c2402a,0x657d3173,0x973d0011}},	//   _ankt, ্মা_, rpsh, pućo,
   {{0x368b53a8,0x29030ae6,0x6443dc6b,0x291cc449}},	//   исан_, rkja_, _gyni, _imva_,
   {{0x3eaf40cb,0x2b4680b4,0x63a8c04f,0xa2a514aa}},	//   ügt_, jloc_, mudn, _काट्,
   {{0x628281c8,0xbcfb4070,0x95cb401b,0x764d3174}},	// [3650] dboo, _muév, шува_, _uzay,
   {{0x69dd4570,0x61ed41c8,0xaa7b402d,0x60c8c0f8}},	//   _vrse, rxal, _iným, nedm,
   {{0xf53f1127,0x656d3175,0x88bcc0a0,0xdb0744c9}},	//   rråd_, _huah, tněj, ttjä,
   {{0x656d012c,0x2d498018,0xf53f0ded,0x2d4bc0d9}},	//   _kuah, túeo_, sråd_, jøen_,
   {{0x69cf7176,0x6f1d4032,0x25708321,0x88bcc047}},	//   _usce, _imsc, _càl_, rněj,
   {{0xddc9c570,0xdb0207fb,0x62828149,0xe9df455d}},	//   jceš, stlø, aboo, _irú_,
   {{0x628bc10b,0x7b03454a,0x656bc8e5,0x07a588a9}},	//   _pego, _nõuk, _sugh, чайн,
   {{0x212140b3,0x16168036,0x656f801e,0xe8a80185}},	//   lihh_, _देकर_, _écho, _कञ्च,
   {{0x25a94093,0x1ddbc09d,0x91b0c0d1,0x3b0dc13b}},	//   nual_, बिधत, _đại_, rheq_,
   {{0xa3b8801c,0x61e6c588,0x973d11ae,0x628bc75d}},	//   _ژانر_, åkla, sućl, _wego,
   {{0x68f8c077,0x68fccbdc,0x656bc0eb,0x78bb06f0}},	//   _dovd, örda, _wugh, đuvl,
   {{0xdb23c1aa,0x27f8c041,0x672b94bc,0x673d013b}},	//   _توصی, ärna_, nngj, gosj,
   {{0x316d8815,0xdddbd5d8,0x14ac4048,0x6d470043}},	//   _juez_, lauž, _चालण, flja,
   {{0x6d4709b7,0x7989828d,0x24913177,0x76440024}},	//   glja, _mwew, gazm_, _vyiy,
   {{0xdee64661,0x8c42c291,0x9f5e4047,0x0442c43e}},	//   пови, _пеше, ští_, _пешн,
   {{0xe9df56e7,0x7d06d09c,0xea8a0dbe,0x9bfac0c3}},	//   _brú_, ūkst, _убил_, _להצט,
   {{0x80cec079,0x44441866,0x69dbc019,0x63a38089}},	// [3660] ়ার্, _wy_, nvue, hrnn,
   {{0x7bde0011,0xd24f4032,0xb92540eb,0x2905c98f}},	//   _trpu, انك_, mkpụ_, nkla_,
   {{0xe9df402e,0x09b7c02a,0x929dc036,0xf2128112}},	//   _erú_, জিটা, zkła, pọkọ,
   {{0x25708060,0x69c400f6,0xb17b4329,0x2bdcc1e2}},	//   _pàl_, _kpie, _dråb, यिता,
   {{0xda16809d,0x2b468157,0x4973884e,0xe804054a}},	//   _देखत_, rloc_, еліс, रनका_,
   {{0x6282b178,0xfe6f405f,0xed574051,0xe80ec047}},	//   sboo, _لگے_, _ноя_, ानमा_,
   {{0x60c8c6a9,0x68f8e4e7,0x6d5883ad,0x27954f67}},	//   vedm, _rovd, rmva, _оштр,
   {{0x290e8150,0x63a8c854,0x6b5193f6,0x7766417a}},	//   shfa_, vudn, tåge, _jikx,
   {{0x673d3179,0x7afdd368,0xdbcbc30d,0xceb34052}},	//   vosj, östa, dóñe, גיח_,
   {{0x290af17a,0xf7788085,0x6aa84045,0x80ca402a}},	//   óba_, _erħa_, गलुर, রাক্,
   {{0x7bdc02bc,0xc059811b,0x7af9c085,0x25a9717b}},	//   jvru, _дії_, _fowt, zual_,
   {{0x973d0011,0x6d4180a0,0x7d1e2e91,0xb34741ff}},	//   mućk, _zkla, _amps, _maçô,
   {{0xcb13c21d,0x7b2c403a,0xc54a0112,0xceb38323}},	//   _אלף_, rğul, _áhị̄, עיש_,
   {{0x291cc00d,0xd3788123,0xa3bc717c,0xed590007}},	//   _umva_, _zrća_, _अहं_, įžo_,
   {{0x8c41c0fa,0x88bbc0c3,0x94bbc0c3,0x38cbd006}},	//   ößte, _המוז, _המות, _دانی_,
   {{0xaefb45ef,0x61e08061,0xa3c240e6,0xdb058397}},	//   _giùl, _orml, ्बन_, sthú,
   {{0x6f0d2dc4,0xfe7043a9,0xdb0201ff,0x63a38089}},	// [3670] _ilac, ادف_, bulâ, zrnn,
   {{0x63aa82bc,0x26c006f0,0x6f0d0b7e,0x98b340cc}},	//   kufn, _zbio_, _hlac, doxă_,
   {{0xe4edc444,0xf6d580d9,0x7bdc8107,0xd011554f}},	//   जाति_, діля, _áruh, خلا_,
   {{0xd49180d1,0x7bc500f7,0xa3d3ee7e,0x200f4062}},	//   _còn_, _iphu, _सैफ_, ągi_,
   {{0x6d4180b3,0x49744f94,0x29cd46f0,0x60d54138}},	//   _pkla, _пляс, _uža_, _tazm,
   {{0x7b1600b3,0x69dd009d,0x657d717d,0x656f468a}},	//   nšur, ivse, _itsh, _iuch,
   {{0x32020066,0x2246c44e,0x442544c9,0x7af9c036}},	//   zyky_, _ayok_, _äl_, _powt,
   {{0x290c8fb3,0xa3da4027,0x68e88065,0xe3b24009}},	//   _elda_, ़िर_, _endd, _שױן_,
   {{0xf1e04d22,0xc27c40c3,0x657b8398,0xdcf608f1}},	//   नियन, זרחי, _utuh, _styč,
   {{0xa2bdc1e7,0xdb03f17e,0x2ee9317f,0x7bc5000b}},	//   _वॉर्, muní, _anaf_, _ophu,
   {{0xbcfb446a,0xa6ca0883,0x1eca02fd,0x629d4272}},	//   _hués, олна_, олни_, _odso,
   {{0xeab0c032,0xdb020070,0x2905c089,0x7cfd8303}},	//   _معه_, pulí, skla_, _tèrs,
   {{0x672d7180,0x656f4431,0x7afbb181,0xdce3c0f6}},	//   dnaj, _nuch, _mout, _jinċ,
   {{0x672dc41b,0xcb6a20a1,0x333fd7cd,0x7afbb182}},	//   čaju, жаве_, loux_, _lout,
   {{0x98acc047,0xdbcbc004,0x5043001d,0x2f23c1c0}},	//   hodě_, póñe, верб, _gègè_,
   {{0x628f7183,0x333fc1cb,0x7dd84107,0x26cb00b9}},	//   _ceco, noux_, júsá, ceco_,
   {{0x65677184,0x14ae8048,0x9c148112,0x05664bd9}},	// [3680] _bijh, _घालण, _tọgz, дван,
   {{0xc0a94032,0x51f70107,0x26170bc0,0x6da358ed}},	//   كامل_, _آسٹر, _पेटी_, тифа,
   {{0xd259c017,0x75238157,0x6d5c03ad,0x3eb34025}},	//   meņu_, dinz, mmra, äntö_,
   {{0x333ff185,0xa2bdc028,0x464a8b24,0xaac10419}},	//   joux_, _वॉल्, озен_, ष्पक,
   {{0x2fc58033,0x6d48c086,0xddcd40cc,0x80bb06fc}},	//   _aplg_, ylda, rcaţ, श्वे,
   {{0x26c240b9,0x6d46c0a0,0x75238024,0xddcd4379}},	//   _hbko_, ůkaz, ginz, scaţ,
   {{0x656f5a76,0x66044107,0x3b0a80b4,0x6602a117}},	//   _zuch, lyik, _дево_, syok,
   {{0xb90586fc,0x70ca0c13,0xdd9ac01f,0x26cb00d2}},	//   _बो_, ाजुल, ошо_, xeco_,
   {{0xd1b382cf,0x88c580a0,0x6f0d005e,0xf7728107}},	//   _لینک, _směř, _rlac, راں_,
   {{0x7523b176,0x29078041,0xbebb111b,0x28c00ae7}},	//   cinz, ckna_, giën, श्मि,
   {{0x26cb01f1,0xdb0ac041,0x6d48c4c9,0x2b4941c8}},	//   teco_, ttfä, rlda, ylac_,
   {{0xa3df4eec,0xdce2c02d,0x2572c02c,0xe283c119}},	//   तित_, _uvoľ, _tâl_, _алци,
   {{0x2768c2cf,0x8af0403a,0x33200396,0x2911006f}},	//   _کشتی_, rməl, _dmix_, thza_,
   {{0xdb0ad073,0x23c28036,0x200180cb,0xab94c6b1}},	//   stfä, _शहाद, ähig_, _закљ,
   {{0xb065cc99,0x27390066,0x25a68bd7,0x9c7cb186}},	//   rjää, zény_, hrol_, _ančk,
   {{0x80bf0045,0xe6670244,0x656f7187,0xae1a409d}},	//   _लॉरे, _отпо, _puch, _नइखन_,
   {{0x443f0064,0x75239415,0x7e6d3188,0xdd9443d0}},	// [3690] łu_, yinz, _igap, каты,
   {{0x22490c47,0x25a6815a,0x7ae9b189,0x63a54089}},	//   _iyak_, drol_, _snet, trhn,
   {{0x6d4500f7,0xa295431e,0x2b4940d2,0x35f8016a}},	//   _ikha, _пані, plac_, _فرید_,
   {{0x60c1807a,0x80bb157c,0x798d0faa,0xe0cf402a}},	//   _sblm, श्रे, _kwaw, রাইভ,
   {{0x752395e0,0x7e6d0006,0xaac10036,0x31794009}},	//   tinz, _mgap, ष्यक, _מאָד,
   {{0x26d9438f,0x2c0ec033,0x7afbb18a,0xabd59025}},	//   _haso_, ानां_, _wout, ециј,
   {{0x8c429124,0x644882cd,0x5ed2402a,0x6568801c}},	//   леше, _cydi, হারে, _didh,
   {{0x61e2f18b,0x64488039,0xbcfb401e,0xd1bb8032}},	//   _brol, _dydi, _guér, _واذا_,
   {{0x333ff18c,0x1d3580c5,0x65689bea,0xc8b5cc38}},	//   roux_, _зная, _fidh, нсны,
   {{0x2d8d80eb,0xb4ce0314,0x3f688189,0x6568b18d}},	//   _iwee_, _रसे_, _uğur_, _gidh,
   {{0xbebb0b32,0x6b5f0017,0x6e2940e5,0x644fc062}},	//   riën, _lūgu, _žebl, ęcio,
   {{0x2d8d80eb,0xbebb02a4,0xa3c24a39,0x290edcc6}},	//   _kwee_, siën, ्बत_, _elfa_,
   {{0x61e2c127,0x52abc036,0x0d84d8d5,0xaa07c7ce}},	//   _grol, छलीस, _алін, _تظاه,
   {{0x23d3839a,0x7bd54036,0xe81ac0aa,0xe7c3802a}},	//   _दनाद, _oszu, _फेका_, ্মীয,
   {{0x1be710fc,0x2d99318e,0x3b0a06b1,0x764980bb}},	//   ндри_, asse_, _неко_, _lyey,
   {{0xdb020c5e,0x8c1ac0c3,0x798d00f6,0x6e24c026}},	//   bulá, _מוצי, _fwaw, _žibi,
   {{0x2d8d8094,0x05aa4c34,0x26d9718f,0x237f4011}},	// [36a0] _nwee_, явай_, _daso_, _čuja_,
   {{0x69d63190,0x973d0013,0x26d94545,0x66164062}},	//   _isye, vući, _easo_, rzyk,
   {{0x68fc5fc6,0xcd020064,0x29290166,0x1ee8405f}},	//   _vord, ęść_, ýtať_, _ہوگی_,
   {{0xa96a423f,0x6b560257,0x25adc450,0x65688729}},	//   _нима_, lágb, kuel_, _sidh,
   {{0xfe79c0a0,0x6568b191,0xd6d98062,0xd4918104}},	//   dců_, _pidh, _dał_, _bè_,
   {{0x6146406f,0x7aebf192,0xb17b4041,0xb4bc809d}},	//   _чега, _angt, _krån, ेजे_,
   {{0x25a6a7a8,0x3ea000b6,0x6568b193,0x764980bb}},	//   srol_, _odit_, _vidh, _eyey,
   {{0x61e2d599,0x3ebfc077,0x26c043fe,0x973d0077}},	//   _prol, gfut_, nfio_, pući,
   {{0x764980bc,0x95ef0a3c,0x68fe014d,0x6448b194}},	//   _gyey, _चपेट_, _oopd, _wydi,
   {{0x62967195,0x61fdd40b,0x7e6d05ef,0x644884f5}},	//   hayo, äsla, _sgap, _tydi,
   {{0x2418d09b,0x69d61232,0x61e40ec5,0xb3e98032}},	//   фоны_, _asye, _aril, _يعمل_,
   {{0xaadf40aa,0xbebdc026,0x6b9c4127,0x1dd480e9}},	//   _पोंक, liūn, _mvrg, _धनात,
   {{0xaca441c0,0x26d950a1,0x60dab196,0xdb0207fb}},	//   _ayọr, _raso_, _katm, kulæ,
   {{0xbebdc007,0xdb03c066,0x2005c109,0x60da85b2}},	//   niūn, muná, byli_, _jatm,
   {{0xe9ff8015,0xb4becb6d,0x35a6ca3c,0x26c07197}},	//   _khảo_, ुजी_, _खिड़, ffio_,
   {{0x798d2dd2,0xa3df4314,0x2249002f,0x7b03409d}},	//   _twaw, तिस_, _tyak_, _nõut,
   {{0x6ca74889,0xa2b68185,0x31720303,0xa0a740b4}},	// [36b0] ереж, ैभन्, _guyz_, ешел,
   {{0x629640f8,0x6d45000b,0x6b45f198,0x6362c25d}},	//   aayo, _ukha, nógr, _ọnla,
   {{0xa3c5054a,0xe7e3c09d,0x2d8d821b,0x61e40123}},	//   _एहि_, गिया_, _swee_, _zril,
   {{0x644acc4b,0x5d8402f0,0x7aff01d6,0x6d5e5738}},	//   _myfi, _جلیل, _joqt, ampa,
   {{0xfe79c047,0x0ab481f7,0x60daaff8,0x644af199}},	//   vců_, احمد, _batm, _lyfi,
   {{0x6722c1c0,0xbb854032,0xe4a74de7,0x6b9acc19}},	//   _amoj, _للسي, _ярмо, kstg,
   {{0xe5344051,0x7aed319a,0x58948032,0xe4e44589}},	//   _серь, _onat, اجهز, _сіян,
   {{0x7aed319b,0x6b560107,0xe9ff80d1,0xb88380a0}},	//   _nnat, zágb, _chảo_, _svíč,
   {{0x61e4c032,0x26cf8036,0x6f0340b4,0xaefb468a}},	//   _áill, mego_, _încu, _ciùi,
   {{0xeb0e42ea,0xdce3c3aa,0x62966444,0x60da814b}},	//   _सत्त_, _tinč, zayo, _gatm,
   {{0x61edc007,0x62965494,0x25adf19c,0xa3da4036}},	//   _šald, yayo, suel_, ़िए_,
   {{0x660618be,0x644af19d,0x8af04080,0x7aed0321}},	//   tykk, _dyfi, rmək, _cnat,
   {{0x60da8189,0x6d5e4786,0x3f9cc0bc,0xfe70c20c}},	//   _yatm, ympa, _evvu_, _ادم_,
   {{0x66061b59,0x6b45c004,0x7aed1b33,0x26cfb19e}},	//   rykk, cógr, _enat, hego_,
   {{0x644ac02c,0xfaff40b1,0xad9b0107,0x25764397}},	//   _gyfi, _boë_, nyúj, _sæl_,
   {{0x26cf8064,0x63ae0089,0x2127835d,0x6b560107}},	//   jego_, rubn, hinh_, ságb,
   {{0x16664547,0x6455440d,0x26c041f4,0x68fe319f}},	// [36c0] твам, _azzi, rfio_, _topd,
   {{0xb17b4041,0xdced4080,0x7986c0eb,0x776bc073}},	//   _trån, rpağ, ̣kwo, _ligx,
   {{0xdbcc4004,0x69c9802e,0x60da8472,0x2127800c}},	//   _póña, _apee, _ratm, dinh_,
   {{0xc6a39ee9,0x799bd96e,0xdb1e6ece,0xec3700c3}},	//   арши, ksuw, _espò, _יאיר_,
   {{0x31bdc7a5,0x6455440d,0x6d4e31a0,0x60dab1a1}},	//   ्बोध, _ezzi, olba, _patm,
   {{0xdfd24107,0xa3df484d,0x3f5741cb,0xa3e4c0e9}},	//   _پير_, तिश_, rçue_, निम_,
   {{0xdb0740a0,0x68ee40f6,0x273c8089,0x20078107}},	//   zují, _inbd, zíny_, gyni_,
   {{0x95d8d637,0x9405c03a,0x9f584854,0xdb1c8963}},	//   едит_, qalə_, byrå_, _spræ,
   {{0x799bd17e,0x261a8047,0x224780b4,0xb0b2017e}},	//   gsuw, _मेची_, _апти_, _जांग,
   {{0xdb0740a0,0xddcb0026,0xdb03c56e,0x2bc94a7c}},	//   vují, šiūn, runá, _रहमा,
   {{0x6f00b1a2,0x2b4dc011,0x3fa586b0,0xd6cfc3e1}},	//   _komc, blec_, _مصنف, _кт_,
   {{0x6b9ad19e,0x6d4e207b,0x7626c0b4,0xb226c025}},	//   rstg, elba, _имез, _имел,
   {{0x83341045,0x26c6c031,0x644ac14b,0x79a705f5}},	//   рнях, _iboo_, _wyfi, ърне,
   {{0xaca4c112,0xfbcfc01c,0xdb0581cb,0x273c8089}},	//   _kpọz, حتی_, rrhé, ríny_,
   {{0x61e64007,0x39430017,0xd9180051,0xdb0740a0}},	//   _arkl, rojs_, тья_, sují,
   {{0x4734428a,0xfcd9405f,0xa5c6c031,0x7bcac449}},	//   ансс, کارڈ_, _gbóó, _ipfu,
   {{0xba55401b,0x2fd84024,0xaa55401d,0x6d5a80d2}},	// [36d0] увај, _asrg_, уваш, _ohta,
   {{0x6d438140,0x39145065,0x68ee405e,0x3ce28c5c}},	//   xona, амур, _cnbd, _टोले_,
   {{0x6d43805f,0x2effae77,0x61e2af36,0xf1bf0cc6}},	//   vona, _pouf_, evol, ltá_,
   {{0x224b4041,0xe7e3cf92,0x98ba4017,0x2c000185}},	//   _tyck_, गिता_, ropā_, रहरू_,
   {{0x29010ecd,0x61e64242,0x3f9e804f,0x6d5a805e}},	//   _koha_, _grkl, _avtu_, _bhta,
   {{0x68ee4053,0xf99f40ce,0xe3b342f0,0x621a44e0}},	//   _gnbd, _ivè_, _پرس_, _טורק,
   {{0xb4c1414a,0xf3678979,0xf8b2421d,0xdcfb86f0}},	//   ्जी_, _атан, _לשם_, _utuč,
   {{0x2ca98080,0xdce3c8f1,0x6b588cc6,0x21278104}},	//   şad_, _pinď, tíge, sinh_,
   {{0x3947c0c9,0x6289f07b,0x7e7bf1a3,0x20078086}},	//   _pkns_, rbeo, rcup, syni_,
   {{0x7c3a80f6,0x28c66acf,0x973d0013,0x14c64a91}},	//   _fxtr, र्पि, kućs, र्पण,
   {{0x764d1833,0x799bc0e2,0x28ab4062,0x95fe0062}},	//   _ayay, ssuw, _चयनि, ॉन्ट_,
   {{0x24980372,0x4a74c119,0x764d0536,0xd8388119}},	//   warm_, _кышт, _byay, _рэу_,
   {{0xe5a5c604,0x6da5dd10,0x29010066,0xdb020fd0}},	//   _сили, _сила, _boha_, ktlö,
   {{0xf487cff8,0x9d560e40,0xdce3c017,0x764d00b6}},	//   _рудн, انست, _finā, _dyay,
   {{0x6609c05f,0xfaa6530c,0x3ea24b0e,0x3945c975}},	//   lyek, лаво, _pdkt_, mols_,
   {{0x25bfc0b4,0x224d80b9,0x7d018127,0x61e67186}},	//   otul_, _oyek_, _lols, _prkl,
   {{0xecea71a4,0xceb4403a,0x224d8537,0xee3a442d}},	// [36e0] ндал_, rgə_, _nyek_, хна_,
   {{0x98a78007,0x26ddc0f7,0x94078080,0x61e28157}},	//   monė_, _lawo_, sanə_, vvol,
   {{0x94bb0093,0x7afbd254,0x66e680c1,0x20565e4d}},	//   _אמית, kjut, ложа, утар,
   {{0xd6d980d9,0x25798565,0xd5ba800a,0x60dc5ffb}},	//   кті_, _bèl_, еск_, _warm,
   {{0xdb090018,0x6729f1a5,0x69d9cf2d,0x212a06d3}},	//   xudí, diej, _nswe, oibh_,
   {{0x26dde8c3,0xdb1c8041,0x661bc0b3,0x6f034119}},	//   _aawo_, _sprä, dzuk, _încr,
   {{0x26ddf1a6,0x6299b1a7,0x6aa40157,0x7982c2a8}},	//   _bawo_, bawo, _odif, _stow,
   {{0xf1bf0089,0x7afbcfb7,0x656e405e,0x6aa41677}},	//   ytá_, gjut, _hibh, _ndif,
   {{0x80c14c8c,0xb114cf27,0xe9ff80d1,0x25798b94}},	//   र्वे, имиш, _thạo_, _gèl_,
   {{0x7d018085,0xd90ec05f,0x69d9c053,0x7ddb04c9}},	//   _gols, ثیت_, _dswe, _läså,
   {{0xdb1e80fd,0x7528f1a8,0x61e471a9,0x629631aa}},	//   jtpë, ridz, hvil, _beyo,
   {{0x41e6c49f,0x2d498019,0x6d4560b4,0x656e71ab}},	//   _مستف, búes_, zoha, _libh,
   {{0x644e40e2,0x26d24848,0x6aa401f4,0x629600b6}},	//   _lybi, deyo_, _ddif, _deyo,
   {{0x272b00b6,0x3076c244,0x14c671ac,0xf1bf31ad}},	//   _bònè_, _судс, र्मण, rtá_,
   {{0xe47bc093,0xd4980441,0x26ddf1ae,0x644e4655}},	//   _ארוכ, ыря_, _yawo_, _nybi,
   {{0xfe734a2c,0xdce74013,0x6d454f4f,0xa3e85cfa}},	//   صدر_, _vijč, woha, बिन_,
   {{0x29010056,0x2bdcc4d8,0x6f02c43e,0xdb020136}},	// [36f0] _toha_, यिका, _mooc, ttlö,
   {{0xd257c0c3,0xe8d9425d,0x92686012,0xb4c14bc0}},	//   רשמה_, kpụ_, урса_, ्जे_,
   {{0x656e429a,0xdb020402,0x69c0c09d,0xa87a00c3}},	//   _dibh, rtlö, htme, _באתר,
   {{0x61e44511,0xdb020fd0,0x69c0c98f,0x8c644798}},	//   bvil, stlö, ktme, студ,
   {{0x39a79924,0x25bfc0b4,0x26c9012c,0x6d454230}},	//   ушев, xtul_, _mbao_, poha,
   {{0xfce59d5e,0xdce88053,0xa2bd44fb,0x7b21c1cb}},	//   роко, _fidč, शभक्, nœuv,
   {{0xd7e4513b,0x2d84806a,0x5fc94549,0x611446b1}},	//   _літо, _etme_, _रहिल, _удру,
   {{0xbddb4141,0x3eb9f1af,0xdc0f00a0,0x628d4104}},	//   _fyèt, üst_, _něče, nbao,
   {{0x6d4731b0,0x3945f1b1,0xdb18c047,0x3f9ef1b2}},	//   koja, tols_, ctví, estu_,
   {{0x26c9017b,0x6729cf59,0x6445809d,0x61e99aad}},	//   _abao_, siej, ühis, _irel,
   {{0xb17b4300,0xf99f03bc,0x6aa7c079,0x69cd1c15}},	//   _bråk, syèl_, ক্ষো, _apae,
   {{0x69d9c396,0x232a0acf,0xb17b4854,0xe7b6c632}},	//   _tswe, томи_, _isåf, _अमरप,
   {{0x4cdf002a,0xda1dc5da,0x28c644fb,0x6b85026b}},	//   মানু, _बेचत_, र्डि, _athg,
   {{0x361ac323,0x73e5d702,0x98a0841b,0x61e98303}},	//   _בונד, _вокз, đić_, _mrel,
   {{0x61e98010,0x6e3d4303,0x1e964119,0x96964c4d}},	//   _lrel, _axsb, ирар, ираш,
   {{0x3947801e,0x644e5e83,0x656e4c42,0x60de2f99}},	//   hons_, _rybi, _sibh, _wapm,
   {{0x8af04435,0x2903467d,0x6b56005f,0x394a405c}},	// [3700] dmət, _boja_, lágo, _pkbs_,
   {{0x7d03c3db,0x6d470019,0x399b01f2,0xa5a7425c}},	//   _jons, coja, _שייד, _चिरौ,
   {{0x60c30107,0x26d271b3,0x7bc1f18c,0xdb0200b2}},	//   _önma, peyo_, ntlu, stlõ,
   {{0x25ad0166,0x644e4089,0x99924036,0x7c3e0085}},	//   šele_, _vybi, rzył_, _ixpr,
   {{0x98a3003f,0x7bc1c54a,0xd24f801c,0x6b5d0107}},	//   lijā_, htlu, ونم_, ségg,
   {{0x2fcc8018,0x6f02c1c8,0x61e9899e,0x644e415a}},	//   _ppdg_, _sooc, _drel, _tybi,
   {{0x98a3003f,0xeb9749cd,0x81cc002a,0x6b5d00dd}},	//   nijā_, _вис_, রটি_, lége,
   {{0x7bdaa056,0x25a98120,0x61edf1b4,0x2ee00396}},	//   _vstu, šala_, _šala, _naif_,
   {{0x6d471549,0xf8c6664d,0xb997c039,0x3f688189}},	//   yoja, र्थय, авых_, _oğuz_,
   {{0x30a3c11b,0x57b4c051,0x7ae098e2,0x63ae1188}},	//   орюв, ббот, _hamt, krbn,
   {{0x3f9ef1b5,0x8af04080,0x7ae299a2,0x6c34c032}},	//   ustu_, nməs, odot, صفحا,
   {{0x645ab1b6,0x6b828112,0xf53f0d27,0xdce9817a}},	//   _izti, _ọgwa, pråk_, _iweġ,
   {{0x9c7c806f,0x661d0047,0x5507042d,0xef118052}},	//   _tačd, uzsk, ачва, פּט_,
   {{0x7ae09355,0x2d86f1b7,0x00000000,0x00000000}},	//   _lamt, _itoe_, --, --,
   {{0xb17b4673,0x7ae2b023,0x6b560018,0x68fcc09d}},	//   _tråk, kdot, cágo, ördu,
   {{0x212cc5ef,0x27ed551a,0x5b1444df,0x6d4731b8}},	//   lidh_, _čen_, омст, soja,
   {{0xaefb4321,0xdef8459d,0xdcfd4017,0x24984206}},	// [3710] _biùr, шыр_, _atsā, _berm_,
   {{0x3f78006f,0x6abbb1b9,0xaefb4321,0xf48753a4}},	//   _očuh_, _scuf, _ciùr, руан,
   {{0xd7fb10a1,0x39460032,0xaefb429a,0x4ac6c314}},	//   _руп_, _íosa_, _diùr, लभाव,
   {{0x7ae0821b,0x6b5d0b01,0xa3ea81f9,0x28c480e6}},	//   _camt, légb, मिन_, ल्सि,
   {{0x26cb4022,0x6d48c631,0x6b56005f,0x4aa88f37}},	//   _ibco_, koda, zágo, ркін_,
   {{0x672d5937,0x29c2800c,0x1c06c027,0xe1648032}},	//   liaj, _dưa_, शहाल_, يدوي,
   {{0x8352805f,0x6b560019,0x237840f6,0x2d86c2c0}},	//   _کھلا, xágo, _gurj_, _atoe_,
   {{0x7ae08039,0x28380093,0x3947abd3,0x7ae2b1ba}},	//   _gamt, ינוך_, sons_, cdot,
   {{0x752880b3,0xdb1e4041,0x6d48c1f4,0x51849a54}},	//   _fmdz, _uppå, foda, _духа,
   {{0xe8f9c53a,0x2ee02405,0x6b5607c9,0xddcd017b}},	//   уло_, _saif_, tágo, _eyaŋ,
   {{0x672d412c,0x60d531bb,0xf770805f,0x6282c0bb}},	//   kiaj, dezm, _راہ_, _ffoo,
   {{0x68e18535,0xfaff00fd,0x69cf4514,0x7ae0807a}},	//   _hald, gjë_, _opce, _xamt,
   {{0x290597a8,0x33290c53,0x5d85c1b4,0x6b56005f}},	//   _kola_, _dmax_, _التل, ságo,
   {{0x2f18c107,0x6d48f1bc,0x70b20048,0xc5f2c0c3}},	//   _vége_, coda, जलेल, _מדד_,
   {{0xb4c5c045,0x31d4825c,0x673b8044,0x6579c303}},	//   ॉजी_, _धन्ध, _ojuj, _huwh,
   {{0x69c2b1bd,0x25a040b2,0x691000b2,0xaefb4061}},	//   ytoe, tsil_, _käek, _siùr,
   {{0x63a3c17b,0x98a30017,0x171b00c3,0xaefb405e}},	// [3720] _hvnn, sijā_, _תופע, _piùr,
   {{0x2f154673,0xaa7b0574,0xaefb4321,0xd838c11a}},	//   _våga_, ndýn, _chùb, sače_,
   {{0x25a071be,0x23600022,0x845a4ae8,0xf7464081}},	//   ssil_, _khij_, урат_, _гено,
   {{0xf48701aa,0x6299c876,0x8af0403a,0x9b258187}},	//   _پایی, _newo, rməs, офіл,
   {{0xadc3400c,0x7ae08022,0x24984093,0x6d48f1bf}},	//   _thạc, _vamt, _term_, yoda,
   {{0xdd8f4032,0x614388ba,0xe0c7c032,0x629d31c0}},	//   _سوف_, печа, _عز_, zaso,
   {{0xf48740fb,0x6d4e40f1,0xd90d405f,0xe73a801d}},	//   _چاہی, _ikba, _جیل_, _бев_,
   {{0x69c464ef,0x61ebc247,0x212cc149,0x11d8c359}},	//   otie, _brgl, widh_, لوبة_,
   {{0x80df0079,0x629d31c1,0x2905b1c2,0xdca68ce0}},	//   মাত্, vaso, _fola_, _гази,
   {{0x6f0640e2,0xd3788011,0xdb020414,0x18a383a7}},	//   _lokc, _tuć_, hrlä, _наум,
   {{0x69c471c3,0x443e8004,0xd6d5109b,0x645a8017}},	//   htie, _uxt_, ожны, _uzti,
   {{0x6d48df53,0x6d4ab1c4,0x6f1bd138,0xa3e7017e}},	//   soda, lofa, chuc, पिस_,
   {{0x672d71c5,0xdcef4119,0x2bdac743,0xceb380c3}},	//   viaj, _jucă, _बनवा, היר_,
   {{0x2905010d,0xf7730032,0x777a80fc,0x973d0158}},	//   ðla_, كار_, _kutx, vrću,
   {{0xd7f81045,0x60d50141,0x6f0671c6,0x33290c7c}},	//   бут_, rezm, _bokc, _tmax_,
   {{0x7ae2c09d,0xe29f4397,0x6e2dc247,0x777ab1c7}},	//   _jaot, _boða_, _žabi, _mutx,
   {{0x6f1d0359,0x777a8545,0x69c44b68,0x3f9e0397}},	// [3730] mhsc, _lutx, gtie, átur_,
   {{0x2918405e,0x660f1fae,0x6d4a8011,0x7ae2c0b2}},	//   _clra_, myck, jofa, _laot,
   {{0x80cac048,0x2b5f800c,0xf2dc002a,0x680ac080}},	//   त्ये, _phuc_, ধারণ, qədd,
   {{0xa3aa4021,0xdcef40b4,0x6b58b1c8,0x3f874017}},	//   _गटर_, _bucă, sígn, īnu_,
   {{0x68e1b1c9,0x210d0048,0xdea44107,0xe5a58ce0}},	//   _pald, _सकाळ_, _ریلی, цили,
   {{0x777ab1ca,0x27ec805e,0xdb238107,0xd138c036}},	//   _butx, _brdn_, _کوری, jną_,
   {{0x6f1bd92a,0x2b5f800c,0x6b954062,0x6299c0ce}},	//   thuc, _thuc_, _uwzg, _pewo,
   {{0x6729b1cb,0xc9a9c0c5,0x61fbc0fc,0x2f189045}},	//   _umej, авие_, txul, _лось_,
   {{0x5bc9454a,0x290580fd,0x88d5c0d7,0x1994818d}},	//   _रहुव, _tola_, оўні, _натя,
   {{0xe616c026,0x53c9d6ea,0x929d8062,0x7bc571cc}},	//   юды_, агом_, _koło, othu,
   {{0x7d0771cd,0x23600022,0xe29f010d,0x6f1bf1ce}},	//   _mojs, _phij_, fað_, phuc,
   {{0xe29f0086,0x7bc571cf,0x6aa98085,0xba3b0206}},	//   gað_, ithu, _jdef, zaïe,
   {{0x7de7c01c,0x629f71d0,0xdb18c329,0x7bc571d1}},	//   _دسام, daqo, ftvæ, hthu,
   {{0x61e9c0f7,0x98a5c017,0x637780eb,0xddc98036}},	//   mvel, bilā_, _ụnya, _sześ,
   {{0x869a4c08,0x23600022,0x6f06405c,0x3ea900f6}},	//   итат_, _thij_, _pokc, _fdat_,
   {{0x6abbf1d2,0x6d4ab1d3,0x6ec104fb,0x6d5500a8}},	//   nguf, zofa, _वायु, alza,
   {{0x6d4a939a,0xd838c06c,0x61e9c4f1,0x69c471d4}},	// [3740] yofa, mača_, nvel, utie,
   {{0x3ebf8912,0x7ae440fd,0xdb058089,0x69c400f6}},	//   _acut_, sdit, vrhá, _iqie,
   {{0x6b5d001e,0x60c343bc,0x61e9c8a1,0x79898f2d}},	//   léga, ònma, hvel, _atew,
   {{0xd043c09c,0x61e9c7d0,0x657b81c8,0xd138c036}},	//   _wanɗ, kvel, _buuh, zną_,
   {{0x2d4f46ed,0xa3bbc036,0x6b5d001e,0x2240803a}},	//   gües_, इंड_, néga, çik_,
   {{0x45d94009,0xf1bf005f,0xd83886ab,0x2bd24384}},	//   _פֿרא, szág_, _leče_, _सहपा,
   {{0x798980bb,0x6f19c02c,0x7af603ad,0x7bc54104}},	//   _etew, _blwc, _onyt, cthu,
   {{0x2907c29a,0x3da6c0d9,0x65a380eb,0xd138c036}},	//   _aona_, ороб, _ọher, wną_,
   {{0x80c167c1,0xd138c036,0x6d4a812c,0x61e9f1d5}},	//   र्के, tną_, pofa, gvel,
   {{0x38cb84e8,0xad26c032,0x3ea05aae,0x2907ce12}},	//   _نامی_, تربو, hait_, _cona_,
   {{0x9c7c8043,0xc07b4009,0x62864011,0xbebb068e}},	//   _gača, יטיש, _ofko, diër,
   {{0x74ca4419,0x8cca4f76,0x68e3c127,0x3f6601cb}},	//   स्तृ, स्तो, _eand, _sœur_,
   {{0x63b8805b,0x224bc0fa,0x6aa0c033,0x63758007}},	//   luvn, ückt_, mamf, _išna,
   {{0x25fc0027,0x2b49c011,0x62844062,0x6e228247}},	//   _ऊपरी_, čace_, ecio, izob,
   {{0x7ae41d80,0x7bc54041,0x3ea0401e,0x7c220020}},	//   _fait, xthu, fait_, _ƙora,
   {{0xba3b0d4a,0xab280244,0x61e901e5,0xdb18d2ca}},	//   raïb, _моја_, åels, stvæ,
   {{0x59b200b2,0x3f574138,0xd8cb0186,0xdce70611}},	// [3750] _जियर, lçuk_, _кынд_, şlıg,
   {{0x29074086,0x3ebf80cc,0x28c64330,0x6abd070d}},	//   ðna_, _scut_, र्लि, lgsf,
   {{0x753ac0fc,0x7bc55994,0x98a30026,0x6aa0d4c4}},	//   intz, uthu, giją_, kamf,
   {{0x5ead0079,0x6441805c,0xdb074166,0x80cad3c4}},	//   ট্রে, _rxli, hujú, त्ते,
   {{0x823481aa,0x7d074046,0x5eb9c02a,0xdb07402d}},	//   ورها, _tojs, _আসলে, kujú,
   {{0x2db80093,0x9ccb823d,0xb97a40c3,0x80c14185}},	//   קלון_, рыда_, _לנשי, र्खे,
   {{0xdb074038,0x7bc731d6,0xd9a831d7,0x4809b1d8}},	//   dujú, ntju, _कट्ट, сейн_,
   {{0xd3d88032,0x3980c141,0xc7b24323,0x68e50025}},	//   تبها_, _bòs_, _רבן_, _lahd,
   {{0xb17b5539,0x6f1b8070,0x61e9c127,0x3980c061}},	//   _gråt, _iluc, uvel, _còs_,
   {{0x672d07cf,0x44b49349,0xe576c1c3,0x291ef1d9}},	//   _amaj, _обус, язь_, ghta_,
   {{0x2907f1da,0x26d906f3,0x7bc50046,0xdee60563}},	//   _vona_, feso_, _nqhu, пони,
   {{0x3980c3bc,0x629d71db,0xdb1c4066,0xdbd00066}},	//   _fòs_, _neso, ktrá, užív,
   {{0xee37011b,0x21a30051,0x657d4003,0x291ec510}},	//   зня_, ниям, _nush, bhta_,
   {{0x5fbf8185,0x3ea045e2,0xf1b9c013,0x68e3c150}},	//   _एमाल, wait_, muš_, _uand,
   {{0x657d40cb,0x69c631dc,0xf86311a0,0xd2590017}},	//   _aush, stke, евро, ļņa_,
   {{0xd764008c,0xbebb014b,0x672d0147,0x691000b2}},	//   _تنبی, siër, _gmaj, _näev,
   {{0x3b0742fd,0xb2bb0093,0xbebb0b43,0xc333021d}},	// [3760] чето_, _המפר, piër, _רוח_,
   {{0xb4d580b2,0x3ea214c1,0x9878c011,0x629d42ea}},	//   िजो_, lakt_, ršći_, _eeso,
   {{0xc04700d1,0x777c4149,0x6f028c5d,0x645e0411}},	//   _mượn_, _qurx, tjoc, _uzpi,
   {{0xdb0ac041,0x7d08804f,0xdddb8011,0xf7465027}},	//   ltfö, _sods, _sfuš, _хемо,
   {{0xaac10185,0x62860654,0x98a30007,0x5ea383be}},	//   ष्टक, icko, siją_, رمول,
   {{0x60224107,0xf8c00db4,0x3dc6b1dd,0xf80680d9}},	//   _címé, श्चय, rtow_, зчин,
   {{0x6e228107,0x6aa0f1de,0x629d400b,0xb4b84a3c}},	//   szob, tamf, _yeso, छली_,
   {{0xa6b5804c,0x7ae64b11,0xa686b1df,0x6d4e07f0}},	//   _осущ, _jakt, _хлад, hoba,
   {{0xba3b468e,0xdb07402d,0xdb0ac4c9,0x291ec13b}},	//   _geïd, tujú, ktfö, thta_,
   {{0xf55a81b4,0x6aa0db59,0x98a5c0b4,0x28cf43ae}},	//   _الطب_, samf, vilă_, स्पि,
   {{0x3f5931e0,0xdb1c71e1,0xf8b8c35d,0x7ae643ad}},	//   séum_, mtræ, ghĩa_, _oakt,
   {{0x290a71e2,0xc7b34093,0x6d5893bd,0xe0cfc1aa}},	//   _loba_, עבר_, llva, پزی_,
   {{0x6d58b1e3,0x612071e4,0x78a1f1e5,0xdb18c4c9}},	//   olva, _köld, balv, rtvä,
   {{0xdddbc119,0xe6c883b0,0x61e2eecb,0x98a78119}},	//   scuţ, रभुज, _isol, mină_,
   {{0x3d0d15a8,0x25b902bc,0xccf88047,0xd838c04f}},	//   _सकीं_, susl_, _mně_, mačo_,
   {{0x657d4346,0xd7bbc0c3,0x77640085,0x6d43404f}},	//   _push, _הצהר, _ghix, čnam,
   {{0x7b3caeb3,0x7bc703ad,0x68e531e6,0x657d59ba}},	// [3770] rčul, stju, _tahd, _qush,
   {{0x61edc9bd,0x673bdd0c,0xdb1c8036,0xe3b0005f}},	//   _šalk, znuj, _opró, ضرہ_,
   {{0x8af04080,0x6f09b1e7,0xdb0200d2,0x2b81c35d}},	//   mlən, _poec, culó, _xóc_,
   {{0x657731e8,0x5a3581eb,0x3d23c031,0x636380b2}},	//   _hixh, мнет, _kéwù_, kõne,
   {{0xfce5a8d3,0x06cc802a,0x61e2c1ae,0x798d00f6}},	//   доло, _রোহি, _nsol, _jtaw,
   {{0x798d012c,0xdb1c8032,0x6b560070,0xd6d9c036}},	//   _mtaw, _bpró, rági, weł_,
   {{0x78a1f1e9,0xa3d28169,0x7ae64138,0xd00680c5}},	//   valv, војч, _yakt, деще_,
   {{0x27f84066,0x6d588004,0x6b560070,0x68f8c0b9}},	//   šený_, alva, pági, _anvd,
   {{0x61ed71ea,0x7e7bb1eb,0x2d99dace,0x80ca4314}},	//   nval, _igup, èse_, स्वे,
   {{0x9c1380eb,0xb4ab4185,0xb6038089,0x6aad0449}},	//   _pọdk, _गयो_, _vláč, _adaf,
   {{0x68e771ec,0x7c24c020,0x78a38915,0x6d4e0247}},	//   _majd, _ƙira, manv, voba,
   {{0x61e2c0f6,0x4735d301,0x657f0073,0x98bc80a0}},	//   _fsol, _юнес, _buqh, kově_,
   {{0x78a1e112,0x7ae9c0ce,0xdb0ad044,0xaefb40d1}},	//   palv, mdet, ttfö, _phùn,
   {{0x28cf4f76,0xf8cec00c,0x26cdc019,0x3d23c031}},	//   स्मि, _hứng_, lfeo_, _déwù_,
   {{0xdb0ade9d,0x3ea201d4,0x5894c1b4,0x69c9f1ed}},	//   rtfö, pakt_, _أجهز, ltee,
   {{0x7e7ba31a,0x680ac03a,0xdb0acbdc,0x799bb1ee}},	//   _ngup, qəda, stfö, _owuw,
   {{0x68e741d6,0x7ae9f1ef,0x6365c004,0x6aa280c4}},	// [3780] _bajd, idet, mónd, vaof,
   {{0x7ae9c04c,0x6d4e284c,0xc05a4a66,0x3ea01154}},	//   hdet, qoba, орец_, _heit_,
   {{0x68e742bc,0x04460623,0x46ea8844,0x336655f3}},	//   _dajd, _ценн, жден_, _овог,
   {{0xaca38094,0x6d418077,0x61ed4017,0x7ae671f0}},	//   _faịl, _ajla, bval, _uakt,
   {{0x60dac03a,0x63bc31f1,0x056a801d,0x2f1c4171}},	//   yetm, lurn, ојки_, _gíga_,
   {{0x7ae9ef26,0x28cfc8b8,0x69c9c09d,0x291831f2}},	//   edet, त्मि, dtee, nkra_,
   {{0x61e4017b,0x2bddf1f3,0x60dc31f4,0x61204086}},	//   _lsil, _फैला, ierm, _völd,
   {{0x7ae9f1f5,0x8cca40c6,0x3ea01686,0x26c04eb9}},	//   gdet, स्रो, _neit_, ngio_,
   {{0x6b8dc011,0x81d6c02a,0x61e4017b,0x60dadd21}},	//   _čaga, ায়ন_, _nsil, tetm,
   {{0x60dc00d9,0x78a38580,0x5edbc02a,0x7d0ac0fd}},	//   jerm, canv, ভাগে, _qofs,
   {{0x3d0201e7,0x34b74093,0x69c9f1f6,0x290c8010}},	//   शाने_, ופים_, atee, _ioda_,
   {{0x7bc8c353,0xdbd9410b,0x3ea00321,0xaefb4321}},	//   rtdu, cçõe, _ceit_, _chùl,
   {{0x6aa085ba,0x290cb1f7,0x61e4005f,0xf506c09b}},	//   _memf, _koda_, _csil, _оздо,
   {{0x68e8a5b8,0x60dc1ae0,0x6aa0875d,0x7e62efd1}},	//   _jadd, germ, _lemf, _izop,
   {{0x5bdc8419,0xead56a1b,0x36d54381,0x7b3cb0e9}},	//   _मनोव, новь, новр, rčuj,
   {{0xdb0580da,0x290c97cf,0xadc3c1c0,0x69c80119}},	//   rshë, _loda_, _apẹj, ăder,
   {{0xd567076b,0xf1bcc02a,0x8d794032,0x6722b1f8}},	// [3790] _отоп, _অনুভ, سماء_, dhoj,
   {{0x60dc31f9,0xa91d9208,0x7bcaa4e7,0x6f0d213c}},	//   cerm, _kuže, ktfu, _hoac,
   {{0x7ae9d2ea,0x63bc0070,0x656f80c4,0x2d8d8140}},	//   ydet, curn, _èchi, _stee_,
   {{0x26dc0009,0x81d5c02a,0x69c9c051,0x38b541c0}},	//   ַקומ, হিত_, ytee, _bùrà_,
   {{0x195983d0,0x61e4005c,0x16168d20,0xa1598401}},	//   пады_, _xsil, थनगर_, паду_,
   {{0x25a94776,0x02dc0185,0x41bc00c3,0xf1b20036}},	//   msal_, _बस्न, קצוע, _जिसन,
   {{0x3f8131fa,0x6aa0b1fb,0x442555db,0x7e62c073}},	//   _juhu_, _femf, _ål_, _azop,
   {{0x2616408f,0x645f8080,0xc2c5c032,0x290c80b9}},	//   पैकी_, əqil, ريخي, _eoda_,
   {{0x3219c066,0x3ea031fc,0xee39c297,0xdbd9410b}},	//   ásy_, _reit_, яни_, rçõe,
   {{0x4425c2ad,0x69c9f1fd,0x6578c024,0x3d0e009d}},	//   tzl_, rtee, _civh, _हवें_,
   {{0xed59c0b3,0x7afbb1fe,0x25a942d6,0xdbd9401f}},	//   juže_, _knut, hsal_, pçõe,
   {{0xe2972599,0xa91d80e0,0x8c1a4093,0xed59c7ca}},	//   наю_, _duže, פורי, duže_,
   {{0xaca34112,0x09cd8079,0x2d800070,0x7ae9a316}},	//   _ayọc, লিকা, _quie_, _maet,
   {{0x5cd504c5,0xafe61065,0x7f5bf1ff,0x8d65cac2}},	//   кісх, ногл, lluq, _явле,
   {{0xf484c259,0xb4abc048,0xc0528052,0x6a76806a}},	//   _ручн, गणी_, ָזן_, _küfü,
   {{0x8af0403a,0x66e34259,0x6b81b200,0x29183201}},	//   lməz, лоса, _mulg, skra_,
   {{0x0566512e,0x377541dc,0xf772c052,0x62967202}},	// [37a0] еван, тырс, רקן_, rbyo,
   {{0x69100025,0x2ca5db0e,0x30bdc02a,0x69cb8414}},	//   _väes, nald_, _অসুস, dtge,
   {{0x06e30079,0x7980af12,0xdb1c4851,0x25a940f8}},	//   যারি, _sumw, tträ, asal_,
   {{0x291e8b0e,0x6f0d0004,0x06b20079,0x7980802f}},	//   _slta_, _xoac, ট্রি, _pumw,
   {{0x78a1b203,0x3ce0c914,0x2bd244fb,0x2ca5c211}},	//   _belv, _कसले_, _सहवा, kald_,
   {{0x2b405a65,0x6722b204,0x628be775,0xdb1b013b}},	//   lnic_, shoj, _afgo, tutë,
   {{0x9d43694e,0x69cbb063,0xf0930093,0xbebb00fd}},	//   _серд, atge, ננה_, dhën,
   {{0x2d827205,0x290c8036,0x7980a531,0x67244077}},	//   _kuke_, _woda_, _tumw, nhij,
   {{0xb14686d7,0xa3e85142,0x68e8b206,0x3ea4f01e}},	//   _знал, बिक_, _tadd, ramt_,
   {{0xf1b34626,0xa91d813f,0x3ea6802f,0x3ea27061}},	//   נסת_, _puže, laot_, _lekt_,
   {{0x6e95009b,0x313740c3,0xdb1c413b,0x7e6400c2}},	//   кину, תנים_, gurë, _azip,
   {{0x8c1b8093,0x25a941c8,0x3f574016,0x7659c1f4}},	//   _מובי, ysal_, nçut_, _fywy,
   {{0x7d0e40f8,0xfba48db4,0x298b00c5,0xdb1b0089}},	//   _oobs, _गौतम, ясно_, nuté,
   {{0x64568080,0x657a817a,0xd90ec107,0x26ddb207}},	//   əyir, _jith, _چیک_, zewo_,
   {{0x8af0403a,0x657ab208,0x3957c093,0x6026c01e}},	//   lməy, _mith, _רשום_, _démé,
   {{0x61180696,0x3df50d0d,0x612201cb,0x60c844c9}},	//   _ağlı, _азис, _rôle, _ödmj,
   {{0x3ea6871c,0x645a8007,0xdcfb8011,0x8af04080}},	// [37b0] daot_, _lyti, _suuč, nməy,
   {{0xf9900032,0x7afb8854,0xe6ddca39,0x28d8425c}},	//   _ابي_, _snut, _मस्ज, ड़गि,
   {{0xe8df40d1,0xf1bf034d,0xc43502f0,0x0fdc85a8}},	//   _ngục_, luá_, _شکست, _मनगढ,
   {{0x2b406934,0xcda801aa,0x26c6c046,0x2c0e0260}},	//   cnic_, _تهیه_, _ncoo_, ठहरू_,
   {{0x7aed40b4,0x6124c0b6,0xdbdd0031,0x7afb87cb}},	//   mdat, _gòlg, _háàp, _vnut,
   {{0x7c87804c,0x81d6c079,0xbc38001c,0x29c980ae}},	//   худе, াটা_, _آسیا_, rúa_,
   {{0x29c9819d,0x2ca5e4f5,0xbebd90aa,0x22958032}},	//   súa_, vald_, _plūd, _للأس,
   {{0x2ca5d0fe,0x78a180bf,0x63b84166,0x6b884070}},	//   wald_, _welv, ávne, _édga,
   {{0x7aed4580,0x64488060,0xe969c93f,0xbebb00fd}},	//   idat, _exdi, маил_, thën,
   {{0x7aed6313,0x2ca34085,0x6289c359,0xf99f4053}},	//   hdat, _jejd_, sceo, _mwè_,
   {{0x765b8033,0x28c6516e,0x69cd4f4c,0x6d40129d}},	//   _hyuy, र्टि, htae, émam,
   {{0x3f8346f0,0xfaff40fd,0xdb1c40fd,0x25de0c5c}},	//   _muju_, _shën_, rurë, गबली_,
   {{0x6f09c451,0x7aebc329,0x3ea24127,0xb4cd048b}},	//   mjec, _iagt, _rekt_, रभू_,
   {{0x2bd24027,0xaca3c044,0x3ea27209,0x7aebf20a}},	//   _सहला, _kpọk, _sekt_, _hagt,
   {{0x3f83401c,0x61e28064,0x2b40720b,0x98a30f21}},	//   _nuju_, zwol, tnic_, рисе,
   {{0x93435045,0x3a3f4123,0x7aebf20c,0xf99f43bc}},	//   ансе, _župa_, _jagt, _bwè_,
   {{0x2b40720d,0x6d41f20e,0x3ea2411b,0x0683720f}},	// [37c0] rnic_, onla, _vekt_, ргун,
   {{0x6d41f210,0x2a7f805e,0x3f834011,0xb17b0041}},	//   nnla, _agub_, _buju_, svår,
   {{0x765b80e2,0x2b40404f,0xb90a4c4b,0xf99f4303}},	//   _ayuy, pnic_, _मस_, _ewè_,
   {{0xee3aaec6,0x61e2a69d,0xdce3c054,0x69d9c0bf}},	//   мне_, twol, _minđ, _opwe,
   {{0x98a78f66,0x201c42bc,0xdce3c123,0x3ea680f8}},	//   linę_, švi_, _linđ, raot_,
   {{0x9c7cb211,0xdb1b0070,0x25bff212,0x41538589}},	//   _kači, ruté, duul_, авіс,
   {{0xb8dab213,0xec77458f,0x6363854a,0x97a38007}},	//   _आए_, _апр_, sõna, арыл,
   {{0x9c7c8f9e,0xdb1b001e,0x7aebc1c8,0xd7f7802b}},	//   _mači, puté, _cagt, туш_,
   {{0x61e450fe,0x2d92017b,0xdb1c47b0,0xcf77e34e}},	//   nwil, _ntye_, guré, خصوص_,
   {{0x657a8353,0x2ca78119,0x7bce3214,0x61e440cb}},	//   _uith, cand_, ktbu, iwil,
   {{0x2369023b,0x9182000c,0x33750221,0x3949803c}},	//   _phaj_, yện_, лгор, éase_,
   {{0x9c138d0c,0x61e47215,0x6124c3bc,0x7aed415d}},	//   _kọnk, kwil, _sòld, xdat,
   {{0xfb1bc0c3,0x7ae0f216,0x58d4f217,0x2b46802d}},	//   _קודמ, memt, _болт, čoch_,
   {{0x69c0c1c6,0x7aed4303,0x7ae0ea42,0x7bce03ad}},	//   mume, wdat, lemt, ftbu,
   {{0xb4bec4ae,0x6b560c5a,0x78a7289b,0x443ac09d}},	//   इली_, rágr, rajv, _äp_,
   {{0x69cd404c,0x2ca7b218,0x7aed40c4,0xb4df8036}},	//   ttae, zand_, udat, _तस्_,
   {{0x3f8353e1,0x26c93219,0x61edc018,0x69c0de2c}},	// [37d0] _suju_, _icao_, _áalt, nume,
   {{0x69cd40fc,0x31c44267,0xd138cf59,0xd499011b}},	//   rtae, јств, nią_, _якої_,
   {{0x6d55011a,0x69c0f21a,0x2ca7b21b,0xa91d87ef}},	//   moza, hume, vand_, _nuža,
   {{0x3cfe85b2,0x2ca7a746,0x6f1d321c,0x69cd4359}},	//   _antv_, wand_, nksc, ptae,
   {{0x2249806a,0x6d58c06c,0x4ac608b8,0x6eba40c3}},	//   çak_, _okva, _वासव, _אזרח,
   {{0x6722c30d,0x3ea948f6,0x18698b5d,0xa06984b6}},	//   _aloj, laat_, нали_, нала_,
   {{0xdce1805e,0x888242cf,0x6120721d,0x3866409c}},	//   _chlā, _ایمن, _köln, ƙora_,
   {{0x3ea94e76,0xa6e5f21e,0x6e29ee56,0x2ca7b21f}},	//   naat_, ужил, tzeb, sand_,
   {{0x7aebc0b0,0x80ca44d8,0x6b83e2ac,0x6d553220}},	//   _vagt, स्के, _sung, koza,
   {{0x3ea97221,0xeb99d5a4,0xaefb45ef,0x6d41c340}},	//   haat_, нио_, _dhùi, unla,
   {{0x7aebf222,0xc1d04185,0x9815c1aa,0x2d84b223}},	//   _tagt, _सङ्ग, ابخا, _zume_,
   {{0x212f0112,0x2ca580c3,0x3ea97224,0x2d84835d}},	//   _įgha_, _held_, jaat_, _yume_,
   {{0x629be468,0x69d9c2c0,0x7aed0149,0xef170025}},	//   mbuo, _upwe, _daat, умя_,
   {{0x2f18c05f,0x6722c0b3,0xfaff40fd,0x98a78039}},	//   _régi_, _zloj, _anë_, tinę_,
   {{0x7aed3225,0x9c7cc11a,0x201e1f98,0x765d4141}},	//   _faat, teče, áti_, _aysy,
   {{0x61e44295,0x69db846a,0x777d4018,0x543ac009}},	//   twil, _opue, _cisx, _רעקא,
   {{0x7bce197c,0x777d4018,0x16666a11,0x8cc48045}},	// [37e0] stbu, _disx, увам, _रालो,
   {{0x9c7cc13f,0x3f858051,0x61e45263,0x645c7226}},	//   seče, _oulu_, rwil, _pyri,
   {{0xeb9a4441,0x25e5c064,0x657c404c,0x27220443}},	//   хие_, _जैसी_, _virh, _zóna_,
   {{0xa91d80ab,0x7bc1c0b4,0x6363809d,0x60db0077}},	//   _ruža, iulu, sõnn, đume,
   {{0x35b6888c,0x68e1f227,0xfdf40285,0x2c784639}},	//   ущес, keld, इटिस_, dždž_,
   {{0x5f26402a,0xe9738182,0xe505544e,0x96d045cb}},	//   _যদিও_, مهند, राणि_, ड्रॉ,
   {{0x186750fc,0xfaff40fd,0x67243228,0x68e1ed5d}},	//   _бари_, _ynë_, _olij, deld,
   {{0xdc08003f,0x2d84b229,0x6d58eb73,0x63bac011}},	//   dēļa, _tume_, _skva, vrtn,
   {{0x2ca580cb,0x7ae0f22a,0xdb0af22b,0xd9f641f9}},	//   _feld_, remt, nsfé, ीमित_,
   {{0x7ae2b22c,0x680ac03a,0x295681bc,0x8af0403a}},	//   leot, lədi, _събр, sləh,
   {{0x6d5500e0,0x315742a6,0x7b15c7c9,0x7986722d}},	//   voza, ריין_, _cáus, _lukw,
   {{0xa91d829f,0x6da6c8b5,0xd24fc1aa,0x6d551950}},	//   _južn, _бида, _کنه_, woza,
   {{0x25adf22e,0x3989c031,0x7986484f,0xa2d908b8}},	//   csel_, _gús_, _nukw, _फॉण्,
   {{0x2727454a,0xf0e8010e,0x98a78047,0x53c4c036}},	//   _mõne_, льск_, dině_, लंदश,
   {{0xceb4403a,0xc7b8010e,0x56951575,0xdbe30004}},	//   rkən_, лёт_, _кайт, téñe,
   {{0xf207622e,0x6724015d,0x3e0740c5,0x6d55322f}},	//   лязо, _glij, лязв, soza,
   {{0x7986409c,0xdb1b0066,0x6d43802c,0x2f1544c9}},	// [37f0] _cukw, nutí, ynna, _sågs_,
   {{0x7b15c070,0x2abb4171,0x60c54022,0x798641c6}},	//   _jáur, _bàbà_, ughm, _dukw,
   {{0x60c5405c,0x7aee4051,0x3ea971a9,0x7d1a0041}},	//   rghm, öntä, paat_, ötse,
   {{0x61207230,0x25adf231,0x8f9a0093,0xd9f08021}},	//   _höll, ysel_, _שירי, चिंत_,
   {{0xa3e5456c,0x3f85a959,0x61207232,0x69360017}},	//   _बैर_, _sulu_, _köll, zņem,
   {{0x7bc1f233,0x25adc253,0x1fb5927f,0x61e9b234}},	//   yulu, vsel_, асир, _vsel,
   {{0x2af50027,0x629bc556,0x6341c017,0x6d57443e}},	//   इयाँ_, tbuo, lēni, moxa,
   {{0xdc2101b7,0x63a10038,0x6d5a8d66,0x78a77235}},	//   _aċċe, álny, _ekta, _hejv,
   {{0x629bc039,0xfba50b08,0xaa45ce03,0x68e1ebbf}},	//   rbuo, गीतम, репл, teld,
   {{0xdb1c436b,0x69dd421b,0xdbde8397,0x62880047}},	//   strø, _mpse, _tíða, ědom,
   {{0x2a691514,0x225f93e1,0x67240514,0x236d823b}},	//   _azab_, _hyuk_, _plij, _khej_,
   {{0x2498c9d7,0x8503809d,0x657e00f7,0xe73a3236}},	//   ırma_, लावट_, _siph, тем_,
   {{0x68e1f237,0xe3c78079,0xd838c97c,0xe5a5c157}},	//   peld, _শনিব, daču_, _тили,
   {{0xa96a0c1b,0x629d002f,0x291ec041,0x29130fc2}},	//   тига_, abso, ckta_, _coxa_,
   {{0x68e3b238,0x398b8586,0x7f5b80f7,0x225fb239}},	//   iend, _løs_, _okuq, _lyuk_,
   {{0x6724323a,0x96ba2151,0xc3234748,0x645e0066}},	//   _ulij, _руку_, омск, _vypi,

   {{0xb5fb4031,0x2ca7f23b,0x9c7cc011,0x225f8303}},	// [3800] _ayáb, _kend_, meča, _nyuk_,
   {{0x7f4440fd,0x645e180e,0xba3b4b32,0x9c7cc3aa}},	//   sniq, _typi, _geïm, leča,
   {{0x7aef52c5,0x06868466,0xc6a688b7,0x7ae2a8d6}},	//   _fact, аген, арли, teot,
   {{0x7c4440b3,0x661bc11c,0x3f87c086,0x50d20045}},	//   _čurć, kyuk, _munu_, द्रष,
   {{0x680ac080,0x7ae4723c,0x4c948910,0x3f87c17b}},	//   rədi, meit, билс, _lunu_,
   {{0xa91d86f0,0x7bc3b23d,0x661bc340,0x7f5b80f7}},	//   _dužo, funu, dyuk, _ekuq,
   {{0x753af23e,0x50435201,0x398b8b9a,0x98b100cc}},	//   vitz, _дерб, _eøs_, liză_,
   {{0x753aeb83,0xdb021da9,0x2bd9c5da,0x272ac35d}},	//   witz, nslä, यौछा, _mùng_,
   {{0x5506c5d7,0x272ac00c,0xa534c119,0xcd06c5e6}},	//   ачна, _lùng_, йнич, ачни,
   {{0xdb1c4815,0x776d0149,0xd838c0ab,0x33d6811b}},	//   durí, _shax, začu_, _відт,
   {{0x25ec8a3c,0xb8cec39a,0x2ba6c036,0x6d58b23f}},	//   _आईडी_, _ओज_, _कौशा, mova,
   {{0x612b009d,0x69c47240,0x3f87cbc2,0x78a8b241}},	//   _külg, kuie, _dunu_, _hedv,
   {{0x8d94c1b4,0x6d4541f4,0x3eab3242,0xfd578031}},	//   _التش, ynha, ract_, _abaṣ,
   {{0x3f87c123,0x80aa4045,0x753dc107,0x62840140}},	//   _funu_, टरफे, észt, _egio,
   {{0x93881892,0x92a744ee,0x61206026,0x0b881201}},	//   иста_, ијал, _völl, исти_,
   {{0x78a8b243,0xfaff00fd,0x6e2d7244,0xdb020041}},	//   _ledv, rmës_, tzab, gslä,
   {{0x26db0022,0x7bde0115,0xe0eac031,0x7bc38526}},	// [3810] _ibqo_, _eppu, _gbòò_, zunu,
   {{0x68e385c2,0x3958146e,0x6b8884f1,0x32094c64}},	//   xend, cors_, _oudg, rxay_,
   {{0xee87509b,0xaefb429a,0x6e2d4107,0x656e405e}},	//   _выго, _bhùt, szab, _dhbh,
   {{0xe505439a,0x85054027,0x6f02c112,0x256f409d}},	//   राहि_, राहट_, _nnoc, külg_,
   {{0x8af04080,0x67f04107,0xeef801f2,0xdc3c00f6}},	//   tləv, tójá, ימאר_, _iġġa,
   {{0x6aad60f9,0x6d473245,0xa2d90045,0x36df4112}},	//   laaf, nnja, _फॉस्, _ịpụọ_,
   {{0xd37b80b4,0x60da00b2,0x29034073,0x6729d9a5}},	//   _ача_, õtmi, _inja_, thej,
   {{0x0ae9ea1b,0x850550de,0xd105505d,0x6d5c4047}},	//   удий_, रावट_, रावण_, _zkra,
   {{0xa19488a9,0x661d0065,0x673d011b,0x6d4725b6}},	//   _матч, jysk, disj, knja,
   {{0x6729c91f,0x6f02f246,0x3ea9049a,0x8af0403a}},	//   shej, _enoc, _aeat_, llət,
   {{0x6aa9b247,0x61fb82bc,0x7bc57248,0x9c7ccf47}},	//   _keef, _hrul, nuhu, teča,
   {{0x2ca7c14b,0x6d470820,0x272ac0d1,0x3958014b}},	//   _wend_, enja, _rùng_, wors_,
   {{0x753dc0fb,0x39583249,0xc588c015,0x7981b24a}},	//   észs, tors_, _hồn_, _kilw,
   {{0x6d470077,0x61e9f24b,0xf992c093,0xb226c10d}},	//   gnja, mwel, _צרו_, svæð,
   {{0x61ed283d,0x7d1cc508,0xd838806c,0xc795c5a7}},	//   _esal, örse, _peči_, _اشتب,
   {{0x3958324c,0x8699665b,0x6aa9b24d,0x79819216}},	//   sors_, итут_, _neef, _lilw,
   {{0x39580b04,0xc588c0d1,0xdb021521,0x95c9001b}},	// [3820] pors_, _lồn_, gslå, _куќа_,
   {{0x6d58a3ff,0x63b84166,0x6b894077,0xdca65562}},	//   xova, ávno, _čegr, сажи,
   {{0xe73a5707,0x7e608dc5,0xb53ac009,0x94184080}},	//   _бен_, _symp, נגעש, _yerə_,
   {{0x6aad565c,0x6d48006f,0xdb03c4c9,0x9980402d}},	//   caaf, čdau, nsnä, dziť_,
   {{0x69c62c04,0x61ed005c,0xad9b41c0,0x7981b24e}},	//   nuke, _xsal, _arúf, _bilw,
   {{0xc588c0d1,0x9f98a1ab,0x612b0526,0x7ae6324f}},	//   _bồn_, авку_, _güld, hekt,
   {{0x25bfc0b4,0x69c62efe,0x74164de9,0x61fb817b}},	//   erul_, huke, _اوزا, _erul,
   {{0xbc1b4093,0x61fb80c4,0x3ea051a7,0x63bec11b}},	//   _גולש, _frul, nbit_, _åpni,
   {{0xe9a38afa,0x673d00d9,0x3f827250,0x799bc010}},	//   _натп, visj, _miku_, gpuw,
   {{0x6d5e0044,0x8c468f93,0xa2c10891,0x50469d7c}},	//   _nkpa, _лезе, _वाङ्, _лезб,
   {{0x415b4052,0x673d3251,0x2cacc02c,0x25bfc0cc}},	//   רדיג, tisj, radd_, arul_,
   {{0x2bdd809d,0x67228efa,0x395a70cd,0x3f8a471c}},	//   _महता, nkoj, hops_, _mubu_,
   {{0x5eab002a,0x3f8a7252,0xad9b41c0,0x69c617bd}},	//   _কাদে, _lubu_, _irúg, guke,
   {{0x661d0036,0xdb1c7253,0x7e62f254,0x6722b255}},	//   rysk, ktró, _iyop, hkoj,
   {{0x7ae61f41,0x653bc093,0x61ed005c,0x3f8a4449}},	//   bekt, _תעוד, _wsal, _nubu_,
   {{0x26c94a93,0xa91d8514,0x69c62736,0xdb1b010b}},	//   ugao_, _ružm, buke, butá,
   {{0x6aa9ae0e,0xdb24005f,0x3f8240fd,0x9f604107}},	// [3830] _reef, _írás, _diku_, írás_,
   {{0xd131078a,0x3f8a4230,0x612b091a,0xaefb45ef}},	//   _آمد_, _bubu_, _büle, _chùr,
   {{0x1aec002a,0x68e73256,0x3ea07257,0x68e54025}},	//   টারে_, mejd, bbit_, rehd,
   {{0x01c940fb,0x9df99229,0xcf93c009,0x68e54051}},	//   _پوسٹ_, инет_, לטע_, sehd,
   {{0xbddb46ed,0x79818033,0x80c4939f,0xf389c0d1}},	//   _exèr, _pilw, _राखे, _nản_,
   {{0x3f8240b3,0xad9b402e,0x27958244,0x9c7cc6ab}},	//   _ziku_, _arúg, ошир, večn,
   {{0x7bd50e07,0x8af04435,0x3d0cc036,0x25a6c0f8}},	//   ntzu, mlər, ़ाने_, _awol_,
   {{0x672d4813,0x61fbb258,0x25bfc119,0xd8388011}},	//   nhaj, _trul, trul_, _neču_,
   {{0x2d8365d5,0x3eadc240,0x61fb4242,0x6124c060}},	//   _kije_, raet_, _šulj, _còlo,
   {{0x3eafafb0,0x6f1603e9,0x2d837259,0x69c6325a}},	//   lagt_, _soyc, _jije_, vuke,
   {{0xd8388351,0x64414514,0x25bfc056,0xe7dd8028}},	//   _beču_, _žlij, srul_, _महिप,
   {{0xdb1b0089,0xdb1c47cb,0x61ef4359,0x7d05035d}},	//   tutá, kurá, _oscl, _anhs,
   {{0xa2cc8575,0x1d09c01b,0x6d894166,0xfe7f6db7}},	//   _हास्, _вели_, _uľah, _maïs_,
   {{0x6d5aed59,0x80e80079,0x69c6011b,0x7f5bc01f}},	//   cota, গঞ্জ_, ruke, louq,
   {{0x3ea0725b,0x69c600f7,0x290593f1,0x2d8b725c}},	//   tbit_, suke, _mnla_, _auce_,
   {{0x2b494daf,0x6f040e83,0xa3bb017e,0x5f7605a7}},	//   gnac_, _unic, _घिर_, _باتر,
   {{0x3f82410d,0x612b325d,0x2d8b4020,0xb0c98048}},	// [3840] _viku_, _süle, _cuce_, _रांग,
   {{0x63718240,0xf5074119,0x673b8ca0,0x6b8415d4}},	//   hånd, онул_, _amuj, _hiig,
   {{0x3f6a4bfc,0xc616d32e,0x753e41a8,0x67298591}},	//   _вино_, _तथ्य_, ripz, _blej,
   {{0x57ccc009,0x6d5c185f,0x27f88086,0x3eab4085}},	//   רמאַ, lora, _árni_, _gect_,
   {{0x6d5ac150,0xc33302a6,0x7d17003a,0x59f88119}},	//   yota, ווא_, _yoxs, селя_,
   {{0x6d5c18de,0x3f8a40f6,0x67298107,0x6d5ac0fc}},	//   nora, _tubu_, _elej, xota,
   {{0x6d48c211,0x26ddc17b,0xa2da8036,0x4fc684c5}},	//   vnda, _bbwo_, नभद्, іска,
   {{0x3a3f4123,0x7af6725e,0x2d83725f,0x3f82c086}},	//   _župi_, ndyt, _zije_, öku_,
   {{0x7e643260,0x628d8570,0xc878c138,0x7afdb261}},	//   _nyip, žaoc, meği_, _ósta,
   {{0x01d0002a,0x7af64051,0x37e6b262,0xa3ce4045}},	//   িবাদ, hdyt, _мозг, _शमा_,
   {{0xe61f4015,0xab2aca66,0x0e8ec25d,0x2fc7b263}},	//   _ngôn_, _кожа_, _dịrị_, cung_,
   {{0x78a20077,0xc878c06a,0x5694009b,0x2bdbc75b}},	//   _đova, neği_, мают, _बहरा,
   {{0x2cac805f,0x6d4a9e70,0x201ec007,0xee840c38}},	//   _kedd_, onfa, syti_, дыро,
   {{0x7e6400f8,0x7983c0f8,0x3f8481ae,0x3eab6616}},	//   _dyip, _ginw, _limu_, _sect_,
   {{0x2d8b7264,0x656fc01e,0x5f941efa,0xc588c0d1}},	//   _suce_, îche, дист, _mồm_,
   {{0x28dd48bc,0x29187265,0x9f4cc032,0x2cac80d9}},	//   न्नि, _aora_, _ardú_, _ledd_,
   {{0x8af04435,0x5a355aec,0x6d5c0129,0x7983c0e2}},	// [3850] tlər, чнат, bora, _yinw,
   {{0x61e2d80c,0x9967411e,0xecc98285,0xf389c0d1}},	//   _mpol, італ, _राइफ, _xảo_,
   {{0xf7708de9,0x2d83413b,0x3f84b266,0xea98825d}},	//   چان_, _vije_, _bimu_, _ịhụn,
   {{0x80cd895e,0x68e8c1f4,0x2d8b4242,0x25a906df}},	//   _साहे, hedd, _tuce_, _kwal_,
   {{0xfa964087,0x68e8cb1f,0x80d86008,0xe5a58293}},	//   _מדרש_, kedd, न्हे, чили,
   {{0x61ed724a,0x7bc8eebc,0x2bdbc61a,0x68e8c0d9}},	//   mwal, kudu, _बहला, jedd,
   {{0x0e8ec112,0x68e8c2cd,0xb8868086,0xc4d244e0}},	//   _rịrị_, dedd, _svíþ, _רגל_,
   {{0x69c28fd7,0xa3bbcd20,0x673b800d,0x753c5bee}},	//   broe, ेंस_, _umuj, _zmrz,
   {{0xad9b402d,0x68e8c02c,0x6abbb267,0x6aabc3ff}},	//   _hrúb, fedd, _iduf, _vegf,
   {{0xa8a78a55,0x3f8c8031,0x81dcc02a,0x81e5402a}},	//   _фрак, _fudu_, ডিং_, পটপ_,
   {{0x2d858044,0x09e1c079,0x3f85801e,0xd91c40c3}},	//   _iile_, বিধা, _élus_, יוזל,
   {{0xd343c0fb,0x7b1cc018,0xf7720865,0x68f555d8}},	//   _تفصی, _déus, عاد_, _lazd,
   {{0x6130054a,0x7ed4c78a,0xa159c31e,0x3eada7a5}},	//   _jälg, _آزما, _ладу_, _meet_,
   {{0x6df2c032,0x6f19e68d,0x3dc94010,0x25e0c3fc}},	//   _أكوا, _howc, duaw_, _कहती_,
   {{0x7f5d0019,0xfaa64911,0x2d9fc070,0x6aad3268}},	//   bosq, забо, lpue_, _feaf,
   {{0xfaff00da,0xed59c7ca,0x2b9180d1,0x8af04080}},	//   llën_, duži_, _mác_, tləq,
   {{0x6365c019,0x68f57269,0x7bc38347,0x25a900e2}},	// [3860] góni, _bazd, hrnu, _gwal_,
   {{0xd00f005f,0x6d5c326a,0x69c283b3,0x79850f2d}},	//   خلہ_, qora, vroe, _gihw,
   {{0x799b81ae,0x2ec7c17e,0x6ee180eb,0x64a35027}},	//   _atuw, _रफ़्त, _ịbaw, хаха,
   {{0x3f8cb26b,0x69d64c05,0x6f19c157,0x2cacb26c}},	//   _rudu_, ptye, _nowc, _sedd_,
   {{0x2918726d,0x68e8c1ae,0x61ed400b,0xc878c06a}},	//   _tora_, yedd, cwal, reği_,
   {{0x3f8cb26e,0x672bc086,0x2d85b26f,0xadf2cb35}},	//   _pudu_, _algj, _cile_, _अनबन_,
   {{0x7bc38158,0x81ce4079,0x236680ab,0x9c7c9bee}},	//   grnu, _শনি_, ploj_, _obče,
   {{0x68e8d8e5,0x7b1cc2cb,0x973d1530,0x93fb0093}},	//   wedd, _réus, opće, מלצי,
   {{0x61fbc078,0x5eab002a,0xd64e80eb,0x3134e17b}},	//   gvul, _কালে, gọtụ_, депр,
   {{0x2918c10d,0x69c47270,0xf8cc44fb,0x26d20024}},	//   ðra_, irie, ालिय, _acyo_,
   {{0x61ed4064,0xbc6a8c59,0xb09b82a6,0x6365c019}},	//   zwal, _امان_, _היבר, zóni,
   {{0x25a903e2,0xd64e80eb,0xa6db0086,0x61ed45d9}},	//   _pwal_, bọtụ_, fiða, ywal,
   {{0xd05c4360,0xddcf0007,0x28af4314,0xc8820080}},	//   _karɓ, ždži, टरमि, əşə_,
   {{0x58d3c8b5,0x2d85054a,0x6365d3be,0x28df81f9}},	//   _зошт, öle_, vóni, प्पि,
   {{0xd8dbc0c3,0xd0f7c2a6,0xf8dbc0c3,0x04dbc0c3}},	//   _הקור, _זצוק_, _החומ, _הקול,
   {{0xae9b01b4,0x7d1ab271,0x6568c041,0xe1ff4fc2}},	//   _اضغط_, _lots, lldh, _pró_,
   {{0x68f57272,0xdebc00c3,0x8ccda366,0xa3b3809d}},	// [3870] _pazd, _המחל, _सालो, _जौन_,
   {{0x7d1aaefe,0x2a66c033,0x635203a0,0xfc46580a}},	//   _nots, _myob_, māna, čína_,
   {{0x78ae4070,0xd49803d0,0x672d3273,0x6365c344}},	//   _debv, _эры_, _klaj, sóni,
   {{0x7d08b274,0xb915425d,0x3a3f4123,0x672d088b}},	//   _ands, _yabụ_, _župu_, _jlaj,
   {{0xb8d34079,0x61ed7275,0x672d3276,0x69c47277}},	//   _টা_, qwal, _mlaj, crie,
   {{0x7bca8a06,0x9c7cc04f,0x98b04043,0x2b91b278}},	//   fufu, rečj, _ćaća_, _pác_,
   {{0x2a66c05c,0x46bf0185,0x672d3279,0x395ec017}},	//   _ayob_, ्लाह, _olaj, dots_,
   {{0x7f4d40f6,0x7d088414,0x2b91b278,0xdb18c089}},	//   nnaq, _ends, _vác_, trvá,
   {{0x7bc380e0,0xe4e7811e,0xfd4e8044,0xedd58183}},	//   srnu, _ніжн, _jekọ, _زياد,
   {{0x61fbc1b0,0x66023023,0x3f8ec17b,0x2a66c0ce}},	//   rvul, _šoko, _bufu_, _dyob_,
   {{0x69cba3f8,0x69d980fa,0xfd4e80eb,0x39430b37}},	//   luge, ltwe, _lekọ, dijs_,
   {{0xd5d18eb5,0x28dd4185,0xe29707fe,0x63b8405b}},	//   _समाज, न्ति, маю_, ávni,
   {{0x68f70c64,0x6d5e4150,0x7bc540fa,0x291a1807}},	//   _baxd, yopa, hrhu, _popa_,
   {{0x672d09a3,0xb17b5521,0x28d4c919,0x395ecc76}},	//   _elaj, _spån, _दायि, cots_,
   {{0x257440cb,0x2d87c05e,0x69cb8196,0x35d3c17e}},	//   näle_, _iine_, huge, _दमड़,
   {{0xbebb00fd,0x69cbb27a,0x798f40bb,0x63a20011}},	//   shër, kuge, _bucw, _čond,
   {{0xaa4358d7,0x61e40fee,0x27e0c011,0x6b9c647e}},	// [3880] ветл, _upil, _ćini_, _strg,
   {{0x25a06d99,0xa06a0949,0x7c2dc09c,0x6e22812c}},	//   rpil_, _мапа_, _ƙarh, vyob,
   {{0xdb0ac0da,0x7d1a87d3,0x25a0480d,0x69cb8654}},	//   ënës, _rots, spil_, euge,
   {{0x628bc1aa,0x3f9c4017,0x232598d5,0x6d438007}},	//   _nggo, īvu_, нфіг, eina,
   {{0xb0d28027,0xd00f801c,0x6f098047,0x6ed61146}},	//   _सादग, یله_, _dnec, _भानु,
   {{0x28dd727b,0x6299c0ce,0x6d4e10a0,0x2e4e80eb}},	//   न्दि, _afwo, nnba, fọrọ_,
   {{0xa91d8007,0x6376034d,0xa2cf0047,0x69d98fd7}},	//   _nužu, cáng, _थाल्, atwe,
   {{0x657ac022,0x69cb8e3e,0x28cc40e9,0x68f88157}},	//   wmth, buge, ालवि, sdvd,
   {{0x7d1ab27c,0x63ad81be,0x6365c10d,0x2d8fc011}},	//   _tots, ćana, jónu, _cuge_,
   {{0xb7d481c0,0x7769dac8,0x63760019,0x628bc0bc}},	//   _aṣed, alex, hánd, _eggo,
   {{0xc588c00c,0x69c6327d,0xdb0201ff,0x7f4d4561}},	//   _mồi_, erke, mplê, ynaq,
   {{0x7e26c04c,0x394301d4,0xaefb402e,0x7988802f}},	//   _одеж, wijs_, _akùn, _hidw,
   {{0x637602b0,0xa26400c5,0xbebb414d,0x9f45c0b1}},	//   dánd, върл, _hoëg, _oplê_,
   {{0x63880565,0x61fd0065,0x6e2440f8,0x7aeb9ae9}},	//   tènè, rvsl, dyib, zegt,
   {{0x63760018,0x2bc5c027,0xc1db8047,0x1bd41109}},	//   fánd, _विया, _मङ्ग, коря,
   {{0xa3cf8742,0xd30fc00c,0x3d0cc09d,0x7bc54089}},	//   वंत_, _lệnh_, ़ावे_, vrhu,
   {{0x93780c59,0x7bdac04c,0x6e245c44,0x3cf8404f}},	// [3890] _تصور_, lttu, gyib, _barv_,
   {{0x291cc06f,0x88c60079,0x2369405c,0xceb98047}},	//   _jova_, শ্বক, slaj_, _moře_,
   {{0x7ae2f27e,0x2e9c8044,0x6124c060,0x291ccf02}},	//   _obot, _ịjụ_, _còli, _mova_,
   {{0x2b080036,0x69cba8c7,0x2bd04374,0xe81c0027}},	//   षाएँ_, tuge, _हमरा, नहरा_,
   {{0x7aed6133,0x332da041,0xae0f03b0,0xa1eb8032}},	//   meat, _vlex_, ामिन_, تراك_,
   {{0x29354009,0xad9b40e1,0x80da84d8,0x3ea68aee}},	//   _טאָן_, _grúa, प्ले, abot_,
   {{0x6d43b27f,0xf770801c,0xdbc6409d,0x7ae2c17b}},	//   rina, _چاق_, _söög, _bbot,
   {{0x6602f280,0xe619d8cc,0x628d155f,0x644e8011}},	//   _brok, зди_, _ngao, _žbic,
   {{0x64570018,0x291cec01,0x6d4e3281,0x6ff38080}},	//   _lxxi, _bova_, ynba, _məcə,
   {{0xf389c082,0x637602b0,0x3ea2c06a,0xa3c34036}},	//   _hải_, zánd, ıkta_, _एटा_,
   {{0x25a2021b,0xd009f282,0x6376034d,0x6602c89f}},	//   wpkl_, чене_, yánd, _erok,
   {{0xef198085,0xe7320425,0x3f890d7d,0xdb0acfd0}},	//   _biżi_, اصد_, _ciau_, gsfä,
   {{0x5e27c280,0x6f0bc00b,0x63a1c089,0xf389c35d}},	//   _تعاق, _ingc, spln, _mải_,
   {{0x63763283,0x6d4542c0,0x2a690141,0x628d005e}},	//   dáne, jiha, _dyab_, _egao,
   {{0x3945c0d2,0xf99f6b80,0x98ba40b4,0x63a4f284}},	//   mils_, _atè_, hipă_, _čing,
   {{0x4425d604,0x637884b3,0x3f9e003f,0x28df8db4}},	//   myl_, míng, ītu_, प्ति,
   {{0x7e6989a1,0x612b3285,0x61300041,0x63763286}},	// [38a0] _nyep, _küll, _välb, ránd,
   {{0x3945f287,0x63718041,0x7afbc051,0xb1435aca}},	//   nils_, våna, hdut, гнул,
   {{0x6b89b288,0x98a78039,0xaec697a9,0x3cf84041}},	//   _bieg, linė_, ебел, _varv_,
   {{0x7bce3289,0x2722328a,0x2d920339,0xb605c04f}},	//   mubu, _ións_, _kuye_, _košč,
   {{0x9c7cd151,0x28f8b28b,0x98a78039,0x58d4b28c}},	//   reči, дель_, ninė_, волт,
   {{0x7bdac086,0xc588c0d1,0xdfd0820c,0x7b2b06df}},	//   yttu, _tồi_, ليت_, nƙur,
   {{0xd47a0052,0x25ad8085,0xfbc7c1f7,0x68eec080}},	//   האַל, _ewel_, _حت_, _öhdə,
   {{0x6d41a3a0,0x69dbc0fd,0x7af9c2d9,0x5fdb40c3}},	//   _emla, ftue, _cawt, _מחלק,
   {{0xf8dd4371,0x612dc166,0x7bdc00fd,0x7d1e328d}},	//   न्वय, _súla, htru, _oops,
   {{0x6561c97e,0x6b89b28e,0x6f0bc0f7,0x98a78007}},	//   golh, _zieg, _engc, dinė_,
   {{0x313740c3,0x41c2c7a9,0x64a38951,0x7ae4005e}},	//   גנים_, _शिवस, _саха, _bbit,
   {{0x2d8a400b,0x7bdaf28f,0x7ae40061,0x15f48e95}},	//   _libe_, rttu, _cbit, _इनार_,
   {{0x66043290,0x6d4180de,0x16038064,0x6f1d7291}},	//   _crik, _ymla, लियर_, _rosc,
   {{0xe1ff0877,0x612b02d6,0x4425c047,0x7d1e0060}},	//   rvó_, _güll, byl_, _cops,
   {{0x4425c75d,0x272e410d,0xaf075045,0xc6a74748}},	//   cyl_, _sýna_, нчак, ерзи,
   {{0x98a78007,0xf7734280,0x7b2b0020,0x2d8a40cc}},	//   binė_, ااس_, rƙus, _aibe_,
   {{0x6d897292,0x6126810d,0x5cc75213,0x2a6900f8}},	// [38b0] _džan, _eðli, есез, _uyab_,
   {{0xf38a0015,0x612b054a,0x48ab004c,0x2727454a}},	//   _rải_, _külm, _этим_, _mõni_,
   {{0x6f1d7293,0x3204b294,0x660400b3,0xf65000fb}},	//   _tosc, _army_, _zrik, _نئی_,
   {{0xf1b90077,0x80d70d91,0xb4bec705,0x2734035d}},	//   ššu_, _बाडे, ेलु_, _vãng_,
   {{0x290c821b,0x7afd1cbb,0x63788004,0xdb178ad6}},	//   _bnda_, idst, dínd, nsxé,
   {{0x1869a506,0x69dd14ed,0xf9940087,0x291eb295}},	//   мали_, itse, ארס_, _cota_,
   {{0xd5e2c1c0,0xb0d285da,0x9c65401c,0xdb1b07fb}},	//   _ayò, _सारग, _شهرو, butø,
   {{0x3ea97296,0x7aef125b,0x7afd24a7,0x25744041}},	//   nbat_, ject, jdst, mäla_,
   {{0x6ea20045,0x6d473297,0x7afbd3cf,0xb606805b}},	//   _क्षु, kija, rdut, _pláž,
   {{0x69cf3298,0x4425f299,0x69c00166,0x2735527d}},	//   duce, tyl_, ámem, _hånd_,
   {{0xbea60a6b,0x660425d9,0x7bdc11d2,0x69dd0b43}},	//   канк, _srik, xtru, etse,
   {{0x6378803c,0x26c3c007,0x3f8b40b4,0x69dd1064}},	//   cínd, ėjos_, _nicu_, ftse,
   {{0x3945f29a,0x733ac009,0xbb3ac009,0x4427954b}},	//   pils_, _קענס, _קעני, lyn_,
   {{0x6d47204c,0x98a78039,0x6f0d329b,0x629d729c}},	//   gija, rinė_, _enac, _afso,
   {{0x290c01df,0x442c0032,0x612b329d,0x28d30288}},	//   ıda_, ád_, _gülm, _तारि,
   {{0x6d55406f,0x69dd0022,0x3f8b4123,0x6609406f}},	//   _ajza, btse, _cicu_, _šeka,
   {{0x442781f4,0x25a0329e,0x6b8bc40d,0xb0d28027}},	// [38c0] hyn_, _util_, _migg, _सालग,
   {{0xb5b702a6,0x6ab643a6,0x7bce000d,0x98a65252}},	//   _שליח_, sayf, pubu, тиже,
   {{0xf65140fb,0x80d70064,0x8fa60a81,0x20560aec}},	//   لئے_, _बाते, _шане, _штир,
   {{0x25ad0119,0x2cb8329f,0x6d8972a0,0x63788004}},	//   ţele_, lard_, _užan, xínd,
   {{0x27354041,0x80da802a,0x7d1ccbdc,0x3947b2a1}},	//   _sång_, _যোগ্, örsk, fins_,
   {{0x2366c4c9,0xa0a34245,0x6563843e,0x39479802}},	//   _skoj_, _вард, gonh, gins_,
   {{0x8c464156,0x63bc42a3,0x6b66b2a2,0x61e9b2a3}},	//   _реве, _uvrn, _аква, _epel,
   {{0x291e8033,0x637893af,0x33200d21,0x7bc5834d}},	//   _wota_, fíne, _noix_, áhua,
   {{0x28d30758,0xc6f7cc4e,0xd1868157,0x6d8941be}},	//   _तालि, тных_, _алай, _ožal,
   {{0x6563801d,0xa3cf809d,0x2cb800e5,0x273544c9}},	//   conh, वंश_, jard_, _tång_,
   {{0x25a6802f,0x4427802c,0x69c9c1c8,0x6602a949}},	//   lpol_, cyn_, aree, lvok,
   {{0x645a92f6,0x2d8c80c3,0x63760107,0x69dd0535}},	//   _ixti, _hide_, vánc, ttse,
   {{0xb5fd8007,0x9ad380eb,0x69dcc0cc,0x201e0025}},	//   _ryšk, lịch, ăres, ätin_,
   {{0xd943c157,0x6286cc81,0x2cb824fd,0xe8cc4d22}},	//   _кечи, žkos, gard_, ालोच,
   {{0x3320060c,0xa2d38428,0x7ae29b1d,0x27354240}},	//   _foix_, _डाल्, kfot, _låne_,
   {{0x7f5600da,0x6f0d32a4,0x81e74079,0xaad180e4}},	//   _gjyq, _unac, ভিস_, _हाइक,
   {{0xdb1b0041,0x3f8b46f0,0x44278036,0x3ea64018}},	// [38d0] rrtä, _vicu_, zyn_, ñota_,
   {{0x612b02d6,0x3b1f805c,0x3ea94580,0x6b810044}},	//   _mülk, _souq_, sbat_, _ịgha,
   {{0x69c9c05c,0x67208303,0xf4874119,0xdb154107}},	//   zree, _bomj, туан, lszí,
   {{0xdbd1054a,0x5a35847f,0x60db00b3,0x92598409}},	//   _müüg, лнет, đumu, нает_,
   {{0x212100f8,0x6b8bc98f,0xa3d4c045,0xdcb180d1}},	//   _kohh_, _rigg, िंड_, _hỏi_,
   {{0x3eb9009d,0xd491800c,0x69c9c7f5,0x6d48f2a5}},	//   hast_, _vào_, vree, jida,
   {{0x3eb90ae6,0x62868066,0x7e6d017b,0x65639065}},	//   kast_, _úkon, _lyap, ronh,
   {{0x23690046,0x672d4931,0xde8f40eb,0x98bc8119}},	//   _nkaj_, nkaj, _aịza_, tivă_,
   {{0x442786bc,0xaca301c0,0x7e6d32a6,0x3947ac9a}},	//   syn_, _akọd, _nyap, pins_,
   {{0x236ddac6,0x3f8d800c,0x442781f4,0x6033c03a}},	//   slej_, _hieu_, pyn_, ləmə,
   {{0x80d84eec,0x3f8d80d1,0x7ad5c425,0x98bc80cc}},	//   न्टे, _kieu_, _مقاص, sivă_,
   {{0x28a3c048,0xe5a607e3,0x7d1ac022,0x2cb832a7}},	//   _ख्रि, лими, ajts, ward_,
   {{0x33200669,0x6b8d05cf,0x7c2dc360,0xe60ed213}},	//   _voix_, _diag, _ƙars, _уд_,
   {{0x2d8c131e,0x7e6d00b6,0x10a2c051,0x82768052}},	//   öde_, _dyap, _лишн, טערע_,
   {{0x6717c4fb,0x23b7c25c,0x7ae29064,0x80db88b8}},	//   थापक_, _आबिद, yfot, _नाने,
   {{0x3f8d82a4,0x80cd8444,0x3eb91433,0x6f1dc414}},	//   _nieu_, _साझे, cast_, ösch,
   {{0x635c9684,0xe57a448f,0xfd9ec044,0xdb1b0066}},	// [38e0] nčne, еза_, _kụọ_, nutý,
   {{0xd9100de9,0xd5b80017,0x7bde559a,0x23b7eeaf}},	//   _بیس_, ņās_, ttpu, _आबाद,
   {{0x67209ba6,0x8af0403a,0x7afd435b,0x5aca87ea}},	//   _pomj, zləy, _fast, елем_,
   {{0xdcf4f2a8,0x68fe30ab,0x128881aa,0xda7a8051}},	//   _čači, _hapd, نمای_, нял_,
   {{0xe3a7c4fc,0x7521b2a9,0x3d054b35,0x98bec0b4}},	//   _گر_, _bolz, _होवे_, nită_,
   {{0xfd9ec0eb,0x6e29c02f,0x2731c089,0xe3a442cf}},	//   _nụọ_, dyeb, _rána_, _نشری,
   {{0x63a944d6,0x69cb911b,0x8b955702,0xf366d614}},	//   _čeng, arge, _вруч, лтин,
   {{0x70534301,0x2731c089,0x2d8cacad,0x7c28c089}},	//   _انفا, _pána_, _wide_, vydr,
   {{0x50d688a7,0x442a0066,0x6b8285b0,0xe4d6854c}},	//   _مزار, hyb_, mmog, _متاب,
   {{0x59838051,0xad9b434d,0x2366824c,0x7d1ac022}},	//   _глуб, _brúj, looj_, ujts,
   {{0xb893b2aa,0x6b8d32ab,0x612f96a9,0x2458c11b}},	//   _المع, _piag, _møll, тань_,
   {{0x926b0c9d,0x2579c01e,0x69c684c9,0x637604cc}},	//   ерга_, vèle_, _åkes, tána,
   {{0xa195059d,0x3b004df5,0x6d8958ca,0x637d0396}},	//   рагч, ddiq_, _džaj, héng,
   {{0xe9df32ac,0x660972ad,0xfd9ec094,0x2579c01e}},	//   rtú_, _šeko, _gụọ_, tèle_,
   {{0xe9df0671,0xf773438b,0x6376005f,0x3d11c036}},	//   stú_, مار_, sána, तारे_,
   {{0xd6d863bb,0xfd9ec044,0x672d412c,0x637614f2}},	//   лту_, _zụọ_, ukaj, pána,
   {{0x612b009d,0x30a76024,0x7c2a802c,0x3f858157}},	// [38f0] _lüli, грев, hyfr, _èlui_,
   {{0x61ed32ae,0x399983e2,0x6fea803a,0x51845045}},	//   _ipal, _rès_, _məcb, буха,
   {{0xdb1b0004,0x768bc06a,0x6033c080,0x6d4fc1cb}},	//   esté, _köyü, təmə, écai,
   {{0x7aff01d6,0x929d8062,0x45d55000,0xfde5c09d}},	//   _jaqt, _małg, _комс, _कहलस_,
   {{0xe8d9000c,0x69cbb2af,0x66044066,0xf9c78e03}},	//   _quỷ_, urge, cvik, ущен,
   {{0x2d8ef2b0,0xfbc5c1f9,0x9f5ec580,0x635cb2b1}},	//   _nife_, _विलम, _artà_, včne,
   {{0x2a7f002d,0xd8b89546,0x6d474085,0xc6a78244}},	//   ľuby_, ادها_, _imja, _брзи,
   {{0x29040017,0x6e3bd846,0x272740b2,0x5334b2b2}},	//   ēmai_, tzub, _tõnu_, _лест,
   {{0x7d124107,0xa283808c,0x25a940f8,0x2d8ef2b3}},	//   _újsá, _ایشو, npal_, _bife_,
   {{0x6609b2b4,0x6ab632b5,0xdb020fd0,0xdce3c085}},	//   _irek, _seyf, nslö, _binġ,
   {{0x998481b4,0x610b803f,0x2d8ec3bc,0x7ae98033}},	//   _اللو, _vēlē, _dife_, _kbet,
   {{0x2007c04f,0xdce18085,0x7eb00031,0xb602c047}},	//   _vrni_, _bilħ, _bẹẹk, čárk,
   {{0x3da7c9d3,0x2738c88b,0x3eadf2b6,0x768bc03a}},	//   _среб, _séng_, mbet_, _döyü,
   {{0x6609b2b7,0x3eadf2b8,0x853000e2,0xdb05801e}},	//   _mrek, lbet_, _buɗa, sphè,
   {{0x63a5021b,0x80da8185,0x6722c04d,0x85300020}},	//   _cthn, प्टे, _yooj, _cuɗa,
   {{0x6609b2b9,0x6abbc0cb,0x291172ba,0x66020574}},	//   _orek, nauf, _anza_, _šoku,
   {{0x7ae440da,0x47361971,0x3ead030d,0x6d4a8d08}},	// [3900] rfit, _مرکز, ñete_, yifa,
   {{0x3b00403a,0xddcd0011,0x49910de9,0xf0a74156}},	//   sdiq_, _uzaš, _ریفر, икул_,
   {{0x7523cf75,0x61fb8922,0x637d0018,0x66e672bb}},	//   _monz, _asul, bénd, _кона,
   {{0x539b03bd,0x69cd72bc,0x2911400b,0x305b04e0}},	//   _שיכו, brae, _enza_, _ידיד,
   {{0x9ad40112,0x63788dda,0xb4c39f38,0x3cf284ef}},	//   _rịlt, gína, ्लू_, ंजले_,
   {{0x6b82b2bd,0xed5a4156,0x23668022,0xfaff013b}},	//   smog, _рог_, sooj_, llët_,
   {{0xb34780f6,0xaca381c0,0x78baf2be,0x9ad38112}},	//   _baħħ, _gbọl, vatv, sịah,
   {{0x5b14c156,0xa3b80185,0x78adc011,0x66168025}},	//   смит, घीय_, _đava, äyks,
   {{0xdb1c4004,0xdb15405f,0x8cd70036,0xb606060f}},	//   luró, nszá, _बालो, njšč,
   {{0x99b1402a,0x399bc43e,0x3f8fc086,0x92d6c02a}},	//   _চমৎক, _dês_, _eigu_, াজে_,
   {{0x257444d3,0x27354300,0x7523f2bf,0x6722c64d}},	//   väll_, _låna_, _donz, _tooj,
   {{0x853000e2,0x3f9872c0,0x98a5c007,0x2d8ec0c3}},	//   _ruɗa, _muru_, bilį_, _wife_,
   {{0x78bc093b,0x15a7c0c5,0x25744041,0xa3d4f2c1}},	//   farv, _къщи_, täll_, िंह_,
   {{0xf1bf0032,0xf669c01c,0x78bc1044,0x59c984e3}},	//   rsá_, _صحنه_, garv, _रिसर,
   {{0x757bc323,0x897bc0c3,0xdb0581cb,0xe3a4c16a}},	//   _שטופ, _שרוצ, sphé, _اشتی,
   {{0xa3be0045,0x442cc2cd,0x9ed9027f,0x4ea70245}},	//   ुंज_, myd_, _смит_, _трка,
   {{0x6f02b2c2,0xf993c009,0x2effb2c3,0x7bce0010}},	// [3910] ddoc, ַרף_, _rauf_, arbu,
   {{0x637ec0fd,0x6609ae18,0x394cf2c4,0xf80746ac}},	//   lënd, _rrek, nids_, ичен,
   {{0x442cc2cd,0x6371826c,0xf99f435d,0x6f008073}},	//   nyd_, låni, _trèo_, _bamc,
   {{0x26d901aa,0xe807c8b8,0x3f9846ce,0x7bd532c5}},	//   ngso_, षिता_, _duru_, muzu,
   {{0x61e2885d,0x98a5908b,0xaae6408c,0xdb07410d}},	//   gtol, биле, _اسپو, ssjó,
   {{0xa2d3a477,0x75354033,0x637ec0fd,0x69c0c51f}},	//   _डाक्, _ulzz, hënd, dsme,
   {{0xdb09010d,0x59c98027,0x7523c0c4,0x6f02b2c6}},	//   nsdó, _रिवर, _ronz, bdoc,
   {{0x29011fcd,0x442cc1f4,0x005804e0,0x2d91434d}},	//   _laha_, dyd_, ישות_, _hize_,
   {{0x68f5005f,0x929d8064,0xd706c04c,0x7523c0c4}},	//   kezd, _całe, сные_, _ponz,
   {{0xd7e78761,0xdce3c1b7,0x3eadf2c7,0x290124ec}},	//   _відо, _minħ, sbet_, _naha_,
   {{0x3eb94016,0xc689021d,0x2911c1df,0xab2a01f6}},	//   _oest_, _נא_, ıza_, гона_,
   {{0x99894242,0x7bd5209d,0xa3cf42ea,0x613004c9}},	//   jzaž_, duzu, _शिन_, _välm,
   {{0x7523c17b,0x2d9940fd,0x637d003c,0x98a78007}},	//   _tonz, _nuse_, xéne, ninį_,
   {{0x64a30fd2,0x6136c0b4,0x2d915187,0xa009ca2c}},	//   зара, _vâlc, _nize_, _مقتل_,
   {{0x251ac093,0x27354041,0x1dda40e4,0x6d4fc01e}},	//   _תוצא, _såna_, यूनत, écau,
   {{0x7999c0e2,0xdb154107,0x7bc1c3ad,0x2d914140}},	//   _kuww, tszá, mslu, _aize_,
   {{0x2cb872c8,0x3ea05a98,0x0eb94039,0x6e2d72c9}},	// [3920] _perd_, rcit_, русы_, gyab,
   {{0x2018cded,0xb69b19b5,0x3f920303,0x7bd532ca}},	//   årig_, ndân, _hiyu_, buzu,
   {{0x7bc1cb32,0x2cb872cb,0x637d005f,0xc625802a}},	//   nslu, _verd_, séne, _মেলা_,
   {{0xfe0546ca,0x6e2d49dc,0x673bc04f,0x59af0fb2}},	//   रिशस_, byab, jhuj, जीकर,
   {{0x291c44c9,0x660dc026,0x6568c23c,0xb7efc02a}},	//   övas_, _šakn, yodh, য়মিত_,
   {{0x3f96401b,0xe9a35822,0x6f028206,0xa06a4887}},	//   _граѓ, _харп, sdoc, _бага_,
   {{0x1fa383d0,0x7bc1dda6,0x67264303,0x3c07835d}},	//   прыг, jslu, _kokj, _cđv_,
   {{0x69c0ede3,0x2360c06c,0xae180028,0x62960340}},	//   tsme, čijo_, दमान_, _ngyo,
   {{0x6f0445ef,0x3f9a32cc,0x63788089,0x2d91662b}},	//   idic, _lupu_, líno, _yize_,
   {{0x3f868f02,0x61e440b2,0x7999c14d,0x7bc1c4a9}},	//   lmou_, itil, _duww, fslu,
   {{0xab9681b4,0x6568f2cd,0x3fcb808c,0x28dd4f92}},	//   _الصغ, rodh, _مدنی_, न्टि,
   {{0xeeab03d0,0x637d0018,0xa3d7c027,0x6d4e0b32}},	//   ыток_, dénc, ाढ़_, eiba,
   {{0x78ba8039,0x13ad8079,0x69c28b45,0x5118c43c}},	//   _ketv, _গিয়, nsoe, _волю_,
   {{0x68e900b3,0x6f02c05e,0x6d5c4303,0x2902c017}},	//   đedo, _haoc, _njra, ēkas_,
   {{0x3f9a044e,0x6eaec036,0x3326c1c8,0x889b8052}},	//   _cupu_, ीरपु, _koox_, רבלי,
   {{0x78ba811a,0xdb09010d,0x16054045,0x337544c5}},	//   _letv, rsdó, रिलर_, ігар,
   {{0x7f4d72ce,0x69d672cf,0x61e44b44,0x6a7f01c0}},	// [3930] riaq, guye, gtil, _dàfí,
   {{0x200c903c,0x6e2d556d,0xdce383aa,0x127bc052}},	//   _ordi_, ryab, tonč, ראמע,
   {{0x273b00fd,0x69c00017,0x2a9e80eb,0x7e7b8107}},	//   _tënd_, šmet, _ịba_, _szup,
   {{0x2d9b00fd,0xa6db0086,0x291c44c9,0x7aed01d6}},	//   _kuqe_, miðs, övar_, _jbat,
   {{0x35e7811b,0x7ccb4017,0xceb400c3,0x2b4dde8f}},	//   сцев, tērē, ליף_, viec_,
   {{0x2c83001e,0xdb1b32d0,0x1d099532,0x1c18c036}},	//   cédé_, nstâ, реки_, धमाल_,
   {{0xa3b387f6,0x26c9011f,0x3ea20041,0xdb0572d1}},	//   जीं_, _odao_, yckt_, _athé,
   {{0x80db83b0,0x200790b4,0x612b005f,0x6f02c5ef}},	//   _नावे, rvni_, _küls, _caoc,
   {{0x7e7b8036,0x28d4c1c2,0x660d088b,0xa2dc5337}},	//   _uzup, _दाखि, _nrak, _फास्,
   {{0x3bc3c435,0x7bc1d3c1,0x6f046f9b,0x799b80f8}},	//   tıq_, tslu, zdic, _iuuw,
   {{0x3d1d0ca2,0x2b4dc036,0xb69b19b5,0x51848026}},	//   माने_, piec_, rdân, _хута,
   {{0xcb6a0541,0x2735411b,0x3bc3c03a,0x78ba8077}},	//   раме_, _sånn_, rıq_, _zetv,
   {{0xbebb42a4,0x4a4332d2,0xaa7b4047,0x3cfa4185}},	//   _voël, дняв, _zbýv, _उसले_,
   {{0x61fbd8e2,0xf99f4053,0x6b5ec017,0x799b8230}},	//   mwul, _erèk_, mīga, _muuw,
   {{0x7af6404c,0x7bc3a9b0,0x67264033,0x5f064547}},	//   teyt, nsnu, _pokj, озва,
   {{0x7ae9f2d3,0x26cc0039,0x2d930160,0xdb1c410d}},	//   nfet, ėdos_, _eixe_, gurð,
   {{0x15ba423d,0xdb1b010b,0x25adc07a,0x854a422b}},	// [3940] рыбы_, bstâ, npel_, азав_,
   {{0x61e472d4,0x7d03d6a2,0x7aed00da,0x69d672d5}},	//   rtil, _jans, _zbat, ruye,
   {{0x6f040c29,0x071e2495,0xdb1c4086,0x78adc123}},	//   _kaic, _बचाव_, burð, _đavl,
   {{0xdcb6ce18,0x798180c7,0x69c2b2d6,0x6abb899e}},	//   _आज्ञ, _ahlw, tsoe, _ceuf,
   {{0x3ebfc010,0x6aa29930,0x26c05c52,0xada38089}},	//   daut_, rcof, maio_, _neúč,
   {{0x2574404c,0x320db2d7,0x2d9301cb,0x388ec080}},	//   käli_, _drey_, _xixe_, yər_,
   {{0x2d9fc34d,0x394e8669,0x78baa696,0x3ebfc669}},	//   eque_, rifs_, _vetv, faut_,
   {{0x67028d62,0x26c0423f,0x2905c881,0x61e6159a}},	//   _रोचक_, naio_, edla_, ktkl,
   {{0x5b21805f,0xdb059e0b,0x320db2d8,0x2731c104}},	//   _سہول, tshö, _grey_, _mánh_,
   {{0x637d24d5,0x2731c0d1,0x64404080,0x7f4bc75d}},	//   déna, _lánh_, _əmin, _emgq,
   {{0xeb9a88b5,0x78bc72d9,0x60dc0639,0x6b9c72da}},	//   _тие_, _merv, dgrm, _jurg,
   {{0xad9b72db,0x28e08045,0x93fb80c3,0x2011802d}},	//   _krút, _नाडि, _כלבי, _ázia_,
   {{0x2d9fee77,0xa5070e03,0x6b5ec017,0x6f0431cf}},	//   cque_, оявл, cīga, _daic,
   {{0x3ebf46f0,0xdea2809c,0x3cf64036,0xfa77c0c3}},	//   _žut_, rkoƙ, ीयों_, _ועדת_,
   {{0x6b9c409d,0x3d054027,0x533513f4,0xb4b6ecb5}},	//   _nurg, _होगे_, _нект, जरी_,
   {{0x7d03c3bc,0x213a29a9,0x7c2804c9,0x6d5e00d2}},	//   _zans, _elph_, ädra, _ejpa,
   {{0x6edc4021,0x3d174185,0xdb1b0016,0x80db8021}},	// [3950] _फारु, नाले_, mstà, _नाले,
   {{0x2fd832dc,0x3d056a5d,0x332932dd,0x44f44119}},	//   burg_, _होखे_, _hoax_, мпус,
   {{0xdb18c0b0,0x2d9fc070,0xe4e2cd91,0xdc9840d9}},	//   msvæ, zque_, _खानि_, івці_,
   {{0x63760c1e,0x2731c0d1,0xad9b4107,0xdb18c255}},	//   vánk, _gánh_, _csúc, lsvæ,
   {{0x6abd405c,0xe1ff434d,0xa3dd8048,0xdca5aa0c}},	//   _iesf, _usó_, थून_, пали,
   {{0x68f880b2,0x1fb580b4,0x61f9450c,0xceb980a0}},	//   gevd, псир, ğalı, _moři_,
   {{0x7bd8b2de,0x2d878147,0x8fa285b4,0x61f9491a}},	//   guvu, rmne_, наще, şalı,
   {{0x9623c079,0xf41240c3,0xdcfd4007,0x799d6950}},	//   _বেগম_, _אפל_, _pusė, _kusw,
   {{0x7c389ba6,0x4cd30079,0xe616d05e,0x200ef2df}},	//   _čarš, দ্যু, зды_, _arfi_,
   {{0x2001007a,0x1c45c22b,0x6d5aec06,0x610f0007}},	//   _oshi_, зном, gnta, nėlė,
   {{0x2c748032,0x3f89405c,0x98bec047,0x27220066}},	//   rúdú_, kmau_, litě_, _zóny_,
   {{0x7d03c31c,0xf53f5a5e,0x6fea803a,0x61e60621}},	//   _wans, _stål_, _məcl, ttkl,
   {{0x6d5ac046,0x69d99005,0x26c040c4,0x2d834051}},	//   bnta, nuwe, vaio_, _ohje_,
   {{0x2fd832e0,0x2905b2e1,0x320fc303,0x637d01cb}},	//   turg_, _jala_, _irgy_, réna,
   {{0xb4d7c048,0xdb1b32e2,0x61e610ff,0x25ab42c0}},	//   िली_, bstà, stkl, _atcl_,
   {{0x030b8027,0x2d9df2e3,0xf1c742f6,0x6e964032}},	//   _सोलह_, _kuwe_, _लिखन, سلطا,
   {{0xda634acf,0x799572e4,0x63bb02bc,0x6b9c72e5}},	// [3960] евти, _bizw, ćuna, _surg,
   {{0x3d1d008f,0x2d9dc55e,0x2905b2e6,0x673b83e0}},	//   माणे_, _muwe_, _nala_, _aluj,
   {{0x69d9815d,0xad9b72e7,0xa09b0323,0x26c04070}},	//   euwe, _brús, _לייט, paio_,
   {{0xdce38185,0x673b8119,0x78bc415d,0x6299c044}},	//   plně, _cluj, _werv, _ngwo,
   {{0x2d4d32e8,0x6b9c72e9,0x67228051,0x387e8077}},	//   džej_, _wurg, rjoj, _sztr_,
   {{0x26c232ea,0x60c1c0f1,0x6299c0ce,0x98a40007}},	//   hako_, jalm, _agwo, ėmė_,
   {{0xdb074041,0x6d5ac022,0xbef9c045,0xd64e80eb}},	//   rsjö, vnta, ्यून_, wọdụ_,
   {{0xe80d04fb,0xd00f4107,0x69c632eb,0x2905873f}},	//   हिता_, _حلف_, kske, _eala_,
   {{0x69c6219c,0x6f0644a7,0x76447233,0x444440fa}},	//   jske, _makc, nziy, lz_,
   {{0x2d9dc1aa,0x6fea803a,0x69cfd0ec,0x6b84084f}},	//   _duwe_, _həcm, ácea, _ahig,
   {{0x26c21950,0x28ddca30,0xfbd28a87,0x67298033}},	//   fako_, _मारि, _ستا_, _yoej,
   {{0x6d4e57c8,0xe45742a6,0x987b40c3,0x63b84166}},	//   _lmba, לייט_, מריק, ávny,
   {{0x2905b2ec,0x518732ed,0x3f9ea44a,0x672472ee}},	//   _yala_, зува, _hutu_, djij,
   {{0xf617c0c3,0x3d0c40b2,0xa3d08185,0x799d41c6}},	//   _מחדש_, _डोले_, _वटा_, _rusw,
   {{0x961d8017,0x1897c032,0x9f5a40d2,0x387ac107}},	//   _izņe, _عضوة_, _espí_, _ápr_,
   {{0xaf045ea7,0x6b840157,0x5f944911,0x69c606b7}},	//   нчук, _ghig, еист, bske,
   {{0x6f064b89,0x4d984523,0x3d11c048,0x78a545ce}},	// [3970] _dakc, зкую_, ताचे_, tchv,
   {{0x272e4086,0x2a5800c3,0x8cd70047,0xa25b41af}},	//   _sýnt_, _מבחן_, _बाटो, _odôv,
   {{0xd251078a,0x3d0c4048,0x7ae2c070,0xe3a502cf}},	//   _سنگ_, _डोळे_, _ocot, _تشخی,
   {{0x7bc572ef,0x64438089,0x2bc5c045,0x52758156}},	//   rshu, vzni, _विघा, мулу,
   {{0xa3cf49cb,0x556280eb,0x613004c9,0x1eea8231}},	//   _शिव_, wụọl, _välv, تونی_,
   {{0x2d9dca26,0x61334080,0x7bc572f0,0x6f064127}},	//   _ruwe_, _qılı, pshu, _zakc,
   {{0x28e24314,0xdb18c041,0x29079bd8,0x63760019}},	//   _पाति, ksvä, rdna_, sáni,
   {{0x273c5752,0x2b4d8018,0xeab38032,0xdb1b0066}},	//   _kína_, _umec_, _سعر_, ystá,
   {{0x2b1c0314,0x6602c107,0x64439243,0xdb18c041}},	//   यासु_, _csok, szni, dsvä,
   {{0x273c4086,0xdbc9dd1a,0x3ebf8414,0x98a58053}},	//   _mína_, огод_, _heut_, _kolč_,
   {{0x7bdaf2f1,0x660d4134,0x6602f2f2,0x203583be}},	//   gutu, hvak, _esok, _تفاس,
   {{0x69c632f3,0x2d9dc12c,0xdb18c4c9,0x612dc359}},	//   tske, _tuwe_, gsvä, _cúlr,
   {{0xba2300d9,0xfce5c6bc,0x444466f8,0x6f09ded1}},	//   вдяк, _жоло, zz_, mdec,
   {{0x853006df,0x60c3b2f4,0x7afbcd7f,0xdb1b2fbf}},	//   _kuɗi, nanm, leut, rstá,
   {{0x10a319e3,0xd00702f8,0x7bdac0b4,0xdee66b86}},	//   тисн, мере_, cutu, мови,
   {{0xc7d6c093,0x7e76004c,0x257440fa,0xbb860032}},	//   _חוקי_, _tyyp, hält_, _تلبي,
   {{0xdb1b010d,0xaa46039d,0x7d074fb7,0xd838004f}},	// [3980] fstæ, _цепл, _bajs, šč_,
   {{0xe9d74842,0x20114a11,0x7afbc04c,0x6aa9802e}},	//   ьку_, _brzi_, heut, _afef,
   {{0x61e9d3c6,0xad1b0087,0x7afbc04c,0x929d8064}},	//   htel, _וויר, keut, _cało,
   {{0x973cc242,0x3f9e8199,0xdb0ac041,0xef1a8523}},	//   _kuće, _rutu_, lsfö, юме_,
   {{0xb0ddc08b,0x7d08c4d3,0x80c3c079,0x6d4e4056}},	//   _मांग, ydds, _শান্, _tmba,
   {{0x68fc01bc,0x7d0772f5,0x60c3b2f6,0x2d858053}},	//   nerd, _gajs, ganm, _chle_,
   {{0x31570009,0x2fc78033,0x69da8027,0x63788032}},	//   ויסן_, gsng_, _नमकी, híni,
   {{0x85a6c01b,0x3ebf814d,0x2d858073,0xa3c1817e}},	//   мјод, _geut_, _ehle_, _्टर_,
   {{0x929d8064,0xd37907ca,0x63adc06f,0xdb0ac041}},	//   _zało, nuće_, _čana, ksfö,
   {{0x637d0089,0xe0d786b1,0x6368050c,0x6f09c062}},	//   téno, _ову_, hınd, adec,
   {{0x61e9f2f7,0xdb0ac4d3,0xd36fc156,0x3f52006f}},	//   atel, dsfö, _ач_, ršun_,
   {{0x6602f2f8,0xd37900e0,0x2cb1c1df,0x6d41c05c}},	//   _tsok, kuće_, ızda_, ahla,
   {{0x68fc1d21,0xad9b4031,0xc1b80d9b,0x2907f2f9}},	//   ferd, _asún, млях_, _fana_,
   {{0x2d984e07,0x68fc32fa,0xe44fc646,0xf7734de9}},	//   _nire_, gerd, اضی_, چار_,
   {{0x5c06c1bc,0x7d0898ac,0xf7734183,0x212c9440}},	//   _цяла, _mads, نار_, _modh_,
   {{0x26c000b9,0x2b17c062,0x660dd754,0x660d5439}},	//   _geio_, थाएँ_, _šaki, tvak,
   {{0xf99f59f3,0x7bc732fb,0x2d985abb,0x6378810b}},	// [3990] _què_, ssju, _bire_, cíni,
   {{0x20114158,0x2907f2fc,0x6f09d466,0xda08c0d1}},	//   _przi_, _xana_, zdec, _mỏ_,
   {{0x7bdc091f,0x7bc8cc2a,0x7aed4b11,0x636802d6}},	//   curu, nsdu, pfat, bınd,
   {{0x60c3ac0d,0x273c45e7,0x8530009c,0x98bf40b5}},	//   wanm, _tína_, _ruɗi, ırın_,
   {{0xdb1b14a6,0x637632fd,0xfad64093,0x7afd0156}},	//   mstä, mánt, _אורך_, iest,
   {{0xdb1c84c9,0x613d80b6,0x6f09c1ff,0xb0ddc1f9}},	//   _avrä, _bèla, wdec, _माइग,
   {{0x6d41c022,0x3f9972fe,0x7c3b40e2,0x64e08048}},	//   vhla, _kisu_, _ƙuru, _नारळ,
   {{0xda08c082,0x60c3b2ff,0x26c4e0cc,0x2d8cc353}},	//   _bỏ_, sanm, gamo_, emde_,
   {{0x6d41ce8d,0x6f09f300,0x5155e267,0xc955c5f1}},	//   thla, rdec, етну, етны,
   {{0x25a000bf,0x1425f301,0x636800b5,0x70d9c048}},	//   _ruil_, едом, zınd, ढलेल,
   {{0xdbd70c99,0x66e61045,0x636801df,0x69dd001e}},	//   _jääv, нона, yınd, euse,
   {{0x9f47c166,0x68e53302,0x9f480065,0x672d00b4}},	//   ktné_, _achd, _opnå_, _coaj,
   {{0xdb0ac4d3,0xdb1b04d3,0x6d553303,0xb606c10d}},	//   tsfö, dstä, fiza, rráð,
   {{0x25d6c009,0x9c82c04f,0xdb18c621,0xfce5c16f}},	//   _נוצן_, ščam, rsvå, _чоко,
   {{0xdb0ac4c9,0xd8d6c323,0xe73a0271,0xe465c0b2}},	//   rsfö, _טוסט_, _нек_, ööde_,
   {{0x14e2408f,0xdb0ac041,0x23274217,0x61348016}},	//   _पाहण, ssfö, носи_, _vàli,
   {{0x6d553304,0x3171166c,0xe3636145,0x291a0056}},	// [39a0] biza, bozz_, укти, _tnpa_,
   {{0x69c9c051,0x61300041,0x020343d0,0xe5774f67}},	//   isee, _väls, ызун, езу_,
   {{0xeb9a5469,0x59d8008f,0x59d28374,0x6d5e4402}},	//   чие_, भंकर, _सिहर, rnpa,
   {{0x2bd17305,0xe9f901c0,0x2731c018,0x63763306}},	//   _हिरा, _afẹ_, _máns_, máns,
   {{0x613240b0,0x7d08b307,0x69c90011,0x2d9a0449}},	//   _bælt, _pads, šeev, _kipe_,
   {{0x59d31543,0x63a1805e,0x98a7c0ce,0xf99f4053}},	//   _तिसर, _buln, _bonč_, _erès_,
   {{0x7afd3308,0x69dd3309,0x63a18303,0x777bcf02}},	//   yest, zuse, _culn, flux,
   {{0xff2680c5,0x80038051,0xd138c062,0x2d87f30a}},	//   _ямбо, учше, wką_, _ahne_,
   {{0x26c2497c,0x6ce6c026,0x60c1aa65,0x9162800c}},	//   _meko_, ніне, _felm, _từ_,
   {{0x26c2730b,0x69dd330c,0xd90d808c,0x61fb001f}},	//   _leko_, vuse, _وین_, çulm,
   {{0x69dd00c2,0x2d8cd36a,0x26c4f30d,0x2013c004}},	//   wuse, rmde_, pamo_, _áxil_,
   {{0x2a66c04d,0xdb1c4095,0x9f47c066,0x3f53c0b4}},	//   _txob_, nsrä, ytné_, nţul_,
   {{0x60c18070,0x6fa8802a,0xd1388062,0x569409b0}},	//   _yelm, _গিয়ে, _ciąg_, лают,
   {{0xde8f4112,0x3f99454a,0xe80d008f,0x60c1803c}},	//   _dịla_, _sisu_, हिला_, _xelm,
   {{0x799ab30e,0x3ea9730f,0x3f9956eb,0x6846c88b}},	//   _mitw, tcat_, _pisu_, _dédé,
   {{0x6b8d4286,0xa87bc4e0,0x2b403310,0x8e150119}},	//   umag, _מאור, _glic_, _адиц,
   {{0x6376082f,0x752e4085,0x290cc1c8,0x26c27311}},	// [39b0] ránt, _bobz, odda_, _deko_,
   {{0x3dc95b2d,0x1be4cfa8,0xfaff02a4,0x04674119}},	//   rsaw_, _कमाल_, leë_, нтем,
   {{0x28e24298,0xb4dd106a,0xdb1b04c9,0xc8e245da}},	//   _पारि, डली_, pstä, _पारट,
   {{0xd32484df,0x60c73312,0x799a812c,0x92598051}},	//   льчи, lajm, _aitw, мает_,
   {{0x5b1441bc,0x290a4004,0x6d438032,0x9a844d4c}},	//   _смят, _faba_, thna, _бурл,
   {{0x5ff547e3,0xd184893d,0x7ae280fc,0x799a8053}},	//   _изгу, глій, agot, _citw,
   {{0x61ed4831,0x3206c105,0x613240b0,0x3cfec1ff}},	//   ltal, _asoy_, _vælt, detv_,
   {{0x9f5d0038,0x69c9c8a1,0x290a7313,0x5f9486b1}},	//   _prvý_, tsee, _zaba_, _бист,
   {{0x5f76c1b4,0x9c82802d,0x3b6480c5,0x6376039e}},	//   خميس_, ľčan, _сърв, záns,
   {{0xe7a9c770,0x635c804f,0x6368006a,0x69cb95b6}},	//   мвол_, včni, kınc, msge,
   {{0x3f89005e,0x2b402d1a,0x3f6a031f,0x29cd002d}},	//   _bhau_, _plic_, дино_, eľa_,
   {{0x3f893314,0x6da600b4,0x69df400b,0x291cc0bc}},	//   _chau_, кима, kuqe, _enva_,
   {{0x28e244fb,0xdb1c41e5,0x9105c119,0xdb01c13b}},	//   _पालि, nsrå, _апле, _lulë,
   {{0x69cb9ad1,0x60c73315,0x3cfec0b3,0x48d00079}},	//   isge, gajm, cetv_, িভ্র,
   {{0x7f44401e,0x8c45c3fe,0x07a6078b,0x26c247a7}},	//   thiq, _шеке, табн, _peko_,
   {{0x273c405b,0x66f9c371,0x6e2440fc,0x752e441b}},	//   _víno_, ्यटक_, txib, _sobz,
   {{0x9e66011b,0x61ed7316,0x6d41b317,0x23604e19}},	// [39c0] _швид, gtal, _olla, rnij_,
   {{0xc8e08285,0x6f1d415d,0x6f0d5335,0x69cb81b0}},	//   _नाइट, _ensc, adac, dsge,
   {{0x823611be,0x15fe6a5d,0x673bcc99,0x26c27318}},	//   _سرکا, _उनकर_, kkuj, _teko_,
   {{0x7bde5649,0x63a3e068,0xdcebc017,0x69cb8572}},	//   rupu, _munn, _augļ, fsge,
   {{0x63a3f319,0x69cb98e8,0x6b898057,0x6729c0b3}},	//   _lunn, gsge, _dheg, djej,
   {{0xd12f81b4,0x14ddc048,0x7ae2b31a,0x4616808c}},	//   يمن_, _मागण, sgot, _یوزر,
   {{0x69cb82a4,0x6378849a,0x63a3d4ed,0x6f0bc00b}},	//   asge, fínt, _nunn, _bagc,
   {{0x26c2c55d,0xe3afc079,0x35a74027,0x831a8280}},	//   úko_, _কিংব, _कूड़, _تقرر_,
   {{0x25a68303,0x71ea8032,0x3d174048,0x7bca80c3}},	//   qqol_, _زفاف_, नाचे_, ssfu,
   {{0x63680165,0x637d07b0,0x661dc588,0x23c6425c}},	//   yınc, méni, åska, _लबाद,
   {{0x6d58b31b,0x91ae4079,0x61ed4107,0x6aad0484}},	//   miva, টওয়্, ztal, _pfaf,
   {{0x3f890022,0x61ed731c,0x6712439a,0x66045698}},	//   _qhau_, ytal, _ढोलक_, kwik,
   {{0x63788b83,0x9f4781cb,0x09e3c523,0x61ed731d}},	//   líns, îné_, _вочн, xtal,
   {{0xf99f03bc,0x44381f80,0x26c4866b,0x799c5698}},	//   twèb_, fyr_, _lemo_, _nirw,
   {{0x60c7331e,0x291e8056,0x4ea7401b,0xcfa41189}},	//   rajm, _mnta_, врза, ишти,
   {{0x6d58b31f,0x15e30028,0x05d28028,0x7ae4531c}},	//   hiva, कंदर_, _सिंब, ggit,
   {{0x6d577320,0x6604402f,0x5f9440d9,0x80b480b2}},	// [39d0] tixa, gwik, ритт, ुराइ,
   {{0x4fc70b8e,0x4438036b,0x7bdac820,0x50b711c8}},	//   _исма, byr_, ortu, _अभिष,
   {{0x637ec0fd,0x82b08112,0x36b080eb,0xaeb080eb}},	//   rënj, _ịnọg, _ịnọk, _ịnọs,
   {{0xbd05c1c0,0x69cb8cb2,0x6d4180fd,0x6f1d702c}},	//   _abẹ́, tsge, _slla, _unsc,
   {{0x61ef3321,0xe4a74119,0xdd2c8007,0x80c3c02a}},	//   ntcl, _арбо, _dėžu, _শাস্,
   {{0x799c417b,0xa3e98219,0x04c98359,0x2b468104}},	//   _girw, едка_, روبي_, ahoc_,
   {{0x6b89b322,0x7ff5800f,0x6d4180fd,0xe4e4811b}},	//   _theg, استا, _vlla, річн,
   {{0x60c508a1,0x291e821b,0x63a3f323,0x69cb87d3}},	//   _lehm, _enta_, _runn, psge,
   {{0x89d98c59,0x673bf324,0x64a5d373,0x7ae98560}},	//   _سوار_, rkuj, лапа, _icet,
   {{0x7f42f2bf,0x6378b325,0x6609b326,0xc27c40c3}},	//   _eloq, sínt, _isek, ורחי,
   {{0xf285002e,0x36d5c119,0xccf8c0a0,0x7e7d47fb}},	//   _ibẹ̀_, _боер, mněl_, _lysp,
   {{0x60c3c0e2,0xdb154107,0x6d468007,0x2ab8c119}},	//   _wenm, gszü, _įkai, _алць_,
   {{0x60c502bc,0x9f47c185,0xde8f4efc,0x63a3c17b}},	//   _behm, ntní_, _dịka_, _wunn,
   {{0x6b9d4311,0x3eadc0d2,0xe5a300b4,0x3ce90048}},	//   _aisg, lcet_, сири, _जाणे_,
   {{0x2007c158,0x09cc4048,0x63a50303,0xab1a41dc}},	//   _usni_, ाळ्य, _cuhn, нцах_,
   {{0x2d9cc2a3,0x3eadcb0e,0x395802cb,0x661b7327}},	//   _zive_, ncet_, sirs_, _šuka,
   {{0xdb1e84c9,0x660984db,0xae16c0b2,0x6b9d554b}},	// [39e0] nspå, _nsek, तियन_, _disg,
   {{0x7e7d7328,0x7d01c407,0x613d80ce,0x11d74032}},	//   _dysp, nels, _bèlm, اولة_,
   {{0x6b9d41ff,0x0d3ac052,0x7ae44125,0x6f0d3329}},	//   _fisg, עגעב, pgit, _yaac,
   {{0xbae5811b,0xf1bf0004,0x6d5540c2,0x613d80ce}},	//   ицій, ixán_, _emza, _dèlm,
   {{0x539b40c3,0x81a9c02a,0xed5a91a0,0x29014127}},	//   _ריכו, গীত_, нод_, beha_,
   {{0xdca353ec,0x24589045,0x7bdc332a,0xe7e4c07c}},	//   _гари, каль_, orru, _कमला_,
   {{0xb8cc8314,0x61fbb32b,0x6609b254,0x2a9e8112}},	//   _गल_, _epul, _esek, _ịbu_,
   {{0xbb438f1e,0x2dd4c051,0x6d43e2e2,0xec774bb4}},	//   _леск, ажир, _alna, _спс_,
   {{0x69dbc0fd,0x25a4b32c,0x7d01ea97,0xdb1e8d42}},	//   grue, _uuml_, fels, rspä,
   {{0x61e28007,0xdb1b0240,0xf53f44c9,0xbebb013b}},	//   muol, lstø, _utåt_, njëv,
   {{0xb9938032,0xf5938032,0x60c52f7a,0x3f804026}},	//   _اللب, _اللج, _rehm, kliu_,
   {{0x63a524ec,0x395a5433,0xdc3b4052,0x6f0d01c8}},	//   _ruhn, hips_, געטר, _qaac,
   {{0xfc43c1aa,0x3636c4a4,0x2b59332d,0xd35780c3}},	//   لپیپ, _حراس, risc_, ריכי_,
   {{0x6f0d012c,0x63a50451,0xdb154107,0x7f44000b}},	//   _waac, _puhn, sszü, _eliq,
   {{0x65750443,0x645c82bc,0x5335401f,0x602ac03a}},	//   rozh, _žrij, аевт, kəmi,
   {{0x6d47332e,0x6368091a,0x774bc031,0x3f80459d}},	//   shja, pına, _kábọ, gliu_,
   {{0xa3e484d8,0x29014033,0xa4d50187,0x6b8d332f}},	// [39f0] भूत_, teha_, _копі, _ihag,
   {{0x7e7d4066,0x395a4379,0x6d48c35d,0xb4df4926}},	//   _vysp, gips_, nhda, णले_,
   {{0x7e7d4036,0x69cf3330,0x29033331,0xe5220314}},	//   _wysp, lsce, meja_, मारि_,
   {{0x681c80b4,0x491d0185,0x61e28112,0xdb1b0211}},	//   _mădă, माको_, fuol, gstø,
   {{0xf625859d,0x6f0f4157,0x20186c04,0xe4c5818d}},	//   рдло, _iacc, _erri_, айли,
   {{0x29033332,0x672d510f,0x69cf0032,0x69dd0032}},	//   neja_, ljaj, isce, irse,
   {{0xdb040d4a,0x6f0f7013,0x273c435d,0x6b8d00c7}},	//   _funè, _kacc, _bính_, _ohag,
   {{0x6f0f6e44,0x29033333,0xdb0780b0,0x61e2b334}},	//   _jacc, heja_, _stjæ, buol,
   {{0x29033335,0x3255893d,0x273c400c,0x3f420031}},	//   keja_, _твар, _dính_, _bóun_,
   {{0x5a34b336,0x291100b3,0x25a6c0f8,0x6b8d000d}},	//   _унут, jdza_, _duol_, _ahag,
   {{0x0467b337,0xb4d18048,0xaca3c0eb,0x336609b0}},	//   _стам, वणी_, _nwụk, ивог,
   {{0xad9b4018,0x6f0f46c9,0x2ba90b35,0x2d9ea1aa}},	//   _crúz, _nacc, _कढ़ा, _zite_,
   {{0x80d04079,0x63a7405c,0x6d5ac277,0x6d89551a}},	//   স্ট্, _lujn, bita, _džaz,
   {{0xa06a00d7,0x2d9e17ec,0x290ef338,0x7bce2c47}},	//   вага_, öte_, _gafa_, tsbu,
   {{0xdea201aa,0xa879c009,0x9879c009,0x0fd903d0}},	//   _ویدی, _באַר, _באַט, льты_,
   {{0x26cb01ff,0x2d01825c,0x33202a31,0x224dc0b9}},	//   caco_, लजुल_, _unix_, ozek_,
   {{0x09e6484e,0x6f0f4c7c,0x29033339,0x6aa401c6}},	// [3a00] розн, _dacc, beja_, _igif,
   {{0x613d80ce,0xb17b14b2,0x69c401d6,0x8cb655ab}},	//   _dèlk, står, _iwie, рсач,
   {{0x35dc0027,0x60c7733a,0x3f8d805e,0x98a7c0b4}},	//   _बिड़, _dejm, _bheu_, _zonă_,
   {{0x1bf6c009,0x09e6404c,0x69c4333b,0x443a40b1}},	//   יצער_, _комн, _kwie, ryp_,
   {{0xdca64b8e,0x201a0011,0x64a6733c,0x69c4017a}},	//   _ваги, _hrpi_, _вага, _jwie,
   {{0x2ae3c185,0x4153811b,0xf8c602f6,0x26cb0070}},	//   _गाउँ_, овіс, वरिय, zaco_,
   {{0xcc248079,0x25a6c157,0xe758c0d9,0x40348039}},	//   বন্ধ_, _suol_, ликі_, сейс,
   {{0x29031396,0x2d9e9e8c,0x320ac036,0x2b404570}},	//   zeja_, _wite_, łbym_, nkic_,
   {{0x290ec05c,0x61e44755,0xfce68910,0x6e3bc010}},	//   _pafa_, nuil, _возо, gyub,
   {{0x98a3800a,0x25a6c5f5,0x6b82b33d,0x6aa419f1}},	//   _дифе, _vuol_, llog, _agif,
   {{0xd6c4c1aa,0xa3c96add,0xb4c28384,0x6b82b33e}},	//   _همای, लीप_, ंरी_, olog,
   {{0x60c8b33f,0x7f49f340,0x69cf3341,0x48e900aa}},	//   _hedm, cheq, tsce, _जाहो_,
   {{0x6b82acba,0x6f044fce,0x6445c09d,0xb28701dc}},	//   ilog, deic, _ühin, рынк,
   {{0x63a09b33,0x6722c066,0x6aa4040d,0x50670b5d}},	//   _limn, _hnoj, _egif, атба,
   {{0x201a06f0,0x533510a1,0x6b828010,0x6f044359}},	//   _crpi_, _гейт, klog, feic,
   {{0xb09bc2a6,0x7e6d0232,0xa3c94a3c,0xf8b48185}},	//   _ביור, _txap, लीफ_, ुरुप,
   {{0xa3c956e2,0x2d8140c7,0xeabf00c4,0x14e24384}},	// [3a10] लीन_, tlhe_, mbù_, _पाखण,
   {{0xb4c288b8,0x6b82b342,0x867c00c3,0x4a7c00c3}},	//   ्णो_, elog, _ברחו, _ברחב,
   {{0xc67800fe,0x6368006a,0x46b48044,0x28e0817e}},	//   _محیط_, kınl, _ịtọ_, _नाजि,
   {{0x63a74013,0x59d58032,0x661645e5,0x9f47c02d}},	//   _vujn, مغتر, bvyk, ktná_,
   {{0xf8b48036,0xe9df0032,0x7bde7343,0x613d8c2b}},	//   ुरूप, nrú_, arpu, _hèli,
   {{0x3d16c027,0x3a3644e0,0x320947b0,0x660d3344}},	//   _भोले_, _הרשם_, mway_, _msak,
   {{0x7aed00d2,0x98f48968,0x7f49c7b0,0xdb0980cb}},	//   _ocat, تثنا, theq, _gieß,
   {{0x777b80f7,0x1ee782f0,0x9984c007,0xd54341c0}},	//   _ukux, _خوری_, kymų_, _fẹ́l,
   {{0xe579c47f,0x628081f4,0x60c881a7,0x7f5d00d2}},	//   лзи_, _gymo, _fedm, disq,
   {{0x61e68673,0xa3c8c285,0x99858032,0x2738c016}},	//   _åkla, _लौह_, _الطو, _béns_,
   {{0x660d075d,0xf99f40b6,0x2b46d83a,0x61e4412c}},	//   _asak, _asèk_, _floc_, zuil,
   {{0x59c4c185,0x6fea803a,0x2bf6821d,0x3ea40240}},	//   लीहर, _təcr, _למען_, ømt_,
   {{0x3a29c03a,0x5f74c1b4,0x2374c1b4,0xab74c1b4}},	//   _çap_, _بالر, _بالح, _بالإ,
   {{0x6f0440cb,0x6609d7e6,0x7aed3345,0x29117346}},	//   weic, mwek, _ecat, _naza_,
   {{0xbebb00da,0x92e9c079,0x3942c03f,0xe1ff402e}},	//   gjës, য়ী_, īkst_, _apó_,
   {{0x7aed0032,0x657c4570,0xe9df32e7,0x3ebfc010}},	//   _gcat, _skrh, brú_, nbut_,
   {{0x637d01aa,0x6368059a,0x99d608a7,0x753545d4}},	// [3a20] rént, nınm, _اتبا, _bozz,
   {{0x6f0445ef,0x61e459bf,0xc7b88043,0x4a43401b}},	//   seic, ruil, _hrđe_, чнув,
   {{0x75354bfd,0x61e63347,0x7afb817b,0x672430be}},	//   _dozz, lukl, _bbut, _knij,
   {{0x2b210036,0xd379811b,0x9f47c089,0xba2680b4}},	//   याएँ_, ачі_, ytná_, йдек,
   {{0x99164761,0xb347001b,0xa2aa8028,0x61e63348}},	//   _льві, luçõ, टशब्, nukl,
   {{0x8bc695ff,0x6d41c206,0xe9188589,0x62808089}},	//   бсид, jkla, рокі_, _vymo,
   {{0x236680e0,0x395c8041,0xd7fa8157,0xdb078240}},	//   pnoj_, rivs_, уул_, _stjå,
   {{0x3eb24018,0xa3e6c46d,0x75354157,0x35a68030}},	//   ncyt_, यंस_, _zozz, _гааг,
   {{0x29117349,0x6d800025,0x6368091a,0x63a18303}},	//   _yaza_, löau, rınl, _èlna,
   {{0x672427c6,0x6b84734a,0xc7bac1dc,0xf8ba41f9}},	//   _anij, hlig, лём_, ेरिय,
   {{0xe97b4009,0x6d5a803a,0x25a9003a,0x43950eef}},	//   רניש, _imta, _sual_, жанс,
   {{0xb347010b,0xa09b4052,0x9984c007,0x3209734b}},	//   duçõ, טייט, tymų_, yway_,
   {{0xa3cb0064,0x2d83041b,0x25a11d11,0x3209443e}},	//   रीन_, tlje_, _pihl_, xway_,
   {{0x3f84c283,0xd90f008c,0x273c4086,0x6b654007}},	//   llmu_, ریج_, _mínu_, mėgi,
   {{0x6fb4c301,0x2d830043,0x395ef34c,0xd48fdd10}},	//   _بمبا, rlje_, mits_, _хр_,
   {{0x67240451,0xbfa80b3d,0x25a90033,0x322b431e}},	//   _gnij, стре_, _tual_, лізм_,
   {{0x61e603a6,0x7535734d,0x7d05403a,0x6d5e4171}},	// [3a30] cukl, _pozz, tehs, fipa,
   {{0x973cc077,0x66df4031,0xe0044045,0x6b84734e}},	//   _bućk, _bàkà, रबंद_, alig,
   {{0x2b49021b,0x3f15899b,0xe787893d,0xb4d50048}},	//   _klac_, ждес, будо, हणी_,
   {{0x501bc0c3,0x6282c0eb,0x273c41c0,0x201cc043}},	//   טובו, _oyoo, _bínu_, _mrvi_,
   {{0x443ef34f,0x6d5e6c97,0xd62996ea,0x29130545}},	//   hyt_, bipa, роле_, _kaxa_,
   {{0x6e2044f2,0x527a40c3,0x2b493350,0x973cc123}},	//   _ámba, _כנרא, _llac_, _fućk,
   {{0x2913162b,0x6282f351,0x3ebfc010,0xa5bb4359}},	//   _maxa_, _ayoo, tbut_, _bróg,
   {{0x6d48b352,0x2905f353,0xc245d000,0xf1d4c036}},	//   _elda, wela_, жник, _दिखन,
   {{0xdb1c810d,0x05a6c04c,0x63aac0fa,0xa3e6c028}},	//   _evró, овый_, _aufn, यूस_,
   {{0x628bd2b8,0x7ae9f354,0x58d484df,0xe8f6c1c3}},	//   _vzgo, sget, _ноут, оль_,
   {{0x63a2c4f8,0x6b847355,0x7d071e91,0x02d9c4a4}},	//   _fion, ylig, dejs, _نواب_,
   {{0x27e7868a,0x6d5e7356,0x59e08549,0xa2cd8036}},	//   munn_, zipa, _निमर, दृच्,
   {{0xdb00b30f,0x5f74cd9e,0x1539c01c,0x6282c0bb}},	//   _dimè, _عامر, _پزشک_, _gyoo,
   {{0xa3e6c045,0x26cfafc2,0x7d0700b0,0x03a600a9}},	//   यूह_, hago_, gejs, живо,
   {{0x18a30645,0x48fb8185,0x628d03e2,0xdb008053}},	//   дарм, ल्यो_, _ezao, _fimè,
   {{0x236d806c,0x26cb4157,0x61e63357,0x26cfb358}},	//   _njej_, _ceco_, pukl, jago_,
   {{0x26cb418a,0x25a344f1,0x2d85c025,0x98a58062}},	// [3a40] _deco_, _bijl_, olle_, _wolę_,
   {{0xf1e08444,0x613d8303,0x98ac80cc,0x69d60f2d}},	//   _निबन, _kèlu, _modă_, _ivye,
   {{0x48eb456c,0x7aef4051,0xbc6a405f,0x26cf8bf5}},	//   _चारो_, äntö, جمان_, fago_,
   {{0x068695bc,0x6b8441c8,0xa5bb7359,0xf99f4053}},	//   оген, qlig, _bród, _apèd_,
   {{0x41b68051,0xad9b4107,0xcb079c0c,0xb77b4052}},	//   цсет, _csús, زيون_, _כאטש,
   {{0xe4764156,0x26cb4398,0x7a40c1c0,0x27e784f5}},	//   _дубэ, _zeco_, _látú, funn_,
   {{0x7f499e11,0xd5758589,0xa5bb45e7,0xfbcf8182}},	//   _fleq, чуць, _próg, نتي_,
   {{0xceb44435,0x236d80da,0x6d86c10d,0x443ec051}},	//   ncə_, _gjej_, rðam, vyt_,
   {{0x2240464c,0x61f64036,0x0566922c,0xa3cccc4b}},	//   nyik_, ntyl, _дван, शीन_,
   {{0x6d5ab35a,0xb603c02d,0x88bc8047,0xdb01c580}},	//   _umta, úšaj, _zněn, _eulà,
   {{0x7d07335b,0x777bc004,0x2731c107,0xceb4403a}},	//   vejs, boux, _lány_, kcə_,
   {{0x2d85c051,0x63b5c574,0x201e8051,0x29130d31}},	//   alle_, ízna, _irti_, _saxa_,
   {{0x657af35c,0xdb9b8087,0x26cb735d,0xf8c6105d}},	//   poth, יסטר, _reco_, वरूप,
   {{0x63aac077,0x61e28480,0x657ac0f7,0x656a8359}},	//   _tufn, irol, qoth, nnfh,
   {{0x63760107,0x78b00089,0x40351394,0x6d4ad4da}},	//   hány, _živý, чевс, _ilfa,
   {{0xd37900e0,0x63a402a7,0x6602c044,0x6d5c735e}},	//   kući_, _giin, _kpok, _amra,
   {{0x7640c99e,0x25a340a8,0x32554bac,0x657c105f}},	// [3a50] nymy, _pijl_, чвар, borh,
   {{0x7f4d72e6,0xbef8c1f9,0x63a4324a,0x6602c12c}},	//   shaq, ्जुन_, _ziin, _mpok,
   {{0x92ad002a,0x7f49813b,0xfa3402cf,0x82341755}},	//   গরী_, _pleq, _فرید, _فریا,
   {{0x661d47ca,0x2907ac53,0x6602f35f,0xdb0b0041}},	//   _trsk, wena_, _opok, _utfä,
   {{0x98aa4036,0x63760107,0x2d85f360,0x661d4402}},	//   _sobą_, gány, ylle_, _ursk,
   {{0x660d6531,0x8cbac945,0xdce8c0a0,0x93bc8379}},	//   mwak, _श्लो, rodě, _orăd,
   {{0x201e8043,0xbc198026,0x644dc0e2,0x3f86b361}},	//   _crti_, сілі_, _ƙaim, blou_,
   {{0x6d438402,0x6d457362,0x6d5c4089,0x63760107}},	//   skna, lkha, _zmra, bány,
   {{0x613d996a,0x63a43363,0x8027805f,0x7640c99e}},	//   _bèlt, _riin, _ڈرام, gymy,
   {{0x69c9817b,0x9f4601cb,0xc5f244e0,0x3439c032}},	//   _iwee, mulé_, עדי_, مسجد_,
   {{0x6284005c,0x63a40f4c,0x7d156aa3,0x7538c147}},	//   _syio, _piin, _mazs, _dovz,
   {{0x6d4af364,0xdb043365,0x25a580c3,0xe4ee02ea}},	//   _elfa, _tuní, _hill_, _जाहि_,
   {{0x9f4626dc,0x7aed597a,0x25a5af2a,0xeb07c8b8}},	//   nulé_, dgat, _kill_, वजीत_,
   {{0xdb1c401e,0x6f09c149,0x55bac0c3,0x69c9828d}},	//   mpré, leec, _המסו, _mwee,
   {{0x63a42057,0xd37900b3,0x6754c01c,0x973cc011}},	//   _tiin, zući_, _رییس_, _sući,
   {{0xf4128009,0x6441f366,0x6e390397,0x3dc90053}},	//   עפן_, myli, ðabó, _fwaw_,
   {{0x248ec077,0x69c98044,0xa3c94389,0x25bfc06f}},	// [3a60] _zzfm_, _nwee, लीस_, npul_,
   {{0xef180017,0x6aa9b367,0x4583401d,0x66043368}},	//   ēļu_, _agef, егув, _ipik,
   {{0x913b00c3,0x69c981ae,0x26140428,0x2d87802d}},	//   _העיק, _awee, दिकी_, dlne_,
   {{0x29180ae6,0x69c980bc,0xe5a65401,0xd3790451}},	//   ldra_, _bwee, _ними, tući_,
   {{0x25a580c3,0x613d8053,0xbb44c025,0x6f160556}},	//   _bill_, _nèls, äämä, _mayc,
   {{0xd37902a3,0x69c98498,0x63760107,0x261d0048}},	//   rući_, _dwee, rány, मिती_,
   {{0x9f98c974,0x06e3c079,0x69c981ae,0x6602f23f}},	//   овку_, _মসজি, _ewee, _spok,
   {{0x7d08d11b,0x998900b4,0xf1be042f,0xddc44017}},	//   weds, _oraş_, ्ठान, rziņ,
   {{0x69d67369,0x63ae736a,0x290a2791,0x9f4601cb}},	//   nsye, _hubn, keba_, culé_,
   {{0x753a00fa,0xdb1c4acd,0x6286736b,0x26d2736c}},	//   ötzl, sprè, _myko, hayo_,
   {{0x201e930e,0x3a200396,0xa2be0048,0x6f09e775}},	//   _urti_, _arip_, _व्ह्, beec,
   {{0x753a80fc,0x98a7c047,0xa5f90051,0xaacc8db4}},	//   _hotz, _koně_, оему_, ारिक,
   {{0xdcf880b3,0x6b82c451,0x753a9b39,0x26d2736d}},	//   hovč, _ikog, _kotz, dayo_,
   {{0x25a50086,0x93bc80cc,0x7bd5321d,0x290a336e}},	//   öll_, _trăd, tszu, geba_,
   {{0x753a8545,0x317ec0fc,0x61e45213,0x4acc8048}},	//   _motz, motz_, eril, ाराव,
   {{0x753a80fc,0x53345d5e,0x7d0a814b,0x48e9039a}},	//   _lotz, нест, hefs, _जाको_,
   {{0xdb040004,0x290a336f,0xc434c0fb,0x7f4d0a8c}},	// [3a70] _etnó, beba_, _رکھت, _ilaq,
   {{0x7afd3370,0x9d1450f6,0x25ad80f8,0x66ed0374}},	//   lfst, ндуч, _ruel_, _झाँक_,
   {{0x661bd487,0x69c9a408,0x69ca86ff,0xf770816a}},	//   zvuk, _swee, सीसी, گال_,
   {{0x63ae4347,0xd5ddc374,0xf99f4303,0x9f46001e}},	//   _dubn, _मिलज, _asèt_, tulé_,
   {{0x7ae49792,0x63bc4053,0x6441f371,0x9f4340a0}},	//   óita, _etrn, zyli, nují_,
   {{0x6739db39,0xc7b8841b,0xba7482f0,0x9f460018}},	//   _sowj, _srđa_, رانت, rulé_,
   {{0x9f434047,0x2d83413b,0xdb04056e,0x613d80b6}},	//   hují_, _ikje_, _luná, _sèls,
   {{0x6e24ec38,0xf0940087,0x2f54c889,0x29183372}},	//   _šiba, ענק_, етьс, zdra_,
   {{0x6561f373,0x63ae41b8,0x6f09f2e6,0x7bd8c40d}},	//   tilh, _zubn, reec, _avvu,
   {{0x9f434047,0x0445c6d8,0x1c45ddf6,0x3f897035}},	//   dují_, деон, дном, hlau_,
   {{0x661d013b,0xb17b04c9,0x3f89433e,0x660419c2}},	//   evsk, trån, klau_, _spik,
   {{0xa5b20064,0x34c60275,0xe9ff400c,0x64550630}},	//   _इंदौ, वर्द, _nhắc_, dzzi,
   {{0x7d173374,0x5155e162,0x6b89cae6,0xd7f8c119}},	//   _baxs, _отку, mleg, ată_,
   {{0x2480806a,0x26cfc0fc,0xd37907ca,0x44210053}},	//   şime_, _hego_, duću_, _brh_,
   {{0x35a3059d,0xe1f9c007,0x628640b1,0x833a4d29}},	//   тарг, ltų_, _syko, очат_,
   {{0x378701bc,0x61e47375,0xdb07834d,0x290a3376}},	//   _общо_, tril, _bují, seba_,
   {{0xd37900ab,0xed5a079c,0x24f6499b,0x61e446ae}},	// [3a80] guću_, _мои_, дчер, uril,
   {{0xa3cb0275,0x64439375,0xe1f9c007,0xb4ac82f6}},	//   रीह_, kyni, itų_, _गले_,
   {{0xdfcf41b4,0x673b83e2,0x25ea4021,0x98bec017}},	//   ليل_, _bouj, _चमकी_, nktā_,
   {{0x236dddd5,0xdb02c018,0xb95b4031,0x0b46a532}},	//   jnej_, _tioé, _atìd, ьнен,
   {{0x656383bb,0xf2d34052,0xf1a76b03,0x776281a8}},	//   finh, _בער_, _कंचन, riox,
   {{0x8e570323,0x344a820d,0x672980b6,0xdcf88043}},	//   וינג_, жчин_, _enej, povč,
   {{0x6b640107,0x20058024,0x6d4e4149,0x8af04080}},	//   zőga, _cpli_, _ilba, biət,
   {{0x6b9bc010,0xf363c59d,0xda0e0048,0x26cfc50e}},	//   gmug, ктын, िबात_, _cego_,
   {{0xe4e6c0d9,0x3cfb9be4,0x201e460f,0x26cfc149}},	//   мінн, ल्हे_, _štih_, _dego_,
   {{0x26cfc1c8,0x799ac022,0x93bc80b4,0xdb1b3377}},	//   _eego_, umtw, _crăc, nstö,
   {{0xc057c11b,0x753c5243,0x61e6053d,0x3f89402c}},	//   дія_, _morz, erkl, ylau_,
   {{0x3a29c158,0xdcfa817a,0x122ac051,0x4444443e}},	//   _šape_, _bitħ, _моей_, iy_,
   {{0x25afc654,0x753c41d4,0xa2db046d,0x3cfb88c5}},	//   _gugl_, _oorz, पृष्, ल्वे_,
   {{0x9f4340a0,0x661d3378,0xf806c0b4,0x8ca008b8}},	//   rují_, rvsk, _жчин, _गृहो,
   {{0x6b51577c,0xf99f4303,0x9999c02d,0x3f89415a}},	//   _låge, _osèr_, ásť_, tlau_,
   {{0x7d18dbcd,0x29184031,0x14bf0759,0x6e22c303}},	//   _havs, _aara_, ्रहण, _krob,
   {{0xddc9c036,0xa5f8453a,0x6aad084f,0x3f897379}},	// [3a90] czeń, мету_, _igaf, rlau_,
   {{0xddc28064,0x6729b37a,0x661d810d,0x236dcb81}},	//   szoś, _snej, _áski, znej_,
   {{0x99498166,0x6f02c02d,0x2b4db37b,0x39841633}},	//   núť_, _oboc, _plec_, röst_,
   {{0x6e22c7f3,0x2918405e,0xceeb401c,0xd3790123}},	//   _orob, _eara_, _بردن_, puću_,
   {{0x9f5a4086,0x6f0d6bbb,0x9105b37c,0x644381f4}},	//   _uppá_, meac, епле, wyni,
   {{0xfbd00646,0xf1e08c13,0x7d18dc6c,0x6f02f37d}},	//   _حتی_, _निरन, _navs, _aboc,
   {{0xd88345dc,0x290cc039,0x57b4428a,0x3206c5bb}},	//   _شهری, deda_, _абст, _apoy_,
   {{0x6443b37e,0x3cff0036,0x394ec085,0x49c9c0cc}},	//   ryni, श्ते_, _alfs_, плин_,
   {{0x7d01b37f,0x6443b380,0x61ed4193,0xdb064303}},	//   _tbls, syni, nual, _dikè,
   {{0x63a9804c,0x6aad3381,0x2bdad284,0x26cfc21b}},	//   _hien, _agaf, _भिखा, _wego_,
   {{0x1da88027,0x78ac8066,0x6e22e3de,0x69d99b5d}},	//   _छूटत, ňové, _erob, lswe,
   {{0x6f02c25d,0x62898033,0x7c3cc041,0x48dbc185}},	//   _gboc, _kyeo, ärra, _गएको_,
   {{0xfce5d2b0,0x7d18dd7e,0x7bc1f382,0x44234033}},	//   _золо, _favs, splu, _lrj_,
   {{0x69d9a746,0x463ac052,0x7f85cfc2,0x3f77c0cc}},	//   iswe, _מענע, róqu, săud_,
   {{0xb8d8054a,0x279641bc,0xeb9a40c1,0xab2a7383}},	//   _छल_, ешар, зив_, пова_,
   {{0xe737422e,0x6fe1009d,0x6f1bd2c5,0x6b960211}},	//   нес_, _फिरं, nduc, _uhyg,
   {{0x0d863384,0x753c7385,0x673d430e,0xb8f60079}},	// [3aa0] _плин, _porz, _dosj, _হা_,
   {{0xb95b41c0,0xdb1c403c,0x6abb9ca0,0x649a442e}},	//   _atìb, mprí, _afuf, птер_,
   {{0x130a8efa,0xd91081aa,0x974345c7,0x76444056}},	//   зней_, ییر_, šćav, syiy,
   {{0xdb1b3386,0x6f0d5440,0x61fbdf41,0xa3e50a3c}},	//   sstö, ceac, ktul, _नित_,
   {{0xa3a9c045,0x69d9b387,0x290cc0e2,0xbd87801c}},	//   _गंज_, gswe, yeda_, کنون_,
   {{0x6e24c0b3,0x3cfb8a1b,0x6f02c23f,0x3b00405c}},	//   _šibo, ल्ले_, _sboc, lfiq_,
   {{0xd0075d20,0xdcfc0077,0x6abb817b,0x9c7c8089}},	//   _пере_, jorč, _ffuf, _odče,
   {{0x7bd89e77,0x8fa3946f,0x69c45521,0xdcfc0570}},	//   rsvu, _басе, opie, dorč,
   {{0x6e2400d2,0xdb00805e,0xdce38026,0xcfd1c02e}},	//   _nrib, _iimà, jonė, _ijẹẹ,
   {{0xd24f8032,0xdb008016,0x0e6380b4,0x7d1c2d43}},	//   _انك_, _himà, _скун, jdrs,
   {{0x61fbeedd,0xdb1c8019,0x395740c3,0x31574009}},	//   atul, _atré, גשים_, גיין_,
   {{0x21f9c1aa,0x6b82b388,0x59dc03fc,0x88bc8047}},	//   bèh_, noog, _बिखर, _sněh,
   {{0x61fbc119,0x6e240c7c,0xf204039d,0x60d500b3}},	//   ctul, _crib, ляро, tazm,
   {{0xf99f40ce,0x291cb389,0x7966c396,0x6f04040d}},	//   _apèn_, ndva_, _déwè, _ebic,
   {{0xf773479e,0x2d9ec0fa,0x291a338a,0xd7e4031e}},	//   هار_, mmte_, _dapa_, літо,
   {{0x69c08054,0x224680f8,0x2d9ec9dd,0x69d9947c}},	//   _otme, kyok_, lmte_, yswe,
   {{0x7bdc43a6,0x4423406f,0x2d814024,0x6368006a}},	// [3ab0] _avru, _srj_, tohe_, rınt,
   {{0x79852c08,0x2246b38b,0x61ed738c,0xdb01c4c9}},	//   _ukhw, dyok_, rual, _utlö,
   {{0x2fd901b4,0x69c0b38d,0xceb4403a,0x6e24c41b}},	//   _توجد_, _atme, mdən_, _šibl,
   {{0x6b829bf4,0x6f1d252a,0xddcd4036,0xceb44080}},	//   goog, ndsc, rzał, ldən_,
   {{0x291a338e,0x23748446,0x6286836b,0x08f80973}},	//   _yapa_, دالح, _økol, _غریب_,
   {{0xa3cc4a3c,0xdb0400fa,0x69d998d0,0x63a9b38f}},	//   _शौक_, _zunä, rswe, _wien,
   {{0x7bdaf390,0x3a24805c,0x6b82a2e0,0x7f49c0fd}},	//   jstu, _ermp_, boog, tkeq,
   {{0x6f0f06ed,0x3eb98530,0x2d830003,0x2366859d}},	//   jecc, _üst_, hoje_, cioj_,
   {{0x5724c032,0xc11581e6,0x6f0f0157,0xfe4382f0}},	//   طريق, _имај, decc, _حکای,
   {{0x6b8d4600,0x7cd98973,0x672d0a05,0xd68485e9}},	//   hlag, _آواز_, _anaj, _сусп,
   {{0x6b8d5020,0x2d833391,0x2905b392,0x05d7908d}},	//   klag, doje_, _ibla_, _डबडब,
   {{0x7d0e3393,0x7d050061,0x4425b394,0xd138c036}},	//   webs, _abhs, _irl_, ają_,
   {{0xee37022b,0x3b1b01d6,0xc4bf0036,0xd0454080}},	//   вня_, _daqq_, ्रूख, rahə,
   {{0xd138c064,0x4425b395,0x7dd881b4,0x66098d0b}},	//   cją_, _krl_, _húsá, _mpek,
   {{0x947911a9,0x61e9c98f,0x998f8026,0x291a3396}},	//   есту_, lrel, lygų_, _vapa_,
   {{0x6e241372,0xdb0e8019,0x6f0f00c4,0x63abc0b4}},	//   _trib, _tubé, cecc, _jign,
   {{0x6e243397,0x2d833398,0x63abdae3,0x61e9f399}},	// [3ac0] _urib, boje_, _mign, nrel,
   {{0xe2974156,0xf2134879,0xf8e1c064,0x08c341ce}},	//   тау_, সমূহ_, पणिय, ибун,
   {{0x6609abed,0x9fa30018,0x628bf39a,0x63abc01e}},	//   _apek, cíón_, _lygo, _oign,
   {{0x6f1ba13f,0x66e68638,0x6b8d739b,0x61e9d6cd}},	//   _cauc, тода, clag, krel,
   {{0x798381f4,0x628ec036,0x2d87c02d,0x2366859d}},	//   fonw, ębok, _okne_, rioj_,
   {{0x6f0f023f,0x3f86f39c,0x2b40112d,0x290c4089}},	//   zecc, _skou_, _loic_, ímač_,
   {{0x290eb39d,0x6f1b818a,0x7d1c4032,0x7d1a8051}},	//   refa_, _fauc, _iars, _vats,
   {{0x63abd02f,0x3a29c6f0,0x3f8dc123,0x61e9f39e}},	//   _cign, _šapa_, gleu_, frel,
   {{0xbb438e9d,0x79838eb3,0x637d0107,0x9605801c}},	//   _тетк, bonw, pénz, _مبلم,
   {{0x4a9b4052,0x2d83013b,0x7e6940e5,0xe7ea8048}},	//   ויפג, xoje_, _žepk, _टिपा_,
   {{0x7bdaf39f,0x6fb6805f,0x14178032,0x6b8d43ad}},	//   ustu, _شمشا, _ليلة_, ylag,
   {{0x61fd04e6,0x7bdb4093,0x6fdc0374,0xb17b0383}},	//   ttsl, וקטו, _फिजू, pråk,
   {{0xceb4403a,0x9f47c166,0x6b8d42e9,0x06d7802a}},	//   tdən_, ntný_, vlag, _হামি,
   {{0x929d8036,0xa2c5002a,0x3f84f3a0,0x64bf04fb}},	//   _cały, ্লেখ, lomu_, ्रेश,
   {{0x61ef00b3,0x1b08002a,0x61fd0ded,0x6568c0f8}},	//   sucl, ষয়ে_, stsl, midh,
   {{0x3a26c065,0xf1bf4031,0x6b8d4396,0x9f47c166}},	//   _krop_, _aráa_, ulag, ktný_,
   {{0x2d8333a1,0x6f1b80fa,0xdb124032,0x999946b1}},	// [3ad0] poje_, _rauc, ágái, екат_,
   {{0x2d8742cb,0x6568f3a2,0x2d83c91c,0x63ad33a3}},	//   ône_, nidh, čjeg_, _hian,
   {{0x6f029954,0x60d74c64,0x63ad2582,0xe1ff33a4}},	//   ffoc, raxm, _kian, ltó_,
   {{0x7c2a010d,0x7ae2c99f,0x6568f3a5,0x6b8d40f6}},	//   _áfra, _ndot, hidh, qlag,
   {{0x0f364009,0x80ca8079,0x61e4806c,0x62fac079}},	//   _ערשט_, _রাজ্, šiln, ্যায়_,
   {{0x6568c0da,0x69dd33a6,0x2b8e805b,0x75d28032}},	//   jidh, isse, hých_, حيوا,
   {{0x6f1b80fa,0xdcfc0017,0x7ae2c085,0xb8cb9933}},	//   _tauc, norā, _bdot, _गण_,
   {{0x93bc800c,0x69dbc232,0xaad359d6,0x6705009d}},	//   _trăn, tsue, तरिक, ष्मक_,
   {{0x3999c01e,0x63b5409c,0xdea1805f,0x7d1c73a7}},	//   hèse_, _huzn, _ایشی, _yars,
   {{0x29110043,0x8cca8eec,0x2369404d,0x22494c47}},	//   jeza_, _स्पो, hiaj_, iyak_,
   {{0x628bc064,0x6d4188a6,0x628d33a8,0xfaff015d}},	//   _wygo, _iola, _ayao, riën_,
   {{0xa5bb73a9,0xf0924093,0xaca3c25d,0xdb08c107}},	//   _pról, מני_, _ntụk, _tudá,
   {{0xbbe044ef,0x69c6012c,0x69dd0b44,0xdb0bc13b}},	//   _पट्क, upke, gsse, _ligë,
   {{0xf8c686d6,0x291cc0bc,0x394cc157,0x6b9b805e}},	//   रुपय, _gava_, ckds_, _lhug,
   {{0x1fb508c8,0x63b547ef,0x69dd0b44,0x2b8e8089}},	//   истр, _nuzn, asse, bých_,
   {{0xe3554523,0x6d434051,0xfaff00bf,0x7bdc33aa}},	//   атуэ, önan, niël_, rsru,
   {{0xe1ff0815,0xdd924228,0x6e9341b4,0x7649f3ab}},	// [3ae0] ctó_, مور_, ملفا, nyey,
   {{0x2d85f3ac,0x20565654,0x18a6517a,0xe6cc842f}},	//   nole_, лтер, газм, ार्ज,
   {{0x3cfb0093,0x0446074a,0x8c46092f,0xd46a10f6}},	//   _אלינ, _сенн, _сене, _чине_,
   {{0x69c40283,0xaab840c6,0x6b514041,0x31b980ce}},	//   _ktie, _अलिक, _tåga, _bèz_,
   {{0xa96a806f,0xd6d9c064,0xdb040032,0xd946a8f4}},	//   нида_, dał_, _bunú, леди,
   {{0xb17b0c9f,0x6f1d48f1,0x9f430089,0x6568c149}},	//   rsåg, _zasc, čké_, xidh,
   {{0x26d933ad,0x7f40823b,0x37aaf3ae,0x4f968c93}},	//   yaso_, _tomq, нтин_, _брау,
   {{0x3a26f3af,0x291cf3b0,0xbea68660,0x63a0c022}},	//   _prop_, _sava_, _бабк, ummn,
   {{0x63bb40b3,0x6448d799,0xbd6af3b1,0x63a2b3b2}},	//   _čuni, wydi, ерне_, mmon,
   {{0x845a9512,0x6448d6cd,0x69fb4052,0x26d915ca}},	//   _прет_, tydi, עליק, waso_,
   {{0x337533b3,0x69c433b4,0x4c94d124,0x291e8119}},	//   игор, _atie, ринс, _iata_,
   {{0xa3c94028,0x7649c00d,0x6568f3b5,0x645c005c}},	//   लीट_, byey, sidh, dzri,
   {{0x2d85e0ae,0x63ad33b6,0xef1f0676,0x5ce7011b}},	//   bole_, _vian, rdü_, люва,
   {{0xe693c1b4,0x63a2b3b7,0x69dd33b8,0x26d933b9}},	//   _الهد, hmon, rsse, saso_,
   {{0x6f0453d6,0x4427c02f,0x63a28396,0x6db2c036}},	//   ffic, _grn_, kmon, _wład,
   {{0xa3b9de7d,0xa6db4397,0x69c4017a,0x9f47c2f4}},	//   _अंत_, _boða, _ftie, trné_,
   {{0x61e48359,0x5f74001c,0x7bde56d1,0x2366c398}},	// [3af0] áill, _داور, espu, _mmoj_,
   {{0x3a2900c4,0xd6d9c036,0xdd92005f,0x290773ba}},	//   _irap_, zał_, _ووٹ_, ýna_,
   {{0x6aa64079,0x48154077,0x60d54066,0xe81493a2}},	//   গুলো, рмес, _vezm, _थैला_,
   {{0x7bc500f7,0x27ec0066,0x7d1e00a0,0x63a28107}},	//   _ithu, ádne_, _zaps, gmon,
   {{0x964743d0,0x3f51c031,0x2d85d7e0,0x06d7802a}},	//   _сэнд, _báun_, yole_, _হাদি,
   {{0xed5140fb,0x18698798,0x63a2b3bb,0x61ed73bc}},	//   _بھر_, кали_, amon, mral,
   {{0x200c8004,0x7f42c057,0x8835859d,0xe9df0032}},	//   _cpdi_, _booq, рэлц, hsú_,
   {{0xa3ea40aa,0x25aec061,0x39434247,0x6b9b89f3}},	//   _मित_, _aifl_, _hojs_, _uhug,
   {{0x61ed4cc2,0xd6d9c062,0x256c0031,0x673bf3bd}},	//   nral, rał_, _jólè_, rjuj,
   {{0x661b8d08,0x60d70033,0x23bac0fd,0xa5bb434d}},	//   _isuk, _nexm, _bëj_, _prój,
   {{0x764b802c,0x7bc5004d,0x61ed4166,0xb4c18389}},	//   lygy, _nthu, hral, ंडी_,
   {{0xf3f1c044,0x60d78017,0xcb6a13fd,0x6386059d}},	//   rụ_, šamī, таме_, ргма,
   {{0xbb84c1b4,0x04b6011b,0x26110036,0x2d87809d}},	//   _الني, исвя, दौली_, oone_,
   {{0x18a5cc8a,0x98a5d9a2,0x3a290535,0x661b812c}},	//   _калм, _киле, _drap_, _msuk,
   {{0x3a2933be,0xdb1c8086,0xdb0e830d,0x7bc5129a}},	//   _erap_, _strí, _subí, _cthu,
   {{0x6d5573bf,0xaec65520,0xcc3640fb,0x7ae40a48}},	//   _alza, рбал, یراع, _udit,
   {{0x3a2933c0,0x2baf83b0,0x4aaa54e9,0x4420800c}},	// [3b00] _grap_, _जंजा, ткан_, ̉i_,
   {{0xe3ba0025,0x7afbb3c1,0x89db00c3,0xc0e6568c}},	//   _ибо_, _acut, _שחיי, рожк,
   {{0x6d43c69c,0x6e29b3c2,0x3dc94340,0xdd01c0a0}},	//   _mona, _areb, apaw_, _štěp,
   {{0xdb1c80b4,0xb2268156,0x256c01c0,0xe739802c}},	//   _strâ, имел, _fólè_, _siŵr_,
   {{0x6d58b3c3,0x66768d9e,0x799c402c,0x3b834466}},	//   thva, جدار, _thrw, _фляг,
   {{0xe5e58032,0x92ce402a,0x63a46e40,0x07e691e8}},	//   إثني, _রায়_, lmin, ацим,
   {{0x8fa69807,0x63a280b1,0x37e359a2,0x661bb3c4}},	//   _ваве, pmon, _морг, _esuk,
   {{0x6e2dc11f,0xab7481aa,0x24534032,0xdb078086}},	//   _šaba, _انرژ, _بنفس, _stjö,
   {{0x6e298545,0x6db2c036,0x0e6694ea,0x60dadecf}},	//   _greb, _słab, _ткан, tatm,
   {{0x442a5208,0x2d87b3c5,0x6299c036,0x20b980d7}},	//   _krb_, cone_, _dzwo, _быць_,
   {{0x6d43ce6e,0xaee8c079,0x3cfe4fb2,0x69d40185}},	//   _dona, ক্ষণ_, _लाने_, बीसी,
   {{0x3a2900fd,0x6602812c,0x60daf3c6,0x7bca80cb}},	//   _prap_, otok, satm, mpfu,
   {{0x7bca80c3,0x60c200cc,0xdb0e80d2,0x7a0a4017}},	//   lpfu, _şoma, _mubà, nētā,
   {{0x442a6514,0xd24fc231,0xb866c01c,0xa18700d7}},	//   _orb_, _تنه_, _پاتو, рымл,
   {{0xf36751cd,0x2913403c,0xd7fac119,0x7b674051}},	//   атан, vexa_, _рул_, атае,
   {{0xe73801bd,0xc2e8c079,0x23bc0107,0x61e2c02d}},	//   _већ_, ক্রি_, _díj_, _kvol,
   {{0x6d43e97a,0x2b920066,0x5d554119,0x6b8d33c7}},	// [3b10] _yona, dách_, бкат, _ikag,
   {{0xdb0bc34d,0x58870007,0x93bc80cc,0x9f43402d}},	//   _vigé, _выма, _vrăj, nujú_,
   {{0x2d8780c4,0x7d15006a,0x442a72bc,0xad9b030d}},	//   vone_, mezs, _crb_, ctúa,
   {{0x29134ad6,0x200155fa,0x63a44696,0x92598051}},	//   sexa_, rthi_, cmin, лает_,
   {{0x7afd4010,0x672089b7,0x200141aa,0x9f048567}},	//   _icst, _damj, sthi_, تونو,
   {{0x5dda0052,0x6b73c0cc,0x45d458f9,0x3f4740b2}},	//   אַקס, măgi, _форс, _tõus_,
   {{0x3dc6c033,0x2b920066,0x6d5af3c8,0x9f43402d}},	//   _atow_, bách_, dhta, dujú_,
   {{0x67208020,0x2d540134,0x32020089,0x2129c50c}},	//   _gamj, _näen_, ytky_, _şah_,
   {{0xaa49c051,0x48fe4185,0x6e2981c6,0x3e188523}},	//   уппа_, _लामो_, _ureb, _котэ_,
   {{0x21210033,0xaca301c0,0x26dd820e,0x63a453b3}},	//   _nahh_, _amọd, lawo_, zmin,
   {{0x2b9c8185,0x7c9581b4,0x7f440018,0x6db2c036}},	//   síce_, _الاص, _poiq, _płac,
   {{0x69c9f3c9,0xdb0e8c1e,0x26ddaba3,0x6b55f261}},	//   ppee, _kubá, nawo_, _fága,
   {{0x9f434166,0x42798009,0xdb1c8036,0xee2ecc85}},	//   bujú_, ראָג, _zwró, _эн_,
   {{0x41cf8045,0xa06a0030,0x63a46cde,0x442787fb}},	//   सीएस, гага_, wmin, ovn_,
   {{0x6d4533ca,0x2cac0041,0x26dd811c,0x25b940c4}},	//   _doha, ädd_, kawo_, _ausl_,
   {{0xdb0d40cb,0x63a473cb,0x6e4706a6,0x2498f3cc}},	//   rmaß, umin, ërbë, ürme_,
   {{0x78c6c05f,0xf1b98043,0x6d8d9b87,0x26d94396}},	// [3b20] _érvé, _kršu_, núas, _deso_,
   {{0x05b50045,0x6e3b00c3,0x2259c02d,0xb4c18bc0}},	//   ंदरब, _עתיד, úsky_, ंडो_,
   {{0x26c04559,0xa2aa8d6c,0x232a82d2,0xe3b2405f}},	//   pcio_, जेन्, ложи_, سرا_,
   {{0x2d8a1647,0x27fac0d9,0x2bb7c0b4,0xa3ccc9fd}},	//   lobe_, _åpne_, _căci_, शीट_,
   {{0x3945b3cd,0xdb1c4b4c,0x764d484f,0x6722b3ce}},	//   _bols_, rprä, cyay, rdoj,
   {{0xdce3803f,0x2d8a33cf,0x225fc0b3,0x6d450004}},	//   tinā, nobe_, dzuk_, _xoha,
   {{0x9f434166,0x60d8cac0,0x26d973d0,0x2b920066}},	//   vujú_, _revm, _yeso_, pách_,
   {{0x6b55c018,0x236dc036,0x2c57c03a,0x660473d1}},	//   _pága, giej_, cədə_, otik,
   {{0x2d8c805c,0xdb0f4396,0x07a38007,0x61f64138}},	//   _tkde_, _dicè, _хатн, nuyl,
   {{0x6b8d33d2,0x660473d3,0x61e29b33,0xc7b88123}},	//   _skag, itik, msol, _srđu_,
   {{0xdb1c8047,0x6d4533d4,0x48fd4384,0x9f43402d}},	//   _ztrá, _roha, र्टो_, rujú_,
   {{0x236dc036,0x6d4533d5,0x61f64105,0x644e0026}},	//   ciej_, _soha, kuyl, dybi,
   {{0x63ba865a,0x60de6561,0x61e2c347,0x926b0ff8}},	//   _hutn, kapm, _uvol, урна_,
   {{0x63ba801a,0xd8514031,0x01fbc0c3,0x6d5d8007}},	//   _kutn, _bọ́_, _עפול, _įsak,
   {{0x660473d6,0x776d4018,0x2c57c080,0x24580156}},	//   etik, tiax, yədə_, барь_,
   {{0x2121042c,0x3d064959,0x201e8aef,0xc7b80026}},	//   _wahh_, स्से_, _msti_, сёр_,
   {{0x8b044047,0x6d45034c,0x6f0d33d7,0x248d4017}},	// [3b30] ířat, _toha, _ibac, _ņem_,
   {{0xdd0e003a,0xdb0f4018,0x60de4033,0x26dd81ae}},	//   mışd, _micé, gapm, wawo_,
   {{0xdb0e862a,0x61e433d8,0x26d9595a,0x660460db}},	//   _subá, _zvil, _teso_, atik,
   {{0x62354119,0x2b46c1c8,0x93bc8379,0xd7fbcd89}},	//   _дему, _nooc_, _grăi, רהאל,
   {{0x201e8dd2,0x3945b3d9,0x6280805c,0x26dd811c}},	//   _asti_, _pols_, _cxmo, rawo_,
   {{0x69cd4303,0x629d4017,0x6e2d0b29,0x98b84026}},	//   mpae, _izso, _mrab, _porą_,
   {{0x75218157,0xa2ce4048,0x64a283bf,0x7f9ec13b}},	//   _valz, तरच्, маша, zëqe,
   {{0x9b58935b,0x58948032,0x61e2a556,0xdff2c045}},	//   _лист_, أجهز, bsol, _अमजद_,
   {{0x60c4c03a,0xfaf9c017,0xd67b808c,0x6b89c206}},	//   _şima, rgū_, _صحرا_, roeg,
   {{0xf1bf005f,0x3945821b,0x6a14805f,0xbc84c0d1}},	//   tván_, _uols_, _عبقر, ườn,
   {{0xe73a047f,0x07a6093d,0xd009c777,0xe787c2fd}},	//   аен_, жанн, шене_, _лудо,
   {{0x6604410e,0x644e0007,0x9954402d,0xa6d7802a}},	//   ytik, vybi, mäť_, _হাঁট,
   {{0x2d8a33da,0xf1b5409d,0xe28ed5a4,0x60da8165}},	//   tobe_, _अंगन, _ца_, _yetm,
   {{0x61e48359,0x660440e5,0x6d4773db,0xdcf880a0}},	//   áili, vtik, _noja, dově,
   {{0x8b26401d,0xa3d408b8,0xf74608d3,0x61e285ca}},	//   одве, सीं_, _меко, zsol,
   {{0x3947cbc2,0x6e2d0498,0x6f0d0044,0x644e0007}},	//   _hons_, _frab, _gbac, rybi,
   {{0x5ea80079,0x60de4033,0xcb12c21d,0x2480806a}},	// [3b40] _ক্রে, tapm, ולן_, ğimi_,
   {{0x21a3401b,0x6d476cbb,0x23814007,0x6b584996}},	//   диум, _coja, vėje_, _díga,
   {{0x69c9811c,0x3a2d85dc,0x293704e0,0x6d4773dc}},	//   _atee, _arep_, _ואין_, _doja,
   {{0x6b8b82a4,0x6b58450e,0x409b00c3,0xddd64036}},	//   gogg, _fíga, _כביס, rzył,
   {{0x888444e8,0x6b814107,0x7ae9b3dd,0xeda686b1}},	//   _کیان, élge, _ddet, ошко,
   {{0x201e807a,0xe4da4a87,0xe918831e,0xe7ea8cfc}},	//   _psti_, _خوست_, сокі_, афик_,
   {{0xd7f081b4,0x6b8bb3de,0x69c99cfc,0xfc0351e1}},	//   ركة_, bogg, _etee, _опро,
   {{0x49064185,0x3f8fc05c,0xdb17403c,0x3a2000ab}},	//   स्रो_, _ckgu_, _puxé, _osip_,
   {{0xdb04401e,0xd04e0080,0xc878c080,0x7791c01c}},	//   rmiè, rabə, dağa_, ریها,
   {{0x94aac42e,0x61e4473b,0x0caac2d2,0x6f0d0157}},	//   итна_, isil, итни_, _sbac,
   {{0x41b4c2f0,0x66040073,0x6d48b3df,0x6e2d33e0}},	//   _کمتر, _aqik, _ioda, _srab,
   {{0xc178c039,0xdb0f4032,0x80dd002a,0xf1f0417e}},	//   snė_, _ticé, _বাধ্, _चिढ़_,
   {{0x6b5cc107,0x637ec017,0x61e4465a,0x60dc414d}},	//   _cége, cīna, jsil, _oerm,
   {{0x224bc851,0xdd0e0080,0xe6d345cb,0x28f7c156}},	//   äcke_, rışd, तर्ज, _дешь_,
   {{0x61e642e9,0x6b5873e1,0xdb1ac621,0xdb6b4f75}},	//   _avkl, _síga, _ettå, арал_,
   {{0x6d4885ef,0x2616008f,0x99928166,0x5ed50079}},	//   _loda, _पैकी_, ždňa_, _থাকে,
   {{0x3eaf4600,0x6d48b3e2,0xdcbb411b,0x6e2d01c6}},	// [3b50] ägt_, _ooda, аще_, _urab,
   {{0xceb400c3,0x7d18b3e3,0x44f50030,0xed598123}},	//   _קיץ_, jevs, _эпос, _kuže_,
   {{0x6d4747a7,0x69c9818e,0x4974031e,0x657ae5b7}},	//   _voja, _stee, _ілюс, inth,
   {{0xed598047,0x6d48868a,0x63bc73e4,0x9954402d}},	//   _muže_, _aoda, _durn, väť_,
   {{0xeb3a4009,0x7c2e40cb,0x332480f6,0x7ae0c09c}},	//   _הערש, _erbr, _damx_, damt,
   {{0x6e20401f,0xf771c2cf,0x442ec34b,0x6b8d73e5}},	//   _âmba, کات_, _orf_, loag,
   {{0x7523f3e6,0x290102c0,0x2d8cc127,0x00000000}},	//   _ranz, _mcha_, dode_, --,
   {{0x85b987e3,0x6b8d4140,0x7ae0f32b,0xb5fb0107}},	//   _глас_, noag, gamt, zzáa,
   {{0x61e90242,0xee36c39d,0x442ef3e7,0x6f09f3e8}},	//   šelj, зны_, _arf_, rfec,
   {{0x6b5cc107,0x442ec3ad,0xf770c64c,0x7afd09dd}},	//   _rége, _brf_, _یان_, egst,
   {{0x6b8d41a8,0x6b96423d,0x6b5cc1c0,0x3d008314}},	//   koag, ylyg, _dégb, _राते_,
   {{0xe4564009,0x7523e44a,0x889a8093,0x6376006c}},	//   פירט_, _wanz, _הבעי, kšne,
   {{0xe8eec8e5,0xa92405e5,0x66bac0c3,0x479ac323}},	//   _пл_, ížov, _המנה, _פינס,
   {{0xc104c1b4,0x88bcc047,0xdb1ac016,0x9f43180a}},	//   _يوني, nděl, _autè, čká_,
   {{0x475a410e,0x290113a9,0x6b55c086,0x442102cd}},	//   брая_, _dcha_, _lágm, _csh_,
   {{0x7d188077,0xdce70017,0xf74342e0,0x97ae0080}},	//   zevs, rijā, несо, üşdü,
   {{0x63a433e9,0x26d24010,0x6b9673ea,0x31712a1f}},	// [3b60] _ihin, rbyo_, rlyg, bizz_,
   {{0x6296009c,0xceb44080,0xc006002b,0x8ccb0045}},	//   _iyyo, ddət_, _епок, तुदो,
   {{0x63a433eb,0x9c7cc142,0x14d70052,0xa5bb53ab}},	//   _khin, pače, _מויל_, _brós,
   {{0x68e1c27a,0x60c54e94,0x37bdc079,0xdfcf4182}},	//   hald, achm, _আবার, اين_,
   {{0xf3f1000c,0xba764200,0x0cdbc09d,0x2007b3ec}},	//   ợc_, _راحت, _मजूम, etni_,
   {{0x68e1f3ed,0x61e2404f,0xe6d90045,0x6d488149}},	//   jald, šols, _भज्ज, _qoda,
   {{0x68e1f3ee,0x8af00080,0x7c2e4011,0x7afd1fae}},	//   dald, _aləm, _urbr, ygst,
   {{0xad6681aa,0x7d1880b3,0x207b4052,0x6b51559a}},	//   _کاره, sevs, _האלא, _pågi,
   {{0x0566b3ef,0x26ddc033,0x672667d8,0x93bc8119}},	//   _еван, _dewo_, _makj, _arăt,
   {{0x394a652a,0x291a48dc,0x237f4047,0xed598011}},	//   _jobs_, nepa_, čuji_, _puže_,
   {{0xf2dbc079,0xdeefc119,0x63a2d8de,0xd00f944f}},	//   _ধারণ, _пы_, _thon, _ملل_,
   {{0x7afd0017,0x8cccc4e3,0x2d8ccdc5,0x09b50048}},	//   ugst, _द्रो, sode_, ंद्य,
   {{0x46a3ce6d,0x61e60838,0x442ec0b9,0xe81ec048}},	//   _зацв, gskl, _wrf_, _बनवा_,
   {{0xed5984f9,0x4a53c11b,0x1874c11b,0x442100fd}},	//   _tuže_, _якіс, _огля, _psh_,
   {{0x31710283,0x7ae2b3f0,0x672640a8,0xb4e8c047}},	//   rizz_, kaot, _bakj, यणी_,
   {{0x6d4ac0b1,0x656e4bd3,0x6c7bc0c3,0x2138499e}},	//   _hofa, _ambh, _לאופ, _anrh_,
   {{0x7ae28105,0x7afdc016,0x67264b89,0x291a4070}},	// [3b70] daot, òsti, _dakj, fepa_,
   {{0x69cd012c,0x6d5c405e,0xecdac02a,0x6ca740c5}},	//   _itae, _clra, _দাঁড, преж,
   {{0x63a9f3f1,0x60c573f2,0x6b8d73f3,0xbb1b07b0}},	//   ymen, rchm, poag, boît,
   {{0x6d4af3f4,0x21258396,0x656e40c2,0x6f02c05e}},	//   _lofa, _salh_, _embh, _ncoc,
   {{0x5a344289,0x9a84443e,0xdb01c4c9,0xb5fb05ca}},	//   _знят, _зурл, _kulö, zzán,
   {{0xa3d4049d,0x6f0d497f,0x34dbd001,0x92d9002a}},	//   सीक_, lfac, _मजेद, ালয়_,
   {{0xb8e58191,0x6e22e912,0x6726421b,0x3209409e}},	//   _एल_, _asob, _yakj, ltay_,
   {{0x0dc9ea1b,0x7aed3267,0xa6db410d,0x2d83c11a}},	//   олий_, _ndat, _boði, čjem_,
   {{0x75274013,0x2b4b421b,0x80e14036,0x629a0036}},	//   _kajz, _mocc_, _फ़ाइ, ętok,
   {{0x61e9b3f5,0x63a41af2,0xdb1c84e2,0x9f58413b}},	//   _ivel, _shin, _aurè, turë_,
   {{0xdbf20047,0x6e22d63e,0x212bc0a0,0x2b5fc35d}},	//   třít, _esob, ěch_, phuc_,
   {{0x3255cabe,0x3a29c011,0x399444c9,0x25bfb0ad}},	//   _овер, _šapu_, läst_, _kuul_,
   {{0xdb1c8396,0x6d4ac8b7,0x3cfe425c,0x6f0d73f6}},	//   _durè, _fofa, _लाले_, dfac,
   {{0x7aed2122,0x6f1bf0d5,0xa3e6c285,0x10a61a2c}},	//   _edat, leuc, _पिच_, дигн,
   {{0x46cb4094,0x6f0d73f7,0x68e3b3f8,0x61e60168}},	//   _ụtọ_, ffac, iand, sskl,
   {{0x63a433f9,0x9f584016,0x2127c00c,0x6b998046}},	//   _uhin, ltrú_, _hanh_, jlwg,
   {{0x91e34c3f,0xe3a704e8,0x0d860157,0x13d68079}},	// [3b80] коте, _تشوی, _олин, সওয়,
   {{0x6609ebbe,0x3f80c007,0x6abb84db,0x9c7cc147}},	//   itek, čiui_, _aguf, lača,
   {{0x2127c00c,0x44234674,0x63be0077,0x61ed82bc}},	//   _manh_, _csj_, _uupn, šall,
   {{0xa3c18743,0x2127c00c,0x75e380eb,0x3f8f8017}},	//   ंदन_, _lanh_, _ọzar, gogu_,
   {{0x2127c0d1,0xdee381f6,0x4cdec02a,0x66e384e9}},	//   _oanh_, точи, _মাসু, точа,
   {{0x61fbd65c,0x25bf9dcf,0xf1bf580a,0x2ee01a5e}},	//   duul, _duul_, _práv_, _leif_,
   {{0x55770052,0x6609f3fa,0x442c41cb,0x6f1bc414}},	//   ועסן_, etek, _éd_, feuc,
   {{0x1f5b4052,0xdb02c35d,0xf772dc0c,0x7c3eeac4}},	//   ַדיא, _khoé, ضاع_, _àpri,
   {{0xb0cf808f,0x6d4ac043,0x9f454171,0x28cf8191}},	//   _स्वग, _pofa, élé_, _स्वि,
   {{0x9986c123,0x4cd88079,0xab640036,0x80a54314}},	//   _broš_, _ঠাকু, óżni, _करमे,
   {{0x9c7c82d8,0x6e2433fb,0xd0f74093,0xdb0f73fc}},	//   _beče, _asib, ומית_, _sicí,
   {{0x9c7cc242,0x6d5e1f1a,0x7ae44051,0x61fbc31c}},	//   gača, _alpa, jait, buul,
   {{0x7d1af3fd,0x394c8017,0x6b5cc303,0xad9b0359}},	//   pets, _kods_, _géga, ltúi,
   {{0x92bf0079,0x9f4ec359,0x795d888b,0xf1b88085}},	//   ইরে_, irfí_, _kèwa, _jiġ_,
   {{0xad9b0032,0x75274107,0xeb934865,0x3869c6df}},	//   ntúi, _rajz, نظر_, _ƙare_,
   {{0xed59b1fa,0x25b8405e,0x6e2dc054,0x291ca3c0}},	//   _muža_, _airl_, _šabi, heva_,
   {{0x6f0d55b7,0x6d45400b,0x7bce73fe,0x3a32014b}},	// [3b90] rfac, tjha, _atbu, _gryp_,
   {{0x7d1c02b0,0x2127c082,0x9c7c823e,0x1af5c079}},	//   cers, _xanh_, _zeče, _আসছে_,
   {{0x61e9b3ff,0x6d588ded,0x2d910ff5,0x77a5c018}},	//   _svel, dkva, moze_, lóxe,
   {{0x6b82ddd2,0x23814007,0xa3e88632,0x7ae44359}},	//   _njog, mėjo_, _बिज_, cait,
   {{0x395e80b6,0x77a5c004,0x44314036,0xe9d8913b}},	//   _blts_, nóxe, _wrz_, дкі_,
   {{0x69c0b400,0x6b82f401,0x44237402,0x2d913403}},	//   _dume, _ajog, _tsj_, noze_,
   {{0x61fd29b5,0x23814007,0xa7b5c6b1,0xdb160053}},	//   husl, nėjo_, нсиј, _fiyè,
   {{0xe9d9d40c,0x68e57404,0x2d91091f,0xba25c579}},	//   пки_, lahd, hoze_, едик,
   {{0x44330018,0xe8e0000c,0xf1bf4070,0x2bd7c0b2}},	//   _lrx_, _liều_, _irás_, _भौजा,
   {{0x6b55f405,0x6f041b05,0x653a4009,0x23814039}},	//   _mági, _scic, ִערד, kėjo_,
   {{0xb5fb005f,0x6616276e,0x26098070,0x67298303}},	//   szál, _spyk, lúo_, _kaej,
   {{0x7d1c3406,0x6d5e005c,0x98a34077,0x7d0500cb}},	//   wers, _slpa, _najč_, _achs,
   {{0x7c2527d8,0x7bc1b407,0x65750033,0x26098019}},	//   _ashr, _hulu, fizh, núo_,
   {{0xd138c036,0x1869c0c5,0x7d1c0c3e,0x2b5f8580}},	//   gląd_, _нали_, uers, _lluc_,
   {{0x6f1d143b,0x69cf403f,0xa879c009,0x7d1c0414}},	//   besc, _atce, _מאַר, rers,
   {{0x6e241899,0x2d835083,0x6f1d2640,0x39580590}},	//   _tsib, _ajje_, cesc, skrs_,
   {{0xe1fa7408,0x291c803a,0x24f6590e,0x6b840cc0}},	// [3ba0] яга_, yeva_, ечер, _ijig,
   {{0x673b8396,0x23814007,0x8d764032,0x6299c35d}},	//   _anuj, bėjo_, راءا, _mywo,
   {{0x6b8400b3,0xdb16002e,0xa3db408f,0xe1ff0559}},	//   _kjig, _aiyé, ढील_, nzón_,
   {{0x5de681bc,0xed59897c,0x63ad7409,0x0686964e}},	//   ежда, _ruža_, cman, нген,
   {{0x9c7ccee2,0x69c0813b,0x82d70052,0xfe7289ab}},	//   jačn, _qume, גונג_, ددا_,
   {{0xd9439bb0,0x680a803a,0x9c7cc56e,0x7bc54022}},	//   лечи, _hədi, dačn, bqhu,
   {{0x7bce44d3,0xb4dc5c79,0x7ae0b40a,0x98a3423f}},	//   _utbu, ठरी_, _temt, _бире,
   {{0x6b9bc10d,0x4425aa4b,0x68e1809d,0x5694ce50}},	//   glug, _dsl_, _eeld, кайт,
   {{0x3207c59d,0xe7e0817e,0xc33340c3,0x6aa40ca0}},	//   нхэн_, _गौरा_, רוח_, _nzif,
   {{0x4444740b,0x61fd00b2,0xbebb013b,0x5066c16f}},	//   ox_, vusl, ndëv, етма,
   {{0x98a4809d,0x2498c065,0xdbdbc070,0x387884c9}},	//   _ओरिए, ærm_, _báñe, _ärr_,
   {{0x637600b3,0x680a8080,0xb286c119,0x7ae6340c}},	//   tšna, _nədi, _пылк, gakt,
   {{0x9f4781aa,0xa3dc8314,0xf8d1c8bc,0xdb09c107}},	//   éné_, तीर_, _द्वय, _önál,
   {{0x6363454a,0xd5b8004c,0x444440f1,0x3f804036}},	//   _mõne, есс_, kx_, eniu_,
   {{0x25ed017e,0x7b060025,0x61fd0526,0x680a8080}},	//   _अटकी_, ättö, susl, _bədi,
   {{0x2d87406c,0x61fd340d,0x29050283,0x6b8400fd}},	//   čnem_, pusl, żla_, _gjig,
   {{0x7f98830d,0x9f5a81cb,0x2385c017,0xdcf888c7}},	// [3bb0] níqu, cupé_, nēja_, novē,
   {{0x9c7cc066,0x61ed804f,0x2b9c80a0,0x2ba5162f}},	//   načo, šalk, lích_, _गीता,
   {{0x26c940b3,0xe8028185,0xf48741eb,0xe1ff0070}},	//   pcao_, रूमा_, хуан, luó_,
   {{0x45d598f9,0x2d9c8019,0xb5fb0089,0xdbe3c1c0}},	//   водс, elve_, vzáj, _déèt,
   {{0x9c7cc066,0xdd91461e,0x05b2c036,0x44444f0b}},	//   xačn, _نوح_, ीदाब, ax_,
   {{0x660d740e,0x672d454a,0x9c7cd487,0x212a424f}},	//   mtak, ldaj, vačn, _gabh_,
   {{0x649881bc,0x7ae2f40f,0xd7f841bd,0x3a26c031}},	//   нтър_, _beot, _пут_, _asop_,
   {{0x9c7cf410,0x2b9c8047,0x660d4ce6,0x6b5cc1cb}},	//   tačn, jích_, otak, _dégo,
   {{0xe78484b6,0x4423024c,0x9f4d0166,0x7ae60833}},	//   _суро, hwj_, budú_, vakt,
   {{0xdb1c858a,0xa2d9a2cf,0x236000b3,0x6b9601a7}},	//   _strø, मरक्, _slij_, _skyg,
   {{0x660d7411,0x61e9e374,0xed59806f,0x7e7b4123}},	//   htak, ssel, _hužo_, _župl,
   {{0x25644107,0x63bb812c,0x916280d1,0x795d8303}},	//   _zöld_, _jiun, _tự_, _kèwo,
   {{0x2b49411f,0x61eb96dc,0x98a580b6,0x2385c8c7}},	//   djac_, nsgl, _malč_, cēja_,
   {{0x2a697412,0x61ed2eeb,0x2d540051,0x660d40d9}},	//   dzab_, _dval, _näet_, dtak,
   {{0x660d4e07,0x3ebf807a,0x49098185,0x28c68285}},	//   etak, _ogut_, _सानो_, रुटि,
   {{0x6619c21b,0x93fac3bd,0xa2c31142,0x680a803a}},	//   _kpwk, _חלקי, रखण्, _qədi,
   {{0xaa461653,0x7e69c0fa,0x7ae401f4,0x4427d351}},	// [3bc0] _репл, nzep, _ieit, _hsn_,
   {{0x4427c05c,0x672bc0fd,0x69fb02a6,0x3f804007}},	//   _ksn_, _lagj, _קליק, sniu_,
   {{0x998003de,0x62898018,0x6faa41bd,0x63bb805e}},	//   _križ_, _axeo, _овог_, _biun,
   {{0x7ae43413,0x69c43414,0x6363409d,0xe8134027}},	//   _jeit, _kuie, _põne, _ठहरा_,
   {{0x444440f6,0x2b9c8066,0x7bc3f415,0x777d003c}},	//   sx_, níci_, _lunu, érxi,
   {{0xae1ccb35,0x6b55c51e,0x38c882cf,0x2385c017}},	//   _बैगन_, _mágu, راتی_, vēja_,
   {{0x63bb982f,0x5f0685a6,0x317b0093,0x63660019}},	//   _fiun, _изва, ורסמ, _góng,
   {{0x63a9a4e4,0x2d54009d,0x248080cc,0x7ae4035b}},	//   _ghen, _käes_, ăim_, _neit,
   {{0x24928064,0x68e3e670,0x6d5c0086,0x15ee0027}},	//   łym_, _bend, kkra, _जिगर_,
   {{0xdbd9801d,0x6d5c07a7,0x2385c03f,0x6f160047}},	//   _açõe, jkra, rēja_, _abyc,
   {{0x2bbbc342,0x3a26c0b6,0xdd8f8301,0x01354009}},	//   _ऊंचा, _wsop_, _بول_, אָרט_,
   {{0xe1ff046a,0xbf13c05f,0x63a980fd,0x69c40a26}},	//   tuó_, _نومب, _xhen, _buie,
   {{0x7e69c036,0x22870119,0x660d4561,0x201a00b2}},	//   czep, тунг, xtak, _appi_,
   {{0x040d800c,0xceb3821d,0x3f823416,0x48fe44ef}},	//   _nướn, ייר_, anku_, _लागो_,
   {{0xa18400d7,0xdb1cb417,0x6faf4285,0x68e73418}},	//   рыял, _aurí, ंगलू, rajd,
   {{0xe0b7c009,0x636600e1,0x7ae43419,0x6f044157}},	//   _בלוט_, _cónd, _geit, ggic,
   {{0x6600c056,0x63a9802c,0x69c41871,0x7bc3c360}},	// [3bd0] numk, _rhen, _guie, _zunu,
   {{0x3a291514,0x636603e9,0x212cb41a,0x80dd0079}},	//   _isap_, _póng, _nadh_, _বাক্,
   {{0x63a9918d,0xdb1c80d2,0x33204580,0x4e94016a}},	//   _phen, _eurí, beix_, _مشیر,
   {{0x4ae30371,0xfe70405f,0x6600f41b,0x6445413b}},	//   परिव, حدہ_, kumk, rxhi,
   {{0xa3e5b41c,0x672d341d,0x63bd40f8,0x7bc5341e}},	//   बीन_, _maaj, _iisn, _huhu,
   {{0x68e8d8da,0x2409879c,0x9c7c8570,0x212c8061}},	//   jadd, енки_, _seča, _cadh_,
   {{0x68e8e55b,0x63bd741f,0x6b5cc107,0x26c98004}},	//   dadd, _kisn, _tégl, ñaos_,
   {{0x2d833420,0xe1f9c007,0x3ebf80c9,0x0325c156}},	//   hnje_, trų_, _ugut_, удин,
   {{0xd9e37421,0x68e8f422,0x6600e4fe,0x7c2880b6}},	//   गठित_, fadd, gumk, _esdr,
   {{0x320dc057,0x6e29800b,0x7fd5c176,0xdb0f401f}},	//   rtey_, _iseb, лімі, _ficç,
   {{0x7bc53423,0xc4d28093,0x61ed403a,0x6d5c1127}},	//   _nuhu, _הגב_, hsal, vkra,
   {{0x69c43424,0xb69b15f5,0xca74c01c,0x68e8c17b}},	//   _puie, rgân, انیک, aadd,
   {{0xe8e0000c,0x3634c16a,0x6e2980f6,0x7bc5043e}},	//   _liễu_, _پرنس, _jseb, _auhu,
   {{0x6e20443d,0x2001442c,0x61ed6437,0x7995012c}},	//   _âmbi, kuhi_, dsal, gozw,
   {{0xd00ec61e,0x6b55c032,0x2b9c8047,0xd46a0bb4}},	//   _فلو_, _fágt, síci_, хиве_,
   {{0xa09ac052,0x040d800c,0x23274c35,0x8cd400e6}},	//   _איצט, _sướn, лоси_, _ब्रो,
   {{0x6d5c01b0,0x8fa364e8,0xe1f2001c,0x2d8300e5}},	// [3be0] pkra, сате, _اسب_, bnje_,
   {{0x69d640f8,0x7ae9c02c,0x6d5a009d,0xab5d80f6}},	//   rpye, haet, ötad, _jiżf,
   {{0x29c9f425,0x672d0022,0x201a0086,0x6e2980f7}},	//   _lúa_, _yaaj, _uppi_, _aseb,
   {{0x2fd742cf,0xb4dfcc4b,0xb8271702,0x3a3f46f0}},	//   اوند_, तरु_, _союз_, _šupe_,
   {{0x040d8015,0x7bc53426,0x29c9c004,0x88e8402a}},	//   _tướn, _zuhu, _núa_, _পাঠক,
   {{0x64588039,0x7bc501c8,0x29360052,0x2366813b}},	//   tyvi, _yuhu, ראַן_, shoj_,
   {{0x6e29b427,0x6b8455d4,0x7ae9c02c,0x6b828011}},	//   _eseb, onig, faet, pnog,
   {{0x7ae9c0de,0x3d09aa5d,0xad9b0038,0x68e8c11c}},	//   gaet, _साथे_, ntúr, wadd,
   {{0x7ae67428,0x8b5742a6,0xdb1ac30d,0x6b847429}},	//   _mekt, טיקס_, _cutá, inig,
   {{0x69c644db,0x672d342a,0xd7faf20f,0x361b8323}},	//   _muke, _saaj, нум_, _אומד,
   {{0x7764156e,0x0d974093,0x2d830451,0x66028051}},	//   _blix, רכים_, vnje_, luok,
   {{0x48a7c39d,0x7ae66a8b,0x61fbd0d0,0x43952ec5}},	//   ытым_, _nekt, brul, рамс,
   {{0x63bd4c12,0x79950bc9,0x27ee8157,0x63b8802d}},	//   _risn, tozw, lsfn_, ívny,
   {{0x6b584004,0xc69382a6,0x68e8f42b,0xbd450032}},	//   _mígu, מאר_, qadd, جنسي,
   {{0x6b584018,0x63bd742c,0x853b8323,0xb6d24044}},	//   _lígu, _pisn, עגלי, _ọgọs,
   {{0x2d9a025d,0x291845c5,0x2602009d,0xe80e44ef}},	//   _ekpe_, _abra_, वंशी_, _सहजा_,
   {{0x3a290871,0x44384631,0x25ee4036,0xccfb41bd}},	// [3bf0] _usap_, _arr_, ेंगी_, еће_,
   {{0x20016a8f,0x9c7c8054,0x81e80079,0x7bc5342d}},	//   tuhi_, _rečn, মূহ_, _tuhu,
   {{0x61e2c40d,0x69c64140,0x99800026,0xab5d8283}},	//   _lwol, _euke, _erių_, _jiżg,
   {{0x657ac98d,0x799a8d45,0x96359da8,0x09dac02a}},	//   hith, _aktw, инец, _দিনা,
   {{0x3f89342e,0x05db4036,0xa5098982,0x69c6400d}},	//   _mjau_, मीखब, вела_, _guke,
   {{0xa3c18028,0x23694033,0xee38805f,0x752e409c}},	//   ंदल_, lhaj_, اقوں_, _gabz,
   {{0x7ae9c1f4,0xf8b50027,0x20110232,0x7ae65f41}},	//   taet, ंधिय, ntzi_, _yekt,
   {{0x986a42d6,0x27fc4166,0x29c9c019,0x68e7695c}},	//   lığa_, ávne_, _púa_, _hejd,
   {{0x7aeba8f7,0x3eb9cfd0,0x623493f7,0x7b6481fa}},	//   magt, äst_, _лету, _утре,
   {{0x7aebb42f,0x3f84ccff,0x20030185,0x0555d8dc}},	//   lagt, anmu_, kuji_, ртия,
   {{0x63ad0e89,0xdb0a4066,0x9f8611d7,0x257bc031}},	//   _bhan, žnéh, игод, _aálè_,
   {{0x7aebb430,0xe3bf434d,0x257bc1c0,0xab5d80f6}},	//   nagt, _niñ_, _bálè_, _diżg,
   {{0x7c2ac10b,0x55e5c0b4,0x6145c01b,0x4427802c}},	//   _esfr, _толб, _вела, lwn_,
   {{0xbdfd402a,0x257bc02e,0x39410053,0xa2aa8036}},	//   ুবাদ_, _dálè_, _cnhs_, जेट्,
   {{0xe7e10021,0x7bc747a8,0x6366030d,0xafe63431}},	//   गीला_, _nuju, _cónc, робл,
   {{0x69c65311,0x6b847432,0xab5d80f1,0x6a865654}},	//   _puke, unig, _jiżd, алба,

   {{0x7523b433,0x8d7608a7,0x442a4791,0xe8e000d1}},	// [3c00] kenz, _نادا, _ssb_, _niệu_,
   {{0xdb1d45dc,0x7523b434,0x442a7435,0x6b898303}},	//   _lisè, jenz, _psb_, _ajeg,
   {{0x6b58653f,0xd026423d,0xaec69bf1,0x8c46195e}},	//   _sígu, рмей, абел, _тене,
   {{0x2d980193,0xa2d54047,0x3a394f2d,0x63ad013b}},	//   lore_, युद्, _frsp_, _xhan,
   {{0x6b8980fd,0xdb1b001e,0x69d980f8,0x69268077}},	//   _djeg, mptô, gpwe, имда,
   {{0x4438406c,0xb4dfc0e9,0x99890089,0x672f4451}},	//   _trr_, तरो_, _trať_, _zacj,
   {{0xdb1d40b6,0x38ac402e,0x657ac073,0x442a4c18}},	//   _bisè, _dórí_, vith, _usb_,
   {{0xe81e0027,0x9c7cc67d,0x68eab436,0xb8fd8036}},	//   _पहना_, sačk, safd, _थ्_,
   {{0xa5bb41c0,0x63a29388,0x765bc010,0xdb02c0d1}},	//   _aróy, mlon, gyuy, _choá,
   {{0x2d983437,0x26d20053,0x2918c086,0xe506954f}},	//   jore_, _afyo_, ýra_, _خبري,
   {{0x3f868c5a,0x656a8311,0x61e400e2,0xa5bb4512}},	//   onou_, mhfh, _awil, _próz,
   {{0x645acf37,0x6604414b,0x6db2c036,0x61e40053}},	//   ryti, kuik, _płas, _bwil,
   {{0xdb1c8018,0x63a280c4,0x9d18c0a7,0x98a74242}},	//   _xurá, ilon, _болт_, _čiča_,
   {{0x7f880080,0xdcf88007,0x61e4088b,0xa157defa}},	//   lıql, rovė, _dwil, _вашу_,
   {{0x9c7cc2a3,0xd7c901aa,0x442c805c,0x672f4036}},	//   kači, اوره_, _jsd_, _pacj,
   {{0xd6d846d7,0x63ad03f2,0x7bc0800d,0xadc3c02e}},	//   иту_, _uhan, _nimu, _atẹj,
   {{0x68e74570,0x61e4002c,0xcf78001c,0x657c002f}},	// [3c10] _pejd, _gwil, _خصوص_, birh,
   {{0x2366c0da,0xdb09c032,0x443a00d9,0xdb1d6ac4}},	//   _lloj_, imeá, _frp_, _misé,
   {{0x7bc881aa,0x2fc7c015,0x4395459d,0x2d768036}},	//   _nudu, _xung_, _ганс, ałek_,
   {{0x9f5840c4,0x27fe002d,0x338480c5,0x6d4a44c9}},	//   strò_, átne_, оучв, öfar,
   {{0x68e8b438,0x7aebb39c,0x661d5348,0xa159b439}},	//   _bedd, ragt, _upsk, ладу_,
   {{0xed598f26,0x7a1a8017,0x7aeb8cb8,0x27fe0eae}},	//   _kuži_, dātā, sagt, štne_,
   {{0x68e881f4,0x256440fa,0xdc3bc283,0x6296806a}},	//   _dedd, _köln_, _oġġe, üyor,
   {{0xed59805b,0x2d98343a,0x2fc7f43b,0x9c7cc97c}},	//   _muži_, zore_, _rung_, cači,
   {{0xaab748c4,0x6f1ba99d,0x98a34062,0x7a1a88c7}},	//   अधिक, _ibuc, _dają_, gātā,
   {{0x7bc88057,0x7aed743c,0x7bc08491,0xe1ff343d}},	//   _fudu, haat, _zimu, dró_,
   {{0x7bd7024c,0x3319c11b,0x61e4099e,0xc7d992af}},	//   _ntxu, _біля_, _swil, _смех_,
   {{0xd05c003a,0x68e88bed,0x680a8080,0x6f0d017b}},	//   carə, _zedd, _tədr, _ccac,
   {{0x6441036b,0x7ae9b43e,0xd00ec5d3,0x2d87801e}},	//   ålin, _meet, ولی_, onne_,
   {{0x69dbc815,0x9c7cc068,0x2fc7f43f,0x8636c009}},	//   mpue, zači, _tung_, _לאנג_,
   {{0x7aed7440,0x7bc881c8,0x26e7002a,0x1867042e}},	//   faat, _xudu, _কারো_, бари_,
   {{0xd113e888,0xed5985c7,0xad9b0038,0x637616c1}},	//   त्रण_, _duži_, stúp, kšni,
   {{0x7bc0b441,0x63660018,0x52aa6a11,0xe1ff0070}},	// [3c20] _rimu, _góna, увам_, cró_,
   {{0x6b5cc107,0xad9b003c,0x636a4086,0xfe370052}},	//   _végi, trúe, _sýnd, _פריי_,
   {{0x3f86b442,0x9c7cc6a4,0x6b584018,0x6e29cb4d}},	//   tnou_, tači, _dígr, hweb,
   {{0x6e3b84a3,0x7bdc3443,0x8fc500fe,0x69c98070}},	//   _brub, mpru, _گزین, _buee,
   {{0x3f86b444,0x68f844fc,0x2005f445,0xa3e58b08}},	//   rnou_, _نکاح_, huli_, बीस_,
   {{0x290a0083,0x63a28618,0x3f9dc0eb,0x9c7cc199}},	//   ngba_, slon, _akwu_, sači,
   {{0xdcf5003f,0x2366c24c,0x38c8c973,0xe50e89d5}},	//   nizā, _ploj_, یادی_, _साठि_,
   {{0x672600da,0x657e40f7,0x2d9cc21b,0x2d8794ed}},	//   jekj, liph, _skve_, anne_,
   {{0x9c7c8077,0x9f5a8018,0x442a0022,0x4254c01c}},	//   _kečk, cupá_, hwb_, زندر,
   {{0x3d1a04ef,0x6f0d05f5,0xdb09f446,0x66062313}},	//   म्मे_, _scac, rmeá, dukk,
   {{0xe60fc646,0x459b4009,0xc19b4052,0x442a005c}},	//   وشی_, רסיע, רשיי, jwb_,
   {{0x7b67022e,0x6e29c28d,0x2d9a7447,0xdfcf8032}},	//   стое, bweb, hope_, _أين_,
   {{0xdbe2c018,0x225ad094,0x291822c6,0xe1ff0070}},	//   _véñe, _حجاب_, ffra_, uró_,
   {{0x7f4400c7,0x41b6c5f5,0x7c2e414d,0xb69b00cc}},	//   _eniq, _усет, _osbr, ngâi,
   {{0x67d18017,0x98480025,0x6b998149,0x6fcfe2d5}},	//   _kāja, бята_, yowg, _संयं,
   {{0x6e2d0360,0x07f7c032,0xbe9a00eb,0x2e4b45f5}},	//   _tsab, _اروع_, ọhụr, лязо_,
   {{0x442ec033,0x31350b8e,0x9f5f0531,0x5d5551cd}},	// [3c30] _hsf_, _депр, nutí_, окат,
   {{0xb8824531,0x317ed846,0x6f1b823f,0x6aad2e01}},	//   čína, nitz_, _sbuc, _izaf,
   {{0x2f19410e,0x59d4005f,0x442ef448,0x61e64085}},	//   _конь_, _وغیر, _jsf_, _ewkl,
   {{0x442ed16b,0x63a450b0,0xcf27401c,0x317ec1a8}},	//   _msf_, clin, _اردي, hitz_,
   {{0xe1ff0036,0x657e7449,0x69c980c3,0x67c8c0a0}},	//   rzów_, biph, _quee, _ději,
   {{0xabd58244,0xe1ff0036,0x442121c8,0x98be8053}},	//   оциј, szów_, _kph_, _entč_,
   {{0x7aef00a8,0x657a805e,0x1b49d8dc,0x6aa2c75d}},	//   kact, _dmth, изки_, _ayof,
   {{0x09d88079,0x88bcc047,0x65688086,0x987c02a6}},	//   _সিরা, vděp, _eldh, טרוק,
   {{0x69c1b44a,0x443cc2ea,0x9f605d89,0x3a2d8033}},	//   _tile, _arv_, érés_, _usep_,
   {{0x69c182d4,0x23690053,0x6e29e582,0x8d59c119}},	//   _uile, _alaj_, rweb, ршит_,
   {{0x291cc077,0x8b260f1e,0x6aad344b,0x7aef1726}},	//   _dbva_, одне, _azaf, fact,
   {{0xeb9a344c,0x657e4339,0x2bd042f6,0x68ee005c}},	//   рим_, ziph, _तूफा, wabd,
   {{0x317ec100,0x2005f44d,0xa3e58959,0x75270639}},	//   bitz_, suli_, बीर_, fejz,
   {{0x6b5cc669,0x7aebc2a4,0x256b8240,0x2005f3c9}},	//   _dégu, _hegt, _føle_, puli_,
   {{0xdb064107,0x44210329,0x6da30c60,0x3f89402c}},	//   _mikö, _cph_, фира, fnau_,
   {{0x6443097c,0x69c3f44e,0x6b89f44f,0x7f441d80}},	//   _šnic, _hine, nneg, _uniq,
   {{0x44213450,0xe57a4381,0x256444d3,0x644344d3}},	// [3c40] _eph_, аза_, _föll_, ånin,
   {{0x850601aa,0x63b65044,0x7bdc00f1,0x273f0051}},	//   _بودن, smyn, ppru, _tänä_,
   {{0x4f9680b4,0x656e0032,0x2d9a7451,0xdfcf4032}},	//   орду, mhbh, rope_, نيل_,
   {{0x2007b452,0x657e4339,0x6b89f453,0x9f5cc047}},	//   duni_, siph, jneg, prvé_,
   {{0xbddb4315,0x7f4640c2,0x2d9a4022,0xd041c03a}},	//   _crèd, _inkq, pope_, rclə,
   {{0xc0aa44a4,0x7d0041c0,0x799c1ae2,0x39458449}},	//   _نازل_, _dárà, norw, _cnls_,
   {{0xa0a354e9,0x69d9d24b,0xd90d801c,0x645820b0}},	//   _жард, _atwe, ایم_, _àvid,
   {{0xdb064051,0x6b9bc077,0x7c220123,0x938ac217}},	//   _eikö, goug, _ćorl, јска_,
   {{0x66164039,0x7bcae325,0x7aebf454,0x094ad027}},	//   ntyk, _sufu, _degt, ачни_,
   {{0xdc3e8066,0x291884ff,0x02e30185,0xd6e2c079}},	//   líče, _ùra_, पर्न, _যাওয,
   {{0x39587455,0x6d573456,0x69d9c0bb,0x3a22405c}},	//   _mors_, _roxa, _etwe, _lpkp_,
   {{0xed5982a3,0x443e9d64,0x44210056,0x236dc7ab}},	//   _dužu_, _irt_, _rph_, chej_,
   {{0x6d570004,0x799af37f,0x69c3ce83,0x660280f8}},	//   _poxa, potw, _fine, nrok,
   {{0x443eb457,0x443cc147,0x386f8189,0x6b80c398}},	//   _krt_, _trv_, _ömrü_, limg,
   {{0xd5b8c017,0x6602b458,0x2fcc8053,0x645cc0b2}},	//   mmā_, hrok, _judg_, ärid,
   {{0x44210070,0xe8e0400c,0xdd1e8047,0x98aec053}},	//   _vph_, _đền_, jížd, _jafč_,
   {{0x6b9d0018,0x799c01c6,0x443eb459,0xa6e24397}},	// [3c50] mosg, borw, _lrt_, óðan,
   {{0xdb0bc2e3,0x69c3cf8f,0x39586934,0x290cc4f5}},	//   _sigü, _xine, _cors_, ngda_,
   {{0x9ad88112,0x3869c6df,0x6b9bd138,0x9c134112}},	//   _ịrụg, _ƙari_, youg, pọmk,
   {{0x29d0802e,0xab5d817a,0x7aed0053,0x8c1bc4e0}},	//   _bàa_, _biża, _jeat, שואי,
   {{0x8af04435,0x2d9c82a3,0xa2a24617,0x8d7401aa}},	//   rkət, fove_, _कुप्, _رایا,
   {{0x2fcc8085,0xe9df0070,0x3cf780b2,0xab5d80f1}},	//   _budg_, ipú_, ीलें_, _diża,
   {{0x6e3b40b3,0x7ae2823f,0x6b9bc0b3,0x80d64048}},	//   _šubh, bbot, toug, मुळे,
   {{0x2b46c24f,0x3f8b0077,0xe1ff0004,0xed5986f0}},	//   _cnoc_, jncu_, nzós_, _ružu_,
   {{0x2d9c87ca,0x6b9bc3d4,0x3ead9295,0x0ca80fb2}},	//   bove_, roug, _uzet_, _गर्म,
   {{0x6009cf0d,0xaefb4321,0x7aebc9dd,0x6b9bd955}},	//   бном_, _dlùi, _wegt, soug,
   {{0x6aa4012d,0x6b89d645,0x03a62162,0x7aed1d28}},	//   _syif, pneg, зино, _beat,
   {{0x753545d4,0x6e2d745a,0x4431745b,0xb4abc8c5}},	//   _lazz, kwab, _msz_, _खरी_,
   {{0x656e024f,0x65654033,0xf1c38283,0x7aed345c}},	//   thbh, kkhh, poġġ_, _deat,
   {{0x2d82c05f,0xe20b0086,0x77a5c018,0x63660089}},	//   éket_, _stóð_, dóxi, _tóno,
   {{0xdb1d41b4,0xa06715f5,0x04430179,0x8c430119}},	//   _eisí, пара_, нерн, нере,
   {{0x2b594032,0xdcfc00b3,0x5aca401b,0xaffac009}},	//   _cosc_, mirč, слам_, _פּוי,
   {{0x9b46405f,0x61e98112,0x3958745d,0x799c02c0}},	// [3c60] _ہندو, _nwel, _pors_, porw,
   {{0x7afb9d81,0x6729e043,0x6b8b80f8,0x69c501c6}},	//   _adut, heej, engg, _gihe,
   {{0x2b595ea2,0xc7268a23,0xdb098321,0x6d058027}},	//   _fosc_, здей, _bheà, _राजग_,
   {{0x4431745e,0x64484283,0x802502cf,0xdb0985ef}},	//   _dsz_, _ġdid, _کریم, _cheà,
   {{0xe519409d,0x64415a7a,0x75354a48,0x9f5f0066}},	//   न्हि_, _álin, _fazz, nutá_,
   {{0x6b8b80f8,0x22400303,0xfe45416a,0x3a3f8177}},	//   angg, _mrik_, _تکفی, _drup_,
   {{0x442c43bc,0x6ba7401d,0x80e34079,0x7c24c570}},	//   _èd_, _órgã, _পাচ্, _ćiro,
   {{0x2eed8ef1,0x8fa38604,0x3947f0d4,0x61d8c67b}},	//   _geef_, _засе, _anns_, омия_,
   {{0x6d58d763,0xe8e00082,0x6604745f,0xb51945a3}},	//   _pova, _chịu_, nrik, न्वय_,
   {{0x26c08007,0x63ae8007,0x20183460,0x7aed3461}},	//   žios_, šinė, ktri_, _seat,
   {{0x7aed3462,0x442cc1d4,0x7bce412d,0x6fbe408f}},	//   _peat, uwd_, _jubu, ्दां,
   {{0x7bc65fc8,0x7bce6912,0x6b82b463,0x61f64051}},	//   _niku, _mubu, niog, ksyl,
   {{0x65ab40fa,0x6609c033,0xdce38007,0x6234ca66}},	//   fühl, cuek, ginė, _целу,
   {{0x2582c02e,0x7aed3464,0xdb11c4c9,0x6600017c}},	//   _délè_, _weat, åför, ámka,
   {{0x200a0ee2,0x443af465,0x69c53466,0x66045904}},	//   gubi_, _ép_, _vihe, erik,
   {{0x7ae44c46,0xe81e0275,0xdce38007,0xee3f4047}},	//   gbit, _पहरा_, binė, _prý_,
   {{0x89d941b4,0x6d5a854a,0xdce38039,0x2d8cf467}},	// [3c70] زوار_, _oota, cinė, onde_,
   {{0x77a5c5f4,0xdb0d0359,0x7ae47468,0x853cc026}},	//   róxi, _mhaí, abit, klėm,
   {{0x66044d98,0x5b158ff8,0x2d817469,0xf9900032}},	//   arik, дмет, rihe_, _حبي_,
   {{0x23668022,0x63a2c9f4,0xcb0b4051,0xbddb401e}},	//   gkoj_, _nkon, _уход_, _crèc,
   {{0x3a3f803a,0x45d44b54,0x2b490060,0xe3c9c35d}},	//   _qrup_, _пояс, _mnac_, _rằm_,
   {{0xb92541b4,0x69dd746a,0x7bc6426d,0xdb064051}},	//   _تفسي, _itse, _ziku, _ehkä,
   {{0x5c04410e,0x999f8107,0x2eed875a,0xbddb40b6}},	//   _пята, éről_, _teef_, _frèc,
   {{0xeafb9971,0x61c8d527,0x5f75c71d,0x3a3fb46b}},	//   _درست_, रदूष, باتر, _trup_,
   {{0xdb0d0018,0x6d5ab46c,0x4433007a,0x7bd2403f}},	//   _chaí, _fota, _lsx_, ējuš,
   {{0x7aef4277,0xceb280c3,0x69cf746d,0x672b813b}},	//   _lect, _יין_, _muce, legj,
   {{0x6b5cc05f,0x4433100b,0x7c678032,0x7981c17b}},	//   _végr, _nsx_, _عائل, rilw,
   {{0x69dd454a,0x92ec002a,0x22401dda,0x63a2c024}},	//   _otse, কল্প_, _prik_, _gkon,
   {{0x64418077,0x63a9ee50,0x2ef2405c,0xbf180031}},	//   _hrli, mlen, vayf_, _aṣís,
   {{0x4425804c,0x2242c065,0x1869eec6,0xa069dc21}},	//   _kpl_, ække_, _мали_, _мала_,
   {{0x6d89346e,0x7bc6746f,0xdce38007,0xa2c041ac}},	//   džad, _piku, sinė, लेन्,
   {{0x200a2176,0x04100079,0x20182304,0x70aa4027}},	//   rubi_, াবলী_, rtri_, _करौल,
   {{0x1da94a3c,0x03a350fc,0x9ad340eb,0x7c250fee}},	// [3c80] कतंत, тито, _aịsa, _ephr,
   {{0x7ae456e1,0x3aec400c,0x44258141,0x7e628150}},	//   sbit, ếp_, _opl_, vyop,
   {{0x637147fb,0x63a40140,0x68fcc1ff,0x7aef499e}},	//   _bånd, _kkin, órdi, _fect,
   {{0xab5d81d6,0xdaaa8708,0x63a9f470,0x200502f4}},	//   _diżo, овед_, jlen, álie_,
   {{0x63a9f471,0x637144d3,0x6d488df5,0x63a94283}},	//   dlen, _sång, _pnda, ċent,
   {{0x63a40010,0x2d9ef472,0x2bbe48b8,0x7f4980c7}},	//   _lkin, xote_, ्दवा, _eneq,
   {{0xa2a005b9,0x7bce402f,0xdb040032,0xd7fa8119}},	//   _गुस्, _uubu, _dhiú, цул_,
   {{0x63a9e06b,0x4425844e,0x9343a345,0x236d806c}},	//   glen, _dpl_, _инсе, _glej_,
   {{0x0e8e80eb,0x69c77473,0x2d830f2d,0x00000000}},	//   rịsị_, _yije, yije_, --,
   {{0x2d8cf474,0xdb0d0070,0x0e8e80eb,0x63660031}},	//   unde_, _riañ, bịrị_, _fónk,
   {{0x644185c7,0xcad2c0eb,0xd138c007,0x2005c0ab}},	//   _grli, _dịrị, rdą_, grli_,
   {{0x95cb001b,0x63a9f475,0xe81fc09d,0x4ab2908d}},	//   жува_, clen, _बहरा_, _जराव,
   {{0x6722c171,0x7bdcc56e,0x6d5c43c3,0xc046c231}},	//   _iboj, írub, _oora, سخگو,
   {{0x2ca7c0de,0xdb0d0018,0x61e28157,0xd90f016a}},	//   _fynd_, _viañ, ipol, جید_,
   {{0x394d42bc,0x776d03e9,0x3ead40b3,0x44258010}},	//   _đes_, _tlax, _šet_, _xpl_,
   {{0x3f84f476,0x6d5c7477,0x3a26f478,0x23880107}},	//   nimu_, _aora, _kpop_, tője_,
   {{0x200cc283,0x35b55eab,0xbddb405e,0xd0d500c5}},	// [3c90] ludi_, ебар, _brèa, _попъ,
   {{0xdb0f4019,0x9f5f0032,0x7e6004c9,0x7538c085}},	//   _picó, irtí_, ämpe, _javz,
   {{0x63a9ccea,0x63bbf479,0xd7f8c119,0x63a0d044}},	//   ylen, ymun, nsă_, komn,
   {{0x7afd49ca,0x2fc90022,0x63a9c43e,0x69c74b0e}},	//   _udst, _jiag_, xlen, _wije,
   {{0x7c220451,0xdb0405ef,0xaefb468a,0x3c390047}},	//   _ćori, _chiù, _dlùt, bývá_,
   {{0x6d5cc041,0x660d747a,0x23694573,0x4425b093}},	//   öral, muak, lkaj_, _ppl_,
   {{0xdca29934,0x63bbca84,0x64a28896,0x61ed1030}},	//   лаши, tmun, лаша, _lwal,
   {{0x61ed11c6,0x3f84f47b,0xe51f0185,0x2385c017}},	//   _owal, gimu_, म्ति_, vējs_,
   {{0x61ed025d,0x3f8df47c,0xdb04029a,0x3ea9088b}},	//   _nwal, rneu_, _ghiù, _nyat_,
   {{0x6366030d,0xe576c119,0x7bc9b142,0x98a30017}},	//   _ióni, езь_, _hieu, zejā_,
   {{0x660d4df5,0x1ae70079,0xc625c079,0x98ac80b4}},	//   huak, _কাজে_, বিধা_, _vadă_,
   {{0xfaff00fd,0x61ed011c,0x6722c1c0,0x6aa980bb}},	//   dhës_, _bwal, _gboj, _kyef,
   {{0x6d890639,0x998d8147,0x672d747d,0x66080062}},	//   džab, _mrež_, deaj, ądko,
   {{0x61ed0820,0x6aa98157,0x661bf47e,0x61fb8dc0}},	//   _dwal, _myef, mtuk, _mvul,
   {{0xdfd201b4,0xd7be408f,0x1fb65df8,0xa2a0347f}},	//   اير_, ्दलच, есар, _गुर्,
   {{0x7f5d434d,0x7538ef8b,0xe46ac09d,0x61e2b480}},	//   _cosq, _zavz, stöö_, ypol,
   {{0xb91080eb,0x6aa9825d,0x660d4140,0xfbac0045}},	// [3ca0] _celụ_, _nyef, guak, _टीएम,
   {{0x3f84dfd6,0xd29b0093,0x4427f481,0xba9b0942}},	//   zimu_, _משפט, _kpn_, _מספי,
   {{0x61fbb482,0x2619c00c,0x7c24c590,0x1306801b}},	//   _avul, hèo_, _ćirk, езем,
   {{0x76443483,0xd6c481aa,0x798181f4,0x65ad8166}},	//   _kriy, نمای, _amlw, súhl,
   {{0xb17b55db,0x6366030d,0x7bc9b484,0xdcfac0b4}},	//   _ståe, _cóni, _dieu, nită,
   {{0x5bbe425d,0x7af64dc9,0xceb300c3,0x76440396}},	//   _ọchị_, layt, איד_, _mriy,
   {{0x5334c0c5,0x7b66c077,0x61e47485,0x1dd5c17e}},	//   вейт, етпе, lpil, _डूबत,
   {{0x63661b87,0x69c8b486,0xe7f18027,0x2572c01e}},	//   _fóni, _wide, _घबरा_, _mâle_,
   {{0x63a2b487,0xadc34015,0x6443f488,0xa2a00185}},	//   moon, _hoạc, _arni, _गुल्,
   {{0x6d5e0bd3,0x02e0def1,0x67243489,0xee37946f}},	//   _nopa, _ग्रह_, _abij, _яну_,
   {{0x661bc0fc,0x69d640fd,0x6ea2515e,0xfaff013b}},	//   atuk, hqye, _कुसु, xhës_,
   {{0xe0df8015,0x395e80fc,0x76440141,0x6b86002f}},	//   _đòi_, _hots_, _briy, gikg,
   {{0xb51040aa,0x22404077,0x7644088b,0x5186f48a}},	//   ालाय_, jvik_, _criy, _пука,
   {{0x65b040fa,0x4427c570,0x60338080,0x7644044e}},	//   wähn, _fpn_, _səmə, _driy,
   {{0x1fa72159,0x2fc9298e,0x7644348b,0xfbd90079}},	//   _приг, _tiag_, _eriy, ধীনত,
   {{0x7af6402f,0x7644042b,0x753a81a8,0x660d748c}},	//   gayt, _friy, _latz, tuak,
   {{0x4ea7010e,0x2a668022,0xab5d817a,0xc6a70051}},	// [3cb0] _ярка, jyob_, _fiżj, _ярки,
   {{0x753ab1c7,0x6d9cc138,0x63b30026,0x660f29c4}},	//   _natz, _uçağ, šenė, muck,
   {{0x63660070,0x798701c6,0x69caf48d,0x29011876}},	//   _sóni, mijw, _mife, _idha_,
   {{0x6d5e056e,0x69cae374,0x61e44017,0x3f86a4ad}},	//   _zopa, _life, bpil, giou_,
   {{0x22404066,0x6d5e0070,0x72ec0052,0x7ae4834d}},	//   cvik_, _yopa, פֿאַ, ñita,
   {{0xdb1ac004,0x6b82e834,0xdb00f48e,0x6eaa1890}},	//   _outó, _amog, lomè, _घरघु,
   {{0x753a9fd3,0x98a7c047,0xa5bb0018,0x63a2b48f}},	//   _datz, _daně_, ptóf, boon,
   {{0x6ed54045,0x672f0043,0x63a285d1,0x7d07402e}},	//   युचु, jecj, coon, _férà,
   {{0xa5359022,0x45d5811b,0x320957de,0x661d02bc}},	//   _инач, _розс, nray_, jtsk,
   {{0x4427f490,0xdcfac119,0x29010010,0x395e8580}},	//   _ppn_, vită, _ndha_, _gots_,
   {{0x3a293491,0x92c3c079,0x76440033,0x61e44017}},	//   _apap_, ্রে_, _sriy, zpil,
   {{0x2d9100c5,0x6e29825d,0x661d056d,0x753ab492}},	//   enze_, _kpeb, ftsk, _zatz,
   {{0x9f5f004c,0xdb00dea2,0x53b5409d,0x673b834c}},	//   yttö_, domè, ंतनश, _mauj,
   {{0x32094181,0x61e4403f,0x6b82d3d7,0x61fbf493}},	//   dray_, vpil, _zmog, msul,
   {{0x7bcbe81f,0x25ee009d,0x661d02a4,0xdb0f405e}},	//   _kigu, _अबकी_, atsk, _bhcà,
   {{0x63ad7494,0x98a74185,0x7644244e,0x7ae9ee56}},	//   glan, žně_, _triy, nbet,
   {{0x3f868c5a,0x0e635000,0x60db4077,0x764401c6}},	// [3cc0] viou_, актн, _đumr, _uriy,
   {{0xbef2008f,0xbc660ece,0x9c12db43,0x22407495}},	//   _अजुन_, _авок, _mọnd, rvik_,
   {{0xa2a254f7,0x1c09d6c0,0x22407051,0x673b80cb}},	//   _कुर्, _विफल_, svik_, _bauj,
   {{0x32097496,0x61fbf497,0x753a80cb,0xdb00c0d2}},	//   bray_, ksul, _satz, comè,
   {{0xdbdf7498,0x394c809c,0x82338032,0x3f86a6d2}},	//   _bíót, _pnds_, لروا, riou_,
   {{0xa3b652c7,0x77b8803c,0x6b82f499,0x6e29006a}},	//   _चीत_, díxe, _smog, çebi,
   {{0x7bcbc568,0x3c3c8047,0xf7838085,0x2fda401c}},	//   _bigu, dává_, _baħħ_, _آورد_,
   {{0x4734cf1e,0x60cdc06a,0x200ea4ce,0x466ae1b7}},	//   унис, _şamp, rufi_, дром_,
   {{0x442a4f26,0xa1c690a1,0xd2a78156,0xa3bf858e}},	//   _hpb_, _абад, _акте_, ँगर_,
   {{0x7bcbc086,0x661d004f,0x63a4749a,0xd7facc93}},	//   _eigu, vtsk, hoin, мум_,
   {{0x63714673,0x61fbc0bb,0x6441c078,0xc057d8d5}},	//   _låna, asul, gvli, вія_,
   {{0x66e6c523,0xf4134093,0xdce1c03f,0x661d0833}},	//   _рода, ספר_, rklā, ttsk,
   {{0x63ad46bc,0x7642b49b,0x69cac0f1,0x7000825d}},	//   vlan, nvoy, _tife, _ịche,
   {{0x61edc676,0xdb00cc2c,0x660f0b4c,0x7e600041}},	//   _çala, domé, ruck, ämpa,
   {{0x7987000d,0xa2c045a3,0x08f14079,0x2246c011}},	//   rijw, लेस्, _চালু_, _hrok_,
   {{0x2fc05b85,0x8afd8047,0x25fe43fc,0x2246c750}},	//   gmig_, _koře, _लिखी_, _krok_,
   {{0x201ef49c,0x320941c8,0xdb00d46e,0xa7fcc06a}},	// [3cd0] ltti_, uray_, romè, zyıl,
   {{0x201ef06a,0xdb044086,0xd6d98036,0x3f84809d}},	//   otti_, smið, _małe_, _ammu_,
   {{0x02cb8027,0x753c749d,0x442a4c2a,0x48ab423d}},	//   िश्न, _darz, _cpb_, фтам_,
   {{0xd6db811b,0xc477c0c3,0xe9f984f5,0x77608303}},	//   єте_, כתבו_, енді_, _comx,
   {{0xdb00c03c,0x1287408c,0x98b14119,0x61e2f49e}},	//   comé, _شمسی_, _bază_, _ntol,
   {{0x7bcd0007,0x0d6440c5,0x7c2ac2a0,0x6aad0177}},	//   _liau, _късм, _opfr, _myaf,
   {{0x7bcbf49f,0x673d43c9,0x2246f4a0,0x3d1b0b35}},	//   _pigu, _kasj, _arok_, _बाने_,
   {{0x673d40a8,0x77b8803c,0x80bf002a,0x6447417a}},	//   _jasj, tíxe, ্ডপ্, _irji,
   {{0x7bcbf4a1,0x201ec844,0x7bd56a24,0x63660018}},	//   _vigu, etti_, _huzu, _mónt,
   {{0x6b8413a7,0x7ae6c3a6,0x2d87a6e1,0x27fe006c}},	//   _smig, ıkta, qine_, štni_,
   {{0xb4bf05da,0x1869c27f,0xfb15c5a7,0x6aad2185}},	//   ेशो_, хани_, _مواج, _ayaf,
   {{0x6aad2912,0x7bcd267d,0x2a694010,0x2bba0032}},	//   _byaf, _ciau, kyab_, عادة_,
   {{0x6aad0449,0x63a982c0,0x7bd5489f,0x6b89c097}},	//   _cyaf, _mken, _luzu, mieg,
   {{0xab5d81d6,0x6aad0053,0xd567c0b4,0x2fcdb4a2}},	//   _diżi, _dyaf, _штеп, _lieg_,
   {{0xd011c1b4,0x6375c19d,0x7c220570,0xe1ff450e}},	//   _الع_, _tánd, _ćors, _avó_,
   {{0x6366003c,0x442a405c,0x753c4c7c,0xb6a65702}},	//   _cónt, _rpb_, _sarz, гибл,
   {{0xc7a90f4d,0x63784c5a,0x443874a3,0x7bd574a4}},	// [3ce0] _جدول_, _líng, _ssr_, _auzu,
   {{0x7bd574a5,0x2011011c,0x63bbb4a6,0xee374007}},	//   _buzu, buzi_, _ahun, ыну_,
   {{0xbb468844,0x4f0a8bc1,0x69d634a7,0x7ae4834d}},	//   лежк, енен_, _huye, ñito,
   {{0x753c4036,0x69d60116,0x63660686,0x7c3cc415}},	//   _warz, _kuye, _tónu, ærri,
   {{0xe918811e,0x69d600e2,0xef218017,0x7e69c1c6}},	//   волі_, _juye, daļā_, jyep,
   {{0x6d4e74a8,0xd8388066,0xdb0d00fd,0x3326c010}},	//   _unba, _psč_, _thaç, _sbox_,
   {{0x6366010d,0x6fba4b6d,0x802681aa,0xb426805f}},	//   _jóns, ्षपू, ارتم, اعتو,
   {{0xfaff40fd,0x6f0434a9,0x637840d2,0xb8934032}},	//   _ulët_, _ndic, _díng, _الفع,
   {{0x3a2059bd,0x6d8905c7,0xfce6865e,0x443a001c}},	//   ntip_, džan, _бозо, _lsp_,
   {{0x7bd574aa,0x90d5800c,0x20b84374,0xe8e040d1}},	//   _yuzu, _hàn, _अराध, _đớn_,
   {{0xdb55004c,0x69d6009c,0x7bcd010b,0x63784070}},	//   авны, _auye, _piau, _kínd,
   {{0x998955e7,0x442c806c,0x2b4040b3,0x68e4c0b5}},	//   ktaş_, _ipd_, jdic_, _şidd,
   {{0x64488066,0x442cb4ab,0x7afdc086,0x644e8018}},	//   _hrdi, _hpd_, ðste, _ábib,
   {{0x68e942bc,0x26d201ae,0xdb09805e,0x443a1f97}},	//   _đedo, _egyo_, _dheù, _bsp_,
   {{0x63a617fb,0x3f8941f4,0x6366030d,0x673d6b97}},	//   bokn, tiau_, _cóns, _pasj,
   {{0x673d413b,0xd90ec16a,0x7bc280a0,0x213ea2b6}},	//   _qasj, _بیگ_, jmou, _lath_,
   {{0x3f8b34ac,0xa3da4a3c,0x3d95011b,0x32554abe}},	// [3cf0] micu_, _डूब_, _випр, швар,
   {{0x64488e83,0x66cbc561,0x6e2d1b85,0x6b89c017}},	//   _ordi, _hökü, _ipab, zieg,
   {{0x63bb935a,0x6561801f,0x673d40a8,0xb8fd41f9}},	//   _phun, _rolh, _tasj, _डल_,
   {{0x636ec171,0xdb044018,0x6561b4ad,0x69ce431d}},	//   _bùnm, pliá, _solh, _eibe,
   {{0x6b89c017,0x7af9809c,0xb92040eb,0x69d6035d}},	//   vieg, rawt, ntrị_, _xuye,
   {{0x443a0010,0x3ce9c11f,0xd009a0a6,0x2cad0047}},	//   _ysp_, _đavo_, веке_, ředu_,
   {{0xf99f4141,0x6db9802d,0x7c3ab4ae,0x63bb9aad}},	//   _avèg_, _kňaz, _cstr, _thun,
   {{0x290ac05f,0x7bd701c8,0x2d8a34af,0x3d178048}},	//   óban_, _muxu, zibe_, _नावे_,
   {{0xc955c5f1,0x3f9c801e,0x3dcec0ce,0x7bd734b0}},	//   атны, évue_, _bifw_, _luxu,
   {{0x0c25c23d,0x63784018,0xbddb4031,0x63a6007a}},	//   амон, _tíng, _arèk, wokn,
   {{0x8af04435,0x3f8b02a3,0x44214093,0x69d6042c}},	//   rkəz, ficu_, nth_, _suye,
   {{0x6e39c022,0x7bcf58bd,0x69d608ae,0x07a61ed6}},	//   _tswb, _nicu, _puye, рамн,
   {{0xdd95c523,0x66cbc06a,0x63a634b1,0x7afbdc2e}},	//   _кады, _dökü, rokn, maut,
   {{0x63a634b2,0x427ac4e0,0x7af634b3,0x224914a0}},	//   sokn, _באנג, _weyt, _drak_,
   {{0x673f00da,0x3f8b0199,0x6b6641bc,0x7c3a8498}},	//   _faqj, bicu_, аква, _xstr,
   {{0x3f8b05c7,0x61e9e982,0x2d8a34b4,0x28a94036}},	//   cicu_, opel, sibe_, _कड़ि,
   {{0x433b0052,0x6724415d,0xe1ff005f,0xe7374051}},	// [3d00] _יעקב, rfij, csó_, шет_,
   {{0x01fb0052,0x2fcfc4f5,0x7abb0093,0x8886079c}},	//   _שפיל, _ligg_, _בצפו, _влож,
   {{0x6e3bb4b5,0x59d84a3c,0x3d1b0a3c,0x213eb4b6}},	//   _asub, _भंवर, _बाते_, _rath_,
   {{0x61e9c05c,0x7bcf400d,0x6b8b8212,0x6d41c07a}},	//   kpel, _gicu, gigg, hdla,
   {{0x68fac080,0x9ea782f8,0x443801f4,0x442caa4b}},	//   yatd, авца_, lwr_, _spd_,
   {{0x6563d08c,0x645cc134,0x67298085,0x6d890043}},	//   _nonh, ärik, _ebej, jžal,
   {{0x9cd70093,0x20134033,0x61e9f4b7,0x76499238}},	//   בוצה_, cuxi_, epel, _erey,
   {{0xe4570009,0x7c3ab4b8,0x7c2e643b,0x98b84085}},	//   שיקט_, _vstr, _ipbr, _gorġ_,
   {{0x6563f4b9,0x7c2947ca,0x0ea503ae,0x2fcff4ba}},	//   _bonh, _ćeri, _गुंड, _digg_,
   {{0x65b040cb,0x66cbc189,0x5bc48044,0xab5d80f6}},	//   fähi, _sökü, _ịchị_, _diżu,
   {{0xa739c0b3,0x660d456e,0x68fc1304,0x64414086}},	//   ščaš, zrak, dard, _álit,
   {{0x29180070,0x2b4000d2,0x70d34288,0x176b0156}},	//   egra_, _caic_, _तल्ल, троп_,
   {{0x7bcf5bf7,0x2ee04018,0x3d1b054a,0x7bd701c8}},	//   _ricu, dcif_, _बादे_, _suxu,
   {{0x200500ab,0xdd1a4283,0x6375c107,0x3d10446d}},	//   šlim_, għżu, _tánc, ालों_,
   {{0xe1ff0714,0x2b40068a,0x2249075a,0x7aed4127}},	//   ssó_, _faic_, _wrak_, tbat,
   {{0xb4b71543,0x68f8c0d9,0x7aed4df5,0xc17400e2}},	//   _जरी_, _hevd, ubat, _ruɗe_,
   {{0x76b96029,0x3eaf74bb,0x22491efd,0x4aa741f9}},	// [3d10] улар_, ægt_, _urak_, _कुशव,
   {{0x201e06ed,0x442ec21b,0x68f8c077,0xe4e7411b}},	//   àtic_, _kpf_, _jevd, ріан,
   {{0x533548ba,0x63784a2c,0x6375de6f,0xab5b74bc}},	//   _лент, _síne, _lána, _diür,
   {{0x7bd8f4bd,0x2d8cd58d,0x3d19454a,0x29dd00d1}},	//   _muvu, hide_, _पावे_, _kìa_,
   {{0x443cf4be,0xb60458c8,0x2453c0eb,0x7afbc39d}},	//   _lsv_, _мярк, _ịme_, vaut,
   {{0x63ad0010,0x2a3a4052,0x6b8b8a97,0x77b88018}},	//   _lkan, _געשמ, sigg, ríxa,
   {{0x6563c2bc,0x65ab40fa,0x2fcfc621,0x6d41c022}},	//   _ronh, bühr, _pigg_, vdla,
   {{0x9ad34044,0x7649b4bf,0x291804f9,0x6729b4c0}},	//   _aịza, _trey, zgra_, _ubej,
   {{0x68fc34c1,0x7e6d74c2,0x443cc03f,0x644af4c3}},	//   yard, nyap, _asv_, _arfi,
   {{0x442ec05c,0x7535166c,0x7bd8f4c4,0x7afbefa8}},	//   _bpf_, jezz, _buvu, saut,
   {{0x6d8902a3,0x69c574c5,0x442ec10b,0xd2ae409d}},	//   ržal, imhe, _cpf_, _झुनझ,
   {{0x320dc05e,0x6375f4c6,0x29dd000c,0x6d43b4c7}},	//   prey_, _fána, _bìa_, ldna,
   {{0x657ac2d4,0x6375c070,0x63a9c14b,0x254b0007}},	//   bhth, _gána, moen, kėlė_,
   {{0x1ddb4064,0x7e6d5f41,0x6b9b8041,0x28cc8048}},	//   _बढ़त, dyap, _ljug, ाशचि,
   {{0x480705af,0x6e2f4053,0xafe61000,0xbddb4303}},	//   йерн_, _apcb, собл, _krèw,
   {{0x6b8d74c8,0x63a9e906,0x443801f4,0x63ad0303}},	//   giag, noen, rwr_, _gkan,
   {{0x753500bc,0x9f5f0066,0xa3ddc048,0xfd9e8112}},	// [3d20] bezz, nutý_, _थंड_, hụọ_,
   {{0x753505d4,0xd9104de9,0x9cf60156,0x3f8df4c9}},	//   cezz, بیس_, _учиш, hieu_,
   {{0x32020089,0xfbd2483b,0x07a6443c,0x6abb80e1}},	//   lsky_, ستا_, _ганн, _azuf,
   {{0xdb00c2b0,0x3f89005c,0xa5bb19a9,0x69d9c0a8}},	//   tomí, _xmau_, ntón, _ouwe,
   {{0x69d9f4ca,0x6d890077,0x7ae434cb,0xde5884c5}},	//   _nuwe, džaj, _mfit, ралі_,
   {{0x64584051,0x2d8c6110,0xa3d34428,0xdb060851}},	//   ävis, _öde_, _हूक_, llkä,
   {{0xbddb4303,0xe577459d,0x7ae400cc,0xe3afc2f0}},	//   _brèw, _узр_, _ofit, کرو_,
   {{0x637cc88b,0x63a9c232,0x68fe4010,0x6e229604}},	//   _méng, goen, lapd, ptob,
   {{0x6719c17e,0x511a8107,0x7afdc086,0x386cc02c}},	//   _धारक_, _مزاح_, ðsta, wydr_,
   {{0x7ae4091f,0x291a4d5c,0x320234cc,0x7c3e258e}},	//   _afit, ngpa_, dsky_, _ospr,
   {{0x649a8d44,0x2fc00e89,0x320234cd,0x98b14f86}},	//   _стар_, _bhig_, esky_, _bazę_,
   {{0x68fe5b85,0xcae30045,0xf1da0185,0x6b8d43d2}},	//   hapd, कुंड_, _यूहन, xiag,
   {{0x6b8d4f75,0x7bdab4ce,0x2d8a4150,0x6604056e}},	//   viag, _hutu, _ombe_, _cvik,
   {{0xdceb8cfe,0xd943d654,0x6143d3ae,0x637cc303}},	//   čići, _нечи, _неча, _béng,
   {{0x2366c046,0x443eb4cf,0xc0580187,0x637cc303}},	//   _kooj_, _jst_, біт_, _céng,
   {{0x89d9001c,0x02a34112,0x29f68062,0xf3644e5a}},	//   _پودر_, swọọ, kła_, птун,
   {{0x2fc687ca,0x7d088718,0x6d438786,0xeab34032}},	// [3d30] dmog_, _odds, ydna, سعر_,
   {{0x68fa8329,0x29f68036,0x6b8d45c4,0x200174d0}},	//   _netd, dła_, siag, tshi_,
   {{0xdb0d4032,0x63a9c150,0x93e00048,0xf77082f0}},	//   llaí, yoen, _खूपच_, کال_,
   {{0x256f0080,0x7bc08062,0x2d8a748d,0x31658147}},	//   _sülh_, _chmu, _embe_, _solz_,
   {{0x3f8dc016,0x29f68036,0xfd9e8112,0xdb26801c}},	//   vieu_, gła_, wụọ_, تونی,
   {{0x1be98dae,0xd5af805f,0x20015d9a,0xb5fb0107}},	//   адки_, رہا_, pshi_, lyás,
   {{0x69d9f4d1,0x6b9b8673,0x6d45434c,0xfaff013b}},	//   _suwe, _tjug, mdha, nkës_,
   {{0x637860c0,0x7bda8449,0x9f5f0359,0x764d0165}},	//   _kína, _dutu, artú_, _oray,
   {{0x2ca98064,0xe579cc1b,0xdcf5003f,0xa2cb0185}},	//   ład_, изи_, nizē, सेम्,
   {{0x68fa803a,0x98ba003f,0x44314570,0xd7fb8b80}},	//   _getd, _lapā_, _kpz_, _буд_,
   {{0x7dc00107,0x660434d2,0x63a9f4d3,0x55ac4052}},	//   nöse, _svik, poen, רייַ,
   {{0x32020870,0x69dbb4d4,0xcaca05a6,0x0675cda4}},	//   tsky_, _kuue, игне_, _муля,
   {{0x637cc396,0x7bda8918,0xdb0d4359,0xed59cb63}},	//   _dénd, _zutu, glaí, _вол_,
   {{0xc17400e2,0x65b04f4c,0x1a9ac052,0x3cfec157}},	//   _buɗa_, näht, _דינע, catv_,
   {{0x2366c24c,0x764d01c8,0x04430ffe,0x6375ccec}},	//   _yooj_, _eray, мерн, _jáno,
   {{0x2246097c,0x6d5574d5,0x61e9b4d6,0x7ae4000d}},	//   _šoku_, _anza, _otel, _ufit,
   {{0x61e9939c,0x63ab8157,0xdb0d4032,0x98b840b4}},	// [3d40] _ntel, dogn, claí, _oară_,
   {{0x7f444080,0x20110639,0x2240009d,0xa1c340d9}},	//   sdiq, brzi_, _isik_, дбуд,
   {{0xe521c58e,0xdb0b801f,0x2effc0cb,0xe72a40b4}},	//   _मानि_, mogê, kauf_, _конд_,
   {{0x6d4574d7,0x224db4d8,0x7afb8ee9,0x68fab4d9}},	//   adha, _brek_, _ceut, _setd,
   {{0x7f440070,0xa2a240b2,0xc6280079,0x69c1873f}},	//   _maiq, _कुच्, মিকা_, _bhle,
   {{0x2d99c30d,0x443ea4f5,0x7bcf0066,0x66046ce7}},	//   ésel_, _pst_, íbuz, msik,
   {{0xdb00c6ed,0xd37ac5e3,0x2366c046,0xdce1897c}},	//   tomà, ичи_, _pooj_, _golč,
   {{0x93bcc156,0x3f8f86f0,0x644e74da,0x69c1800b}},	//   _apăr, cigu_, _irbi, _ehle,
   {{0x6d43f4db,0x2e240086,0x69db8303,0x20058165}},	//   _bana, jöf_, _guue, _evli_,
   {{0xa2cb0dd0,0x7c45410d,0x69c1892c,0x77bd0018}},	//   _सृष्, _ótrú, _ghle, déxa,
   {{0x637cc30d,0x0cdec083,0x7bda8051,0xd8db4052}},	//   _pénd, _bẹrẹ_, _uutu, יקיר,
   {{0x9e66c684,0x44cec03a,0xd62ae087,0x9f51405f}},	//   _واشن, rə_, _воде_, sszú_,
   {{0x637f013b,0x6282919e,0x6f00c09c,0xa3b405da}},	//   _lëng, nzoo, mamc, _जीओ_,
   {{0x291c8007,0xd378c011,0x6f00ceeb,0x69c70011}},	//   ngva_, _duće_, lamc, umje,
   {{0x44cec03a,0x984801bc,0x938b41ff,0x394353df}},	//   qə_, оята_, асаа_, _rajs_,
   {{0xdb0d4397,0x63b674dc,0x03c44289,0xdcf50017}},	//   gmað, glyn, дсум, tizē,
   {{0x63ab8240,0x65674022,0x7bdc6c90,0x9fbf0166}},	// [3d50] vogn, _pojh, _auru, nčín_,
   {{0x344b4445,0x4431405c,0x3a3f8033,0x644e4ddd}},	//   ичен_, _ppz_, _rsup_, _brbi,
   {{0xe520054a,0x6fcac045,0xdb0d4018,0x2fc2405e}},	//   _बाति_, ागां, smañ, _fhkg_,
   {{0x883a0093,0x2d9e8013,0x657aa198,0xa2c204c7}},	//   _פתרו, _ajte_, _alth, रेक्,
   {{0x68fc74dd,0xdb09829a,0xfce582d5,0xc0e5839d}},	//   _ferd, _bheò, поло, полк,
   {{0x63ad74de,0x6375c066,0x443c823b,0x799ac022}},	//   loan, _páno, fwv_, jntw,
   {{0xe4e4812b,0x6b8d1417,0xddc9c064,0x7dc000fa}},	//   фічн, _omag, rzeż, lösc,
   {{0x7bc2dad0,0x69dd586d,0xb4bb828b,0x03a8c1b4}},	//   _chou, _kuse, _घरी_, يديو_,
   {{0x61e9b4df,0x2d912444,0x69d55955,0xdb09829a}},	//   _utel, kize_, _kize, _fheò,
   {{0x8d778e5f,0x637f00fd,0x0577871d,0x7bdc4057}},	//   _بارا, _lënd, _بارد, _yuru,
   {{0xcea90052,0x6aa2c033,0xf8ced05d,0x63ad6d76}},	//   _עי_, _exof, _हृदय, koan,
   {{0x65b040fa,0x6441b4e0,0x6d5700d2,0xa5bb34e1}},	//   nähr, _isli, _anxa, stól,
   {{0xee2ec7d6,0x64484018,0x2138005c,0x69dd74e2}},	//   _ян_, _ádiv, terh_, _nuse,
   {{0xd378c011,0x7bc2f4e3,0x270cc026,0x65bdc231}},	//   _vuće_, _zhou, rėnų_, bèha,
   {{0x3079c009,0x63ad4156,0x69dd74e4,0xc1e6c4e8}},	//   _לאַנ, foan, _ause, _وکیل_,
   {{0x6ea70c7e,0xbea6011b,0xe51e40aa,0x68fc74e5}},	//   _टुकु, _найк, _पाहि_, _serd,
   {{0xdb0d410d,0x69d56b02,0x171b0093,0xdce3f4e6}},	// [3d60] rmað, _bize, _הופע, _lonč,
   {{0x645cc0ac,0xdb0d4086,0x6d4534e7,0x69dd725f}},	//   årig, smað, _gaha, _duse,
   {{0x2005e634,0x63b6456e,0x6ec04047,0x63ad46bc}},	//   nsli_, plyn, लेजु, boan,
   {{0xdb1d4018,0x63a974e8,0xd7ef4032,0x77b60018}},	//   _disó, čenc, اكن_, fáxi,
   {{0x6568a169,0x290174e9,0x69dd400d,0x69c8c02c}},	//   _podh, baha_, _guse, ymde,
   {{0x6d450283,0x29028017,0x645827be,0x3a26b4ea}},	//   _xaha, _ēkas_, _àvis, rtop_,
   {{0x39458402,0x644e74eb,0x62828046,0xb8f493c4}},	//   _dals_, _urbi, szoo, _सः_,
   {{0x2d9134ec,0xa2b34384,0x69d5640b,0xab279198}},	//   zize_, _आडम्, _zize, _носа_,
   {{0x2007f4ed,0x69dd4057,0x65688311,0x80a68de9}},	//   _avni_, _xuse, _todh, _کمان,
   {{0x63ad5234,0x628474ee,0x7bde00f8,0x69c3c73f}},	//   zoan, izio, _oupu, _chne,
   {{0x636ec05e,0x201a40f8,0x69c8f4ef,0x7bde204c}},	//   _bùnt, nupi_, rmde, _nupu,
   {{0xba2ac01c,0xe6950051,0x7bd6044e,0xe521c185}},	//   _هستم_, димы, _ciyu, _माथि_,
   {{0x6fd64e31,0x2be48079,0xe9ff800c,0x7bd609c7}},	//   _मंजू, _গিয়ে_, _trấn_, _diyu,
   {{0x3d170021,0x645cf4f0,0x62844f59,0x69c3c061}},	//   तलें_, äris, dzio, _ghne,
   {{0x26120b6d,0x7afd52c5,0x69dd50d5,0x628445f5}},	//   _तिथी_, _pest, _suse, ezio,
   {{0x201a6561,0x7bd60010,0xf99f2212,0x7bc434f1}},	//   dupi_, _giyu, très_, _ghiu,
   {{0x290174f2,0x6f02b4f3,0x63ad74f4,0x4427805c}},	// [3d70] taha_, daoc, roan, ztn_,
   {{0x63ad74f5,0x201a4150,0x261c4027,0xdb00c521}},	//   soan, fupi_, मढ़ी_, lomä,
   {{0x69d574f6,0x63ad61ca,0x200774f7,0xf1bf4032}},	//   _vize, poan, éni_, _spás_,
   {{0x56958051,0xdb1d4019,0xe6958032,0xdce3c123}},	//   мает, _visó, ولاد, _ronč,
   {{0x39459a8a,0x657dc13b,0x2901402f,0x2169a188}},	//   _pals_, ëshk, paha_, жили_,
   {{0x6722c34d,0x61ed34f8,0x7aff00d2,0x69d70085}},	//   _acoj, _mtal, _leqt, _jixe,
   {{0x7642c031,0x7ae60041,0x6f0280eb,0xdbf180a0}},	//   _asoy, yckt, baoc, příj,
   {{0x61ed34f9,0xe1ff1ed3,0xe7bf4a91,0x645a4013}},	//   _otal, nyós_, ्षिप, _štig,
   {{0xdb1b80d1,0xd346c01c,0xdb26816a,0x7ae9a988}},	//   _thuâ, بینه_, _توقی, _ifet,
   {{0x69d734fa,0x291ec05c,0x7bd612e8,0x656ac321}},	//   _nixe, ggta_, _siyu, _cofh,
   {{0x7d01ca62,0xa3ad428b,0xd469e497,0xd7bf408f}},	//   rals, गवा_, цине_, ्षाच,
   {{0x32090053,0x3e83c303,0x61ed01d6,0x66e3c1c0}},	//   _bvay_, _cèté_, _btal, _díkó,
   {{0xc447c01c,0xe51e45a8,0x89f60c38,0x9f9f44f1}},	//   زیکن_, _पालि_, ьянц, _géén_,
   {{0xed59c119,0x6f0280e5,0x89dac1f2,0xd131ce5f}},	//   _фок_, zaoc, _וחסי, _شمع_,
   {{0xb9061326,0xd6f54079,0x7bd6117e,0x2ac40031}},	//   _फल_, _ছাড়া_, _tiyu, _bèbí_,
   {{0x7d0389b0,0x69c50107,0x6609879b,0xe3ba431e}},	//   hans, _ehhe, _ovek, іба_,
   {{0xb8d50185,0x61fb80eb,0x69d734fb,0x71764032}},	// [3d80] _छु_, _nwul, _fixe, وهرا,
   {{0x76440602,0x637cf4fc,0x3947c3b3,0x4ab185da}},	//   _isiy, _ména, _jans_, _जड़व,
   {{0xb4ea34fd,0x20078077,0x2eff8053,0x61fb963e}},	//   मडी_, jsni_, _beuf_, _awul,
   {{0x442a034d,0x628440fc,0xbddb4396,0x9179435d}},	//   mtb_, pzio, _isèn, _vấn_,
   {{0x201a4033,0x59f88119,0x69bf80b2,0x644e07fb}},	//   supi_, челя_, _लीही, lvbi,
   {{0x6f0470d4,0x2738c015,0xc1a8808f,0xad9b4031}},	//   laic, _ẩn_, गवेग, _awúf,
   {{0x661640b1,0x00000000,0x00000000,0x00000000}},	//   lryk, --, --, --,
   {{0xdd998053,0x44440378,0x7d0381b0,0x200a4024}},	//   _awňd_, _ms_, aans, _ivbi_,
   {{0x6443c181,0x6d58c545,0x661bc0bb,0x00000000}},	//   _asni, _pnva, guuk, --,
   {{0x61ed0303,0x64484018,0x290c8041,0x3eb8c017}},	//   _rtal, _ádis, _udda_, ārt_,
   {{0x660982a3,0xab2ac0d7,0x63af0ff5,0x443ec0a8}},	//   _zvek, _можа_, tocn, uwt_,
   {{0x61e0b4fe,0x6d4aada3,0xb9230112,0x6b829e20}},	//   _kuml, ldfa, barụ_, nhog,
   {{0x6f0474ff,0x63af0487,0x6b9d0041,0xe4e7011b}},	//   daic, rocn, rnsg, дібн,
   {{0x753c3500,0xfaff40b1,0x44440c18,0x6f04405e}},	//   gerz, _seë_, _bs_, eaic,
   {{0x6d8900b3,0x5ba71dff,0x764400f7,0x5f950156}},	//   džat, _ориз, _esiy, _пикт,
   {{0x69d8f501,0x6f00929d,0x657e005e,0x63a2c033}},	//   _hive, _nemc, _elph, _jjon,
   {{0x98bf003a,0x62860036,0x5d554b24,0x23668570}},	// [3d90] ırıb_, czko, нкат, djoj_,
   {{0x7dc00041,0x71750032,0x3980c3e2,0x201cb502}},	//   lösn, _أهدا, _fòse_, kuvi_,
   {{0xa739d8ca,0x3a2948f9,0x2d9358e1,0x660986bc}},	//   ščiš, stap_, rixe_, _svek,
   {{0x6d48a505,0xc7b902bc,0x63a2f4d0,0x673d3245}},	//   _aada, buđe_, _njon, nesj,
   {{0x636600e1,0x2901009d,0x8db58039,0x61e0b503}},	//   _cóny, _keha_, нскі, _cuml,
   {{0x63a2c051,0x9179435d,0x9f5f07cb,0x637cc1cb}},	//   _ajon, _dẫn_, vrtý_, _réna,
   {{0xe05781aa,0x2fc6c68a,0xdce3c017,0xad9b41c0}},	//   بیات_, _bhog_, _nonā, _awúg,
   {{0x1309c761,0xc245cf34,0x644504fd,0x6d48b0d4}},	//   чний_, еник, _mshi, _eada,
   {{0x69d8cc9f,0x461580a3,0x260985d5,0x64484018}},	//   _bive, _سوار, _सिटी_, _ádir,
   {{0xf1b9c077,0x67240011,0x63a2cbc2,0x3eb9443e}},	//   kuše_, _scij, _ejon, _myst_,
   {{0x7ae4993f,0x236d80b3,0x661bf504,0xc7b9c107}},	//   žite, _koej_, suuk, plő_,
   {{0x70dc557c,0xf1b9eea1,0x63a2c13b,0xc0524052}},	//   _बल्ल, duše_, _gjon, אזט_,
   {{0x6d48a02c,0xab18c11b,0x3947cb45,0x657e00f8}},	//   _yada, _цієї_, _tans_, _plph,
   {{0x7d01b505,0x3f8200da,0x32095176,0x66d683a6}},	//   _jels, shku_, dsay_, _hükü,
   {{0x6d890039,0xe4e4c11b,0xfd690044,0x6f04468a}},	//   ežas, _річн, _hapụ, taic,
   {{0x6375c79f,0x63bbc253,0x661d1880,0x69d8e4a2}},	//   _báni, nlun, busk, _zive,
   {{0xd2a751e8,0x6375c018,0x661d22fd,0xdb0d0018}},	// [3da0] екте_, _cáni, cusk, _ghañ,
   {{0xfd6900eb,0x7d054aef,0x661664ef,0x3eb95f80}},	//   _mapụ, gahs, rryk, _dyst_,
   {{0x63bbd0e8,0x2905c0b4,0x06f409fd,0xad1b0052}},	//   klun, iala_, _आभाव_, _צוטר,
   {{0x6366003c,0x6609f506,0x46a683d0,0x26ddc112}},	//   _cónx, ksek, наев, _ngwo_,
   {{0x6609f507,0x613380b5,0xa2d643a9,0x29fdc02d}},	//   jsek, kılı, _سيست, jňa_,
   {{0x29fdc166,0x7bd9c031,0x6b82a92f,0x6d4a805c}},	//   dňa_, _aiwu, shog, udfa,
   {{0x290ec070,0x7d0198fd,0xca48c0d1,0x61338080}},	//   _rdfa_, _dels, _sờ_, dılı,
   {{0x7c2aa9f3,0x63bbcfb3,0xa3e30027,0x7bd9c09c}},	//   rtfr, glun, _फंस_, _ciwu,
   {{0xada68097,0x6d5a8056,0x2905c634,0xdb0d410b}},	//   _заал, _tnta, fala_, slaç,
   {{0xf8abc00c,0x8233c032,0x764280bc,0xc178c007}},	//   ười_, اريا, mwoy, ukė_,
   {{0xe521c0b2,0x2d9ec0cb,0x98b84036,0x63a2f448}},	//   _मारि_, rnte_, _parę_, _tjon,
   {{0x389b4087,0x7ae9ca48,0xca48c015,0x656e4e89}},	//   ליינ, ccet, _tờ_, _lobh,
   {{0x59b0408f,0x6d893508,0x7995119b,0x637cc396}},	//   जकार, džar, tizw, _héno,
   {{0x2246c231,0x7642809c,0x63a42c64,0x7ec908c7}},	//   _isok_, iwoy, _ejin, _rūpī,
   {{0x27fe805c,0xf1bf005f,0x5f95401b,0x66d68165}},	//   _jwtn_, lták_, вивт, _yükü,
   {{0x213ecd4e,0x201ef509,0xf1b9e822,0x3209687a}},	//   leth_, muti_, ruše_, tsay_,
   {{0x69dab50a,0x02a300eb,0xaac9c185,0x7bcd750b}},	// [3db0] _oite, _kpọọ, ाइएक, rmau,
   {{0x491b0185,0x200c8123,0x2007401f,0x6f02d29a}},	//   _बाटो_, _ovdi_, ânio_, _leoc,
   {{0x2121405c,0x656e46d3,0x7d01b50c,0xac99001c}},	//   rghh_, _dobh, _rels, _آنجا_,
   {{0x3eb9750d,0x69da88a6,0x645a4011,0x656e405e}},	//   _tyst_, _aite, _štic, _eobh,
   {{0xce5841dc,0x7d01854e,0xe8d9c0d1,0x7aed0449}},	//   _заяц_, _pels, _đọ_, _mfat,
   {{0x4438491f,0x7ae9c3f3,0x7f4d750e,0x7d07152b}},	//   _fpr_, wcet, ldaq, najs,
   {{0xad9b0359,0x6f02c359,0x7aed350f,0xa96685f5}},	//   gsúi, _beoc, _ofat, тища_,
   {{0x2246c033,0x9f5f0066,0x257400fa,0x637cc669}},	//   _bsok_, ystá_, _hält_, _déno,
   {{0x6d4ac4da,0x290356d0,0x3eb9c80d,0x2d81010b}},	//   _bafa, _keja_, æst_, _olhe_,
   {{0x69da800d,0x645a7510,0x673f40fd,0x6e2d661c}},	//   _gite, _átic, heqj, itab,
   {{0xa0a5e1c8,0x2246ec16,0x7886ed53,0xc9849acb}},	//   танд, _esok_, _révé, _сути,
   {{0x64554a11,0x6e2d6117,0x1eeac0fb,0x753e40fc}},	//   _mrzi, ktab, _قومی_, zepz,
   {{0x29079234,0x333fc01e,0xe29f0086,0x07a3002b}},	//   oana_, meux_, taða_, раян,
   {{0x64a63511,0x29037512,0x645540c4,0x200a0077}},	//   вага, _neja_, _orzi, tsbi_,
   {{0xe1ff402e,0xf99f40ce,0x2fc9029a,0x6b84515a}},	//   _awó_, _evèk_, _fhag_, thig,
   {{0x6f02c004,0x63a4012c,0x44384f2d,0x645ec013}},	//   _xeoc, _ujin, _rpr_, _špig,
   {{0x6d4ace0b,0x6e2d471c,0xc9aa08b5,0xdb0b830d}},	// [3dc0] _yafa, gtab, _овие_, gogí,
   {{0x7d560009,0x6f043513,0x2258804f,0x91a7435d}},	//   _ייִד_, _heic, _črk_, _địa_,
   {{0x61e415a9,0xe6bec191,0x92bdc079,0x660d1dec}},	//   _huil, _ऊर्ज, _আলো_, _zvak,
   {{0x61e422d4,0x333fc01e,0x443a3514,0xeb9a40d9}},	//   _kuil, jeux_, _ipp_, _цим_,
   {{0x7bc9861f,0x2907a704,0x64557515,0x81cb8079}},	//   _dheu, fana_, _erzi, রআন_,
   {{0x1ea9879e,0xd378c2bc,0x2b404032,0x7d03e73c}},	//   راني_, _pućo_, leic_, _nens,
   {{0x61e2cf77,0x443a3516,0x4394cd44,0x97a6c4b6}},	//   _suol, _jpp_, лакс, крил,
   {{0x798186bf,0x999f8011,0x333fc01e,0x6d4af517}},	//   _ellw, _gruž_, geux_, _safa,
   {{0x69daa925,0xcf934626,0x49ba8d6b,0x63a2b518}},	//   _tite, יטה_, _قائد_, mnon,
   {{0x3f86b519,0xd130c183,0x1e83812b,0x2d980119}},	//   lhou_, حمد_, _тлум, jire_,
   {{0xd91b4087,0xcad2c044,0xf9934093,0x6f04002c}},	//   וויל, _gịnị, שרת_, _beic,
   {{0xaca44044,0x69dc751a,0x6d4e0fd7,0x7644400d}},	//   _asịr, _lire, edba, kwiy,
   {{0xb5fb005f,0x7d07006c,0x7ae08010,0xe534c092}},	//   lyáz, tajs, _mgmt, _бель,
   {{0x2d85cd04,0x6e20ca77,0xa3ddc374,0x7c93c08c}},	//   chle_, mumb, _थूक_, اشیا,
   {{0xdb1bc016,0x7d07351b,0x29cf017a,0xfbd3401c}},	//   fluè, rajs, _bżar_, لتر_,
   {{0x660d86a4,0x443a0398,0x5b144844,0x4444402c}},	//   šaki, _dpp_, имст, dw_,
   {{0x4444751c,0x6b82c077,0x2eed8019,0x2369404f}},	// [3dd0] ew_, _mlog, _rfef_, rjaj_,
   {{0x2bc34028,0x6f040600,0x6ac3682d,0x3f992499}},	//   _वीरा, _zeic, _शरीर, lisu_,
   {{0x48156c74,0xdb044018,0x439542d3,0x333fc01e}},	//   умес, aliñ, _банс, yeux_,
   {{0x671d4c6b,0x63a29ae3,0x69dc424f,0x7644491f}},	//   _फाटक_, gnon, _eire, bwiy,
   {{0x637cc018,0x61e24032,0x443a004f,0x257404c9}},	//   _vénl, íolt, _zpp_, _tält_,
   {{0x3ea98283,0x7aed409f,0x7c3a8303,0x527c0323}},	//   ħat_, lcat, _bptr, ונדא,
   {{0xdd944097,0x80ad8079,0x26c6c011,0x387f40e2}},	//   _тары, য়েন্, _azoo_, _ƙuru_,
   {{0x3f86856e,0x6b82f51d,0x7bdd4033,0xf1b9dffd}},	//   chou_, _clog, _jisu, duša_,
   {{0x69cacf35,0x6f04351e,0x3f99351f,0x9f5f004c}},	//   _bhfe, _reic, disu_, istä_,
   {{0x2b4dc05c,0x2d98003c,0x61e201cb,0xbc19c097}},	//   sdec_, xire_, _éoli, німі_,
   {{0x2d87824f,0x7f4d0057,0x660d5c68,0xeb9a0b8e}},	//   mhne_, _baaq, hsak, еин_,
   {{0x6e20c26d,0x637f00fd,0xdcfac007,0x888c8052}},	//   bumb, _dëno, kitė, _קראַ,
   {{0x44217520,0x26068028,0xed4ed1e8,0x877a8009}},	//   huh_, सीपी_, _ло_, גארי,
   {{0x6f0400fa,0x9f5f0051,0x55e301cc,0x7c2e2c70}},	//   _weic, estä_, сорб, ttbr,
   {{0x2249021b,0x69dc7521,0xe73a4069,0x3cebb522}},	//   _esak_, _rire, нев_, _चलने_,
   {{0x2eedc906,0x2d980ddb,0xf7720567,0x8afd80a0}},	//   ncef_, sire_, _چاک_, _mořs,
   {{0xa7a74f36,0x733b0009,0xa5bb1792,0x31714303}},	// [3de0] укта_, _טעקס, dróf, _bozz_,
   {{0xed461807,0xdb044018,0x7d050414,0xe3b90138}},	//   _сноп, rliñ, _gehs, ltıp_,
   {{0x661bf523,0xb9250112,0x7c21c05c,0x2d83404f}},	//   hruk, _lepụ_, nulr, _dlje_,
   {{0x6e20f524,0xa09b0009,0x20555373,0x7bdd42a7}},	//   yumb, _טייט, штур, _gisu,
   {{0x6375dd9d,0x4a764156,0xf1a9001c,0x6b84001c}},	//   _láns, _сынт, _سایه_, _mlig,
   {{0x6b840315,0x6e20db03,0x63a28cdc,0x2be88045}},	//   _llig, vumb, snon, _चंदू_,
   {{0xa2d6e7d7,0x7bdd41c6,0x6e20c18c,0xdcfe4017}},	//   मेन्, _yisu, wumb, sipē,
   {{0x7afbcaee,0xa5bb02b0,0xa614cc8a,0x466ac86c}},	//   gbut, cróf, амич, ером_,
   {{0x6b82c06c,0x63a47525,0xcad2c112,0xbb3b4009}},	//   _vlog, inin, _gịlị, געפי,
   {{0x6b960100,0x290a3526,0x3d94f527,0x1637c1b4}},	//   _amyg, jaba_, риор, اسية_,
   {{0xa5bb0064,0xa3b444b2,0x61e64340,0x2fc04383}},	//   któr, टवा_, _lukl, klig_,
   {{0x29058232,0x7dc00041,0x660d535f,0x22490033}},	//   _zela_, lösh, ysak, _psak_,
   {{0x6eb0461a,0x442140b3,0x5f9400c5,0x518711e5}},	//   _अँगु, zuh_, сият, гува,
   {{0x290a2d31,0x7d0ab528,0x6d41e60f,0x6378410d}},	//   gaba_, nafs, cela, _mínu,
   {{0x61e67023,0x7aed40d2,0x6b84125d,0xab5b00cb}},	//   _aukl, tcat, _flig, glüc,
   {{0x644ac0f1,0x4c13c61e,0x6602f529,0x6d4e752a}},	//   _isfi, _ابوس, _kwok, _aaba,
   {{0x3b0941c8,0x61e64303,0x461552c0,0xdb044086}},	// [3df0] raaq_, _cukl, شوار, rlið,
   {{0x7afd0600,0x8d77451b,0xf527067b,0x3f848cac}},	//   lbst, دارا, _сфин, _almu_,
   {{0x660d55f0,0x44214033,0xf8b90028,0xa2d9109f}},	//   ssak, uuh_, _इडिय, _नृत्,
   {{0x7ae48066,0x320dc1c8,0x63a44147,0xa3d64036}},	//   žitn, ysey_, cnin, िगण_,
   {{0xaf04811b,0x44230c56,0x6d4e45ec,0x6602c094}},	//   спіл, luj_, _faba, _nwok,
   {{0x6edbc03f,0x6458d136,0x661d352b,0xbdf886b0}},	//   _jābū, _orvi, irsk, ارنا_,
   {{0x98b800b4,0x649880c5,0x442ec0c2,0x4423082a}},	//   meră_, лтър_, _nqf_, nuj_,
   {{0x68fc00ab,0x7d0767eb,0x3f89402c,0x543c0009}},	//   zbrd, _hejs, nhau_, געהא,
   {{0x443cc07a,0x63bbb52c,0x52388c59,0x99804166}},	//   _apv_, _ikun, _مسلح_, stiť_,
   {{0x661beca8,0x8e848032,0xe7ed8021,0x2175d213}},	//   rruk, _الكه, _चंपा_, руир,
   {{0x442300e2,0x290a352d,0x63bb8283,0xfd108032}},	//   juj_, vaba_, _kkun, _رجل_,
   {{0x63bb81b7,0x7bdf0018,0x69de352e,0x6b8400f1}},	//   _jkun, _ciqu, _sipe, _qlig,
   {{0xe8eecc93,0x799ad9f1,0x442ec085,0x3f89402c}},	//   _мл_, bitw, _eqf_, dhau_,
   {{0x63bb8010,0xbddb4053,0x63784359,0x8cb103fc}},	//   _lkun, _erèz, _línt, _आँखो,
   {{0x63784004,0x61e650df,0x1d072145,0x4126c11b}},	//   _oínt, _sukl, реси_, _тощо_,
   {{0x2bbf7213,0x59b40185,0x6b89f52f,0x661d004f}},	//   ्षगा, ंकहर, nheg, brsk,
   {{0xa3c8c08f,0x27e7c6bc,0x69de3530,0x44310545}},	// [3e00] ोगत_, _hunn_, _tipe, atz_,
   {{0x69c1e934,0xda18c08f,0x2fc044a0,0xe8f750e9}},	//   nlle, _दिसत_, slig_, илу_,
   {{0x799c2912,0x3f894046,0x68e3c0f8,0x2fcd805e}},	//   mirw, bhau_, _mgnd, _bheg_,
   {{0x3f897531,0xa5bb030d,0x2fdf8004,0xcad2c044}},	//   chau_, tróg, _ciug_, _dịjị,
   {{0x98b800b4,0x799ac1c6,0x7ae40303,0x27e7c05e}},	//   beră_, yitw, _mgit, _lunn_,
   {{0x61e4c032,0xdb0f0018,0x63bbab07,0x8e570323}},	//   _éili, vocí, _ekun, יינג_,
   {{0xdca3434a,0x63a980b0,0xe4b880d7,0x2918c359}},	//   _дари, _fjen, ылкі_, óram_,
   {{0xea004082,0x69c1f532,0x63784031,0x8fa69828}},	//   _luật_, elle, _tínu, _табе,
   {{0x68e94119,0x7d0a8a26,0x44231048,0x637cc396}},	//   _şedi, pafs, zuj_, _jéni,
   {{0xd378c011,0x201c8944,0x63a98043,0x27e7c125}},	//   _mući_, prvi_, _zjen, _bunn_,
   {{0x7ae40450,0x7bcd004d,0x2d9c9235,0x7c3b58ca}},	//   _bgit, _phau, mive_, _ćurk,
   {{0x63a4d0b4,0x645ab533,0x779301aa,0x6b9bc5f5}},	//   čins, _irti, تیبا, ciug,
   {{0x602a803a,0x7afd02e6,0x799ac2c0,0x661d075a}},	//   _təms, rbst, pitw, ursk,
   {{0xe4a70589,0x660411ca,0x2d850036,0x2d9c813b}},	//   арбо, _dwik, óle_, nive_,
   {{0x7414c5d3,0x443cc8fd,0x3707527f,0x67d5000a}},	//   _اوبا, _upv_, ичав, _локу,
   {{0x7d089bcd,0x44313534,0x2d9cb535,0x201ec0ab}},	//   _leds, rtz_, hive_, mrti_,
   {{0xdb00c30d,0xa78704e8,0x6e24502f,0x7bc2a01a}},	// [3e10] lomó, _مشکو, guib, dlou,
   {{0x6d43b536,0x2907e4dc,0x764d3537,0x290ccdb2}},	//   xena, _xena_, _isay, nada_,
   {{0x6d43a670,0x2d9cb538,0x2dd84032,0x7e7d014d}},	//   vena, dive_, شبكة_, lysp,
   {{0x60d9c009,0x98b800b4,0x69ce4545,0x1037c052}},	//   אַנג, seră_, _ehbe, שטאם_,
   {{0x637cc669,0x2d8f401e,0x7e7d3539,0x98b800b4}},	//   _géni, èges_, nysp, peră_,
   {{0x22494010,0x6f0d41c8,0x614588b1,0x2b3f40eb}},	//   mwak_, laac, сека, _ịgụọ_,
   {{0x672d04f9,0x6d43b53a,0x2249402f,0xaadb40e4}},	//   _ocaj, rena, lwak_, _मृतक,
   {{0x3f86c4e2,0xa765cb3d,0x201c4077,0x7d089179}},	//   _clou_, скид, švic_, _eeds,
   {{0x645c8086,0xd24ec1b4,0xe7eb456c,0x3a24c0b3}},	//   _árin, فني_, _जूता_, gump_,
   {{0x237ff53b,0x7d7481b4,0x69c1c018,0xa3cb8c6b}},	//   skuj_, _والط, ulle, _रीत_,
   {{0x4433753c,0x3f86f53d,0x6575411f,0x0445c698}},	//   ntx_, _flou_, _mozh, щенн,
   {{0x63b99120,0x6d4540a1,0x6b9d353e,0x7659c1f4}},	//   nown, heha, gisg, _trwy,
   {{0x6fda8047,0x6d45753f,0xf38cc052,0x673bb540}},	//   _důch, keha, _בראָ, _mbuj,
   {{0x60c18051,0x3f99409c,0x7649e844,0xea0040d1}},	//   _kylm, _amsu_, mwey, _quật_,
   {{0x7dc6c80f,0x6563f541,0x799c09c1,0x6f0d4057}},	//   iðsl, _innh, rirw, faac,
   {{0x6e247542,0x9f45c396,0x7bcf4061,0x66043543}},	//   tuib, _bulé_, _chcu, _twik,
   {{0x9f45c674,0x61e981a8,0x2eff0018,0x98a5c007}},	// [3e20] _culé_, _nuel, ñufe_, telė_,
   {{0x637cc7b0,0xbd4607ce,0x3a325f76,0x3f820025}},	//   _véni, _اندي, rtyp_, lkku_,
   {{0x2bc34045,0x6e261348,0x3a324851,0xdce1c007}},	//   _वीका, lukb, styp_, rklė,
   {{0x543b0009,0x4425c119,0xd378c2a3,0x7d0e0856}},	//   _געטא, iul_, _tući_, labs,
   {{0x94128435,0x3f82052f,0xa4f8805f,0x6378402e}},	//   əcək_, ikku_, لکار_, _fínr,
   {{0x7c2544a7,0x6d457544,0x7bc28047,0x3c31c066}},	//   buhr, ceha, slou, káv_,
   {{0x44337545,0xdfd0cf4d,0xa9679025,0x307a0052}},	//   ctx_, ويت_, сија_, טאַנ,
   {{0xadfa00e6,0x69c39815,0x9378c119,0x6563c15a}},	//   ्ठान_, alne, рбит_, _annh,
   {{0x290a405c,0x6e9681b4,0x7d0e3546,0x2002c158}},	//   _keba_, _الذا, kabs, ćkim_,
   {{0x443e8056,0xdb00ca4d,0xd90ed1be,0x64a68f34}},	//   _tpt_, tomó, ریب_, _лаза,
   {{0x91bb42a6,0x7bc44007,0x7aed991f,0x998942bc}},	//   רמיי, kliu, žate, ntaš_,
   {{0x3a24de7a,0x799e40f8,0x7e7d3547,0x61e9809c}},	//   pump_, hipw, tysp, _yuel,
   {{0xfa33c01c,0x3945c57b,0x753c4062,0x645c4085}},	//   _فرود, bels_, _obrz, _lrri,
   {{0xe81d0028,0xe29f010d,0x9989413f,0x3ce504f5}},	//   _फिदा_, naði_, ktaš_, ølv_,
   {{0xfd65c112,0x61d80c38,0x37ab423d,0x6d454253}},	//   hetụ, ёмся_, гтан_, veha,
   {{0x22400303,0x8af9423d,0x7d0ac086,0xc417c107}},	//   _fpik_, рнас_, _hefs, _اغوا_,
   {{0x63ad3548,0xf1ab01aa,0xdb0f0018,0x3f89009c}},	// [3e30] _ijan, _ماده_, cocá, _ilau_,
   {{0x61ed5746,0xdb1d0359,0x91070156,0x7c257549}},	//   rqal, ilsí, _учид, tuhr,
   {{0x290e8c29,0x63b9b54a,0x6ff3c0cc,0x69c3802d}},	//   dafa_, town, _tăce, vlne,
   {{0xe7c90ebe,0x69acc08f,0x5fc90444,0x3f994033}},	//   रतिप, ीकडी, रतिल, _umsu_,
   {{0x61e9aecb,0x290eb54b,0x645c754c,0x63b98064}},	//   _quel, fafa_, _erri, rown,
   {{0x9f4800da,0xe7ed8c63,0x6fe8c185,0x644e40b3}},	//   _punë_, _चंदा_, _těch, _fsbi,
   {{0x947541aa,0x29c9803c,0x3945f54d,0xc0584589}},	//   _بگذا, búan_, vels_, _літ_,
   {{0x61e1a374,0x224d9b85,0x673b800d,0x29c98019}},	//   _will, _tsek_, _ubuj, cúan_,
   {{0xb4fb0048,0x6729f54e,0x3945cdc5,0xb5fb4107}},	//   ्राय_, rgej, tels_, _drág,
   {{0x61e19335,0xae1e40aa,0x2d8cc1b4,0x7649c1c8}},	//   _uill, यूटन_, ghde_, rwey,
   {{0x63ad0085,0xf2c902a6,0x0cab80c5,0x224003ad}},	//   _bjan, _סע_, _стаи_, _spik_,
   {{0x6d551790,0x2d9a0b64,0x2d83015d,0x672ba5c0}},	//   edza, _smpe_, ekje_, nggj,
   {{0x63a9ebd0,0x7dd04136,0xab5b0165,0x25fd8048}},	//   mnen, läse, mlül, रीची_,
   {{0x3f8dc10b,0xdb0f030d,0x64418053,0x2b9b80eb}},	//   lheu_, rocá, _kpli, ụcha_,
   {{0xe73201b4,0x3b00403a,0x290a41c6,0x7de00031}},	//   _قصة_, tbiq_, _reba_, _aásì,
   {{0x290a754f,0x61e3f550,0x2918405c,0x7bc44007}},	//   _seba_, _hinl, _sdra_, uliu,
   {{0xd62a630e,0x6f0bc107,0xf50a4d37,0x39479e2a}},	// [3e40] розе_, _megc, инал_, kens_,
   {{0x637f00fd,0x39478253,0x63a9c0cb,0x7bc607a6}},	//   _rëni, jens_, hnen, llku,
   {{0x6441823b,0x63bbc0b6,0x7bc44039,0xf21e4064}},	//   _npli, koun, pliu, यूज़_,
   {{0x7dcd85b1,0x63a9f551,0x645e05f5,0x290a7552}},	//   yúsc, jnen, _irpi, _weba_,
   {{0xade34027,0xe29f0086,0x88cfc079,0x645e0011}},	//   _कंचन_, taði_, রশিক, _hrpi,
   {{0xdb1d4756,0x29c98004,0x6b9ba28d,0x2d9e4138}},	//   _aksè, súan_, _emug, _öte_,
   {{0x2d9ed372,0x7d0af553,0x44214033,0xf1a9820c}},	//   vite_, _refs, crh_, حانه_,
   {{0x2242421b,0x1c1d0027,0x6b84445f,0xb4ba81ac}},	//   _kpkk_, _फिसल_, nkig, _घडी_,
   {{0xb6a3811b,0x316ac5a4,0x7dc01485,0x3cde4ca7}},	//   _житл, ашно_, nöss, _कृते_,
   {{0x61ebc6eb,0x290ad90f,0x6f0f06df,0xa3ea08b8}},	//   _dugl, úba_, wacc, मदा_,
   {{0x61e3c9d7,0x6b846c2e,0x3f8906ed,0x6d471408}},	//   _dinl, kkig, _plau_, veja,
   {{0x6f02b554,0x637cc781,0xa3c9409d,0x69cac036}},	//   nboc, _cént, _लीं_, _सीरी,
   {{0xb7db8093,0x39530018,0x290cb555,0xe3b9003a}},	//   יקטי, _paxs_, _keda_, brın_,
   {{0x26c48157,0x644000b4,0x637cc0dd,0x61e3c0b6}},	//   _mymo_, ămin, _vénu, _ginl,
   {{0x6f0f05f5,0x7dcd8032,0xe8d9c00c,0xdb09c0fa}},	//   pacc, núsa, _đệ_, nieß,
   {{0x765d4010,0x63ad0dc0,0x2d8a40b4,0x52151450}},	//   _prsy, _ujan, _albe_, _едит,
   {{0xe1f05971,0x61e3ce05,0x68e74070,0x6e22806f}},	// [3e50] نسل_, _yinl, _pgjd, jrob,
   {{0x67f341b7,0x63adc0ef,0xea00400c,0xbddb4031}},	//   _aħja, čani, _quạt_, _asèr,
   {{0x63a9d62b,0xf48501aa,0x6e22b556,0x29033557}},	//   ynen, _رادی, erob, mbja_,
   {{0x39478b45,0xb5fb4531,0xbd05c1c0,0x637cc018}},	//   wens_, _prád, _afẹ́, _méns,
   {{0x291a005c,0xfd5000eb,0x8d658623,0x6e22b558}},	//   _ydpa_, _nchụ, звле, grob,
   {{0x35cfc027,0x764d7559,0x394782a4,0xa2ce04fb}},	//   _सीढ़, mway, uens_, _सरस्,
   {{0x6d48f55a,0x3a295eb5,0x63a9c038,0x60108a2c}},	//   deda, luap_, tnen, _rómá,
   {{0xb5fb41b4,0x059581aa,0x6235b55b,0x69c700b3}},	//   _trád, _کارگ, _небу, hlje,
   {{0x61e3c240,0x764d6060,0x60b5805f,0x799c402c}},	//   _pinl, nway, _کمائ, _ymrw,
   {{0x29111afe,0x6b8440fc,0xd83b8f93,0x7e64c97c}},	//   jaza_, zkig, _вэд_, _šipc,
   {{0x6f0d1cc7,0x63a9f1fa,0xad9b4031,0x63bbc398}},	//   _beac, pnen, _awúk, poun,
   {{0xaadfcebe,0x61e3c2cd,0x7dc00051,0x764d4d68}},	//   _पृथक, _winl, yöss, kway,
   {{0x673bc077,0x2911355c,0x69cd009d,0x63ab8269}},	//   mfuj, faza_, _दीही, ingn,
   {{0x290c11f6,0x6d48f55d,0x69c7060f,0x27fa007a}},	//   úda_, ceda, glje, _ptpn_,
   {{0x66098d2d,0x2618108d,0x6e228062,0x98a788c7}},	//   _lwek, _भटकी_, zrob, denī_,
   {{0xe81d0021,0x33f18c2c,0xa3cb8027,0xfbcbc1f9}},	//   _फिरा_, _máx_, _रील_, ातिम,
   {{0x2903166c,0x764d755e,0x0d86478b,0x61fba6ff}},	// [3e60] bbja_, gway, план, _ntul,
   {{0x6b84420b,0x63ab807a,0xe617493d,0x6e364007}},	//   skig, engn, яду_, rtyb,
   {{0xc8c00028,0x0b4698d7,0x2a601498,0x80da002a}},	//   _एडिट, знен, _hrib_, _ব্র্,
   {{0x7d0140b4,0x98bec0b4,0x2fc68010,0x6609811c}},	//   _pârâ, letă_, ulog_, _bwek,
   {{0x4444104f,0xb6e385bf,0xad9b0070,0x6fc5e285}},	//   _hp_, нюшк, spúe, cóci,
   {{0x63ab8056,0x69c18033,0xdb0d410d,0x7dc6c086}},	//   angn, _ckle, llað, rðsk,
   {{0x290cb55f,0x61fb8f63,0x7f49c05c,0x04435200}},	//   _veda_, _etul, feeq, _перн,
   {{0x6d48e0c9,0x645b4036,0x69c70451,0x7d0e7560}},	//   weda, śció, zlje, _hebs,
   {{0xa5bb13af,0x63a0f561,0xb5fb4019,0xaa58c5ac}},	//   drón, rimn, _tráe, ципу_,
   {{0x3f868d04,0x41be4758,0x637cc03c,0x63a0e10f}},	//   lkou_, ्तिस, _péns, simn,
   {{0x6d4a8150,0xa3be4b26,0x6e244696,0x6ff3c0b4}},	//   mefa, ेता_, hrib, _păca,
   {{0x60c5004c,0x6e247562,0x61ed0033,0x7d0e4295}},	//   _ryhm, krib, _pual, _lebs,
   {{0x764d5dc4,0x29112791,0x6e244398,0xab27c93d}},	//   xway, taza_, jrib, _хоча_,
   {{0x27e6c05e,0x3f868089,0x44441f0b,0x9f44813b}},	//   _hion_, hkou_, _bp_, _bimë_,
   {{0xb5fb68b9,0x29033563,0x637f00fd,0xa5bb0018}},	//   _orác, rbja_, _bënt, brón,
   {{0x63a28150,0x29110502,0x61ed1754,0x83fc8011}},	//   jion, saza_, _tual, _grđe,
   {{0x6b8d3564,0x2bb18064,0xab5b003a,0x27e6c24f}},	// [3e70] _ilag, jąca_, hlük, _mion_,
   {{0x6fc5c036,0x60c50051,0x61efc018,0x645c0157}},	//   róci, _tyhm, ícli, bvri,
   {{0x6d557565,0x63a2b566,0x764d4faa,0x6d4a8b44}},	//   _vaza, fion, sway, defa,
   {{0x27e6c1a8,0x49050185,0x6445000b,0x3f86809c}},	//   _nion_, वरको_, _iphi, gkou_,
   {{0xdd95823d,0xa3c0c191,0x44440113,0xddeb471d}},	//   мады, ंकन_, _zp_, _درجه_,
   {{0x7bc2f567,0x6d4ab568,0xceb40052,0x1620017e}},	//   _akou, gefa, עיס_, _बिसर_,
   {{0xfd10879e,0x26c6cb0e,0x657ab569,0x27e6e798}},	//   اجه_, _ayoo_, _doth, _bion_,
   {{0x2d8c83a6,0x27fc4166,0x6d57356a,0x6568801c}},	//   _elde_, ívne_, _laxa, _endh,
   {{0x66098150,0x61fb8150,0xddc98119,0x7dd05478}},	//   _uwek, _utul, _greş, läsa,
   {{0xac85cd4c,0x3915816a,0x7bc2c0ce,0x8885c57e}},	//   дгол, _آواز, _ekou, длож,
   {{0x290ec3a6,0xa5bb356b,0x442a004d,0xa34a0477}},	//   _defa_, trón, xub_, озна_,
   {{0x6e29d9e4,0xa2d48045,0x63ad7343,0xb6a60176}},	//   pueb, बेक्, jnan, димл,
   {{0xa5bb1792,0x63ad5165,0x6445000b,0x290ef56c}},	//   rrón, dnan, _aphi, _fefa_,
   {{0x57b6408f,0x290ec10d,0x2d9e03bc,0x63ad59bf}},	//   ंव्ह, _gefa_, òte_, enan,
   {{0x04b50525,0x63ad410d,0x29134057,0x645c32c6}},	//   естя, fnan, daxa_, uvri,
   {{0x2fc94274,0x6f1d409c,0x7bdbc051,0x6e246ecb}},	//   glag_, _cdsc, nmuu, trib,
   {{0x61ef406f,0x3f86805b,0x645c111b,0x6d4a82fe}},	// [3e80] _cucl, vkou_, svri, yefa,
   {{0x63ad756d,0x7769850e,0x61ef4af1,0x290ec03c}},	//   anan, _anex, _ducl, _xefa_,
   {{0x6c4a50da,0x51f60973,0x926501aa,0x7bc9f56e}},	//   تلاف_, _عسکر, _قدیم, kleu,
   {{0xd83e404f,0x5aca801d,0x7e6949b8,0x42ca83fe}},	//   ščob_, олем_, _šepe, оген_,
   {{0x657ab56f,0x7bc9c1f4,0xeb9740b4,0x69c3c109}},	//   _poth, dleu, _ция_, _okne,
   {{0x98becf66,0x20184b0e,0xa69700c3,0xdce18017}},	//   letą_, _tvri_, וכנה_, _nolē,
   {{0x63a28064,0xa5bb0004,0x98a5c007,0xc7a689d3}},	//   pion, dról, delį_, _живк,
   {{0xb50a0c13,0x7c37006a,0x2905c070,0x61e740a8}},	//   वरुप_, _çarş, ebla_, _zijl,
   {{0x7c38815d,0xa5bb0107,0x9f480060,0x07a386b1}},	//   stvr, rtóz, _cuní_, _ратн,
   {{0x656881aa,0x26c6c2c0,0x6d41805e,0x98a5c026}},	//   _undh, _vyoo_, _gbla, gelį_,
   {{0x39587570,0x9f448694,0x69dad062,0x2018f571}},	//   _mars_, _aimé_, rmte, éri_,
   {{0x6e951a92,0x63a45d72,0x8354c01c,0x998dc011}},	//   еиму, jiin, _سپتا, rteš_,
   {{0x6d400068,0x2905f572,0xb50a0191,0x2918c1b4}},	//   đman, bbla_, वरूप_, óras_,
   {{0x63ad4036,0x5f01002a,0x6d570149,0x657c7573}},	//   wnan, ্লেখ_, _qaxa, _norh,
   {{0x04c90032,0xdb00c0b0,0xd37b40c1,0x61e740a8}},	//   سوري_, rnmæ, оча_, _rijl,
   {{0xb4af008f,0x9df94c86,0x6d5af574,0x394cc041}},	//   _कशी_, знат_, ldta, leds_,
   {{0x6f0f41bc,0x7aed3575,0x7bdd04c9,0xc2994099}},	// [3e90] _vecc, _igat, mmsu, чках_,
   {{0x64930039,0x660d3576,0x2246c07a,0x395840c3}},	//   ežiū, _iwak, _mpok_, _cars_,
   {{0x660d0303,0xc7b907ca,0x7d1515e7,0x6445000b}},	//   _hwak, suđu_, mazs, _uphi,
   {{0x6e2b8105,0x63a45409,0x7bc0f577,0x394cf578}},	//   tugb, ciin, jomu, heds_,
   {{0x7769800c,0xa9698244,0x39587579,0x7aed0498}},	//   _vnex, зила_, _fars_, _mgat,
   {{0x20558652,0xac1950f9,0x7f42c580,0x63a0817a}},	//   етир, _ногу_, _aboq, _emmn,
   {{0x7aed255a,0x1dbe4926,0x69c50303,0x29114545}},	//   _ogat, ्तरत, _mkhe, _ieza_,
   {{0x656ac061,0xd7f880d1,0x7bc0c0c2,0xf09240c3}},	//   _anfh, _trăn_, gomu, _ענן_,
   {{0x6fd607c9,0x7bdbea86,0x2911757a,0x2b59757b}},	//   náce, rmuu, _keza_, _masc_,
   {{0xb176c00c,0x2dd49d91,0x63a4722d,0x7c3af57c}},	//   _phượ, _ажур, ziin, fttr,
   {{0xf8b1c973,0x2246f57d,0x28a54045,0xa069f57e}},	//   دکش_, _epok_, _गेमि, чана_,
   {{0x660d2912,0x27e9073f,0x2918c086,0xb5fb0089}},	//   _bwak, _cian_, órar_, dváb,
   {{0x4425c0c4,0x7c3ac157,0x63a4757f,0xe617002b}},	//   srl_, attr, viin, ндя_,
   {{0xc6928087,0xb176c015,0x83fc8043,0x661b8e1d}},	//   ראך_, _thượ, _hrđa, _mvuk,
   {{0x63a47580,0xf3f18112,0x2b594016,0xe1ff4083}},	//   tiin, _jụ_, _basc_, _ató_,
   {{0x2b594016,0x6b89c51f,0xdb00f581,0x660d0053}},	//   _casc_, nkeg, timé, _fwak,
   {{0xd24f405f,0x7853803a,0x44278ef4,0x3ea0c086}},	// [3ea0] ینہ_, _dəvə, hrn_, _þitt_,
   {{0x6d58c3fd,0x71a35213,0xdb00c01e,0xed5740b4}},	//   _xava, гауз, rimé, ноу_,
   {{0x661bb582,0x29117583,0x660d015d,0x10a600d9}},	//   _avuk, _deza_, _zwak, _чинн,
   {{0x63a44149,0x395842b5,0x29074086,0x6e2d7584}},	//   qiin, _wars_, ðnar_, buab,
   {{0x64930039,0x3d05008f,0x442780fa,0x59b1c185}},	//   ržiū, वरचे_, ern_, ीकार,
   {{0x7e64c2bc,0x6f16406a,0x3f8ff585,0xdb1d0870}},	//   _šipo, layc, _algu_, rosé,
   {{0x6d5c3586,0x83fc841b,0x3cf0809d,0x97438077}},	//   idra, _brđa, _चलीं_, šćar,
   {{0x442cc98f,0x63a080f8,0xa3d04444,0x657e00c7}},	//   vud_, _ummn, षति_, _loph,
   {{0x25a5f587,0x63a60056,0x442cc7a8,0x27e9115a}},	//   fill_, dikn, wud_, _rian_,
   {{0x25f40028,0x38c884e8,0x1621c028,0x660d01c6}},	//   ंदनी_, _قاضی_, _मिरर_, _rwak,
   {{0x661b81b8,0x27e91738,0x660d02a4,0x6d5c04aa}},	//   _zvuk, _pian_, _swak, ddra,
   {{0x27e93588,0x9f9740fd,0x671081f9,0x6d58cfee}},	//   _qian_, rçë_, ारिक_, _wava,
   {{0x2fc6c498,0xb5fd8011,0xb5fb49ac,0x443cb589}},	//   _ikog_, _krša, _arán, ltv_,
   {{0xb5fb4194,0xca57c087,0x26c90150,0xdcf8d0b4}},	//   _brán, _ניוז_, _vyao_, _kovč,
   {{0xf3674640,0x6fc5c2b0,0xb5fb4996,0x80a0408f}},	//   нтан, mócr, _crán, _गेले,
   {{0x660d018b,0x7e64358a,0xf215c3fc,0x6fd60004}},	//   _twak, _frip, _दौड़_, táce,
   {{0xb1840089,0x3f894026,0x776d0545,0x2b594104}},	// [3eb0] šťav, rkau_, _inax, _vasc_,
   {{0xdd0400b4,0x6fd60047,0x7c2e06f0,0x6e2d41a8}},	//   ărăr, ráce, bubr, ruab,
   {{0x6d450339,0xa3c0c1f9,0xb5fb654e,0x6375c018}},	//   _ibha, ंका_, _grán, _tánx,
   {{0x441a021d,0xf3f18112,0x291160b4,0x27fc402d}},	//   _קורס, _rụ_, _weza_, ívna_,
   {{0xb5fd8011,0x2bb60017,0x6e3d0df2,0x59d0c0aa}},	//   _brša, nāca_, ntsb, हतार,
   {{0x63a2e467,0x201cc0c4,0x6e3d00cb,0xf2d40052}},	//   _amon, _ovvi_, itsb, נעס_,
   {{0x94d452bf,0x1fb5c2db,0xf4ffc031,0x2164758b}},	//   _борц, ксир, _dẹlé_, _стяг,
   {{0x2249056e,0x6d5a86d3,0x883c00c3,0xf3f180d1}},	//   _opak_, _eata, פתחו, _vụ_,
   {{0x6d5a8517,0x2489803f,0x6d4e34d0,0x6b89c240}},	//   _fata, ņam_, yeba, rkeg,
   {{0x7bcd6026,0x98bec036,0x261b0027,0x6d4e01a8}},	//   hlau, letę_, _बिजी_, xeba,
   {{0x61eaccbf,0x6d5c358c,0x4735c375,0x7afd758d}},	//   _difl, vdra, _анес, _ofst,
   {{0x8fa60525,0x7dcd8166,0x6e3d1870,0x7bcd423b}},	//   таме, kúsk, ftsb, jlau,
   {{0x27768009,0x6d450303,0x2d99c01e,0x6f09c230}},	//   דערש_, _bbha, èses_, mbec,
   {{0x63a2f58e,0x6d5a81c8,0x61eac50c,0x6286358f}},	//   _zmon, _xata, _gifl, ryko,
   {{0x711ac2a6,0x9f4a834d,0xf992c0c3,0x6286064b}},	//   _חוצפ, _subí_, _דרג_, syko,
   {{0x69d8c0fd,0x7e640c54,0x6d4500f7,0xeafa0de9}},	//   _zhve, _trip, _ebha, _غربت_,
   {{0x6d5c3590,0x661bc339,0xb5fb0066,0x3a2948ae}},	// [3ec0] pdra, nsuk, rvác, grap_,
   {{0xdb008669,0x80a2854a,0x6e224077,0x62998036}},	//   _immé, _कइले, šobo, dzwo,
   {{0x7dd044c9,0xa7fc891a,0x6e29f591,0xb5fb4443}},	//   säso, _arın, hreb, _hrál,
   {{0xa3d206d6,0xdcf8c570,0xf1bf0047,0x66044025}},	//   वति_, _rovč, hrál_, ppik,
   {{0xbad5459d,0x63a2c085,0x63a43592,0x29183593}},	//   _біры, _rmon, _mmin, oara_,
   {{0x4a9b0052,0x64488011,0x442e81c8,0x661bf594}},	//   וינג, _ppdi, tuf_, dsuk,
   {{0xe5a35213,0x63a43595,0xd7f88015,0xa2ce8a3c}},	//   _тири, _omin, _trăm_, _तरक्,
   {{0x3d0a408f,0x2fcdc4f5,0x63a400f8,0x7c3e40cb}},	//   िरके_, gleg_, _nmin, mtpr,
   {{0x6d41f596,0x661bc29e,0x201e011f,0xd251c05f}},	//   ffla, gsuk, štih_, منٹ_,
   {{0xceb4003a,0xb5fd8011,0x27e07597,0x7afbccc6}},	//   _edək_, _kršn, hmin_, acut,
   {{0x63a4005c,0x29130018,0x6f09f598,0x19b98051}},	//   _bmin, _rexa_, bbec, _чуть_,
   {{0x69d446ff,0x63a2c00b,0x69dd8157,0x27e07599}},	//   _बीसी, _umon, _èser, jmin_,
   {{0x2bb38374,0x6e29c004,0x6aa20077,0xbf0ec045}},	//   ंचता, creb, _žofr, सरीन_,
   {{0x7c3e6911,0x6ff188c7,0xf484cde9,0x7dcb4314}},	//   ktpr, _sāci, _مابی, püsi,
   {{0xdb1d04f2,0xc313802a,0xb6024089,0xa5bdc026}},	//   losí, _হাসি_, šáln, krųj,
   {{0x7d1896a9,0x33f88070,0x395ed7fc,0x7e664303}},	//   havs, _méx_, ldts_, _brkp,
   {{0xdb1d1b72,0x95d9447f,0xdb0600fd,0x93b800c3}},	// [3ed0] nosí, едат_, zikë, _שלחו_,
   {{0xad9b41c0,0x6d4507ac,0xe4a71c27,0x27e0759a}},	//   _awúr, _ubha, _армо, amin_,
   {{0x2619c50b,0x3cde449d,0x7d1741c8,0x95c85720}},	//   _मौनी_, केले_, raxs, тута_,
   {{0x9f81c10d,0xb8eb4027,0x443ecae6,0x7dcd99a9}},	//   jóð_, _लड_, itt_, músi,
   {{0x6d41c15a,0x637840d2,0x6602c9f4,0x201e80e5}},	//   yfla, _rínx, _ntok, _avti_,
   {{0x237f83bc,0x6458f59b,0x644ac0b0,0x32b88032}},	//   _wouj_, _osvi, _opfi, خدمة_,
   {{0x3206802f,0xe5fcc112,0x6ce440d9,0x69c5413b}},	//   apoy_, _rịịs, _віте, mohe,
   {{0x236d8033,0x69da809d,0x69c3b59c,0x661d291d}},	//   _unej_, _ehte, sone, kssk,
   {{0xab5b00fa,0x6fd60070,0x7d188013,0x61fb0018}},	//   hlüs, jáca, bavs, íull,
   {{0x2fcdf59d,0x6009c04c,0xdb0d0086,0x4431359e}},	//   sleg_, нном_, _skað, kuz_,
   {{0x26cd8033,0x4431359f,0xc984806f,0x5b25c1b4}},	//   _hyeo_, juz_, _тути, _مفضل,
   {{0x6f198036,0x7981b5a0,0x69c575a1,0x6e29f5a2}},	//   nawc, _holw, hohe, preb,
   {{0x661d1ef0,0xd945c495,0x27edb5a3,0x1545c5d7}},	//   gssk, _бели, _mien_, _белм,
   {{0x2005c085,0x442a041b,0x44311231,0x64a6059d}},	//   ppli_, trb_, fuz_, гага,
   {{0xb1840047,0xa066c0c5,0x69c5413b,0xe61f401f}},	//   šťov, _баща_, dohe, _avô_,
   {{0x7f5d4669,0x7c3cc6ed,0x3f8dc07a,0xf3e650e7}},	//   _casq, àrre, nkeu_, ужбо,
   {{0xb5fb005f,0x629bcceb,0x7db6061e,0x3a3fcead}},	// [3ee0] lván, nzuo, _مصدا, ntup_,
   {{0x69c540fd,0xdcfa811f,0x29180405,0xc88500b5}},	//   gohe, _potč, qara_, _başı_,
   {{0x6289c07a,0x0c2653c7,0x03a6434a,0x07a65c2e}},	//   hyeo, умен, _бино, _банн,
   {{0xeb97881e,0x66040056,0x27edb5a4,0x2f56411b}},	//   лих_, _ktik, _cien_, _стос,
   {{0x69c54426,0x6f160033,0x6d43821b,0x80caca30}},	//   bohe, _meyc, ffna, _सुने,
   {{0xdcfc71fa,0x25a58070,0x6604012c,0xbd024089}},	//   _korč, _cmll_, _mtik, _šéfk,
   {{0x4c948a74,0xdd41c40d,0xdcf8c017,0x853b40c3}},	//   рийс, _eŋŋi, _novā, _רגלי,
   {{0x2240633a,0x672406dd,0x61ee4274,0x2360404f}},	//   otik_, _ndij, _hibl, ndij_,
   {{0x35d94027,0x853cc007,0x6604018b,0xeb97827f}},	//   _बीड़, siėm, _ntik, _сит_,
   {{0x2fc6832e,0x7e6dca93,0xaa9381b4,0x63a9d973}},	//   loog_, _šapc, _الكث, aien,
   {{0x58d4c9bd,0x6d4881c0,0xdcfc40e5,0x224040b9}},	//   ронт, _ibda, _norč, htik_,
   {{0x6d5e338a,0x16200027,0x443100b5,0xe3c9c018}},	//   _aapa, _बिखर_, vuz_, riñá_,
   {{0x69dc75a5,0x291a75a6,0x61ee4359,0xc6a70ace}},	//   _ohre, kapa_, _oibl, урни,
   {{0xf99f4565,0xf237c3bd,0x61ee4018,0x1a9bc009}},	//   _jwèt_, _ערוץ_, _nibl, _אידע,
   {{0xfbd3471d,0xee3f0347,0x26148048,0x4c9428ab}},	//   متر_, stý_, नीती_, бирс,
   {{0x67240043,0x6d610077,0x69d8f5a7,0x533440b4}},	//   _gdij, _žvać, _नीती, йест,
   {{0x248d003f,0x6b82c149,0x6b8d6a1f,0x201ef5a8}},	// [3ef0] ņem_, _moog, rkag, lsti_,
   {{0x69dc75a9,0x63a9f5aa,0x6d5e246c,0x61ee5d05}},	//   _chre, zien, _gapa, _cibl,
   {{0x224075ab,0x201ef5ac,0x69c735ad,0x54555a2b}},	//   atik_, nsti_, moje, рвет,
   {{0x7a47403f,0x201ecb68,0x2eb0854a,0x2837c009}},	//   tītā, isti_, जपूत, רנאך_,
   {{0xe6d30028,0x69dc44f8,0xb5fb005b,0xfe354009}},	//   _सरोज, _fhre, zván, _דאָך_,
   {{0x69dc424f,0x27edb5ae,0x443e800c,0x361a805f}},	//   _ghre, _wien_, _bqt_, ئرنگ_,
   {{0x32094e37,0xf53802a6,0xfaf1c1b4,0x7bdb8033}},	//   lpay_, אטור_, يثة_, _thuu,
   {{0x637cc05f,0xf625c4b6,0xd34681aa,0xba25e5d7}},	//   _kény, адио, _نیمه_, адик,
   {{0x69c735af,0xbb8481b4,0x7f8481b4,0x2a69004d}},	//   koje, _القي, _القن, _nrab_,
   {{0x2007810d,0xd49b81bd,0x7bc61030,0x395e8016}},	//   ppni_, _пре_, woku, _gats_,
   {{0x7bc61595,0xa3c30b64,0x7dcb40fa,0x645ec6b7}},	//   toku, ्तं_, lüss, _špir,
   {{0x6b82cc18,0xfc3090da,0x800ac05f,0xe47a8052}},	//   _goog, _رحم_, کریہ_, _ברעכ,
   {{0x6f0905b1,0x201ec04c,0x6d5e23e2,0x69da846d}},	//   ñeca, asti_, _papa, _पीडी,
   {{0x6e2d4b68,0xdcfc40b3,0x3a200056,0xf1b9c0ab}},	//   drab, _porč, _vvip_, gršt_,
   {{0xa3d58e31,0x443e0669,0xc0e60587,0x6b82c07a}},	//   हता_, ît_, ровк, _yoog,
   {{0x25aa01f4,0x7e6440b3,0x25a7c011,0x2fc68046}},	//   sibl_, tvip, _hmnl_, xoog_,
   {{0x637cc0fb,0x61ee4565,0x236075b0,0x290740b5}},	// [3f00] _pénz, _pibl, rdij_, ınan_,
   {{0x645a0086,0xdb09c0a8,0x186a6282,0x27eff5b1}},	//   ætis, fieë, кази_, _lign_,
   {{0xed574b0f,0xa3bd0275,0xdb09c0a8,0xc2e7402a}},	//   рох_, _आदम_, gieë, গুলি_,
   {{0xf74689b0,0x6441c106,0x6d414041,0xab2a8911}},	//   редо, itli, _ölan, тода_,
   {{0x06e44079,0x7d1af5b2,0xee3784b6,0x2fc688f9}},	//   _ফ্রি, yats, инц_, roog_,
   {{0x6b9601f4,0x201ef5b3,0x69dc48f0,0x2fc6b5b4}},	//   _llyg, ysti_, _uhre, soog_,
   {{0x6609f2d7,0x6b96002c,0x2eaedc08,0xd017909b}},	//   epek, _olyg, ञप्त, афы_,
   {{0x9f45c018,0x63ab80c4,0x628b81f4,0x9faec047}},	//   _zulú_, cign, bygo, _tří_,
   {{0xcb67c4ee,0x179b8087,0xb5fb0107,0x3a2dc0d9}},	//   рање_, _סימב, gvál, grep_,
   {{0x3a204871,0x80f50b26,0x2918466b,0xb5fb4574}},	//   isip_, _आलेख_, _jera_, _dráh,
   {{0x6f0d7294,0x201ef5b5,0x6f1bf5b6,0x6b82c1c8}},	//   ybac, usti_, bauc, _toog,
   {{0x80bf96c0,0x6b840510,0x0ba700d9,0x2a690b94}},	//   _लुटे, _coig, ршом, _prab_,
   {{0xda198064,0x37cc4079,0xfaff00fd,0xf1bf0107}},	//   नीपत_, লগার, rcë_, nság_,
   {{0x3206c29e,0x44d580d1,0xdb0d75b7,0x3f84b5b8}},	//   _itoy_, _ý_, rnaí, _lomu_,
   {{0x6441c127,0x1fa74f37,0xf773400f,0x7f5f11ab}},	//   ctli, араг, يار_, _taqq,
   {{0x2a6901d6,0x8aa70e90,0x6eddc314,0x27ef4086}},	//   _trab_, _врод, _परमु, ögn_,
   {{0x2d8340e5,0x6801c017,0x2b8e40a0,0x3eaf04c9}},	// [3f10] _poje_, _vēde, _mých_, _ägt_,
   {{0x7e698fc0,0xf6500fdd,0xfaff413b,0x2b5f8017}},	//   _rrep, _آئي_, _anët_, _sauc_,
   {{0x3f84812c,0xfbd0405f,0x7d18c06a,0x6f1bc09c}},	//   _bomu_, ستہ_, _mevs, yauc,
   {{0xdb09c1d4,0xe4560052,0x3a758b6f,0xf568805f}},	//   rieë, _פירט_, йлер, یمنٹ_,
   {{0x645a01b7,0x69c8f055,0x291875b9,0x6f1d00b4}},	//   ħtie, kode, _fera_, iasc,
   {{0xdb09c0bf,0x69c8c070,0xfd4780d7,0x0effc045}},	//   pieë, jode, рэдн, ईड्स_,
   {{0x7dcda2be,0xe8df4082,0x69c8e3ef,0xe0e54079}},	//   dúst, _trực_, dode, _প্রভ,
   {{0xa3d7532e,0x6f1d35ba,0xdb00ca6e,0x23bac03f}},	//   िति_, jasc, timá, tīja_,
   {{0x69c8e7eb,0x7e698140,0x7dddc7b0,0x2901529a}},	//   fode, _urep, hèse, ocha_,
   {{0x7d1c1169,0x69c8f5bb,0x6b8435bc,0x63bb806f}},	//   xars, gode, _soig, _hjun,
   {{0x6ca78773,0x442175bd,0x61e546d3,0x74cac0e6}},	//   _траж, nsh_, imhl, _सुदृ,
   {{0x23600046,0x63a98047,0x6e20c05c,0xad9b410d}},	//   _qaij_, _jmen, bsmb, _stúl,
   {{0xe8d9c015,0x65618047,0x69c10066,0x61fbce05}},	//   _đổ_, _kalh, člen, qqul,
   {{0xdcfe0054,0x7dcd8019,0x237fc04f,0x910300c5}},	//   _topč, cúst, ljuj_, зпре,
   {{0x6561b5be,0xe0d1cc59,0xdcfa8119,0x6f1d0bf5}},	//   _malh, _عزت_, _hotă, basc,
   {{0xa3c9d946,0x96960363,0x2d858031,0xfbdf400c}},	//   ोति_, _грош, _lole_, _chê_,
   {{0xb5fd813f,0x6443804f,0x67c1c017,0x67d80031}},	// [3f20] _dršk, htni, mējd, _e̟jó,
   {{0x6fdd0ad6,0x2d858654,0x3a204b0e,0x8af0403a}},	//   réce, _nole_, rsip_, ddət,
   {{0x442e13ab,0x0fda401c,0x291a2cab,0x3897c080}},	//   _íf_, _مبحث_, _iepa_, fərə_,
   {{0xbddb35bf,0xfbdf400c,0xb5fd804f,0x3a204c47}},	//   ntèn, _ghê_, _gršk, psip_,
   {{0x29184591,0x63a980f6,0x7e6dc011,0xd138c007}},	//   _tera_, _dmen, _šapn, ygą_,
   {{0x27f84093,0x2360af8b,0xf5964032,0x76429e1d}},	//   _turn_, žij_, _السج, rtoy,
   {{0x64438065,0x3206c070,0x645c4011,0xef1980f6}},	//   gtni, _stoy_, _usri, _feż_,
   {{0xb5fb41b4,0x77645a46,0xf76fc5a7,0x4343b019}},	//   _srái, ndix, فاً_, _несв,
   {{0xd6d0c1b4,0x7d18c0e5,0x6f19c02c,0xb5fb4359}},	//   بقة_, _pevs, _dewc, _prái,
   {{0x2d85b5c0,0x6443806c,0xdd9280a3,0x6561801f}},	//   _gole_, btni, _عوض_, _galh,
   {{0x26c00033,0x6f0903e9,0x6fd88f51,0x6f1d0bbf}},	//   _axio_, ñeco, níco, tasc,
   {{0x4871801c,0x7e64d1c4,0x8af04080,0xb4d8c1f9}},	//   _آگوس, _šipu, ndəs, _ारी_,
   {{0x6e22a538,0x3206c02f,0x2bc988c4,0x27f20398}},	//   nsob, _utoy_, िकता, _diyn_,
   {{0xd010d438,0xf99f596a,0x3897c080,0x27e0002e}},	//   _قلت_, _atèn_, zərə_, _ehin_,
   {{0x6f02b5c1,0x7afdc066,0x6f1d0db3,0xbc67c01c}},	//   kcoc, žste, pasc, _همون_,
   {{0x291a0031,0x6d48e881,0x061544df,0x27e00755}},	//   _eepa_, lfda, ждаю, _ghin_,
   {{0xdb00c051,0x8af04080,0x764475c2,0x63a9817b}},	// [3f30] mimä, ddəs, gtiy, _rmen,
   {{0x63bb84d3,0x628f0396,0x753ac619,0x44234033}},	//   _sjun, myco, ngtz, _pvj_,
   {{0x1bf2417e,0x2d85b5c3,0xfbdf40d1,0x92d9402a}},	//   _आंचल_, _role_, _thê_, াশে_,
   {{0x398b8586,0x69d500cb,0x5555005f,0xdb00c134}},	//   _løst_, llze, _اپگر, nimä,
   {{0x6561810b,0xb5fd8618,0xeb3a4009,0x2d85abd2}},	//   _palh, _krši, _דערש, _pole_,
   {{0x24098c93,0xbddb40d2,0x291a01ff,0x2169b5c4}},	//   анки_, _epèr, _xepa_, рики_,
   {{0xeae5c079,0xb5fd8f26,0xcfe981b4,0x44230125}},	//   _নভেম, _mrši, _نفسه_, nsj_,
   {{0x91f90028,0x64455ae2,0xd5b8c017,0x7762c303}},	//   ंदाज_, mthi, enā_, _caox,
   {{0x6561b5c5,0x6b9bf5c6,0x27e01d05,0x69ca801f}},	//   _talh, rhug, _rhin_, bofe,
   {{0x7d1ab5c7,0x6f1b9ad1,0x6d8b003a,0x7db787c3}},	//   _gets, _heuc, _müas, _اصرا,
   {{0xb5fb410b,0x7dd06a9c,0xe3b900b5,0x06ad402a}},	//   _gráv, mäst, rsın_, _কুমি,
   {{0xa2aac08f,0x660d75c8,0x6d5741c8,0x98b34007}},	//   _जेव्, kpak, hexa, ždės_,
   {{0xa2d0c045,0x6f1b82eb,0x444475c9,0x76444561}},	//   _डुप्, _meuc, zt_, xtiy,
   {{0x6f02b5ca,0xa069c01b,0xac0a185b,0x2901c09d}},	//   zcoc, _вака_, инга_, _üha_,
   {{0x2b4d8531,0xbc19c4f5,0xea00800c,0x6feac036}},	//   _obec_, _тілі_, _đậm_, _ręcz,
   {{0x6f02b0fc,0x6f1ba2dd,0x69cab4d0,0x6443c085}},	//   xcoc, _neuc, zofe, _iqni,
   {{0x2d87f5cb,0x6563c498,0x05aa55ea,0x3f9940f8}},	// [3f40] _kone_, _kanh, авай_, _dlsu_,
   {{0x5bd28bfa,0x2242809d,0x3ea040fd,0x2d87f5cc}},	//   तत्व, _äkki_, rzit_, _jone_,
   {{0x7bcbb405,0x6609ab02,0x776400fc,0x7d1e75cd}},	//   fogu, _atek, _kaix, raps,
   {{0x6563d994,0x6f1b8060,0x7644725b,0x61fbb5ce}},	//   _lanh, _ceuc, ptiy, _buul,
   {{0xb51e0a3c,0x6f1b85ef,0x672980f6,0x16a782d2}},	//   _बजाय_, _deuc, _ddej, овци_,
   {{0x64a64026,0xf806b5cf,0x291ab5d0,0x61fb8057}},	//   _дага, очин, úpa_, _duul,
   {{0x660988bd,0x395832af,0x7f49ce05,0xe9df030d}},	//   _etek, iers_, ffeq, ntúa_,
   {{0x776406ed,0x207b4052,0x050a802a,0x9b6ac01b}},	//   _naix, _דאלא, রণের_, ршка_,
   {{0xef1f09d7,0x395827a5,0xe2978f19,0x6609406a}},	//   kkür_, kers_, _дат_, _çekt,
   {{0x7dd06a9c,0x6563f5d1,0x67298109,0x2b91eb35}},	//   mäss, _canh, _zdej, _lách_,
   {{0x7dd075d2,0x2246aa8b,0xe4fb4009,0xa3ab4a30}},	//   läss, ltok_, יפיש, कोड_,
   {{0x6b828ca0,0xf1bf0185,0x9f5203bc,0x37ab042e}},	//   njog, hrát_, _jiyè_, ртон_,
   {{0x7c388aa2,0x80cac945,0x39581e1f,0x290c00b5}},	//   luvr, _सुरे, fers_, ıdan_,
   {{0x291ef5d3,0x645c01f4,0xc87e803a,0x64454be5}},	//   qata_, fwri, şğul_, ythi,
   {{0x2b91c00c,0x5f950051,0x769101c0,0x291cd0a4}},	//   _bách_, _никт, _bóyú, _ieva_,
   {{0x77640232,0x6d588f4c,0x7dcfc240,0x25db0036}},	//   _gaix, heva, søst, _खीरी_,
   {{0x6d5775d4,0x518735d5,0xd50b464c,0x2b91c00c}},	// [3f50] texa, _дуна, لغان_, _dách_,
   {{0x2246a78c,0x7dcd8066,0x2b5935d6,0x69da8036}},	//   dtok_, júsp, lesc_, _पीली,
   {{0xdb062a2b,0xc8d235d7,0x7dd0404c,0xe9df030d}},	//   liká, _दुपट, väst, ctúa_,
   {{0x6f04423f,0x6d4e431c,0x660d7042,0x6fd60066}},	//   ccic, _ebba, ppak, váck,
   {{0xea008015,0xdb0635d8,0x2246885d,0xee388187}},	//   _đảm_, niká, gtok_, жні_,
   {{0x4e164093,0x6b9d00fd,0x291cf5d9,0xb5fb75da}},	//   _מחשב_, ërgj, _neva_, _drát,
   {{0x2d9ef5db,0xdb0d401f,0x7bcbb5dc,0x319c00c3}},	//   dhte_, gnaç, pogu, שבונ,
   {{0x6563c5bb,0xe619c764,0x7d1c40fa,0x63ad002f}},	//   _sanh, бди_, _zers, _nman,
   {{0x6f1d502f,0x3964804c,0x39580093,0x2b590379}},	//   _mesc, össä_, yers_, desc_,
   {{0xdb060a6e,0xdb16405f,0x10a5c8e5,0xdbd70c99}},	//   diká, rnyé, зион, hääl,
   {{0x395815b7,0x5fbd5087,0x2ef5daec,0x291ccb42}},	//   vers_, ्काल, _езер, _deva_,
   {{0x9f58b05d,0x6ee10044,0x8c494165,0x739a0143}},	//   _puré_, _ịban, maşı, стос_,
   {{0x63ad35dd,0x8c49438a,0x644b89b7,0x6f0442a3}},	//   _dman, laşı, žnič, vcic,
   {{0xdca5d23a,0xaca3c094,0x395835de,0x645c35df}},	//   _нали, _ahụi, uers_, twri,
   {{0x251ac3bd,0x6b9b9ab1,0x76460efb,0xa3d7407a}},	//   _הוצא, _olug, stky, ितं_,
   {{0x63ad35e0,0x3a26009f,0x2a60024c,0x9f4682a4}},	//   _gman, _емиг, _tsib_, rmoë_,
   {{0x88d18079,0x395806ba,0xa3c1858e,0x2b91c0d1}},	// [3f60] াধিক, pers_, ुवन_, _vách_,
   {{0x7521c511,0x444435e1,0x7dd04051,0x6fd60166}},	//   nalz, _tq_, väss, dáci,
   {{0x27e942cd,0x6f0440b3,0x2b91c00c,0x61f575e2}},	//   bman_, pcic, _tách_, _dizl,
   {{0x69ce253c,0x7d1e03a6,0xe73a932d,0x20074f9c}},	//   lobe, _heps, сед_, ínia_,
   {{0x63bbdd77,0x65650b0e,0x2907f5e3,0xb5fd8011}},	//   dnun, _yahh, _ofna_, _oršu,
   {{0x7dd20065,0x51554409,0x2246b1f2,0x6da39d10}},	//   mæss, _отсу, rtok_, нича,
   {{0xb5fb5d9d,0x6d4ab5e4,0x6e398010,0x22468fe6}},	//   _frás, rffa, auwb, stok_,
   {{0x7d1e35e5,0xa91c8166,0xb886c018,0x9f5843e9}},	//   _leps, _koľk, _laíñ, mpró_,
   {{0x98b1803f,0x4427f5e6,0xdcfc003f,0x6fd6010b}},	//   ībām_, _avn_, nkrē, cáci,
   {{0x4c94cb57,0x6447014b,0x2d8a400b,0x5a638026}},	//   диос, ytji, _jobe_, _якуб,
   {{0xdb0f0018,0x6720c0fd,0x6619c031,0x443a75e7}},	//   licé, pamj, _ewwk, nup_,
   {{0xdb06279f,0x27e9589d,0x6b84409c,0x57fb80c3}},	//   tiká, xman_, jjig, _הלאו,
   {{0x4427f5e8,0xdfa5c20c,0x6f1d4277,0xdbd70025}},	//   _evn_, _تحلي, _resc, vääl,
   {{0x69ce031c,0x7521c119,0xa3dd0a3c,0xdb00810d}},	//   gobe, calz, _तीर_, _ummæ,
   {{0xfce3c6b1,0xa3dc848b,0x2b5900cc,0x6447014b}},	//   _пољо, डता_, pesc_, utji,
   {{0xf1bf253f,0x1cbbc093,0xb5fd891c,0xddc400e0}},	//   trás_, _למוע, _kršt, _vriš,
   {{0xb5fb41c0,0x7d0575e9,0xddc2c047,0xddd04047}},	// [3f70] _arár, tchs, _spoř, _řeši,
   {{0xe7e1063c,0x213ec093,0xfd56c1c0,0xf1bf1a6d}},	//   _गीता_, ngth_, _angẹ, rrás_,
   {{0x6f1d75ea,0x2d8a75eb,0x660d0150,0x99894077}},	//   _tesc, _dobe_, _htak, graš_,
   {{0x291e80f8,0x6d41b361,0x69d883b3,0x27e4805e}},	//   _aeta_, _scla, elve, _chmn_,
   {{0x6b8981d4,0x957cc007,0x6b9b87f5,0xb5fb48e2}},	//   _voeg, rmąj, _vlug, _vrás,
   {{0x6448f5ec,0xb90b0031,0x2d8ac969,0x4425c047}},	//   ktdi, _adiẹ_, öbel_, ysl_,
   {{0x246cc047,0x7e62c083,0x9d184823,0xa3e9e328}},	//   _něm_, _asop, _хост_, одка_,
   {{0x8c4942d6,0x672d3204,0xa3a98027,0x2d8a75ed}},	//   raşı, _ndaj, गोश_, _zobe_,
   {{0xb5fd860f,0x69ce060d,0x3165801f,0x7afbb5ee}},	//   _pršu, yobe, _talz_, _igut,
   {{0x6d5ad2c5,0xbebb414b,0x35b48119,0x59bf4047}},	//   geta, _geëe, _збур, ्विर,
   {{0x2369404f,0x06ab002a,0x6aa44157,0xdce18147}},	//   kdaj_, _গুলি, zzif, _kalč,
   {{0x2905e310,0xb605d0b4,0x23694022,0x7bcf0018}},	//   scla_, _pešč, jdaj_, gocu,
   {{0xe9cecb3d,0x69c35684,0xa3cad1f1,0xdce19188}},	//   _ак_, čnej, लकर_, _malč,
   {{0x6b8bf5ef,0x291e35f0,0x22495cf4,0x656747a7}},	//   _hogg, úta_, dtak_, _najh,
   {{0x6448c17a,0x65a04107,0x6e3bec33,0x7afb81ae}},	//   ctdi, _jöhe, luub, _ogut,
   {{0xd8d6c009,0x660d00f1,0x09c675f1,0x3f8b5ba2}},	//   _קוקט_, _ftak, वव्य, _cocu_,
   {{0x6fd88c81,0xdcf8c0a0,0x200c0411,0x558a75f2}},	// [3f80] síck, _nově, ūdi_, обам_,
   {{0x75239e02,0x60c48165,0x7afb924b,0x8e370052}},	//   janz, şimi, _agut, _קניא_,
   {{0x395a522b,0x1d1940d9,0x67c1c017,0x7f4d413b}},	//   reps_, яють_, zēja, bfaq,
   {{0x69c18077,0x3f8b4570,0xf1bf35f3,0xa91c802d}},	//   _ajle, _gocu_, nsán_, _toľk,
   {{0x925a883b,0x7769c057,0x6fd8b5f4,0x6da68d9a}},	//   تشار_, ddex, níci, мида,
   {{0x2d980107,0x6b8bc17b,0xdce3c085,0x67c1c017}},	//   nkre_, _aogg, _canċ, vēja,
   {{0xeb9ab5f5,0x443a40fd,0x61ea9b0c,0xfc034244}},	//   _див_, qup_, rmfl, _апсо,
   {{0x6f1641f4,0x88bc80a0,0x7afb80bb,0xfce35065}},	//   nbyc, _oděv, _ggut, _росо,
   {{0xfd6500d1,0x6b8bd4d9,0xf1bf417c,0x6aadc147}},	//   _chuồ, _dogg, _ovál_, _žafr,
   {{0xb33b43a6,0x6fd88166,0x67244206,0xaad20036}},	//   _ilçe, díci, haij, _सड़क,
   {{0x80d6c079,0x6b8bea0b,0x657a800b,0x013740c3}},	//   ডেন্, _fogg, _inth, ורית_,
   {{0x6600932b,0x6e364036,0xb5fb0089,0x660d0062}},	//   _kumk, kryb, kvát, _ptak,
   {{0x16dc8be9,0x02e2c1f9,0x67208056,0x66008077}},	//   _बरोब, _परिभ, _memj, _jumk,
   {{0xa5bb010d,0xe8dfc00c,0x2d8cb5f6,0x7019c05f}},	//   msók, _giỏi_, _jode_, _کروڑ_,
   {{0x4bdb0032,0x0463c23d,0xbddb0004,0x94d40442}},	//   _وبعد_, _атым, ntèi, ворц,
   {{0x6568823c,0x660d011c,0x2d8ca71b,0x7e6d43ad}},	//   _ladh, _ttak, _lode_, tvap,
   {{0xdb02c10b,0x443c8046,0x752389dc,0x7c28f5f7}},	// [3f90] _emoç, huv_, yanz, lsdr,
   {{0x6568b5f8,0x7f5d0781,0x7c3c0232,0xdce180b3}},	//   _nadh, lesq, burr, _salč,
   {{0x47359edf,0x6e3d35f9,0xdce1811a,0xc178c007}},	//   енес, lusb, _palč, lmės_,
   {{0x442780b3,0x61f8f4ad,0xdb06006a,0x657ab5fa}},	//   vsn_, _livl, rikç, _anth,
   {{0x6e3d35fb,0xa509846c,0xdce192cc,0x3cfcc17b}},	//   nusb, пела_, _valč, _ogvv_,
   {{0x3edf0044,0xa3ab4e64,0xfce58798,0x6fd6030d}},	//   _arịọ_, कोर_, ноло, láct,
   {{0x37d60079,0xa5c581c0,0x65688396,0x2d8c83b3}},	//   _সংঘর, _akóì, _dadh, _dode_,
   {{0x6568824f,0x36d5811b,0x200111f4,0xc178c007}},	//   _eadh, _зобр, _muhi_, kmės_,
   {{0x2d8c810b,0x7bc2f5fc,0x7f5d00d2,0x23b0c09d}},	//   _fode_, _djou, desq, _जगरद,
   {{0x7649f5fd,0x332000d2,0x6b7e80cc,0x3f82c086}},	//   rtey, _seix_, _tăgâ, ökur_,
   {{0x917bc00c,0x672f4043,0x7649f5fe,0xf54ec0d1}},	//   _về_, _odcj, stey, _tụng_,
   {{0x69daf5ff,0x34948125,0x4c82c0d9,0x65688303}},	//   alte, _шахр, улюв, _zadh,
   {{0xbb3a8052,0xd7ccc048,0x45e3402e,0xdb1d04c9}},	//   הערי, ावरच, _díẹ̀_, ylsö,
   {{0xd945c547,0x656881c8,0x7afd7560,0x6d5c0414}},	//   _чеки, _xadh, _agst, uera,
   {{0x8d74c16a,0x64a600d7,0x6e29dcef,0x16dcb600}},	//   _جانا, хава, lseb, _बर्ब,
   {{0x69d540fa,0x6fd63601,0x7c3c0360,0x6d41cb61}},	//   _akze, tácu, rurr, lgla,
   {{0x97c3409b,0xb906002a,0x7bdbc051,0x7e641549}},	// [3fa0] уйте, _ফল_, iluu, _usip,
   {{0x65a0403a,0x7ae40339,0x64a67602,0xb5fb0cec}},	//   _söhb, _izit, наза, rvát,
   {{0x644ab5e9,0x98a6c654,0x27edf603,0x77698127}},	//   xtfi, ćiće_, kmen_, _baex,
   {{0x656883a9,0x6db28064,0xd7078a0b,0x63a280b3}},	//   _sadh, ałal, енце_, uhon,
   {{0xdb00c0da,0x63a47604,0xa3bf4048,0x777b8303}},	//   shmë, mhin, ेवर_, _dnux,
   {{0x7db64032,0x442a40d1,0x7ae4012c,0x06cd002a}},	//   _أصحا, _tvb_, _mzit, রেকি,
   {{0x395cb605,0x27e6c157,0x67c54007,0x71d740c3}},	//   revs_, _phon_, lėja, _נולד_,
   {{0x7c3e40b3,0x49084185,0xff5f01cb,0x93bcc17b}},	//   mupr, ाँको_, noît_, _mwăg,
   {{0x67260033,0x61f8c06f,0xe60fc5d3,0x62844004}},	//   dakj, _pivl, یشی_, nxio,
   {{0x9f404051,0x7c28f061,0x2fc0402c,0x320241ae}},	//   lmiä_, tsdr, hnig_, _muky_,
   {{0x7ae43606,0x7c3e4017,0xdcbac0c5,0x91a6c062}},	//   _azit, nupr, ящи_, टोगै,
   {{0x2d83c041,0x6d5e516a,0x7c28f607,0xb6a6d148}},	//   öjer_, hepa, rsdr, _пиел,
   {{0x61fab608,0x12c4402a,0xddc44043,0x7ae43609}},	//   _kitl, ্ধুদ, zviš, _czit,
   {{0x6c54c051,0x81dec02a,0x660fc02d,0x7bd601ae}},	//   _акку, _দূর_, ícke, _ekyu,
   {{0x7ae4360a,0x6d5e760b,0xdbd70051,0xa4d50589}},	//   _ezit, depa, _pääh, тові,
   {{0x6602f60c,0x2121005c,0x61fa8ae6,0xb275360d}},	//   _kuok, _wehh_, _litl, _алиш,
   {{0x99894166,0xfc45c066,0x2d878036,0x2918360e}},	// [3fb0] hrať_, žíte_, yjne_, bbra_,
   {{0x63a44057,0xb6bc00c3,0x28d201f9,0x98c74c85}},	//   ahin, _מצחי, _दुवि, нсел,
   {{0xbd054031,0x55ac0009,0xe5c4479a,0x31c44244}},	//   _abéè, _זייַ, усто, уств,
   {{0xdab98032,0x6d41c11a,0x61fa805e,0xd8380347}},	//   وهات_, zgla, _aitl, áče_,
   {{0xa3c40419,0xd9458e46,0x273ac676,0x6d5e4fd7}},	//   ्वत_, вели, zünü_, bepa,
   {{0x20d50b78,0x61fa805b,0xdb0f0066,0xdce3e177}},	//   _धडाध, _citl, dicí, _sanč,
   {{0xa06681bc,0x186681bc,0xaca340eb,0x61fa8c9a}},	//   ваща_, ващи_, _kpọc, _ditl,
   {{0x442caa31,0x34e18036,0xe7e10027,0x61fa8032}},	//   _dvd_, _फरीद, _गीला_, _eitl,
   {{0x20035662,0x7bdbf60f,0xba22cc38,0x4222c051}},	//   _huji_, rluu, адык, адыв,
   {{0x99894038,0x6ca7b610,0x63a440fd,0x2175e280}},	//   brať_, _преж, zhin, туир,
   {{0x752705c7,0xb4e00834,0xe8dfc015,0x22594033}},	//   dajz, _तरे_, _phối_, _lpsk_,
   {{0x764d406a,0x2005c080,0x28d2049d,0x6722c396}},	//   ktay, rqli_, _दुषि, _geoj,
   {{0x7c2482bc,0xfe79010e,0x273ac50c,0x2a66c024}},	//   ćire, нёры_, sünü_, _gsob_,
   {{0x212780d1,0x7bdd009d,0x291800f8,0x3f8fc0b6}},	//   nanh_, alsu, ubra_, _hogu_,
   {{0x224df1f2,0x61ee00fd,0x6d5e6e56,0x60231653}},	//   ltek_, rmbl, vepa, идра,
   {{0x236dc0fd,0x2fdd8046,0x6fd88166,0xdfcf0396}},	//   ndej_, jlwg_, níct, _ويو_,
   {{0x2fc0480f,0xa7fc859a,0x764d6768,0x7ae40dc0}},	// [3fc0] rnig_, _asıl, gtay, _uzit,
   {{0x69c1cae6,0x672428a0,0x70f641b4,0x7c3e5b9d}},	//   nnle, _heij, نسائ, tupr,
   {{0xd59b00c3,0x764d72cd,0x9f4240b6,0x64a60184}},	//   _חביל, atay, _dikò_, _рана,
   {{0x99d381aa,0x61ca86c1,0x20034303,0x32024089}},	//   یتوا, ाक्ष, _duji_, _tuky_,
   {{0xf7730052,0x7f838032,0xfe4380bd,0x201141a8}},	//   יקא_, شلون, инцо, _etzi_,
   {{0xa3e28b08,0x399404d3,0x35b680c5,0x59df85da}},	//   _नीर_, _gäst_, ъщес, _पीआर,
   {{0x7d5741f2,0x1c394051,0x33f6800a,0xa3bec25c}},	//   _שילד_, _пять_, _ачас, ँचल_,
   {{0xfbcfc182,0x236dc022,0x6b9bc006,0x7c2a8655}},	//   يتي_, gdej_, gkug, rsfr,
   {{0x6f0d3611,0x61fc4165,0x200346f0,0x7c2ab612}},	//   _rfac, _kirl, _zuji_, ssfr,
   {{0xa3e7c28b,0xa3e44028,0x6f0d0bfd,0x7c2480b3}},	//   _मीठ_, _पीस_, _sfac, ćirb,
   {{0x6fd88004,0x61fc40b6,0x7b66caba,0x27e93613}},	//   sícu, _mirl, _атле, _phan_,
   {{0x6602d09b,0x3ea94107,0x7bc2b614,0x3f8fc379}},	//   _tuok, yzat_, nnou, _gogu_,
   {{0xa5bb4686,0x1634c8f8,0x75e34112,0xee94c01c}},	//   _kvót, _селя, ọzir, _حداک,
   {{0x7e7d85f4,0x7e7607fb,0xdee3cc93,0xe5c40025}},	//   _áspe, _dryp, _точи, ассо,
   {{0xe1ff4031,0x03228027,0x225940b0,0x1df80051}},	//   _aróp_, मराह_, _spsk_, теры_,
   {{0xad9b41c0,0xddd9c053,0x63a2c303,0xddcd00cc}},	//   _atúp, _apwň, _jlon, _braţ,
   {{0xd7f855bc,0x7523c0f7,0x6fdd0070,0xeb1f32c1}},	// [3fd0] тур_, _yenz, véch, परीत_,
   {{0x63a2f615,0x61fc501e,0x212780d1,0x236dd466}},	//   _llon, _cirl, xanh_, zdej_,
   {{0xf99204e0,0x21278022,0xf7eb4032,0x38c9416a}},	//   _הרי_, vanh_, _يرجى_, رائی_,
   {{0xddcd00b4,0xe7d1802a,0x7528f616,0x442ccf2c}},	//   _fraţ, িষ্য, hadz, isd_,
   {{0x69c1c3ff,0x2003409c,0x6fdd3617,0x6595932d}},	//   ynle, _wuji_, réch, ладу,
   {{0x26180036,0xf2d40009,0x9f596df3,0x7640eaad}},	//   बीटी_, סעס_, _sisè_, dumy,
   {{0x6f048618,0xdc288032,0x7bc28109,0xe0558032}},	//   žica, نسيه_, bnou, اختب,
   {{0xdfd5804c,0x9f594303,0xdce7404f,0xf771d2c0}},	//   _собы, _bisé_, _jajč, صاب_,
   {{0x7528c056,0xadc441c0,0x3204865a,0xf771c646}},	//   fadz, _abẹr, _gumy_, لاک_,
   {{0x660418bf,0x2fc6c303,0x6b9d00a8,0xd49b8119}},	//   _ruik, _ejog_, eksg, _оре_,
   {{0x6604054b,0x6aa9c05f,0x7dddc1aa,0xbf1f0048}},	//   _suik, szef, nèsi, परून_,
   {{0x2d914242,0xf770cb92,0x9f4cc34d,0xbebb42a4}},	//   _loze_, _وان_, _dudó_, _reën,
   {{0x7523f618,0xff04c0c5,0xceb9c047,0xdce1c06a}},	//   _tenz, _тяхн, kaři_, rklı,
   {{0xa06a05dd,0xa3e7c09d,0xfd4b8031,0x2fdfc0f1}},	//   нага_, _मीत_, _aamẹ, llug_,
   {{0x2b4900d2,0x21258085,0x589500d9,0xfbdf043e}},	//   _fcac_, _melh_, ашту, blê_,
   {{0x77a60070,0x69c7417b,0xc31e002a,0x7e7b46f0}},	//   _bóxe, _ajje, _থাকি_, _šupa,
   {{0x4e1d0064,0xd9e3808f,0x6e290158,0x7e6980eb}},	// [3fe0] बीआई_, गतात_, šebr, _nsep,
   {{0x7f498019,0xdb1d0018,0x6561f619,0x39964086}},	//   _aceq, bosó, nelh, _næst_,
   {{0x6f0d4010,0xdb0f2285,0x7bd9c094,0xe3be80b5}},	//   bcac, licá, _okwu, şıma_,
   {{0x6f0d761a,0x42caa67d,0xd24f04e8,0x2fdfc23b}},	//   ccac, нген_, _بنی_, jlug_,
   {{0xdb0f0019,0x84e64027,0x61fc402c,0x6e3bc09c}},	//   nicá, _करवट_, _tirl, jrub,
   {{0xa3e604ae,0xb4265094,0x7bd9c094,0x63a41ab3}},	//   _बीस_, _معرو, _akwu, _llin,
   {{0x6561d628,0x201803bc,0x52e10371,0x64a643bf}},	//   delh, npri_, _नर्स, _сава,
   {{0x63a40303,0x69d5361b,0x5f94ddff,0x200592ad}},	//   _nlin, zoze, риит, _duli_,
   {{0x28db0419,0xa8058019,0x6e3bd04a,0x66064025}},	//   _मुनि, _peñí, grub, _jukk,
   {{0x660641ae,0x317e82bc,0x2609c4b3,0x645c405c}},	//   _mukk, _untz_, _dúo_, _kpri,
   {{0x69dab53c,0xdce3c03f,0x3cf8c20b,0x2a690041}},	//   _ikte, _panā, ärv_, _ssab_,
   {{0x63a412c5,0xdc9b4093,0x645c6adb,0x7528ddd5}},	//   _clin, גיטל, _mpri, sadz,
   {{0x27e0761c,0x6b9d2cb3,0xdce7761d,0x3f800036}},	//   dlin_, rksg, _rajč, _dniu_,
   {{0x244e4d01,0x9f4941b4,0x20058067,0x656e5c40}},	//   kým_, rmaí_, _yuli_, _nabh,
   {{0x2d91761e,0xd084004c,0xddc2c06c,0x442e80b6}},	//   _roze_, быти, _krož, nsf_,
   {{0xe7c5402a,0x27e06fe8,0x244e4089,0x67c54007}},	//   ্ষ্য, glin_, dým_, rėjo,
   {{0xa9c70301,0x656e761f,0x35b54097,0xddc2c011}},	// [3ff0] _مزدو, _babh, абар, _mrož,
   {{0x66067620,0x61fe0006,0xbe8f41c0,0x6f0d7621}},	//   _dukk, _gipl, _aṣáj, scac,
   {{0x2d9ef622,0x27e07623,0xddc2c06c,0x6d4ae2fe}},	//   ikte_, blin_, _orož, _mcfa,
   {{0x932787c3,0x656e4510,0x6d454032,0x442e8018}},	//   اران, _eabh, sgha, dsf_,
   {{0x15f6c028,0x92078017,0x6606440d,0x2fdfc14b}},	//   ीदार_, klāš, _gukk, vlug_,
   {{0x69c3869a,0x672642bc,0x0587404c,0x2d9ec15d}},	//   unne, _zekj, _сумм, jkte_,
   {{0x6e22c3e0,0xddc2c089,0x65a06e59,0x96260017}},	//   _awob, _brož, _möhl, _ziņā,
   {{0x2d9ec0bf,0xe3b3878a,0x6441f624,0x69da80d9}},	//   ekte_, _طرز_, vuli, _ekte,
   {{0xa3d90a3c,0xddc8c590,0x2d9c4107,0x6aad4c10}},	//   ़कन_, _šošk, öveg_, nzaf,
   {{0x27e0682c,0x6e3bc2eb,0xbebb42a4,0x463c4052}},	//   zlin_, rrub, _reël, געזע,
   {{0x9f9746ed,0x6e3bc041,0xb17a8009,0x28cfc9fd}},	//   nçó_, srub, _שטער, _सुखि,
   {{0x61fe3625,0x2d9ec0bf,0x6e3bcd45,0xdb0f0e79}},	//   _sipl, akte_, prub, ticá,
   {{0x8f9ac093,0x61fe00ce,0x212a0053,0x6e22c1f4}},	//   _שיני, _pipl, tabh_, _gwob,
   {{0x6d470fa0,0x3f8dc242,0x27e07219,0x66067626}},	//   ggja, ljeu_, wlin_, _rukk,
   {{0x7ae980b3,0x44234022,0x69c5405c,0x1fb64442}},	//   _lzet, _nwj_, dnhe, асар,
   {{0x66064e76,0x7ae983bc,0x69c56881,0x2b9c40d1}},	//   _pukk, _ozet, enhe, _xích_,

  };
  // table_hash = 8afb-a95b, unused_entries = 75 (0.04%)

static const uint32 kQuadChrome0122_19_2SizeOne = 13863;    // One-langprob count
static const uint32 kQuadChrome0122_19_2IndSize = 13863;    // Largest subscript
extern const uint32 kQuadChrome2IndSize = kQuadChrome0122_19_2IndSize; // Source-agnostic named constant
static const uint32 kQuadChrome0122_19_2Ind[kQuadChrome0122_19_2IndSize] = {
  // [0000]
  0x00000000, 0x00000000, 0x080c03a7, 0x20005504,   // -- --  nl.sv.no_532 rw.sq.un_320
  0x00001903, 0x18122114, 0x00006b0a, 0x0000100f,   // gl.un.un_300 fa.ur.ar_666  ceb.un.un_500 lt.un.un_600
  0x03080c04, 0x00002415, 0x0000111c, 0x0000350f,   // sv.no.nl_332 yi.un.un_700  ro.un.un_800 zu.un.un_600
  0x00002b0f, 0x00005515, 0x17070a05, 0x21001814,   // vi.un.un_600 rw.un.un_700  mk.bg.sr_333 ar.fa.un_660
  // [0010]
  0x00006b06, 0x00001601, 0x21190a02, 0x17001602,   // ceb.un.un_400 hr.un.un_200  pt.gl.jw_222 hr.sr.un_220
  0x04000e02, 0x00002b15, 0x0000230a, 0x00000f0f,   // is.fi.un_220 vi.un.un_700  ca.un.un_500 lv.un.un_600
  0x00001901, 0x19000b02, 0x16000d05, 0x00000a15,   // gl.un.un_200 es.gl.un_220  cs.hr.un_330 mk.un.un_700
  0x0000210f, 0x00000a0f, 0x0000050a, 0x00000a06,   // fa.un.un_600 pt.un.un_600  fr.un.un_500 pt.un.un_400
  // [0020]
  0x00005206, 0x1c091305, 0x00006e06, 0x281852a0,   // ha.un.un_400 bh.hi.mr_333  hmn.un.un_400 ha.ga.sw_322
  0x00005501, 0x0000040a, 0x0000100a, 0x13000909,   // rw.un.un_200 ru.un.un_500  lt.un.un_500 hi.bh.un_440
  0x1c000909, 0x3b2028a4, 0x00000b0f, 0x0700110c,   // hi.mr.un_440 sw.sq.so_433  bn.un.un_600 ro.bg.un_530
  0x00001f0f, 0x00002d0a, 0x00004a0a, 0x00001a03,   // cy.un.un_600 sk.un.un_500  yo.un.un_500 tl.un.un_300
  // [0030]
  0x04001004, 0x00004a03, 0x0000180f, 0x00001c01,   // be.ru.un_320 yo.un.un_300  ar.un.un_600 id.un.un_200
  0x1e001a04, 0x0e002014, 0x0000090f, 0x0312355a,   // tl.ms.un_320 sq.is.un_660  pl.un.un_600 zu.hu.nl_553
  0x00002d15, 0x00001015, 0x00003115, 0x1c131e0c,   // sk.un.un_700 lt.un.un_700  az.un.un_700 ms.et.id_543
  0x00001906, 0x1b2825ee, 0x1200180c, 0x00000f15,   // gl.un.un_400 eu.sw.tr_422  ga.hu.un_530 lv.un.un_700
  // [0040]
  0x35001a02, 0x00000c0a, 0x2153230c, 0x32001602,   // tl.zu.un_220 sv.un.un_500  ca.ht.jw_543 hr.bs.un_220
  0x0000680f, 0x1c000905, 0x00006e0a, 0x00000d0f,   // ig.un.un_600 hi.mr.un_330  hmn.un.un_500 cs.un.un_600
  0x00001c0f, 0x03003f02, 0x04130fa0, 0x2d001102,   // mr.un.un_600 af.nl.un_220  lv.et.fi_322 ro.sk.un_220
  0x00000415, 0x00006e15, 0x28001602, 0x0000290a,   // fi.un.un_700 hmn.un.un_700  hr.sw.un_220 sl.un.un_500
  // [0050]
  0x18002729, 0x0000040f, 0x0000240f, 0x00005301,   // gd.ga.un_960 fi.un.un_600  yi.un.un_600 ht.un.un_200
  0x32001705, 0x281a5512, 0x1e001c02, 0x00003b15,   // sr.bs.un_330 rw.tl.sw_654  id.ms.un_220 so.un.un_700
  0x041a2807, 0x03002d08, 0x12003513, 0x2d000d14,   // sw.tl.fi_432 sk.nl.un_430  zu.hu.un_650 cs.sk.un_660
  0x00001e01, 0x32291007, 0x00002701, 0x00001215,   // ms.un.un_200 lt.sl.bs_432  gd.un.un_200 ur.un.un_700
  // [0060]
  0x00002303, 0x00002703, 0x0000090a, 0x00001c0a,   // ca.un.un_300 gd.un.un_300  pl.un.un_500 mr.un.un_500
  0x00000915, 0x0000020f, 0x2d000d0e, 0x00005215,   // pl.un.un_700 da.un.un_600  cs.sk.un_550 ha.un.un_700
  0x321716a9, 0x040a07ec, 0x00001b0f, 0x13551a07,   // hr.sr.bs_544 bg.mk.ru_644  tr.un.un_600 tl.rw.et_432
  0x0000290f, 0x00000601, 0x0d002a07, 0x00001703,   // sl.un.un_600 de.un.un_200  mt.cs.un_420 sr.un.un_300
  // [0070]
  0x00000b01, 0x2d1c35a0, 0x04071707, 0x00003503,   // es.un.un_200 zu.id.sk_322  sr.bg.ru_432 zu.un.un_300
  0x2d230204, 0x2a2818a0, 0x040c0e07, 0x00001701,   // da.ca.sk_332 ga.sw.mt_322  is.sv.fi_432 sr.un.un_200
  0x03003f09, 0x00000b15, 0x00001c03, 0x0a04175a,   // af.nl.un_440 bn.un.un_700  id.un.un_300 sr.ru.mk_553
  0x13000d04, 0x1100081a, 0x100d29a0, 0x13092d0c,   // ne.bh.un_320 uk.ro.un_760  sl.cs.lt_322 sk.pl.et_543
  // [0080]
  0x0000310f, 0x0a0717a4, 0x00002b1c, 0x00004a15,   // az.un.un_600 sr.bg.mk_433  vi.un.un_800 yo.un.un_700
  0x32002904, 0x00002a01, 0x00000e0f, 0x01002412,   // sl.bs.un_320 mt.un.un_200  is.un.un_600 yi.iw.un_640
  0x0c0f13a0, 0x2d000d09, 0x556435a0, 0x1c130911,   // et.lv.sv_322 cs.sk.un_440  zu.lg.rw_322 hi.bh.mr_653
  0x2100120e, 0x0e0c0607, 0x06001b12, 0x00001c15,   // ur.fa.un_550 de.sv.is_432  tr.de.un_640 mr.un.un_700
  // [0090]
  0x10081112, 0x64071c07, 0x10070408, 0x00000115,   // ro.uk.be_654 id.it.lg_432  ru.bg.be_443 iw.un.un_700
  0x0000681c, 0x06000c0d, 0x09001213, 0x00001006,   // ig.un.un_800 sv.de.un_540  hu.pl.un_650 be.un.un_400
  0x0c080205, 0x1004080d, 0x3555640b, 0x04000813,   // da.no.sv_333 uk.ru.be_554  lg.rw.zu_542 uk.ru.un_650
  0x00005201, 0x0000130f, 0x1b003105, 0x07001105,   // ha.un.un_200 et.un.un_600  az.tr.un_330 ro.it.un_330
  // [00a0]
  0x00000d0a, 0x35002109, 0x03200607, 0x121821af,   // cs.un.un_500 jw.zu.un_440  de.sq.nl_432 fa.ar.ur_655
  0x21002812, 0x3f003202, 0x18531902, 0x04070a09,   // sw.jw.un_640 bs.af.un_220  gl.ht.ga_222 mk.bg.ru_444
  0x00000306, 0x070a170d, 0x1c001304, 0x32171605,   // nl.un.un_400 sr.mk.bg_554  bh.mr.un_320 hr.sr.bs_333
  0x08020cec, 0x27001f19, 0x0e190b02, 0x04355505,   // sv.da.no_644 cy.gd.un_750  es.gl.is_222 rw.zu.fi_333
  // [00b0]
  0x0000020a, 0x00003f03, 0x0000130a, 0x00003201,   // da.un.un_500 af.un.un_300  et.un.un_500 bs.un.un_200
  0x0000110a, 0x31001b13, 0x00005303, 0x0e2d0d08,   // ro.un.un_500 tr.az.un_650  ht.un.un_300 cs.sk.is_443
  0x211218af, 0x00002501, 0x0d001c12, 0x00006403,   // ar.ur.fa_655 eu.un.un_200  mr.ne.un_640 lg.un.un_300
  0x0000640a, 0x04000a08, 0x1b2d0d04, 0x03003f0d,   // lg.un.un_500 mk.ru.un_430  cs.sk.tr_332 af.nl.un_540
  // [00c0]
  0x3500642a, 0x0a07170c, 0x0000350a, 0x0000010f,   // lg.zu.un_970 sr.bg.mk_543  zu.un.un_500 iw.un.un_600
  0x00000703, 0x0000070f, 0x091c0d5a, 0x00003501,   // it.un.un_300 bg.un.un_600  ne.mr.hi_553 zu.un.un_200
  0x040208a4, 0x00001e06, 0x2a2855ac, 0x0000060a,   // no.da.fi_433 ms.un.un_400  rw.sw.mt_632 de.un.un_500
  0x00001106, 0x071004a9, 0x00005306, 0x100804ad,   // ro.un.un_400 ru.be.bg_544  ht.un.un_400 ru.uk.be_643
  // [00d0]
  0x1f080205, 0x00002b0a, 0x00002301, 0x11002504,   // da.no.cy_333 vi.un.un_500  ca.un.un_200 eu.ro.un_320
  0x25643507, 0x04081009, 0x0a1710ad, 0x0000101c,   // zu.lg.eu_432 be.uk.ru_444  be.sr.mk_643 be.un.un_800
  0x1200130e, 0x0000080f, 0x00002015, 0x1c1e12ad,   // et.hu.un_550 uk.un.un_600  sq.un.un_700 hu.ms.id_643
  0x53290305, 0x12000509, 0x00001f1c, 0x0d001302,   // nl.sl.ht_333 fr.hu.un_440  cy.un.un_800 bh.ne.un_220
  // [00e0]
  0x32171609, 0x19000b04, 0x00005203, 0x090620a7,   // hr.sr.bs_444 es.gl.un_320  ha.un.un_300 sq.de.pl_532
  0x09000d0e, 0x00002906, 0x1c090da9, 0x1b1e25ad,   // ne.hi.un_550 sl.un.un_400  ne.hi.mr_544 eu.ms.tr_643
  0x0c000e13, 0x0d000902, 0x64004a1a, 0x0000680a,   // is.sv.un_650 hi.ne.un_220  yo.lg.un_760 ig.un.un_500
  0x6b001a0e, 0x18002102, 0x552d1ba4, 0x17002d05,   // tl.ceb.un_550 jw.ga.un_220  tr.sk.rw_433 sk.sr.un_330
  // [00f0]
  0x1e004a08, 0x00002a0f, 0x6b1820ee, 0x3500010d,   // yo.ms.un_430 mt.un.un_600  sq.ga.ceb_422 en.zu.un_540
  0x0d091c0d, 0x315228a4, 0x00002a03, 0x00003515,   // mr.hi.ne_554 sw.ha.az_433  mt.un.un_300 zu.un.un_700
  0x00001a01, 0x10041107, 0x0000060f, 0x0000121c,   // tl.un.un_200 ro.ru.be_432  de.un.un_600 ur.un.un_800
  0x0000250f, 0x0000200f, 0x12002118, 0x0900350c,   // eu.un.un_600 sq.un.un_600  fa.ur.un_740 zu.pl.un_530
  // [0100]
  0x01006b04, 0x03003f0e, 0x11522507, 0x1c130960,   // ceb.en.un_320 af.nl.un_550  eu.ha.ro_432 hi.bh.mr_664
  0x00002b03, 0x00006b0f, 0x18000607, 0x0000120f,   // vi.un.un_300 ceb.un.un_600  de.ga.un_420 ur.un.un_600
  0x013f1f07, 0x09000d0d, 0x1a1f02ee, 0x00000a0a,   // cy.af.en_432 ne.hi.un_540  da.cy.tl_422 pt.un.un_500
  0x21000a05, 0x00000e15, 0x0400100d, 0x18002702,   // pt.jw.un_330 is.un.un_700  be.ru.un_540 gd.ga.un_220
  // [0110]
  0x0c046407, 0x0e001012, 0x00006806, 0x292d0d04,   // lg.fi.sv_432 lt.is.un_640  ig.un.un_400 cs.sk.sl_332
  0x0f002904, 0x0700040e, 0x285535a4, 0x4a0e1b0c,   // sl.lv.un_320 ru.bg.un_550  zu.rw.sw_433 tr.is.yo_543
  0x2d0d1902, 0x0000110f, 0x16002904, 0x00000815,   // gl.cs.sk_222 ro.un.un_600  sl.hr.un_320 uk.un.un_700
  0x00006415, 0x030501a4, 0x08001013, 0x16321704,   // lg.un.un_700 en.fr.nl_433  be.uk.un_650 sr.bs.hr_332
  // [0120]
  0x16002908, 0x044a0ea7, 0x284a1bec, 0x00001603,   // sl.hr.un_430 is.yo.fi_532  tr.yo.sw_644 hr.un.un_300
  0x64680412, 0x0000080a, 0x01003f04, 0x00000301,   // fi.ig.lg_654 no.un.un_500  af.en.un_320 nl.un.un_200
  0x200c08a4, 0x00000103, 0x0b530aa0, 0x08001014,   // no.sv.sq_433 en.un.un_300  pt.ht.es_322 be.uk.un_660
  0x0000280a, 0x1e001c05, 0x07042055, 0x1b313bec,   // sw.un.un_500 id.ms.un_330  sq.fi.it_442 so.az.tr_644
  // [0130]
  0x2d040da7, 0x32092907, 0x1c3b2102, 0x0d003504,   // cs.fi.sk_532 sl.pl.bs_432  jw.so.id_222 zu.cs.un_320
  0x0400130d, 0x18001f07, 0x06000c05, 0x060c1f10,   // et.fi.un_540 cy.ga.un_420  sv.de.un_330 cy.sv.de_642
  0x00001b0a, 0x1f0e0ca9, 0x06000c02, 0x0000200a,   // tr.un.un_500 sv.is.cy_544  sv.de.un_220 sq.un.un_500
  0x2b006b08, 0x0d6b1fee, 0x03122aa7, 0x32171604,   // ceb.vi.un_430 cy.ceb.cs_422  mt.hu.nl_532 hr.sr.bs_332
  // [0140]
  0x00002503, 0x0000530a, 0x0d002904, 0x0a17110c,   // eu.un.un_300 ht.un.un_500  sl.cs.un_320 ro.sr.mk_543
  0x20000604, 0x00001806, 0x28250108, 0x00002903,   // de.sq.un_320 ga.un.un_400  en.eu.sw_443 sl.un.un_300
  0x09001c0e, 0x00003b0a, 0x1c130908, 0x00003f0a,   // mr.hi.un_550 so.un.un_500  hi.bh.mr_443 af.un.un_500
  0x08003f05, 0x00003f01, 0x3b00310e, 0x0300280c,   // af.no.un_330 af.un.un_200  az.so.un_550 sw.nl.un_530
  // [0150]
  0x0000280f, 0x6b1a3b07, 0x2d0d0e0e, 0x3f0e3ba4,   // sw.un.un_600 so.tl.ceb_432  is.cs.sk_555 so.is.af_433
  0x1e1c1fee, 0x13000612, 0x00001115, 0x00000701,   // cy.id.ms_422 de.et.un_640  ro.un.un_700 it.un.un_200
  0x17163202, 0x1f6b0eec, 0x00001f0a, 0x12001b11,   // bs.hr.sr_222 is.ceb.cy_644  cy.un.un_500 tr.hu.un_630
  0x3b000119, 0x0000030a, 0x521b3ba4, 0x0b293ba0,   // en.so.un_750 nl.un.un_500  so.tr.ha_433 so.sl.es_322
  // [0160]
  0x23001908, 0x64010507, 0x02180107, 0x0d091c0e,   // gl.ca.un_430 fr.en.lg_432  en.ga.da_432 mr.hi.ne_555
  0x080201ee, 0x31001b12, 0x00002d0f, 0x0a070460,   // en.da.no_422 tr.az.un_640  sk.un.un_600 ru.bg.mk_664
  0x060c08a0, 0x17000a14, 0x2100120d, 0x25205207,   // no.sv.de_322 mk.sr.un_660  ur.fa.un_540 ha.sq.eu_432
  0x31552aa0, 0x0a0704a4, 0x17162902, 0x17000a13,   // mt.rw.az_322 ru.bg.mk_433  sl.hr.sr_222 mk.sr.un_650
  // [0170]
  0x2a001702, 0x00004a0f, 0x01000802, 0x07041702,   // sr.mt.un_220 yo.un.un_600  no.en.un_220 sr.ru.bg_222
  0x0c060404, 0x13000609, 0x00000801, 0x00003f06,   // fi.de.sv_332 de.et.un_440  uk.un.un_200 af.un.un_400
  0x27000407, 0x07040807, 0x00002a06, 0x00006401,   // fi.gd.un_420 uk.ru.bg_432  mt.un.un_400 lg.un.un_200
  0x122d0d04, 0x3b000c0d, 0x13000905, 0x081b04ad,   // cs.sk.hu_332 sv.so.un_540  hi.bh.un_330 fi.tr.no_643
  // [0180]
  0x5505010c, 0x00000501, 0x21001812, 0x21121812,   // en.fr.rw_543 fr.un.un_200  ar.fa.un_640 ar.ur.fa_654
  0x070a1004, 0x00000d15, 0x00001124, 0x10000819,   // be.mk.bg_332 cs.un.un_700  ro.un.un_900 uk.be.un_750
  0x01000204, 0x1b00310e, 0x01000504, 0x64005514,   // da.en.un_320 az.tr.un_550  fr.en.un_320 rw.lg.un_660
  0x6400351a, 0x0708040d, 0x033f01a4, 0x1e005202,   // zu.lg.un_760 ru.uk.bg_554  en.af.nl_433 ha.ms.un_220
  // [0190]
  0x20000e07, 0x1c0d0914, 0x170704a7, 0x07000108,   // is.sq.un_420 hi.ne.mr_666  ru.bg.sr_532 en.it.un_430
  0x0d002d13, 0x0c0305ee, 0x35005502, 0x20002807,   // sk.cs.un_650 fr.nl.sv_422  rw.zu.un_220 sw.sq.un_420
  0x272504ec, 0x321716a0, 0x202304ee, 0x170a07a4,   // fi.eu.gd_644 hr.sr.bs_322  fi.ca.sq_422 bg.mk.sr_433
  0x170a0405, 0x0b001904, 0x170708ad, 0x2b001e04,   // ru.mk.sr_333 gl.es.un_320  uk.bg.sr_643 ms.vi.un_320
  // [01a0]
  0x17070a60, 0x25002709, 0x17000805, 0x3100550d,   // mk.bg.sr_664 gd.eu.un_440  uk.sr.un_330 rw.az.un_540
  0x07001009, 0x2a003f04, 0x6b251304, 0x0e080204,   // be.bg.un_440 af.mt.un_320  et.eu.ceb_332 da.no.is_332
  0x0000250a, 0x040711ee, 0x00002115, 0x0b231904,   // eu.un.un_500 ro.bg.ru_422  fa.un.un_700 gl.ca.es_332
  0x1c000d05, 0x3b1e5204, 0x0000640f, 0x00002d06,   // ne.mr.un_330 ha.ms.so_332  lg.un.un_600 sk.un.un_400
  // [01b0]
  0x03003f05, 0x04001a05, 0x2d100dad, 0x1a002a07,   // af.nl.un_330 tl.fi.un_330  cs.lt.sk_643 mt.tl.un_420
  0x00001815, 0x0c001a04, 0x091c130c, 0x00002a1c,   // ar.un.un_700 tl.sv.un_320  bh.mr.hi_543 mt.un.un_800
  0x162d0d08, 0x02001a04, 0x3b1955a0, 0x08041702,   // cs.sk.hr_443 tl.da.un_320  rw.gl.so_322 sr.ru.uk_222
  0x00000715, 0x0000171c, 0x171632a0, 0x521e55a0,   // bg.un.un_700 sr.un.un_800  bs.hr.sr_322 rw.ms.ha_322
  // [01c0]
  0x00004a06, 0x081b3fa0, 0x130d09ad, 0x08100413,   // yo.un.un_400 af.tr.no_322  hi.ne.bh_643 ru.be.uk_665
  0x213501a4, 0x31532812, 0x0000550f, 0x13030404,   // en.zu.jw_433 sw.ht.az_654  rw.un.un_600 fi.nl.et_332
  0x00003b0f, 0x3b000707, 0x3f0625ad, 0x00000506,   // so.un.un_600 it.so.un_420  eu.de.af_643 fr.un.un_400
  0x04070aa0, 0x060e3fa4, 0x080717ee, 0x1c001a07,   // mk.bg.ru_322 af.is.de_433  sr.bg.uk_422 tl.id.un_420
  // [01d0]
  0x20286407, 0x20003202, 0x1c012d07, 0x041013a4,   // lg.sw.sq_432 bs.sq.un_220  sk.en.id_432 et.lt.fi_433
  0x0000030f, 0x10001112, 0x00002a0a, 0x1a0c0807,   // nl.un.un_600 ro.be.un_640  mt.un.un_500 no.sv.tl_432
  0x4a006e08, 0x11002a02, 0x1c090dee, 0x311f0eee,   // hmn.yo.un_430 mt.ro.un_220  ne.hi.mr_422 is.cy.az_422
  0x0400100c, 0x102d0d08, 0x27183508, 0x31001b14,   // be.ru.un_530 cs.sk.lt_443  zu.ga.gd_443 tr.az.un_660
  // [01e0]
  0x05210107, 0x0e355504, 0x00000d03, 0x21181205,   // en.jw.fr_432 rw.zu.is_332  ne.un.un_300 ur.ar.fa_333
  0x1f520407, 0x0c080208, 0x0a001719, 0x1c00090e,   // fi.ha.cy_432 da.no.sv_443  sr.mk.un_750 hi.mr.un_550
  0x321617a6, 0x06292504, 0x133f03a9, 0x07000a08,   // sr.hr.bs_521 eu.sl.de_332  nl.af.et_544 mk.bg.un_430
  0x21002702, 0x3f1303a9, 0x3200350b, 0x4a003b0d,   // gd.jw.un_220 nl.et.af_544  zu.bs.un_520 so.yo.un_540
  // [01f0]
  0x00000403, 0x190b0aee, 0x01002408, 0x55002805,   // ru.un.un_300 pt.es.gl_422  yi.iw.un_430 sw.rw.un_330
  0x00001f15, 0x23002907, 0x070417a0, 0x211812a4,   // cy.un.un_700 sl.ca.un_420  sr.ru.bg_322 ur.ar.fa_433
  0x3f2b03a0, 0x0d000905, 0x07040a04, 0x2a00200b,   // nl.vi.af_322 hi.ne.un_330  mk.ru.bg_332 sq.mt.un_520
  0x12002d0d, 0x29002d05, 0x64001902, 0x00000a03,   // sk.hu.un_540 sk.sl.un_330  gl.lg.un_220 mk.un.un_300
  // [0200]
  0x121821ec, 0x063f0302, 0x071e1c02, 0x07040811,   // fa.ar.ur_644 nl.af.de_222  id.ms.it_222 uk.ru.bg_653
  0x32161707, 0x2a001b14, 0x00000303, 0x09001802,   // sr.hr.bs_432 tr.mt.un_660  nl.un.un_300 ga.pl.un_220
  0x060d35a9, 0x03293bee, 0x230701a4, 0x13000c0c,   // zu.cs.de_544 so.sl.nl_422  en.it.ca_433 sv.et.un_530
  0x21001813, 0x08000412, 0x35006419, 0x0a001722,   // ar.fa.un_650 ru.uk.un_640  lg.zu.un_750 sr.mk.un_870
  // [0210]
  0x0a040704, 0x0800020c, 0x1200640c, 0x531264a6,   // bg.ru.mk_332 da.no.un_530  lg.hu.un_530 lg.hu.ht_521
  0x041707ad, 0x100d2d0b, 0x0f291605, 0x0a00171a,   // bg.sr.ru_643 sk.cs.lt_542  hr.sl.lv_333 sr.mk.un_760
  0x04000d04, 0x100407ee, 0x122118ad, 0x00001e03,   // cs.fi.un_320 bg.ru.be_422  ar.fa.ur_643 ms.un.un_300
  0x6b3512ad, 0x24000113, 0x130f0204, 0x4a006813,   // hu.zu.ceb_643 iw.yi.un_650  da.lv.et_332 ig.yo.un_650
  // [0220]
  0x2d000d11, 0x08040aa9, 0x2d321702, 0x0a000414,   // cs.sk.un_630 mk.ru.uk_544  sr.bs.sk_222 ru.mk.un_660
  0x2d000d08, 0x0c082009, 0x2112180c, 0x6b043f05,   // cs.sk.un_430 sq.no.sv_444  ar.ur.fa_543 af.fi.ceb_333
  0x181221af, 0x0a08070d, 0x290c2504, 0x04000812,   // fa.ur.ar_655 bg.uk.mk_554  eu.sv.sl_332 uk.ru.un_640
  0x09200f07, 0x1c000d08, 0x04070aec, 0x53001a05,   // lv.sq.pl_432 ne.mr.un_430  mk.bg.ru_644 tl.ht.un_330
  // [0230]
  0x00002803, 0x0000210a, 0x00002515, 0x122a21a4,   // sw.un.un_300 fa.un.un_500  eu.un.un_700 jw.mt.hu_433
  0x131b31ad, 0x0600350c, 0x12001b0c, 0x0c0e01a0,   // az.tr.et_643 zu.de.un_530  tr.hu.un_530 en.is.sv_322
  0x0e000a07, 0x0f033fa4, 0x6b4a1a12, 0x00006e0f,   // pt.is.un_420 af.nl.lv_433  tl.yo.ceb_654 hmn.un.un_600
  0x3b002808, 0x00001001, 0x16001707, 0x00000706,   // sw.so.un_430 be.un.un_200  sr.hr.un_420 it.un.un_400
  // [0240]
  0x0800020e, 0x0d003507, 0x321617a0, 0x2b030504,   // da.no.un_550 zu.cs.un_420  sr.hr.bs_322 fr.nl.vi_332
  0x0a001714, 0x17000a12, 0x1221180d, 0x00002901,   // sr.mk.un_660 mk.sr.un_640  ar.fa.ur_554 sl.un.un_200
  0x121821a7, 0x290c35a0, 0x23000113, 0x170408a4,   // fa.ar.ur_532 zu.sv.sl_322  en.ca.un_650 uk.ru.sr_433
  0x00006e1c, 0x2300251a, 0x07000a05, 0x18002713,   // hmn.un.un_800 eu.ca.un_760  mk.bg.un_330 gd.ga.un_650
  // [0250]
  0x0b001908, 0x0a0817a0, 0x23000607, 0x08000205,   // gl.es.un_430 sr.uk.mk_322  de.ca.un_420 da.no.un_330
  0x64552504, 0x0e00020c, 0x1b3b0504, 0x4a001213,   // eu.rw.lg_332 da.is.un_530  fr.so.tr_332 hu.yo.un_650
  0x3b002104, 0x10080405, 0x0525060d, 0x1800120c,   // jw.so.un_320 ru.uk.be_333  de.eu.fr_554 ur.ar.un_530
  0x09001307, 0x00006815, 0x21122d0c, 0x1e001804,   // bh.hi.un_420 ig.un.un_700  sk.hu.jw_543 ga.ms.un_320
  // [0260]
  0x00000d1c, 0x08071007, 0x170a07a0, 0x190b23a0,   // cs.un.un_800 be.bg.uk_432  bg.mk.sr_322 ca.es.gl_322
  0x130c0612, 0x11001f04, 0x103b12ec, 0x17000a1a,   // de.sv.et_654 cy.ro.un_320  hu.so.lt_644 mk.sr.un_760
  0x10001f19, 0x2700180e, 0x1b033faf, 0x2700180c,   // cy.lt.un_750 ga.gd.un_550  af.nl.tr_655 ga.gd.un_530
  0x08020cee, 0x356455af, 0x130e0607, 0x17081004,   // sv.da.no_422 rw.lg.zu_655  de.is.et_432 be.uk.sr_332
  // [0270]
  0x07080aa0, 0x0a071707, 0x29000d0d, 0x023f080c,   // mk.uk.bg_322 sr.bg.mk_432  cs.sl.un_540 no.af.da_543
  0x6b001a0d, 0x0d0913a4, 0x35000c08, 0x23000104,   // tl.ceb.un_540 bh.hi.ne_433  sv.zu.un_430 en.ca.un_320
  0x0d00130b, 0x00000f1c, 0x130e08af, 0x07132504,   // bh.ne.un_520 lv.un.un_800  no.is.et_655 eu.et.it_332
  0x21002504, 0x131c2109, 0x32001304, 0x07000a02,   // eu.jw.un_320 jw.id.et_444  et.bs.un_320 mk.bg.un_220
  // [0280]
  0x18001209, 0x1c090d0e, 0x16293507, 0x00002a15,   // ur.ar.un_440 ne.hi.mr_555  zu.sl.hr_432 mt.un.un_700
  0x4a002a0d, 0x0d000909, 0x13006b04, 0x0611090b,   // mt.yo.un_540 hi.ne.un_440  ceb.et.un_320 pl.ro.de_542
  0x091c0dad, 0x10000813, 0x080410ee, 0x13001c1a,   // ne.mr.hi_643 uk.be.un_650  be.ru.uk_422 mr.bh.un_760
  0x0c001313, 0x28006407, 0x6b1a25a4, 0x271801ee,   // et.sv.un_650 lg.sw.un_420  eu.tl.ceb_433 en.ga.gd_422
  // [0290]
  0x1f003f08, 0x0a04070d, 0x182a0c0c, 0x17040804,   // af.cy.un_430 bg.ru.mk_554  sv.mt.ga_543 uk.ru.sr_332
  0x13063107, 0x06002a04, 0x11120704, 0x040708af,   // az.de.et_432 mt.de.un_320  it.hu.ro_332 no.it.fi_655
  0x1c0d0907, 0x080a1712, 0x0000270a, 0x0c002005,   // hi.ne.mr_432 sr.mk.uk_654  gd.un.un_500 sq.sv.un_330
  0x3b000419, 0x07001104, 0x1a006b13, 0x17002d04,   // fi.so.un_750 ro.it.un_320  ceb.tl.un_650 sk.sr.un_320
  // [02a0]
  0x02000304, 0x53321702, 0x116b07a0, 0x17163205,   // nl.da.un_320 sr.bs.ht_222  it.ceb.ro_322 bs.hr.sr_333
  0x00003f0f, 0x041707a7, 0x0100240d, 0x00006b1c,   // af.un.un_600 bg.sr.ru_532  yi.iw.un_540 ceb.un.un_800
  0x3f000912, 0x212a1b05, 0x0c0208a0, 0x03063f12,   // pl.af.un_640 tr.mt.jw_333  no.da.sv_322 af.de.nl_654
  0x13000819, 0x00000603, 0x0708100e, 0x29001609,   // no.et.un_750 de.un.un_300  be.uk.bg_555 hr.sl.un_440
  // [02b0]
  0x19000b09, 0x07001113, 0x1c002518, 0x08001704,   // es.gl.un_440 ro.bg.un_650  eu.id.un_740 sr.uk.un_320
  0x2b00250e, 0x0506010c, 0x16003f02, 0x182035ee,   // eu.vi.un_550 en.de.fr_543  af.hr.un_220 zu.sq.ga_422
  0x1c1309ad, 0x2d0d20ee, 0x180e1907, 0x551a07ee,   // hi.bh.mr_643 sq.cs.sk_422  gl.is.ga_432 it.tl.rw_422
  0x00003203, 0x07272ba7, 0x182b27a0, 0x35523b0d,   // bs.un.un_300 vi.gd.it_532  gd.vi.ga_322 so.ha.zu_554
  // [02c0]
  0x00002806, 0x0717040d, 0x52005502, 0x08001713,   // sw.un.un_400 ru.sr.bg_554  rw.ha.un_220 sr.uk.un_650
  0x64001f0d, 0x060c0305, 0x32000604, 0x09002a08,   // cy.lg.un_540 nl.sv.de_333  de.bs.un_320 mt.pl.un_430
  0x0d0913a9, 0x271718a9, 0x16000a02, 0x00000515,   // bh.hi.ne_544 ga.sr.gd_544  pt.hr.un_220 fr.un.un_700
  0x3f080cee, 0x00001f03, 0x1c0f1305, 0x12002113,   // sv.no.af_422 cy.un.un_300  et.lv.id_333 fa.ur.un_650
  // [02d0]
  0x07000819, 0x13212004, 0x170a07af, 0x170a07ec,   // uk.bg.un_750 sq.jw.et_332  bg.mk.sr_655 bg.mk.sr_644
  0x1800270e, 0x080704ee, 0x1b003113, 0x1a006b19,   // gd.ga.un_550 fi.it.no_422  az.tr.un_650 ceb.tl.un_750
  0x0000170a, 0x2d005204, 0x35000113, 0x0a0704af,   // sr.un.un_500 ha.sk.un_320  en.zu.un_650 ru.bg.mk_655
  0x0f522da0, 0x13521aa0, 0x06030ca0, 0x04006404,   // sk.ha.lv_322 tl.ha.et_322  sv.nl.de_322 lg.fi.un_320
  // [02e0]
  0x17070a0c, 0x06080ea0, 0x070a1714, 0x23001904,   // mk.bg.sr_543 is.no.de_322  sr.mk.bg_666 gl.ca.un_320
  0x041710a4, 0x200f35a0, 0x1000060c, 0x2d000907,   // be.sr.ru_433 zu.lv.sq_322  de.lt.un_530 pl.sk.un_420
  0x4a1f5304, 0x0c00080d, 0x00001306, 0x19000a05,   // ht.cy.yo_332 no.sv.un_540  bh.un.un_400 pt.gl.un_330
  0x04645509, 0x010f3f07, 0x17005302, 0x010a110c,   // rw.lg.fi_444 af.lv.en_432  ht.sr.un_220 ro.pt.en_543
  // [02f0]
  0x12002112, 0x0a071705, 0x5200680c, 0x68162507,   // fa.ur.un_640 sr.bg.mk_333  ig.ha.un_530 eu.hr.ig_432
  0x2d000d0c, 0x0a005502, 0x13000913, 0x13000413,   // cs.sk.un_530 rw.pt.un_220  hi.bh.un_650 fi.et.un_650
  0x0400170e, 0x0d005202, 0x213b3f07, 0x0a192307,   // sr.ru.un_550 ha.cs.un_220  af.so.jw_432 ca.gl.pt_432
  0x04005305, 0x170a0712, 0x203528a4, 0x13000419,   // ht.fi.un_330 bg.mk.sr_654  sw.zu.sq_433 fi.et.un_750
  // [0300]
  0x08000c0d, 0x211812ad, 0x211c2007, 0x00002101,   // sv.no.un_540 ur.ar.fa_643  sq.id.jw_432 jw.un.un_200
  0x525501a4, 0x0e2d0d09, 0x1f005202, 0x3b001012,   // en.rw.ha_433 cs.sk.is_444  ha.cy.un_220 lt.so.un_640
  0x252d29ad, 0x3b04010c, 0x25002102, 0x03082504,   // sl.sk.eu_643 en.fi.so_543  jw.eu.un_220 eu.no.nl_332
  0x0f100607, 0x19000b05, 0x321620ee, 0x0a0811a0,   // de.lt.lv_432 es.gl.un_330  sq.hr.bs_422 ro.uk.mk_322
  // [0310]
  0x050e250c, 0x27001812, 0x062103ee, 0x08173f04,   // eu.is.fr_543 ga.gd.un_640  nl.jw.de_422 af.sr.no_332
  0x00001303, 0x00002315, 0x3f1f0ca7, 0x080225ec,   // bh.un.un_300 ca.un.un_700  sv.cy.af_532 eu.da.no_644
  0x1900230e, 0x19000b0e, 0x1b1a31a7, 0x040c3ba0,   // ca.gl.un_550 es.gl.un_550  az.tl.tr_532 so.sv.fi_322
  0x0000641c, 0x06000302, 0x0800100e, 0x0000170f,   // lg.un.un_800 nl.de.un_220  be.uk.un_550 sr.un.un_600
  // [0320]
  0x080225a9, 0x00002706, 0x642a52a0, 0x0100240c,   // eu.da.no_544 gd.un.un_400  ha.mt.lg_322 yi.iw.un_530
  0x3f0809ad, 0x352001ac, 0x31003b05, 0x12001a04,   // pl.no.af_643 en.sq.zu_632  so.az.un_330 tl.hu.un_320
  0x09292da0, 0x00000206, 0x00001f06, 0x1c000f05,   // sk.sl.pl_322 da.un.un_400  cy.un.un_400 lv.id.un_330
  0x20006404, 0x25000313, 0x033f1307, 0x020c3fa4,   // lg.sq.un_320 nl.eu.un_650  et.af.nl_432 af.sv.da_433
  // [0330]
  0x1c0d09a9, 0x206b01a6, 0x13005519, 0x21003519,   // hi.ne.mr_544 en.ceb.sq_521  rw.et.un_750 zu.jw.un_750
  0x0800520b, 0x05005208, 0x281a1055, 0x1f2327a7,   // ha.no.un_520 ha.fr.un_430  lt.tl.sw_442 gd.ca.cy_532
  0x1f061004, 0x0000351c, 0x1f002a04, 0x1f003519,   // lt.de.cy_332 zu.un.un_800  mt.cy.un_320 zu.cy.un_750
  0x0d122d0d, 0x3b002507, 0x00000f01, 0x29000819,   // sk.hu.cs_554 eu.so.un_420  lv.un.un_200 no.sl.un_750
  // [0340]
  0x00001a06, 0x080c2d55, 0x13000914, 0x041117a4,   // tl.un.un_400 sk.sv.no_442  hi.bh.un_660 sr.ro.ru_433
  0x0a190b04, 0x27002312, 0x2000010d, 0x2d000d12,   // es.gl.pt_332 ca.gd.un_640  en.sq.un_540 cs.sk.un_640
  0x07040804, 0x28002a04, 0x17040704, 0x01000609,   // uk.ru.bg_332 mt.sw.un_320  bg.ru.sr_332 de.en.un_440
  0x21002804, 0x00000b03, 0x013506a6, 0x09041012,   // sw.jw.un_320 es.un.un_300  de.zu.en_521 lt.fi.pl_654
  // [0350]
  0x041206a0, 0x321617a9, 0x0c123504, 0x03003f13,   // de.hu.fi_322 sr.hr.bs_544  zu.hu.sv_332 af.nl.un_650
  0x64551207, 0x2d0901a0, 0x321608ec, 0x23002704,   // hu.rw.lg_432 en.pl.sk_322  no.hr.bs_644 gd.ca.un_320
  0x556408a0, 0x0000180a, 0x3f000802, 0x0e000104,   // no.lg.rw_322 ga.un.un_500  no.af.un_220 en.is.un_320
  0x12001814, 0x00002b06, 0x110501af, 0x0a000e19,   // ar.ur.un_660 vi.un.un_400  en.fr.ro_655 is.pt.un_750
  // [0360]
  0x0000520f, 0x3f0301a4, 0x281e2a07, 0x1000081b,   // ha.un.un_600 en.nl.af_433  mt.ms.sw_432 uk.be.un_770
  0x682b01a4, 0x29002804, 0x08000a0d, 0x24000120,   // en.vi.ig_433 sw.sl.un_320  mk.uk.un_540 iw.yi.un_850
  0x010752ee, 0x03003f19, 0x08021305, 0x08000214,   // ha.it.en_422 af.nl.un_750  et.da.no_333 da.no.un_660
  0x68251107, 0x53002004, 0x05000202, 0x11006404,   // ro.eu.ig_432 sq.ht.un_320  da.fr.un_220 lg.ro.un_320
  // [0370]
  0x08022da9, 0x1c090dec, 0x06003f04, 0x130455ee,   // sk.da.no_544 ne.hi.mr_644  af.de.un_320 rw.fi.et_422
  0x09001308, 0x04070a02, 0x0400070d, 0x0c000812,   // bh.hi.un_430 mk.bg.ru_222  bg.ru.un_540 no.sv.un_640
  0x06000113, 0x00001103, 0x0300050c, 0x17041004,   // en.de.un_650 ro.un.un_300  fr.nl.un_530 be.ru.sr_332
  0x2d090604, 0x28640502, 0x3f281307, 0x19002b09,   // de.pl.sk_332 fr.lg.sw_222  et.sw.af_432 vi.gl.un_440
  // [0380]
  0x20001604, 0x17070408, 0x4a00520d, 0x0c000813,   // hr.sq.un_320 ru.bg.sr_443  ha.yo.un_540 no.sv.un_650
  0x0d091305, 0x55005205, 0x551201ee, 0x0c000a0e,   // bh.hi.ne_333 ha.rw.un_330  en.hu.rw_422 pt.sv.un_550
  0x08010502, 0x13091caf, 0x31001b1a, 0x12211813,   // fr.en.no_222 mr.hi.bh_655  tr.az.un_760 ar.fa.ur_665
  0x112916a4, 0x1a004a08, 0x255255a7, 0x321716a4,   // hr.sl.ro_433 yo.tl.un_430  rw.ha.eu_532 hr.sr.bs_433
  // [0390]
  0x190a53a0, 0x01003504, 0x18120107, 0x0407110c,   // ht.pt.gl_322 zu.en.un_320  en.hu.ga_432 ro.bg.ru_543
  0x062a0411, 0x643f035a, 0x00002103, 0x00000e0a,   // fi.mt.de_653 nl.af.lg_553  jw.un.un_300 is.un.un_500
  0x00002801, 0x1c121b07, 0x0d0913ee, 0x1a00130e,   // sw.un.un_200 tr.hu.id_432  bh.hi.ne_422 et.tl.un_550
  0x0f0127a0, 0x04001012, 0x12002d0c, 0x6b000c05,   // gd.en.lv_322 be.ru.un_640  sk.hu.un_530 sv.ceb.un_330
  // [03a0]
  0x00000f03, 0x190b12a0, 0x1f002808, 0x0e000404,   // lv.un.un_300 hu.es.gl_322  sw.cy.un_430 fi.is.un_320
  0x040701a0, 0x20001004, 0x00001b15, 0x17000a07,   // en.it.fi_322 lt.sq.un_320  tr.un.un_700 mk.sr.un_420
  0x1c000d07, 0x18002112, 0x29001602, 0x01005502,   // ne.mr.un_420 fa.ar.un_640  hr.sl.un_220 rw.en.un_220
  0x01001f02, 0x00000c03, 0x09001c13, 0x00000906,   // cy.en.un_220 sv.un.un_300  mr.hi.un_650 pl.un.un_400
  // [03b0]
  0x1c0913a4, 0x23000808, 0x170a0404, 0x3f000304,   // bh.hi.mr_433 no.ca.un_430  ru.mk.sr_332 nl.af.un_320
  0x52002905, 0x0e005207, 0x121a6b12, 0x231304ad,   // sl.ha.un_330 ha.is.un_420  ceb.tl.hu_654 fi.et.ca_643
  0x05006e07, 0x16290d07, 0x28001308, 0x19000a0c,   // hmn.fr.un_420 cs.sl.hr_432  et.sw.un_430 pt.gl.un_530
  0x00005315, 0x24000119, 0x182112a9, 0x10001704,   // ht.un.un_700 iw.yi.un_750  ur.fa.ar_544 sr.lt.un_320
  // [03c0]
  0x52122aa4, 0x23190b05, 0x290913a0, 0x3b003f05,   // mt.hu.ha_433 es.gl.ca_333  et.pl.sl_322 af.so.un_330
  0x16291007, 0x0f321704, 0x170a0709, 0x3216170c,   // lt.sl.hr_432 sr.bs.lv_332  bg.mk.sr_444 sr.hr.bs_543
  0x0a100405, 0x09000f08, 0x23001f0e, 0x28003513,   // ru.be.mk_333 lv.pl.un_430  cy.ca.un_550 zu.sw.un_650
  0x2a00121a, 0x351e28a4, 0x32160914, 0x08021fa9,   // hu.mt.un_760 sw.ms.zu_433  pl.hr.bs_666 cy.da.no_544
  // [03d0]
  0x04001009, 0x290d2d0c, 0x25001902, 0x0a000104,   // be.ru.un_440 sk.cs.sl_543  gl.eu.un_220 en.pt.un_320
  0x0000011c, 0x070a11ee, 0x070811ee, 0x68253ba4,   // en.un.un_800 ro.mk.bg_422  ro.uk.bg_422 so.eu.ig_433
  0x13040e04, 0x21130405, 0x071104a4, 0x0c000809,   // is.fi.et_332 fi.et.jw_333  ru.ro.bg_433 no.sv.un_440
  0x0a00070d, 0x3f033ba0, 0x3229160c, 0x3f3b29ee,   // bg.mk.un_540 so.nl.af_322  hr.sl.bs_543 sl.so.af_422
  // [03e0]
  0x35004a04, 0x0a040705, 0x0000530f, 0x071008ec,   // yo.zu.un_320 bg.ru.mk_333  ht.un.un_600 uk.be.bg_644
  0x32162aee, 0x12080204, 0x11073ba4, 0x07041705,   // mt.hr.bs_422 da.no.hu_332  so.it.ro_433 sr.ru.bg_333
  0x08005218, 0x00000b06, 0x3f535213, 0x041b0e07,   // ha.no.un_740 es.un.un_400  ha.ht.af_665 is.tr.fi_432
  0x212813ad, 0x68643b55, 0x13321607, 0x0c0353ee,   // et.sw.jw_643 so.lg.ig_442  hr.bs.et_432 ht.nl.sv_422
  // [03f0]
  0x6b351aad, 0x17000f13, 0x35002905, 0x35005302,   // tl.zu.ceb_643 lv.sr.un_650  sl.zu.un_330 ht.zu.un_220
  0x0d130955, 0x21121860, 0x2d0d1b12, 0x11080408,   // hi.bh.ne_442 ar.ur.fa_664  tr.cs.sk_654 ru.uk.ro_443
  0x1a1b03a0, 0x1711040c, 0x27231a07, 0x28001013,   // nl.tr.tl_322 ru.ro.sr_543  tl.ca.gd_432 lt.sw.un_650
  0x13000912, 0x0a002302, 0x07000a04, 0x08000e0c,   // hi.bh.un_640 ca.pt.un_220  pt.it.un_320 is.no.un_530

  // [0400]
  0x18000d1a, 0x08101712, 0x00000c01, 0x070a1002,   // cs.ga.un_760 sr.be.uk_654  sv.un.un_200 be.mk.bg_222
  0x07101107, 0x31003b04, 0x3f1f35ad, 0x0c080202,   // ro.be.bg_432 so.az.un_320  zu.cy.af_643 da.no.sv_222
  0x2d003202, 0x0a000413, 0x071711ee, 0x5355280d,   // bs.sk.un_220 ru.mk.un_650  ro.sr.bg_422 sw.rw.ht_554
  0x011805ee, 0x00006406, 0x55353baf, 0x35006809,   // fr.ga.en_422 lg.un.un_400  so.zu.rw_655 ig.zu.un_440
  // [0410]
  0x12000e09, 0x10000f0d, 0x0802200c, 0x092d0d02,   // is.hu.un_440 lv.lt.un_540  sq.da.no_543 cs.sk.pl_222
  0x00000606, 0x08000208, 0x200802ad, 0x080a1707,   // de.un.un_400 da.no.un_430  da.no.sq_643 sr.mk.uk_432
  0x28002102, 0x09000d08, 0x08170a05, 0x32161702,   // jw.sw.un_220 cs.pl.un_430  mk.sr.uk_333 sr.hr.bs_222
  0x28000e13, 0x31000505, 0x0d1c13ac, 0x0a190b5a,   // is.sw.un_650 fr.az.un_330  bh.mr.ne_632 es.gl.pt_553
  // [0420]
  0x1000290e, 0x0a0410ee, 0x2b00110d, 0x32001708,   // sl.lt.un_550 be.ru.mk_422  ro.vi.un_540 sr.bs.un_430
  0x643b31a0, 0x182112ad, 0x2000550d, 0x35001f19,   // az.so.lg_322 ur.fa.ar_643  rw.sq.un_540 cy.zu.un_750
  0x1c0913a0, 0x0a171108, 0x25121b11, 0x53005202,   // bh.hi.mr_322 ro.sr.mk_443  tr.hu.eu_653 ha.ht.un_220
  0x21001c02, 0x10000712, 0x17070a04, 0x091c0da9,   // id.jw.un_220 bg.be.un_640  mk.bg.sr_332 ne.mr.hi_544
  // [0430]
  0x1c000d09, 0x19000307, 0x1a006b0b, 0x13281fee,   // ne.mr.un_440 nl.gl.un_420  ceb.tl.un_520 cy.sw.et_422
  0x070a0804, 0x0000311c, 0x162032ee, 0x070a1155,   // uk.mk.bg_332 az.un.un_800  bs.sq.hr_422 ro.mk.bg_442
  0x06000119, 0x1f001108, 0x28005513, 0x28080ead,   // en.de.un_750 ro.cy.un_430  rw.sw.un_650 is.no.sw_643
  0x04081012, 0x19000a0b, 0x00000a01, 0x06100e04,   // be.uk.ru_654 pt.gl.un_520  pt.un.un_200 is.lt.de_332
  // [0440]
  0x09002d12, 0x0400110d, 0x10001107, 0x122d0d0d,   // sk.pl.un_640 ro.ru.un_540  ro.be.un_420 cs.sk.hu_554
  0x09000d13, 0x0a00071b, 0x21181212, 0x032705ee,   // ne.hi.un_650 bg.mk.un_770  ur.ar.fa_654 fr.gd.nl_422
  0x040807ee, 0x0000550a, 0x0000071c, 0x125553a7,   // bg.uk.ru_422 rw.un.un_500  bg.un.un_800 ht.rw.hu_532
  0x040708a4, 0x08002719, 0x1c002104, 0x211e2005,   // uk.bg.ru_433 gd.no.un_750  jw.id.un_320 sq.ms.jw_333
  // [0450]
  0x1e001c04, 0x32001605, 0x52001107, 0x13090804,   // id.ms.un_320 hr.bs.un_330  ro.ha.un_420 no.pl.et_332
  0x020a100d, 0x0c00060c, 0x1c201602, 0x07000a14,   // lt.pt.da_554 de.sv.un_530  hr.sq.id_222 mk.bg.un_660
  0x32001607, 0x00000901, 0x52000113, 0x3b1b1f04,   // hr.bs.un_420 hi.un.un_200  en.ha.un_650 cy.tr.so_332
  0x091f2d04, 0x32092d04, 0x070417ad, 0x25003b04,   // sk.cy.pl_332 sk.pl.bs_332  sr.ru.bg_643 so.eu.un_320
  // [0460]
  0x0c040805, 0x3f070104, 0x6b1c1aec, 0x100a07ec,   // no.fi.sv_333 en.it.af_332  tl.id.ceb_644 bg.mk.be_644
  0x1110010c, 0x28536ba0, 0x080410a0, 0x192d0deb,   // en.lt.ro_543 ceb.ht.sw_322  be.ru.uk_322 cs.sk.gl_662
  0x2d321602, 0x1c002102, 0x19000b07, 0x20002802,   // hr.bs.sk_222 jw.id.un_220  es.gl.un_420 sw.sq.un_220
  0x04001708, 0x1c000912, 0x21100f12, 0x53006b12,   // sr.ru.un_430 hi.mr.un_640  lv.lt.jw_654 ceb.ht.un_640
  // [0470]
  0x253f4aee, 0x1c00130d, 0x53002104, 0x070a0408,   // yo.af.eu_422 bh.mr.un_540  jw.ht.un_320 ru.mk.bg_443
  0x1300091a, 0x3f1220a4, 0x04171104, 0x080a07a4,   // hi.bh.un_760 sq.hu.af_433  ro.sr.ru_332 bg.mk.uk_433
  0x1c0d1311, 0x03322aee, 0x6b006e0d, 0x11640408,   // bh.ne.mr_653 mt.bs.nl_422  hmn.ceb.un_540 fi.lg.ro_443
  0x1b0435ad, 0x110a0714, 0x172916a0, 0x07000a13,   // zu.fi.tr_643 bg.mk.ro_666  hr.sl.sr_322 mk.bg.un_650
  // [0480]
  0x0a001904, 0x0e1013a0, 0x042513a0, 0x0e00190c,   // gl.pt.un_320 et.lt.is_322  et.eu.fi_322 gl.is.un_530
  0x06000305, 0x0d122d0c, 0x16000d04, 0x2d002904,   // nl.de.un_330 sk.hu.cs_543  cs.hr.un_320 sl.sk.un_320
  0x3500110d, 0x016b04ad, 0x100806a0, 0x09001c07,   // ro.zu.un_540 fi.ceb.en_643  de.no.lt_322 mr.hi.un_420
  0x3b002904, 0x271118af, 0x0000190f, 0x071117a4,   // sl.so.un_320 ga.ro.gd_655  gl.un.un_600 sr.ro.bg_433
  // [0490]
  0x0f0806a6, 0x35645508, 0x4a002a21, 0x3b1935ee,   // de.no.lv_521 rw.lg.zu_443  mt.yo.un_860 zu.gl.so_422
  0x29171605, 0x17070a13, 0x352825ad, 0x030c0804,   // hr.sr.sl_333 mk.bg.sr_665  eu.sw.zu_643 no.sv.nl_332
  0x00006b03, 0x1f002313, 0x23190b02, 0x21001218,   // ceb.un.un_300 ca.cy.un_650  es.gl.ca_222 ur.fa.un_740
  0x52001a04, 0x1c0d1305, 0x64356804, 0x2118120c,   // tl.ha.un_320 bh.ne.mr_333  ig.zu.lg_332 ur.ar.fa_543
  // [04a0]
  0x0c000808, 0x01272902, 0x04000e13, 0x08002102,   // no.sv.un_430 sl.gd.en_222  is.fi.un_650 jw.no.un_220
  0x182112ec, 0x06086e07, 0x68050607, 0x00001e0a,   // ur.fa.ar_644 hmn.no.de_432  de.fr.ig_432 ms.un.un_500
  0x1a00041b, 0x03080204, 0x0c000204, 0x2d032802,   // fi.tl.un_770 da.no.nl_332  da.sv.un_320 sw.nl.sk_222
  0x4a641b04, 0x271825ee, 0x0d09130e, 0x0c0106a4,   // tr.lg.yo_332 eu.ga.gd_422  bh.hi.ne_555 de.en.sv_433
  // [04b0]
  0x09291807, 0x08001705, 0x1c001311, 0x23190b55,   // ga.sl.pl_432 sr.no.un_330  bh.mr.un_630 es.gl.ca_442
  0x0d1c0913, 0x1c006402, 0x170a0704, 0x1c043bee,   // hi.mr.ne_665 lg.id.un_220  bg.mk.sr_332 so.fi.id_422
  0x3f000212, 0x3b006b0c, 0x12290cee, 0x534a1aa0,   // da.af.un_640 ceb.so.un_530  sv.sl.hu_422 tl.yo.ht_322
  0x06000a08, 0x13043b04, 0x53081b07, 0x552305ad,   // pt.de.un_430 so.fi.et_332  tr.no.ht_432 fr.ca.rw_643
  // [04c0]
  0x13001108, 0x03005304, 0x10000304, 0x0a001723,   // ro.et.un_430 ht.nl.un_320  nl.lt.un_320 sr.mk.un_880
  0x040a17a0, 0x08001012, 0x32002907, 0x0d091c11,   // sr.mk.ru_322 be.uk.un_640  sl.bs.un_420 mr.hi.ne_653
  0x3b00520c, 0x00000c06, 0x0c080260, 0x0c3f03a0,   // ha.so.un_530 sv.un.un_400  da.no.sv_664 nl.af.sv_322
  0x18001213, 0x05530308, 0x080407af, 0x08020c0c,   // ur.ar.un_650 nl.ht.fr_443  bg.ru.uk_655 sv.da.no_543
  // [04d0]
  0x1c0d0913, 0x25312aad, 0x3b3f0305, 0x00000c0f,   // hi.ne.mr_665 mt.az.eu_643  nl.af.so_333 sv.un.un_600
  0x04133ba7, 0x07001702, 0x171632ee, 0x645368a7,   // so.et.fi_532 sr.bg.un_220  bs.hr.sr_422 ig.ht.lg_532
  0x091c0dec, 0x23071b0c, 0x3500550d, 0x64005508,   // ne.mr.hi_644 tr.it.ca_543  rw.zu.un_540 rw.lg.un_430
  0x12000e0c, 0x11131bad, 0x071710a4, 0x08000413,   // is.hu.un_530 tr.et.ro_643  be.sr.bg_433 ru.uk.un_650
  // [04e0]
  0x24000112, 0x3f00030e, 0x05002304, 0x0d1c09ec,   // iw.yi.un_640 nl.af.un_550  ca.fr.un_320 hi.mr.ne_644
  0x2d001808, 0x0c005302, 0x0c00081a, 0x27001804,   // ga.sk.un_430 ht.sv.un_220  no.sv.un_760 ga.gd.un_320
  0x21001213, 0x041007a4, 0x183107a0, 0x0d001c13,   // ur.fa.un_650 bg.be.ru_433  it.az.ga_322 mr.ne.un_650
  0x20000808, 0x12002d04, 0x17000a22, 0x1c001307,   // no.sq.un_430 sk.hu.un_320  mk.sr.un_870 bh.mr.un_420
  // [04f0]
  0x6e000e1a, 0x3f000307, 0x0b001907, 0x1b04315a,   // is.hmn.un_760 nl.af.un_420  gl.es.un_420 az.fi.tr_553
  0x64193ba0, 0x00000806, 0x2000230b, 0x52002904,   // so.gl.lg_322 no.un.un_400  ca.sq.un_520 sl.ha.un_320
  0x2700181a, 0x321617a4, 0x3f355505, 0x1c0d090e,   // ga.gd.un_760 sr.hr.bs_433  rw.zu.af_333 hi.ne.mr_555
  0x21001214, 0x00002815, 0x6e6b0707, 0x0000271c,   // ur.fa.un_660 sw.un.un_700  it.ceb.hmn_432 gd.un.un_800
  // [0500]
  0x4a6b6804, 0x06080cad, 0x6400551b, 0x2500070d,   // ig.ceb.yo_332 sv.no.de_643  rw.lg.un_770 it.eu.un_540
  0x6b1b3112, 0x170804a4, 0x072a01a4, 0x03132507,   // az.tr.ceb_654 ru.uk.sr_433  en.mt.it_433 eu.et.nl_432
  0x0e060c0b, 0x1e1c6409, 0x55356404, 0x1c091302,   // sv.de.is_542 lg.id.ms_444  lg.zu.rw_332 bh.hi.mr_222
  0x1b00310d, 0x21001112, 0x19000a09, 0x3210160d,   // az.tr.un_540 ro.jw.un_640  pt.gl.un_440 hr.lt.bs_554
  // [0510]
  0x27001813, 0x12000704, 0x122d0d09, 0x1e006404,   // ga.gd.un_650 it.hu.un_320  cs.sk.hu_444 lg.ms.un_320
  0x32001609, 0x64213507, 0x03006e07, 0x52000808,   // hr.bs.un_440 zu.jw.lg_432  hmn.nl.un_420 no.ha.un_430
  0x08002d04, 0x0f0e10a0, 0x08032502, 0x12182113,   // sk.no.un_320 lt.is.lv_322  eu.nl.no_222 fa.ar.ur_665
  0x531c01a6, 0x3200080c, 0x12001809, 0x0c080204,   // en.id.ht_521 no.bs.un_530  ga.hu.un_440 da.no.sv_332
  // [0520]
  0x07001012, 0x04000c04, 0x081710a0, 0x04001008,   // be.bg.un_640 sv.fi.un_320  be.sr.uk_322 be.ru.un_430
  0x3f6b0107, 0x080407ec, 0x31001b0e, 0x180627ac,   // en.ceb.af_432 bg.ru.uk_644  tr.az.un_550 gd.de.ga_632
  0x211c23a9, 0x0e001809, 0x0e000608, 0x041b31ad,   // ca.id.jw_544 ga.is.un_440  de.is.un_430 az.tr.fi_643
  0x28182702, 0x08021baf, 0x4a311b08, 0x04001c02,   // gd.ga.sw_222 tr.da.no_655  tr.az.yo_443 id.fi.un_220
  // [0530]
  0x31001b19, 0x2d000d13, 0x2513110c, 0x5200090c,   // tr.az.un_750 cs.sk.un_650  ro.et.eu_543 pl.ha.un_530
  0x12002108, 0x0e000804, 0x55006413, 0x21001a04,   // jw.hu.un_430 no.is.un_320  lg.rw.un_650 tl.jw.un_320
  0x0f112d0c, 0x32001614, 0x04081705, 0x291602a0,   // sk.ro.lv_543 hr.bs.un_660  sr.uk.ru_333 da.hr.sl_322
  0x01060c0c, 0x08000302, 0x10000f04, 0x0c1812ee,   // sv.de.en_543 nl.no.un_220  lv.lt.un_320 hu.ga.sv_422
  // [0540]
  0x0d2d3507, 0x10070aa4, 0x0300040d, 0x531f64ac,   // zu.sk.cs_432 mk.bg.be_433  fi.nl.un_540 lg.cy.ht_632
  0x06001309, 0x00002506, 0x52006e07, 0x04071704,   // et.de.un_440 eu.un.un_400  hmn.ha.un_420 sr.bg.ru_332
  0x121b09ec, 0x1c001308, 0x00001315, 0x033f0808,   // pl.tr.hu_644 bh.mr.un_430  bh.un.un_700 no.af.nl_443
  0x21001819, 0x2b0405a7, 0x3f02080c, 0x033f0107,   // ar.fa.un_750 fr.fi.vi_532  no.da.af_543 en.af.nl_432
  // [0550]
  0x252006a0, 0x31001b04, 0x110d1211, 0x312a1fad,   // de.sq.eu_322 tr.az.un_320  hu.cs.ro_653 cy.mt.az_643
  0x031a64a4, 0x05070160, 0x00002b01, 0x6b042511,   // lg.tl.nl_433 en.it.fr_664  vi.un.un_200 eu.fi.ceb_653
  0x0704110b, 0x23190b04, 0x27002513, 0x551035a0,   // ro.ru.bg_542 es.gl.ca_332  eu.gd.un_650 zu.lt.rw_322
  0x1f020807, 0x00004a1c, 0x2800640d, 0x13001c18,   // no.da.cy_432 yo.un.un_800  lg.sw.un_540 mr.bh.un_740
  // [0560]
  0x0b002304, 0x0000310a, 0x183f0107, 0x17040aa0,   // ca.es.un_320 az.un.un_500  en.af.ga_432 mk.ru.sr_322
  0x13090da4, 0x0000531c, 0x03000212, 0x21001208,   // ne.hi.bh_433 ht.un.un_800  da.nl.un_640 ur.fa.un_430
  0x64005505, 0x01550504, 0x270306ee, 0x1c111ea7,   // rw.lg.un_330 fr.rw.en_332  de.nl.gd_422 ms.ro.id_532
  0x0900130d, 0x0c060807, 0x2d000d05, 0x0e001a04,   // bh.hi.un_540 no.de.sv_432  cs.sk.un_330 tl.is.un_320
  // [0570]
  0x32001702, 0x0e000b02, 0x03063fa4, 0x00003b01,   // sr.bs.un_220 es.is.un_220  af.de.nl_433 so.un.un_200
  0x0d002d0d, 0x09001c08, 0x09000307, 0x0d112304,   // sk.cs.un_540 mr.hi.un_430  nl.pl.un_420 ca.ro.cs_332
  0x1c0d09af, 0x170811ee, 0x21001202, 0x3f0301a0,   // hi.ne.mr_655 ro.uk.sr_422  ur.fa.un_220 en.nl.af_322
  0x31253bee, 0x1000111a, 0x040a07a0, 0x55001f07,   // so.eu.az_422 ro.be.un_760  bg.mk.ru_322 cy.rw.un_420
  // [0580]
  0x00002306, 0x0c0e0fee, 0x126435a0, 0x07001119,   // ca.un.un_400 lv.is.sv_422  zu.lg.hu_322 ro.bg.un_750
  0x04131104, 0x0f230507, 0x0200080d, 0x080704ad,   // ro.et.fi_332 fr.ca.lv_432  no.da.un_540 ru.bg.uk_643
  0x08020ca4, 0x0800100d, 0x0200081a, 0x1202080c,   // sv.da.no_433 be.uk.un_540  no.da.un_760 no.da.hu_543
  0x093235ee, 0x641b35a0, 0x0d00130d, 0x17040707,   // zu.bs.pl_422 zu.tr.lg_322  bh.ne.un_540 bg.ru.sr_432
  // [0590]
  0x32001704, 0x17002004, 0x644a1055, 0x352a31ee,   // sr.bs.un_320 sq.sr.un_320  lt.yo.lg_442 az.mt.zu_422
  0x080410ac, 0x060e0804, 0x122a0405, 0x082a0e0c,   // be.ru.uk_632 no.is.de_332  fi.mt.hu_333 is.mt.no_543
  0x68201113, 0x3b002119, 0x1b003119, 0x53000704,   // ro.sq.ig_665 jw.so.un_750  az.tr.un_750 it.ht.un_320
  0x1c000d18, 0x00001003, 0x08060ea4, 0x063f03ac,   // ne.mr.un_740 be.un.un_300  is.de.no_433 nl.af.de_632
  // [05a0]
  0x2d0d1702, 0x08000402, 0x25005307, 0x091c0d0d,   // sr.cs.sk_222 ru.uk.un_220  ht.eu.un_420 ne.mr.hi_554
  0x17070a12, 0x3f552104, 0x170a0713, 0x18002113,   // mk.bg.sr_654 jw.rw.af_332  bg.mk.sr_665 fa.ar.un_650
  0x0d0913a0, 0x23110707, 0x27033fa0, 0x27002309,   // bh.hi.ne_322 it.ro.ca_432  af.nl.gd_322 ca.gd.un_440
  0x0804170c, 0x68100107, 0x27191107, 0x0700110d,   // sr.ru.uk_543 en.lt.ig_432  ro.gl.gd_432 ro.bg.un_540
  // [05b0]
  0x01000c04, 0x19000b08, 0x1c002108, 0x0f002305,   // sv.en.un_320 es.gl.un_430  jw.id.un_430 ca.lv.un_330
  0x0800040e, 0x170f0707, 0x1b003513, 0x3f682011,   // ru.uk.un_550 it.lv.sr_432  zu.tr.un_650 sq.ig.af_653
  0x1e312a12, 0x1c1309ec, 0x1e001c0d, 0x00001a0f,   // mt.az.ms_654 hi.bh.mr_644  id.ms.un_540 tl.un.un_600
  0x64003513, 0x04080aa4, 0x07000f08, 0x08041004,   // zu.lg.un_650 mk.uk.ru_433  lv.it.un_430 be.ru.uk_332
  // [05c0]
  0x2000250c, 0x3b0e2aad, 0x2a190a04, 0x231b3107,   // eu.sq.un_530 mt.is.so_643  pt.gl.mt_332 az.tr.ca_432
  0x1c002504, 0x190b0a04, 0x20001013, 0x32161709,   // eu.id.un_320 pt.es.gl_332  lt.sq.un_650 sr.hr.bs_444
  0x08171104, 0x1a00010b, 0x0000120a, 0x1c00090c,   // ro.sr.uk_332 en.tl.un_520  hu.un.un_500 hi.mr.un_530
  0x52072a07, 0x1b003204, 0x08020c05, 0x0f000108,   // mt.it.ha_432 bs.tr.un_320  sv.da.no_333 en.lv.un_430
  // [05d0]
  0x082901a0, 0x00003b03, 0x2100121b, 0x12002114,   // en.sl.no_322 so.un.un_300  ur.fa.un_770 fa.ur.un_660
  0x2a000704, 0x1c0d09a4, 0x09042007, 0x070a10a7,   // it.mt.un_320 hi.ne.mr_433  sq.fi.pl_432 be.mk.bg_532
  0x045325ac, 0x09000108, 0x09001304, 0x0d1c13ee,   // eu.ht.fi_632 en.pl.un_430  bh.hi.un_320 bh.mr.ne_422
  0x0000211c, 0x00001024, 0x09000d19, 0x6b000213,   // jw.un.un_800 be.un.un_900  ne.hi.un_750 da.ceb.un_650
  // [05e0]
  0x071711ec, 0x25000113, 0x6b003b04, 0x0a071755,   // ro.sr.bg_644 en.eu.un_650  so.ceb.un_320 sr.bg.mk_442
  0x070a1104, 0x2d000d0d, 0x170a0808, 0x00000e06,   // ro.mk.bg_332 cs.sk.un_540  uk.mk.sr_443 is.un.un_400
  0x23001b12, 0x0a170812, 0x020e0812, 0x31006404,   // tr.ca.un_640 uk.sr.mk_654  no.is.da_654 lg.az.un_320
  0x53001f04, 0x0700110e, 0x1200050c, 0x0000270f,   // cy.ht.un_320 ro.bg.un_550  fr.hu.un_530 gd.un.un_600
  // [05f0]
  0x1f0511ad, 0x10000414, 0x06130807, 0x2d001107,   // ro.fr.cy_643 ru.be.un_660  no.et.de_432 ro.sk.un_420
  0x190b0a05, 0x0000070a, 0x12000508, 0x12190e05,   // pt.es.gl_333 it.un.un_500  fr.hu.un_430 is.gl.hu_333
  0x0d120960, 0x3b0413a9, 0x0e641f04, 0x2d0d0ca0,   // pl.hu.cs_664 et.fi.so_544  cy.lg.is_332 sv.cs.sk_322
  0x17002a04, 0x1f3b0808, 0x133b03ee, 0x352855ad,   // mt.sr.un_320 no.so.cy_443  nl.so.et_422 rw.sw.zu_643
  // [0600]
  0x00000615, 0x10006b02, 0x35002814, 0x070a10a4,   // de.un.un_700 ceb.lt.un_220  sw.zu.un_660 be.mk.bg_433
  0x040a07a4, 0x133b64a0, 0x35285509, 0x08001712,   // bg.mk.ru_433 lg.so.et_322  rw.sw.zu_444 sr.uk.un_640
  0x3b003108, 0x0a041702, 0x2d120d0e, 0x07230a04,   // az.so.un_430 sr.ru.mk_222  cs.hu.sk_555 pt.ca.it_332
  0x190523a4, 0x283555ec, 0x08041002, 0x29001604,   // ca.fr.gl_433 rw.zu.sw_644  be.ru.uk_222 hr.sl.un_320
  // [0610]
  0x01181302, 0x00001b01, 0x13006e09, 0x1c0811a0,   // et.ga.en_222 tr.un.un_200  hmn.et.un_440 ro.no.id_322
  0x040c2da0, 0x53132a07, 0x190b2309, 0x09001302,   // sk.sv.fi_322 mt.et.ht_432  ca.es.gl_444 bh.hi.un_220
  0x16002907, 0x0c005202, 0x0d0913a7, 0x04682513,   // sl.hr.un_420 ha.sv.un_220  bh.hi.ne_532 eu.ig.fi_665
  0x01352a07, 0x35095508, 0x21181208, 0x2000270d,   // mt.zu.en_432 rw.pl.zu_443  ur.ar.fa_443 gd.sq.un_540
  // [0620]
  0x31006b07, 0x08000c08, 0x201703ee, 0x07000414,   // ceb.az.un_420 sv.no.un_430  nl.sr.sq_422 ru.bg.un_660
  0x19000d13, 0x3f00031a, 0x2400011a, 0x042128a4,   // cs.gl.un_650 nl.af.un_760  iw.yi.un_760 sw.jw.fi_433
  0x211e29ee, 0x3f1118a0, 0x12001902, 0x020c08ee,   // sl.ms.jw_422 ga.ro.af_322  gl.hu.un_220 no.sv.da_422
  0x1a4a5504, 0x190b31a0, 0x09000707, 0x25232a04,   // rw.yo.tl_332 az.es.gl_322  it.pl.un_420 mt.ca.eu_332
  // [0630]
  0x0f003202, 0x08001304, 0x0d091302, 0x31002a0c,   // bs.lv.un_220 et.no.un_320  bh.hi.ne_222 mt.az.un_530
  0x52000704, 0x2a2920a7, 0x10070812, 0x3f040312,   // it.ha.un_320 sq.sl.mt_532  uk.bg.be_654 nl.fi.af_654
  0x04070805, 0x00003206, 0x231801ee, 0x01000509,   // uk.bg.ru_333 bs.un.un_400  en.ga.ca_422 fr.en.un_440
  0x0d1c09a4, 0x091c2104, 0x080231ee, 0x110a07a4,   // hi.mr.ne_433 jw.id.pl_332  az.da.no_422 bg.mk.ro_433
  // [0640]
  0x04070a07, 0x31033fa0, 0x190b01a4, 0x11000707,   // mk.bg.ru_432 af.nl.az_322  en.es.gl_433 it.ro.un_420
  0x060405a6, 0x10000804, 0x12002119, 0x0c040107,   // fr.fi.de_521 uk.be.un_320  fa.ur.un_750 en.fi.sv_432
  0x19052107, 0x052301a4, 0x18006b09, 0x08020c02,   // jw.fr.gl_432 en.ca.fr_433  ceb.ga.un_440 sv.da.no_222
  0x12002104, 0x13006e0c, 0x3f006e0d, 0x0311085a,   // jw.hu.un_320 hmn.et.un_530  hmn.af.un_540 no.ro.nl_553
  // [0650]
  0x64682160, 0x07040805, 0x17070a0e, 0x04131a04,   // jw.ig.lg_664 uk.ru.bg_333  mk.bg.sr_555 tl.et.fi_332
  0x00001706, 0x08020ca0, 0x171604ee, 0x08000714,   // sr.un.un_400 sv.da.no_322  fi.hr.sr_422 bg.uk.un_660
  0x1b00110c, 0x190a050c, 0x092d0d09, 0x21522804,   // ro.tr.un_530 fr.pt.gl_543  cs.sk.pl_444 sw.ha.jw_332
  0x1e1c31a0, 0x64133bac, 0x17070aa0, 0x100a07a0,   // az.id.ms_322 so.et.lg_632  mk.bg.sr_322 bg.mk.be_322
  // [0660]
  0x08041008, 0x080a17af, 0x040a07a9, 0x0c000108,   // be.ru.uk_443 sr.mk.uk_655  bg.mk.ru_544 en.sv.un_430
  0x283152a0, 0x532023ad, 0x2a5325ee, 0x68000813,   // ha.az.sw_322 ca.sq.ht_643  eu.ht.mt_422 no.ig.un_650
  0x2a00250c, 0x0000050f, 0x18000104, 0x4a005204,   // eu.mt.un_530 fr.un.un_600  en.ga.un_320 ha.yo.un_320
  0x12190b08, 0x11070a05, 0x23000e0e, 0x2d0d01a4,   // es.gl.hu_443 mk.bg.ro_333  is.ca.un_550 en.cs.sk_433
  // [0670]
  0x0a070404, 0x2d001812, 0x52002104, 0x08000c0c,   // ru.bg.mk_332 ga.sk.un_640  jw.ha.un_320 sv.no.un_530
  0x23000b02, 0x10081707, 0x1b003114, 0x25040804,   // es.ca.un_220 sr.uk.be_432  az.tr.un_660 no.fi.eu_332
  0x130d1c12, 0x0c005304, 0x643b2a07, 0x070411ad,   // mr.ne.bh_654 ht.sv.un_320  mt.so.lg_432 ro.ru.bg_643
  0x01002307, 0x16002d04, 0x281610ee, 0x11002a0c,   // ca.en.un_420 sk.hr.un_320  lt.hr.sw_422 mt.ro.un_530
  // [0680]
  0x5228550c, 0x0700100c, 0x32005502, 0x0f100807,   // rw.sw.ha_543 be.bg.un_530  rw.bs.un_220 no.lt.lv_432
  0x211812af, 0x1c121e04, 0x12000e07, 0x07041704,   // ur.ar.fa_655 ms.hu.id_332  is.hu.un_420 sr.ru.bg_332
  0x16000b02, 0x0b0a2aa0, 0x00002715, 0x00001201,   // es.hr.un_220 mt.pt.es_322  gd.un.un_700 ur.un.un_200
  0x3f0b01ad, 0x06002909, 0x03003f0c, 0x13000911,   // en.es.af_643 sl.de.un_440  af.nl.un_530 hi.bh.un_630
  // [0690]
  0x3f6b28a0, 0x531c05ad, 0x4a001a02, 0x27001a04,   // sw.ceb.af_322 fr.id.ht_643  tl.yo.un_220 tl.gd.un_320
  0x5300050c, 0x20000702, 0x1b003112, 0x0e0c1304,   // fr.ht.un_530 it.sq.un_220  az.tr.un_640 et.sv.is_332
  0x08000414, 0x181221a9, 0x00000e03, 0x03253fa9,   // ru.uk.un_660 fa.ur.ar_544  is.un.un_300 af.eu.nl_544
  0x06000108, 0x29001f07, 0x1b0608a0, 0x03002302,   // en.de.un_430 cy.sl.un_420  no.de.tr_322 ca.nl.un_220
  // [06a0]
  0x06001f08, 0x21080204, 0x25001804, 0x251f0504,   // cy.de.un_430 da.no.jw_332  ga.eu.un_320 fr.cy.eu_332
  0x10001604, 0x3b2d0d04, 0x00002006, 0x080c0e13,   // hr.lt.un_320 cs.sk.so_332  sq.un.un_400 is.sv.no_665
  0x35046b04, 0x02000808, 0x23000f08, 0x1700290d,   // ceb.fi.zu_332 no.da.un_430  lv.ca.un_430 sl.sr.un_540
  0x110704a4, 0x1f03020c, 0x1300110c, 0x2b000a04,   // ru.bg.ro_433 da.nl.cy_543  ro.et.un_530 pt.vi.un_320
  // [06b0]
  0x1800120d, 0x00001715, 0x110a1007, 0x3f002b04,   // ur.ar.un_540 sr.un.un_700  lt.pt.ro_432 vi.af.un_320
  0x06550111, 0x182b0aa0, 0x05003107, 0x2d002908,   // en.rw.de_653 pt.vi.ga_322  az.fr.un_420 sl.sk.un_430
  0x013b2d07, 0x2a003112, 0x3f0301a9, 0x2821350d,   // sk.so.en_432 az.mt.un_640  en.nl.af_544 zu.jw.sw_554
  0x00000803, 0x1000090e, 0x08030fa0, 0x06001f04,   // no.un.un_300 pl.lt.un_550  lv.nl.no_322 cy.de.un_320
  // [06c0]
  0x3f0610ee, 0x090d1c60, 0x28005502, 0x0e520804,   // lt.de.af_422 mr.ne.hi_664  rw.sw.un_220 no.ha.is_332
  0x2d0d12a4, 0x0a1711ec, 0x64101f07, 0x320c0e07,   // hu.cs.sk_433 ro.sr.mk_644  cy.lt.lg_432 is.sv.bs_432
  0x1a006404, 0x07002a02, 0x091c1307, 0x1a0a350c,   // lg.tl.un_320 mt.it.un_220  bh.mr.hi_432 zu.pt.tl_543
  0x0f002502, 0x27182107, 0x4a002804, 0x55004a02,   // eu.lv.un_220 jw.ga.gd_432  sw.yo.un_320 yo.rw.un_220
  // [06d0]
  0x203207a0, 0x016b0604, 0x0408170e, 0x2700180d,   // it.bs.sq_322 de.ceb.en_332  sr.uk.ru_555 ga.gd.un_540
  0x1f3f64a0, 0x020c08a9, 0x13000d05, 0x040817af,   // lg.af.cy_322 no.sv.da_544  ne.bh.un_330 sr.uk.ru_655
  0x0804070d, 0x0b230107, 0x2800290e, 0x53002a07,   // bg.ru.uk_554 en.ca.es_432  sl.sw.un_550 mt.ht.un_420
  0x0a0407a4, 0x2000640c, 0x11271807, 0x0000520a,   // bg.ru.mk_433 lg.sq.un_530  ga.gd.ro_432 ha.un.un_500
  // [06e0]
  0x10001114, 0x6b3f08ee, 0x00003103, 0x12003f04,   // ro.be.un_660 no.af.ceb_422  az.un.un_300 af.hu.un_320
  0x17070a07, 0x1e006e0c, 0x16002007, 0x1f002504,   // mk.bg.sr_432 hmn.ms.un_530  sq.hr.un_420 eu.cy.un_320
  0x27113bee, 0x6e212b05, 0x2d006e07, 0x08000e13,   // so.ro.gd_422 vi.jw.hmn_333  hmn.sk.un_420 is.no.un_650
  0x170807ee, 0x0000230f, 0x1f000309, 0x06121bad,   // bg.uk.sr_422 ca.un.un_600  nl.cy.un_440 tr.hu.de_643
  // [06f0]
  0x32171602, 0x13001a04, 0x1f001c02, 0x28005504,   // hr.sr.bs_222 tl.et.un_320  id.cy.un_220 rw.sw.un_320
  0x3f1c2702, 0x1f001704, 0x31002011, 0x01200da6,   // gd.id.af_222 sr.cy.un_320  sq.az.un_630 cs.sq.en_521
  0x2d0d1bee, 0x0f001602, 0x2000080d, 0x13103ba9,   // tr.cs.sk_422 hr.lv.un_220  no.sq.un_540 so.lt.et_544
  0x091c0d09, 0x100408a9, 0x081004ad, 0x0d1c09ad,   // ne.mr.hi_444 uk.ru.be_544  ru.be.uk_643 hi.mr.ne_643
  // [0700]
  0x07080aee, 0x18001205, 0x29001105, 0x1a003b19,   // mk.uk.bg_422 ur.ar.un_330  ro.sl.un_330 so.tl.un_750
  0x1e000607, 0x13090dec, 0x13120613, 0x1c090daf,   // de.ms.un_420 ne.hi.bh_644  de.hu.et_665 ne.hi.mr_655
  0x071710a0, 0x2500110c, 0x21101ea0, 0x06110107,   // be.sr.bg_322 ro.eu.un_530  ms.lt.jw_322 en.ro.de_432
  0x2a2301a0, 0x06080204, 0x0500070e, 0x04091fa7,   // en.ca.mt_322 da.no.de_332  it.fr.un_550 cy.pl.fi_532
  // [0710]
  0x21203bec, 0x10001111, 0x283f5507, 0x03003f07,   // so.sq.jw_644 ro.be.un_630  rw.af.sw_432 af.nl.un_420
  0x19002307, 0x131c0908, 0x01001304, 0x08040a04,   // ca.gl.un_420 hi.mr.bh_443  et.en.un_320 mk.ru.uk_332
  0x08000e04, 0x04006b05, 0x1f311b08, 0x28011802,   // is.no.un_320 ceb.fi.un_330  tr.az.cy_443 ga.en.sw_222
  0x00006b15, 0x18002119, 0x35006e18, 0x08002104,   // ceb.un.un_700 fa.ar.un_750  hmn.zu.un_740 jw.no.un_320
  // [0720]
  0x6b6410ee, 0x0800200e, 0x21292da0, 0x27000822,   // lt.lg.ceb_422 sq.no.un_550  sk.sl.jw_322 no.gd.un_870
  0x02003f02, 0x28535207, 0x06001b19, 0x23001012,   // af.da.un_220 ha.ht.sw_432  tr.de.un_750 lt.ca.un_640
  0x02001a07, 0x21002808, 0x1b2a0713, 0x6b001f12,   // tl.da.un_420 sw.jw.un_430  it.mt.tr_665 cy.ceb.un_640
  0x3b2128a0, 0x1c2352a6, 0x08041712, 0x10002302,   // sw.jw.so_322 ha.ca.id_521  sr.ru.uk_654 ca.lt.un_220
  // [0730]
  0x0c080209, 0x1f000a07, 0x16001007, 0x2100010d,   // da.no.sv_444 pt.cy.un_420  lt.hr.un_420 en.jw.un_540
  0x23190a13, 0x18002104, 0x3b000b02, 0x17060804,   // pt.gl.ca_665 jw.ga.un_320  es.so.un_220 no.de.sr_332
  0x21005204, 0x27002005, 0x20100fa6, 0x13000412,   // ha.jw.un_320 sq.gd.un_330  lv.lt.sq_521 fi.et.un_640
  0x08001002, 0x040c1fa4, 0x3b1e1304, 0x18002708,   // be.uk.un_220 cy.sv.fi_433  et.ms.so_332 gd.ga.un_430
  // [0740]
  0x10081705, 0x28030955, 0x09001c14, 0x13091cec,   // sr.uk.be_333 pl.nl.sw_442  mr.hi.un_660 mr.hi.bh_644
  0x05002107, 0x5268200b, 0x19000508, 0x0a1711af,   // jw.fr.un_420 sq.ig.ha_542  fr.gl.un_430 ro.sr.mk_655
  0x0a00171b, 0x041007a7, 0x04071007, 0x28000119,   // sr.mk.un_770 bg.be.ru_532  be.bg.ru_432 en.sw.un_750
  0x21190aa7, 0x0a00110c, 0x1c006407, 0x17080204,   // pt.gl.jw_532 ro.mk.un_530  lg.id.un_420 da.no.sr_332
  // [0750]
  0x2d0d09af, 0x1f080e04, 0x07080a02, 0x1800050c,   // pl.cs.sk_655 is.no.cy_332  mk.uk.bg_222 fr.ga.un_530
  0x08043fa0, 0x18002704, 0x53002107, 0x012d090d,   // af.fi.no_322 gd.ga.un_320  jw.ht.un_420 pl.sk.en_554
  0x1c090d12, 0x091c0d05, 0x03003f08, 0x0d000908,   // ne.hi.mr_654 ne.mr.hi_333  af.nl.un_430 hi.ne.un_430
  0x1b311213, 0x00003506, 0x10001f07, 0x29203202,   // hu.az.tr_665 zu.un.un_400  cy.lt.un_420 bs.sq.sl_222
  // [0760]
  0x170a0760, 0x0000081c, 0x01003507, 0x051c03ac,   // bg.mk.sr_664 uk.un.un_800  zu.en.un_420 nl.id.fr_632
  0x17000a05, 0x132507a0, 0x23001a07, 0x25000f19,   // mk.sr.un_330 it.eu.et_322  tl.ca.un_420 lv.eu.un_750
  0x0804100c, 0x53002113, 0x6b1a27ad, 0x04000714,   // be.ru.uk_543 jw.ht.un_650  gd.tl.ceb_643 bg.ru.un_660
  0x291b3107, 0x35000702, 0x060c0809, 0x6b000912,   // az.tr.sl_432 it.zu.un_220  no.sv.de_444 pl.ceb.un_640
  // [0770]
  0x0408070d, 0x132506ee, 0x07311b55, 0x11001719,   // bg.uk.ru_554 de.eu.et_422  tr.az.it_442 sr.ro.un_750
  0x1a006807, 0x1b2b05ec, 0x31001b0b, 0x080717a9,   // ig.tl.un_420 fr.vi.tr_644  tr.az.un_520 sr.bg.uk_544
  0x212701ee, 0x1a0e3b05, 0x130d09ac, 0x12250405,   // en.gd.jw_422 so.is.tl_333  hi.ne.bh_632 fi.eu.hu_333
  0x2100050e, 0x1f250805, 0x5300011a, 0x0c2521ee,   // fr.jw.un_550 no.eu.cy_333  en.ht.un_760 jw.eu.sv_422
  // [0780]
  0x08212008, 0x05190b02, 0x211e1c0d, 0x10272b07,   // sq.jw.no_443 es.gl.fr_222  id.ms.jw_554 vi.gd.lt_432
  0x3b07110e, 0x6b010404, 0x0c001f07, 0x1e003f12,   // ro.it.so_555 fi.en.ceb_332  cy.sv.un_420 af.ms.un_640
  0x32002007, 0x1c005304, 0x1200211a, 0x10040805,   // sq.bs.un_420 ht.id.un_320  fa.ur.un_760 uk.ru.be_333
  0x182768ad, 0x0912250c, 0x520a1fa9, 0x28356404,   // ig.gd.ga_643 eu.hu.pl_543  cy.pt.ha_544 lg.zu.sw_332
  // [0790]
  0x23052107, 0x3b000808, 0x28352004, 0x686455a4,   // jw.fr.ca_432 no.so.un_430  sq.zu.sw_332 rw.lg.ig_433
  0x0d1c1307, 0x16002905, 0x23071104, 0x171307ee,   // bh.mr.ne_432 sl.hr.un_330  ro.it.ca_332 it.et.sr_422
  0x08000705, 0x092d0d08, 0x17040705, 0x29001704,   // it.no.un_330 cs.sk.pl_443  bg.ru.sr_333 sr.sl.un_320
  0x070a0412, 0x12001818, 0x18002114, 0x12004a04,   // ru.mk.bg_654 ar.ur.un_740  fa.ar.un_660 yo.hu.un_320
  // [07a0]
  0x13000918, 0x1b2113ee, 0x2d000305, 0x04101260,   // hi.bh.un_740 et.jw.tr_422  nl.sk.un_330 hu.lt.fi_664
  0x0800020d, 0x13000d14, 0x0c002004, 0x29002d07,   // da.no.un_540 ne.bh.un_660  sq.sv.un_320 sk.sl.un_420
  0x1e1c21a0, 0x0d091c07, 0x1004080e, 0x0d092d0c,   // jw.id.ms_322 mr.hi.ne_432  uk.ru.be_555 sk.pl.cs_543
  0x27003511, 0x07001002, 0x10000605, 0x2d000204,   // zu.gd.un_630 be.bg.un_220  de.lt.un_330 da.sk.un_320
  // [07b0]
  0x00000503, 0x25230b02, 0x53000407, 0x2d0d2902,   // fr.un.un_300 es.ca.eu_222  fi.ht.un_420 sl.cs.sk_222
  0x0f002912, 0x033f0613, 0x35001a04, 0x27230608,   // sl.lv.un_640 de.af.nl_665  tl.zu.un_320 de.ca.gd_443
  0x64005507, 0x12000e02, 0x00001b06, 0x040e0c04,   // rw.lg.un_420 is.hu.un_220  tr.un.un_400 sv.is.fi_332
  0x040710a0, 0x122118a9, 0x04080aa0, 0x04170708,   // be.bg.ru_322 ar.fa.ur_544  mk.uk.ru_322 bg.sr.ru_443
  // [07c0]
  0x080a1702, 0x04000c0b, 0x17070a55, 0x1821120d,   // sr.mk.uk_222 sv.fi.un_520  mk.bg.sr_442 ur.fa.ar_554
  0x131c0960, 0x211e1c55, 0x0d00090d, 0x13090d0e,   // hi.mr.bh_664 id.ms.jw_442  hi.ne.un_540 ne.hi.bh_555
  0x070a080e, 0x0b0a1902, 0x32161705, 0x0d002d08,   // uk.mk.bg_555 gl.pt.es_222  sr.hr.bs_333 sk.cs.un_430
  0x251f28ee, 0x6423530c, 0x1800210d, 0x64355512,   // sw.cy.eu_422 ht.ca.lg_543  fa.ar.un_540 rw.zu.lg_654
  // [07d0]
  0x03000807, 0x010e0604, 0x0c0208a4, 0x08033f08,   // no.nl.un_420 de.is.en_332  no.da.sv_433 af.nl.no_443
  0x080411ee, 0x08000707, 0x0800100c, 0x12556b0b,   // ro.ru.uk_422 bg.uk.un_420  be.uk.un_530 ceb.rw.hu_542
  0x21181255, 0x0a11170c, 0x280131a0, 0x1c0d090c,   // ur.ar.fa_442 sr.ro.mk_543  az.en.sw_322 hi.ne.mr_543
  0x17040807, 0x29321704, 0x08000419, 0x2d290dee,   // uk.ru.sr_432 sr.bs.sl_332  ru.uk.un_750 cs.sl.sk_422
  // [07e0]
  0x53002109, 0x08070408, 0x1f1001a4, 0x070a17af,   // jw.ht.un_440 ru.bg.uk_443  en.lt.cy_433 sr.mk.bg_655
  0x021b2b04, 0x06040c07, 0x3f0304a4, 0x25280907,   // vi.tr.da_332 sv.fi.de_432  fi.nl.af_433 pl.sw.eu_432
  0x103f0907, 0x2d1b3104, 0x10080412, 0x161a2d07,   // pl.af.lt_432 az.tr.sk_332  ru.uk.be_654 sk.tl.hr_432
  0x13091ca9, 0x0f1017a0, 0x23110505, 0x17321604,   // mr.hi.bh_544 sr.lt.lv_322  fr.ro.ca_333 hr.bs.sr_332
  // [07f0]
  0x52002807, 0x070a11a0, 0x35006404, 0x07002507,   // sw.ha.un_420 ro.mk.bg_322  lg.zu.un_320 eu.it.un_420
  0x52001f02, 0x03003f12, 0x091c1304, 0x06003511,   // cy.ha.un_220 af.nl.un_640  bh.mr.hi_332 zu.de.un_630
  0x21521207, 0x530d0405, 0x0f532d04, 0x08000209,   // hu.ha.jw_432 fi.cs.ht_333  sk.ht.lv_332 da.no.un_440
  0x05100107, 0x0b000a12, 0x081004af, 0x1f003b07,   // en.lt.fr_432 pt.es.un_640  ru.be.uk_655 so.cy.un_420

  // [0800]
  0x04000709, 0x3f643b11, 0x08000a13, 0x0c216ba6,   // bg.ru.un_440 so.lg.af_653  mk.uk.un_650 ceb.jw.sv_521
  0x2d0d12af, 0x03041304, 0x201b3204, 0x551e28a4,   // hu.cs.sk_655 et.fi.nl_332  bs.tr.sq_332 sw.ms.rw_433
  0x041711a7, 0x0900550c, 0x040c0807, 0x0d006b07,   // ro.sr.ru_532 rw.pl.un_530  no.sv.fi_432 ceb.cs.un_420
  0x19003b19, 0x0e000212, 0x044a1308, 0x00000e1c,   // so.gl.un_750 da.is.un_640  et.yo.fi_443 is.un.un_800
  // [0810]
  0x3200170c, 0x18002718, 0x321716af, 0x0000521c,   // sr.bs.un_530 gd.ga.un_740  hr.sr.bs_655 ha.un.un_800
  0x1c000908, 0x19000b0c, 0x2a0e2808, 0x03006404,   // hi.mr.un_430 es.gl.un_530  sw.is.mt_443 lg.nl.un_320
  0x250604ee, 0x0a1107a4, 0x17163209, 0x0000241c,   // fi.de.eu_422 bg.ro.mk_433  bs.hr.sr_444 yi.un.un_800
  0x1b000614, 0x09001318, 0x0800171a, 0x12045304,   // de.tr.un_660 bh.hi.un_740  sr.uk.un_760 ht.fi.hu_332
  // [0820]
  0x03003f04, 0x3500040c, 0x04202bad, 0x04001007,   // af.nl.un_320 fi.zu.un_530  vi.sq.fi_643 be.ru.un_420
  0x0c001f04, 0x1105010c, 0x311b1a02, 0x0a170808,   // cy.sv.un_320 en.fr.ro_543  tl.tr.az_222 uk.sr.mk_443
  0x1c5512a4, 0x35003f08, 0x2d0d09ee, 0x09200408,   // hu.rw.id_433 af.zu.un_430  pl.cs.sk_422 fi.sq.pl_443
  0x2a321b04, 0x0c003108, 0x06006b04, 0x1200180e,   // tr.bs.mt_332 az.sv.un_430  ceb.de.un_320 ga.hu.un_550
  // [0830]
  0x4a003f19, 0x08021205, 0x20000307, 0x0e0c08a4,   // af.yo.un_750 hu.da.no_333  nl.sq.un_420 no.sv.is_433
  0x0000131c, 0x16000908, 0x120e0cee, 0x0f321702,   // bh.un.un_800 pl.hr.un_430  sv.is.hu_422 sr.bs.lv_222
  0x08000c02, 0x2b002304, 0x170711ee, 0x12182112,   // sv.no.un_220 ca.vi.un_320  ro.bg.sr_422 fa.ar.ur_654
  0x0a071113, 0x0d091c60, 0x10000108, 0x06531f0d,   // ro.bg.mk_665 mr.hi.ne_664  en.lt.un_430 cy.ht.de_554
  // [0840]
  0x29005308, 0x0a3f25a0, 0x0400081a, 0x1b001e04,   // ht.sl.un_430 eu.af.pt_322  uk.ru.un_760 ms.tr.un_320
  0x04000713, 0x25002014, 0x0a071107, 0x29202dee,   // bg.ru.un_650 sq.eu.un_660  ro.bg.mk_432 sk.sq.sl_422
  0x556453a7, 0x0f213507, 0x110405a4, 0x3b033f02,   // ht.lg.rw_532 zu.jw.lv_432  fr.fi.ro_433 af.nl.so_222
  0x0817105a, 0x13000902, 0x08001008, 0x00005506,   // be.sr.uk_553 hi.bh.un_220  be.uk.un_430 rw.un.un_400
  // [0850]
  0x351b31af, 0x06000c08, 0x2168280c, 0x1c001e08,   // az.tr.zu_655 sv.de.un_430  sw.ig.jw_543 ms.id.un_430
  0x08000c09, 0x64003502, 0x06003b08, 0x0a001908,   // sv.no.un_440 zu.lg.un_220  so.de.un_430 gl.pt.un_430
  0x07170805, 0x1c211207, 0x1c0d0908, 0x230a0704,   // uk.sr.bg_333 hu.jw.id_432  hi.ne.mr_443 it.pt.ca_332
  0x04002509, 0x12006b08, 0x17081002, 0x1e002508,   // eu.fi.un_440 ceb.hu.un_430  be.uk.sr_222 eu.ms.un_430
  // [0860]
  0x0f006402, 0x190b23ee, 0x0807040b, 0x4a006819,   // lg.lv.un_220 ca.es.gl_422  ru.bg.uk_542 ig.yo.un_750
  0x1304290b, 0x122118af, 0x01033b0d, 0x35285508,   // sl.fi.et_542 ar.fa.ur_655  so.nl.en_554 rw.sw.zu_443
  0x0a1c21a0, 0x1b006409, 0x190b0aa6, 0x0b0705ee,   // jw.id.pt_322 lg.tr.un_440  pt.es.gl_521 fr.it.es_422
  0x17080412, 0x216b12a4, 0x190b35a0, 0x532d0d55,   // ru.uk.sr_654 hu.ceb.jw_433  zu.es.gl_322 cs.sk.ht_442
  // [0870]
  0x0d002d04, 0x00001a15, 0x0a1704ad, 0x23042504,   // sk.cs.un_320 tl.un.un_700  ru.sr.mk_643 eu.fi.ca_332
  0x1c0d13a0, 0x252313ac, 0x53006402, 0x12000b04,   // bh.ne.mr_322 et.ca.eu_632  lg.ht.un_220 es.hu.un_320
  0x280c0811, 0x00000b1c, 0x682a52a9, 0x0a040707,   // no.sv.sw_653 bn.un.un_800  ha.mt.ig_544 bg.ru.mk_432
  0x0a2d0507, 0x05002b12, 0x07171155, 0x0553060d,   // fr.sk.pt_432 vi.fr.un_640  ro.sr.bg_442 de.ht.fr_554
  // [0880]
  0x21002704, 0x09002d0d, 0x64551213, 0x0a07170e,   // gd.jw.un_320 sk.pl.un_540  hu.rw.lg_665 sr.bg.mk_555
  0x3b4a6411, 0x2d3f2909, 0x271a1807, 0x00000401,   // lg.yo.so_653 sl.af.sk_444  ga.tl.gd_432 ru.un.un_200
  0x0c311b07, 0x04000819, 0x320f1707, 0x00002106,   // tr.az.sv_432 uk.ru.un_750  sr.lv.bs_432 jw.un.un_400
  0x07000419, 0x27051902, 0x09101fad, 0x051f07ee,   // ru.bg.un_750 gl.fr.gd_222  cy.lt.pl_643 it.cy.fr_422
  // [0890]
  0x25005312, 0x090d1cec, 0x2a006807, 0x091f3b04,   // ht.eu.un_640 mr.ne.hi_644  ig.mt.un_420 so.cy.pl_332
  0x0d091c14, 0x08070aa0, 0x17000413, 0x0a070414,   // mr.hi.ne_666 mk.bg.uk_322  ru.sr.un_650 ru.bg.mk_666
  0x21095507, 0x251805ad, 0x21006807, 0x1f000708,   // rw.pl.jw_432 fr.ga.eu_643  ig.jw.un_420 it.cy.un_430
  0x1c3b1eee, 0x6b3b1aee, 0x18002807, 0x25006404,   // ms.so.id_422 tl.so.ceb_422  sw.ga.un_420 lg.eu.un_320
  // [08a0]
  0x2818270c, 0x04001308, 0x190a05a6, 0x202d0d08,   // gd.ga.sw_543 et.fi.un_430  fr.pt.gl_521 cs.sk.sq_443
  0x554a0807, 0x03006b07, 0x18002707, 0x211812a9,   // no.yo.rw_432 ceb.nl.un_420  gd.ga.un_420 ur.ar.fa_544
  0x27000108, 0x10040812, 0x033f080c, 0x21006b07,   // en.gd.un_430 uk.ru.be_654  no.af.nl_543 ceb.jw.un_420
  0x12290c02, 0x01003b0c, 0x1c002105, 0x1707040b,   // sv.sl.hu_222 so.en.un_530  jw.id.un_330 ru.bg.sr_542
  // [08b0]
  0x1300210c, 0x17040a04, 0x1b00110e, 0x20000c02,   // jw.et.un_530 mk.ru.sr_332  ro.tr.un_550 sv.sq.un_220
  0x6b3b0455, 0x00000a1c, 0x041708af, 0x17000a04,   // fi.so.ceb_442 mk.un.un_800  uk.sr.ru_655 mk.sr.un_320
  0x1c000902, 0x09000d14, 0x0a070413, 0x6b2510a0,   // hi.mr.un_220 ne.hi.un_660  ru.bg.mk_665 lt.eu.ceb_322
  0x1c000d04, 0x1b00250d, 0x210c06a7, 0x08001b13,   // ne.mr.un_320 eu.tr.un_540  de.sv.jw_532 tr.no.un_650
  // [08c0]
  0x130d09ec, 0x0d1c090c, 0x0e000507, 0x28002104,   // hi.ne.bh_644 hi.mr.ne_543  fr.is.un_420 jw.sw.un_320
  0x09000d12, 0x09001c12, 0x193b2509, 0x00000f0a,   // ne.hi.un_640 mr.hi.un_640  eu.so.gl_444 lv.un.un_500
  0x04110855, 0x163217a7, 0x3b001907, 0x06293504,   // uk.ro.ru_442 sr.bs.hr_532  gl.so.un_420 zu.sl.de_332
  0x286e3bad, 0x0c0603a0, 0x071708af, 0x3f020ead,   // so.hmn.sw_643 nl.de.sv_322  uk.sr.bg_655 is.da.af_643
  // [08d0]
  0x203153ee, 0x17100813, 0x0c080604, 0x17070a08,   // ht.az.sq_422 uk.be.sr_665  de.no.sv_332 mk.bg.sr_443
  0x27001c02, 0x13091ca4, 0x16290e07, 0x53004a04,   // id.gd.un_220 mr.hi.bh_433  is.sl.hr_432 yo.ht.un_320
  0x3b005511, 0x1f1801ee, 0x1c006e07, 0x09061f02,   // rw.so.un_630 en.ga.cy_422  hmn.id.un_420 cy.de.pl_222
  0x53002102, 0x64004a02, 0x10001113, 0x102007ee,   // jw.ht.un_220 yo.lg.un_220  ro.be.un_650 it.sq.lt_422
  // [08e0]
  0x0d000119, 0x2d0329a0, 0x0a2d0d0b, 0x0b033fa4,   // en.cs.un_750 sl.nl.sk_322  cs.sk.pt_542 af.nl.es_433
  0x32162aa9, 0x11000705, 0x07171004, 0x2b1825a0,   // mt.hr.bs_544 it.ro.un_330  be.sr.bg_332 eu.ga.vi_322
  0x212d0d55, 0x0c003f02, 0x0d001f11, 0x32002808,   // cs.sk.jw_442 af.sv.un_220  cy.cs.un_630 sw.bs.un_430
  0x64123104, 0x1a2a55a7, 0x4a190b08, 0x1900050d,   // az.hu.lg_332 rw.mt.tl_532  es.gl.yo_443 fr.gl.un_540
  // [08f0]
  0x0400060d, 0x2d000d02, 0x08000e0d, 0x08290604,   // de.fi.un_540 cs.sk.un_220  is.no.un_540 de.sl.no_332
  0x04061308, 0x080e0411, 0x04033f0d, 0x1000060d,   // et.de.fi_443 fi.is.no_653  af.nl.fi_554 de.lt.un_540
  0x07100812, 0x03133f55, 0x313f1f07, 0x0d1c090d,   // uk.be.bg_654 af.et.nl_442  cy.af.az_432 hi.mr.ne_554
  0x643555a4, 0x0b002512, 0x0b002104, 0x3f000c05,   // rw.zu.lg_433 eu.es.un_640  jw.es.un_320 sv.af.un_330
  // [0900]
  0x2d060d07, 0x6b1b35a4, 0x110a0704, 0x28643560,   // cs.de.sk_432 zu.tr.ceb_433  it.pt.ro_332 zu.lg.sw_664
  0x321704af, 0x53002302, 0x05005202, 0x05005302,   // fi.sr.bs_655 ca.ht.un_220  ha.fr.un_220 ht.fr.un_220
  0x29003205, 0x2a0f10ee, 0x0d001904, 0x23551105,   // bs.sl.un_330 lt.lv.mt_422  gl.cs.un_320 ro.rw.ca_333
  0x0c001a02, 0x021310a4, 0x11170a12, 0x12000b02,   // tl.sv.un_220 lt.et.da_433  mk.sr.ro_654 es.hu.un_220
  // [0910]
  0x17040a0d, 0x04170a04, 0x11002304, 0x2500111a,   // mk.ru.sr_554 mk.sr.ru_332  ca.ro.un_320 ro.eu.un_760
  0x1c000d13, 0x20000407, 0x01002411, 0x0a080702,   // ne.mr.un_650 fi.sq.un_420  yi.iw.un_630 bg.uk.mk_222
  0x06002507, 0x13090d11, 0x31001b0d, 0x281355af,   // eu.de.un_420 ne.hi.bh_653  tr.az.un_540 rw.et.sw_655
  0x32171608, 0x04000c0e, 0x312a0704, 0x0000551c,   // hr.sr.bs_443 sv.fi.un_550  it.mt.az_332 rw.un.un_800
  // [0920]
  0x171008a4, 0x1a1b6ba4, 0x13006407, 0x21001f1a,   // uk.be.sr_433 ceb.tr.tl_433  lg.et.un_420 cy.jw.un_760
  0x283b01a7, 0x0e1a6b04, 0x1c000d12, 0x16001208,   // en.so.sw_532 ceb.tl.is_332  ne.mr.un_640 hu.hr.un_430
  0x1f000707, 0x112723a0, 0x195323a0, 0x35311bad,   // it.cy.un_420 ca.gd.ro_322  ca.ht.gl_322 tr.az.zu_643
  0x18002719, 0x356455a0, 0x07170aa0, 0x0a001702,   // gd.ga.un_750 rw.lg.zu_322  mk.sr.bg_322 sr.pt.un_220
  // [0930]
  0x09002a05, 0x12002d12, 0x12000309, 0x13002507,   // mt.pl.un_330 sk.hu.un_640  nl.hu.un_440 eu.et.un_420
  0x0b0d2d0c, 0x21005505, 0x68182ba4, 0x28080c08,   // sk.cs.es_543 rw.jw.un_330  vi.ga.ig_433 sv.no.sw_443
  0x07111308, 0x553b06ee, 0x35001c04, 0x02000e0d,   // et.ro.it_443 de.so.rw_422  id.zu.un_320 is.da.un_540
  0x31003502, 0x1000081a, 0x040a1702, 0x0a0711ee,   // zu.az.un_220 uk.be.un_760  sr.mk.ru_222 ro.bg.mk_422
  // [0940]
  0x21050dac, 0x35285507, 0x24000118, 0x04000108,   // cs.fr.jw_632 rw.sw.zu_432  iw.yi.un_740 en.fi.un_430
  0x29001702, 0x0d091caf, 0x17080d07, 0x31002013,   // sr.sl.un_220 mr.hi.ne_655  cs.no.sr_432 sq.az.un_650
  0x35003f14, 0x080a17a4, 0x1b003b13, 0x3b2021ac,   // af.zu.un_660 sr.mk.uk_433  so.tr.un_650 jw.sq.so_632
  0x12000f13, 0x2d000307, 0x21000407, 0x1b001304,   // lv.hu.un_650 nl.sk.un_420  fi.jw.un_420 et.tr.un_320
  // [0950]
  0x1c0d6404, 0x08100408, 0x283555af, 0x25001113,   // lg.cs.id_332 ru.be.uk_443  rw.zu.sw_655 ro.eu.un_650
  0x21000707, 0x133f1007, 0x00002001, 0x211a6bad,   // it.jw.un_420 lt.af.et_432  sq.un.un_200 ceb.tl.jw_643
  0x133f0411, 0x1c000913, 0x21011bac, 0x1a6b1b07,   // fi.af.et_653 hi.mr.un_650  tr.en.jw_632 tr.ceb.tl_432
  0x0a000713, 0x1e552807, 0x13001c14, 0x25006b08,   // bg.mk.un_650 sw.rw.ms_432  mr.bh.un_660 ceb.eu.un_430
  // [0960]
  0x1a0a280d, 0x4a1b550d, 0x6b1a21a0, 0x0e00020d,   // sw.pt.tl_554 rw.tr.yo_554  jw.tl.ceb_322 da.is.un_540
  0x251a5507, 0x6b55640d, 0x53003504, 0x03083fa0,   // rw.tl.eu_432 lg.rw.ceb_554  zu.ht.un_320 af.no.nl_322
  0x12182111, 0x06001312, 0x032a3507, 0x1c000d19,   // fa.ar.ur_653 et.de.un_640  zu.mt.nl_432 ne.mr.un_750
  0x090408a0, 0x2100050c, 0x532855ee, 0x530e28a7,   // no.fi.pl_322 fr.jw.un_530  rw.sw.ht_422 sw.is.ht_532
  // [0970]
  0x3b4a1205, 0x3f050107, 0x4a682807, 0x21001219,   // hu.yo.so_333 en.fr.af_432  sw.ig.yo_432 ur.fa.un_750
  0x04000814, 0x00000f06, 0x11000a13, 0x1c001f05,   // uk.ru.un_660 lv.un.un_400  mk.ro.un_650 cy.id.un_330
  0x03230112, 0x0a17070e, 0x041007a0, 0x0b4a55ec,   // en.ca.nl_654 bg.sr.mk_555  bg.be.ru_322 rw.yo.es_644
  0x17001605, 0x4a000a0d, 0x12001f0d, 0x1f000605,   // hr.sr.un_330 pt.yo.un_540  cy.hu.un_540 de.cy.un_330
  // [0980]
  0x09002005, 0x2d003507, 0x08001707, 0x0c083f5a,   // sq.pl.un_330 zu.sk.un_420  sr.uk.un_420 af.no.sv_553
  0x03060207, 0x0e1f1b11, 0x1a006b04, 0x55002811,   // da.de.nl_432 tr.cy.is_653  ceb.tl.un_320 sw.rw.un_630
  0x2b0c01a6, 0x3f122da0, 0x0e000607, 0x0c020812,   // en.sv.vi_521 sk.hu.af_322  de.is.un_420 no.da.sv_654
  0x070811ac, 0x35001813, 0x3200280c, 0x0c000804,   // ro.uk.bg_632 ga.zu.un_650  sw.bs.un_530 no.sv.un_320
  // [0990]
  0x4a002819, 0x27005307, 0x122a20a9, 0x1c033f07,   // sw.yo.un_750 ht.gd.un_420  sq.mt.hu_544 af.nl.id_432
  0x2a0d0908, 0x18042709, 0x18190b05, 0x064a550e,   // pl.cs.mt_443 gd.fi.ga_444  es.gl.ga_333 rw.yo.de_555
  0x6b352da0, 0x08040607, 0x0c000612, 0x0400070e,   // sk.zu.ceb_322 de.fi.no_432  de.sv.un_640 bg.ru.un_550
  0x020e0807, 0x123f1007, 0x00001f01, 0x20002812,   // no.is.da_432 lt.af.hu_432  cy.un.un_200 sw.sq.un_640
  // [09a0]
  0x07110a12, 0x1c28210d, 0x2d0d29a0, 0x13005304,   // mk.ro.bg_654 jw.sw.id_554  sl.cs.sk_322 ht.et.un_320
  0x08110a04, 0x0a001104, 0x04251108, 0x2718010c,   // mk.ro.uk_332 ro.pt.un_320  ro.eu.fi_443 en.ga.gd_543
  0x4a001812, 0x271813ee, 0x13020ea4, 0x18002109,   // ga.yo.un_640 et.ga.gd_422  is.da.et_433 fa.ar.un_440
  0x4a001212, 0x21356407, 0x10000912, 0x09000d1a,   // hu.yo.un_640 lg.zu.jw_432  pl.lt.un_640 ne.hi.un_760
  // [09b0]
  0x04000808, 0x0800101a, 0x25122304, 0x0c0807ad,   // uk.ru.un_430 be.uk.un_760  ca.hu.eu_332 it.no.sv_643
  0x1c000d14, 0x0500110d, 0x4a000e12, 0x171629a0,   // ne.mr.un_660 ro.fr.un_540  is.yo.un_640 sl.hr.sr_322
  0x29001007, 0x090d13ad, 0x1b536408, 0x52000607,   // lt.sl.un_420 bh.ne.hi_643  lg.ht.tr_443 de.ha.un_420
  0x1e1c01a0, 0x10001702, 0x0c0806a0, 0x311e29ac,   // en.id.ms_322 sr.be.un_220  de.no.sv_322 sl.ms.az_632
  // [09c0]
  0x112301a4, 0x64005521, 0x0c002904, 0x3b211f04,   // en.ca.ro_433 rw.lg.un_860  sl.sv.un_320 cy.jw.so_332
  0x6b0431ee, 0x55646ba4, 0x13080202, 0x3b001a04,   // az.fi.ceb_422 ceb.lg.rw_433  da.no.et_222 tl.so.un_320
  0x0c00270d, 0x53641ea0, 0x00000215, 0x130d0914,   // gd.sv.un_540 ms.lg.ht_322  da.un.un_700 hi.ne.bh_666
  0x162d6bee, 0x07001107, 0x080227ee, 0x640501af,   // ceb.sk.hr_422 ro.bg.un_420  gd.da.no_422 en.fr.lg_655
  // [09d0]
  0x0b002d0d, 0x2a002011, 0x08003504, 0x0a0717af,   // sk.es.un_540 sq.mt.un_630  zu.no.un_320 sr.bg.mk_655
  0x1200020c, 0x1c00130c, 0x051001a4, 0x31001b1b,   // da.hu.un_530 bh.mr.un_530  en.lt.fr_433 tr.az.un_770
  0x10033f07, 0x535564a9, 0x53000804, 0x07001007,   // af.nl.lt_432 lg.rw.ht_544  no.ht.un_320 be.bg.un_420
  0x64005513, 0x06033fa4, 0x4a003202, 0x351809ad,   // rw.lg.un_650 af.nl.de_433  bs.yo.un_220 pl.ga.zu_643
  // [09e0]
  0x010d2d0c, 0x25005313, 0x21022905, 0x0e0801a4,   // sk.cs.en_543 ht.eu.un_650  sl.da.jw_333 en.no.is_433
  0x25190b02, 0x31645504, 0x0f000804, 0x05013bee,   // es.gl.eu_222 rw.lg.az_332  no.lv.un_320 so.en.fr_422
  0x351355ec, 0x202902ad, 0x27181f12, 0x081c2104,   // rw.et.zu_644 da.sl.sq_643  cy.ga.gd_654 jw.id.no_332
  0x20682907, 0x25211aa4, 0x21001c08, 0x0c002812,   // sl.ig.sq_432 tl.jw.eu_433  id.jw.un_430 sw.sv.un_640
  // [09f0]
  0x170711a9, 0x092101a0, 0x1f080c04, 0x35005504,   // ro.bg.sr_544 en.jw.pl_322  sv.no.cy_332 rw.zu.un_320
  0x64355504, 0x201153a4, 0x13001c05, 0x55001b05,   // rw.zu.lg_332 ht.ro.sq_433  mr.bh.un_330 tr.rw.un_330
  0x10081702, 0x2710250c, 0x321716ee, 0x0c033f07,   // sr.uk.be_222 eu.lt.gd_543  hr.sr.bs_422 af.nl.sv_432
  0x08062304, 0x1c0913ee, 0x31071baf, 0x0e122d0b,   // ca.de.no_332 bh.hi.mr_422  tr.it.az_655 sk.hu.is_542
  // [0a00]
  0x03100107, 0x13000a07, 0x311f3507, 0x0c08030b,   // en.lt.nl_432 pt.et.un_420  zu.cy.az_432 nl.no.sv_542
  0x173112a4, 0x64002812, 0x64352808, 0x0f2a1305,   // hu.az.sr_433 sw.lg.un_640  sw.zu.lg_443 et.mt.lv_333
  0x350453a4, 0x1b0e1f07, 0x0e001814, 0x170710a0,   // ht.fi.zu_433 cy.is.tr_432  ga.is.un_660 be.bg.sr_322
  0x4a3f03ee, 0x25005202, 0x31051104, 0x251f0107,   // nl.af.yo_422 ha.eu.un_220  ro.fr.az_332 en.cy.eu_432
  // [0a10]
  0x1200181a, 0x3217160e, 0x06002a02, 0x2a006e07,   // ar.ur.un_760 hr.sr.bs_555  mt.de.un_220 hmn.mt.un_420
  0x32171655, 0x6400680d, 0x31002a0d, 0x083b02ee,   // hr.sr.bs_442 ig.lg.un_540  mt.az.un_540 da.so.no_422
  0x16321708, 0x040810a7, 0x01001307, 0x09001c18,   // sr.bs.hr_443 be.uk.ru_532  et.en.un_420 mr.hi.un_740
  0x29000e0d, 0x18001212, 0x090813a0, 0x31001b07,   // is.sl.un_540 ur.ar.un_640  et.no.pl_322 tr.az.un_420
  // [0a20]
  0x0a171155, 0x126407a0, 0x6825550c, 0x07000413,   // ro.sr.mk_442 it.lg.hu_322  rw.eu.ig_543 ru.bg.un_650
  0x050711ee, 0x29000813, 0x3f000308, 0x2b002104,   // ro.it.fr_422 no.sl.un_650  nl.af.un_430 jw.vi.un_320
  0x211c1e07, 0x02280308, 0x21040ea0, 0x07001902,   // ms.id.jw_432 nl.sw.da_443  is.fi.jw_322 gl.it.un_220
  0x12001812, 0x321708ee, 0x204a040b, 0x041708ec,   // ar.ur.un_640 no.sr.bs_422  fi.yo.sq_542 uk.sr.ru_644
  // [0a30]
  0x09000d07, 0x06002013, 0x17100812, 0x1100010d,   // ne.hi.un_420 sq.de.un_650  uk.be.sr_654 en.ro.un_540
  0x52000e19, 0x2d290d0e, 0x080220af, 0x050820ee,   // is.ha.un_750 cs.sl.sk_555  sq.da.no_655 sq.no.fr_422
  0x6b000105, 0x130d09af, 0x03002b04, 0x00001f24,   // en.ceb.un_330 hi.ne.bh_655  vi.nl.un_320 cy.un.un_900
  0x1300090e, 0x1b002119, 0x04120cee, 0x0c0204af,   // hi.bh.un_550 jw.tr.un_750  sv.hu.fi_422 fi.da.sv_655
  // [0a40]
  0x06032702, 0x12192004, 0x053f0304, 0x3f1b0107,   // gd.nl.de_222 sq.gl.hu_332  nl.af.fr_332 en.tr.af_432
  0x291c21ee, 0x13001c0d, 0x32001208, 0x04081711,   // jw.id.sl_422 mr.bh.un_540  hu.bs.un_430 sr.uk.ru_653
  0x2a000708, 0x0a001108, 0x1b311112, 0x1b351208,   // it.mt.un_430 ro.mk.un_430  ro.az.tr_654 hu.zu.tr_443
  0x3b10290c, 0x190b0a0e, 0x64005214, 0x3b0607ad,   // sl.lt.so_543 pt.es.gl_555  ha.lg.un_660 it.de.so_643
  // [0a50]
  0x2d1b310c, 0x64000713, 0x28211e02, 0x2d001223,   // az.tr.sk_543 it.lg.un_650  ms.jw.sw_222 hu.sk.un_880
  0x0000201c, 0x04100805, 0x29311ba7, 0x08096bee,   // sq.un.un_800 uk.be.ru_333  tr.az.sl_532 ceb.pl.no_422
  0x080210af, 0x0823250c, 0x08070ba0, 0x1b310c12,   // lt.da.no_655 eu.ca.no_543  es.it.no_322 sv.az.tr_654
  0x09000b05, 0x190a0b02, 0x27002304, 0x35000819,   // es.pl.un_330 es.pt.gl_222  ca.gd.un_320 no.zu.un_750
  // [0a60]
  0x120e04a0, 0x64033f04, 0x02000807, 0x033f3b12,   // fi.is.hu_322 af.nl.lg_332  no.da.un_420 so.af.nl_654
  0x063f0c0c, 0x13100c0d, 0x040a0712, 0x080410a7,   // sv.af.de_543 sv.lt.et_554  bg.mk.ru_654 be.ru.uk_532
  0x0a002b08, 0x0e005304, 0x091c13ad, 0x070410a0,   // vi.pt.un_430 ht.is.un_320  bh.mr.hi_643 be.ru.bg_322
  0x64003b1a, 0x2d000308, 0x122d0d0e, 0x640306a4,   // so.lg.un_760 nl.sk.un_430  cs.sk.hu_555 de.nl.lg_433
  // [0a70]
  0x556453a0, 0x1c0913a7, 0x17163214, 0x210105a7,   // ht.lg.rw_322 bh.hi.mr_532  bs.hr.sr_666 fr.en.jw_532
  0x08040712, 0x290c1308, 0x063f030e, 0x642855a0,   // bg.ru.uk_654 et.sv.sl_443  nl.af.de_555 rw.sw.lg_322
  0x1e130404, 0x21180107, 0x20103205, 0x060c0107,   // fi.et.ms_332 en.ga.jw_432  bs.lt.sq_333 en.sv.de_432
  0x1c000907, 0x231320ac, 0x1104200c, 0x041364a0,   // hi.mr.un_420 sq.et.ca_632  sq.fi.ro_543 lg.et.fi_322
  // [0a80]
  0x3f130c02, 0x040a1004, 0x08000211, 0x25001c02,   // sv.et.af_222 be.mk.ru_332  da.no.un_630 id.eu.un_220
  0x08003f02, 0x080255a0, 0x1b00060d, 0x00001203,   // af.no.un_220 rw.da.no_322  de.tr.un_540 ur.un.un_300
  0x643528ad, 0x13001c08, 0x130d1c13, 0x080e2107,   // sw.zu.lg_643 mr.bh.un_430  mr.ne.bh_665 jw.is.no_432
  0x2a203b04, 0x0d091cee, 0x122d0eec, 0x06355502,   // so.sq.mt_332 mr.hi.ne_422  is.sk.hu_644 rw.zu.de_222
  // [0a90]
  0x0f003b08, 0x091c0d07, 0x1a006b0c, 0x32001707,   // so.lv.un_430 ne.mr.hi_432  ceb.tl.un_530 sr.bs.un_420
  0x09000d05, 0x291e1c04, 0x030e2007, 0x3b003f08,   // ne.hi.un_330 id.ms.sl_332  sq.is.nl_432 af.so.un_430
  0x211e1ca0, 0x1f060204, 0x2d0d01ec, 0x170711ad,   // id.ms.jw_322 da.de.cy_332  en.cs.sk_644 ro.bg.sr_643
  0x09130d0c, 0x2b001c02, 0x170704a4, 0x3f0e0807,   // ne.bh.hi_543 id.vi.un_220  ru.bg.sr_433 no.is.af_432
  // [0aa0]
  0x1c000d02, 0x0b000104, 0x3216170e, 0x0d010504,   // ne.mr.un_220 en.es.un_320  sr.hr.bs_555 fr.en.cs_332
  0x02003f08, 0x11050111, 0x21024aad, 0x6b00250d,   // af.da.un_430 en.fr.ro_653  yo.da.jw_643 eu.ceb.un_540
  0x0a033f60, 0x13060c02, 0x182112a4, 0x1b080260,   // af.nl.pt_664 sv.de.et_222  ur.fa.ar_433 da.no.tr_664
  0x16200e04, 0x08311002, 0x3b002a0e, 0x021b12a4,   // is.sq.hr_332 lt.az.no_222  mt.so.un_550 hu.tr.da_433
  // [0ab0]
  0x18000113, 0x0a07100c, 0x080411a9, 0x64002502,   // en.ga.un_650 be.bg.mk_543  ro.ru.uk_544 eu.lg.un_220
  0x28552007, 0x080201a0, 0x681e1c0d, 0x323b2d07,   // sq.rw.sw_432 en.da.no_322  id.ms.ig_554 sk.so.bs_432
  0x17311107, 0x0d000504, 0x070a1705, 0x07033bee,   // ro.az.sr_432 fr.cs.un_320  sr.mk.bg_333 so.nl.it_422
  0x356455ad, 0x0d091ca4, 0x04001707, 0x13000c12,   // rw.lg.zu_643 mr.hi.ne_433  sr.ru.un_420 sv.et.un_640
  // [0ac0]
  0x0d002905, 0x060e2807, 0x0807040d, 0x07080a12,   // sl.cs.un_330 sw.is.de_432  ru.bg.uk_554 mk.uk.bg_654
  0x643b27ee, 0x1a6b2805, 0x09001902, 0x3f030c04,   // gd.so.lg_422 sw.ceb.tl_333  gl.pl.un_220 sv.nl.af_332
  0x27093b08, 0x6b213b04, 0x11002305, 0x191368a7,   // so.pl.gd_443 so.jw.ceb_332  ca.ro.un_330 ig.et.gl_532
  0x53001c04, 0x2100230c, 0x0a170804, 0x08070a05,   // id.ht.un_320 ca.jw.un_530  uk.sr.mk_332 mk.bg.uk_333
  // [0ad0]
  0x1200060b, 0x55002d04, 0x1b0e08a0, 0x06001f02,   // de.hu.un_520 sk.rw.un_320  no.is.tr_322 cy.de.un_220
  0x0d001308, 0x02000112, 0x0000190a, 0x02000c0e,   // bh.ne.un_430 en.da.un_640  gl.un.un_500 sv.da.un_550
  0x11100fee, 0x311b3b0d, 0x08020302, 0x0c08020c,   // lv.lt.ro_422 so.tr.az_554  nl.da.no_222 da.no.sv_543
  0x0e080ca0, 0x093b0107, 0x0e2931a0, 0x05193bee,   // sv.no.is_322 en.so.pl_432  az.sl.is_322 so.gl.fr_422
  // [0ae0]
  0x1e002702, 0x2d001907, 0x2d0d2502, 0x110a28ee,   // gd.ms.un_220 gl.sk.un_420  eu.cs.sk_222 sw.pt.ro_422
  0x08000712, 0x1235060c, 0x0e000808, 0x1c000d0e,   // bg.uk.un_640 de.zu.hu_543  no.is.un_430 ne.mr.un_550
  0x10001119, 0x6b211a09, 0x251b6ba7, 0x130106ee,   // ro.be.un_750 tl.jw.ceb_444  ceb.tr.eu_532 de.en.et_422
  0x080411a6, 0x23250fa0, 0x1a006b1b, 0x21001e05,   // ro.ru.uk_521 lv.eu.ca_322  ceb.tl.un_770 ms.jw.un_330
  // [0af0]
  0x040e3fa9, 0x2b005304, 0x07000e04, 0x02000812,   // af.is.fi_544 ht.vi.un_320  is.it.un_320 no.da.un_640
  0x081f18a0, 0x18002502, 0x0e1f06a0, 0x080e29a7,   // ga.cy.no_322 eu.ga.un_220  de.cy.is_322 sl.is.no_532
  0x3f050305, 0x1700081a, 0x17000a19, 0x3500020d,   // nl.fr.af_333 uk.sr.un_760  mk.sr.un_750 da.zu.un_540
  0x3f000d07, 0x28272307, 0x1b051fa0, 0x050b010c,   // cs.af.un_420 ca.gd.sw_432  cy.fr.tr_322 en.es.fr_543
  // [0b00]
  0x19270104, 0x12004a08, 0x0e290855, 0x2d0e0d09,   // en.gd.gl_332 yo.hu.un_430  no.sl.is_442 cs.is.sk_444
  0x0f002302, 0x13091c0c, 0x2d190d09, 0x1c0e25a6,   // ca.lv.un_220 mr.hi.bh_543  cs.gl.sk_444 eu.is.id_521
  0x0d091309, 0x073f11a0, 0x08020d05, 0x091710ad,   // bh.hi.ne_444 ro.af.it_322  cs.da.no_333 lt.sr.pl_643
  0x07040aa0, 0x09001313, 0x21001c04, 0x17111007,   // mk.ru.bg_322 bh.hi.un_650  id.jw.un_320 lt.ro.sr_432
  // [0b10]
  0x0e0c01a4, 0x0c000814, 0x683b11ee, 0x1f0c0e07,   // en.sv.is_433 no.sv.un_660  ro.so.ig_422 is.sv.cy_432
  0x35003207, 0x12000212, 0x3f030808, 0x32002d08,   // bs.zu.un_420 da.hu.un_640  no.nl.af_443 sk.bs.un_430
  0x07001008, 0x040118a0, 0x1f002707, 0x17001604,   // be.bg.un_430 ga.en.fi_322  gd.cy.un_420 hr.sr.un_320
  0x131c0911, 0x13643ba9, 0x1b002a05, 0x3b006413,   // hi.mr.bh_653 so.lg.et_544  mt.tr.un_330 lg.so.un_650
  // [0b20]
  0x35645208, 0x12190b5a, 0x16003204, 0x0d001c19,   // ha.lg.zu_443 es.gl.hu_553  bs.hr.un_320 mr.ne.un_750
  0x0a000714, 0x06001f07, 0x0d130908, 0x0d2d3f0d,   // bg.mk.un_660 cy.de.un_420  hi.bh.ne_443 af.sk.cs_554
  0x3b00640e, 0x2100280c, 0x2d0d3fa4, 0x061b3ba6,   // lg.so.un_550 sw.jw.un_530  af.cs.sk_433 so.tr.de_521
  0x0a071105, 0x17000108, 0x5300060d, 0x0000091c,   // ro.bg.mk_333 en.sr.un_430  de.ht.un_540 pl.un.un_800
  // [0b30]
  0x522164ad, 0x05002305, 0x3f000309, 0x162d09a4,   // lg.jw.ha_643 ca.fr.un_330  nl.af.un_440 pl.sk.hr_433
  0x04006407, 0x0900130c, 0x3f2101a4, 0x0f000305,   // lg.fi.un_420 bh.hi.un_530  en.jw.af_433 nl.lv.un_330
  0x52006409, 0x31002007, 0x4a121804, 0x190b11a0,   // lg.ha.un_440 sq.az.un_420  ga.hu.yo_332 ro.es.gl_322
  0x170410a9, 0x04171107, 0x201308ec, 0x21121813,   // be.ru.sr_544 ro.sr.ru_432  no.et.sq_644 ar.ur.fa_665
  // [0b40]
  0x231901ee, 0x3f0e6407, 0x0f001107, 0x3f00030c,   // en.gl.ca_422 lg.is.af_432  ro.lv.un_420 nl.af.un_530
  0x08000202, 0x00003f15, 0x270401a0, 0x64070eee,   // da.no.un_220 af.un.un_700  en.fi.gd_322 is.it.lg_422
  0x03003b0b, 0x291607a0, 0x170a1113, 0x6b0e0607,   // so.nl.un_520 it.hr.sl_322  ro.mk.sr_665 de.is.ceb_432
  0x0c000607, 0x06003512, 0x21006404, 0x181f6b02,   // de.sv.un_420 zu.de.un_640  lg.jw.un_320 ceb.cy.ga_222
  // [0b50]
  0x200c2d07, 0x06004a08, 0x05555304, 0x12553507,   // sk.sv.sq_432 yo.de.un_430  ht.rw.fr_332 zu.rw.hu_432
  0x100408a4, 0x112a2305, 0x522a1208, 0x0700040d,   // uk.ru.be_433 ca.mt.ro_333  hu.mt.ha_443 fi.it.un_540
  0x01521107, 0x071028a0, 0x0410080e, 0x0d1c1304,   // ro.ha.en_432 sw.lt.it_322  uk.be.ru_555 bh.mr.ne_332
  0x06034aee, 0x040807a4, 0x09001f08, 0x072a11ee,   // yo.nl.de_422 bg.uk.ru_433  cy.pl.un_430 ro.mt.it_422
  // [0b60]
  0x27033f04, 0x0c001305, 0x070a1708, 0x0a171002,   // af.nl.gd_332 et.sv.un_330  sr.mk.bg_443 be.sr.mk_222
  0x00001c06, 0x08001112, 0x12002122, 0x28001809,   // id.un.un_400 ro.uk.un_640  fa.ur.un_870 ga.sw.un_440
  0x10000f08, 0x10070a04, 0x0f1804a4, 0x2d0d09a4,   // lv.lt.un_430 mk.bg.be_332  fi.ga.lv_433 pl.cs.sk_433
  0x3500641b, 0x1c001302, 0x01002507, 0x04000704,   // lg.zu.un_770 bh.mr.un_220  eu.en.un_420 bg.ru.un_320
  // [0b70]
  0x3f040507, 0x13005204, 0x190b21a0, 0x0a111704,   // fr.fi.af_432 ha.et.un_320  jw.es.gl_322 sr.ro.mk_332
  0x17000808, 0x2d0d09ec, 0x203525ad, 0x0c001112,   // uk.sr.un_430 pl.cs.sk_644  eu.zu.sq_643 ro.sv.un_640
  0x1c001305, 0x18001214, 0x643b680c, 0x3f112dee,   // bh.mr.un_330 ur.ar.un_660  ig.so.lg_543 sk.ro.af_422
  0x163f03a0, 0x0a1711a0, 0x32162905, 0x05030809,   // nl.af.hr_322 ro.sr.mk_322  sl.hr.bs_333 no.nl.fr_444
  // [0b80]
  0x040a08a7, 0x0d2d0912, 0x2d001804, 0x0e2d0d04,   // uk.mk.ru_532 pl.sk.cs_654  ga.sk.un_320 cs.sk.is_332
  0x25001007, 0x3b2152a4, 0x040110a0, 0x00001801,   // lt.eu.un_420 ha.jw.so_433  lt.en.fi_322 ga.un.un_200
  0x31001802, 0x03002104, 0x12000405, 0x063b01a0,   // ga.az.un_220 jw.nl.un_320  fi.hu.un_330 en.so.de_322
  0x29041007, 0x3f000b02, 0x04070a04, 0x130e04a7,   // lt.fi.sl_432 es.af.un_220  mk.bg.ru_332 fi.is.et_532
  // [0b90]
  0x1800271a, 0x55682807, 0x12211811, 0x10080a02,   // gd.ga.un_760 sw.ig.rw_432  ar.fa.ur_653 mk.uk.be_222
  0x21005304, 0x6b35280d, 0x53001104, 0x645528ad,   // ht.jw.un_320 sw.zu.ceb_554  ro.ht.un_320 sw.rw.lg_643
  0x55005308, 0x08551fa0, 0x0200080c, 0x13000704,   // ht.rw.un_430 cy.rw.no_322  no.da.un_530 it.et.un_320
  0x0c082904, 0x071011ee, 0x310904a4, 0x020c08af,   // sl.no.sv_332 ro.be.bg_422  fi.pl.az_433 no.sv.da_655
  // [0ba0]
  0x0a0407af, 0x02002104, 0x6b003f05, 0x21002807,   // bg.ru.mk_655 jw.da.un_320  af.ceb.un_330 sw.jw.un_420
  0x042010a4, 0x07170aee, 0x08070411, 0x230b0a02,   // lt.sq.fi_433 mk.sr.bg_422  ru.bg.uk_653 pt.es.ca_222
  0x1218210c, 0x13000e08, 0x6b090107, 0x0a003b05,   // fa.ar.ur_543 is.et.un_430  en.pl.ceb_432 so.pt.un_330
  0x07171007, 0x020e08ac, 0x211f5207, 0x1b002a08,   // be.sr.bg_432 no.is.da_632  ha.cy.jw_432 mt.tr.un_430
  // [0bb0]
  0x04080e04, 0x016b100c, 0x05001105, 0x090d1104,   // is.no.fi_332 lt.ceb.en_543  ro.fr.un_330 ro.cs.pl_332
  0x04001713, 0x2d0d050c, 0x2a20020c, 0x0a041713,   // sr.ru.un_650 fr.cs.sk_543  da.sq.mt_543 sr.ru.mk_665
  0x11102daf, 0x5500520e, 0x11000413, 0x321701a0,   // sk.lt.ro_655 ha.rw.un_550  ru.ro.un_650 en.sr.bs_322
  0x04170702, 0x0500040d, 0x07170aa7, 0x070206ee,   // bg.sr.ru_222 fi.fr.un_540  mk.sr.bg_532 de.da.it_422
  // [0bc0]
  0x0d1c095a, 0x0400070b, 0x00004a01, 0x021106a0,   // hi.mr.ne_553 bg.ru.un_520  yo.un.un_200 de.ro.da_322
  0x250501ec, 0x16292007, 0x0800170e, 0x28251e07,   // en.fr.eu_644 sq.sl.hr_432  sr.uk.un_550 ms.eu.sw_432
  0x0d001c07, 0x2800550d, 0x09006412, 0x1f103555,   // mr.ne.un_420 rw.sw.un_540  lg.pl.un_640 zu.lt.cy_442
  0x2d2911ee, 0x0f002513, 0x3b3f35a7, 0x28351212,   // ro.sl.sk_422 eu.lv.un_650  zu.af.so_532 hu.zu.sw_654
  // [0bd0]
  0x231b5507, 0x04005304, 0x13250707, 0x21003504,   // rw.tr.ca_432 ht.fi.un_320  it.eu.et_432 zu.jw.un_320
  0x07170aa4, 0x1c0820a0, 0x31001b22, 0x1f001e05,   // mk.sr.bg_433 sq.no.id_322  tr.az.un_870 ms.cy.un_330
  0x522a28a4, 0x08100707, 0x09250807, 0x21000c0d,   // sw.mt.ha_433 bg.be.uk_432  no.eu.pl_432 sv.jw.un_540
  0x0e000c0c, 0x200c0404, 0x1b00311a, 0x1e1c2505,   // sv.is.un_530 fi.sv.sq_332  az.tr.un_760 eu.id.ms_333
  // [0be0]
  0x08041009, 0x1f3b0408, 0x17002913, 0x521e0ca0,   // be.ru.uk_444 fi.so.cy_443  sl.sr.un_650 sv.ms.ha_322
  0x68211cad, 0x1f00011a, 0x2d002912, 0x0f00251a,   // id.jw.ig_643 en.cy.un_760  sl.sk.un_640 eu.lv.un_760
  0x080417a4, 0x13001c19, 0x182725a0, 0x1e3f0355,   // sr.ru.uk_433 mr.bh.un_750  eu.gd.ga_322 nl.af.ms_442
  0x071101a4, 0x07006404, 0x321e1ba0, 0x53050613,   // en.ro.it_433 lg.it.un_320  tr.ms.bs_322 de.fr.ht_665
  // [0bf0]
  0x061101a4, 0x070a17ec, 0x072001a0, 0x08040a07,   // en.ro.de_433 sr.mk.bg_644  en.sq.it_322 mk.ru.uk_432
  0x0d1c1312, 0x0b000704, 0x3b52010b, 0x2a1703a7,   // bh.mr.ne_654 it.es.un_320  en.ha.so_542 nl.sr.mt_532
  0x08001714, 0x04071702, 0x091c0da4, 0x1e1c0ea4,   // sr.uk.un_660 sr.bg.ru_222  ne.mr.hi_433 is.id.ms_433
  0x170a0755, 0x2a000707, 0x682813ec, 0x1c211f12,   // bg.mk.sr_442 it.mt.un_420  et.sw.ig_644 cy.jw.id_654

  // [0c00]
  0x0a071702, 0x1a3b0614, 0x27000804, 0x3b1325a7,   // sr.bg.mk_222 de.so.tl_666  no.gd.un_320 eu.et.so_532
  0x285564a0, 0x1a006b07, 0x35001a07, 0x1c0d0904,   // lg.rw.sw_322 ceb.tl.un_420  tl.zu.un_420 hi.ne.mr_332
  0x0a07110d, 0x29000f13, 0x0c2d0d02, 0x68131b05,   // ro.bg.mk_554 lv.sl.un_650  cs.sk.sv_222 tr.et.ig_333
  0x17000f0b, 0x0c0e3f04, 0x060713a0, 0x033f1f55,   // lv.sr.un_520 af.is.sv_332  et.it.de_322 cy.af.nl_442
  // [0c10]
  0x12000702, 0x2d0d3fa0, 0x08002704, 0x1c000d0d,   // it.hu.un_220 af.cs.sk_322  gd.no.un_320 ne.mr.un_540
  0x29001708, 0x1f010604, 0x35001f04, 0x553521a0,   // sr.sl.un_430 de.en.cy_332  cy.zu.un_320 jw.zu.rw_322
  0x06000104, 0x080203ee, 0x0e3b1fa0, 0x17000704,   // en.de.un_320 nl.da.no_422  cy.so.is_322 it.sr.un_320
  0x06001f0d, 0x033f100b, 0x122d0d08, 0x520c08a0,   // cy.de.un_540 lt.af.nl_542  cs.sk.hu_443 no.sv.ha_322
  // [0c20]
  0x11251fa9, 0x07000a0e, 0x073f0302, 0x3f001f14,   // cy.eu.ro_544 mk.bg.un_550  nl.af.it_222 cy.af.un_660
  0x12000e12, 0x17060505, 0x1c0c2105, 0x131701a4,   // is.hu.un_640 fr.de.sr_333  jw.sv.id_333 en.sr.et_433
  0x0c00130c, 0x2a005204, 0x01000304, 0x21002304,   // et.sv.un_530 ha.mt.un_320  nl.en.un_320 ca.jw.un_320
  0x190b0aa9, 0x0a2a0107, 0x186e2aa9, 0x200401ee,   // pt.es.gl_544 en.mt.pt_432  mt.hmn.ga_544 en.fi.sq_422
  // [0c30]
  0x6b0305ee, 0x2100120c, 0x0c006b07, 0x041008a4,   // fr.nl.ceb_422 ur.fa.un_530  ceb.sv.un_420 uk.be.ru_433
  0x0700100d, 0x0800110d, 0x2d190a55, 0x08031212,   // be.bg.un_540 ro.uk.un_540  pt.gl.sk_442 hu.nl.no_654
  0x04001005, 0x16000304, 0x321703a0, 0x11000411,   // be.ru.un_330 nl.hr.un_320  nl.sr.bs_322 fi.ro.un_630
  0x32082d07, 0x0d001b05, 0x3f00060c, 0x04001104,   // sk.no.bs_432 tr.cs.un_330  de.af.un_530 ro.fi.un_320
  // [0c40]
  0x12000104, 0x1b202da0, 0x182735ee, 0x0a00050c,   // en.hu.un_320 sk.sq.tr_322  zu.gd.ga_422 fr.pt.un_530
  0x04682511, 0x19050104, 0x6b001a05, 0x00001a0a,   // eu.ig.fi_653 en.fr.gl_332  tl.ceb.un_330 tl.un.un_500
  0x1a134aa7, 0x35006812, 0x5200250e, 0x00001301,   // yo.et.tl_532 ig.zu.un_640  eu.ha.un_550 bh.un.un_200
  0x2111050c, 0x17070aad, 0x1000041a, 0x0c250107,   // fr.ro.jw_543 mk.bg.sr_643  ru.be.un_760 en.eu.sv_432
  // [0c50]
  0x354a2504, 0x2d0d55a9, 0x021018a0, 0x2b001e02,   // eu.yo.zu_332 rw.cs.sk_544  ga.lt.da_322 ms.vi.un_220
  0x23000107, 0x0c000e02, 0x2d0d090c, 0x0e002d0c,   // en.ca.un_420 is.sv.un_220  pl.cs.sk_543 sk.is.un_530
  0x53190a08, 0x18211211, 0x19000a0e, 0x2864120c,   // pt.gl.ht_443 ur.fa.ar_653  pt.gl.un_550 hu.lg.sw_543
  0x091c13a0, 0x0c001107, 0x12000a02, 0x271f1812,   // bh.mr.hi_322 ro.sv.un_420  pt.hu.un_220 ga.cy.gd_654
  // [0c60]
  0x17000711, 0x32311b0b, 0x00000c15, 0x09001312,   // bg.sr.un_630 tr.az.bs_542  sv.un.un_700 bh.hi.un_640
  0x31003b13, 0x17003104, 0x1a005502, 0x3f1c35a0,   // so.az.un_650 az.sr.un_320  rw.tl.un_220 zu.id.af_322
  0x27181fad, 0x21002007, 0x311a2712, 0x1c091309,   // cy.ga.gd_643 sq.jw.un_420  gd.tl.az_654 bh.hi.mr_444
  0x08111304, 0x17006e08, 0x28181fee, 0x55001a0c,   // et.ro.no_332 hmn.sr.un_430  cy.ga.sw_422 tl.rw.un_530
  // [0c70]
  0x03001b04, 0x0a0704ec, 0x08000c04, 0x20001307,   // tr.nl.un_320 ru.bg.mk_644  sv.no.un_320 et.sq.un_420
  0x2d0d1807, 0x20080c04, 0x21000504, 0x0c005507,   // ga.cs.sk_432 sv.no.sq_332  fr.jw.un_320 rw.sv.un_420
  0x11002104, 0x20231108, 0x640b11ee, 0x2d0d0faf,   // jw.ro.un_320 ro.ca.sq_443  ro.es.lg_422 lv.cs.sk_655
  0x05000704, 0x0d022d07, 0x0d1c130c, 0x1f6401a4,   // it.fr.un_320 sk.da.cs_432  bh.mr.ne_543 en.lg.cy_433
  // [0c80]
  0x21060807, 0x0d002d0c, 0x16003207, 0x0c000e0d,   // no.de.jw_432 sk.cs.un_530  bs.hr.un_420 is.sv.un_540
  0x2d0d200c, 0x04001002, 0x17070aaf, 0x07000304,   // sq.cs.sk_543 be.ru.un_220  mk.bg.sr_655 nl.it.un_320
  0x0f130e04, 0x16352855, 0x170411ee, 0x2d2110a6,   // is.et.lv_332 sw.zu.hr_442  ro.ru.sr_422 lt.jw.sk_521
  0x0d091ca9, 0x08291204, 0x0c080ea0, 0x20000e12,   // mr.hi.ne_544 hu.sl.no_332  is.no.sv_322 is.sq.un_640
  // [0c90]
  0x2d0d29a4, 0x180e4a09, 0x0900350d, 0x08070405,   // sl.cs.sk_433 yo.is.ga_444  zu.pl.un_540 ru.bg.uk_333
  0x080b06ee, 0x1b041207, 0x182820a4, 0x1f002802,   // de.es.no_422 hu.fi.tr_432  sq.sw.ga_433 sw.cy.un_220
  0x07005308, 0x04001313, 0x21000204, 0x12111ba0,   // ht.it.un_430 et.fi.un_650  da.jw.un_320 tr.ro.hu_322
  0x29002d13, 0x040810a0, 0x23000a04, 0x08000c07,   // sk.sl.un_650 be.uk.ru_322  pt.ca.un_320 sv.no.un_420
  // [0ca0]
  0x55006404, 0x170a070d, 0x13091c60, 0x10051f0c,   // lg.rw.un_320 bg.mk.sr_554  mr.hi.bh_664 cy.fr.lt_543
  0x050320ee, 0x23060108, 0x0f0912ad, 0x00000d01,   // sq.nl.fr_422 en.de.ca_443  hu.pl.lv_643 ne.un.un_200
  0x27003b0d, 0x1e1c120e, 0x53002304, 0x1f005502,   // so.gd.un_540 hu.id.ms_555  ca.ht.un_320 rw.cy.un_220
  0x21002a04, 0x4a00520e, 0x17100a05, 0x28006b07,   // mt.jw.un_320 ha.yo.un_550  mk.be.sr_333 ceb.sw.un_420
  // [0cb0]
  0x033f25a0, 0x1b003109, 0x0e0306a4, 0x2a030613,   // eu.af.nl_322 az.tr.un_440  de.nl.is_433 de.nl.mt_665
  0x1c132755, 0x12002013, 0x2704060d, 0x05005312,   // gd.et.id_442 sq.hu.un_650  de.fi.gd_554 ht.fr.un_640
  0x3f000607, 0x6b033fee, 0x181f0555, 0x09000d04,   // de.af.un_420 af.nl.ceb_422  fr.cy.ga_442 ne.hi.un_320
  0x0c001f02, 0x271203ee, 0x31051b04, 0x52001f11,   // cy.sv.un_220 nl.hu.gd_422  tr.fr.az_332 cy.ha.un_630
  // [0cc0]
  0x55006808, 0x0b0a05ee, 0x1b003108, 0x0b231907,   // ig.rw.un_430 fr.pt.es_422  az.tr.un_430 gl.ca.es_432
  0x0804070b, 0x035207ee, 0x0b000a02, 0x08030607,   // bg.ru.uk_542 it.ha.nl_422  pt.es.un_220 de.nl.no_432
  0x4a133507, 0x53110107, 0x1b2153a0, 0x02000c04,   // zu.et.yo_432 en.ro.ht_432  ht.jw.tr_322 sv.da.un_320
  0x1a2a010c, 0x556421ec, 0x64001c05, 0x3f072aa0,   // en.mt.tl_543 jw.lg.rw_644  id.lg.un_330 mt.it.af_322
  // [0cd0]
  0x0e060107, 0x25001a04, 0x55063f02, 0x311b1208,   // en.de.is_432 tl.eu.un_320  af.de.rw_222 hu.tr.az_443
  0x25003514, 0x0a1017ee, 0x04005509, 0x0e2d0d13,   // zu.eu.un_660 sr.be.mk_422  rw.fi.un_440 cs.sk.is_665
  0x251035a0, 0x080f100c, 0x1f6b010c, 0x1b3b04ad,   // zu.lt.eu_322 lt.lv.no_543  en.ceb.cy_543 fi.so.tr_643
  0x1a002307, 0x0c086ba0, 0x08060c07, 0x063f04a4,   // ca.tl.un_420 ceb.no.sv_322  sv.de.no_432 fi.af.de_433
  // [0ce0]
  0x070a1704, 0x211218ac, 0x35682a07, 0x10552511,   // sr.mk.bg_332 ar.ur.fa_632  mt.ig.zu_432 eu.rw.lt_653
  0x211c0e0e, 0x06002002, 0x2800250c, 0x6b002505,   // is.id.jw_555 sq.de.un_220  eu.sw.un_530 eu.ceb.un_330
  0x10000413, 0x2a002304, 0x01091b08, 0x10000708,   // ru.be.un_650 ca.mt.un_320  tr.pl.en_443 bg.be.un_430
  0x2d001213, 0x020e1f04, 0x6b005518, 0x04003b0b,   // hu.sk.un_650 cy.is.da_332  rw.ceb.un_740 so.fi.un_520
  // [0cf0]
  0x08110a07, 0x35551f07, 0x2a271808, 0x121b3112,   // mk.ro.uk_432 cy.rw.zu_432  ga.gd.mt_443 az.tr.hu_654
  0x201e31ee, 0x4a005214, 0x0800230e, 0x086828a4,   // az.ms.sq_422 ha.yo.un_660  ca.no.un_550 sw.ig.no_433
  0x55281a08, 0x2d0d35ee, 0x092a28a7, 0x20190a08,   // tl.sw.rw_443 zu.cs.sk_422  sw.mt.pl_532 pt.gl.sq_443
  0x17070407, 0x32002a12, 0x17321608, 0x1e001c09,   // ru.bg.sr_432 mt.bs.un_640  hr.bs.sr_443 id.ms.un_440
  // [0d00]
  0x08070a07, 0x0d002d19, 0x2a00310c, 0x121629a4,   // mk.bg.uk_432 sk.cs.un_750  az.mt.un_530 sl.hr.hu_433
  0x2d000d19, 0x080e06a0, 0x040a1002, 0x3b312a0d,   // cs.sk.un_750 de.is.no_322  be.mk.ru_222 mt.az.so_554
  0x35005512, 0x063f0407, 0x06006404, 0x64006812,   // rw.zu.un_640 fi.af.de_432  lg.de.un_320 ig.lg.un_640
  0x4a006809, 0x0a001112, 0x102d0d05, 0x52091804,   // ig.yo.un_440 ro.mk.un_640  cs.sk.lt_333 ga.pl.ha_332
  // [0d10]
  0x27003112, 0x101809ad, 0x080203a4, 0x0d09130c,   // az.gd.un_640 pl.ga.lt_643  nl.da.no_433 bh.hi.ne_543
  0x280413ee, 0x190b12af, 0x092104ad, 0x10283b0d,   // et.fi.sw_422 hu.es.gl_655  fi.jw.pl_643 so.sw.lt_554
  0x202931ee, 0x070105a0, 0x64072811, 0x351e0d12,   // az.sl.sq_422 fr.en.it_322  sw.it.lg_653 cs.ms.zu_654
  0x083f0c02, 0x0e3109ad, 0x08071705, 0x211812ee,   // sv.af.no_222 pl.az.is_643  sr.bg.uk_333 ur.ar.fa_422
  // [0d20]
  0x0d000911, 0x532105a7, 0x1c090d0c, 0x53090fa0,   // hi.ne.un_630 fr.jw.ht_532  ne.hi.mr_543 lv.pl.ht_322
  0x2a000f11, 0x1a536ba7, 0x1c00350b, 0x0c00080e,   // lv.mt.un_630 ceb.ht.tl_532  zu.id.un_520 no.sv.un_550
  0x2d0d09a6, 0x07040aee, 0x27211f04, 0x554a1007,   // pl.cs.sk_521 mk.ru.bg_422  cy.jw.gd_332 lt.yo.rw_432
  0x0a171114, 0x3500640d, 0x1c090d0b, 0x060e08a0,   // ro.sr.mk_666 lg.zu.un_540  ne.hi.mr_542 no.is.de_322
  // [0d30]
  0x106409ee, 0x00003b06, 0x0a0807a4, 0x1e00060d,   // pl.lg.lt_422 so.un.un_400  bg.uk.mk_433 de.ms.un_540
  0x1b2a020c, 0x03001313, 0x3b000407, 0x070a0405,   // da.mt.tr_543 et.nl.un_650  fi.so.un_420 ru.mk.bg_333
  0x3f130112, 0x64002a13, 0x09000c04, 0x03063fee,   // en.et.af_654 mt.lg.un_650  sv.pl.un_320 af.de.nl_422
  0x1f00130c, 0x0500011a, 0x122925ac, 0x04001211,   // et.cy.un_530 en.fr.un_760  eu.sl.hu_632 hu.fi.un_630
  // [0d40]
  0x4a1a6ba0, 0x556428af, 0x0c000609, 0x25190b13,   // ceb.tl.yo_322 sw.lg.rw_655  de.sv.un_440 es.gl.eu_665
  0x17070aa4, 0x1a006b0e, 0x1c000d1a, 0x05680107,   // mk.bg.sr_433 ceb.tl.un_550  ne.mr.un_760 en.ig.fr_432
  0x010c18ee, 0x08170aa0, 0x53000507, 0x21041809,   // ga.sv.en_422 mk.sr.uk_322  fr.ht.un_420 ga.fi.jw_444
  0x08041005, 0x06000c04, 0x01001f13, 0x64325508,   // be.ru.uk_333 sv.de.un_320  cy.en.un_650 rw.bs.lg_443
  // [0d50]
  0x131c090c, 0x19004a07, 0x183527af, 0x09271fee,   // hi.mr.bh_543 yo.gl.un_420  gd.zu.ga_655 cy.gd.pl_422
  0x08170a02, 0x04122807, 0x2a525304, 0x4a172905,   // mk.sr.uk_222 sw.hu.fi_432  ht.ha.mt_332 sl.sr.yo_333
  0x2a072007, 0x19000707, 0x351e10a0, 0x06033fa0,   // sq.it.mt_432 it.gl.un_420  lt.ms.zu_322 af.nl.de_322
  0x1a001e04, 0x102d110e, 0x2a1125a4, 0x27002819,   // ms.tl.un_320 ro.sk.lt_555  eu.ro.mt_433 sw.gd.un_750
  // [0d60]
  0x090d130c, 0x292028a7, 0x1c0d09ee, 0x2a552105,   // bh.ne.hi_543 sw.sq.sl_532  hi.ne.mr_422 jw.rw.mt_333
  0x5200640b, 0x090d1307, 0x1a006b05, 0x355525a9,   // lg.ha.un_520 bh.ne.hi_432  ceb.tl.un_330 eu.rw.zu_544
  0x55003505, 0x55642812, 0x20000104, 0x18001219,   // zu.rw.un_330 sw.lg.rw_654  en.sq.un_320 ur.ar.un_750
  0x13090daf, 0x2d2928a4, 0x01001a04, 0x0425280d,   // ne.hi.bh_655 sw.sl.sk_433  tl.en.un_320 sw.eu.fi_554
  // [0d70]
  0x281f6407, 0x06003f05, 0x2118120d, 0x21193502,   // lg.cy.sw_432 af.de.un_330  ur.ar.fa_554 zu.gl.jw_222
  0x20003109, 0x17002909, 0x04006b08, 0x10531ba4,   // az.sq.un_440 sl.sr.un_440  ceb.fi.un_430 tr.ht.lt_433
  0x0913040d, 0x2700252b, 0x27001822, 0x52001e07,   // fi.et.pl_554 eu.gd.un_980  ga.gd.un_870 ms.ha.un_420
  0x190b550b, 0x10000702, 0x05190aa7, 0x08000604,   // rw.es.gl_542 it.lt.un_220  pt.gl.fr_532 de.no.un_320
  // [0d80]
  0x0f002504, 0x11001902, 0x531a6b5a, 0x08000a04,   // eu.lv.un_320 gl.ro.un_220  ceb.tl.ht_553 pt.no.un_320
  0x130853ec, 0x536b1a55, 0x06001c02, 0x0400250c,   // ht.no.et_644 tl.ceb.ht_442  id.de.un_220 eu.fi.un_530
  0x12000c08, 0x0000240a, 0x080e06af, 0x2a4a6808,   // sv.hu.un_430 yi.un.un_500  de.is.no_655 ig.yo.mt_443
  0x3b006b04, 0x20120ba0, 0x0b2327a0, 0x530527a0,   // ceb.so.un_320 es.hu.sq_322  gd.ca.es_322 gd.fr.ht_322
  // [0d90]
  0x1b2331ad, 0x0d001304, 0x23000b07, 0x09000d20,   // az.ca.tr_643 bh.ne.un_320  es.ca.un_420 ne.hi.un_850
  0x52000e07, 0x17000a21, 0x2d1629ee, 0x25000411,   // is.ha.un_420 mk.sr.un_860  sl.hr.sk_422 fi.eu.un_630
  0x0400130c, 0x2d0d3b08, 0x07170a02, 0x040810a9,   // et.fi.un_530 so.cs.sk_443  mk.sr.bg_222 be.uk.ru_544
  0x232a01a0, 0x100920a0, 0x18211208, 0x250810ee,   // en.mt.ca_322 sq.pl.lt_322  ur.fa.ar_443 lt.no.eu_422
  // [0da0]
  0x13003b0c, 0x1f00100e, 0x0b2519ee, 0x170a11a7,   // so.et.un_530 lt.cy.un_550  gl.eu.es_422 ro.mk.sr_532
  0x040810a4, 0x0c0413ec, 0x100a17a4, 0x04060c0c,   // be.uk.ru_433 et.fi.sv_644  sr.mk.be_433 sv.de.fi_543
  0x53356408, 0x00005324, 0x0f006b04, 0x5564280c,   // lg.zu.ht_443 ht.un.un_900  ceb.lv.un_320 sw.lg.rw_543
  0x6800281a, 0x6b0501a0, 0x08070414, 0x080205ee,   // sw.ig.un_760 en.fr.ceb_322  ru.bg.uk_666 fr.da.no_422
  // [0db0]
  0x130d1c0d, 0x21001220, 0x3b000108, 0x10002d02,   // mr.ne.bh_554 ur.fa.un_850  en.so.un_430 sk.lt.un_220
  0x091c0d0c, 0x21005302, 0x131a0407, 0x32092904,   // ne.mr.hi_543 ht.jw.un_220  fi.tl.et_432 sl.pl.bs_332
  0x3b2a07ad, 0x0407115a, 0x030e06ad, 0x0c3f03ee,   // it.mt.so_643 ro.bg.ru_553  de.is.nl_643 nl.af.sv_422
  0x0e0c0612, 0x643f030d, 0x07040aa9, 0x17000707,   // de.sv.is_654 nl.af.lg_554  mk.ru.bg_544 bg.sr.un_420
  // [0dc0]
  0x35002808, 0x3f00080c, 0x0200080b, 0x1e006e08,   // sw.zu.un_430 no.af.un_530  no.da.un_520 hmn.ms.un_430
  0x08001b0e, 0x05000108, 0x554a6408, 0x0d1c0955,   // tr.no.un_550 en.fr.un_430  lg.yo.rw_443 hi.mr.ne_442
  0x0a101705, 0x211a3bee, 0x080704ec, 0x3f002102,   // sr.be.mk_333 so.tl.jw_422  ru.bg.uk_644 jw.af.un_220
  0x31005508, 0x0a2d0d04, 0x0a081704, 0x08000f05,   // rw.az.un_430 cs.sk.pt_332  sr.uk.mk_332 lv.no.un_330
  // [0dd0]
  0x091c0daf, 0x04000c05, 0x07000412, 0x0a00110d,   // ne.mr.hi_655 sv.fi.un_330  ru.bg.un_640 ro.mk.un_540
  0x0b0d1907, 0x531b310b, 0x4a005509, 0x64006b04,   // gl.cs.es_432 az.tr.ht_542  rw.yo.un_440 ceb.lg.un_320
  0x1800120e, 0x04080aa9, 0x2d000b02, 0x55000104,   // ur.ar.un_550 mk.uk.ru_544  es.sk.un_220 en.rw.un_320
  0x55001602, 0x27001604, 0x0e005219, 0x25045307,   // hr.rw.un_220 hr.gd.un_320  ha.is.un_750 ht.fi.eu_432
  // [0de0]
  0x10001104, 0x2100120b, 0x06001f12, 0x17000207,   // ro.lt.un_320 ur.fa.un_520  cy.de.un_640 da.sr.un_420
  0x1a0f1ba4, 0x17080aa4, 0x2a003109, 0x04081008,   // tr.lv.tl_433 mk.uk.sr_433  az.mt.un_440 be.uk.ru_443
  0x6b4a1a07, 0x21001212, 0x53003b02, 0x180e23a7,   // tl.yo.ceb_432 ur.fa.un_640  so.ht.un_220 ca.is.ga_532
  0x29002007, 0x0c08025a, 0x0f1001a0, 0x0a081707,   // sq.sl.un_420 da.no.sv_553  en.lt.lv_322 sr.uk.mk_432
  // [0df0]
  0x2d120d09, 0x530d065a, 0x00000203, 0x09310e04,   // cs.hu.sk_444 de.cs.ht_553  da.un.un_300 is.az.pl_332
  0x555328a0, 0x1c001e04, 0x3f002b11, 0x11080207,   // sw.ht.rw_322 ms.id.un_320  vi.af.un_630 da.no.ro_432
  0x290f0c09, 0x10170aee, 0x083b0e07, 0x080c09a7,   // sv.lv.sl_444 mk.sr.be_422  is.so.no_432 pl.sv.no_532
  0x0a170714, 0x0a171007, 0x09002b08, 0x1e001c07,   // bg.sr.mk_666 be.sr.mk_432  vi.pl.un_430 id.ms.un_420
  // [0e00]
  0x29211313, 0x063f3b07, 0x17100aa0, 0x07080412,   // et.jw.sl_665 so.af.de_432  mk.be.sr_322 ru.uk.bg_654
  0x04003b12, 0x00003101, 0x1f0e18a6, 0x0000251c,   // so.fi.un_640 az.un.un_200  ga.is.cy_521 eu.un.un_800
  0x2a3f0ea4, 0x0f001707, 0x03001c05, 0x3528550c,   // is.af.mt_433 sr.lv.un_420  id.nl.un_330 rw.sw.zu_543
  0x0a001907, 0x100a0708, 0x53001a04, 0x091c0d0e,   // gl.pt.un_420 bg.mk.be_443  tl.ht.un_320 ne.mr.hi_555
  // [0e10]
  0x030e08a4, 0x09006b08, 0x18002904, 0x07001111,   // no.is.nl_433 ceb.pl.un_430  sl.ga.un_320 ro.bg.un_630
  0x0717110c, 0x11000a02, 0x0c0208ec, 0x19000e09,   // ro.sr.bg_543 pt.ro.un_220  no.da.sv_644 is.gl.un_440
  0x091c0d12, 0x09000304, 0x0d091cec, 0x052301a0,   // ne.mr.hi_654 nl.pl.un_320  mr.hi.ne_644 en.ca.fr_322
  0x166b1804, 0x5500280d, 0x3f033baf, 0x04081760,   // ga.ceb.hr_332 sw.rw.un_540  so.nl.af_655 sr.uk.ru_664
  // [0e20]
  0x55003513, 0x1b522508, 0x0e031aee, 0x21000b04,   // zu.rw.un_650 eu.ha.tr_443  tl.nl.is_422 es.jw.un_320
  0x03063f0c, 0x2b0b23a0, 0x1a1b0fa4, 0x120a2304,   // af.de.nl_543 ca.es.vi_322  lv.tr.tl_433 ca.pt.hu_332
  0x532a07a0, 0x556b1aa0, 0x32162904, 0x20001b14,   // it.mt.ht_322 tl.ceb.rw_322  sl.hr.bs_332 tr.sq.un_660
  0x526b6808, 0x0200040c, 0x3b003112, 0x13001a08,   // ig.ceb.ha_443 fi.da.un_530  az.so.un_640 tl.et.un_430
  // [0e30]
  0x291e080c, 0x1c130914, 0x0a0710a0, 0x551c21a0,   // no.ms.sl_543 hi.bh.mr_666  be.bg.mk_322 jw.id.rw_322
  0x0a071160, 0x3b003f19, 0x1c0752a9, 0x11002702,   // ro.bg.mk_664 af.so.un_750  ha.it.id_544 gd.ro.un_220
  0x23190704, 0x3b1b1604, 0x055325a4, 0x0e000207,   // it.gl.ca_332 hr.tr.so_332  eu.ht.fr_433 da.is.un_420
  0x29090da9, 0x190b1aee, 0x64553512, 0x53002512,   // cs.pl.sl_544 tl.es.gl_422  zu.rw.lg_654 eu.ht.un_640
  // [0e40]
  0x181221ad, 0x2a002704, 0x091a55a0, 0x1f006b08,   // fa.ur.ar_643 gd.mt.un_320  rw.tl.pl_322 ceb.cy.un_430
  0x1b290d0b, 0x1c0913a6, 0x04110807, 0x131c09ec,   // cs.sl.tr_542 bh.hi.mr_521  uk.ro.ru_432 hi.mr.bh_644
  0x25041308, 0x233f2ba9, 0x1e1c2855, 0x1300280d,   // et.fi.eu_443 vi.af.ca_544  sw.id.ms_442 sw.et.un_540
  0x4a0e2dad, 0x1f040707, 0x1e1f1ca0, 0x251c1fee,   // sk.is.yo_643 it.fi.cy_432  id.cy.ms_322 cy.id.eu_422
  // [0e50]
  0x04080712, 0x23051f07, 0x18005304, 0x1c1208ad,   // bg.uk.ru_654 cy.fr.ca_432  ht.ga.un_320 no.hu.id_643
  0x3b4a3505, 0x03000a07, 0x09131c55, 0x0e002d12,   // zu.yo.so_333 pt.nl.un_420  mr.bh.hi_442 sk.is.un_640
  0x17311fad, 0x21063fa4, 0x17001004, 0x28005307,   // cy.az.sr_643 af.de.jw_433  be.sr.un_320 ht.sw.un_420
  0x3f002012, 0x03000504, 0x2a002102, 0x18122112,   // sq.af.un_640 fr.nl.un_320  jw.mt.un_220 fa.ur.ar_654
  // [0e60]
  0x1b063107, 0x6b081302, 0x130e0ca7, 0x19051004,   // az.de.tr_432 et.no.ceb_222  sv.is.et_532 lt.fr.gl_332
  0x0d091c12, 0x2a001f13, 0x00002d1c, 0x6b001a19,   // mr.hi.ne_654 cy.mt.un_650  sk.un.un_800 tl.ceb.un_750
  0x194a0b0c, 0x32005504, 0x0f292aa0, 0x1a683b0c,   // es.yo.gl_543 rw.bs.un_320  mt.sl.lv_322 so.ig.tl_543
  0x32043baf, 0x080a1007, 0x23000108, 0x12000d13,   // so.fi.bs_655 be.mk.uk_432  en.ca.un_430 cs.hu.un_650
  // [0e70]
  0x121821a9, 0x1f001104, 0x27201f04, 0x17001c02,   // fa.ar.ur_544 ro.cy.un_320  cy.sq.gd_332 id.sr.un_220
  0x4a002102, 0x29000d11, 0x3f040304, 0x4a120b09,   // jw.yo.un_220 cs.sl.un_630  nl.fi.af_332 es.hu.yo_444
  0x0d322904, 0x12000a04, 0x112b01a4, 0x1c000504,   // sl.bs.cs_332 pt.hu.un_320  en.vi.ro_433 fr.id.un_320
  0x020c08a4, 0x095505a7, 0x55005313, 0x29131a07,   // no.sv.da_433 fr.rw.pl_532  ht.rw.un_650 tl.et.sl_432
  // [0e80]
  0x091c1355, 0x2d0d29ec, 0x0b00010d, 0x07000104,   // bh.mr.hi_442 sl.cs.sk_644  en.es.un_540 en.it.un_320
  0x190b0a09, 0x19122d0c, 0x0f002a19, 0x1c290207,   // pt.es.gl_444 sk.hu.gl_543  mt.lv.un_750 da.sl.id_432
  0x25001f19, 0x1800270d, 0x070f0a08, 0x131c0d07,   // cy.eu.un_750 gd.ga.un_540  pt.lv.it_443 ne.mr.bh_432
  0x0e000c0e, 0x27001805, 0x10000807, 0x11002013,   // sv.is.un_550 ga.gd.un_330  no.lt.un_420 sq.ro.un_650
  // [0e90]
  0x0a0804a6, 0x27001a09, 0x55002702, 0x3f1f04ad,   // ru.uk.mk_521 tl.gd.un_440  gd.rw.un_220 fi.cy.af_643
  0x18002705, 0x0d001312, 0x050f5209, 0x040a0707,   // gd.ga.un_330 bh.ne.un_640  ha.lv.fr_444 bg.mk.ru_432
  0x13090dac, 0x10000814, 0x0d002d11, 0x0d2d35ad,   // ne.hi.bh_632 uk.be.un_660  sk.cs.un_630 zu.sk.cs_643
  0x063f0355, 0x04170a55, 0x53282004, 0x0f0d1b04,   // nl.af.de_442 mk.sr.ru_442  sq.sw.ht_332 tr.cs.lv_332
  // [0ea0]
  0x06033f0d, 0x02003f05, 0x070411ee, 0x3f1720a4,   // af.nl.de_554 af.da.un_330  ro.ru.bg_422 sq.sr.af_433
  0x6e092da0, 0x101a350c, 0x10002d07, 0x52006812,   // sk.pl.hmn_322 zu.tl.lt_543  sk.lt.un_420 ig.ha.un_640
  0x3200550c, 0x355564af, 0x5300110d, 0x080a0405,   // rw.bs.un_530 lg.rw.zu_655  ro.ht.un_540 ru.mk.uk_333
  0x53033f07, 0x21006b08, 0x29002d0e, 0x2d0d0905,   // af.nl.ht_432 ceb.jw.un_430  sk.sl.un_550 pl.cs.sk_333
  // [0eb0]
  0x556435a7, 0x07170a07, 0x080710a0, 0x55003512,   // zu.lg.rw_532 mk.sr.bg_432  be.bg.uk_322 zu.rw.un_640
  0x0d130913, 0x0d001c0c, 0x0a002807, 0x2d050aee,   // hi.bh.ne_665 mr.ne.un_530  sw.pt.un_420 pt.fr.sk_422
  0x0c000e12, 0x280710a0, 0x17292da4, 0x311b1212,   // is.sv.un_640 lt.it.sw_322  sk.sl.sr_433 hu.tr.az_654
  0x17000d07, 0x1b0413a9, 0x1c090da4, 0x1e3b28a0,   // cs.sr.un_420 et.fi.tr_544  ne.hi.mr_433 sw.so.ms_322
  // [0ec0]
  0x122118ec, 0x0c003502, 0x0e001808, 0x3f050304,   // ar.fa.ur_644 zu.sv.un_220  ga.is.un_430 nl.fr.af_332
  0x10040711, 0x17000813, 0x2d3216a0, 0x06005204,   // bg.ru.be_653 uk.sr.un_650  hr.bs.sk_322 ha.de.un_320
  0x3500680b, 0x13040c0c, 0x32002912, 0x0d0913ac,   // ig.zu.un_520 sv.fi.et_543  sl.bs.un_640 bh.hi.ne_632
  0x040817a0, 0x1300201a, 0x070a11a7, 0x28001207,   // sr.uk.ru_322 sq.et.un_760  ro.mk.bg_532 hu.sw.un_420
  // [0ed0]
  0x0a00180c, 0x08170a5a, 0x2d191207, 0x321f1baf,   // ga.pt.un_530 mk.sr.uk_553  hu.gl.sk_432 tr.cy.bs_655
  0x18005208, 0x07000a0d, 0x010528ad, 0x0500210b,   // ha.ga.un_430 mk.bg.un_540  sw.fr.en_643 jw.fr.un_520
  0x3100121a, 0x18011fad, 0x4a001013, 0x23530904,   // hu.az.un_760 cy.en.ga_643  lt.yo.un_650 pl.ht.ca_332
  0x1b310e0d, 0x4a0155a0, 0x2d001f05, 0x07000107,   // is.az.tr_554 rw.en.yo_322  cy.sk.un_330 en.it.un_420
  // [0ee0]
  0x3b2a19a0, 0x121f100d, 0x17002904, 0x0f0e0112,   // gl.mt.so_322 lt.cy.hu_554  sl.sr.un_320 en.is.lv_654
  0x3b0e0ca0, 0x250f0707, 0x2b00230d, 0x2d005313,   // sv.is.so_322 it.lv.eu_432  ca.vi.un_540 ht.sk.un_650
  0x0c130107, 0x27190b02, 0x0c13060b, 0x12001b04,   // en.et.sv_432 es.gl.gd_222  de.et.sv_542 tr.hu.un_320
  0x1c090d0d, 0x23003f09, 0x07061f07, 0x10071707,   // ne.hi.mr_554 af.ca.un_440  cy.de.it_432 sr.bg.be_432
  // [0ef0]
  0x13000919, 0x00000315, 0x0602520c, 0x55683512,   // hi.bh.un_750 nl.un.un_700  ha.da.de_543 zu.ig.rw_654
  0x062d0d04, 0x3f232904, 0x04551304, 0x08041707,   // cs.sk.de_332 sl.ca.af_332  et.rw.fi_332 sr.ru.uk_432
  0x11000302, 0x35000204, 0x04001013, 0x0e080255,   // nl.ro.un_220 da.zu.un_320  be.ru.un_650 da.no.is_442
  0x00006824, 0x02120807, 0x0c030807, 0x64355508,   // ig.un.un_900 no.hu.da_432  no.nl.sv_432 rw.zu.lg_443
  // [0f00]
  0x035207a0, 0x066b0107, 0x19000a02, 0x040811a0,   // it.ha.nl_322 en.ceb.de_432  pt.gl.un_220 ro.uk.ru_322
  0x1a002804, 0x012708a0, 0x170711a6, 0x193513ee,   // sw.tl.un_320 no.gd.en_322  ro.bg.sr_521 et.zu.gl_422
  0x2d1f05a0, 0x190b0705, 0x04081002, 0x07003b05,   // fr.cy.sk_322 it.es.gl_333  be.uk.ru_222 so.it.un_330
  0x32003f04, 0x04001709, 0x1e003108, 0x12005205,   // af.bs.un_320 sr.ru.un_440  az.ms.un_430 ha.hu.un_330
  // [0f10]
  0x04001705, 0x130e0407, 0x3500641a, 0x6b005513,   // sr.ru.un_330 fi.is.et_432  lg.zu.un_760 rw.ceb.un_650
  0x08041013, 0x00001724, 0x1f1b0e12, 0x531f2ba9,   // be.ru.uk_665 sr.un.un_900  is.tr.cy_654 vi.cy.ht_544
  0x25552807, 0x17101107, 0x20090f07, 0x21002312,   // sw.rw.eu_432 ro.be.sr_432  lv.pl.sq_432 ca.jw.un_640
  0x215511ee, 0x041711a0, 0x0a041707, 0x1b006405,   // ro.rw.jw_422 ro.sr.ru_322  sr.ru.mk_432 lg.tr.un_330
  // [0f20]
  0x171b04ee, 0x170a11a0, 0x64552a0c, 0x120a23ee,   // fi.tr.sr_422 ro.mk.sr_322  mt.rw.lg_543 ca.pt.hu_422
  0x01001f07, 0x033f28a6, 0x00001606, 0x1700110c,   // cy.en.un_420 sw.af.nl_521  hr.un.un_400 ro.sr.un_530
  0x20001f04, 0x17001119, 0x023f6b02, 0x041b3b0c,   // cy.sq.un_320 ro.sr.un_750  ceb.af.da_222 so.tr.fi_543
  0x27000308, 0x00005503, 0x21000512, 0x170811a0,   // nl.gd.un_430 rw.un.un_300  fr.jw.un_640 ro.uk.sr_322
  // [0f30]
  0x01091fee, 0x1a000411, 0x20251260, 0x13000904,   // cy.pl.en_422 fi.tl.un_630  hu.eu.sq_664 hi.bh.un_320
  0x070a17a4, 0x0000181c, 0x0400071a, 0x08001004,   // sr.mk.bg_433 ar.un.un_800  bg.ru.un_760 be.uk.un_320
  0x0f5235a0, 0x64003104, 0x3b231355, 0x02000604,   // zu.ha.lv_322 az.lg.un_320  et.ca.so_442 de.da.un_320
  0x2d005304, 0x05182711, 0x00001b1c, 0x0c1f3b07,   // ht.sk.un_320 gd.ga.fr_653  tr.un.un_800 so.cy.sv_432
  // [0f40]
  0x31001904, 0x1b005204, 0x06002102, 0x32002102,   // gl.az.un_320 ha.tr.un_320  jw.de.un_220 jw.bs.un_220
  0x033f23a4, 0x55006804, 0x3f0812ee, 0x16002913,   // ca.af.nl_433 ig.rw.un_320  hu.no.af_422 sl.hr.un_650
  0x122a1fa9, 0x3f021fec, 0x090d13ee, 0x07170a14,   // cy.mt.hu_544 cy.da.af_644  bh.ne.hi_422 mk.sr.bg_666
  0x04001312, 0x1800211a, 0x32002807, 0x1c001a04,   // et.fi.un_640 fa.ar.un_760  sw.bs.un_420 tl.id.un_320
  // [0f50]
  0x011a31ad, 0x19002304, 0x31000a05, 0x64002819,   // az.tl.en_643 ca.gl.un_320  pt.az.un_330 sw.lg.un_750
  0x121b0f04, 0x0c1306ad, 0x10000f19, 0x18284aa0,   // lv.tr.hu_332 de.et.sv_643  lv.lt.un_750 yo.sw.ga_322
  0x1e002302, 0x10000913, 0x1c1f0704, 0x10000714,   // ca.ms.un_220 pl.lt.un_650  it.cy.id_332 bg.be.un_660
  0x06003b12, 0x35000604, 0x0e1364ee, 0x0d092d07,   // so.de.un_640 de.zu.un_320  lg.et.is_422 sk.pl.cs_432
  // [0f60]
  0x02556ba0, 0x23022004, 0x065221a6, 0x0400640d,   // ceb.rw.da_322 sq.da.ca_332  jw.ha.de_521 lg.fi.un_540
  0x06033f04, 0x09033f02, 0x09001013, 0x040817a4,   // af.nl.de_332 af.nl.pl_222  lt.pl.un_650 sr.uk.ru_433
  0x64123504, 0x061e0e07, 0x0a0710af, 0x080a1708,   // zu.hu.lg_332 is.ms.de_432  be.bg.mk_655 sr.mk.uk_443
  0x04110713, 0x041008ad, 0x0800201a, 0x09006405,   // bg.ro.ru_665 uk.be.ru_643  sq.no.un_760 lg.pl.un_330
  // [0f70]
  0x0d350408, 0x52211c07, 0x041011ad, 0x3f0e08ad,   // fi.zu.cs_443 id.jw.ha_432  ro.be.ru_643 no.is.af_643
  0x6b001a12, 0x0a000707, 0x1c0d0912, 0x07100411,   // tl.ceb.un_640 bg.mk.un_420  hi.ne.mr_654 fi.lt.it_653
  0x100708a4, 0x030205ee, 0x0400101b, 0x1b3125ee,   // uk.bg.be_433 fr.da.nl_422  lt.fi.un_770 eu.az.tr_422
  0x211e1c08, 0x102012a7, 0x32063f0b, 0x0a000712,   // id.ms.jw_443 hu.sq.lt_532  af.de.bs_542 bg.mk.un_640
  // [0f80]
  0x071f27a4, 0x2920035a, 0x230e1b07, 0x1c06020d,   // gd.cy.it_433 nl.sq.sl_553  tr.is.ca_432 da.de.id_554
  0x18004a04, 0x19000e04, 0x09001009, 0x0a07040e,   // yo.ga.un_320 is.gl.un_320  lt.pl.un_440 ru.bg.mk_555
  0x1b1c1ea0, 0x55002514, 0x25000a08, 0x13000908,   // ms.id.tr_322 eu.rw.un_660  pt.eu.un_430 hi.bh.un_430
  0x53003f05, 0x170a0708, 0x09556404, 0x1900230d,   // af.ht.un_330 bg.mk.sr_443  lg.rw.pl_332 ca.gl.un_540
  // [0f90]
  0x280720ad, 0x64001c04, 0x1c090d11, 0x0400110c,   // sq.it.sw_643 id.lg.un_320  ne.hi.mr_653 ro.ru.un_530
  0x070410a7, 0x20001602, 0x29002808, 0x21352804,   // be.ru.bg_532 hr.sq.un_220  sw.sl.un_430 sw.zu.jw_332
  0x201a2507, 0x08001702, 0x3b1b2807, 0x28556409,   // eu.tl.sq_432 sr.no.un_220  sw.tr.so_432 lg.rw.sw_444
  0x0a002304, 0x17100808, 0x2d001008, 0x21000904,   // ca.pt.un_320 uk.be.sr_443  lt.sk.un_430 pl.jw.un_320
  // [0fa0]
  0x0e00081a, 0x29000919, 0x1b1f31af, 0x12000507,   // no.is.un_760 pl.sl.un_750  az.cy.tr_655 fr.hu.un_420
  0x19180d0e, 0x351b4a07, 0x06356404, 0x0d001c04,   // cs.ga.gl_555 yo.tr.zu_432  lg.zu.de_332 mr.ne.un_320
  0x1c13090e, 0x55005311, 0x556435ec, 0x1b200605,   // hi.bh.mr_555 ht.rw.un_630  zu.lg.rw_644 de.sq.tr_333
  0x046b53a0, 0x1a006b18, 0x21001f1b, 0x17321655,   // ht.ceb.fi_322 ceb.tl.un_740  cy.jw.un_770 hr.bs.sr_442
  // [0fb0]
  0x080c35ad, 0x1b003b0c, 0x0d000912, 0x0c000e07,   // zu.sv.no_643 so.tr.un_530  hi.ne.un_640 is.sv.un_420
  0x0b000a09, 0x04002804, 0x271f0107, 0x12000c07,   // pt.es.un_440 sw.fi.un_320  en.cy.gd_432 sv.hu.un_420
  0x110a0708, 0x052319a0, 0x31111b0c, 0x32000304,   // bg.mk.ro_443 gl.ca.fr_322  tr.ro.az_543 nl.bs.un_320
  0x2d0d55a0, 0x033b3204, 0x351b55a0, 0x213b53ad,   // rw.cs.sk_322 bs.so.nl_332  rw.tr.zu_322 ht.so.jw_643
  // [0fc0]
  0x2a00200c, 0x0e001214, 0x19000a07, 0x21553bee,   // sq.mt.un_530 hu.is.un_660  pt.gl.un_420 so.rw.jw_422
  0x6b080c02, 0x0b2d0d04, 0x1b000a07, 0x4a000a05,   // sv.no.ceb_222 cs.sk.es_332  pt.tr.un_420 pt.yo.un_330
  0x07170a08, 0x53005219, 0x190b1105, 0x06001809,   // mk.sr.bg_443 ha.ht.un_750  ro.es.gl_333 ga.de.un_440
  0x21201e09, 0x1c211e04, 0x06000b04, 0x1f003f0e,   // ms.sq.jw_444 ms.jw.id_332  es.de.un_320 af.cy.un_550
  // [0fd0]
  0x06000c07, 0x13091c12, 0x0a101707, 0x0825040c,   // sv.de.un_420 mr.hi.bh_654  sr.be.mk_432 fi.eu.no_543
  0x0000112d, 0x110a070c, 0x0704110c, 0x3f000305,   // ro.un.un_A00 it.pt.ro_543  ro.ru.bg_543 nl.af.un_330
  0x5535640d, 0x070a100e, 0x23000504, 0x03001104,   // lg.zu.rw_554 be.mk.bg_555  fr.ca.un_320 ro.nl.un_320
  0x084a0c04, 0x00001206, 0x0c080e55, 0x08001107,   // sv.yo.no_332 ur.un.un_400  is.no.sv_442 ro.no.un_420
  // [0fe0]
  0x683564a9, 0x171809ee, 0x1200280b, 0x136e28a4,   // lg.zu.ig_544 pl.ga.sr_422  sw.hu.un_520 sw.hmn.et_433
  0x35003114, 0x122d0dad, 0x2d000905, 0x6e6b68a0,   // az.zu.un_660 cs.sk.hu_643  pl.sk.un_330 ig.ceb.hmn_322
  0x04081007, 0x041b13ad, 0x11100f05, 0x08230ead,   // be.uk.ru_432 et.tr.fi_643  lv.lt.ro_333 is.ca.no_643
  0x6e003f13, 0x02006412, 0x28003504, 0x194a0eaf,   // af.hmn.un_650 lg.da.un_640  zu.sw.un_320 is.yo.gl_655
  // [0ff0]
  0x2a001704, 0x27532355, 0x0c000819, 0x13000411,   // sr.mt.un_320 ca.ht.gd_442  no.sv.un_750 fi.et.un_630
  0x032105ee, 0x32002d04, 0x0800180e, 0x1f000204,   // fr.jw.nl_422 sk.bs.un_320  ga.no.un_550 da.cy.un_320
  0x070a1707, 0x040710a4, 0x0810170d, 0x1c0621ee,   // sr.mk.bg_432 be.bg.ru_433  sr.be.uk_554 jw.de.id_422
  0x1b0c2ba0, 0x0f001011, 0x17100405, 0x13091c14,   // vi.sv.tr_322 lt.lv.un_630  ru.be.sr_333 mr.hi.bh_666

  // [1000]
  0x070804a4, 0x1c1309af, 0x23530511, 0x061801a4,   // ru.uk.bg_433 hi.bh.mr_655  fr.ht.ca_653 en.ga.de_433
  0x12180e5a, 0x1a003f04, 0x21001209, 0x0c080ea4,   // is.ga.hu_553 af.tl.un_320  ur.fa.un_440 is.no.sv_433
  0x190a0ba4, 0x0825010c, 0x06023f07, 0x08003f08,   // es.pt.gl_433 en.eu.no_543  af.da.de_432 af.no.un_430
  0x321629af, 0x27050108, 0x0f132004, 0x0200130c,   // sl.hr.bs_655 en.fr.gd_443  sq.et.lv_332 et.da.un_530
  // [1010]
  0x17100a04, 0x2d101211, 0x6b530507, 0x3f000c04,   // mk.be.sr_332 hu.lt.sk_653  fr.ht.ceb_432 sv.af.un_320
  0x1a3f6bee, 0x12000108, 0x133f0304, 0x03002102,   // ceb.af.tl_422 en.hu.un_430  nl.af.et_332 jw.nl.un_220
  0x09000d18, 0x01001308, 0x026b1a08, 0x202d11a0,   // ne.hi.un_740 et.en.un_430  tl.ceb.da_443 ro.sk.sq_322
  0x06000207, 0x05250d08, 0x00001101, 0x32001b07,   // da.de.un_420 cs.eu.fr_443  ro.un.un_200 tr.bs.un_420
  // [1020]
  0x0c020807, 0x00002003, 0x04170709, 0x3216100c,   // no.da.sv_432 sq.un.un_300  bg.sr.ru_444 lt.hr.bs_543
  0x20002104, 0x17000a1b, 0x1819010b, 0x17070a0d,   // jw.sq.un_320 mk.sr.un_770  en.gl.ga_542 mk.bg.sr_554
  0x21000d08, 0x25001b04, 0x0605010b, 0x4a2753a6,   // cs.jw.un_430 tr.eu.un_320  en.fr.de_542 ht.gd.yo_521
  0x4a2d0d07, 0x040a170b, 0x20001108, 0x23000704,   // cs.sk.yo_432 sr.mk.ru_542  ro.sq.un_430 it.ca.un_320
  // [1030]
  0x35006414, 0x060a04ad, 0x010a07ee, 0x21003b1a,   // lg.zu.un_660 fi.pt.de_643  it.pt.en_422 so.jw.un_760
  0x0a003512, 0x28000707, 0x03002107, 0x01003f05,   // zu.pt.un_640 it.sw.un_420  jw.nl.un_420 af.en.un_330
  0x02006b08, 0x02000307, 0x21000807, 0x1f006404,   // ceb.da.un_430 nl.da.un_420  no.jw.un_420 lg.cy.un_320
  0x23000507, 0x171011ad, 0x4a00211a, 0x10002918,   // fr.ca.un_420 ro.be.sr_643  jw.yo.un_760 sl.lt.un_740
  // [1040]
  0x27071f0c, 0x040711ac, 0x1c110107, 0x1b130414,   // cy.it.gd_543 ro.bg.ru_632  en.ro.id_432 fi.et.tr_666
  0x0c000e05, 0x04081004, 0x64000d12, 0x1a6b21ec,   // is.sv.un_330 be.uk.ru_332  cs.lg.un_640 jw.ceb.tl_644
  0x2d000908, 0x0f000704, 0x09000204, 0x10080c07,   // pl.sk.un_430 it.lv.un_320  da.pl.un_320 sv.no.lt_432
  0x1b002304, 0x1e001a02, 0x211812a7, 0x050601ad,   // ca.tr.un_320 tl.ms.un_220  ur.ar.fa_532 en.de.fr_643
  // [1050]
  0x12356408, 0x071704af, 0x53005519, 0x05000e04,   // lg.zu.hu_443 ru.sr.bg_655  rw.ht.un_750 is.fr.un_320
  0x4a002305, 0x356b2da0, 0x0c020ea0, 0x1c090d04,   // ca.yo.un_330 sk.ceb.zu_322  is.da.sv_322 ne.hi.mr_332
  0x0a071104, 0x1a5552ee, 0x021b03a0, 0x270553a0,   // ro.bg.mk_332 ha.rw.tl_422  nl.tr.da_322 ht.fr.gd_322
  0x1c211a04, 0x090d1c12, 0x00000406, 0x0000010a,   // tl.jw.id_332 mr.ne.hi_654  fi.un.un_400 iw.un.un_500
  // [1060]
  0x0c080214, 0x1f001e07, 0x06000307, 0x190b2509,   // da.no.sv_666 ms.cy.un_420  nl.de.un_420 eu.es.gl_444
  0x06000807, 0x04000a04, 0x13003207, 0x070f0107,   // no.de.un_420 mk.ru.un_320  bs.et.un_420 en.lv.it_432
  0x551f28a0, 0x6b006418, 0x09001c1a, 0x522a230e,   // sw.cy.rw_322 lg.ceb.un_740  mr.hi.un_760 ca.mt.ha_555
  0x1b322d0d, 0x25193b07, 0x0e002304, 0x0e0208af,   // sk.bs.tr_554 so.gl.eu_432  ca.is.un_320 no.da.is_655
  // [1070]
  0x3b0f52ad, 0x53052d05, 0x0f1f5304, 0x06000c09,   // ha.lv.so_643 sk.fr.ht_333  ht.cy.lv_332 sv.de.un_440
  0x121004af, 0x210825a7, 0x03062007, 0x090d1c11,   // fi.lt.hu_655 eu.no.jw_532  sq.de.nl_432 mr.ne.hi_653
  0x06000309, 0x2d3f0d0d, 0x07040a02, 0x0d002902,   // nl.de.un_440 cs.af.sk_554  mk.ru.bg_222 sl.cs.un_220
  0x04645507, 0x07005304, 0x0b2308a4, 0x6b2135ad,   // rw.lg.fi_432 ht.it.un_320  no.ca.es_433 zu.jw.ceb_643
  // [1080]
  0x3f0106a7, 0x4a002107, 0x1e533f04, 0x5200640c,   // de.en.af_532 jw.yo.un_420  af.ht.ms_332 lg.ha.un_530
  0x282b1bee, 0x3b002019, 0x10040813, 0x13000d09,   // tr.vi.sw_422 sq.so.un_750  uk.ru.be_665 ne.bh.un_440
  0x1c0d090d, 0x17080a07, 0x23000a0b, 0x170a0407,   // hi.ne.mr_554 mk.uk.sr_432  pt.ca.un_520 ru.mk.sr_432
  0x01003505, 0x091c13ee, 0x020e0c04, 0x0c080b02,   // zu.en.un_330 bh.mr.hi_422  sv.is.da_332 es.no.sv_222
  // [1090]
  0x16042907, 0x1f133b08, 0x1f1a6bad, 0x35002513,   // sl.fi.hr_432 so.et.cy_443  ceb.tl.cy_643 eu.zu.un_650
  0x18122160, 0x2d0d10ec, 0x08023f09, 0x0c00100d,   // fa.ur.ar_664 lt.cs.sk_644  af.da.no_444 lt.sv.un_540
  0x080925a0, 0x0a081004, 0x13033f08, 0x10000412,   // eu.pl.no_322 be.uk.mk_332  af.nl.et_443 ru.be.un_640
  0x0f001013, 0x04070aee, 0x112d0d04, 0x1c0d0905,   // lt.lv.un_650 mk.bg.ru_422  cs.sk.ro_332 hi.ne.mr_333
  // [10a0]
  0x08000607, 0x07001004, 0x07001112, 0x07000513,   // de.no.un_420 be.bg.un_320  ro.bg.un_640 fr.it.un_650
  0x10000f0e, 0x23032b0c, 0x0d040604, 0x6e211207,   // lv.lt.un_550 vi.nl.ca_543  de.fi.cs_332 hu.jw.hmn_432
  0x1e1a28a7, 0x00002d03, 0x10000f12, 0x093202a0,   // sw.tl.ms_532 sk.un.un_300  lv.lt.un_640 da.bs.pl_322
  0x17070aee, 0x04001019, 0x18000d05, 0x06001a02,   // mk.bg.sr_422 be.ru.un_750  cs.ga.un_330 tl.de.un_220
  // [10b0]
  0x070501a4, 0x12003107, 0x3b000712, 0x03003f18,   // en.fr.it_433 az.hu.un_420  it.so.un_640 af.nl.un_740
  0x17002908, 0x3f006e04, 0x08002512, 0x29003f02,   // sl.sr.un_430 hmn.af.un_320  eu.no.un_640 af.sl.un_220
  0x2d0d0fa0, 0x21291e04, 0x1a002102, 0x12003504,   // lv.cs.sk_322 ms.sl.jw_332  jw.tl.un_220 zu.hu.un_320
  0x20003b09, 0x100705a0, 0x08000a14, 0x100a17af,   // so.sq.un_440 fr.it.lt_322  mk.uk.un_660 sr.mk.be_655
  // [10c0]
  0x25180107, 0x011f35a0, 0x080417ee, 0x2a2012ec,   // en.ga.eu_432 zu.cy.en_322  sr.ru.uk_422 hu.sq.mt_644
  0x08071704, 0x0c031311, 0x55002513, 0x35001104,   // sr.bg.uk_332 et.nl.sv_653  eu.rw.un_650 ro.zu.un_320
  0x68002513, 0x52006e05, 0x040a0711, 0x230e0da0,   // eu.ig.un_650 hmn.ha.un_330  bg.mk.ru_653 cs.is.ca_322
  0x6b1135a7, 0x07080a07, 0x16001704, 0x2a2031ad,   // zu.ro.ceb_532 mk.uk.bg_432  sr.hr.un_320 az.sq.mt_643
  // [10d0]
  0x11000a09, 0x64002a1a, 0x0a00110e, 0x070311ee,   // pt.ro.un_440 mt.lg.un_760  ro.pt.un_550 ro.nl.it_422
  0x3f000311, 0x17002d08, 0x3f0e030e, 0x29000312,   // nl.af.un_630 sk.sr.un_430  nl.is.af_555 nl.sl.un_640
  0x291128a4, 0x4a320ea6, 0x182112af, 0x31001b09,   // sw.ro.sl_433 is.bs.yo_521  ur.fa.ar_655 tr.az.un_440
  0x3f2903a0, 0x1f00641b, 0x0d130911, 0x10000408,   // nl.sl.af_322 lg.cy.un_770  hi.bh.ne_653 ru.be.un_430
  // [10e0]
  0x012d35a0, 0x2a201212, 0x04102904, 0x080425a0,   // zu.sk.en_322 hu.sq.mt_654  sl.lt.fi_332 eu.fi.no_322
  0x21002a07, 0x0807100c, 0x21001c07, 0x04100808,   // mt.jw.un_420 be.bg.uk_543  id.jw.un_420 uk.be.ru_443
  0x0e000c08, 0x040817ec, 0x28005202, 0x350353ec,   // sv.is.un_430 sr.uk.ru_644  ha.sw.un_220 ht.nl.zu_644
  0x0b0a19a0, 0x27006e07, 0x4a201b07, 0x1f231107,   // gl.pt.es_322 hmn.gd.un_420  tr.sq.yo_432 ro.ca.cy_432
  // [10f0]
  0x18033f12, 0x291b315a, 0x080410ad, 0x08171005,   // af.nl.ga_654 az.tr.sl_553  be.ru.uk_643 be.sr.uk_333
  0x4a005504, 0x25002704, 0x1700111a, 0x27011f0c,   // rw.yo.un_320 gd.eu.un_320  ro.sr.un_760 cy.en.gd_543
  0x1c252112, 0x080417a0, 0x08100405, 0x123f03a0,   // jw.eu.id_654 sr.ru.uk_322  ru.be.uk_333 nl.af.hu_322
  0x08001108, 0x1e180107, 0x3f000604, 0x0c000605,   // ro.uk.un_430 en.ga.ms_432  de.af.un_320 de.sv.un_330
  // [1100]
  0x1f5325ad, 0x552901a4, 0x00002d01, 0x524a3ba4,   // eu.ht.cy_643 en.sl.rw_433  sk.un.un_200 so.yo.ha_433
  0x6b1f270c, 0x060710a0, 0x3b002b09, 0x274a0704,   // gd.cy.ceb_543 lt.it.de_322  vi.so.un_440 it.yo.gd_332
  0x0400050e, 0x08040704, 0x0d171307, 0x043529a0,   // fr.fi.un_550 bg.ru.uk_332  et.sr.cs_432 sl.zu.fi_322
  0x533b25ec, 0x041710ee, 0x130504a0, 0x17002907,   // eu.so.ht_644 be.sr.ru_422  fi.fr.et_322 sl.sr.un_420
  // [1110]
  0x25002113, 0x0a0701ee, 0x25000a0c, 0x312d0d08,   // jw.eu.un_650 en.it.pt_422  pt.eu.un_530 cs.sk.az_443
  0x211b1307, 0x21001811, 0x64552511, 0x681b35a4,   // et.tr.jw_432 ar.fa.un_630  eu.rw.lg_653 zu.tr.ig_433
  0x03002802, 0x13001805, 0x6b1c01ee, 0x3f00030d,   // sw.nl.un_220 ga.et.un_330  en.id.ceb_422 nl.af.un_540
  0x04000209, 0x06271804, 0x013f0907, 0x1f2553ee,   // da.fi.un_440 ga.gd.de_332  pl.af.en_432 ht.eu.cy_422
  // [1120]
  0x0100090c, 0x6b2321a9, 0x13050108, 0x0a071704,   // pl.en.un_530 jw.ca.ceb_544  en.fr.et_443 sr.bg.mk_332
  0x17000a08, 0x0f000304, 0x64001f12, 0x08020c09,   // mk.sr.un_430 nl.lv.un_320  cy.lg.un_640 sv.da.no_444
  0x3f000a08, 0x10000713, 0x13012004, 0x071710ec,   // pt.af.un_430 bg.be.un_650  sq.en.et_332 be.sr.bg_644
  0x6e002705, 0x05001805, 0x07041708, 0x0c022007,   // gd.hmn.un_330 ga.fr.un_330  sr.ru.bg_443 sq.da.sv_432
  // [1130]
  0x0400100b, 0x4a00040c, 0x07000813, 0x170804a9,   // be.ru.un_520 fi.yo.un_530  uk.bg.un_650 ru.uk.sr_544
  0x0b1925a7, 0x3b181308, 0x08000704, 0x21001205,   // eu.gl.es_532 et.ga.so_443  it.no.un_320 ur.fa.un_330
  0x0b000a04, 0x1300040d, 0x12040cee, 0x08001019,   // pt.es.un_320 fi.et.un_540  sv.fi.hu_422 be.uk.un_750
  0x0c002a07, 0x18001211, 0x1b00060e, 0x284a350b,   // mt.sv.un_420 ur.ar.un_630  de.tr.un_550 zu.yo.sw_542
  // [1140]
  0x1b20310c, 0x64002505, 0x0d130960, 0x644a53ee,   // az.sq.tr_543 eu.lg.un_330  hi.bh.ne_664 ht.yo.lg_422
  0x17291607, 0x130f1012, 0x1c000d0b, 0x061b31ee,   // hr.sl.sr_432 lt.lv.et_654  ne.mr.un_520 az.tr.de_422
  0x07040a08, 0x10283507, 0x52283bee, 0x3f202107,   // mk.ru.bg_443 zu.sw.lt_432  so.sw.ha_422 jw.sq.af_432
  0x32162902, 0x03000d0c, 0x09002d04, 0x1b00310c,   // sl.hr.bs_222 cs.nl.un_530  sk.pl.un_320 az.tr.un_530
  // [1150]
  0x3b0604a0, 0x17001013, 0x3b311b04, 0x2d162007,   // fi.de.so_322 be.sr.un_650  tr.az.so_332 sq.hr.sk_432
  0x06080e08, 0x530d2809, 0x04000f05, 0x10090ca0,   // is.no.de_443 sw.cs.ht_444  lv.fi.un_330 sv.pl.lt_322
  0x1c0d0911, 0x03001802, 0x27001807, 0x1f080ca9,   // hi.ne.mr_653 ga.nl.un_220  ga.gd.un_420 sv.no.cy_544
  0x041301af, 0x16101304, 0x0d001c08, 0x100d09ad,   // en.et.fi_655 et.lt.hr_332  mr.ne.un_430 pl.cs.lt_643
  // [1160]
  0x0e311baf, 0x120e1809, 0x0f001704, 0x0607030e,   // tr.az.is_655 ga.is.hu_444  sr.lv.un_320 nl.it.de_555
  0x06020702, 0x1f2d0d5a, 0x09121808, 0x13000d0b,   // it.da.de_222 cs.sk.cy_553  ga.hu.pl_443 ne.bh.un_520
  0x641304ad, 0x31001908, 0x21001304, 0x52003b04,   // fi.et.lg_643 gl.az.un_430  et.jw.un_320 so.ha.un_320
  0x683b08a4, 0x311b250b, 0x1c0d0960, 0x32002804,   // no.so.ig_433 eu.tr.az_542  hi.ne.mr_664 sw.bs.un_320
  // [1170]
  0x0a0810ec, 0x25001807, 0x20000309, 0x1300040c,   // be.uk.mk_644 ga.eu.un_420  nl.sq.un_440 fi.et.un_530
  0x53201ea0, 0x08130412, 0x3b001802, 0x27002504,   // ms.sq.ht_322 fi.et.no_654  ga.so.un_220 eu.gd.un_320
  0x08002a08, 0x3b003f02, 0x04000a02, 0x0900060e,   // mt.no.un_430 af.so.un_220  mk.ru.un_220 de.pl.un_550
  0x01000605, 0x64003507, 0x6b001a09, 0x1300041b,   // de.en.un_330 zu.lg.un_420  tl.ceb.un_440 fi.et.un_770
  // [1180]
  0x523121a0, 0x556435ee, 0x1e1b350c, 0x2800040c,   // jw.az.ha_322 zu.lg.rw_422  zu.tr.ms_543 fi.sw.un_530
  0x0a170709, 0x1a005204, 0x0e000702, 0x55003502,   // bg.sr.mk_444 ha.tl.un_320  it.is.un_220 zu.rw.un_220
  0x1600290c, 0x0a111714, 0x1e003512, 0x1b003b0e,   // sl.hr.un_530 sr.ro.mk_666  zu.ms.un_640 so.tr.un_550
  0x076b04ad, 0x1f000108, 0x0100050c, 0x041301a0,   // fi.ceb.it_643 en.cy.un_430  fr.en.un_530 en.et.fi_322
  // [1190]
  0x273118a0, 0x1000090d, 0x10000909, 0x3b210ea9,   // ga.az.gd_322 pl.lt.un_540  pl.lt.un_440 is.jw.so_544
  0x0800170d, 0x01060502, 0x13000c11, 0x08021f02,   // sr.uk.un_540 fr.de.en_222  sv.et.un_630 cy.da.no_222
  0x04080705, 0x0a1f09a0, 0x253b2708, 0x5500280e,   // bg.uk.ru_333 pl.cy.pt_322  gd.so.eu_443 sw.rw.un_550
  0x0600080d, 0x530501a9, 0x06000304, 0x0a0804a4,   // no.de.un_540 en.fr.ht_544  nl.de.un_320 ru.uk.mk_433
  // [11a0]
  0x07001704, 0x1f001905, 0x18004a08, 0x1e083ba0,   // sr.bg.un_320 gl.cy.un_330  yo.ga.un_430 so.no.ms_322
  0x55006419, 0x00003106, 0x0a001207, 0x31005307,   // lg.rw.un_750 az.un.un_400  hu.pt.un_420 ht.az.un_420
  0x6e0105a7, 0x1008170c, 0x131c09ad, 0x31002a02,   // fr.en.hmn_532 sr.uk.be_543  hi.mr.bh_643 mt.az.un_220
  0x1b020807, 0x64006b02, 0x32001604, 0x11070aa4,   // no.da.tr_432 ceb.lg.un_220  hr.bs.un_320 mk.bg.ro_433
  // [11b0]
  0x1700101a, 0x1c2125a0, 0x2a6b1aa9, 0x21043f07,   // be.sr.un_760 eu.jw.id_322  tl.ceb.mt_544 af.fi.jw_432
  0x2d0d35a9, 0x531b2302, 0x3b3135a4, 0x3b0802a4,   // zu.cs.sk_544 ca.tr.ht_222  zu.az.so_433 da.no.so_433
  0x3b000d0d, 0x1c1128ac, 0x0a0411ee, 0x0000061c,   // cs.so.un_540 sw.ro.id_632  ro.ru.mk_422 de.un.un_800
  0x12200c02, 0x03002a0e, 0x2100121a, 0x0100241a,   // sv.sq.hu_222 mt.nl.un_550  ur.fa.un_760 yi.iw.un_760
  // [11c0]
  0x04110a07, 0x09000e07, 0x06001807, 0x2a523bee,   // mk.ro.ru_432 is.pl.un_420  ga.de.un_420 so.ha.mt_422
  0x10171602, 0x0a000718, 0x09003508, 0x033b680c,   // hr.sr.lt_222 bg.mk.un_740  zu.pl.un_430 ig.so.nl_543
  0x0d1c0960, 0x1c1b3f07, 0x1e1c2102, 0x07640ea4,   // hi.mr.ne_664 af.tr.id_432  jw.id.ms_222 is.lg.it_433
  0x06001e04, 0x040a0705, 0x03061804, 0x200f12a4,   // ms.de.un_320 bg.mk.ru_333  ga.de.nl_332 hu.lv.sq_433
  // [11d0]
  0x10040a07, 0x3f2a0908, 0x0c002a04, 0x312d1b12,   // mk.ru.be_432 pl.mt.af_443  mt.sv.un_320 tr.sk.az_654
  0x103f0fa7, 0x2a006b0d, 0x160908a0, 0x0a040805,   // lv.af.lt_532 ceb.mt.un_540  no.pl.hr_322 uk.ru.mk_333
  0x06005504, 0x1e006b04, 0x310b23ee, 0x6b0910ec,   // rw.de.un_320 ceb.ms.un_320  ca.es.az_422 lt.pl.ceb_644
  0x2a32020c, 0x08041107, 0x283b1ea0, 0x093f13a4,   // da.bs.mt_543 ro.ru.uk_432  ms.so.sw_322 et.af.pl_433
  // [11e0]
  0x12001819, 0x07170408, 0x25000614, 0x32253504,   // ar.ur.un_750 ru.sr.bg_443  de.eu.un_660 zu.eu.bs_332
  0x133f03a0, 0x0a000812, 0x03000608, 0x64002108,   // nl.af.et_322 uk.mk.un_640  de.nl.un_430 jw.lg.un_430
  0x17001112, 0x121f10a0, 0x55002814, 0x1f102007,   // ro.sr.un_640 lt.cy.hu_322  sw.rw.un_660 sq.lt.cy_432
  0x041f0dad, 0x18190a05, 0x214a1aee, 0x55001112,   // cs.cy.fi_643 pt.gl.ga_333  tl.yo.jw_422 ro.rw.un_640
  // [11f0]
  0x64000c05, 0x1c000919, 0x3f2a0607, 0x6b0325ee,   // sv.lg.un_330 hi.mr.un_750  de.mt.af_432 eu.nl.ceb_422
  0x29001a02, 0x080704af, 0x2d001904, 0x192311a0,   // tl.sl.un_220 ru.bg.uk_655  gl.sk.un_320 ro.ca.gl_322
  0x0621030c, 0x11002704, 0x21065207, 0x0a041704,   // nl.jw.de_543 gd.ro.un_320  ha.de.jw_432 sr.ru.mk_332
  0x4a000e19, 0x3f030607, 0x1f112102, 0x090d04ad,   // is.yo.un_750 de.nl.af_432  jw.ro.cy_222 fi.cs.pl_643
  // [1200]
  0x080a0712, 0x0a1707a4, 0x120d0f04, 0x1f092d04,   // bg.mk.uk_654 bg.sr.mk_433  lv.cs.hu_332 sk.pl.cy_332
  0x1b0208ee, 0x0b006402, 0x2d0d19a0, 0x12001f04,   // no.da.tr_422 lg.es.un_220  gl.cs.sk_322 cy.hu.un_320
  0x292d0d55, 0x211c1eee, 0x04020c04, 0x021f0812,   // cs.sk.sl_442 ms.id.jw_422  sv.da.fi_332 no.cy.da_654
  0x13643504, 0x082d0d08, 0x52002a05, 0x35093f0c,   // zu.lg.et_332 cs.sk.no_443  mt.ha.un_330 af.pl.zu_543
  // [1210]
  0x0d1c13a7, 0x13030ca0, 0x6b003b12, 0x04001107,   // bh.mr.ne_532 sv.nl.et_322  so.ceb.un_640 ro.ru.un_420
  0x6b3b2b07, 0x08020309, 0x35005202, 0x35686407,   // vi.so.ceb_432 nl.da.no_444  ha.zu.un_220 lg.ig.zu_432
  0x4a3564ad, 0x060501ad, 0x103b07a0, 0x04251a55,   // lg.zu.yo_643 en.fr.de_643  it.so.lt_322 tl.eu.fi_442
  0x100417af, 0x214a64ee, 0x1b2035ee, 0x0a171011,   // sr.ru.be_655 lg.yo.jw_422  zu.sq.tr_422 be.sr.mk_653
  // [1220]
  0x2a315207, 0x12050807, 0x55003514, 0x09131c11,   // ha.az.mt_432 no.fr.hu_432  zu.rw.un_660 mr.bh.hi_653
  0x27181f55, 0x0c0802a7, 0x17100702, 0x6b6801a6,   // cy.ga.gd_442 da.no.sv_532  bg.be.sr_222 en.ig.ceb_521
  0x4a00680c, 0x040a11ee, 0x1f000912, 0x01000804,   // ig.yo.un_530 ro.mk.ru_422  pl.cy.un_640 no.en.un_320
  0x08101702, 0x55311ba4, 0x17040802, 0x31003b09,   // sr.be.uk_222 tr.az.rw_433  uk.ru.sr_222 so.az.un_440
  // [1230]
  0x02000804, 0x1b1131a4, 0x1a005304, 0x25001f04,   // no.da.un_320 az.ro.tr_433  ht.tl.un_320 cy.eu.un_320
  0x11002809, 0x2000290c, 0x112825ad, 0x1a131104,   // sw.ro.un_440 sl.sq.un_530  eu.sw.ro_643 ro.et.tl_332
  0x64003b12, 0x28136407, 0x0700041a, 0x1a313b0c,   // so.lg.un_640 lg.et.sw_432  ru.bg.un_760 so.az.tl_543
  0x3b554aa0, 0x07000604, 0x1c091311, 0x20000e11,   // yo.rw.so_322 de.it.un_320  bh.hi.mr_653 is.sq.un_630
  // [1240]
  0x3f3564ad, 0x0c2512a7, 0x2d000304, 0x12000912,   // lg.zu.af_643 hu.eu.sv_532  nl.sk.un_320 pl.hu.un_640
  0x6b2a1255, 0x0d2d105a, 0x16000504, 0x32643ba4,   // hu.mt.ceb_442 lt.sk.cs_553  fr.hr.un_320 so.lg.bs_433
  0x55296404, 0x4a3b640c, 0x0f002907, 0x55006408,   // lg.sl.rw_332 lg.so.yo_543  sl.lv.un_420 lg.rw.un_430
  0x06033f13, 0x0d291107, 0x080c3ba9, 0x64005312,   // af.nl.de_665 ro.sl.cs_432  so.sv.no_544 ht.lg.un_640
  // [1250]
  0x11100808, 0x17290307, 0x0a000702, 0x0b1c21a0,   // uk.be.ro_443 nl.sl.sr_432  bg.mk.un_220 jw.id.es_322
  0x0e000c0d, 0x2a006b07, 0x12002508, 0x031b29ee,   // sv.is.un_540 ceb.mt.un_420  eu.hu.un_430 sl.tr.nl_422
  0x4a000d13, 0x130c02a0, 0x0a070805, 0x2300010c,   // cs.yo.un_650 da.sv.et_322  uk.bg.mk_333 en.ca.un_530
  0x13003b12, 0x6b000112, 0x0c000907, 0x03001304,   // so.et.un_640 en.ceb.un_640  pl.sv.un_420 et.nl.un_320
  // [1260]
  0x2a310f04, 0x31291bee, 0x16000c04, 0x03063fa0,   // lv.az.mt_332 tr.sl.az_422  sv.hr.un_320 af.de.nl_322
  0x0300050b, 0x2d12640c, 0x32002702, 0x093b1fee,   // fr.nl.un_520 lg.hu.sk_543  gd.bs.un_220 cy.so.pl_422
  0x5300250e, 0x0410110c, 0x06002502, 0x3b3f03a7,   // eu.ht.un_550 ro.be.ru_543  eu.de.un_220 nl.af.so_532
  0x28551807, 0x52003509, 0x3b091f0b, 0x13212807,   // ga.rw.sw_432 zu.ha.un_440  cy.pl.so_542 sw.jw.et_432
  // [1270]
  0x311011a6, 0x090d1c08, 0x35521307, 0x09211f04,   // ro.lt.az_521 mr.ne.hi_443  et.ha.zu_432 cy.jw.pl_332
  0x1300351a, 0x0d0913ad, 0x17000819, 0x110623ec,   // zu.et.un_760 bh.hi.ne_643  uk.sr.un_750 ca.de.ro_644
  0x1c0310a7, 0x4a122d60, 0x0b2305a0, 0x040e6b07,   // lt.nl.id_532 sk.hu.yo_664  fr.ca.es_322 ceb.is.fi_432
  0x4a00320d, 0x02000813, 0x2a0e0807, 0x0a170712,   // bs.yo.un_540 no.da.un_650  no.is.mt_432 bg.sr.mk_654
  // [1280]
  0x10040855, 0x1008040d, 0x11292d07, 0x13000d19,   // uk.ru.be_442 ru.uk.be_554  sk.sl.ro_432 ne.bh.un_750
  0x0d0913ec, 0x230b0705, 0x0900100d, 0x2700130e,   // bh.hi.ne_644 it.es.ca_333  lt.pl.un_540 et.gd.un_550
  0x35556ba0, 0x645308a0, 0x03210fee, 0x1a552104,   // ceb.rw.zu_322 no.ht.lg_322  lv.jw.nl_422 jw.rw.tl_332
  0x2a1207a0, 0x3b000704, 0x25681804, 0x640111a0,   // it.hu.mt_322 it.so.un_320  ga.ig.eu_332 ro.en.lg_322
  // [1290]
  0x12005204, 0x135231ee, 0x313f035a, 0x0c00060b,   // ha.hu.un_320 az.ha.et_422  nl.af.az_553 de.sv.un_520
  0x1f002514, 0x1732165a, 0x04000a18, 0x1c002902,   // eu.cy.un_660 hr.bs.sr_553  mk.ru.un_740 sl.id.un_220
  0x55310507, 0x1f093ba7, 0x00001803, 0x07080204,   // fr.az.rw_432 so.pl.cy_532  ga.un.un_300 da.no.it_332
  0x00001c1c, 0x12002d08, 0x1b080c0d, 0x1100071a,   // mr.un.un_800 sk.hu.un_430  sv.no.tr_554 bg.ro.un_760
  // [12a0]
  0x1f051107, 0x352821a0, 0x01000702, 0x112107a0,   // ro.fr.cy_432 jw.sw.zu_322  it.en.un_220 it.jw.ro_322
  0x2527010b, 0x115335a0, 0x04002d12, 0x0c251a02,   // en.gd.eu_542 zu.ht.ro_322  sk.fi.un_640 tl.eu.sv_222
  0x6b181207, 0x27000b08, 0x0c041307, 0x070b0a05,   // hu.ga.ceb_432 es.gd.un_430  et.fi.sv_432 pt.es.it_333
  0x042d0dad, 0x3b001e02, 0x0f001019, 0x100417a7,   // cs.sk.fi_643 ms.so.un_220  lt.lv.un_750 sr.ru.be_532
  // [12b0]
  0x0800041a, 0x07080107, 0x20312aee, 0x060103a7,   // ru.uk.un_760 en.no.it_432  mt.az.sq_422 nl.en.de_532
  0x050601a4, 0x64001218, 0x2a1107ee, 0x071131a0,   // en.de.fr_433 hu.lg.un_740  it.ro.mt_422 az.ro.it_322
  0x00002915, 0x0d1c1308, 0x05170dee, 0x2d001604,   // sl.un.un_700 bh.mr.ne_443  cs.sr.fr_422 hr.sk.un_320
  0x29211f04, 0x036b0aee, 0x64003202, 0x07170a05,   // cy.jw.sl_332 pt.ceb.nl_422  bs.lg.un_220 mk.sr.bg_333
  // [12c0]
  0x1218210d, 0x19052304, 0x1c09130c, 0x050b23a0,   // fa.ar.ur_554 ca.fr.gl_332  bh.hi.mr_543 ca.es.fr_322
  0x251c28ee, 0x11000104, 0x0c230707, 0x1c091307,   // sw.id.eu_422 en.ro.un_320  it.ca.sv_432 bh.hi.mr_432
  0x063f03a4, 0x0c1f12a4, 0x08020ea4, 0x52006419,   // nl.af.de_433 hu.cy.sv_433  is.da.no_433 lg.ha.un_750
  0x10002d04, 0x08001005, 0x08000911, 0x12002a04,   // sk.lt.un_320 be.uk.un_330  pl.no.un_630 mt.hu.un_320
  // [12d0]
  0x213b1b0e, 0x01080202, 0x0c020307, 0x29172d0c,   // tr.so.jw_555 da.no.en_222  nl.da.sv_432 sk.sr.sl_543
  0x35000a04, 0x0f060111, 0x64550807, 0x236b5302,   // pt.zu.un_320 en.de.lv_653  no.rw.lg_432 ht.ceb.ca_222
  0x2d122bad, 0x170a0805, 0x0a001008, 0x640c08a0,   // vi.hu.sk_643 uk.mk.sr_333  lt.pt.un_430 no.sv.lg_322
  0x52130fa4, 0x2a00040e, 0x07171107, 0x100a2d05,   // lv.et.ha_433 fi.mt.un_550  ro.sr.bg_432 sk.pt.lt_333
  // [12e0]
  0x0a000d04, 0x06130c08, 0x0c000807, 0x533b010b,   // cs.pt.un_320 sv.et.de_443  no.sv.un_420 en.so.ht_542
  0x2700181b, 0x04071107, 0x08005212, 0x3f001f04,   // ga.gd.un_770 ro.bg.ru_432  ha.no.un_640 cy.af.un_320
  0x3b211a0c, 0x6b6801a4, 0x1b000413, 0x27040607,   // tl.jw.so_543 en.ig.ceb_433  fi.tr.un_650 de.fi.gd_432
  0x06000e07, 0x250523a0, 0x1e1c2107, 0x3b006e07,   // is.de.un_420 ca.fr.eu_322  jw.id.ms_432 hmn.so.un_420
  // [12f0]
  0x0c0e0802, 0x033f3bad, 0x1831250c, 0x18001012,   // no.is.sv_222 so.af.nl_643  eu.az.ga_543 lt.ga.un_640
  0x0c083f04, 0x2a001a07, 0x3b003113, 0x07292da4,   // af.no.sv_332 tl.mt.un_420  az.so.un_650 sk.sl.it_433
  0x1b003111, 0x12530aa0, 0x081b2507, 0x21190ba7,   // az.tr.un_630 pt.ht.hu_322  eu.tr.no_432 es.gl.jw_532
  0x1e044aa0, 0x01006b07, 0x18092da0, 0x080407a0,   // yo.fi.ms_322 ceb.en.un_420  sk.pl.ga_322 bg.ru.uk_322
  // [1300]
  0x53001213, 0x07100805, 0x2100050d, 0x03062702,   // hu.ht.un_650 uk.be.bg_333  fr.jw.un_540 gd.de.nl_222
  0x0e311b05, 0x05002102, 0x0d000a07, 0x052312ee,   // tr.az.is_333 jw.fr.un_220  pt.cs.un_420 hu.ca.fr_422
  0x042013ad, 0x68000808, 0x07311007, 0x3b00350d,   // et.sq.fi_643 no.ig.un_430  lt.az.it_432 zu.so.un_540
  0x170810a0, 0x2112180d, 0x20000704, 0x231e1b05,   // be.uk.sr_322 ar.ur.fa_554  it.sq.un_320 tr.ms.ca_333
  // [1310]
  0x050106a4, 0x20000412, 0x0d002104, 0x1a043bac,   // de.en.fr_433 fi.sq.un_640  jw.cs.un_320 so.fi.tl_632
  0x121821ac, 0x0c1f07ee, 0x04000f0d, 0x12000605,   // fa.ar.ur_632 it.cy.sv_422  lv.fi.un_540 de.hu.un_330
  0x32160bee, 0x1e311b12, 0x1c203ba7, 0x213f0304,   // es.hr.bs_422 tr.az.ms_654  so.sq.id_532 nl.af.jw_332
  0x21000704, 0x352855a0, 0x060c130c, 0x12002d0e,   // it.jw.un_320 rw.sw.zu_322  et.sv.de_543 sk.hu.un_550
  // [1320]
  0x1c0d090b, 0x643531a7, 0x1b5209a4, 0x23000a05,   // hi.ne.mr_542 az.zu.lg_532  pl.ha.tr_433 pt.ca.un_330
  0x070817a4, 0x0c1a35ee, 0x130d0908, 0x1b530905,   // sr.uk.bg_433 zu.tl.sv_422  hi.ne.bh_443 pl.ht.tr_333
  0x3b000a04, 0x271925a0, 0x3f1b35a0, 0x35002813,   // pt.so.un_320 eu.gl.gd_322  zu.tr.af_322 sw.zu.un_650
  0x351302a0, 0x10000a04, 0x130d0912, 0x10643ba9,   // da.et.zu_322 mk.be.un_320  hi.ne.bh_654 so.lg.lt_544
  // [1330]
  0x043513a9, 0x03133fa9, 0x17080460, 0x2d090fee,   // et.zu.fi_544 af.et.nl_544  ru.uk.sr_664 lv.pl.sk_422
  0x3b202805, 0x18002712, 0x3f005204, 0x1c000904,   // sw.sq.so_333 gd.ga.un_640  ha.af.un_320 hi.mr.un_320
  0x04071012, 0x2d2511ee, 0x1f643b12, 0x31001902,   // be.bg.ru_654 ro.eu.sk_422  so.lg.cy_654 gl.az.un_220
  0x09131c12, 0x322d2aee, 0x0e000819, 0x0a00050d,   // mr.bh.hi_654 mt.sk.bs_422  no.is.un_750 fr.pt.un_540
  // [1340]
  0x2b3513a0, 0x100811a0, 0x4a006821, 0x31000a09,   // et.zu.vi_322 ro.uk.be_322  ig.yo.un_860 pt.az.un_440
  0x29001b0d, 0x2d0d1007, 0x2d001113, 0x0d002012,   // tr.sl.un_540 lt.cs.sk_432  ro.sk.un_650 sq.cs.un_640
  0x3f001a04, 0x0704175a, 0x0c08230d, 0x060c0204,   // tl.af.un_320 sr.ru.bg_553  ca.no.sv_554 da.sv.de_332
  0x1a00640d, 0x23000608, 0x6e052304, 0x1f00070e,   // lg.tl.un_540 de.ca.un_430  ca.fr.hmn_332 it.cy.un_550
  // [1350]
  0x0d001602, 0x01002502, 0x0700550d, 0x190b23a4,   // hr.cs.un_220 eu.en.un_220  rw.it.un_540 ca.es.gl_433
  0x09003b0d, 0x2a002004, 0x35005511, 0x00000b0a,   // so.pl.un_540 sq.mt.un_320  rw.zu.un_630 bn.un.un_500
  0x10001b13, 0x31061302, 0x18002b04, 0x04170804,   // tr.lt.un_650 et.de.az_222  vi.ga.un_320 uk.sr.ru_332
  0x311b20ee, 0x0923110c, 0x042b35a0, 0x10001a04,   // sq.tr.az_422 ro.ca.pl_543  zu.vi.fi_322 tl.lt.un_320
  // [1360]
  0x0e00060c, 0x29321602, 0x121e3bad, 0x10000822,   // de.is.un_530 hr.bs.sl_222  so.ms.hu_643 uk.be.un_870
  0x35003b1b, 0x190b1baf, 0x55006b05, 0x1e006b08,   // so.zu.un_770 tr.es.gl_655  ceb.rw.un_330 ceb.ms.un_430
  0x04000c08, 0x3f001f02, 0x0c3f030c, 0x0400290e,   // sv.fi.un_430 cy.af.un_220  nl.af.sv_543 sl.fi.un_550
  0x08000f12, 0x1b535504, 0x1e215202, 0x2319010b,   // lv.no.un_640 rw.ht.tr_332  ha.jw.ms_222 en.gl.ca_542
  // [1370]
  0x211f3f0c, 0x2a002104, 0x53000104, 0x17001007,   // af.cy.jw_543 jw.mt.un_320  en.ht.un_320 be.sr.un_420
  0x2d1f0dad, 0x0e003f08, 0x10040f04, 0x0b0a08a0,   // cs.cy.sk_643 af.is.un_430  lv.fi.lt_332 no.pt.es_322
  0x0d180608, 0x12003b04, 0x3b000e0e, 0x06000c0c,   // de.ga.cs_443 so.hu.un_320  is.so.un_550 sv.de.un_530
  0x3564550c, 0x04171012, 0x25293b07, 0x065513a7,   // rw.lg.zu_543 be.sr.ru_654  so.sl.eu_432 et.rw.de_532
  // [1380]
  0x0c002a0e, 0x11000512, 0x293552ee, 0x01640f07,   // mt.sv.un_550 fr.ro.un_640  ha.zu.sl_422 lv.lg.en_432
  0x18273512, 0x6b1a01a9, 0x015535a0, 0x530428ad,   // zu.gd.ga_654 en.tl.ceb_544  zu.rw.en_322 sw.fi.ht_643
  0x2b003505, 0x041017ec, 0x0800550b, 0x17002d07,   // zu.vi.un_330 sr.be.ru_644  rw.no.un_520 sk.sr.un_420
  0x0e000c0b, 0x6e005512, 0x2b5511a0, 0x05001108,   // sv.is.un_520 rw.hmn.un_640  ro.rw.vi_322 ro.fr.un_430
  // [1390]
  0x25001b13, 0x0c5508a4, 0x2000211a, 0x253b2a0c,   // tr.eu.un_650 no.rw.sv_433  jw.sq.un_760 mt.so.eu_543
  0x08040aee, 0x0c003b11, 0x17000f04, 0x2300050d,   // mk.ru.uk_422 so.sv.un_630  lv.sr.un_320 fr.ca.un_540
  0x31001f05, 0x0d1029a4, 0x35002819, 0x0c2a0407,   // cy.az.un_330 sl.lt.cs_433  sw.zu.un_750 fi.mt.sv_432
  0x4a002a04, 0x1b000912, 0x110504a4, 0x13000d1a,   // mt.yo.un_320 pl.tr.un_640  fi.fr.ro_433 ne.bh.un_760
  // [13a0]
  0x5500060d, 0x0c0413a0, 0x0d091307, 0x52351107,   // de.rw.un_540 et.fi.sv_322  bh.hi.ne_432 ro.zu.ha_432
  0x0a001002, 0x01005307, 0x11130f08, 0x09002a07,   // be.mk.un_220 ht.en.un_420  lv.et.ro_443 mt.pl.un_420
  0x04071712, 0x0b002704, 0x1c211ea0, 0x00000e01,   // sr.bg.ru_654 gd.es.un_320  ms.jw.id_322 is.un.un_200
  0x0a003f05, 0x21001704, 0x170410ee, 0x18001908,   // af.pt.un_330 sr.jw.un_320  be.ru.sr_422 gl.ga.un_430
  // [13b0]
  0x2d070907, 0x310e09ad, 0x194a280b, 0x10311ba0,   // pl.it.sk_432 pl.is.az_643  sw.yo.gl_542 tr.az.lt_322
  0x11060ca0, 0x0a040711, 0x02080c08, 0x522d0d02,   // sv.de.ro_322 bg.ru.mk_653  sv.no.da_443 cs.sk.ha_222
  0x53001b04, 0x081711a7, 0x1a1b28a0, 0x11001b04,   // tr.ht.un_320 ro.sr.uk_532  sw.tr.tl_322 tr.ro.un_320
  0x18002507, 0x0e080ca9, 0x2d001902, 0x1f2a5304,   // eu.ga.un_420 sv.no.is_544  gl.sk.un_220 ht.mt.cy_332
  // [13c0]
  0x0e4a18a9, 0x03003f14, 0x041355ee, 0x4a00180c,   // ga.yo.is_544 af.nl.un_660  rw.et.fi_422 ga.yo.un_530
  0x09001c04, 0x0900290b, 0x1300041a, 0x08170707,   // mr.hi.un_320 sl.pl.un_520  fi.et.un_760 bg.sr.uk_432
  0x2d0d0aee, 0x29090fad, 0x2d0d29a9, 0x12000907,   // pt.cs.sk_422 lv.pl.sl_643  sl.cs.sk_544 pl.hu.un_420
  0x090e29a4, 0x2d6b09ad, 0x53041055, 0x07112507,   // sl.is.pl_433 pl.ceb.sk_643  lt.fi.ht_442 eu.ro.it_432
  // [13d0]
  0x04001704, 0x27006402, 0x211b04a4, 0x05042804,   // sr.ru.un_320 lg.gd.un_220  fi.tr.jw_433 sw.fi.fr_332
  0x2d120a05, 0x21001c12, 0x0507010c, 0x29001014,   // pt.hu.sk_333 id.jw.un_640  en.it.fr_543 lt.sl.un_660
  0x21002013, 0x311a06a6, 0x020c0811, 0x190b23ec,   // sq.jw.un_650 de.tl.az_521  no.sv.da_653 ca.es.gl_644
  0x04000511, 0x11000a19, 0x4a1f07a0, 0x20001702,   // fr.fi.un_630 mk.ro.un_750  it.cy.yo_322 sr.sq.un_220
  // [13e0]
  0x2a060708, 0x2b001c04, 0x10040a02, 0x520955af,   // it.de.mt_443 id.vi.un_320  mk.ru.be_222 rw.pl.ha_655
  0x1000080d, 0x06040c0c, 0x2a3b3112, 0x55005204,   // uk.be.un_540 sv.fi.de_543  az.so.mt_654 ha.rw.un_320
  0x12000705, 0x172d0dad, 0x0d001307, 0x0e000d04,   // it.hu.un_330 cs.sk.sr_643  bh.ne.un_420 cs.is.un_320
  0x07000402, 0x06002302, 0x110a23a4, 0x1b004a04,   // ru.bg.un_220 ca.de.un_220  ca.pt.ro_433 yo.tr.un_320
  // [13f0]
  0x050413a4, 0x05005204, 0x050b01a4, 0x07001108,   // et.fi.fr_433 ha.fr.un_320  en.es.fr_433 ro.bg.un_430
  0x04001702, 0x13005302, 0x02000c08, 0x040a1008,   // sr.ru.un_220 ht.et.un_220  sv.da.un_430 be.mk.ru_443
  0x08170411, 0x64003f0c, 0x1000040c, 0x0417080d,   // ru.sr.uk_653 af.lg.un_530  ru.be.un_530 uk.sr.ru_554
  0x0700350c, 0x07000a09, 0x2d0d3f5a, 0x64033fa0,   // zu.it.un_530 mk.bg.un_440  af.cs.sk_553 af.nl.lg_322

  // [1400]
  0x0f0c08a4, 0x0a001119, 0x3b6407a0, 0x052d0d0d,   // no.sv.lv_433 ro.mk.un_750  it.lg.so_322 cs.sk.fr_554
  0x351a5505, 0x52160dee, 0x07170dee, 0x17100805,   // rw.tl.zu_333 cs.hr.ha_422  cs.sr.it_422 uk.be.sr_333
  0x0a001007, 0x11003b0c, 0x285564a6, 0x04000c07,   // be.mk.un_420 so.ro.un_530  lg.rw.sw_521 sv.fi.un_420
  0x0a070408, 0x55001c08, 0x07004a07, 0x07040a5a,   // ru.bg.mk_443 id.rw.un_430  yo.it.un_420 mk.ru.bg_553
  // [1410]
  0x5303060c, 0x52090dac, 0x19000a04, 0x13000e09,   // de.nl.ht_543 cs.pl.ha_632  pt.gl.un_320 is.et.un_440
  0x06010d02, 0x00006424, 0x6b12350d, 0x11350704,   // cs.en.de_222 lg.un.un_900  zu.hu.ceb_554 it.zu.ro_332
  0x101c3bad, 0x2d0c0812, 0x10081a0c, 0x12000c04,   // so.id.lt_643 no.sv.sk_654  tl.no.lt_543 sv.hu.un_320
  0x552d0907, 0x190b55ee, 0x1e093bee, 0x193f53a0,   // pl.sk.rw_432 rw.es.gl_422  so.pl.ms_422 ht.af.gl_322
  // [1420]
  0x04120811, 0x1c00520d, 0x020752a4, 0x17070dee,   // no.hu.fi_653 ha.id.un_540  ha.it.da_433 cs.it.sr_422
  0x180601ad, 0x09002908, 0x0e000a08, 0x2110350e,   // en.de.ga_643 sl.pl.un_430  pt.is.un_430 zu.lt.jw_555
  0x2d0d3502, 0x19006b04, 0x55642805, 0x06311b11,   // zu.cs.sk_222 ceb.gl.un_320  sw.lg.rw_333 tr.az.de_653
  0x0a10170c, 0x12006b07, 0x32000905, 0x0410170d,   // sr.be.mk_543 ceb.hu.un_420  pl.bs.un_330 sr.be.ru_554
  // [1430]
  0x3f120305, 0x08023ba0, 0x102328a0, 0x6b000108,   // nl.hu.af_333 so.da.no_322  sw.ca.lt_322 en.ceb.un_430
  0x18000613, 0x28003f04, 0x27000c04, 0x05002504,   // de.ga.un_650 af.sw.un_320  sv.gd.un_320 eu.fr.un_320
  0x12001813, 0x03001004, 0x080e1f11, 0x03000613,   // ar.ur.un_650 lt.nl.un_320  cy.is.no_653 de.nl.un_650
  0x08041007, 0x17070413, 0x0a002a0c, 0x011f0ea0,   // be.ru.uk_432 ru.bg.sr_665  mt.pt.un_530 is.cy.en_322
  // [1440]
  0x27001814, 0x100407a0, 0x092811ee, 0x130435ee,   // ga.gd.un_660 bg.ru.be_322  ro.sw.pl_422 zu.fi.et_422
  0x3f00060d, 0x0d001902, 0x046420a0, 0x133b1ea0,   // de.af.un_540 gl.cs.un_220  sq.lg.fi_322 ms.so.et_322
  0x06000b02, 0x13552805, 0x29001b0c, 0x0e000413,   // es.de.un_220 sw.rw.et_333  tr.sl.un_530 fi.is.un_650
  0x6b001307, 0x10030f02, 0x0d1c0904, 0x18002111,   // et.ceb.un_420 lv.nl.lt_222  hi.mr.ne_332 fa.ar.un_630
  // [1450]
  0x170a1112, 0x286435a9, 0x32002304, 0x05230a04,   // ro.mk.sr_654 zu.lg.sw_544  ca.bs.un_320 pt.ca.fr_332
  0x1b001804, 0x0c1308ec, 0x0c000613, 0x08132907,   // ga.tr.un_320 no.et.sv_644  de.sv.un_650 sl.et.no_432
  0x16530504, 0x1a215304, 0x12001312, 0x0c030aa0,   // fr.ht.hr_332 ht.jw.tl_332  et.hu.un_640 pt.nl.sv_322
  0x2d0d3bee, 0x0c0208ee, 0x060401a4, 0x1f0d2b07,   // so.cs.sk_422 no.da.sv_422  en.fi.de_433 vi.cs.cy_432
  // [1460]
  0x3f3b020d, 0x55001313, 0x3f080204, 0x1312040d,   // da.so.af_554 et.rw.un_650  da.no.af_332 fi.hu.et_554
  0x0f3b13ec, 0x2a1c2102, 0x092d0d04, 0x182725a6,   // et.so.lv_644 jw.id.mt_222  cs.sk.pl_332 eu.gd.ga_521
  0x0f002704, 0x071104af, 0x126b1a08, 0x0a001004,   // gd.lv.un_320 ru.ro.bg_655  tl.ceb.hu_443 be.mk.un_320
  0x29061fa0, 0x04081104, 0x23000508, 0x100807ec,   // cy.de.sl_322 ro.uk.ru_332  fr.ca.un_430 bg.uk.be_644
  // [1470]
  0x121725a6, 0x645235ee, 0x291827ee, 0x042d0d04,   // eu.sr.hu_521 zu.ha.lg_422  gd.ga.sl_422 cs.sk.fi_332
  0x101b0fa0, 0x126b13ee, 0x0f1729a0, 0x20000c05,   // lv.tr.lt_322 et.ceb.hu_422  sl.sr.lv_322 sv.sq.un_330
  0x04000c0d, 0x045305ee, 0x20000411, 0x05530d0c,   // sv.fi.un_540 fr.ht.fi_422  fi.sq.un_630 cs.ht.fr_543
  0x1f003f04, 0x291208ee, 0x060301a0, 0x08020c0e,   // af.cy.un_320 no.hu.sl_422  en.nl.de_322 sv.da.no_555
  // [1480]
  0x28555207, 0x0900070c, 0x040a170d, 0x100a1713,   // ha.rw.sw_432 it.pl.un_530  sr.mk.ru_554 sr.mk.be_665
  0x0800680c, 0x06000412, 0x4a006820, 0x162d0d04,   // ig.no.un_530 fi.de.un_640  ig.yo.un_850 cs.sk.hr_332
  0x523b1b07, 0x03083fee, 0x07000207, 0x3b030607,   // tr.so.ha_432 af.no.nl_422  da.it.un_420 de.nl.so_432
  0x3f000319, 0x29000c05, 0x091f020c, 0x08120c07,   // nl.af.un_750 sv.sl.un_330  da.cy.pl_543 sv.hu.no_432
  // [1490]
  0x3b6453ec, 0x352a55af, 0x10002d08, 0x643552a7,   // ht.lg.so_644 rw.mt.zu_655  sk.lt.un_430 ha.zu.lg_532
  0x3b006412, 0x1e292d07, 0x0b000504, 0x0900100c,   // lg.so.un_640 sk.sl.ms_432  fr.es.un_320 lt.pl.un_530
  0x2d002907, 0x2a55640c, 0x2d002a08, 0x0d2d090d,   // sl.sk.un_420 lg.rw.mt_543  mt.sk.un_430 pl.sk.cs_554
  0x213568ee, 0x0e0c12ac, 0x21525513, 0x18000a0d,   // ig.zu.jw_422 hu.sv.is_632  rw.ha.jw_665 pt.ga.un_540
  // [14a0]
  0x022d0d09, 0x08131b04, 0x2a0112ee, 0x0c550604,   // cs.sk.da_444 tr.et.no_332  hu.en.mt_422 de.rw.sv_332
  0x55643513, 0x02000e09, 0x06000c12, 0x10000e14,   // zu.lg.rw_665 is.da.un_440  sv.de.un_640 is.lt.un_660
  0x09002a04, 0x352128a0, 0x1c130dec, 0x05001f02,   // mt.pl.un_320 sw.jw.zu_322  ne.bh.mr_644 cy.fr.un_220
  0x21645504, 0x18005302, 0x16002004, 0x0e080202,   // rw.lg.jw_332 ht.ga.un_220  sq.hr.un_320 da.no.is_222
  // [14b0]
  0x1800100c, 0x12001b13, 0x02080c04, 0x0304130d,   // lt.ga.un_530 tr.hu.un_650  sv.no.da_332 et.fi.nl_554
  0x10080260, 0x2d0d28a0, 0x0508020e, 0x0f002d13,   // da.no.lt_664 sw.cs.sk_322  da.no.fr_555 sk.lv.un_650
  0x033f53a4, 0x01002a04, 0x1b0e25a0, 0x0c060ea4,   // ht.af.nl_433 mt.en.un_320  eu.is.tr_322 is.de.sv_433
  0x0e000814, 0x19031fa0, 0x0d252dad, 0x133f1b07,   // no.is.un_660 cy.nl.gl_322  sk.eu.cs_643 tr.af.et_432
  // [14c0]
  0x01533fa7, 0x0c000304, 0x0a002b0c, 0x041328a4,   // af.ht.en_532 nl.sv.un_320  vi.pt.un_530 sw.et.fi_433
  0x55352804, 0x64001f04, 0x09213b0c, 0x2d002012,   // sw.zu.rw_332 cy.lg.un_320  so.jw.pl_543 sq.sk.un_640
  0x0c0821a0, 0x1e1c0d0c, 0x13001804, 0x551f08a7,   // jw.no.sv_322 cs.id.ms_543  ga.et.un_320 no.cy.rw_532
  0x2a641fad, 0x08020c07, 0x10001607, 0x0a1708a4,   // cy.lg.mt_643 sv.da.no_432  hr.lt.un_420 uk.sr.mk_433
  // [14d0]
  0x08120c04, 0x1f6428ad, 0x4a3b1304, 0x640413ad,   // sv.hu.no_332 sw.lg.cy_643  et.so.yo_332 et.fi.lg_643
  0x64001f14, 0x2d006b07, 0x5300101a, 0x0c001908,   // cy.lg.un_660 ceb.sk.un_420  lt.ht.un_760 gl.sv.un_430
  0x17100411, 0x1a000104, 0x07000c02, 0x29002d12,   // ru.be.sr_653 en.tl.un_320  sv.it.un_220 sk.sl.un_640
  0x0f001014, 0x6b033f09, 0x0a0408a0, 0x53002120,   // lt.lv.un_660 af.nl.ceb_444  uk.ru.mk_322 jw.ht.un_850
  // [14e0]
  0x0b000907, 0x4a001012, 0x3f0327a4, 0x311b530c,   // pl.es.un_420 lt.yo.un_640  gd.nl.af_433 ht.tr.az_543
  0x281a52ee, 0x0c080705, 0x05060fa0, 0x02002805,   // ha.tl.sw_422 it.no.sv_333  lv.de.fr_322 sw.da.un_330
  0x09001c0d, 0x17000a02, 0x10080414, 0x05640707,   // mr.hi.un_540 mk.sr.un_220  ru.uk.be_666 it.lg.fr_432
  0x16000b04, 0x04001307, 0x180c0808, 0x05000118,   // es.hr.un_320 et.fi.un_420  no.sv.ga_443 en.fr.un_740
  // [14f0]
  0x192d0d04, 0x01311ba0, 0x12001808, 0x0b28100c,   // cs.sk.gl_332 tr.az.en_322  ga.hu.un_430 lt.sw.es_543
  0x16002902, 0x21002909, 0x28002a02, 0x09001c05,   // sl.hr.un_220 sl.jw.un_440  mt.sw.un_220 mr.hi.un_330
  0x21685507, 0x27002805, 0x520435ee, 0x060501a7,   // rw.ig.jw_432 sw.gd.un_330  zu.fi.ha_422 en.fr.de_532
  0x0c0203a0, 0x4a002b14, 0x52003513, 0x07041002,   // nl.da.sv_322 vi.yo.un_660  zu.ha.un_650 be.ru.bg_222
  // [1500]
  0x3b041304, 0x04001805, 0x12032a04, 0x0c003f0d,   // et.fi.so_332 ga.fi.un_330  mt.nl.hu_332 af.sv.un_540
  0x02033fa0, 0x4a6407ee, 0x27091809, 0x04120c04,   // af.nl.da_322 it.lg.yo_422  ga.pl.gd_444 sv.hu.fi_332
  0x1105070d, 0x04100aee, 0x09001f13, 0x3b310b04,   // it.fr.ro_554 mk.be.ru_422  cy.pl.un_650 es.az.so_332
  0x0e100c04, 0x27000504, 0x00003f1c, 0x271f35ee,   // sv.lt.is_332 fr.gd.un_320  af.un.un_800 zu.cy.gd_422
  // [1510]
  0x07000a07, 0x17070a02, 0x0a1711a4, 0x07080a0c,   // mk.bg.un_420 mk.bg.sr_222  ro.sr.mk_433 mk.uk.bg_543
  0x1c001e0c, 0x0f3f0307, 0x53290d07, 0x0f100c08,   // ms.id.un_530 nl.af.lv_432  cs.sl.ht_432 sv.lt.lv_443
  0x6418010c, 0x110601a4, 0x0d001702, 0x0f002104,   // en.ga.lg_543 en.de.ro_433  sr.cs.un_220 jw.lv.un_320
  0x08020e0c, 0x1e1c3ba4, 0x06286ba4, 0x13043b07,   // is.da.no_543 so.id.ms_433  ceb.sw.de_433 so.fi.et_432
  // [1520]
  0x170a10a0, 0x02000c09, 0x200904ee, 0x35003b04,   // be.mk.sr_322 sv.da.un_440  fi.pl.sq_422 so.zu.un_320
  0x1c1e31a7, 0x0e3b095a, 0x09001f0d, 0x0d1c0912,   // az.ms.id_532 pl.so.is_553  cy.pl.un_540 hi.mr.ne_654
  0x030208ee, 0x211e1c07, 0x2d110d0c, 0x29002d14,   // no.da.nl_422 id.ms.jw_432  cs.ro.sk_543 sk.sl.un_660
  0x184a2ba7, 0x020106ee, 0x11071709, 0x100d0412,   // vi.yo.ga_532 de.en.da_422  sr.bg.ro_444 fi.cs.lt_654
  // [1530]
  0x3200160c, 0x230825a0, 0x04000a0d, 0x1e3b350c,   // hr.bs.un_530 eu.no.ca_322  mk.ru.un_540 zu.so.ms_543
  0x040a1711, 0x293510a4, 0x52000104, 0x091b5307,   // sr.mk.ru_653 lt.zu.sl_433  en.ha.un_320 ht.tr.pl_432
  0x1c642108, 0x08000c0e, 0x1b315504, 0x192107a6,   // jw.lg.id_443 sv.no.un_550  rw.az.tr_332 it.jw.gl_521
  0x102135a6, 0x102106a6, 0x12642aad, 0x52002804,   // zu.jw.lt_521 de.jw.lt_521  mt.lg.hu_643 sw.ha.un_320
  // [1540]
  0x0c1220a6, 0x0d13095a, 0x1e1c0909, 0x13001c13,   // sq.hu.sv_521 hi.bh.ne_553  pl.id.ms_444 mr.bh.un_650
  0x041b0faf, 0x2a06010c, 0x1800210e, 0x2b002702,   // lv.tr.fi_655 en.de.mt_543  fa.ar.un_550 gd.vi.un_220
  0x040811ac, 0x3500280d, 0x031925a0, 0x1f00010c,   // ro.uk.ru_632 sw.zu.un_540  eu.gl.nl_322 en.cy.un_530
  0x4a311b12, 0x3b2331a0, 0x16001e04, 0x18001208,   // tr.az.yo_654 az.ca.so_322  ms.hr.un_320 ur.ar.un_430
  // [1550]
  0x1300290d, 0x0800020b, 0x292d3b0e, 0x2a2032a0,   // sl.et.un_540 da.no.un_520  so.sk.sl_555 bs.sq.mt_322
  0x07000b02, 0x041320a9, 0x16000407, 0x0a102d55,   // es.it.un_220 sq.et.fi_544  fi.hr.un_420 sk.lt.pt_442
  0x190b35ee, 0x531b35ee, 0x2300050e, 0x2d0d10af,   // zu.es.gl_422 zu.tr.ht_422  fr.ca.un_550 lt.cs.sk_655
  0x0a0408ad, 0x64551ba4, 0x6e003519, 0x21001808,   // uk.ru.mk_643 tr.rw.lg_433  zu.hmn.un_750 ga.jw.un_430
  // [1560]
  0x2d002909, 0x1c13090d, 0x040708ad, 0x1b53310e,   // sl.sk.un_440 hi.bh.mr_554  uk.bg.ru_643 az.ht.tr_555
  0x06000a04, 0x010535a0, 0x2d290d12, 0x05003b0d,   // pt.de.un_320 zu.fr.en_322  cs.sl.sk_654 so.fr.un_540
  0x026e1804, 0x552305a7, 0x0200180d, 0x3200170e,   // ga.hmn.da_332 fr.ca.rw_532  ga.da.un_540 sr.bs.un_550
  0x16000f12, 0x3b005505, 0x02000c0d, 0x0f13040c,   // lv.hr.un_640 rw.so.un_330  sv.da.un_540 fi.et.lv_543
  // [1570]
  0x09002d13, 0x13091c08, 0x28000414, 0x01001802,   // sk.pl.un_650 mr.hi.bh_443  fi.sw.un_660 ga.en.un_220
  0x31123ba0, 0x080407a4, 0x2a002507, 0x172129a7,   // so.hu.az_322 bg.ru.uk_433  eu.mt.un_420 sl.jw.sr_532
  0x060e08ee, 0x03001b12, 0x1e1112ee, 0x08120e0c,   // no.is.de_422 tr.nl.un_640  hu.ro.ms_422 is.hu.no_543
  0x13000907, 0x1a6b0807, 0x283509ac, 0x3f285204,   // hi.bh.un_420 no.ceb.tl_432  pl.zu.sw_632 ha.sw.af_332
  // [1580]
  0x25190bee, 0x10170a02, 0x06001313, 0x35000308,   // es.gl.eu_422 mk.sr.be_222  et.de.un_650 nl.zu.un_430
  0x290d100e, 0x07080413, 0x106b1b07, 0x021208ee,   // lt.cs.sl_555 ru.uk.bg_665  tr.ceb.lt_432 no.hu.da_422
  0x25230307, 0x23002014, 0x640328a7, 0x100a17ee,   // nl.ca.eu_432 sq.ca.un_660  sw.nl.lg_532 sr.mk.be_422
  0x06033fad, 0x1b001108, 0x0d131c11, 0x11001b13,   // af.nl.de_643 ro.tr.un_430  mr.bh.ne_653 tr.ro.un_650
  // [1590]
  0x1c2129a7, 0x2d0d1ca0, 0x532d1b08, 0x28005304,   // sl.jw.id_532 id.cs.sk_322  tr.sk.ht_443 ht.sw.un_320
  0x1b001f07, 0x0400280b, 0x250e080d, 0x310c1b04,   // cy.tr.un_420 sw.fi.un_520  no.is.eu_554 tr.sv.az_332
  0x052a0107, 0x16000104, 0x08000c05, 0x1000040d,   // en.mt.fr_432 en.hr.un_320  sv.no.un_330 ru.be.un_540
  0x28000c0e, 0x17110a14, 0x060c08ee, 0x1e001902,   // sv.sw.un_550 mk.ro.sr_666  no.sv.de_422 gl.ms.un_220
  // [15a0]
  0x10253b0b, 0x2b2d3b04, 0x070417ee, 0x0d1c0911,   // so.eu.lt_542 so.sk.vi_332  sr.ru.bg_422 hi.mr.ne_653
  0x070a170c, 0x18006e04, 0x0f0612a4, 0x1c1309a9,   // sr.mk.bg_543 hmn.ga.un_320  hu.de.lv_433 hi.bh.mr_544
  0x09001311, 0x0300050d, 0x643b0e05, 0x0a00070c,   // bh.hi.un_630 fr.nl.un_540  is.so.lg_333 bg.mk.un_530
  0x160f1004, 0x0a04070c, 0x10003b07, 0x320d2da0,   // lt.lv.hr_332 bg.ru.mk_543  so.lt.un_420 sk.cs.bs_322
  // [15b0]
  0x1b081fa0, 0x0f0901a4, 0x01001f0b, 0x10003f05,   // cy.no.tr_322 en.pl.lv_433  cy.en.un_520 af.lt.un_330
  0x31080f04, 0x1c002704, 0x06003f02, 0x0500010d,   // lv.no.az_332 gd.id.un_320  af.de.un_220 en.fr.un_540
  0x0a001109, 0x18000512, 0x23001605, 0x032b16a0,   // ro.pt.un_440 fr.ga.un_640  hr.ca.un_330 hr.vi.nl_322
  0x040a0805, 0x64271804, 0x1c0d1307, 0x281620a0,   // uk.mk.ru_333 ga.gd.lg_332  bh.ne.mr_432 sq.hr.sw_322
  // [15c0]
  0x3f030c08, 0x253b31ee, 0x2916040e, 0x3b0653ec,   // sv.nl.af_443 az.so.eu_422  fi.hr.sl_555 ht.de.so_644
  0x11000719, 0x10000f13, 0x1f00050b, 0x18131f55,   // bg.ro.un_750 lv.lt.un_650  fr.cy.un_520 cy.et.ga_442
  0x01102da0, 0x0e033f07, 0x64005204, 0x1c061eee,   // sk.lt.en_322 af.nl.is_432  ha.lg.un_320 ms.de.id_422
  0x21000804, 0x0600350d, 0x21001c0d, 0x10001707,   // no.jw.un_320 zu.de.un_540  id.jw.un_540 sr.be.un_420
  // [15d0]
  0x12352004, 0x28001c04, 0x2a1e2107, 0x070817a0,   // sq.zu.hu_332 id.sw.un_320  jw.ms.mt_432 sr.uk.bg_322
  0x3b00130e, 0x07000804, 0x2a311e08, 0x130408af,   // et.so.un_550 uk.bg.un_320  ms.az.mt_443 no.fi.et_655
  0x0f001012, 0x35006808, 0x0e3b27ad, 0x0c02080c,   // lt.lv.un_640 ig.zu.un_430  gd.so.is_643 no.da.sv_543
  0x1100180d, 0x180128a6, 0x02311bad, 0x3f210360,   // ga.ro.un_540 sw.en.ga_521  tr.az.da_643 nl.jw.af_664
  // [15e0]
  0x11005507, 0x32122904, 0x2000310e, 0x201a1f04,   // rw.ro.un_420 sl.hu.bs_332  az.sq.un_550 cy.tl.sq_332
  0x020413ad, 0x040a11a0, 0x211e0eee, 0x31001b18,   // et.fi.da_643 ro.mk.ru_322  is.ms.jw_422 tr.az.un_740
  0x1c00640c, 0x1f0608ad, 0x07001011, 0x10170808,   // lg.id.un_530 no.de.cy_643  be.bg.un_630 uk.sr.be_443
  0x250b1907, 0x19250aa4, 0x030608a4, 0x1a003f07,   // gl.es.eu_432 pt.eu.gl_433  no.de.nl_433 af.tl.un_420
  // [15f0]
  0x0800040d, 0x3b081a12, 0x08006b05, 0x0a001712,   // ru.uk.un_540 tl.no.so_654  ceb.no.un_330 sr.mk.un_640
  0x12002019, 0x0a001107, 0x18190f04, 0x2b190fa0,   // sq.hu.un_750 ro.mk.un_420  lv.gl.ga_332 lv.gl.vi_322
  0x08006e08, 0x21033f02, 0x1f001813, 0x080a04af,   // hmn.no.un_430 af.nl.jw_222  ga.cy.un_650 ru.mk.uk_655
  0x1e1c2aa0, 0x520e01a4, 0x19230ba4, 0x0408070c,   // mt.id.ms_322 en.is.ha_433  es.ca.gl_433 bg.uk.ru_543
  // [1600]
  0x07081104, 0x0c002a09, 0x234a18ee, 0x642029ee,   // ro.uk.bg_332 mt.sv.un_440  ga.yo.ca_422 sl.sq.lg_422
  0x1f006b04, 0x21001204, 0x12003b0d, 0x120c0807,   // ceb.cy.un_320 ur.fa.un_320  so.hu.un_540 no.sv.hu_432
  0x12000e0d, 0x4a0d2d12, 0x0b000304, 0x0600270c,   // is.hu.un_540 sk.cs.yo_654  nl.es.un_320 gd.de.un_530
  0x0f1001a4, 0x17100cee, 0x29003b0d, 0x3b002914,   // en.lt.lv_433 sv.lt.sr_422  so.sl.un_540 sl.so.un_660
  // [1610]
  0x31002907, 0x12102da6, 0x08100411, 0x530f28ac,   // sl.az.un_420 sk.lt.hu_521  ru.be.uk_653 sw.lv.ht_632
  0x170a11ee, 0x32162907, 0x101708a4, 0x1f001902,   // ro.mk.sr_422 sl.hr.bs_432  uk.sr.be_433 gl.cy.un_220
  0x2900200d, 0x643501a0, 0x0c2128a0, 0x29003204,   // sq.sl.un_540 en.zu.lg_322  sw.jw.sv_322 bs.sl.un_320
  0x18000a0e, 0x040a1704, 0x1812210d, 0x131c0955,   // pt.ga.un_550 sr.mk.ru_332  fa.ur.ar_554 hi.mr.bh_442
  // [1620]
  0x06002504, 0x20003508, 0x120f11a7, 0x07002504,   // eu.de.un_320 zu.sq.un_430  ro.lv.hu_532 eu.it.un_320
  0x6b002705, 0x03010aa0, 0x04100813, 0x21003b13,   // gd.ceb.un_330 pt.en.nl_322  uk.be.ru_665 so.jw.un_650
  0x03000c04, 0x1e000e04, 0x530406a0, 0x09003b04,   // sv.nl.un_320 is.ms.un_320  de.fi.ht_322 so.pl.un_320
  0x2a001819, 0x170728ec, 0x031b31a0, 0x090d1c0c,   // ga.mt.un_750 sw.it.sr_644  az.tr.nl_322 mr.ne.hi_543
  // [1630]
  0x28100aa4, 0x6b0e25a4, 0x645503ec, 0x0e000c07,   // pt.lt.sw_433 eu.is.ceb_433  nl.rw.lg_644 sv.is.un_420
  0x3f6435ee, 0x190b0a55, 0x25001a02, 0x07080404,   // zu.lg.af_422 pt.es.gl_442  tl.eu.un_220 ru.uk.bg_332
  0x0a000411, 0x6b191fa7, 0x4a6855ec, 0x186b01ee,   // ru.mk.un_630 cy.gl.ceb_532  rw.ig.yo_644 en.ceb.ga_422
  0x10070aec, 0x0b1007a0, 0x35006413, 0x02000c02,   // mk.bg.be_644 it.lt.es_322  lg.zu.un_650 sv.da.un_220
  // [1640]
  0x17000908, 0x12000918, 0x0900030d, 0x081017ee,   // pl.sr.un_430 pl.hu.un_740  nl.pl.un_540 sr.be.uk_422
  0x0603040d, 0x0900290d, 0x3b000f07, 0x29003504,   // fi.nl.de_554 sl.pl.un_540  lv.so.un_420 zu.sl.un_320
  0x12192da0, 0x1e1c28a0, 0x0f003505, 0x10352ba7,   // sk.gl.hu_322 sw.id.ms_322  zu.lv.un_330 vi.zu.lt_532
  0x09000612, 0x17040a02, 0x070810a0, 0x6800551b,   // de.pl.un_640 mk.ru.sr_222  be.uk.bg_322 rw.ig.un_770
  // [1650]
  0x2a126407, 0x2100280d, 0x070c0ea0, 0x04070a0c,   // lg.hu.mt_432 sw.jw.un_540  is.sv.it_322 mk.bg.ru_543
  0x0a001704, 0x13523ba9, 0x11003b04, 0x080710ee,   // sr.mk.un_320 so.ha.et_544  so.ro.un_320 be.bg.uk_422
  0x13002712, 0x1b202aa0, 0x3216290c, 0x3f036407,   // gd.et.un_640 mt.sq.tr_322  sl.hr.bs_543 lg.nl.af_432
  0x3b006404, 0x0f55645a, 0x17292da0, 0x181927ac,   // lg.so.un_320 lg.rw.lv_553  sk.sl.sr_322 gd.gl.ga_632
  // [1660]
  0x355521ad, 0x0c0806af, 0x52001704, 0x2a0a07a0,   // jw.rw.zu_643 de.no.sv_655  sr.ha.un_320 it.pt.mt_322
  0x04001304, 0x11001721, 0x16212807, 0x2a000e19,   // et.fi.un_320 sr.ro.un_860  sw.jw.hr_432 is.mt.un_750
  0x041c2804, 0x0e1f27ad, 0x16003104, 0x52130407,   // sw.id.fi_332 gd.cy.is_643  az.hr.un_320 fi.et.ha_432
  0x12002a0c, 0x293b2da0, 0x23000a13, 0x16180704,   // mt.hu.un_530 sk.so.sl_322  pt.ca.un_650 it.ga.hr_332
  // [1670]
  0x182d0d09, 0x080220a0, 0x230511a0, 0x18003204,   // cs.sk.ga_444 sq.da.no_322  ro.fr.ca_322 bs.ga.un_320
  0x3f000f19, 0x190b230c, 0x19131b04, 0x35556408,   // lv.af.un_750 ca.es.gl_543  tr.et.gl_332 lg.rw.zu_443
  0x29531105, 0x1b003107, 0x17000412, 0x01250a07,   // ro.ht.sl_333 az.tr.un_420  ru.sr.un_640 pt.eu.en_432
  0x282a18a4, 0x08120ca0, 0x536b0107, 0x131c095a,   // ga.mt.sw_433 sv.hu.no_322  en.ceb.ht_432 hi.mr.bh_553
  // [1680]
  0x0500110c, 0x2b1f01ad, 0x02000511, 0x066404ee,   // ro.fr.un_530 en.cy.vi_643  fr.da.un_630 fi.lg.de_422
  0x2d002913, 0x3f2003ee, 0x0e000305, 0x0d130912,   // sl.sk.un_650 nl.sq.af_422  nl.is.un_330 hi.bh.ne_654
  0x100523ee, 0x0a351b07, 0x29352807, 0x12030209,   // ca.fr.lt_422 tr.zu.pt_432  sw.zu.sl_432 da.nl.hu_444
  0x081004a9, 0x07001114, 0x182701ad, 0x28082007,   // ru.be.uk_544 ro.bg.un_660  en.gd.ga_643 sq.no.sw_432
  // [1690]
  0x2d0d07a0, 0x291610ee, 0x2718110e, 0x132d2907,   // it.cs.sk_322 lt.hr.sl_422  ro.ga.gd_555 sl.sk.et_432
  0x27000120, 0x182725a4, 0x321721ee, 0x29083f04,   // en.gd.un_850 eu.gd.ga_433  jw.sr.bs_422 af.no.sl_332
  0x1c005504, 0x182701af, 0x0d352804, 0x06033f0c,   // rw.id.un_320 en.gd.ga_655  sw.zu.cs_332 af.nl.de_543
  0x12000e04, 0x161211a0, 0x19002707, 0x16094a02,   // is.hu.un_320 ro.hu.hr_322  gd.gl.un_420 yo.pl.hr_222
  // [16a0]
  0x08554aa0, 0x55001f04, 0x3f0c0304, 0x64005502,   // yo.rw.no_322 cy.rw.un_320  nl.sv.af_332 rw.lg.un_220
  0x111310a0, 0x16000204, 0x32001709, 0x2a52640d,   // lt.et.ro_322 da.hr.un_320  sr.bs.un_440 lg.ha.mt_554
  0x07170a12, 0x08000213, 0x01005302, 0x522d0daf,   // mk.sr.bg_654 da.no.un_650  ht.en.un_220 cs.sk.ha_655
  0x55001705, 0x0a0408a9, 0x1e1c52a0, 0x021310a0,   // sr.rw.un_330 uk.ru.mk_544  ha.id.ms_322 lt.et.da_322
  // [16b0]
  0x1e006408, 0x18270a07, 0x2a0c64a0, 0x2d001b13,   // lg.ms.un_430 pt.gd.ga_432  lg.sv.mt_322 tr.sk.un_650
  0x64005519, 0x3f001314, 0x1a003107, 0x53554aa0,   // rw.lg.un_750 et.af.un_660  az.tl.un_420 yo.rw.ht_322
  0x3b646b0c, 0x13040807, 0x21640107, 0x102529a4,   // ceb.lg.so_543 no.fi.et_432  en.lg.jw_432 sl.eu.lt_433
  0x19550a04, 0x31000604, 0x06080ca4, 0x1e136404,   // pt.rw.gl_332 de.az.un_320  sv.no.de_433 lg.et.ms_332
  // [16c0]
  0x0d00090e, 0x10002913, 0x0b004a07, 0x07012807,   // hi.ne.un_550 sl.lt.un_650  yo.es.un_420 sw.en.it_432
  0x53001b13, 0x0c000704, 0x31230555, 0x0c081b08,   // tr.ht.un_650 it.sv.un_320  fr.ca.az_442 tr.no.sv_443
  0x101729ec, 0x03001b08, 0x0d091c0c, 0x282d0dac,   // sl.sr.lt_644 tr.nl.un_430  mr.hi.ne_543 cs.sk.sw_632
  0x0a642807, 0x080210a0, 0x64005202, 0x0b0a6402,   // sw.lg.pt_432 lt.da.no_322  ha.lg.un_220 lg.pt.es_222
  // [16d0]
  0x17001e02, 0x03000207, 0x4a1f1007, 0x21006b11,   // ms.sr.un_220 da.nl.un_420  lt.cy.yo_432 ceb.jw.un_630
  0x3b006409, 0x051901a4, 0x25006413, 0x09001f04,   // lg.so.un_440 en.gl.fr_433  lg.eu.un_650 cy.pl.un_320
  0x05002902, 0x061204ad, 0x1c0d13a7, 0x08006404,   // sl.fr.un_220 fi.hu.de_643  bh.ne.mr_532 lg.no.un_320
  0x00000201, 0x1f27010c, 0x645528a9, 0x0c00040c,   // da.un.un_200 en.gd.cy_543  sw.rw.lg_544 fi.sv.un_530
  // [16e0]
  0x6b040c04, 0x2a003b07, 0x13001c04, 0x0c001b12,   // sv.fi.ceb_332 so.mt.un_420  mr.bh.un_320 tr.sv.un_640
  0x311a3b55, 0x235301a0, 0x31005204, 0x0e001813,   // so.tl.az_442 en.ht.ca_322  ha.az.un_320 ga.is.un_650
  0x3b004a04, 0x09005304, 0x0400170d, 0x32002505,   // yo.so.un_320 ht.pl.un_320  sr.ru.un_540 eu.bs.un_330
  0x0f2d0912, 0x045206a0, 0x1e6b10ee, 0x2a10110b,   // pl.sk.lv_654 de.ha.fi_322  lt.ceb.ms_422 ro.lt.mt_542
  // [16f0]
  0x09003504, 0x21276807, 0x0e350a04, 0x20002108,   // zu.pl.un_320 ig.gd.jw_432  pt.zu.is_332 jw.sq.un_430
  0x313b1ba4, 0x08060204, 0x170a110d, 0x0b2d0ead,   // tr.so.az_433 da.de.no_332  ro.mk.sr_554 is.sk.es_643
  0x171011a7, 0x0e1f53a0, 0x1f002a07, 0x3b001313,   // ro.be.sr_532 ht.cy.is_322  mt.cy.un_420 et.so.un_650
  0x2a645504, 0x2d001702, 0x35000307, 0x03253f02,   // rw.lg.mt_332 sr.sk.un_220  nl.zu.un_420 af.eu.nl_222
  // [1700]
  0x1a003b07, 0x17080aa0, 0x0400080e, 0x09000b04,   // so.tl.un_420 mk.uk.sr_322  uk.ru.un_550 es.pl.un_320
  0x2d040da0, 0x13080407, 0x23001604, 0x040717a0,   // cs.fi.sk_322 fi.no.et_432  hr.ca.un_320 sr.bg.ru_322
  0x1a001f04, 0x162d35a4, 0x020c1805, 0x1f002a08,   // cy.tl.un_320 zu.sk.hr_433  ga.sv.da_333 mt.cy.un_430
  0x17163210, 0x556b1c0b, 0x17000818, 0x070408ec,   // bs.hr.sr_642 id.ceb.rw_542  uk.sr.un_740 uk.ru.bg_644
  // [1710]
  0x17005507, 0x0f060107, 0x0e12180b, 0x02005502,   // rw.sr.un_420 en.de.lv_432  ga.hu.is_542 rw.da.un_220
  0x1f000e12, 0x3b1029ee, 0x29133b12, 0x55001104,   // is.cy.un_640 sl.lt.so_422  so.et.sl_654 ro.rw.un_320
  0x17115504, 0x093b1307, 0x020c080d, 0x4a00120e,   // rw.ro.sr_332 et.so.pl_432  no.sv.da_554 hu.yo.un_550
  0x0e00640c, 0x13000309, 0x040c06a7, 0x03061bee,   // lg.is.un_530 nl.et.un_440  de.sv.fi_532 tr.de.nl_422
  // [1720]
  0x1000110d, 0x1c000d11, 0x16001104, 0x130d09a9,   // ro.be.un_540 ne.mr.un_630  ro.hr.un_320 hi.ne.bh_544
  0x6e006405, 0x11100a0c, 0x190b01ee, 0x353f03ee,   // lg.hmn.un_330 mk.be.ro_543  en.es.gl_422 nl.af.zu_422
  0x52532112, 0x0410080c, 0x23000b09, 0x040710ee,   // jw.ht.ha_654 uk.be.ru_543  es.ca.un_440 be.bg.ru_422
  0x0e101208, 0x3f002305, 0x31201b05, 0x3f0e0ca0,   // hu.lt.is_443 ca.af.un_330  tr.sq.az_333 sv.is.af_322
  // [1730]
  0x016b040c, 0x322d0dad, 0x1a6435ee, 0x06002702,   // fi.ceb.en_543 cs.sk.bs_643  zu.lg.tl_422 gd.de.un_220
  0x290413ee, 0x100304a4, 0x6b001c07, 0x2800060c,   // et.fi.sl_422 fi.nl.lt_433  id.ceb.un_420 de.sw.un_530
  0x18000407, 0x351b2804, 0x3b004a07, 0x040e1005,   // fi.ga.un_420 sw.tr.zu_332  yo.so.un_420 lt.is.fi_333
  0x1a3f01a7, 0x53000808, 0x35006b12, 0x0e002102,   // en.af.tl_532 no.ht.un_430  ceb.zu.un_640 jw.is.un_220
  // [1740]
  0x3f0329a0, 0x080302ee, 0x0d103f07, 0x3b004a05,   // sl.nl.af_322 da.nl.no_422  af.lt.cs_432 yo.so.un_330
  0x12002d13, 0x07000913, 0x31003b0d, 0x0a0804ad,   // sk.hu.un_650 pl.it.un_650  so.az.un_540 ru.uk.mk_643
  0x2d001802, 0x321725a0, 0x0c2a20a4, 0x2d1b09ac,   // ga.sk.un_220 eu.sr.bs_322  sq.mt.sv_433 pl.tr.sk_632
  0x1f002104, 0x03023f02, 0x2a312004, 0x17041002,   // jw.cy.un_320 af.da.nl_222  sq.az.mt_332 be.ru.sr_222
  // [1750]
  0x1a6b6408, 0x0c2a0408, 0x12000e0e, 0x0e002a0c,   // lg.ceb.tl_443 fi.mt.sv_443  is.hu.un_550 mt.is.un_530
  0x0f001004, 0x1200210c, 0x1e1b5302, 0x25040c0b,   // lt.lv.un_320 fa.ur.un_530  ht.tr.ms_222 sv.fi.eu_542
  0x0f1310a4, 0x10080ead, 0x0b680611, 0x0e080608,   // lt.et.lv_433 is.no.lt_643  de.ig.es_653 de.no.is_443
  0x19000a12, 0x520625ee, 0x111807a0, 0x0d00050c,   // pt.gl.un_640 eu.de.ha_422  it.ga.ro_322 fr.cs.un_530
  // [1760]
  0x1b001707, 0x12000205, 0x053f030b, 0x292d0d60,   // sr.tr.un_420 da.hu.un_330  nl.af.fr_542 cs.sk.sl_664
  0x162d0607, 0x52000507, 0x0d202da0, 0x3b2a31a9,   // de.sk.hr_432 fr.ha.un_420  sk.sq.cs_322 az.mt.so_544
  0x3b120107, 0x0600070d, 0x315564ee, 0x05005305,   // en.hu.so_432 it.de.un_540  lg.rw.az_422 ht.fr.un_330
  0x12001107, 0x68230704, 0x25005207, 0x10001c02,   // ro.hu.un_420 it.ca.ig_332  ha.eu.un_420 id.lt.un_220
  // [1770]
  0x3b0e04ad, 0x11070aaf, 0x0c002a05, 0x3f530405,   // fi.is.so_643 mk.bg.ro_655  mt.sv.un_330 fi.ht.af_333
  0x180306ec, 0x29002d0c, 0x2552550c, 0x19030502,   // de.nl.ga_644 sk.sl.un_530  rw.ha.eu_543 fr.nl.gl_222
  0x071310ad, 0x060c08a4, 0x21121a07, 0x64352812,   // lt.et.it_643 no.sv.de_433  tl.hu.jw_432 sw.zu.lg_654
  0x0c0802ee, 0x4a005219, 0x536455a4, 0x553b52a0,   // da.no.sv_422 ha.yo.un_750  rw.lg.ht_433 ha.so.rw_322
  // [1780]
  0x29002104, 0x6e000313, 0x6e00011a, 0x03000607,   // jw.sl.un_320 nl.hmn.un_650  en.hmn.un_760 de.nl.un_420
  0x52004a04, 0x4a000a0c, 0x3100530d, 0x1f3f030b,   // yo.ha.un_320 pt.yo.un_530  ht.az.un_540 nl.af.cy_542
  0x1b643512, 0x3b001312, 0x102a3f05, 0x07001f13,   // zu.lg.tr_654 et.so.un_640  af.mt.lt_333 cy.it.un_650
  0x55002519, 0x0a005304, 0x13033f07, 0x1a002105,   // eu.rw.un_750 ht.pt.un_320  af.nl.et_432 jw.tl.un_330
  // [1790]
  0x09000f0e, 0x1700041a, 0x12001904, 0x2d0d19ee,   // lv.pl.un_550 ru.sr.un_760  gl.hu.un_320 gl.cs.sk_422
  0x322d0802, 0x4a5552ad, 0x040c1307, 0x28000b08,   // no.sk.bs_222 ha.rw.yo_643  et.sv.fi_432 es.sw.un_430
  0x081b03a0, 0x3f001f19, 0x28001e02, 0x06531307,   // nl.tr.no_322 cy.af.un_750  ms.sw.un_220 et.ht.de_432
  0x68001105, 0x12000c05, 0x2a006813, 0x6b2d0d05,   // ro.ig.un_330 sv.hu.un_330  ig.mt.un_650 cs.sk.ceb_333
  // [17a0]
  0x09070da0, 0x3f000c07, 0x033f25af, 0x3f031fac,   // cs.it.pl_322 sv.af.un_420  eu.af.nl_655 cy.nl.af_632
  0x0c0f0804, 0x03002512, 0x1c00210d, 0x23100ea4,   // no.lv.sv_332 eu.nl.un_640  jw.id.un_540 is.lt.ca_433
  0x17000d08, 0x040a10ee, 0x066b0c08, 0x033f02a7,   // cs.sr.un_430 be.mk.ru_422  sv.ceb.de_443 da.af.nl_532
  0x0f0e23a4, 0x276b01ee, 0x0e001c04, 0x251011ee,   // ca.is.lv_433 en.ceb.gd_422  id.is.un_320 ro.lt.eu_422
  // [17b0]
  0x03200804, 0x03060ca4, 0x12005507, 0x08230ca0,   // no.sq.nl_332 sv.de.nl_433  rw.hu.un_420 sv.ca.no_322
  0x3b000412, 0x05180107, 0x29080eee, 0x0a001e04,   // fi.so.un_640 en.ga.fr_432  is.no.sl_422 ms.pt.un_320
  0x64002814, 0x53681f12, 0x05110107, 0x4a136407,   // sw.lg.un_660 cy.ig.ht_654  en.ro.fr_432 lg.et.yo_432
  0x070e0807, 0x25005504, 0x523b28a0, 0x0e4a52ac,   // no.is.it_432 rw.eu.un_320  sw.so.ha_322 ha.yo.is_632
  // [17c0]
  0x29321607, 0x0e004a14, 0x1710080c, 0x0f310c02,   // hr.bs.sl_432 yo.is.un_660  uk.be.sr_543 sv.az.lv_222
  0x09531f04, 0x10190b04, 0x132006ad, 0x02005309,   // cy.ht.pl_332 es.gl.lt_332  de.sq.et_643 ht.da.un_440
  0x35001e02, 0x0704170e, 0x6b2855a0, 0x172d29a9,   // ms.zu.un_220 sr.ru.bg_555  rw.sw.ceb_322 sl.sk.sr_544
  0x3b005205, 0x02000504, 0x1b001109, 0x09005207,   // ha.so.un_330 fr.da.un_320  ro.tr.un_440 ha.pl.un_420
  // [17d0]
  0x3b1a6404, 0x0e002704, 0x13002702, 0x10002d0c,   // lg.tl.so_332 gd.is.un_320  gd.et.un_220 sk.lt.un_530
  0x042d0d02, 0x281f5507, 0x05110704, 0x133b04ec,   // cs.sk.fi_222 rw.cy.sw_432  it.ro.fr_332 fi.so.et_644
  0x686b3ba4, 0x230b0a04, 0x3f031f0e, 0x0c060209,   // so.ceb.ig_433 pt.es.ca_332  cy.nl.af_555 da.de.sv_444
  0x3b00010d, 0x0a170704, 0x11000304, 0x23131b13,   // en.so.un_540 bg.sr.mk_332  nl.ro.un_320 tr.et.ca_665
  // [17e0]
  0x4a006408, 0x3f072aee, 0x060e1307, 0x6b6835a0,   // lg.yo.un_430 mt.it.af_422  et.is.de_432 zu.ig.ceb_322
  0x18000b08, 0x07000814, 0x6400280e, 0x161155ee,   // es.ga.un_430 uk.bg.un_660  sw.lg.un_550 rw.ro.hr_422
  0x100a21a0, 0x0a5311af, 0x21006b1a, 0x016b0607,   // jw.pt.lt_322 ro.ht.pt_655  ceb.jw.un_760 de.ceb.en_432
  0x060c040c, 0x0c0f02a0, 0x0600081a, 0x1a6b2107,   // fi.sv.de_543 da.lv.sv_322  no.de.un_760 jw.ceb.tl_432
  // [17f0]
  0x06002a0c, 0x3f000302, 0x1100250d, 0x2d0a0507,   // mt.de.un_530 nl.af.un_220  eu.ro.un_540 fr.pt.sk_432
  0x08001308, 0x0a0e28a0, 0x08062aa0, 0x2b001805,   // et.no.un_430 sw.is.pt_322  mt.de.no_322 ga.vi.un_330
  0x03283505, 0x1a006e07, 0x18001904, 0x0c002104,   // zu.sw.nl_333 hmn.tl.un_420  gl.ga.un_320 jw.sv.un_320
  0x08020ca6, 0x3b520f12, 0x1f033f0c, 0x0f001702,   // sv.da.no_521 lv.ha.so_654  af.nl.cy_543 sr.lv.un_220

  // [1800]
  0x0f2a09a0, 0x106b030b, 0x100501a4, 0x1a3555ee,   // pl.mt.lv_322 nl.ceb.lt_542  en.fr.lt_433 rw.zu.tl_422
  0x0a230107, 0x641004a4, 0x1e1c3b05, 0x17001107,   // en.ca.pt_432 fi.lt.lg_433  so.id.ms_333 ro.sr.un_420
  0x11005505, 0x32000a07, 0x0d002d12, 0x1f682a04,   // rw.ro.un_330 pt.bs.un_420  sk.cs.un_640 mt.ig.cy_332
  0x28006412, 0x101b0907, 0x080201a4, 0x13255504,   // lg.sw.un_640 pl.tr.lt_432  en.da.no_433 rw.eu.et_332
  // [1810]
  0x060d03ee, 0x10170fa4, 0x0f2155a7, 0x3217160c,   // nl.cs.de_422 lv.sr.lt_433  rw.jw.lv_532 hr.sr.bs_543
  0x1c1b1ea7, 0x292d09a4, 0x2a002804, 0x182d01a0,   // ms.tr.id_532 pl.sk.sl_433  sw.mt.un_320 en.sk.ga_322
  0x3b2d0d5a, 0x13002904, 0x25230fa7, 0x0c00040e,   // cs.sk.so_553 sl.et.un_320  lv.ca.eu_532 fi.sv.un_550
  0x1104255a, 0x550535ee, 0x6b000413, 0x1a006b0d,   // eu.fi.ro_553 zu.fr.rw_422  fi.ceb.un_650 ceb.tl.un_540
  // [1820]
  0x2d001218, 0x10070a12, 0x0a07110c, 0x106b1a09,   // hu.sk.un_740 mk.bg.be_654  ro.bg.mk_543 tl.ceb.lt_444
  0x23002513, 0x03000702, 0x05062807, 0x28004a02,   // eu.ca.un_650 it.nl.un_220  sw.de.fr_432 yo.sw.un_220
  0x0a171104, 0x530305a7, 0x012b35a7, 0x3f030202,   // ro.sr.mk_332 fr.nl.ht_532  zu.vi.en_532 da.nl.af_222
  0x0d292d55, 0x553f0504, 0x35000c04, 0x12002702,   // sk.sl.cs_442 fr.af.rw_332  sv.zu.un_320 gd.hu.un_220
  // [1830]
  0x3b6425a0, 0x06080c09, 0x100f32a0, 0x52003b08,   // eu.lg.so_322 sv.no.de_444  bs.lv.lt_322 so.ha.un_430
  0x52355502, 0x3132110c, 0x1f001214, 0x181225a7,   // rw.zu.ha_222 ro.bs.az_543  hu.cy.un_660 eu.hu.ga_532
  0x53256404, 0x6b002112, 0x23001f02, 0x101117af,   // lg.eu.ht_332 jw.ceb.un_640  cy.ca.un_220 sr.ro.be_655
  0x0c001319, 0x35002012, 0x05035307, 0x20002307,   // et.sv.un_750 sq.zu.un_640  ht.nl.fr_432 ca.sq.un_420
  // [1840]
  0x13002802, 0x2d120d0c, 0x1f001807, 0x04000a09,   // sw.et.un_220 cs.hu.sk_543  ga.cy.un_420 mk.ru.un_440
  0x231e1ca0, 0x13000414, 0x06002505, 0x0b0a19ee,   // id.ms.ca_322 fi.et.un_660  eu.de.un_330 gl.pt.es_422
  0x04354a0b, 0x190b07a0, 0x08040702, 0x2a000b04,   // yo.zu.fi_542 it.es.gl_322  bg.ru.uk_222 es.mt.un_320
  0x64002112, 0x180827ad, 0x283f1aa4, 0x00002124,   // jw.lg.un_640 gd.no.ga_643  tl.af.sw_433 jw.un.un_900
  // [1850]
  0x4a5564ad, 0x1c0913ac, 0x521b0dee, 0x293f0355,   // lg.rw.yo_643 bh.hi.mr_632  cs.tr.ha_422 nl.af.sl_442
  0x170a11ad, 0x32290da6, 0x06001805, 0x31281b08,   // ro.mk.sr_643 cs.sl.bs_521  ga.de.un_330 tr.sw.az_443
  0x3b001314, 0x1c002908, 0x4a00520c, 0x170704af,   // et.so.un_660 sl.id.un_430  ha.yo.un_530 ru.bg.sr_655
  0x4a3b1a0c, 0x06120c02, 0x171110ad, 0x190b01a0,   // tl.so.yo_543 sv.hu.de_222  be.ro.sr_643 en.es.gl_322
  // [1860]
  0x32172909, 0x3f001b09, 0x11002b02, 0x64063fa6,   // sl.sr.bs_444 tr.af.un_440  vi.ro.un_220 af.de.lg_521
  0x1e002507, 0x212d0d0e, 0x3f1f0907, 0x535231a7,   // eu.ms.un_420 cs.sk.jw_555  pl.cy.af_432 az.ha.ht_532
  0x19052308, 0x0a002a07, 0x175311ee, 0x060c03a0,   // ca.fr.gl_443 mt.pt.un_420  ro.ht.sr_422 nl.sv.de_322
  0x3b252702, 0x3500281a, 0x182728a6, 0x17040a13,   // gd.eu.so_222 sw.zu.un_760  sw.gd.ga_521 mk.ru.sr_665
  // [1870]
  0x0c080607, 0x1900230c, 0x0f1e2707, 0x281335ee,   // de.no.sv_432 ca.gl.un_530  gd.ms.lv_432 zu.et.sw_422
  0x10070a0e, 0x1c216404, 0x3b002a04, 0x04131ca0,   // mk.bg.be_555 lg.jw.id_332  mt.so.un_320 id.et.fi_322
  0x11000414, 0x08063f07, 0x0d00210d, 0x10002d12,   // ru.ro.un_660 af.de.no_432  jw.cs.un_540 sk.lt.un_640
  0x06132aa6, 0x131223a7, 0x320d0907, 0x201031a0,   // mt.et.de_521 ca.hu.et_532  pl.cs.bs_432 az.lt.sq_322
  // [1880]
  0x321709ec, 0x163211a9, 0x13023f0c, 0x0a0e1255,   // pl.sr.bs_644 ro.bs.hr_544  af.da.et_543 hu.is.pt_442
  0x110a0405, 0x040108ad, 0x321608a0, 0x08071104,   // ru.mk.ro_333 no.en.fi_643  no.hr.bs_322 ro.bg.uk_332
  0x0d091c0b, 0x070a1055, 0x170a0812, 0x12532504,   // mr.hi.ne_542 be.mk.bg_442  uk.mk.sr_654 eu.ht.hu_332
  0x1b005304, 0x0c0413a9, 0x041327a0, 0x0b001b08,   // ht.tr.un_320 et.fi.sv_544  gd.et.fi_322 tr.es.un_430
  // [1890]
  0x0d1c13a0, 0x32170fa0, 0x040817a9, 0x1300090b,   // bh.mr.ne_322 lv.sr.bs_322  sr.uk.ru_544 hi.bh.un_520
  0x20002a0c, 0x09130407, 0x0411080c, 0x210631a0,   // mt.sq.un_530 fi.et.pl_432  uk.ro.ru_543 az.de.jw_322
  0x13000c04, 0x18005212, 0x062704af, 0x040e08a0,   // sv.et.un_320 ha.ga.un_640  fi.gd.de_655 no.is.fi_322
  0x13172902, 0x01003b07, 0x0b002805, 0x0b2d3107,   // sl.sr.et_222 so.en.un_420  sw.es.un_330 az.sk.es_432
  // [18a0]
  0x031f08a0, 0x190a2302, 0x090d2d0b, 0x64531f02,   // no.cy.nl_322 ca.pt.gl_222  sk.cs.pl_542 cy.ht.lg_222
  0x0a040855, 0x31001a02, 0x6400682a, 0x04033f08,   // uk.ru.mk_442 tl.az.un_220  ig.lg.un_970 af.nl.fi_443
  0x0e1f1209, 0x041710a9, 0x1c6452a0, 0x1f0818ee,   // hu.cy.is_444 be.sr.ru_544  ha.lg.id_322 ga.no.cy_422
  0x08000212, 0x04201305, 0x0d120c05, 0x3f3b1fa4,   // da.no.un_640 et.sq.fi_333  sv.hu.cs_333 cy.so.af_433
  // [18b0]
  0x2a041205, 0x03000507, 0x060701a4, 0x6b311b07,   // hu.fi.mt_333 fr.nl.un_420  en.it.de_433 tr.az.ceb_432
  0x3b1e21a0, 0x3b311b07, 0x0f553504, 0x0f000b07,   // jw.ms.so_322 tr.az.so_432  zu.rw.lv_332 es.lv.un_420
  0x02001302, 0x4a3555ee, 0x2000280d, 0x27003f07,   // et.da.un_220 rw.zu.yo_422  sw.sq.un_540 af.gd.un_420
  0x080209ec, 0x2700110c, 0x04080205, 0x043f0307,   // pl.da.no_644 ro.gd.un_530  da.no.fi_333 nl.af.fi_432
  // [18c0]
  0x68255508, 0x080203a0, 0x35006402, 0x0d00050e,   // rw.eu.ig_443 nl.da.no_322  lg.zu.un_220 fr.cs.un_550
  0x20103fec, 0x062d1104, 0x021020ac, 0x1827110c,   // af.lt.sq_644 ro.sk.de_332  sq.lt.da_632 ro.gd.ga_543
  0x07001013, 0x1a6455a4, 0x321617ee, 0x182711a7,   // be.bg.un_650 rw.lg.tl_433  sr.hr.bs_422 ro.gd.ga_532
  0x170a0807, 0x5564285a, 0x051901ad, 0x28251f0d,   // uk.mk.sr_432 sw.lg.rw_553  en.gl.fr_643 cy.eu.sw_554
  // [18d0]
  0x063f0304, 0x0e1801ee, 0x351b3b0c, 0x09001212,   // nl.af.de_332 en.ga.is_422  so.tr.zu_543 hu.pl.un_640
  0x201b10a0, 0x08001009, 0x0c032304, 0x07100404,   // lt.tr.sq_322 be.uk.un_440  ca.nl.sv_332 fi.lt.it_332
  0x35025511, 0x06002305, 0x3b005204, 0x170709ee,   // rw.da.zu_653 ca.de.un_330  ha.so.un_320 pl.it.sr_422
  0x0400070c, 0x1f00120b, 0x20000108, 0x1f000502,   // bg.ru.un_530 hu.cy.un_520  en.sq.un_430 fr.cy.un_220
  // [18e0]
  0x28311ba4, 0x19002513, 0x5300280c, 0x01080208,   // tr.az.sw_433 eu.gl.un_650  sw.ht.un_530 da.no.en_443
  0x03311b07, 0x64001f1a, 0x6404130c, 0x10030902,   // tr.az.nl_432 cy.lg.un_760  et.fi.lg_543 pl.nl.lt_222
  0x03063f05, 0x1f0d31ee, 0x01002d04, 0x0e080213,   // af.de.nl_333 az.cs.cy_422  sk.en.un_320 da.no.is_665
  0x28001804, 0x080a1704, 0x3b270e02, 0x166b10ad,   // ga.sw.un_320 sr.mk.uk_332  is.gd.so_222 lt.ceb.hr_643
  // [18f0]
  0x11121f04, 0x05000405, 0x1b1e1aee, 0x080c130e,   // cy.hu.ro_332 fi.fr.un_330  tl.ms.tr_422 et.sv.no_555
  0x31190a12, 0x0c011bee, 0x13314a04, 0x08025302,   // pt.gl.az_654 tr.en.sv_422  yo.az.et_332 ht.da.no_222
  0x020908ee, 0x17070404, 0x020c0e05, 0x68000908,   // no.pl.da_422 ru.bg.sr_332  is.sv.da_333 pl.ig.un_430
  0x13000d18, 0x100c08a0, 0x552d0d04, 0x32000f08,   // ne.bh.un_740 no.sv.lt_322  cs.sk.rw_332 lv.bs.un_430
  // [1900]
  0x10003f04, 0x23001f04, 0x17041007, 0x165528a7,   // af.lt.un_320 cy.ca.un_320  be.ru.sr_432 sw.rw.hr_532
  0x043b1312, 0x19050108, 0x13001b19, 0x120410ee,   // et.so.fi_654 en.fr.gl_443  tr.et.un_750 lt.fi.hu_422
  0x32172102, 0x3553310c, 0x016b0da0, 0x0417070e,   // jw.sr.bs_222 az.ht.zu_543  cs.ceb.en_322 bg.sr.ru_555
  0x1800350d, 0x03002504, 0x08001113, 0x0a001808,   // zu.ga.un_540 eu.nl.un_320  ro.uk.un_650 ga.pt.un_430
  // [1910]
  0x1008040c, 0x53523507, 0x321629a6, 0x6404135a,   // ru.uk.be_543 zu.ha.ht_432  sl.hr.bs_521 et.fi.lg_553
  0x0c0e08a0, 0x11310704, 0x2700080c, 0x0f0d0304,   // no.is.sv_322 it.az.ro_332  no.gd.un_530 nl.cs.lv_332
  0x05033f0d, 0x64002807, 0x64003b05, 0x532328ee,   // af.nl.fr_554 sw.lg.un_420  so.lg.un_330 sw.ca.ht_422
  0x03000a02, 0x09000308, 0x553564ad, 0x2d321604,   // pt.nl.un_220 nl.pl.un_430  lg.zu.rw_643 hr.bs.sk_332
  // [1920]
  0x52200a13, 0x16133fa0, 0x2a1055a9, 0x2a002012,   // pt.sq.ha_665 af.et.hr_322  rw.lt.mt_544 sq.mt.un_640
  0x08170a07, 0x081309af, 0x0a0c01a9, 0x553508a4,   // mk.sr.uk_432 pl.et.no_655  en.sv.pt_544 no.zu.rw_433
  0x091c13a4, 0x31001b05, 0x2b002707, 0x072729a0,   // bh.mr.hi_433 tr.az.un_330  gd.vi.un_420 sl.gd.it_322
  0x080f2d07, 0x0f001b12, 0x0518040b, 0x313b1bee,   // sk.lv.no_432 tr.lv.un_640  fi.ga.fr_542 tr.so.az_422
  // [1930]
  0x11000702, 0x061a0107, 0x02003f04, 0x1c090d05,   // it.ro.un_220 en.tl.de_432  af.da.un_320 ne.hi.mr_333
  0x070a17a0, 0x1c0d13ec, 0x16093502, 0x04002807,   // sr.mk.bg_322 bh.ne.mr_644  zu.pl.hr_222 sw.fi.un_420
  0x555301a0, 0x0600250e, 0x0c030804, 0x2d002b0e,   // en.ht.rw_322 eu.de.un_550  no.nl.sv_332 vi.sk.un_550
  0x18000d12, 0x3f090fee, 0x03001f12, 0x290d2d07,   // cs.ga.un_640 lv.pl.af_422  cy.nl.un_640 sk.cs.sl_432
  // [1940]
  0x1b001107, 0x0a170405, 0x1300090c, 0x3b555207,   // ro.tr.un_420 ru.sr.mk_333  hi.bh.un_530 ha.rw.so_432
  0x061064a0, 0x1900250d, 0x091c0da0, 0x211a090b,   // lg.lt.de_322 eu.gl.un_540  ne.mr.hi_322 pl.tl.jw_542
  0x0a041004, 0x21002b0c, 0x2d001019, 0x05000412,   // be.ru.mk_332 vi.jw.un_530  lt.sk.un_750 fi.fr.un_640
  0x3f1a2807, 0x3f0c0fa0, 0x07211255, 0x3b003105,   // sw.tl.af_432 lv.sv.af_322  hu.jw.it_442 az.so.un_330
  // [1950]
  0x09006408, 0x10170aa0, 0x352864a0, 0x100904a6,   // lg.pl.un_430 mk.sr.be_322  lg.sw.zu_322 fi.pl.lt_521
  0x01000704, 0x55002808, 0x3b212708, 0x2900550c,   // it.en.un_320 sw.rw.un_430  gd.jw.so_443 rw.sl.un_530
  0x01212d07, 0x35006b08, 0x64000705, 0x10005302,   // sk.jw.en_432 ceb.zu.un_430  it.lg.un_330 ht.lt.un_220
  0x55281012, 0x13001013, 0x04071104, 0x23110a05,   // lt.sw.rw_654 lt.et.un_650  ro.bg.ru_332 pt.ro.ca_333
  // [1960]
  0x031004a9, 0x31351b08, 0x1e002105, 0x104a2909,   // fi.lt.nl_544 tr.zu.az_443  jw.ms.un_330 sl.yo.lt_444
  0x1a645502, 0x10070805, 0x102a0e0d, 0x205528ee,   // rw.lg.tl_222 uk.bg.be_333  is.mt.lt_554 sw.rw.sq_422
  0x162d23a4, 0x13643b04, 0x21005308, 0x28003112,   // ca.sk.hr_433 so.lg.et_332  ht.jw.un_430 az.sw.un_640
  0x0a001720, 0x04080a0d, 0x21001a0d, 0x0a286855,   // sr.mk.un_850 mk.uk.ru_554  tl.jw.un_540 ig.sw.pt_442
  // [1970]
  0x2a005305, 0x1200211b, 0x4a0b0a05, 0x3f050307,   // ht.mt.un_330 fa.ur.un_770  pt.es.yo_333 nl.fr.af_432
  0x0d321707, 0x212a1c04, 0x05120da0, 0x04003f0e,   // sr.bs.cs_432 id.mt.jw_332  cs.hu.fr_322 af.fi.un_550
  0x17070aa7, 0x3f0305a4, 0x0c000802, 0x18006404,   // mk.bg.sr_532 fr.nl.af_433  no.sv.un_220 lg.ga.un_320
  0x08020305, 0x12000c0c, 0x4a3f1b04, 0x0f001604,   // nl.da.no_333 sv.hu.un_530  tr.af.yo_332 hr.lv.un_320
  // [1980]
  0x24000111, 0x09001905, 0x19120e08, 0x6e000613,   // iw.yi.un_630 gl.pl.un_330  is.hu.gl_443 de.hmn.un_650
  0x25193b0c, 0x12001a02, 0x070a17ee, 0x0a17070c,   // so.gl.eu_543 tl.hu.un_220  sr.mk.bg_422 bg.sr.mk_543
  0x170a070c, 0x645568ee, 0x03002019, 0x53001012,   // bg.mk.sr_543 ig.rw.lg_422  sq.nl.un_750 lt.ht.un_640
  0x53101bad, 0x182312ec, 0x3f533b04, 0x160c13ad,   // tr.lt.ht_643 hu.ca.ga_644  so.ht.af_332 et.sv.hr_643
  // [1990]
  0x1f533fa0, 0x1a3b55a0, 0x125328ee, 0x04132d0c,   // af.ht.cy_322 rw.so.tl_322  sw.ht.hu_422 sk.et.fi_543
  0x2b001f07, 0x0c0e0813, 0x3b00280c, 0x3b001f05,   // cy.vi.un_420 no.is.sv_665  sw.so.un_530 cy.so.un_330
  0x311301a0, 0x04001a02, 0x2a001e02, 0x10350f04,   // en.et.az_322 tl.fi.un_220  ms.mt.un_220 lv.zu.lt_332
  0x53281b07, 0x3f0625a0, 0x063f0ca0, 0x17160aa0,   // tr.sw.ht_432 eu.de.af_322  sv.af.de_322 pt.hr.sr_322
  // [19a0]
  0x0a1710ee, 0x19000108, 0x04000702, 0x0a281104,   // be.sr.mk_422 en.gl.un_430  bg.ru.un_220 ro.sw.pt_332
  0x3b191004, 0x2a002008, 0x0d2d10ac, 0x1e121b0c,   // lt.gl.so_332 sq.mt.un_430  lt.sk.cs_632 tr.hu.ms_543
  0x051106a9, 0x0e001904, 0x05131b04, 0x3f0c06ee,   // de.ro.fr_544 gl.is.un_320  tr.et.fr_332 de.sv.af_422
  0x4a002502, 0x17000a0e, 0x03271805, 0x080204ee,   // eu.yo.un_220 mk.sr.un_550  ga.gd.nl_333 fi.da.no_422
  // [19b0]
  0x2500060e, 0x0704085a, 0x19070a07, 0x1c2a21a0,   // de.eu.un_550 uk.ru.bg_553  pt.it.gl_432 jw.mt.id_322
  0x071908a0, 0x11000a07, 0x0f00100d, 0x28001c02,   // no.gl.it_322 pt.ro.un_420  lt.lv.un_540 id.sw.un_220
  0x18005504, 0x11101708, 0x1e003b04, 0x324a09a6,   // rw.ga.un_320 sr.be.ro_443  so.ms.un_320 pl.yo.bs_521
  0x0a1304a4, 0x1e1c2109, 0x1c3121a0, 0x04000304,   // fi.et.pt_433 jw.id.ms_444  jw.az.id_322 nl.fi.un_320
  // [19c0]
  0x210802a0, 0x08002902, 0x28000107, 0x10000e04,   // da.no.jw_322 sl.no.un_220  en.sw.un_420 is.lt.un_320
  0x11000807, 0x0c000a08, 0x1b002507, 0x28000104,   // no.ro.un_420 pt.sv.un_430  eu.tr.un_420 en.sw.un_320
  0x4a000d0c, 0x1c1321a0, 0x27162a0c, 0x231901a0,   // cs.yo.un_530 jw.et.id_322  mt.hr.gd_543 en.gl.ca_322
  0x0a001102, 0x27000c07, 0x0b0c13af, 0x1308025a,   // ro.pt.un_220 sv.gd.un_420  et.sv.es_655 da.no.et_553
  // [19d0]
  0x3f230fee, 0x06080302, 0x1b31205a, 0x083f02a0,   // lv.ca.af_422 nl.no.de_222  sq.az.tr_553 da.af.no_322
  0x016b2dad, 0x5321290c, 0x1c0d09ad, 0x19130ca7,   // sk.ceb.en_643 sl.jw.ht_543  hi.ne.mr_643 sv.et.gl_532
  0x532311a7, 0x231b0aa0, 0x01003502, 0x02123fee,   // ro.ca.ht_532 pt.tr.ca_322  zu.en.un_220 af.hu.da_422
  0x181f01a7, 0x53102907, 0x1c002b05, 0x080e1f13,   // en.cy.ga_532 sl.lt.ht_432  vi.id.un_330 cy.is.no_665
  // [19e0]
  0x0400050c, 0x17005204, 0x1200010d, 0x0700080d,   // fr.fi.un_530 ha.sr.un_320  en.hu.un_540 uk.bg.un_540
  0x25000b02, 0x0c3b2002, 0x5300081a, 0x64001a09,   // es.eu.un_220 sq.so.sv_222  no.ht.un_760 tl.lg.un_440
  0x21000b02, 0x0b01110c, 0x190a01a0, 0x3b000307,   // es.jw.un_220 ro.en.es_543  en.pt.gl_322 nl.so.un_420
  0x4a21100c, 0x0c1925a7, 0x270b3bee, 0x09001218,   // lt.jw.yo_543 eu.gl.sv_532  so.es.gd_422 hu.pl.un_740
  // [19f0]
  0x1a130e08, 0x6400550d, 0x21273bad, 0x0000231c,   // is.et.tl_443 rw.lg.un_540  so.gd.jw_643 ca.un.un_800
  0x110a17a4, 0x12271811, 0x0b0a23ee, 0x0b002507,   // sr.mk.ro_433 ga.gd.hu_653  ca.pt.es_422 eu.es.un_420
  0x12020ca4, 0x0d020302, 0x3f001c02, 0x3f006b07,   // sv.da.hu_433 nl.da.cs_222  id.af.un_220 ceb.af.un_420
  0x033f060c, 0x2b002004, 0x5200211a, 0x190a010c,   // de.af.nl_543 sq.vi.un_320  jw.ha.un_760 en.pt.gl_543
  // [1a00]
  0x080a07a0, 0x18001202, 0x201209ec, 0x18000912,   // bg.mk.uk_322 ur.ar.un_220  pl.hu.sq_644 pl.ga.un_640
  0x08006b07, 0x0c0308a0, 0x531b55ee, 0x641b3102,   // ceb.no.un_420 no.nl.sv_322  rw.tr.ht_422 az.tr.lg_222
  0x25190b09, 0x092d0d12, 0x1e0a05a9, 0x1708100c,   // es.gl.eu_444 cs.sk.pl_654  fr.pt.ms_544 be.uk.sr_543
  0x09083bac, 0x033f0ea0, 0x093b2d0c, 0x042a0c02,   // so.no.pl_632 is.af.nl_322  sk.so.pl_543 sv.mt.fi_222
  // [1a10]
  0x3f00130e, 0x133f0355, 0x29131fa0, 0x280635ee,   // et.af.un_550 nl.af.et_442  cy.et.sl_322 zu.de.sw_422
  0x25003113, 0x0c1f1055, 0x2d090da0, 0x1000230d,   // az.eu.un_650 lt.cy.sv_442  cs.pl.sk_322 ca.lt.un_540
  0x0a005202, 0x046453a0, 0x270f5507, 0x251c53ec,   // ha.pt.un_220 ht.lg.fi_322  rw.lv.gd_432 ht.id.eu_644
  0x4a005302, 0x0900120d, 0x130f2d07, 0x322d0d55,   // ht.yo.un_220 hu.pl.un_540  sk.lv.et_432 cs.sk.bs_442
  // [1a20]
  0x296435ee, 0x250612ad, 0x12002711, 0x03353f05,   // zu.lg.sl_422 hu.de.eu_643  gd.hu.un_630 af.zu.nl_333
  0x031f0607, 0x06020c07, 0x29030604, 0x35005304,   // de.cy.nl_432 sv.da.de_432  de.nl.sl_332 ht.zu.un_320
  0x2b001604, 0x03060ca0, 0x102835a0, 0x0800070e,   // hr.vi.un_320 sv.de.nl_322  zu.sw.lt_322 bg.uk.un_550
  0x070a1760, 0x29000d13, 0x53001602, 0x3f000e13,   // sr.mk.bg_664 cs.sl.un_650  hr.ht.un_220 is.af.un_650
  // [1a30]
  0x13000204, 0x0600100c, 0x06130c02, 0x03000707,   // da.et.un_320 lt.de.un_530  sv.et.de_222 it.nl.un_420
  0x18002b12, 0x1c640407, 0x352028ee, 0x53190b08,   // vi.ga.un_640 fi.lg.id_432  sw.sq.zu_422 es.gl.ht_443
  0x5568250c, 0x04080760, 0x2d090d08, 0x0c080212,   // eu.ig.rw_543 bg.uk.ru_664  cs.pl.sk_443 da.no.sv_654
  0x06000818, 0x09005512, 0x200306ee, 0x02286ba7,   // no.de.un_740 rw.pl.un_640  de.nl.sq_422 ceb.sw.da_532
  // [1a40]
  0x0f25230c, 0x08000304, 0x3f250308, 0x081011a4,   // ca.eu.lv_543 nl.no.un_320  nl.eu.af_443 ro.be.uk_433
  0x2000081a, 0x10002104, 0x25002a07, 0x02090807,   // no.sq.un_760 jw.lt.un_320  mt.eu.un_420 no.pl.da_432
  0x192b1b07, 0x3f040807, 0x0d000304, 0x101b0fa4,   // tr.vi.gl_432 no.fi.af_432  nl.cs.un_320 lv.tr.lt_433
  0x0f000b04, 0x0d102d07, 0x311b28a9, 0x3f00020c,   // es.lv.un_320 sk.lt.cs_432  sw.tr.az_544 da.af.un_530
  // [1a50]
  0x23200aaf, 0x203217a0, 0x2a00680d, 0x0c0306a0,   // pt.sq.ca_655 sr.bs.sq_322  ig.mt.un_540 de.nl.sv_322
  0x0407100c, 0x02042704, 0x00003524, 0x13640405,   // be.bg.ru_543 gd.fi.da_332  zu.un.un_900 fi.lg.et_333
  0x20355205, 0x28355507, 0x080417ec, 0x0d002907,   // ha.zu.sq_333 rw.zu.sw_432  sr.ru.uk_644 sl.cs.un_420
  0x310f55af, 0x28006807, 0x0c08020e, 0x0400250e,   // rw.lv.az_655 ig.sw.un_420  da.no.sv_555 eu.fi.un_550
  // [1a60]
  0x3b212aee, 0x08050e07, 0x3f003514, 0x55640faf,   // mt.jw.so_422 is.fr.no_432  zu.af.un_660 lv.lg.rw_655
  0x6b3b08a0, 0x0d2911a9, 0x35273b02, 0x170408ec,   // no.so.ceb_322 ro.sl.cs_544  so.gd.zu_222 uk.ru.sr_644
  0x1f08020d, 0x28130412, 0x64352aaf, 0x2d001602,   // da.no.cy_554 fi.et.sw_654  mt.zu.lg_655 hr.sk.un_220
  0x01002704, 0x19001212, 0x64280fa0, 0x12001007,   // gd.en.un_320 hu.gl.un_640  lv.sw.lg_322 lt.hu.un_420
  // [1a70]
  0x130c0807, 0x11000f12, 0x3100200d, 0x3f003519,   // no.sv.et_432 lv.ro.un_640  sq.az.un_540 zu.af.un_750
  0x2a350655, 0x044a3b0d, 0x090306a7, 0x3b003507,   // de.zu.mt_442 so.yo.fi_554  de.nl.pl_532 zu.so.un_420
  0x0f1113ad, 0x112b0704, 0x0e001908, 0x0e081304,   // et.ro.lv_643 it.vi.ro_332  gl.is.un_430 et.no.is_332
  0x160513a0, 0x11102307, 0x090d1ca4, 0x18001902,   // et.fr.hr_322 ca.lt.ro_432  mr.ne.hi_433 gl.ga.un_220
  // [1a80]
  0x16002104, 0x25132107, 0x1b4a640b, 0x04000d12,   // jw.hr.un_320 jw.et.eu_432  lg.yo.tr_542 cs.fi.un_640
  0x16071105, 0x010f0807, 0x0c093fa0, 0x31203502,   // ro.it.hr_333 no.lv.en_432  af.pl.sv_322 zu.sq.az_222
  0x1f120302, 0x3b1801ee, 0x01002304, 0x212513af,   // nl.hu.cy_222 en.ga.so_422  ca.en.un_320 et.eu.jw_655
  0x13006414, 0x112a5204, 0x200a230c, 0x1b315502,   // lg.et.un_660 ha.mt.ro_332  ca.pt.sq_543 rw.az.tr_222
  // [1a90]
  0x04120604, 0x136b01ee, 0x071704ad, 0x061e25ee,   // de.hu.fi_332 en.ceb.et_422  ru.sr.bg_643 eu.ms.de_422
  0x64000912, 0x03210607, 0x23080504, 0x16001108,   // pl.lg.un_640 de.jw.nl_432  fr.no.ca_332 ro.hr.un_430
  0x20002305, 0x060c0308, 0x35000913, 0x12002009,   // ca.sq.un_330 nl.sv.de_443  pl.zu.un_650 sq.hu.un_440
  0x0a112007, 0x1a281c07, 0x2d356404, 0x06001e07,   // sq.ro.pt_432 id.sw.tl_432  lg.zu.sk_332 ms.de.un_420
  // [1aa0]
  0x0a0411a0, 0x6b000b04, 0x04000212, 0x253528a7,   // ro.ru.mk_322 es.ceb.un_320  da.fi.un_640 sw.zu.eu_532
  0x2b00050d, 0x0f171602, 0x211e3b04, 0x350428a0,   // fr.vi.un_540 hr.sr.lv_222  so.ms.jw_332 sw.fi.zu_322
  0x071318a9, 0x133f0607, 0x111255a6, 0x2a553505,   // ga.et.it_544 de.af.et_432  rw.hu.ro_521 zu.rw.mt_333
  0x11001f0e, 0x18000108, 0x6b000509, 0x53641211,   // cy.ro.un_550 en.ga.un_430  fr.ceb.un_440 hu.lg.ht_653
  // [1ab0]
  0x231807a0, 0x4a006421, 0x00006b24, 0x23001f1a,   // it.ga.ca_322 lg.yo.un_860  ceb.un.un_900 cy.ca.un_760
  0x2d5564ad, 0x4a5564a7, 0x55281a04, 0x0c006412,   // lg.rw.sk_643 lg.rw.yo_532  tl.sw.rw_332 lg.sv.un_640
  0x0e006408, 0x3f002504, 0x1b4a2107, 0x1b00640d,   // lg.is.un_430 eu.af.un_320  jw.yo.tr_432 lg.tr.un_540
  0x1e351c07, 0x032b01a4, 0x3f0c02ee, 0x016b3f08,   // id.zu.ms_432 en.vi.nl_433  da.sv.af_422 af.ceb.en_443
  // [1ac0]
  0x0c006408, 0x281b55ec, 0x27023bee, 0x130704ee,   // lg.sv.un_430 rw.tr.sw_644  so.da.gd_422 fi.it.et_422
  0x533f03ac, 0x10002712, 0x2d00290e, 0x020c0812,   // nl.af.ht_632 gd.lt.un_640  sl.sk.un_550 no.sv.da_654
  0x0b000702, 0x190b25a9, 0x040810ec, 0x0708110c,   // it.es.un_220 eu.es.gl_544  be.uk.ru_644 ro.uk.bg_543
  0x31351b12, 0x6e211c04, 0x53000514, 0x0e292da4,   // tr.zu.az_654 id.jw.hmn_332  fr.ht.un_660 sk.sl.is_433
  // [1ad0]
  0x05005309, 0x06002704, 0x52133507, 0x0800130d,   // ht.fr.un_440 gd.de.un_320  zu.et.ha_432 et.no.un_540
  0x1b160d07, 0x190a0d05, 0x354a6412, 0x352864ad,   // cs.hr.tr_432 cs.pt.gl_333  lg.yo.zu_654 lg.sw.zu_643
  0x18171255, 0x05190a04, 0x19230555, 0x170713a0,   // hu.sr.ga_442 pt.gl.fr_332  fr.ca.gl_442 et.it.sr_322
  0x232520a0, 0x0f000607, 0x1f00280e, 0x0a000509,   // sq.eu.ca_322 de.lv.un_420  sw.cy.un_550 fr.pt.un_440
  // [1ae0]
  0x080206a0, 0x646e250c, 0x35002805, 0x07000507,   // de.da.no_322 eu.hmn.lg_543  sw.zu.un_330 fr.it.un_420
  0x101711a0, 0x08110760, 0x2a3b13a9, 0x01133ba0,   // ro.sr.be_322 bg.ro.uk_664  et.so.mt_544 so.et.en_322
  0x0c1b0407, 0x12000304, 0x1e18110c, 0x175535a0,   // fi.tr.sv_432 nl.hu.un_320  ro.ga.ms_543 zu.rw.sr_322
  0x07000a1b, 0x35005522, 0x061f2304, 0x27004a05,   // mk.bg.un_770 rw.zu.un_870  ca.cy.de_332 yo.gd.un_330
  // [1af0]
  0x3b643508, 0x08005302, 0x52000108, 0x16002a04,   // zu.lg.so_443 ht.no.un_220  en.ha.un_430 mt.hr.un_320
  0x4a000504, 0x07002708, 0x0f1013a7, 0x353b55a9,   // fr.yo.un_320 gd.it.un_430  et.lt.lv_532 rw.so.zu_544
  0x19003b13, 0x07002a13, 0x073b1f04, 0x0d005508,   // so.gl.un_650 mt.it.un_650  cy.so.it_332 rw.cs.un_430
  0x0000041c, 0x16002a07, 0x16002807, 0x05004a04,   // fi.un.un_800 mt.hr.un_420  sw.hr.un_420 yo.fr.un_320
  // [1b00]
  0x313b1208, 0x28005309, 0x071305a4, 0x286455a4,   // hu.so.az_443 ht.sw.un_440  fr.et.it_433 rw.lg.sw_433
  0x040a1012, 0x07002a08, 0x3f0313a0, 0x0c001702,   // be.mk.ru_654 mt.it.un_430  et.nl.af_322 sr.sv.un_220
  0x53001a09, 0x12005219, 0x0c0304ee, 0x6435550c,   // tl.ht.un_440 ha.hu.un_750  fi.nl.sv_422 rw.zu.lg_543
  0x06000e05, 0x0c062504, 0x27000104, 0x3f001f12,   // is.de.un_330 eu.de.sv_332  en.gd.un_320 cy.af.un_640
  // [1b10]
  0x190b0aa4, 0x17001a04, 0x1912180b, 0x0e00310c,   // pt.es.gl_433 tl.sr.un_320  ga.hu.gl_542 az.is.un_530
  0x111707a4, 0x311b11a4, 0x4a1a6b08, 0x313b21a4,   // bg.sr.ro_433 ro.tr.az_433  ceb.tl.yo_443 jw.so.az_433
  0x3f005513, 0x03010602, 0x171632a4, 0x12000708,   // rw.af.un_650 de.en.nl_222  bs.hr.sr_433 it.hu.un_430
  0x093f0f08, 0x0c003f04, 0x3f000204, 0x08170712,   // lv.af.pl_443 af.sv.un_320  da.af.un_320 bg.sr.uk_654
  // [1b20]
  0x25642aa4, 0x2500050e, 0x100704ee, 0x1800060c,   // mt.lg.eu_433 fr.eu.un_550  ru.bg.be_422 de.ga.un_530
  0x040811ee, 0x05070307, 0x162d0d5a, 0x09071104,   // ro.uk.ru_422 nl.it.fr_432  cs.sk.hr_553 ro.it.pl_332
  0x6b041fa7, 0x07010604, 0x1e1f1207, 0x685301ee,   // cy.fi.ceb_532 de.en.it_332  hu.cy.ms_432 en.ht.ig_422
  0x1b080ca4, 0x01001f04, 0x0e0c25a0, 0x32163f07,   // sv.no.tr_433 cy.en.un_320  eu.sv.is_322 af.hr.bs_432
  // [1b30]
  0x100c0814, 0x080c020c, 0x686b01a4, 0x0c003504,   // no.sv.lt_666 da.sv.no_543  en.ceb.ig_433 zu.sv.un_320
  0x17322055, 0x13000807, 0x05003505, 0x0a64040c,   // sq.bs.sr_442 no.et.un_420  zu.fr.un_330 fi.lg.pt_543
  0x1923055a, 0x06003f08, 0x10550504, 0x202852a0,   // fr.ca.gl_553 af.de.un_430  fr.rw.lt_332 ha.sw.sq_322
  0x35212005, 0x6b1a5507, 0x0700170d, 0x04131012,   // sq.jw.zu_333 rw.tl.ceb_432  sr.bg.un_540 lt.et.fi_654
  // [1b40]
  0x312a20ad, 0x29005504, 0x6e000413, 0x4a00680e,   // sq.mt.az_643 rw.sl.un_320  fi.hmn.un_650 ig.yo.un_550
  0x0e1001a4, 0x28006b05, 0x1c130907, 0x102718a4,   // en.lt.is_433 ceb.sw.un_330  hi.bh.mr_432 ga.gd.lt_433
  0x35005518, 0x04000802, 0x031c1ea0, 0x2a1c2107,   // rw.zu.un_740 uk.ru.un_220  ms.id.nl_322 jw.id.mt_432
  0x53130407, 0x190a0b05, 0x06182d07, 0x13041005,   // fi.et.ht_432 es.pt.gl_333  sk.ga.de_432 lt.fi.et_333
  // [1b50]
  0x1c04180c, 0x29003b07, 0x04000e0e, 0x322916a0,   // ga.fi.id_543 so.sl.un_420  is.fi.un_550 hr.sl.bs_322
  0x04530804, 0x17040812, 0x07110a04, 0x17000504,   // no.ht.fi_332 uk.ru.sr_654  mk.ro.bg_332 fr.sr.un_320
  0x11522807, 0x0e08020d, 0x310c3b04, 0x19250ba9,   // sw.ha.ro_432 da.no.is_554  so.sv.az_332 es.eu.gl_544
  0x1c000412, 0x3f0603a0, 0x21064a04, 0x04182804,   // fi.id.un_640 nl.de.af_322  yo.de.jw_332 sw.ga.fi_332
  // [1b60]
  0x11002d0d, 0x11081208, 0x13003b07, 0x204a29a7,   // sk.ro.un_540 hu.no.ro_443  so.et.un_420 sl.yo.sq_532
  0x112055ee, 0x554a13ee, 0x311b2012, 0x1f001c04,   // rw.sq.ro_422 et.yo.rw_422  sq.tr.az_654 id.cy.un_320
  0x02001819, 0x020608a6, 0x013527a0, 0x01002802,   // ga.da.un_750 no.de.da_521  gd.zu.en_322 sw.en.un_220
  0x133f1804, 0x1000251a, 0x110501a4, 0x0c050608,   // ga.af.et_332 eu.lt.un_760  en.fr.ro_433 de.fr.sv_443
  // [1b70]
  0x18272dad, 0x1f002d12, 0x0d001212, 0x351055ee,   // sk.gd.ga_643 sk.cy.un_640  hu.cs.un_640 rw.lt.zu_422
  0x1a6b3b60, 0x09001104, 0x311b640c, 0x06041b0c,   // so.ceb.tl_664 ro.pl.un_320  lg.tr.az_543 tr.fi.de_543
  0x1b003102, 0x174a1b0e, 0x0e08200b, 0x02002d08,   // az.tr.un_220 tr.yo.sr_555  sq.no.is_542 sk.da.un_430
  0x3f5505a0, 0x0a001213, 0x0502080c, 0x25271102,   // fr.rw.af_322 hu.pt.un_650  no.da.fr_543 ro.gd.eu_222
  // [1b80]
  0x64354aa4, 0x07121107, 0x00001a1c, 0x0705550c,   // yo.zu.lg_433 ro.hu.it_432  tl.un.un_800 rw.fr.it_543
  0x0a001120, 0x1a006b09, 0x68005518, 0x0e001902,   // ro.mk.un_850 ceb.tl.un_440  rw.ig.un_740 gl.is.un_220
  0x6428520c, 0x23191fac, 0x192b07a0, 0x0c020e55,   // ha.sw.lg_543 cy.gl.ca_632  it.vi.gl_322 is.da.sv_442
  0x04060307, 0x0c060412, 0x55002113, 0x2d0d31a4,   // nl.de.fi_432 fi.de.sv_654  jw.rw.un_650 az.cs.sk_433
  // [1b90]
  0x52004a0c, 0x18112707, 0x2d0d20a4, 0x29000707,   // yo.ha.un_530 gd.ro.ga_432  sq.cs.sk_433 it.sl.un_420
  0x28292d07, 0x216452a0, 0x1c213fa0, 0x12052da7,   // sk.sl.sw_432 ha.lg.jw_322  af.jw.id_322 sk.fr.hu_532
  0x21005508, 0x160f2904, 0x6b641ba0, 0x2d0d12ee,   // rw.jw.un_430 sl.lv.hr_332  tr.lg.ceb_322 hu.cs.sk_422
  0x01001302, 0x0e000a04, 0x12100407, 0x04000e0c,   // et.en.un_220 pt.is.un_320  fi.lt.hu_432 is.fi.un_530
  // [1ba0]
  0x1a6b3508, 0x1a6e1f12, 0x05000302, 0x52283ba0,   // zu.ceb.tl_443 cy.hmn.tl_654  nl.fr.un_220 so.sw.ha_322
  0x0c082a04, 0x21643108, 0x1716320c, 0x285304a4,   // mt.no.sv_332 az.lg.jw_443  bs.hr.sr_543 fi.ht.sw_433
  0x1c1e3b07, 0x531c5504, 0x55110f04, 0x31000807,   // so.ms.id_432 rw.id.ht_332  lv.ro.rw_332 no.az.un_420
  0x11005302, 0x05520aec, 0x060208a4, 0x211c0602,   // ht.ro.un_220 pt.ha.fr_644  no.da.de_433 de.id.jw_222
  // [1bb0]
  0x17040a08, 0x0c181ba0, 0x100a04a0, 0x551f520b,   // mk.ru.sr_443 tr.ga.sv_322  ru.mk.be_322 ha.cy.rw_542
  0x080c0207, 0x6b1a1213, 0x1b2d12ad, 0x131f6ba4,   // da.sv.no_432 hu.tl.ceb_665  hu.sk.tr_643 ceb.cy.et_433
  0x1a1b080c, 0x0c003118, 0x21001a02, 0x28043b07,   // no.tr.tl_543 az.sv.un_740  tl.jw.un_220 so.fi.sw_432
  0x29000e1a, 0x25006b0d, 0x1a280107, 0x553b1308,   // is.sl.un_760 ceb.eu.un_540  en.sw.tl_432 et.so.rw_443
  // [1bc0]
  0x3b033f12, 0x3b132aa0, 0x556b3b07, 0x0608020d,   // af.nl.so_654 mt.et.so_322  so.ceb.rw_432 da.no.de_554
  0x091f0d07, 0x13271813, 0x6428210c, 0x3b1304ec,   // cs.cy.pl_432 ga.gd.et_665  jw.sw.lg_543 fi.et.so_644
  0x353b5504, 0x0d093507, 0x6b2d0d0d, 0x100b0f55,   // rw.so.zu_332 zu.pl.cs_432  cs.sk.ceb_554 lv.es.lt_442
  0x020a0807, 0x08020ca9, 0x12000e1a, 0x29125504,   // no.pt.da_432 sv.da.no_544  is.hu.un_760 rw.hu.sl_332
  // [1bd0]
  0x320c13ee, 0x1c521eee, 0x210b0507, 0x3f080ca0,   // et.sv.bs_422 ms.ha.id_422  fr.es.jw_432 sv.no.af_322
  0x01001107, 0x04133b11, 0x1f000808, 0x196b0d08,   // ro.en.un_420 so.et.fi_653  no.cy.un_430 cs.ceb.gl_443
  0x0c2a0807, 0x040a10a0, 0x2d005502, 0x3b00550d,   // no.mt.sv_432 be.mk.ru_322  rw.sk.un_220 rw.so.un_540
  0x091e21ee, 0x2a001a02, 0x07002108, 0x52355513,   // jw.ms.pl_422 tl.mt.un_220  jw.it.un_430 rw.zu.ha_665
  // [1be0]
  0x0f2935af, 0x11552507, 0x552511a7, 0x041b31ee,   // zu.sl.lv_655 eu.rw.ro_432  ro.eu.rw_532 az.tr.fi_422
  0x13091cad, 0x0c2a06a4, 0x030f06a0, 0x23640904,   // mr.hi.bh_643 de.mt.sv_433  de.lv.nl_322 pl.lg.ca_332
  0x53006b04, 0x1a006b02, 0x3b002707, 0x0c000a05,   // ceb.ht.un_320 ceb.tl.un_220  gd.so.un_420 pt.sv.un_330
  0x4a295207, 0x10251111, 0x292d0d0d, 0x07020c08,   // ha.sl.yo_432 ro.eu.lt_653  cs.sk.sl_554 sv.da.it_443
  // [1bf0]
  0x21110807, 0x04101104, 0x050429a0, 0x3f0510ee,   // no.ro.jw_432 ro.be.ru_332  sl.fi.fr_322 lt.fr.af_422
  0x3b6413a4, 0x043b1a08, 0x6b281e07, 0x55000704,   // et.lg.so_433 tl.so.fi_443  ms.sw.ceb_432 it.rw.un_320
  0x2100100b, 0x19005204, 0x033f20ac, 0x286b1a04,   // lt.jw.un_520 ha.gl.un_320  sq.af.nl_632 tl.ceb.sw_332
  0x13080204, 0x19003b0e, 0x121f050d, 0x276b1a60,   // da.no.et_332 so.gl.un_550  fr.cy.hu_554 tl.ceb.gd_664

  // [1c00]
  0x25001907, 0x08171155, 0x05002007, 0x290a0f04,   // gl.eu.un_420 ro.sr.uk_442  sq.fr.un_420 lv.pt.sl_332
  0x19052104, 0x120a05a0, 0x64003522, 0x0200230e,   // jw.fr.gl_332 fr.pt.hu_322  zu.lg.un_870 ca.da.un_550
  0x13090dad, 0x21126ba4, 0x170a1007, 0x11001807,   // ne.hi.bh_643 ceb.hu.jw_433  be.mk.sr_432 ga.ro.un_420
  0x2100180e, 0x1e313bad, 0x53100fa0, 0x033f3b04,   // ar.fa.un_550 so.az.ms_643  lv.lt.ht_322 so.af.nl_332
  // [1c10]
  0x192025a0, 0x3b133f07, 0x080c0e0c, 0x091c1308,   // eu.sq.gl_322 af.et.so_432  is.sv.no_543 bh.mr.hi_443
  0x3b313502, 0x0a004a04, 0x09002102, 0x21000308,   // zu.az.so_222 yo.pt.un_320  jw.pl.un_220 nl.jw.un_430
  0x08100aec, 0x041107a4, 0x041707a0, 0x1b00180e,   // mk.be.uk_644 bg.ro.ru_433  bg.sr.ru_322 ga.tr.un_550
  0x1a0155a0, 0x09191004, 0x64001804, 0x2d0a1205,   // rw.en.tl_322 lt.gl.pl_332  ga.lg.un_320 hu.pt.sk_333
  // [1c20]
  0x2a1e2707, 0x10170a07, 0x1a070404, 0x0b041007,   // gd.ms.mt_432 mk.sr.be_432  fi.it.tl_332 lt.fi.es_432
  0x20000507, 0x31003514, 0x0a231fee, 0x040811a7,   // fr.sq.un_420 zu.az.un_660  cy.ca.pt_422 ro.uk.ru_532
  0x04170a11, 0x18271f07, 0x010a1eee, 0x350c6ea7,   // mk.sr.ru_653 cy.gd.ga_432  ms.pt.en_422 hmn.sv.zu_532
  0x0c13230c, 0x53000505, 0x08000407, 0x32162aa4,   // ca.et.sv_543 fr.ht.un_330  ru.uk.un_420 mt.hr.bs_433
  // [1c30]
  0x171610a4, 0x0a110807, 0x0d32160d, 0x08002707,   // lt.hr.sr_433 no.ro.pt_432  hr.bs.cs_554 gd.no.un_420
  0x04070855, 0x25001212, 0x535564a0, 0x18002007,   // uk.bg.ru_442 hu.eu.un_640  lg.rw.ht_322 sq.ga.un_420
  0x552035ac, 0x17002508, 0x2d00250c, 0x3f031307,   // zu.sq.rw_632 eu.sr.un_430  eu.sk.un_530 et.nl.af_432
  0x2d0d640c, 0x3f270407, 0x07100455, 0x295535ec,   // lg.cs.sk_543 fi.gd.af_432  ru.be.bg_442 zu.rw.sl_644
  // [1c40]
  0x3b002705, 0x10002704, 0x52002007, 0x18000702,   // gd.so.un_330 gd.lt.un_320  sq.ha.un_420 it.ga.un_220
  0x12006404, 0x25101fec, 0x280a070c, 0x0e0c0855,   // lg.hu.un_320 cy.lt.eu_644  it.pt.sw_543 no.sv.is_442
  0x2d041205, 0x53283fa0, 0x6b006407, 0x042d0d08,   // hu.fi.sk_333 af.sw.ht_322  lg.ceb.un_420 cs.sk.fi_443
  0x230504ee, 0x12001c02, 0x08002702, 0x12311b0b,   // fi.fr.ca_422 id.hu.un_220  gd.no.un_220 tr.az.hu_542
  // [1c50]
  0x55352812, 0x1218270c, 0x19002508, 0x0a0408ee,   // sw.zu.rw_654 gd.ga.hu_543  eu.gl.un_430 uk.ru.mk_422
  0x1a553507, 0x1b2353a0, 0x17190a04, 0x07041012,   // zu.rw.tl_432 ht.ca.tr_322  pt.gl.sr_332 be.ru.bg_654
  0x122d0e5a, 0x0d005308, 0x27000812, 0x6b1a1c07,   // is.sk.hu_553 ht.cs.un_430  no.gd.un_640 id.tl.ceb_432
  0x311f1b07, 0x1e1f1012, 0x102701a0, 0x16120407,   // tr.cy.az_432 lt.cy.ms_654  en.gd.lt_322 fi.hu.hr_432
  // [1c60]
  0x35002308, 0x1f002702, 0x08250c02, 0x25002809,   // ca.zu.un_430 gd.cy.un_220  sv.eu.no_222 sw.eu.un_440
  0x080711ad, 0x29160da0, 0x1a5564a0, 0x052d0d05,   // ro.bg.uk_643 cs.hr.sl_322  lg.rw.tl_322 cs.sk.fr_333
  0x55001c02, 0x23002902, 0x1c002304, 0x10001f13,   // id.rw.un_220 sl.ca.un_220  ca.id.un_320 cy.lt.un_650
  0x2d0d2909, 0x12002907, 0x06350107, 0x1e1c520c,   // sl.cs.sk_444 sl.hu.un_420  en.zu.de_432 ha.id.ms_543
  // [1c70]
  0x080c05a0, 0x080a0704, 0x536e01a0, 0x1a3f0907,   // fr.sv.no_322 bg.mk.uk_332  en.hmn.ht_322 pl.af.tl_432
  0x290f1012, 0x131f01ad, 0x0300060e, 0x090410a4,   // lt.lv.sl_654 en.cy.et_643  de.nl.un_550 lt.fi.pl_433
  0x120413a7, 0x0d09130b, 0x0c080ea9, 0x25001e02,   // et.fi.hu_532 bh.hi.ne_542  is.no.sv_544 ms.eu.un_220
  0x29000108, 0x183f01a7, 0x1a350807, 0x052112a4,   // en.sl.un_430 en.af.ga_532  no.zu.tl_432 hu.jw.fr_433
  // [1c80]
  0x01003b09, 0x03000813, 0x531e1c04, 0x080711ee,   // so.en.un_440 no.nl.un_650  id.ms.ht_332 ro.bg.uk_422
  0x08022305, 0x35003f05, 0x171b2902, 0x64041311,   // ca.da.no_333 af.zu.un_330  sl.tr.sr_222 et.fi.lg_653
  0x311b120c, 0x0c00350b, 0x07006409, 0x2a556404,   // hu.tr.az_543 zu.sv.un_520  lg.it.un_440 lg.rw.mt_332
  0x210555a0, 0x162d0dee, 0x53000414, 0x0f3f5509,   // rw.fr.jw_322 cs.sk.hr_422  fi.ht.un_660 rw.af.lv_444
  // [1c90]
  0x53050d0c, 0x1b081004, 0x1e1c20a9, 0x25000705,   // cs.fr.ht_543 lt.no.tr_332  sq.id.ms_544 it.eu.un_330
  0x01352da0, 0x31283b02, 0x3f000413, 0x02071fee,   // sk.zu.en_322 so.sw.az_222  fi.af.un_650 cy.it.da_422
  0x0a1004a4, 0x110f0107, 0x07001a04, 0x13000504,   // ru.be.mk_433 en.lv.ro_432  tl.it.un_320 fr.et.un_320
  0x040e0107, 0x2d0d0407, 0x1000280c, 0x0d130907,   // en.is.fi_432 fi.cs.sk_432  sw.lt.un_530 hi.bh.ne_432
  // [1ca0]
  0x28006402, 0x1a6b01a0, 0x04100aa9, 0x52103b04,   // lg.sw.un_220 en.ceb.tl_322  mk.be.ru_544 so.lt.ha_332
  0x19002813, 0x29321605, 0x0f103ba0, 0x64006807,   // sw.gl.un_650 hr.bs.sl_333  so.lt.lv_322 ig.lg.un_420
  0x04111007, 0x28001305, 0x111827a4, 0x35006b19,   // be.ro.ru_432 et.sw.un_330  gd.ga.ro_433 ceb.zu.un_750
  0x0c2128ee, 0x182827a7, 0x1f645212, 0x1f212509,   // sw.jw.sv_422 gd.sw.ga_532  ha.lg.cy_654 eu.jw.cy_444
  // [1cb0]
  0x20291304, 0x2713180c, 0x28000d08, 0x12320d07,   // et.sl.sq_332 ga.et.gd_543  cs.sw.un_430 cs.bs.hu_432
  0x04276404, 0x6b280907, 0x1000110b, 0x0e001308,   // lg.gd.fi_332 pl.sw.ceb_432  ro.be.un_520 et.is.un_430
  0x27113f02, 0x3200290c, 0x08001f07, 0x08033f0c,   // af.ro.gd_222 sl.bs.un_530  cy.no.un_420 af.nl.no_543
  0x521e11a0, 0x2a00280c, 0x01002702, 0x2700230c,   // ro.ms.ha_322 sw.mt.un_530  gd.en.un_220 ca.gd.un_530
  // [1cc0]
  0x3b030407, 0x19003b04, 0x2a2507af, 0x04003b0d,   // fi.nl.so_432 so.gl.un_320  it.eu.mt_655 so.fi.un_540
  0x1b1310a0, 0x04170808, 0x0e001304, 0x062701ad,   // lt.et.tr_322 uk.sr.ru_443  et.is.un_320 en.gd.de_643
  0x0e040fa0, 0x0c070ea7, 0x1700070c, 0x3b000404,   // lv.fi.is_322 is.it.sv_532  bg.sr.un_530 fi.so.un_320
  0x062112a0, 0x180205a0, 0x250a100b, 0x033b3fa9,   // hu.jw.de_322 fr.da.ga_322  lt.pt.eu_542 af.so.nl_544
  // [1cd0]
  0x10000607, 0x0411170d, 0x040c065a, 0x3f0802ee,   // de.lt.un_420 sr.ro.ru_554  de.sv.fi_553 da.no.af_422
  0x2b6801ee, 0x086e35ad, 0x2d0d1302, 0x292d1702,   // en.ig.vi_422 zu.hmn.no_643  et.cs.sk_222 sr.sk.sl_222
  0x181f10ad, 0x0b0a0702, 0x01002418, 0x10004a04,   // lt.cy.ga_643 it.pt.es_222  yi.iw.un_740 yo.lt.un_320
  0x311b110c, 0x0f10050b, 0x352d0d55, 0x101b13ee,   // ro.tr.az_543 fr.lt.lv_542  cs.sk.zu_442 et.tr.lt_422
  // [1ce0]
  0x3f023b02, 0x050110ee, 0x071911a0, 0x53253504,   // so.da.af_222 lt.en.fr_422  ro.gl.it_322 zu.eu.ht_332
  0x0d003b04, 0x28003b07, 0x0c3b35a7, 0x321729a4,   // so.cs.un_320 so.sw.un_420  zu.so.sv_532 sl.sr.bs_433
  0x12211008, 0x0e2910ee, 0x17000205, 0x252112ee,   // lt.jw.hu_443 lt.sl.is_422  da.sr.un_330 hu.jw.eu_422
  0x132902ee, 0x0c1304a4, 0x3f03130e, 0x020c0804,   // da.sl.et_422 fi.et.sv_433  et.nl.af_555 no.sv.da_332
  // [1cf0]
  0x052d1212, 0x03002d0e, 0x1e1c1ba0, 0x062b270b,   // hu.sk.fr_654 sk.nl.un_550  tr.id.ms_322 gd.vi.de_542
  0x12000804, 0x08001021, 0x03110fee, 0x13000305,   // no.hu.un_320 be.uk.un_860  lv.ro.nl_422 nl.et.un_330
  0x17080408, 0x013f3b07, 0x1c090d09, 0x191101a4,   // ru.uk.sr_443 so.af.en_432  ne.hi.mr_444 en.ro.gl_433
  0x64000412, 0x0f001804, 0x0800010d, 0x18190b02,   // fi.lg.un_640 ga.lv.un_320  en.no.un_540 es.gl.ga_222
  // [1d00]
  0x043f13a0, 0x08090d07, 0x090d1ca0, 0x17110a04,   // et.af.fi_322 cs.pl.no_432  mr.ne.hi_322 mk.ro.sr_332
  0x04110711, 0x21000508, 0x071117af, 0x121f1ba0,   // bg.ro.ru_653 fr.jw.un_430  sr.ro.bg_655 tr.cy.hu_322
  0x522a0607, 0x061b08af, 0x27002d13, 0x190b2305,   // de.mt.ha_432 no.tr.de_655  sk.gd.un_650 ca.es.gl_333
  0x2d0d29ee, 0x3f321708, 0x25002107, 0x28005207,   // sl.cs.sk_422 sr.bs.af_443  jw.eu.un_420 ha.sw.un_420
  // [1d10]
  0x04170704, 0x080213a0, 0x081b01a0, 0x28171605,   // bg.sr.ru_332 et.da.no_322  en.tr.no_322 hr.sr.sw_333
  0x04643b0b, 0x64001704, 0x0e5308a0, 0x1e1c0ca0,   // so.lg.fi_542 sr.lg.un_320  no.ht.is_322 sv.id.ms_322
  0x21002308, 0x0c03040c, 0x1700100d, 0x68526407,   // ca.jw.un_430 fi.nl.sv_543  be.sr.un_540 lg.ha.ig_432
  0x2b001308, 0x0f130e12, 0x25000808, 0x02003512,   // et.vi.un_430 is.et.lv_654  no.eu.un_430 zu.da.un_640
  // [1d20]
  0x0a0811ee, 0x1b000807, 0x0b072d5a, 0x19310aee,   // ro.uk.mk_422 no.tr.un_420  sk.it.es_553 pt.az.gl_422
  0x3f000507, 0x3f200309, 0x01000302, 0x272135ee,   // fr.af.un_420 nl.sq.af_444  nl.en.un_220 zu.jw.gd_422
  0x18270111, 0x11552804, 0x04110805, 0x02001209,   // en.gd.ga_653 sw.rw.ro_332  uk.ro.ru_333 hu.da.un_440
  0x01060307, 0x123f01a4, 0x29001e02, 0x121a28a0,   // nl.de.en_432 en.af.hu_433  ms.sl.un_220 sw.tl.hu_322
  // [1d30]
  0x190a230c, 0x6b006e12, 0x250929ee, 0x201f0304,   // ca.pt.gl_543 hmn.ceb.un_640  sl.pl.eu_422 nl.cy.sq_332
  0x28351307, 0x53000e0b, 0x0d6428a6, 0x524a2107,   // et.zu.sw_432 is.ht.un_520  sw.lg.cs_521 jw.yo.ha_432
  0x55216408, 0x0a041104, 0x2700100d, 0x350e2814,   // lg.jw.rw_443 ro.ru.mk_332  lt.gd.un_540 sw.is.zu_666
  0x351e1c02, 0x1a280705, 0x13271808, 0x17200107,   // id.ms.zu_222 it.sw.tl_333  ga.gd.et_443 en.sq.sr_432
  // [1d40]
  0x55256407, 0x170c5302, 0x32001104, 0x27100f05,   // lg.eu.rw_432 ht.sv.sr_222  ro.bs.un_320 lv.lt.gd_333
  0x29312d04, 0x10133fec, 0x556b2104, 0x6b003f0d,   // sk.az.sl_332 af.et.lt_644  jw.ceb.rw_332 af.ceb.un_540
  0x190b2dee, 0x0a006e07, 0x2d0d0a09, 0x53231f55,   // sk.es.gl_422 hmn.pt.un_420  pt.cs.sk_444 cy.ca.ht_442
  0x020e3104, 0x2b002804, 0x32170da0, 0x013f020c,   // az.is.da_332 sw.vi.un_320  cs.sr.bs_322 da.af.en_543
  // [1d50]
  0x063f03a7, 0x1900180b, 0x03213fa0, 0x21000118,   // nl.af.de_532 ga.gl.un_520  af.jw.nl_322 en.jw.un_740
  0x3f030108, 0x130806a6, 0x29001607, 0x05092d0c,   // en.nl.af_443 de.no.et_521  hr.sl.un_420 sk.pl.fr_543
  0x07001f04, 0x27090107, 0x11182dee, 0x19004a04,   // cy.it.un_320 en.pl.gd_432  sk.ga.ro_422 yo.gl.un_320
  0x23190a04, 0x18000a02, 0x08000405, 0x2a1208a0,   // pt.gl.ca_332 pt.ga.un_220  ru.uk.un_330 no.hu.mt_322
  // [1d60]
  0x00000d06, 0x4a1a5505, 0x13000604, 0x322135ee,   // cs.un.un_400 rw.tl.yo_333  de.et.un_320 zu.jw.bs_422
  0x12002704, 0x080306ee, 0x03010207, 0x190a18ac,   // gd.hu.un_320 de.nl.no_422  da.en.nl_432 ga.pt.gl_632
  0x11170aec, 0x68645508, 0x0800030c, 0x2d0d050e,   // mk.sr.ro_644 rw.lg.ig_443  nl.no.un_530 fr.cs.sk_555
  0x28640407, 0x25060aa4, 0x17003504, 0x08180604,   // fi.lg.sw_432 pt.de.eu_433  zu.sr.un_320 de.ga.no_332
  // [1d70]
  0x13000d12, 0x08001a0d, 0x64002804, 0x35000209,   // ne.bh.un_640 tl.no.un_540  sw.lg.un_320 da.zu.un_440
  0x131235a7, 0x3b285507, 0x023106a0, 0x12000613,   // zu.hu.et_532 rw.sw.so_432  de.az.da_322 de.hu.un_650
  0x04080c02, 0x29161309, 0x06120ea7, 0x100d2812,   // sv.no.fi_222 et.hr.sl_444  is.hu.de_532 sw.cs.lt_654
  0x0a1710a0, 0x18000709, 0x01000b02, 0x64130455,   // be.sr.mk_322 it.ga.un_440  es.en.un_220 fi.et.lg_442
  // [1d80]
  0x05000113, 0x16005504, 0x27001314, 0x12040a0c,   // en.fr.un_650 rw.hr.un_320  et.gd.un_660 pt.fi.hu_543
  0x0c1308a7, 0x0300020c, 0x6b100f07, 0x00001e0f,   // no.et.sv_532 da.nl.un_530  lv.lt.ceb_432 ms.un.un_600
  0x3b1013a0, 0x05001213, 0x1a006419, 0x0600020c,   // et.lt.so_322 hu.fr.un_650  lg.tl.un_750 da.de.un_530
  0x16000404, 0x55000611, 0x06000f0c, 0x171104ee,   // fi.hr.un_320 de.rw.un_630  lv.de.un_530 fi.ro.sr_422
  // [1d90]
  0x12000504, 0x040a1707, 0x0e000604, 0x0a071713,   // fr.hu.un_320 sr.mk.ru_432  de.is.un_320 sr.bg.mk_665
  0x250b19ee, 0x0f000411, 0x35005509, 0x080217a0,   // gl.es.eu_422 fi.lv.un_630  rw.zu.un_440 sr.da.no_322
  0x11002302, 0x04000609, 0x20001704, 0x0a005207,   // ca.ro.un_220 de.fi.un_440  sr.sq.un_320 ha.pt.un_420
  0x11051b11, 0x18000e0d, 0x1f002304, 0x0f0e0611,   // tr.fr.ro_653 is.ga.un_540  ca.cy.un_320 de.is.lv_653
  // [1da0]
  0x4a530512, 0x3b003202, 0x102825ad, 0x21061aa0,   // fr.ht.yo_654 bs.so.un_220  eu.sw.lt_643 tl.de.jw_322
  0x313b1807, 0x100704ec, 0x17000304, 0x0f002d0d,   // ga.so.az_432 ru.bg.be_644  nl.sr.un_320 sk.lv.un_540
  0x0a081107, 0x0c00060e, 0x17071002, 0x080a17a7,   // ro.uk.mk_432 de.sv.un_550  be.bg.sr_222 sr.mk.uk_532
  0x0407080e, 0x1f1302a0, 0x6b0b0104, 0x1b001002,   // uk.bg.ru_555 da.et.cy_322  en.es.ceb_332 lt.tr.un_220
  // [1db0]
  0x172d2904, 0x0e000309, 0x012718a0, 0x110523ad,   // sl.sk.sr_332 nl.is.un_440  ga.gd.en_322 ca.fr.ro_643
  0x292a0713, 0x6b355508, 0x3b002a12, 0x1b292d02,   // it.mt.sl_665 rw.zu.ceb_443  mt.so.un_640 sk.sl.tr_222
  0x102852a7, 0x192305a4, 0x3b1864a0, 0x686b3b55,   // ha.sw.lt_532 fr.ca.gl_433  lg.ga.so_322 so.ceb.ig_442
  0x20030807, 0x03321605, 0x011f3fa0, 0x0d092da0,   // no.nl.sq_432 hr.bs.nl_333  af.cy.en_322 sk.pl.cs_322
  // [1dc0]
  0x3b550107, 0x1b3b53a7, 0x533b2a04, 0x17290d07,   // en.rw.so_432 ht.so.tr_532  mt.so.ht_332 cs.sl.sr_432
  0x3b00351a, 0x041710a0, 0x35006423, 0x2d002808,   // zu.so.un_760 be.sr.ru_322  lg.zu.un_880 sw.sk.un_430
  0x1f000919, 0x550e3504, 0x2a281807, 0x3500551a,   // pl.cy.un_750 zu.is.rw_332  ga.sw.mt_432 rw.zu.un_760
  0x060e1304, 0x070c0407, 0x35000e05, 0x3b006b13,   // et.is.de_332 fi.sv.it_432  is.zu.un_330 ceb.so.un_650
  // [1dd0]
  0x290f1707, 0x1b310612, 0x21006412, 0x2d080208,   // sr.lv.sl_432 de.az.tr_654  lg.jw.un_640 da.no.sk_443
  0x3b0f2aa4, 0x2d000912, 0x17000d04, 0x04002107,   // mt.lv.so_433 pl.sk.un_640  cs.sr.un_320 jw.fi.un_420
  0x281f20ee, 0x535564ad, 0x02000302, 0x10000112,   // sq.cy.sw_422 lg.rw.ht_643  nl.da.un_220 en.lt.un_640
  0x6e6b13ec, 0x2a6b280c, 0x524a6b04, 0x08020dee,   // et.ceb.hmn_644 sw.ceb.mt_543  ceb.yo.ha_332 cs.da.no_422
  // [1de0]
  0x0f121ba7, 0x25190b05, 0x31061b0e, 0x200e0407,   // tr.hu.lv_532 es.gl.eu_333  tr.de.az_555 fi.is.sq_432
  0x686435ec, 0x09100207, 0x160d29a0, 0x55003521,   // zu.lg.ig_644 da.lt.pl_432  sl.cs.hr_322 zu.rw.un_860
  0x23641107, 0x026b05a0, 0x21006b13, 0x31002118,   // ro.lg.ca_432 fr.ceb.da_322  ceb.jw.un_650 jw.az.un_740
  0x32001004, 0x281c1eee, 0x16352807, 0x0a190b55,   // lt.bs.un_320 ms.id.sw_422  sw.zu.hr_432 es.gl.pt_442
  // [1df0]
  0x07100808, 0x6b252aad, 0x070a17ac, 0x0e6435ad,   // uk.be.bg_443 mt.eu.ceb_643  sr.mk.bg_632 zu.lg.is_643
  0x21202507, 0x2932520c, 0x1704080e, 0x0f2d3f13,   // eu.sq.jw_432 ha.bs.sl_543  uk.ru.sr_555 af.sk.lv_665
  0x07041004, 0x192105a4, 0x0a080708, 0x1800050e,   // be.ru.bg_332 fr.jw.gl_433  bg.uk.mk_443 fr.ga.un_550
  0x09000607, 0x1300011a, 0x0309060b, 0x070a11ec,   // de.pl.un_420 en.et.un_760  de.pl.nl_542 ro.mk.bg_644
  // [1e00]
  0x2a00060c, 0x1b001104, 0x0b002a04, 0x11530855,   // de.mt.un_530 ro.tr.un_320  mt.es.un_320 no.ht.ro_442
  0x52351a0c, 0x68001f12, 0x103f0807, 0x182768a0,   // tl.zu.ha_543 cy.ig.un_640  no.af.lt_432 ig.gd.ga_322
  0x1a2152a0, 0x1c002a0d, 0x01130ea7, 0x060e0ca0,   // ha.jw.tl_322 mt.id.un_540  is.et.en_532 sv.is.de_322
  0x2b1801ee, 0x08020e05, 0x063f1fee, 0x020c08ec,   // en.ga.vi_422 is.da.no_333  cy.af.de_422 no.sv.da_644
  // [1e10]
  0x0e000812, 0x23000b04, 0x2b0501ee, 0x0600040c,   // no.is.un_640 es.ca.un_320  en.fr.vi_422 fi.de.un_530
  0x023f270c, 0x6400040d, 0x3f03060e, 0x1200090d,   // gd.af.da_543 fi.lg.un_540  de.nl.af_555 pl.hu.un_540
  0x1e1c5505, 0x291304ec, 0x063f135a, 0x3b006b18,   // rw.id.ms_333 fi.et.sl_644  et.af.de_553 ceb.so.un_740
  0x5328090c, 0x04003b07, 0x552835ec, 0x3f00011a,   // pl.sw.ht_543 so.fi.un_420  zu.sw.rw_644 en.af.un_760
  // [1e20]
  0x12000302, 0x1c1e2112, 0x1632295a, 0x04000202,   // nl.hu.un_220 jw.ms.id_654  sl.bs.hr_553 da.fi.un_220
  0x041c1eee, 0x55641105, 0x53556ba4, 0x05005505,   // ms.id.fi_422 ro.lg.rw_333  ceb.rw.ht_433 rw.fr.un_330
  0x2d0d11ee, 0x1f6b10ac, 0x3f000104, 0x13100408,   // ro.cs.sk_422 lt.ceb.cy_632  en.af.un_320 fi.lt.et_443
  0x0c000104, 0x4a003512, 0x03000104, 0x35000a07,   // en.sv.un_320 zu.yo.un_640  en.nl.un_320 pt.zu.un_420
  // [1e30]
  0x250d0f55, 0x53060309, 0x285535a0, 0x55283b04,   // lv.cs.eu_442 nl.de.ht_444  zu.rw.sw_322 so.sw.rw_332
  0x0f100c0b, 0x282a5202, 0x21131007, 0x23001314,   // sv.lt.lv_542 ha.mt.sw_222  lt.et.jw_432 et.ca.un_660
  0x0e640c07, 0x13000122, 0x016435ad, 0x1a001305,   // sv.lg.is_432 en.et.un_870  zu.lg.en_643 et.tl.un_330
  0x3b0955ee, 0x3b1a1ba0, 0x13003b0e, 0x5568640d,   // rw.pl.so_422 tr.tl.so_322  so.et.un_550 lg.ig.rw_554
  // [1e40]
  0x0c002304, 0x10002909, 0x64002821, 0x3f08025a,   // ca.sv.un_320 sl.lt.un_440  sw.lg.un_860 da.no.af_553
  0x122128a4, 0x0d1305a9, 0x19004a11, 0x28536412,   // sw.jw.hu_433 fr.et.cs_544  yo.gl.un_630 lg.ht.sw_654
  0x120208a4, 0x0809040c, 0x10033f04, 0x6b000705,   // no.da.hu_433 fi.pl.no_543  af.nl.lt_332 it.ceb.un_330
  0x23250107, 0x10001121, 0x2b1a6bee, 0x1a002807,   // en.eu.ca_432 ro.be.un_860  ceb.tl.vi_422 sw.tl.un_420
  // [1e50]
  0x1c64550c, 0x3b006402, 0x3f3b0308, 0x0e3f03a7,   // rw.lg.id_543 lg.so.un_220  nl.so.af_443 nl.af.is_532
  0x1b00210c, 0x0a23350c, 0x3b1b3112, 0x1a556404,   // jw.tr.un_530 zu.ca.pt_543  az.tr.so_654 lg.rw.tl_332
  0x09353f0c, 0x09001f02, 0x3b280155, 0x52005504,   // af.zu.pl_543 cy.pl.un_220  en.sw.so_442 rw.ha.un_320
  0x5564350b, 0x17000821, 0x32080f07, 0x0425110c,   // zu.lg.rw_542 uk.sr.un_860  lv.no.bs_432 ro.eu.fi_543
  // [1e60]
  0x170d1607, 0x312d0d0c, 0x130e0f12, 0x4a003b13,   // hr.cs.sr_432 cs.sk.az_543  lv.is.et_654 so.yo.un_650
  0x12552811, 0x12060f09, 0x05001807, 0x0a003504,   // sw.rw.hu_653 lv.de.hu_444  ga.fr.un_420 zu.pt.un_320
  0x1c121aa6, 0x1e00110c, 0x0b2908a0, 0x25005512,   // tl.hu.id_521 ro.ms.un_530  no.sl.es_322 rw.eu.un_640
  0x3f0a0507, 0x05530d12, 0x1a00550e, 0x18000e13,   // fr.pt.af_432 cs.ht.fr_654  rw.tl.un_550 is.ga.un_650
  // [1e70]
  0x18000704, 0x05003502, 0x121a6ba9, 0x11005519,   // it.ga.un_320 zu.fr.un_220  ceb.tl.hu_544 rw.ro.un_750
  0x35645313, 0x0f28130d, 0x254a2a08, 0x080c020d,   // ht.lg.zu_665 et.sw.lv_554  mt.yo.eu_443 da.sv.no_554
  0x1e001c14, 0x0a08070b, 0x13000c08, 0x020804ad,   // id.ms.un_660 bg.uk.mk_542  sv.et.un_430 fi.no.da_643
  0x053f23a4, 0x1c130913, 0x200a0702, 0x071b110c,   // ca.af.fr_433 hi.bh.mr_665  it.pt.sq_222 ro.tr.it_543
  // [1e80]
  0x643507a0, 0x0c3564ee, 0x551e1c04, 0x092d0d0c,   // it.zu.lg_322 lg.zu.sv_422  id.ms.rw_332 cs.sk.pl_543
  0x10002304, 0x1c090d55, 0x0c0701a4, 0x28645512,   // ca.lt.un_320 ne.hi.mr_442  en.it.sv_433 rw.lg.sw_654
  0x52002813, 0x071a28a7, 0x1300250e, 0x01531f07,   // sw.ha.un_650 sw.tl.it_532  eu.et.un_550 cy.ht.en_432
  0x55002104, 0x05001b12, 0x130806a0, 0x2b002d08,   // jw.rw.un_320 tr.fr.un_640  de.no.et_322 sk.vi.un_430
  // [1e90]
  0x13002305, 0x09001705, 0x5500530e, 0x4a686b07,   // ca.et.un_330 sr.pl.un_330  ht.rw.un_550 ceb.ig.yo_432
  0x0c023b07, 0x060e0807, 0x0e6b1a07, 0x03022d07,   // so.da.sv_432 no.is.de_432  tl.ceb.is_432 sk.da.nl_432
  0x01000e04, 0x133b0607, 0x0c2a3b0d, 0x04170aa0,   // is.en.un_320 de.so.et_432  so.mt.sv_554 mk.sr.ru_322
  0x200725a0, 0x1b000c0d, 0x53556404, 0x17000a2b,   // eu.it.sq_322 sv.tr.un_540  lg.rw.ht_332 mk.sr.un_980
  // [1ea0]
  0x061e1c08, 0x053f0307, 0x05002308, 0x133127ee,   // id.ms.de_443 nl.af.fr_432  ca.fr.un_430 gd.az.et_422
  0x131008a0, 0x13522807, 0x310e0807, 0x0a0710a4,   // no.lt.et_322 sw.ha.et_432  no.is.az_432 be.bg.mk_433
  0x06000504, 0x033f0507, 0x55131aa0, 0x11000a0c,   // fr.de.un_320 fr.af.nl_432  tl.et.rw_322 pt.ro.un_530
  0x0a0417ec, 0x211f1c05, 0x19120aa6, 0x13090d5a,   // sr.ru.mk_644 id.cy.jw_333  pt.hu.gl_521 ne.hi.bh_553
  // [1eb0]
  0x531b28af, 0x12001e0d, 0x050f0911, 0x192305a9,   // sw.tr.ht_655 ms.hu.un_540  pl.lv.fr_653 fr.ca.gl_544
  0x02321704, 0x211e1c04, 0x016b18a0, 0x2b1101a4,   // sr.bs.da_332 id.ms.jw_332  ga.ceb.en_322 en.ro.vi_433
  0x11120a02, 0x081110a4, 0x1c211e0c, 0x2b001f19,   // pt.hu.ro_222 be.ro.uk_433  ms.jw.id_543 cy.vi.un_750
  0x2a00200e, 0x1f0e07a0, 0x0f1720a0, 0x03000408,   // sq.mt.un_550 it.is.cy_322  sq.sr.lv_322 fi.nl.un_430
  // [1ec0]
  0x2a003b0d, 0x046e0604, 0x20001a02, 0x0604100c,   // so.mt.un_540 de.hmn.fi_332  tl.sq.un_220 lt.fi.de_543
  0x211b11ad, 0x17003208, 0x11231fa4, 0x170708a0,   // ro.tr.jw_643 bs.sr.un_430  cy.ca.ro_433 uk.bg.sr_322
  0x64005511, 0x040c0607, 0x0c6b1f04, 0x28002507,   // rw.lg.un_630 de.sv.fi_432  cy.ceb.sv_332 eu.sw.un_420
  0x1f192302, 0x0e202b05, 0x0c0e0807, 0x20002102,   // ca.gl.cy_222 vi.sq.is_333  no.is.sv_432 jw.sq.un_220
  // [1ed0]
  0x00006803, 0x2d000302, 0x081f3f04, 0x12002309,   // ig.un.un_300 nl.sk.un_220  af.cy.no_332 ca.hu.un_440
  0x0e085202, 0x2300011a, 0x071008a4, 0x232701ad,   // ha.no.is_222 en.ca.un_760  uk.be.bg_433 en.gd.ca_643
  0x1f233f07, 0x092d3b12, 0x023f0309, 0x23030108,   // af.ca.cy_432 so.sk.pl_654  nl.af.da_444 en.nl.ca_443
  0x19000c04, 0x0f25060e, 0x1a210908, 0x170a11a9,   // sv.gl.un_320 de.eu.lv_555  pl.jw.tl_443 ro.mk.sr_544
  // [1ee0]
  0x05000613, 0x110a1713, 0x35003f12, 0x0c3f2302,   // de.fr.un_650 sr.mk.ro_665  af.zu.un_640 ca.af.sv_222
  0x100c0ead, 0x0e250d0c, 0x2855350d, 0x25073fa4,   // is.sv.lt_643 cs.eu.is_543  zu.rw.sw_554 af.it.eu_433
  0x13000508, 0x041708a4, 0x28251f02, 0x1e1c08a0,   // fr.et.un_430 uk.sr.ru_433  cy.eu.sw_222 no.id.ms_322
  0x2d060f55, 0x0e000c02, 0x0c003f12, 0x211e1cad,   // lv.de.sk_442 sv.is.un_220  af.sv.un_640 id.ms.jw_643
  // [1ef0]
  0x08020ea0, 0x1c1309a4, 0x29003f08, 0x11013fa0,   // is.da.no_322 hi.bh.mr_433  af.sl.un_430 af.en.ro_322
  0x110701a4, 0x080210a4, 0x1b002102, 0x1c2105a9,   // en.it.ro_433 lt.da.no_433  jw.tr.un_220 fr.jw.id_544
  0x35250609, 0x5368520c, 0x17080405, 0x290d2d12,   // de.eu.zu_444 ha.ig.ht_543  ru.uk.sr_333 sk.cs.sl_654
  0x3f2855a0, 0x1200250d, 0x10001109, 0x0d000a02,   // rw.sw.af_322 eu.hu.un_540  ro.lt.un_440 pt.cs.un_220
  // [1f00]
  0x08120607, 0x210b05ee, 0x3b2052ee, 0x1a1c2107,   // de.hu.no_432 fr.es.jw_422  ha.sq.so_422 jw.id.tl_432
  0x13002104, 0x20000f12, 0x01000a04, 0x04100704,   // jw.et.un_320 lv.sq.un_640  pt.en.un_320 bg.be.ru_332
  0x2d0d1f07, 0x2a005202, 0x16173207, 0x060501a4,   // cy.cs.sk_432 ha.mt.un_220  bs.sr.hr_432 en.fr.de_433
  0x07001719, 0x0b0a01ec, 0x08006808, 0x4a00681b,   // sr.bg.un_750 en.pt.es_644  ig.no.un_430 ig.yo.un_770
  // [1f10]
  0x03182707, 0x06005508, 0x6e180405, 0x10003f07,   // gd.ga.nl_432 rw.de.un_430  fi.ga.hmn_333 af.lt.un_420
  0x0c6b64a0, 0x190b01a9, 0x1011080c, 0x1f000704,   // lg.ceb.sv_322 en.es.gl_544  no.ro.lt_543 it.cy.un_320
  0x00004a24, 0x1c2b01a7, 0x6b000802, 0x04130e07,   // yo.un.un_900 en.vi.id_532  no.ceb.un_220 is.et.fi_432
  0x08002a12, 0x100e1ca0, 0x64051fee, 0x060802a7,   // mt.no.un_640 id.is.lt_322  cy.fr.lg_422 da.no.de_532
  // [1f20]
  0x18000c04, 0x3b0519a0, 0x010c20a7, 0x1c002a02,   // sv.ga.un_320 gl.fr.so_322  sq.sv.en_532 mt.id.un_220
  0x120e0c0c, 0x3f021fa9, 0x03000e04, 0x0c1a6b07,   // sv.is.hu_543 cy.da.af_544  is.nl.un_320 ceb.tl.sv_432
  0x1c003b12, 0x0e033f0c, 0x131b3107, 0x3f002005,   // so.id.un_640 af.nl.is_543  az.tr.et_432 sq.af.un_330
  0x3f002702, 0x08020e0e, 0x11003504, 0x1732160d,   // gd.af.un_220 is.da.no_555  zu.ro.un_320 hr.bs.sr_554
  // [1f30]
  0x033f0607, 0x0e001a02, 0x20232ba0, 0x030c02a0,   // de.af.nl_432 tl.is.un_220  vi.ca.sq_322 da.sv.nl_322
  0x21003b09, 0x0000160a, 0x3b042007, 0x1b5225ad,   // so.jw.un_440 hr.un.un_500  sq.fi.so_432 eu.ha.tr_643
  0x1c130955, 0x20005302, 0x530f2104, 0x062a08ec,   // hi.bh.mr_442 ht.sq.un_220  jw.lv.ht_332 no.mt.de_644
  0x6400210e, 0x0d162d0c, 0x521a6bad, 0x03001604,   // jw.lg.un_550 sk.hr.cs_543  ceb.tl.ha_643 hr.nl.un_320
  // [1f40]
  0x06002808, 0x1b002104, 0x0f003b0e, 0x060c0813,   // sw.de.un_430 jw.tr.un_320  so.lv.un_550 no.sv.de_665
  0x28206404, 0x070b2304, 0x1f006414, 0x1f120ca0,   // lg.sq.sw_332 ca.es.it_332  lg.cy.un_660 sv.hu.cy_322
  0x032512a4, 0x0e000d12, 0x110805a0, 0x07101302,   // hu.eu.nl_433 cs.is.un_640  fr.no.ro_322 et.lt.it_222
  0x13001214, 0x53000702, 0x01000507, 0x0c1b310d,   // hu.et.un_660 it.ht.un_220  fr.en.un_420 az.tr.sv_554
  // [1f50]
  0x131827a0, 0x1c23530c, 0x162d0da0, 0x04002904,   // gd.ga.et_322 ht.ca.id_543  cs.sk.hr_322 sl.fi.un_320
  0x2a000812, 0x64551a0c, 0x550203a4, 0x0711010c,   // no.mt.un_640 tl.rw.lg_543  nl.da.rw_433 en.ro.it_543
  0x020a0804, 0x1b000f08, 0x0d321602, 0x1c130d14,   // no.pt.da_332 lv.tr.un_430  hr.bs.cs_222 ne.bh.mr_666
  0x190a1214, 0x12001a07, 0x10071111, 0x09000a02,   // hu.pt.gl_666 tl.hu.un_420  ro.bg.be_653 pt.pl.un_220
  // [1f60]
  0x04110502, 0x0413100e, 0x64551304, 0x0c3f0802,   // fr.ro.fi_222 lt.et.fi_555  et.rw.lg_332 no.af.sv_222
  0x25080205, 0x23000412, 0x16001307, 0x1f080202,   // da.no.eu_333 fi.ca.un_640  et.hr.un_420 da.no.cy_222
  0x1200100d, 0x28000408, 0x21001a09, 0x090c0802,   // lt.hu.un_540 fi.sw.un_430  tl.jw.un_440 no.sv.pl_222
  0x1c091312, 0x21001f21, 0x0d00680c, 0x32005302,   // bh.hi.mr_654 cy.jw.un_860  ig.cs.un_530 ht.bs.un_220
  // [1f70]
  0x0b000509, 0x201605a0, 0x10006b04, 0x4a00290e,   // fr.es.un_440 fr.hr.sq_322  ceb.lt.un_320 sl.yo.un_550
  0x20004a0d, 0x531b3102, 0x200c06a4, 0x0f001a02,   // yo.sq.un_540 az.tr.ht_222  de.sv.sq_433 tl.lv.un_220
  0x190a07a4, 0x20113502, 0x070410a4, 0x05124a05,   // it.pt.gl_433 zu.ro.sq_222  be.ru.bg_433 yo.hu.fr_333
  0x191c2107, 0x170b29a0, 0x3b31270d, 0x290f1104,   // jw.id.gl_432 sl.es.sr_322  gd.az.so_554 ro.lv.sl_332
  // [1f80]
  0x08021fee, 0x0718270c, 0x0d000e11, 0x080c1aa0,   // cy.da.no_422 gd.ga.it_543  is.cs.un_630 tl.sv.no_322
  0x0600180c, 0x2300060c, 0x101f180c, 0x0804110d,   // ga.de.un_530 de.ca.un_530  ga.cy.lt_543 ro.ru.uk_554
  0x25190a07, 0x272d04a0, 0x27180508, 0x0c5306a0,   // pt.gl.eu_432 fi.sk.gd_322  fr.ga.gd_443 de.ht.sv_322
  0x280c1a04, 0x556b1a11, 0x04000307, 0x3b00190c,   // tl.sv.sw_332 tl.ceb.rw_653  nl.fi.un_420 gl.so.un_530
  // [1f90]
  0x29000a12, 0x53050fa0, 0x16290908, 0x0f005214,   // pt.sl.un_640 lv.fr.ht_322  pl.sl.hr_443 ha.lv.un_660
  0x07081711, 0x20001e02, 0x01000808, 0x2a000604,   // sr.uk.bg_653 ms.sq.un_220  no.en.un_430 de.mt.un_320
  0x0e002d08, 0x3b001309, 0x06002905, 0x11000a05,   // sk.is.un_430 et.so.un_440  sl.de.un_330 pt.ro.un_330
  0x03020cee, 0x03080ca0, 0x1c3216a0, 0x1a3b28ee,   // sv.da.nl_422 sv.no.nl_322  hr.bs.id_322 sw.so.tl_422
  // [1fa0]
  0x3f1003a0, 0x28551aa0, 0x6b2d0d09, 0x11001013,   // nl.lt.af_322 tl.rw.sw_322  cs.sk.ceb_444 be.ro.un_650
  0x285535ec, 0x13043bec, 0x040a17af, 0x64041304,   // zu.rw.sw_644 so.fi.et_644  sr.mk.ru_655 et.fi.lg_332
  0x03043f05, 0x04101707, 0x27002d0c, 0x01033fee,   // af.fi.nl_333 sr.be.ru_432  sk.gd.un_530 af.nl.en_422
  0x0c060207, 0x3f0325ec, 0x10000c07, 0x28122a04,   // da.de.sv_432 eu.nl.af_644  sv.lt.un_420 mt.hu.sw_332
  // [1fb0]
  0x1b1220ac, 0x350955ee, 0x12006e08, 0x29172da4,   // sq.hu.tr_632 rw.pl.zu_422  hmn.hu.un_430 sk.sr.sl_433
  0x28001e0d, 0x5500351b, 0x2d092aad, 0x01000a07,   // ms.sw.un_540 zu.rw.un_770  mt.pl.sk_643 pt.en.un_420
  0x13000e12, 0x31001e08, 0x68002013, 0x3f004a04,   // is.et.un_640 ms.az.un_430  sq.ig.un_650 yo.af.un_320
  0x6b3f0309, 0x554a350c, 0x32002107, 0x0a00041a,   // nl.af.ceb_444 zu.yo.rw_543  jw.bs.un_420 ru.mk.un_760
  // [1fc0]
  0x2d092a08, 0x07006402, 0x20001f12, 0x080413ad,   // mt.pl.sk_443 lg.it.un_220  cy.sq.un_640 et.fi.no_643
  0x103b52a0, 0x09200d04, 0x033f06a0, 0x182d1212,   // ha.so.lt_322 cs.sq.pl_332  de.af.nl_322 hu.sk.ga_654
  0x355528a4, 0x13082a08, 0x2100090c, 0x64043baf,   // sw.rw.zu_433 mt.no.et_443  pl.jw.un_530 so.fi.lg_655
  0x0b1853ee, 0x28003b14, 0x556413af, 0x132921a0,   // ht.ga.es_422 so.sw.un_660  et.lg.rw_655 jw.sl.et_322
  // [1fd0]
  0x17162905, 0x55282aad, 0x3f0e0305, 0x0300250d,   // sl.hr.sr_333 mt.sw.rw_643  nl.is.af_333 eu.nl.un_540
  0x1a101304, 0x05120e0c, 0x28643507, 0x3f000704,   // et.lt.tl_332 is.hu.fr_543  zu.lg.sw_432 it.af.un_320
  0x0d3b200b, 0x1707080c, 0x321c21ad, 0x0c003b04,   // sq.so.cs_542 uk.bg.sr_543  jw.id.bs_643 so.sv.un_320
  0x1c552105, 0x35002508, 0x3f0302ad, 0x2d090d0d,   // jw.rw.id_333 eu.zu.un_430  da.nl.af_643 cs.pl.sk_554
  // [1fe0]
  0x3b2035a7, 0x31001704, 0x1c6b1207, 0x091c1311,   // zu.sq.so_532 sr.az.un_320  hu.ceb.id_432 bh.mr.hi_653
  0x1a033bee, 0x68523505, 0x1210010c, 0x04003b04,   // so.nl.tl_422 zu.ha.ig_333  en.lt.hu_543 so.fi.un_320
  0x2d0d3fa9, 0x29320da0, 0x25001013, 0x0a00170e,   // af.cs.sk_544 cs.bs.sl_322  lt.eu.un_650 sr.mk.un_550
  0x080210ee, 0x1f00040c, 0x13090da9, 0x3b002907,   // lt.da.no_422 fi.cy.un_530  ne.hi.bh_544 sl.so.un_420
  // [1ff0]
  0x196810ee, 0x023531a0, 0x64005208, 0x4a6e2804,   // lt.ig.gl_422 az.zu.da_322  ha.lg.un_430 sw.hmn.yo_332
  0x06001212, 0x200f350c, 0x102835ad, 0x18200111,   // hu.de.un_640 zu.lv.sq_543  zu.sw.lt_643 en.sq.ga_653
  0x10190b07, 0x1e1c1a05, 0x55233b05, 0x09030107,   // es.gl.lt_432 tl.id.ms_333  so.ca.rw_333 en.nl.pl_432
  0x07001712, 0x0000320a, 0x18054aa0, 0x1b4a64ee,   // sr.bg.un_640 bs.un.un_500  yo.fr.ga_322 lg.yo.tr_422

  // [2000]
  0x28685507, 0x1e001802, 0x1b003509, 0x35000b04,   // rw.ig.sw_432 ga.ms.un_220  zu.tr.un_440 es.zu.un_320
  0x25000a04, 0x4a532907, 0x5528355a, 0x642104a9,   // pt.eu.un_320 sl.ht.yo_432  zu.sw.rw_553 fi.jw.lg_544
  0x131c0912, 0x0f190b07, 0x04002812, 0x12643f04,   // hi.mr.bh_654 es.gl.lv_432  sw.fi.un_640 af.lg.hu_332
  0x0d002909, 0x1c0d095a, 0x3500521a, 0x28100b02,   // sl.cs.un_440 hi.ne.mr_553  ha.zu.un_760 es.lt.sw_222
  // [2010]
  0x23002102, 0x0900121a, 0x07170405, 0x23005302,   // jw.ca.un_220 hu.pl.un_760  ru.sr.bg_333 ht.ca.un_220
  0x0a006b04, 0x04070a11, 0x01001a02, 0x53002704,   // ceb.pt.un_320 mk.bg.ru_653  tl.en.un_220 gd.ht.un_320
  0x5500350e, 0x311a6b12, 0x53000d13, 0x31003b07,   // zu.rw.un_550 ceb.tl.az_654  cs.ht.un_650 so.az.un_420
  0x0500120c, 0x6400520c, 0x08130c07, 0x04003b02,   // hu.fr.un_530 ha.lg.un_530  sv.et.no_432 so.fi.un_220
  // [2020]
  0x3b060e04, 0x051853a7, 0x25000505, 0x1104130b,   // is.de.so_332 ht.ga.fr_532  fr.eu.un_330 et.fi.ro_542
  0x070a04a4, 0x102729ad, 0x0e000612, 0x6b190111,   // ru.mk.bg_433 sl.gd.lt_643  de.is.un_640 en.gl.ceb_653
  0x3f000207, 0x0a001708, 0x041711ee, 0x3f0c0805,   // da.af.un_420 sr.mk.un_430  ro.sr.ru_422 no.sv.af_333
  0x28005204, 0x29111604, 0x0e3f080c, 0x1e1c3fec,   // ha.sw.un_320 hr.ro.sl_332  no.af.is_543 af.id.ms_644
  // [2030]
  0x040f1011, 0x0a002704, 0x25003512, 0x21001a12,   // lt.lv.fi_653 gd.pt.un_320  zu.eu.un_640 tl.jw.un_640
  0x2100520e, 0x4a006402, 0x0c043fa4, 0x55642807,   // ha.jw.un_550 lg.yo.un_220  af.fi.sv_433 sw.lg.rw_432
  0x1c002507, 0x08100302, 0x321029ad, 0x050d53a0,   // eu.id.un_420 nl.lt.no_222  sl.lt.bs_643 ht.cs.fr_322
  0x1c0d130c, 0x551e1c02, 0x070a2309, 0x0e001a0d,   // bh.ne.mr_543 id.ms.rw_222  ca.pt.it_444 tl.is.un_540
  // [2040]
  0x2800551a, 0x0a000b04, 0x55356804, 0x0f006e08,   // rw.sw.un_760 es.pt.un_320  ig.zu.rw_332 hmn.lv.un_430
  0x10080407, 0x130f2aad, 0x202d0d05, 0x23002721,   // ru.uk.be_432 mt.lv.et_643  cs.sk.sq_333 gd.ca.un_860
  0x11000119, 0x282135a0, 0x1f001a04, 0x2a002902,   // en.ro.un_750 zu.jw.sw_322  tl.cy.un_320 sl.mt.un_220
  0x10001308, 0x0f1009a7, 0x13000404, 0x28552104,   // et.lt.un_430 pl.lt.lv_532  fi.et.un_320 jw.rw.sw_332
  // [2050]
  0x23080204, 0x281e1207, 0x1e3b3f05, 0x1e100405,   // da.no.ca_332 hu.ms.sw_432  af.so.ms_333 fi.lt.ms_333
  0x016b0807, 0x16202907, 0x2d000d1b, 0x3b0413a4,   // no.ceb.en_432 sl.sq.hr_432  cs.sk.un_770 et.fi.so_433
  0x11070808, 0x2b0601ee, 0x294a6412, 0x180a230c,   // uk.bg.ro_443 en.de.vi_422  lg.yo.sl_654 ca.pt.ga_543
  0x3b001008, 0x01182004, 0x025313a9, 0x01213ba0,   // lt.so.un_430 sq.ga.en_332  et.ht.da_544 so.jw.en_322
  // [2060]
  0x3b003504, 0x1c130daf, 0x52532705, 0x0f1006ee,   // zu.so.un_320 ne.bh.mr_655  gd.ht.ha_333 de.lt.lv_422
  0x06180307, 0x6b072da0, 0x08005307, 0x276b18ad,   // nl.ga.de_432 sk.it.ceb_322  ht.no.un_420 ga.ceb.gd_643
  0x64000808, 0x09060304, 0x230d0aa0, 0x1f000813,   // no.lg.un_430 nl.de.pl_332  pt.cs.ca_322 no.cy.un_650
  0x3b5255a7, 0x0a1b05ee, 0x012311ad, 0x10550707,   // rw.ha.so_532 fr.tr.pt_422  ro.ca.en_643 it.rw.lt_432
  // [2070]
  0x0c080304, 0x2300530b, 0x52004a09, 0x131c0d0d,   // nl.no.sv_332 ht.ca.un_520  yo.ha.un_440 ne.mr.bh_554
  0x283f3504, 0x01110704, 0x1c05210c, 0x1a005214,   // zu.af.sw_332 it.ro.en_332  jw.fr.id_543 ha.tl.un_660
  0x081110af, 0x09006402, 0x29684a08, 0x3f030605,   // be.ro.uk_655 lg.pl.un_220  yo.ig.sl_443 de.nl.af_333
  0x28001a05, 0x28640107, 0x18120911, 0x1a4a2811,   // tl.sw.un_330 en.lg.sw_432  pl.hu.ga_653 sw.yo.tl_653
  // [2080]
  0x3f2a080c, 0x033f25ad, 0x12002a08, 0x0d2510ec,   // no.mt.af_543 eu.af.nl_643  mt.hu.un_430 lt.eu.cs_644
  0x211a6b07, 0x286435ec, 0x121013a0, 0x04001719,   // ceb.tl.jw_432 zu.lg.sw_644  et.lt.hu_322 sr.ru.un_750
  0x3f003512, 0x686e0f55, 0x521c1a07, 0x0c010ea7,   // zu.af.un_640 lv.hmn.ig_442  tl.id.ha_432 is.en.sv_532
  0x1100171b, 0x0c043fa0, 0x2a006e09, 0x0c0225a0,   // sr.ro.un_770 af.fi.sv_322  hmn.mt.un_440 eu.da.sv_322
  // [2090]
  0x2500020e, 0x250711ee, 0x321729ad, 0x1a006812,   // da.eu.un_550 ro.it.eu_422  sl.sr.bs_643 ig.tl.un_640
  0x555305a0, 0x07110a02, 0x64554a0c, 0x060107ee,   // fr.ht.rw_322 pt.ro.it_222  yo.rw.lg_543 it.en.de_422
  0x641b53a0, 0x275313af, 0x070311a7, 0x12002007,   // ht.tr.lg_322 et.ht.gd_655  ro.nl.it_532 sq.hu.un_420
  0x0b2d0d55, 0x31002508, 0x161b25a0, 0x1307100c,   // cs.sk.es_442 eu.az.un_430  eu.tr.hr_322 lt.it.et_543
  // [20a0]
  0x2a0f1007, 0x10001712, 0x110a1708, 0x525528a9,   // lt.lv.mt_432 sr.be.un_640  sr.mk.ro_443 sw.rw.ha_544
  0x0a001e02, 0x08556ba7, 0x04000a12, 0x29001c04,   // ms.pt.un_220 ceb.rw.no_532  mk.ru.un_640 id.sl.un_320
  0x1700291b, 0x0e003b19, 0x160f29a0, 0x3b4a3fee,   // sl.sr.un_770 so.is.un_750  sl.lv.hr_322 af.yo.so_422
  0x350f09a4, 0x1b003b1a, 0x07006412, 0x10170812,   // pl.lv.zu_433 so.tr.un_760  lg.it.un_640 uk.sr.be_654
  // [20b0]
  0x23000a07, 0x27003204, 0x3b6b5507, 0x1e1c040e,   // pt.ca.un_420 bs.gd.un_320  rw.ceb.so_432 fi.id.ms_555
  0x2800350d, 0x12645512, 0x2511050e, 0x18273bee,   // zu.sw.un_540 rw.lg.hu_654  fr.ro.eu_555 so.gd.ga_422
  0x1b4a550b, 0x0b00190c, 0x2d001013, 0x550529a7,   // rw.yo.tr_542 gl.es.un_530  lt.sk.un_650 sl.fr.rw_532
  0x11081705, 0x0d2a2d07, 0x07250604, 0x52003b12,   // sr.uk.ro_333 sk.mt.cs_432  de.eu.it_332 so.ha.un_640
  // [20c0]
  0x0e001212, 0x201b2da0, 0x3b5564ee, 0x3529550c,   // hu.is.un_640 sk.tr.sq_322  lg.rw.so_422 rw.sl.zu_543
  0x526401a4, 0x0c00640d, 0x08021fec, 0x3f0603ec,   // en.lg.ha_433 lg.sv.un_540  cy.da.no_644 nl.de.af_644
  0x16002507, 0x21001f04, 0x196e0a07, 0x0d002914,   // eu.hr.un_420 cy.jw.un_320  pt.hmn.gl_432 sl.cs.un_660
  0x55002913, 0x1a355507, 0x13043b0c, 0x1b0f130d,   // sl.rw.un_650 rw.zu.tl_432  so.fi.et_543 et.lv.tr_554
  // [20d0]
  0x3217200c, 0x1e1c0805, 0x0c0608a0, 0x28041304,   // sq.sr.bs_543 no.id.ms_333  no.de.sv_322 et.fi.sw_332
  0x16003505, 0x08020cac, 0x1b0a0407, 0x321625ee,   // zu.hr.un_330 sv.da.no_632  fi.pt.tr_432 eu.hr.bs_422
  0x0305530c, 0x190b0aaf, 0x1e001108, 0x04002008,   // ht.fr.nl_543 pt.es.gl_655  ro.ms.un_430 sq.fi.un_430
  0x08001807, 0x0a1827a7, 0x19002705, 0x0a550107,   // ga.no.un_420 gd.ga.pt_532  gd.gl.un_330 en.rw.pt_432
  // [20e0]
  0x55212505, 0x2d290d05, 0x0a282508, 0x25001b08,   // eu.jw.rw_333 cs.sl.sk_333  eu.sw.pt_443 tr.eu.un_430
  0x1200060e, 0x3f271f02, 0x6b6435a0, 0x310e1b13,   // de.hu.un_550 cy.gd.af_222  zu.lg.ceb_322 tr.is.az_665
  0x3b001f02, 0x120f10ee, 0x321c64a0, 0x0e310408,   // cy.so.un_220 lt.lv.hu_422  lg.id.bs_322 fi.az.is_443
  0x1a0e6ba0, 0x64000b02, 0x271e1c02, 0x040e13a4,   // ceb.is.tl_322 es.lg.un_220  id.ms.gd_222 et.is.fi_433
  // [20f0]
  0x08020e09, 0x19250b0c, 0x311b0505, 0x091f05a4,   // is.da.no_444 es.eu.gl_543  fr.tr.az_333 fr.cy.pl_433
  0x09130d60, 0x09040555, 0x0b1805a7, 0x28001a02,   // ne.bh.hi_664 fr.fi.pl_442  fr.ga.es_532 tl.sw.un_220
  0x130d1ba4, 0x3f033bac, 0x04071308, 0x32311b08,   // tr.cs.et_433 so.nl.af_632  et.it.fi_443 tr.az.bs_443
  0x292d12a6, 0x1f006407, 0x35001f0d, 0x160f2d02,   // hu.sk.sl_521 lg.cy.un_420  cy.zu.un_540 sk.lv.hr_222
  // [2100]
  0x6828350d, 0x0c1208a0, 0x1f255204, 0x20230a04,   // zu.sw.ig_554 no.hu.sv_322  ha.eu.cy_332 pt.ca.sq_332
  0x171632a6, 0x64522aa9, 0x215329ee, 0x00002a24,   // bs.hr.sr_521 mt.ha.lg_544  sl.ht.jw_422 mt.un.un_900
  0x1b550f11, 0x080211a6, 0x0f272512, 0x55000507,   // lv.rw.tr_653 ro.da.no_521  eu.gd.lv_654 fr.rw.un_420
  0x08210511, 0x021b0808, 0x2118055a, 0x35002a04,   // fr.jw.no_653 no.tr.da_443  fr.ga.jw_553 mt.zu.un_320
  // [2110]
  0x1b000c08, 0x321753a0, 0x10000418, 0x0300270d,   // sv.tr.un_430 ht.sr.bs_322  ru.be.un_740 gd.nl.un_540
  0x00001b03, 0x55311ba7, 0x05061208, 0x3b002804,   // tr.un.un_300 tr.az.rw_532  hu.de.fr_443 sw.so.un_320
  0x183b2760, 0x35000804, 0x161325a0, 0x1b0612ee,   // gd.so.ga_664 no.zu.un_320  eu.et.hr_322 hu.de.tr_422
  0x2a55530c, 0x13005219, 0x3b001c05, 0x18271f05,   // ht.rw.mt_543 ha.et.un_750  id.so.un_330 cy.gd.ga_333
  // [2120]
  0x1e1c23a0, 0x122508a0, 0x2500230d, 0x040652a0,   // ca.id.ms_322 no.eu.hu_322  ca.eu.un_540 ha.de.fi_322
  0x170a1002, 0x09005302, 0x211a6b0c, 0x093f0107,   // be.mk.sr_222 ht.pl.un_220  ceb.tl.jw_543 en.af.pl_432
  0x1f0301ec, 0x06172007, 0x55005305, 0x0a190b0d,   // en.nl.cy_644 sq.sr.de_432  ht.rw.un_330 es.gl.pt_554
  0x25060fad, 0x3b002813, 0x3b211ca0, 0x6428090d,   // lv.de.eu_643 sw.so.un_650  id.jw.so_322 pl.sw.lg_554
  // [2130]
  0x080c0e02, 0x270e3bee, 0x031f3f55, 0x2800270c,   // is.sv.no_222 so.is.gd_422  af.cy.nl_442 gd.sw.un_530
  0x3f0313ec, 0x1b2801a7, 0x29122d0c, 0x3f0352ee,   // et.nl.af_644 en.sw.tr_532  sk.hu.sl_543 ha.nl.af_422
  0x170c13a7, 0x21090155, 0x6e2d1255, 0x250a0702,   // et.sv.sr_532 en.pl.jw_442  hu.sk.hmn_442 it.pt.eu_222
  0x19002b07, 0x13000c02, 0x1a6b0108, 0x0b001107,   // vi.gl.un_420 sv.et.un_220  en.ceb.tl_443 ro.es.un_420
  // [2140]
  0x1f09060d, 0x0d172dee, 0x2003040c, 0x1b2520ee,   // de.pl.cy_554 sk.sr.cs_422  fi.nl.sq_543 sq.eu.tr_422
  0x0b003505, 0x0a080705, 0x2a003b13, 0x05080208,   // zu.es.un_330 bg.uk.mk_333  so.mt.un_650 da.no.fr_443
  0x2a0701a0, 0x312125ad, 0x09002a02, 0x64003511,   // en.it.mt_322 eu.jw.az_643  mt.pl.un_220 zu.lg.un_630
  0x0a0811a9, 0x1b100e0c, 0x04001e07, 0x05004a08,   // ro.uk.mk_544 is.lt.tr_543  ms.fi.un_420 yo.fr.un_430
  // [2150]
  0x0b0501a4, 0x08041704, 0x13001102, 0x04202511,   // en.fr.es_433 sr.ru.uk_332  ro.et.un_220 eu.sq.fi_653
  0x3f3509a4, 0x09002304, 0x06001e02, 0x1c13090c,   // pl.zu.af_433 ca.pl.un_320  ms.de.un_220 hi.bh.mr_543
  0x534a0c02, 0x07080408, 0x6e6b6407, 0x271a1811,   // sv.yo.ht_222 ru.uk.bg_443  lg.ceb.hmn_432 ga.tl.gd_653
  0x2100060c, 0x130435a0, 0x080a10a0, 0x190407ee,   // de.jw.un_530 zu.fi.et_322  be.mk.uk_322 it.fi.gl_422
  // [2160]
  0x16122055, 0x20030207, 0x0a1704af, 0x29171602,   // sq.hu.hr_442 da.nl.sq_432  ru.sr.mk_655 hr.sr.sl_222
  0x1b1e3107, 0x2d000b04, 0x64070407, 0x1a2913a7,   // az.ms.tr_432 es.sk.un_320  fi.it.lg_432 et.sl.tl_532
  0x101352ad, 0x2d0d21a4, 0x04000912, 0x6b001a14,   // ha.et.lt_643 jw.cs.sk_433  pl.fi.un_640 tl.ceb.un_660
  0x10001723, 0x06106ba0, 0x20322aee, 0x322b16a0,   // sr.be.un_880 ceb.lt.de_322  mt.bs.sq_422 hr.vi.bs_322
  // [2170]
  0x1b001604, 0x552164a0, 0x35001c08, 0x17001609,   // hr.tr.un_320 lg.jw.rw_322  id.zu.un_430 hr.sr.un_440
  0x080b0a02, 0x09320f04, 0x35006409, 0x17002a08,   // pt.es.no_222 lv.bs.pl_332  lg.zu.un_440 mt.sr.un_430
  0x0820030c, 0x64532007, 0x0b002107, 0x070a1702,   // nl.sq.no_543 sq.ht.lg_432  jw.es.un_420 sr.mk.bg_222
  0x550728ee, 0x0c1b05a0, 0x10000602, 0x0408100d,   // sw.it.rw_422 fr.tr.sv_322  de.lt.un_220 be.uk.ru_554
  // [2180]
  0x0a110712, 0x286429ee, 0x23001207, 0x21002018,   // bg.ro.mk_654 sl.lg.sw_422  hu.ca.un_420 sq.jw.un_740
  0x12100f07, 0x35004a12, 0x121009a4, 0x2d000a04,   // lv.lt.hu_432 yo.zu.un_640  pl.lt.hu_433 pt.sk.un_320
  0x081704ee, 0x2a2028a4, 0x211e1c02, 0x35532808,   // ru.sr.uk_422 sw.sq.mt_433  id.ms.jw_222 sw.ht.zu_443
  0x061b3f12, 0x13031b0c, 0x643f55ec, 0x0a000819,   // af.tr.de_654 tr.nl.et_543  rw.af.lg_644 uk.mk.un_750
  // [2190]
  0x0b0701a4, 0x1b0a28a0, 0x0a041305, 0x643555ec,   // en.it.es_433 sw.pt.tr_322  et.fi.pt_333 rw.zu.lg_644
  0x0c0e0204, 0x3f0208ee, 0x19002a07, 0x07040814,   // da.is.sv_332 no.da.af_422  mt.gl.un_420 uk.ru.bg_666
  0x0300010b, 0x02001308, 0x4a181fa0, 0x0800021b,   // en.nl.un_520 et.da.un_430  cy.ga.yo_322 da.no.un_770
  0x2d00291a, 0x086410a7, 0x354a0408, 0x046410ee,   // sl.sk.un_760 lt.lg.no_532  fi.yo.zu_443 lt.lg.fi_422
  // [21a0]
  0x28133b07, 0x0a00170c, 0x2b041307, 0x2a000702,   // so.et.sw_432 sr.mk.un_530  et.fi.vi_432 it.mt.un_220
  0x68050107, 0x25005214, 0x10040a0e, 0x3f5501a4,   // en.fr.ig_432 ha.eu.un_660  mk.ru.be_555 en.rw.af_433
  0x3f031bee, 0x18000412, 0x5500680d, 0x17080414,   // tr.nl.af_422 fi.ga.un_640  ig.rw.un_540 ru.uk.sr_666
  0x032a3ba0, 0x170d29a0, 0x04003f07, 0x1b001213,   // so.mt.nl_322 sl.cs.sr_322  af.fi.un_420 hu.tr.un_650
  // [21b0]
  0x52006402, 0x2a001c04, 0x521f0607, 0x52001118,   // lg.ha.un_220 id.mt.un_320  de.cy.ha_432 ro.ha.un_740
  0x16001e02, 0x4a060304, 0x29000804, 0x04170a07,   // ms.hr.un_220 nl.de.yo_332  no.sl.un_320 mk.sr.ru_432
  0x6b13010c, 0x6b281307, 0x050701a6, 0x64525555,   // en.et.ceb_543 et.sw.ceb_432  en.it.fr_521 rw.ha.lg_442
  0x2b001112, 0x1a0401a0, 0x18002721, 0x281e1c55,   // ro.vi.un_640 en.fi.tl_322  gd.ga.un_860 id.ms.sw_442
  // [21c0]
  0x6b0501ad, 0x3f00091a, 0x6b011204, 0x6b005505,   // en.fr.ceb_643 pl.af.un_760  hu.en.ceb_332 rw.ceb.un_330
  0x06130c0c, 0x03001702, 0x17002911, 0x3b526404,   // sv.et.de_543 sr.nl.un_220  sl.sr.un_630 lg.ha.so_332
  0x04000805, 0x3f0608a4, 0x11002813, 0x4a6421a0,   // uk.ru.un_330 no.de.af_433  sw.ro.un_650 jw.lg.yo_322
  0x2a0e08a0, 0x0700130d, 0x53003507, 0x04006412,   // no.is.mt_322 et.it.un_540  zu.ht.un_420 lg.fi.un_640
  // [21d0]
  0x256b4aad, 0x161e32a0, 0x0900280e, 0x132a3504,   // yo.ceb.eu_643 bs.ms.hr_322  sw.pl.un_550 zu.mt.et_332
  0x1e522a08, 0x35215504, 0x063f21ee, 0x5500091a,   // mt.ha.ms_443 rw.jw.zu_332  jw.af.de_422 pl.rw.un_760
  0x55353f13, 0x1b230aec, 0x08000504, 0x21356808,   // af.zu.rw_665 pt.ca.tr_644  fr.no.un_320 ig.zu.jw_443
  0x52250608, 0x09000113, 0x055316a0, 0x53002808,   // de.eu.ha_443 en.pl.un_650  hr.ht.fr_322 sw.ht.un_430
  // [21e0]
  0x0d2d05af, 0x112b2102, 0x0c06130c, 0x05003f0c,   // fr.sk.cs_655 jw.vi.ro_222  et.de.sv_543 af.fr.un_530
  0x522a0502, 0x11030507, 0x08070a09, 0x2d000f0e,   // fr.mt.ha_222 fr.nl.ro_432  mk.bg.uk_444 lv.sk.un_550
  0x2a001909, 0x08010c07, 0x530128a0, 0x1f000d11,   // gl.mt.un_440 sv.en.no_432  sw.en.ht_322 cs.cy.un_630
  0x2504130c, 0x08001f12, 0x32212aa0, 0x3b005202,   // et.fi.eu_543 cy.no.un_640  mt.jw.bs_322 ha.so.un_220
  // [21f0]
  0x0b00120b, 0x0e3555a6, 0x102d20ee, 0x0b010aee,   // hu.es.un_520 rw.zu.is_521  sq.sk.lt_422 pt.en.es_422
  0x2a005502, 0x311b0eac, 0x271f0804, 0x0f101e04,   // rw.mt.un_220 is.tr.az_632  no.cy.gd_332 ms.lt.lv_332
  0x2a071104, 0x55351104, 0x130c08a0, 0x06043f02,   // ro.it.mt_332 ro.zu.rw_332  no.sv.et_322 af.fi.de_222
  0x170407a7, 0x0a2325ee, 0x55642004, 0x190b0702,   // bg.ru.sr_532 eu.ca.pt_422  sq.lg.rw_332 it.es.gl_222
  // [2200]
  0x321720ee, 0x352164a6, 0x1c130912, 0x0e00180e,   // sq.sr.bs_422 lg.jw.zu_521  hi.bh.mr_654 ga.is.un_550
  0x07002704, 0x35000104, 0x080d2da7, 0x0e64350e,   // gd.it.un_320 en.zu.un_320  sk.cs.no_532 zu.lg.is_555
  0x090d1c0e, 0x2835550d, 0x0f080204, 0x3b000302,   // mr.ne.hi_555 rw.zu.sw_554  da.no.lv_332 nl.so.un_220
  0x11100812, 0x29005204, 0x202d0d0d, 0x0a170409,   // uk.be.ro_654 ha.sl.un_320  cs.sk.sq_554 ru.sr.mk_444
  // [2210]
  0x111025a0, 0x10250fee, 0x23005312, 0x130420ad,   // eu.lt.ro_322 lv.eu.lt_422  ht.ca.un_640 sq.fi.et_643
  0x1e1c1602, 0x18001a02, 0x3f005304, 0x100507a4,   // hr.id.ms_222 tl.ga.un_220  ht.af.un_320 it.fr.lt_433
  0x233f530d, 0x17080a04, 0x230b25a4, 0x1c0553a0,   // ht.af.ca_554 mk.uk.sr_332  eu.es.ca_433 ht.fr.id_322
  0x1200091a, 0x18110a08, 0x12001104, 0x19050a55,   // pl.hu.un_760 pt.ro.ga_443  ro.hu.un_320 pt.fr.gl_442
  // [2220]
  0x53021ea0, 0x35281aa7, 0x16112007, 0x0906120d,   // ms.da.ht_322 tl.sw.zu_532  sq.ro.hr_432 hu.de.pl_554
  0x033f02a9, 0x0d091c09, 0x1c003f0c, 0x18001104,   // da.af.nl_544 mr.hi.ne_444  af.id.un_530 ro.ga.un_320
  0x092a1bee, 0x28000c07, 0x5521640d, 0x0600530c,   // tr.mt.pl_422 sv.sw.un_420  lg.jw.rw_554 ht.de.un_530
  0x0700101a, 0x080c02ec, 0x1000070e, 0x2d0d1c02,   // be.bg.un_760 da.sv.no_644  bg.be.un_550 id.cs.sk_222
  // [2230]
  0x1b120405, 0x2d0d23ee, 0x2a0c0408, 0x0e2a04ad,   // fi.hu.tr_333 ca.cs.sk_422  fi.sv.mt_443 fi.mt.is_643
  0x0b040e0d, 0x3b005304, 0x032553a0, 0x08003f12,   // is.fi.es_554 ht.so.un_320  ht.eu.nl_322 af.no.un_640
  0x162911a4, 0x2a003107, 0x05250107, 0x0e311b0c,   // ro.sl.hr_433 az.mt.un_420  en.eu.fr_432 tr.az.is_543
  0x3b684aee, 0x082505ad, 0x0c005319, 0x23131007,   // yo.ig.so_422 fr.eu.no_643  ht.sv.un_750 lt.et.ca_432
  // [2240]
  0x170411ec, 0x0c003b14, 0x051f52a9, 0x25185208,   // ro.ru.sr_644 so.sv.un_660  ha.cy.fr_544 ha.ga.eu_443
  0x35001112, 0x12000d0d, 0x09000409, 0x0d1c09af,   // ro.zu.un_640 cs.hu.un_540  fi.pl.un_440 hi.mr.ne_655
  0x0e002113, 0x2a0406a9, 0x11003f07, 0x00001915,   // jw.is.un_650 de.fi.mt_544  af.ro.un_420 gl.un.un_700
  0x0c521fa4, 0x0a00190c, 0x19110a0d, 0x0a002018,   // cy.ha.sv_433 gl.pt.un_530  pt.ro.gl_554 sq.pt.un_740
  // [2250]
  0x2d2004af, 0x64002507, 0x2a003b1a, 0x230c1fad,   // fi.sq.sk_655 eu.lg.un_420  so.mt.un_760 cy.sv.ca_643
  0x27315211, 0x64001102, 0x27001f12, 0x3b1e2aee,   // ha.az.gd_653 ro.lg.un_220  cy.gd.un_640 mt.ms.so_422
  0x12203f09, 0x1e1c2155, 0x2d0d29a6, 0x0c00020b,   // af.sq.hu_444 jw.id.ms_442  sl.cs.sk_521 da.sv.un_520
  0x0b2b52a0, 0x2d3509ad, 0x04311bad, 0x04000f07,   // ha.vi.es_322 pl.zu.sk_643  tr.az.fi_643 lv.fi.un_420
  // [2260]
  0x05001102, 0x0f04100d, 0x16002502, 0x0f130c0b,   // ro.fr.un_220 lt.fi.lv_554  eu.hr.un_220 sv.et.lv_542
  0x28004a0c, 0x2a001f0e, 0x2a183b0b, 0x04100a04,   // yo.sw.un_530 cy.mt.un_550  so.ga.mt_542 mk.be.ru_332
  0x07181f12, 0x1b1606a4, 0x1200290d, 0x091c13a6,   // cy.ga.it_654 de.hr.tr_433  sl.hu.un_540 bh.mr.hi_521
  0x0a1011ec, 0x09002905, 0x3b000e13, 0x53002d0d,   // ro.be.mk_644 sl.pl.un_330  is.so.un_650 sk.ht.un_540
  // [2270]
  0x3f001812, 0x1b31060c, 0x08111714, 0x53214a55,   // ga.af.un_640 de.az.tr_543  sr.ro.uk_666 yo.jw.ht_442
  0x27006e18, 0x23001902, 0x2d00350d, 0x080a0708,   // hmn.gd.un_740 gl.ca.un_220  zu.sk.un_540 bg.mk.uk_443
  0x0603250c, 0x3f030204, 0x08111708, 0x0e3f53ad,   // eu.nl.de_543 da.nl.af_332  sr.ro.uk_443 ht.af.is_643
  0x06001813, 0x1306020d, 0x2500110e, 0x18270d0c,   // ga.de.un_650 da.de.et_554  ro.eu.un_550 cs.gd.ga_543
  // [2280]
  0x11040705, 0x642335ee, 0x17080a13, 0x55001f12,   // bg.ru.ro_333 zu.ca.lg_422  mk.uk.sr_665 cy.rw.un_640
  0x0c101f07, 0x190b0aa0, 0x1900110d, 0x28001c0d,   // cy.lt.sv_432 pt.es.gl_322  ro.gl.un_540 id.sw.un_540
  0x21322dee, 0x13091c09, 0x0100200c, 0x05001f0c,   // sk.bs.jw_422 mr.hi.bh_444  sq.en.un_530 cy.fr.un_530
  0x1b2a07a9, 0x3500640b, 0x060c3f04, 0x35006b04,   // it.mt.tr_544 lg.zu.un_520  af.sv.de_332 ceb.zu.un_320
  // [2290]
  0x11003202, 0x3b6b1a12, 0x10002807, 0x6e002d0c,   // bs.ro.un_220 tl.ceb.so_654  sw.lt.un_420 sk.hmn.un_530
  0x350c0ea0, 0x2d000412, 0x231b0fa9, 0x286b310c,   // is.sv.zu_322 fi.sk.un_640  lv.tr.ca_544 az.ceb.sw_543
  0x35091a07, 0x53643504, 0x12003f02, 0x534a5507,   // tl.pl.zu_432 zu.lg.ht_332  af.hu.un_220 rw.yo.ht_432
  0x55001b14, 0x28006404, 0x3b1b5511, 0x20002907,   // tr.rw.un_660 lg.sw.un_320  rw.tr.so_653 sl.sq.un_420
  // [22a0]
  0x64053ba0, 0x530f05a0, 0x211e3504, 0x190b1005,   // so.fr.lg_322 fr.lv.ht_322  zu.ms.jw_332 lt.es.gl_333
  0x21003f13, 0x07000112, 0x07000408, 0x1b0a25a0,   // af.jw.un_650 en.it.un_640  ru.bg.un_430 eu.pt.tr_322
  0x1a536b08, 0x0f1b2907, 0x3b00551a, 0x03060504,   // ceb.ht.tl_443 sl.tr.lv_432  rw.so.un_760 fr.de.nl_332
  0x1e1c01a4, 0x27002a04, 0x072a1105, 0x552053a4,   // en.id.ms_433 mt.gd.un_320  ro.mt.it_333 ht.sq.rw_433
  // [22b0]
  0x13281104, 0x6406050b, 0x05000a0d, 0x09311e04,   // ro.sw.et_332 fr.de.lg_542  pt.fr.un_540 ms.az.pl_332
  0x201b29ec, 0x130a0807, 0x1f002704, 0x52001b09,   // sl.tr.sq_644 no.pt.et_432  gd.cy.un_320 tr.ha.un_440
  0x130d1cec, 0x0e0f2507, 0x0f2512ad, 0x0e00270d,   // mr.ne.bh_644 eu.lv.is_432  hu.eu.lv_643 gd.is.un_540
  0x0e2a29a0, 0x2a351207, 0x0a002312, 0x0a002b19,   // sl.mt.is_322 hu.zu.mt_432  ca.pt.un_640 vi.pt.un_750
  // [22c0]
  0x100504a0, 0x0600130d, 0x27000e18, 0x033f3b0c,   // fi.fr.lt_322 et.de.un_540  is.gd.un_740 so.af.nl_543
  0x080c0905, 0x08270504, 0x2a000c04, 0x3f06030c,   // pl.sv.no_333 fr.gd.no_332  sv.mt.un_320 nl.de.af_543
  0x3b003f13, 0x3b6b3fa0, 0x25006807, 0x1209250b,   // af.so.un_650 af.ceb.so_322  ig.eu.un_420 eu.pl.hu_542
  0x520612ec, 0x10050412, 0x0b0a23a9, 0x1c001313,   // hu.de.ha_644 fi.fr.lt_654  ca.pt.es_544 et.id.un_650
  // [22d0]
  0x21286404, 0x08320eac, 0x101304a4, 0x52283508,   // lg.sw.jw_332 is.bs.no_632  fi.et.lt_433 zu.sw.ha_443
  0x033f28a0, 0x0d1c09a7, 0x28552508, 0x3b001e04,   // sw.af.nl_322 hi.mr.ne_532  eu.rw.sw_443 ms.so.un_320
  0x3b3528ec, 0x09002105, 0x2d000f13, 0x07282504,   // sw.zu.so_644 jw.pl.un_330  lv.sk.un_650 eu.sw.it_332
  0x10640e07, 0x2d0d05a0, 0x19001804, 0x523b280b,   // is.lg.lt_432 fr.cs.sk_322  ga.gl.un_320 sw.so.ha_542
  // [22e0]
  0x3f006407, 0x1f000507, 0x3b000804, 0x05002904,   // lg.af.un_420 fr.cy.un_420  no.so.un_320 sl.fr.un_320
  0x3b1252ee, 0x686e0107, 0x2d0d1609, 0x270823a0,   // ha.hu.so_422 en.hmn.ig_432  hr.cs.sk_444 ca.no.gd_322
  0x2d35030c, 0x2d0d290e, 0x2500520e, 0x27000b04,   // nl.zu.sk_543 sl.cs.sk_555  ha.eu.un_550 es.gd.un_320
  0x53280307, 0x10640f13, 0x04001319, 0x190b0a08,   // nl.sw.ht_432 lv.lg.lt_665  et.fi.un_750 pt.es.gl_443
  // [22f0]
  0x0407105a, 0x520e1604, 0x0d280307, 0x1a033fad,   // be.bg.ru_553 hr.is.ha_332  nl.sw.cs_432 af.nl.tl_643
  0x031806a4, 0x093f08a4, 0x20003518, 0x532a0a12,   // de.ga.nl_433 no.af.pl_433  zu.sq.un_740 pt.mt.ht_654
  0x11000714, 0x1a3b6ba4, 0x18001307, 0x1f0901a4,   // bg.ro.un_660 ceb.so.tl_433  et.ga.un_420 en.pl.cy_433
  0x11001b0e, 0x12001605, 0x01003f02, 0x2a5264ad,   // tr.ro.un_550 hr.hu.un_330  af.en.un_220 lg.ha.mt_643
  // [2300]
  0x03092507, 0x28130107, 0x1c002111, 0x20002809,   // eu.pl.nl_432 en.et.sw_432  jw.id.un_630 sw.sq.un_440
  0x0e002a07, 0x28002107, 0x3f00640b, 0x536409ad,   // mt.is.un_420 jw.sw.un_420  lg.af.un_520 pl.lg.ht_643
  0x0b00230d, 0x0e006b0c, 0x1e1c1205, 0x036b01ee,   // ca.es.un_540 ceb.is.un_530  hu.id.ms_333 en.ceb.nl_422
  0x01060805, 0x2500040d, 0x170410ad, 0x0c1f1a0d,   // no.de.en_333 fi.eu.un_540  be.ru.sr_643 tl.cy.sv_554
  // [2310]
  0x0a002309, 0x3b001807, 0x35002302, 0x1e1c04ee,   // ca.pt.un_440 ga.so.un_420  ca.zu.un_220 fi.id.ms_422
  0x0f5313a9, 0x19050a07, 0x13001f12, 0x112308ad,   // et.ht.lv_544 pt.fr.gl_432  cy.et.un_640 no.ca.ro_643
  0x0400010c, 0x08000a02, 0x1c352112, 0x0e001312,   // en.fi.un_530 mk.uk.un_220  jw.zu.id_654 et.is.un_640
  0x6b2a0607, 0x2a00520e, 0x0e061fa4, 0x07551004,   // de.mt.ceb_432 ha.mt.un_550  cy.de.is_433 lt.rw.it_332
  // [2320]
  0x012d09a0, 0x07040aaf, 0x1f3f0305, 0x010d1f04,   // pl.sk.en_322 mk.ru.bg_655  nl.af.cy_333 cy.cs.en_332
  0x1e006804, 0x28005212, 0x4a2827a0, 0x082b0107,   // ig.ms.un_320 ha.sw.un_640  gd.sw.yo_322 en.vi.no_432
  0x1004070e, 0x0400011a, 0x040710ec, 0x29320ca0,   // bg.ru.be_555 en.fi.un_760  be.bg.ru_644 sv.bs.sl_322
  0x0a07040c, 0x0b110707, 0x1c0d09a7, 0x2d000a13,   // ru.bg.mk_543 it.ro.es_432  hi.ne.mr_532 pt.sk.un_650
  // [2330]
  0x0c1b2a0c, 0x1a001014, 0x0a002804, 0x13003f02,   // mt.tr.sv_543 lt.tl.un_660  sw.pt.un_320 af.et.un_220
  0x3b553507, 0x09003502, 0x112d0d08, 0x32001e04,   // zu.rw.so_432 zu.pl.un_220  cs.sk.ro_443 ms.bs.un_320
  0x0a001022, 0x286425ad, 0x25002104, 0x28202509,   // be.mk.un_870 eu.lg.sw_643  jw.eu.un_320 eu.sq.sw_444
  0x356828a4, 0x071110a0, 0x311e2dad, 0x27090804,   // sw.ig.zu_433 lt.ro.it_322  sk.ms.az_643 no.pl.gd_332
  // [2340]
  0x1f3b2107, 0x2d033f0d, 0x4a002d12, 0x2d001208,   // jw.so.cy_432 af.nl.sk_554  sk.yo.un_640 hu.sk.un_430
  0x6b6807a0, 0x170a1104, 0x211a3fa4, 0x133b0413,   // it.ig.ceb_322 ro.mk.sr_332  af.tl.jw_433 fi.so.et_665
  0x523f53a4, 0x29002304, 0x35216eee, 0x55003b1b,   // ht.af.ha_433 ca.sl.un_320  hmn.jw.zu_422 so.rw.un_770
  0x110417af, 0x291e1804, 0x12182108, 0x0e0a0ca4,   // sr.ru.ro_655 ga.ms.sl_332  fa.ar.ur_443 sv.pt.is_433
  // [2350]
  0x0d004a02, 0x3b1b0455, 0x271801af, 0x0a29230b,   // yo.cs.un_220 fi.tr.so_442  en.ga.gd_655 ca.sl.pt_542
  0x0b002505, 0x29231207, 0x0e00080c, 0x09000802,   // eu.es.un_330 hu.ca.sl_432  no.is.un_530 no.pl.un_220
  0x06021f07, 0x11130411, 0x2a002908, 0x0a040713,   // cy.da.de_432 fi.et.ro_653  sl.mt.un_430 bg.ru.mk_665
  0x3b006b07, 0x1e211c07, 0x013f2804, 0x0e210b04,   // ceb.so.un_420 id.jw.ms_432  sw.af.en_332 es.jw.is_332
  // [2360]
  0x16003b0e, 0x1b685204, 0x100b0a08, 0x232b3ba0,   // so.hr.un_550 ha.ig.tr_332  pt.es.lt_443 so.vi.ca_322
  0x25002305, 0x091355ee, 0x131c09ac, 0x0b523b0c,   // ca.eu.un_330 rw.et.pl_422  hi.mr.bh_632 so.ha.es_543
  0x553506a4, 0x0c0f050e, 0x1f000d04, 0x211c53a4,   // de.zu.rw_433 fr.lv.sv_555  cs.cy.un_320 ht.id.jw_433
  0x52211e0c, 0x4a2852a4, 0x2303010c, 0x0f105207,   // ms.jw.ha_543 ha.sw.yo_433  en.nl.ca_543 ha.lt.lv_432
  // [2370]
  0x160720ac, 0x08021702, 0x1e1c07ee, 0x1a0f1b11,   // sq.it.hr_632 sr.da.no_222  it.id.ms_422 tr.lv.tl_653
  0x060301a4, 0x3b001f12, 0x060105a9, 0x3f055307,   // en.nl.de_433 cy.so.un_640  fr.en.de_544 ht.fr.af_432
  0x011f23a7, 0x55003b02, 0x20030107, 0x040a0755,   // ca.cy.en_532 so.rw.un_220  en.nl.sq_432 bg.mk.ru_442
  0x3200200d, 0x2d122004, 0x0e003504, 0x32290f07,   // sq.bs.un_540 sq.hu.sk_332  zu.is.un_320 lv.sl.bs_432
  // [2380]
  0x190b230e, 0x03002904, 0x011a5302, 0x16000702,   // ca.es.gl_555 sl.nl.un_320  ht.tl.en_222 it.hr.un_220
  0x250928a7, 0x201852a0, 0x0a05010c, 0x02252805,   // sw.pl.eu_532 ha.ga.sq_322  en.fr.pt_543 sw.eu.da_333
  0x042a3555, 0x3f1129a0, 0x2a0e110c, 0x2800680c,   // zu.mt.fi_442 sl.ro.af_322  ro.is.mt_543 ig.sw.un_530
  0x17110aa4, 0x173201a6, 0x2500200d, 0x1b002912,   // mk.ro.sr_433 en.bs.sr_521  sq.eu.un_540 sl.tr.un_640
  // [2390]
  0x20250107, 0x3b3120a0, 0x20000512, 0x03002902,   // en.eu.sq_432 sq.az.so_322  fr.sq.un_640 sl.nl.un_220
  0x1e1c52ec, 0x0f0e01a4, 0x2300030e, 0x23110107,   // ha.id.ms_644 en.is.lv_433  nl.ca.un_550 en.ro.ca_432
  0x0208060d, 0x12000d1a, 0x3b6b06ec, 0x11000419,   // de.no.da_554 cs.hu.un_760  de.ceb.so_644 ru.ro.un_750
  0x0a000e13, 0x211c3bec, 0x0b091007, 0x23002502,   // is.pt.un_650 so.id.jw_644  lt.pl.es_432 eu.ca.un_220
  // [23a0]
  0x35001b13, 0x3b002102, 0x3f00530c, 0x211805ee,   // tr.zu.un_650 jw.so.un_220  ht.af.un_530 fr.ga.jw_422
  0x132d0855, 0x0e1812ec, 0x1811010c, 0x64522104,   // no.sk.et_442 hu.ga.is_644  en.ro.ga_543 jw.ha.lg_332
  0x6800251b, 0x1800090d, 0x172d20ee, 0x64004a07,   // eu.ig.un_770 pl.ga.un_540  sq.sk.sr_422 yo.lg.un_420
  0x106809ec, 0x12232d0b, 0x02080c07, 0x313b0e12,   // pl.ig.lt_644 sk.ca.hu_542  sv.no.da_432 is.so.az_654
  // [23b0]
  0x1b002509, 0x2a210fee, 0x556404a4, 0x64552805,   // eu.tr.un_440 lv.jw.mt_422  fi.lg.rw_433 sw.rw.lg_333
  0x035528ec, 0x1e1c0c05, 0x132d0d08, 0x2d0d0502,   // sw.rw.nl_644 sv.id.ms_333  cs.sk.et_443 fr.cs.sk_222
  0x531a2b02, 0x112d01a4, 0x35001c02, 0x08171008,   // vi.tl.ht_222 en.sk.ro_433  id.zu.un_220 be.sr.uk_443
  0x13003f13, 0x1b1c1eee, 0x12001f09, 0x2d1912a0,   // af.et.un_650 ms.id.tr_422  cy.hu.un_440 hu.gl.sk_322
  // [23c0]
  0x20001104, 0x08100a14, 0x0a000604, 0x6b0604a0,   // ro.sq.un_320 mk.be.uk_666  de.pt.un_320 fi.de.ceb_322
  0x52004a14, 0x3f006404, 0x281827ad, 0x180127ec,   // yo.ha.un_660 lg.af.un_320  gd.ga.sw_643 gd.en.ga_644
  0x23006e19, 0x041006a4, 0x090d13a4, 0x21002010,   // hmn.ca.un_750 de.lt.fi_433  bh.ne.hi_433 sq.jw.un_620
  0x1b2b250c, 0x101a040c, 0x07520ca0, 0x1708045a,   // eu.vi.tr_543 fi.tl.lt_543  sv.ha.it_322 ru.uk.sr_553
  // [23d0]
  0x23006e0c, 0x0b00250c, 0x1c553505, 0x02004a04,   // hmn.ca.un_530 eu.es.un_530  zu.rw.id_333 yo.da.un_320
  0x1b0e0307, 0x3f001705, 0x1f042014, 0x17164aa0,   // nl.is.tr_432 sr.af.un_330  sq.fi.cy_666 yo.hr.sr_322
  0x06183507, 0x07235207, 0x086e06ad, 0x04000104,   // zu.ga.de_432 ha.ca.it_432  de.hmn.no_643 en.fi.un_320
  0x32171aec, 0x2a130407, 0x06000804, 0x52001a23,   // tl.sr.bs_644 fi.et.mt_432  no.de.un_320 tl.ha.un_880
  // [23e0]
  0x2b070e08, 0x2a000713, 0x21000104, 0x1300310d,   // is.it.vi_443 it.mt.un_650  en.jw.un_320 az.et.un_540
  0x130812a4, 0x19002109, 0x11001704, 0x3b00060e,   // hu.no.et_433 jw.gl.un_440  sr.ro.un_320 de.so.un_550
  0x3b353105, 0x3f18275a, 0x1b3110a0, 0x3b002112,   // az.zu.so_333 gd.ga.af_553  lt.az.tr_322 jw.so.un_640
  0x6b001b12, 0x07170a0d, 0x0d292d07, 0x3f003504,   // tr.ceb.un_640 mk.sr.bg_554  sk.sl.cs_432 zu.af.un_320
  // [23f0]
  0x6b030107, 0x11133b07, 0x20000607, 0x0c002d04,   // en.nl.ceb_432 so.et.ro_432  de.sq.un_420 sk.sv.un_320
  0x1c130d09, 0x52553560, 0x1e003f19, 0x0d00100c,   // ne.bh.mr_444 zu.rw.ha_664  af.ms.un_750 lt.cs.un_530
  0x13006409, 0x290f2d0c, 0x3b002a19, 0x3b35530c,   // lg.et.un_440 sk.lv.sl_543  mt.so.un_750 ht.zu.so_543
  0x646b6809, 0x106b3b02, 0x170f20ee, 0x0a2d0d0e,   // ig.ceb.lg_444 so.ceb.lt_222  sq.lv.sr_422 cs.sk.pt_555

  // [2400]
  0x276b1a0c, 0x100a11a9, 0x01180504, 0x02081212,   // tl.ceb.gd_543 ro.mk.be_544  fr.ga.en_332 hu.no.da_654
  0x19002b0b, 0x52001f04, 0x08003205, 0x2d0d090e,   // vi.gl.un_520 cy.ha.un_320  bs.no.un_330 pl.cs.sk_555
  0x3f000107, 0x04035504, 0x172d2902, 0x35002505,   // en.af.un_420 rw.nl.fi_332  sl.sk.sr_222 eu.zu.un_330
  0x281801ee, 0x2019230c, 0x53001904, 0x090d010c,   // en.ga.sw_422 ca.gl.sq_543  gl.ht.un_320 en.cs.pl_543
  // [2410]
  0x311b0807, 0x3f032a0c, 0x3f0c080d, 0x28003507,   // no.tr.az_432 mt.nl.af_543  no.sv.af_554 zu.sw.un_420
  0x213f35a4, 0x68002d07, 0x352528a4, 0x1e2721a0,   // zu.af.jw_433 sk.ig.un_420  sw.eu.zu_433 jw.gd.ms_322
  0x1c09130b, 0x21181107, 0x11121b08, 0x190b0ea0,   // bh.hi.mr_542 ro.ga.jw_432  tr.hu.ro_443 is.es.gl_322
  0x3f000c02, 0x3b211ea0, 0x03023f05, 0x122d0a04,   // sv.af.un_220 ms.jw.so_322  af.da.nl_333 pt.sk.hu_332
  // [2420]
  0x20003b05, 0x0a001f0c, 0x0b190a04, 0x64033b0d,   // so.sq.un_330 cy.pt.un_530  pt.gl.es_332 so.nl.lg_554
  0x23190a0c, 0x1103130c, 0x28685207, 0x252835a6,   // pt.gl.ca_543 et.nl.ro_543  ha.ig.sw_432 zu.sw.eu_521
  0x32201702, 0x100f0811, 0x190a2d07, 0x02002102,   // sr.sq.bs_222 no.lv.lt_653  sk.pt.gl_432 jw.da.un_220
  0x1e1306ee, 0x13000e04, 0x322813ad, 0x2b000c07,   // de.et.ms_422 is.et.un_320  et.sw.bs_643 sv.vi.un_420
  // [2430]
  0x6428350d, 0x283525a9, 0x2d1b0d08, 0x0e00200c,   // zu.sw.lg_554 eu.zu.sw_544  cs.tr.sk_443 sq.is.un_530
  0x18000514, 0x2113180c, 0x293b0e04, 0x080213a4,   // fr.ga.un_660 ga.et.jw_543  is.so.sl_332 et.da.no_433
  0x190b25a0, 0x23000414, 0x4a3f2504, 0x27002105,   // eu.es.gl_322 fi.ca.un_660  eu.af.yo_332 jw.gd.un_330
  0x023b0407, 0x27006e0d, 0x190527ad, 0x3b20210b,   // fi.so.da_432 hmn.gd.un_540  gd.fr.gl_643 jw.sq.so_542
  // [2440]
  0x18000d0c, 0x1b00010d, 0x10001f0e, 0x521729a9,   // cs.ga.un_530 en.tr.un_540  cy.lt.un_550 sl.sr.ha_544
  0x645355a0, 0x0b002309, 0x35005207, 0x0c290da4,   // rw.ht.lg_322 ca.es.un_440  ha.zu.un_420 cs.sl.sv_433
  0x1e1c20ec, 0x0d0f5508, 0x55005212, 0x1100230c,   // sq.id.ms_644 rw.lv.cs_443  ha.rw.un_640 ca.ro.un_530
  0x0f000807, 0x0e004a1a, 0x1c00530b, 0x21001604,   // no.lv.un_420 yo.is.un_760  ht.id.un_520 hr.jw.un_320
  // [2450]
  0x0a08100d, 0x0b4a0555, 0x203b0607, 0x68002812,   // be.uk.mk_554 fr.yo.es_442  de.so.sq_432 sw.ig.un_640
  0x08001119, 0x185535a0, 0x23000a0d, 0x203f010c,   // ro.uk.un_750 zu.rw.ga_322  pt.ca.un_540 en.af.sq_543
  0x10060404, 0x25040604, 0x25005304, 0x025364ee,   // fi.de.lt_332 de.fi.eu_332  ht.eu.un_320 lg.ht.da_422
  0x28643b02, 0x2d0d0914, 0x25006402, 0x31000f18,   // so.lg.sw_222 pl.cs.sk_666  lg.eu.un_220 lv.az.un_740
  // [2460]
  0x4a001b07, 0x23111809, 0x2b005504, 0x04101704,   // tr.yo.un_420 ga.ro.ca_444  rw.vi.un_320 sr.be.ru_332
  0x04132aa0, 0x28181fa9, 0x2a001e04, 0x6b00011a,   // mt.et.fi_322 cy.ga.sw_544  ms.mt.un_320 en.ceb.un_760
  0x10001a07, 0x2025050d, 0x1f180607, 0x1f1b3fa4,   // tl.lt.un_420 fr.eu.sq_554  de.ga.cy_432 af.tr.cy_433
  0x1c006b04, 0x1e002102, 0x1f1809a4, 0x081704ec,   // ceb.id.un_320 jw.ms.un_220  pl.ga.cy_433 ru.sr.uk_644
  // [2470]
  0x21003523, 0x07000405, 0x01005504, 0x072a0405,   // zu.jw.un_880 ru.bg.un_330  rw.en.un_320 fi.mt.it_333
  0x4a001a0d, 0x2d0d31a0, 0x182709a7, 0x13090d14,   // tl.yo.un_540 az.cs.sk_322  pl.gd.ga_532 ne.hi.bh_666
  0x1000310e, 0x202321ec, 0x06000912, 0x13100fee,   // az.lt.un_550 jw.ca.sq_644  pl.de.un_640 lv.lt.et_422
  0x28090111, 0x3b001902, 0x321629a4, 0x0c3f080c,   // en.pl.sw_653 gl.so.un_220  sl.hr.bs_433 no.af.sv_543
  // [2480]
  0x0600040e, 0x283135a4, 0x1200350d, 0x1e006402,   // fi.de.un_550 zu.az.sw_433  zu.hu.un_540 lg.ms.un_220
  0x090a05a0, 0x19080507, 0x1f006e13, 0x12003511,   // fr.pt.pl_322 fr.no.gl_432  hmn.cy.un_650 zu.hu.un_630
  0x3528090d, 0x09041104, 0x0e000b04, 0x101f2504,   // pl.sw.zu_554 ro.fi.pl_332  es.is.un_320 eu.cy.lt_332
  0x28102507, 0x2a00180c, 0x09002a0c, 0x10000a19,   // eu.lt.sw_432 ga.mt.un_530  mt.pl.un_530 mk.be.un_750
  // [2490]
  0x5500640c, 0x4a002813, 0x08022a02, 0x07050112,   // lg.rw.un_530 sw.yo.un_650  mt.da.no_222 en.fr.it_654
  0x53004a0e, 0x131c090d, 0x55121104, 0x04171112,   // yo.ht.un_550 hi.mr.bh_554  ro.hu.rw_332 ro.sr.ru_654
  0x201c2105, 0x321752ee, 0x092504a4, 0x1e1121a4,   // jw.id.sq_333 ha.sr.bs_422  fi.eu.pl_433 jw.ro.ms_433
  0x05001f05, 0x1a004a05, 0x53006413, 0x060435a0,   // cy.fr.un_330 yo.tl.un_330  lg.ht.un_650 zu.fi.de_322
  // [24a0]
  0x04070a0e, 0x02133b05, 0x17003507, 0x0d002305,   // mk.bg.ru_555 so.et.da_333  zu.sr.un_420 ca.cs.un_330
  0x071105ee, 0x06000111, 0x210e0604, 0x03000209,   // fr.ro.it_422 en.de.un_630  de.is.jw_332 da.nl.un_440
  0x0d122d60, 0x285564a9, 0x230501a7, 0x1b4a1107,   // sk.hu.cs_664 lg.rw.sw_544  en.fr.ca_532 ro.yo.tr_432
  0x68006422, 0x0a002d07, 0x4a642104, 0x1b001a05,   // lg.ig.un_870 sk.pt.un_420  jw.lg.yo_332 tl.tr.un_330
  // [24b0]
  0x080204a4, 0x0f041355, 0x03086407, 0x08021fa4,   // fi.da.no_433 et.fi.lv_442  lg.no.nl_432 cy.da.no_433
  0x10000405, 0x0d004a04, 0x02033f08, 0x3f002502,   // ru.be.un_330 yo.cs.un_320  af.nl.da_443 eu.af.un_220
  0x2b2d3fa0, 0x11000d04, 0x19110bee, 0x1c282008,   // af.sk.vi_322 cs.ro.un_320  es.ro.gl_422 sq.sw.id_443
  0x19122dad, 0x2b006407, 0x1f3f2504, 0x111013ee,   // sk.hu.gl_643 lg.vi.un_420  eu.af.cy_332 et.lt.ro_422
  // [24c0]
  0x3b2864a4, 0x012711a0, 0x0a091107, 0x043b0804,   // lg.sw.so_433 ro.gd.en_322  ro.pl.pt_432 no.so.fi_332
  0x1f192d07, 0x13000f12, 0x35556b07, 0x216455a0,   // sk.gl.cy_432 lv.et.un_640  ceb.rw.zu_432 rw.lg.jw_322
  0x6423250c, 0x3b080e07, 0x1004130e, 0x2100010b,   // eu.ca.lg_543 is.no.so_432  et.fi.lt_555 en.jw.un_520
  0x062a5507, 0x09030404, 0x5200280e, 0x18130411,   // rw.mt.de_432 fi.nl.pl_332  sw.ha.un_550 fi.et.ga_653
  // [24d0]
  0x05001604, 0x2d0d1809, 0x4a5352a0, 0x28001214,   // hr.fr.un_320 ga.cs.sk_444  ha.ht.yo_322 hu.sw.un_660
  0x01100807, 0x05001902, 0x13102a02, 0x13030109,   // no.lt.en_432 gl.fr.un_220  mt.lt.et_222 en.nl.et_444
  0x232b25ad, 0x126b1a11, 0x065355ad, 0x322d1055,   // eu.vi.ca_643 tl.ceb.hu_653  rw.ht.de_643 lt.sk.bs_442
  0x3f002a08, 0x1b002502, 0x19002105, 0x03000912,   // mt.af.un_430 eu.tr.un_220  jw.gl.un_330 pl.nl.un_640
  // [24e0]
  0x2a132807, 0x6b000418, 0x170f1007, 0x23000702,   // sw.et.mt_432 fi.ceb.un_740  lt.lv.sr_432 it.ca.un_220
  0x27001108, 0x021a6e07, 0x1000130e, 0x020c080c,   // ro.gd.un_430 hmn.tl.da_432  et.lt.un_550 no.sv.da_543
  0x070a040c, 0x08060fa4, 0x550f4a55, 0x080f0608,   // ru.mk.bg_543 lv.de.no_433  yo.lv.rw_442 de.lv.no_443
  0x2a001304, 0x283b5304, 0x04002d0e, 0x04003f04,   // et.mt.un_320 ht.so.sw_332  sk.fi.un_550 af.fi.un_320
  // [24f0]
  0x52002811, 0x211a1c0c, 0x311b1a0b, 0x08170705,   // sw.ha.un_630 id.tl.jw_543  tl.tr.az_542 bg.sr.uk_333
  0x52002502, 0x13000804, 0x0a052ba9, 0x4a000705,   // eu.ha.un_220 no.et.un_320  vi.fr.pt_544 it.yo.un_330
  0x0c00061a, 0x1a3f0112, 0x554a680d, 0x0c296bee,   // de.sv.un_760 en.af.tl_654  ig.yo.rw_554 ceb.sl.sv_422
  0x190b07a4, 0x05080107, 0x1e1c35ee, 0x09160804,   // it.es.gl_433 en.no.fr_432  zu.id.ms_422 no.hr.pl_332
  // [2500]
  0x12001308, 0x1b1228a0, 0x2527040c, 0x52053ba0,   // et.hu.un_430 sw.hu.tr_322  fi.gd.eu_543 so.fr.ha_322
  0x113525a9, 0x00003b1c, 0x070a0807, 0x0b0a2da0,   // eu.zu.ro_544 so.un.un_800  uk.mk.bg_432 sk.pt.es_322
  0x321629a0, 0x04005205, 0x130d090c, 0x1600200b,   // sl.hr.bs_322 ha.fi.un_330  hi.ne.bh_543 sq.hr.un_520
  0x1306040c, 0x0a005307, 0x3f00230e, 0x0e003513,   // fi.de.et_543 ht.pt.un_420  ca.af.un_550 zu.is.un_650
  // [2510]
  0x233153a0, 0x0f3f03ec, 0x20003f08, 0x3b000614,   // ht.az.ca_322 nl.af.lv_644  af.sq.un_430 de.so.un_660
  0x11000f04, 0x3f0c08a4, 0x01062008, 0x530425a4,   // lv.ro.un_320 no.sv.af_433  sq.de.en_443 eu.fi.ht_433
  0x08001e04, 0x3f0c0605, 0x0e6406a7, 0x033f2507,   // ms.no.un_320 de.sv.af_333  de.lg.is_532 eu.af.nl_432
  0x17001607, 0x100f2aad, 0x203f08ee, 0x2d00200c,   // hr.sr.un_420 mt.lv.lt_643  no.af.sq_422 sq.sk.un_530
  // [2520]
  0x1f3b4a5a, 0x190b07ee, 0x28550507, 0x202a29a0,   // yo.so.cy_553 it.es.gl_422  fr.rw.sw_432 sl.mt.sq_322
  0x0c0601ee, 0x643b55ee, 0x25000305, 0x233b29a9,   // en.de.sv_422 rw.so.lg_422  nl.eu.un_330 sl.so.ca_544
  0x55003f14, 0x04001812, 0x0306010c, 0x084a01ee,   // af.rw.un_660 ga.fi.un_640  en.de.nl_543 en.yo.no_422
  0x2a322912, 0x35080208, 0x080e0204, 0x0f002511,   // sl.bs.mt_654 da.no.zu_443  da.is.no_332 eu.lv.un_630
  // [2530]
  0x0b001a09, 0x2864550d, 0x04100811, 0x0b190a0d,   // tl.es.un_440 rw.lg.sw_554  uk.be.ru_653 pt.gl.es_554
  0x216404a0, 0x27000705, 0x01000c07, 0x1f191b55,   // fi.lg.jw_322 it.gd.un_330  sv.en.un_420 tr.gl.cy_442
  0x5500640e, 0x3b002305, 0x12002905, 0x04000513,   // lg.rw.un_550 ca.so.un_330  sl.hu.un_330 fr.fi.un_650
  0x64003509, 0x190b0d05, 0x11550fee, 0x19000b14,   // zu.lg.un_440 cs.es.gl_333  lv.rw.ro_422 es.gl.un_660
  // [2540]
  0x07201804, 0x120d0705, 0x52002005, 0x061f5207,   // ga.sq.it_332 it.cs.hu_333  sq.ha.un_330 ha.cy.de_432
  0x201610ad, 0x32170c02, 0x07003f04, 0x1f1a13a0,   // lt.hr.sq_643 sv.sr.bs_222  af.it.un_320 et.tl.cy_322
  0x3f280308, 0x1704070e, 0x28001a08, 0x3f6b1a07,   // nl.sw.af_443 bg.ru.sr_555  tl.sw.un_430 tl.ceb.af_432
  0x160729a0, 0x28001e13, 0x12001804, 0x1b001a02,   // sl.it.hr_322 ms.sw.un_650  ga.hu.un_320 tl.tr.un_220
  // [2550]
  0x07001213, 0x321631a0, 0x3f00200c, 0x040e0804,   // hu.it.un_650 az.hr.bs_322  sq.af.un_530 no.is.fi_332
  0x04522107, 0x03283f0c, 0x190a11a0, 0x1309040e,   // jw.ha.fi_432 af.sw.nl_543  ro.pt.gl_322 fi.pl.et_555
  0x23001c02, 0x290a11a4, 0x3b006407, 0x3b005208,   // id.ca.un_220 ro.pt.sl_433  lg.so.un_420 ha.so.un_430
  0x03000704, 0x2a0e08ad, 0x045525ee, 0x1c000c04,   // it.nl.un_320 no.is.mt_643  eu.rw.fi_422 sv.id.un_320
  // [2560]
  0x0f101104, 0x3f001c04, 0x080c0eac, 0x64002d04,   // ro.lt.lv_332 id.af.un_320  is.sv.no_632 sk.lg.un_320
  0x1c00280d, 0x11120907, 0x091a13ee, 0x091c13a7,   // sw.id.un_540 pl.hu.ro_432  et.tl.pl_422 bh.mr.hi_532
  0x191023ad, 0x13001b13, 0x3b6435a4, 0x00000101,   // ca.lt.gl_643 tr.et.un_650  zu.lg.so_433 en.un.un_200
  0x071104a0, 0x291608ee, 0x2100350c, 0x190b050e,   // fi.ro.it_322 no.hr.sl_422  zu.jw.un_530 fr.es.gl_555
  // [2570]
  0x131b3ba0, 0x21006e07, 0x21003f04, 0x13001f1a,   // so.tr.et_322 hmn.jw.un_420  af.jw.un_320 cy.et.un_760
  0x18201b12, 0x0500350c, 0x53000a02, 0x281f3f04,   // tr.sq.ga_654 zu.fr.un_530  pt.ht.un_220 af.cy.sw_332
  0x684a250c, 0x1f005205, 0x2b0e35ec, 0x18235207,   // eu.yo.ig_543 ha.cy.un_330  zu.is.vi_644 ha.ca.ga_432
  0x04536408, 0x161b2807, 0x01233f07, 0x1e1a1f07,   // lg.ht.fi_443 sw.tr.hr_432  af.ca.en_432 cy.tl.ms_432
  // [2580]
  0x1e1c21ec, 0x17001122, 0x3f002802, 0x28012bee,   // jw.id.ms_644 ro.sr.un_870  sw.af.un_220 vi.en.sw_422
  0x016820a4, 0x10203504, 0x6855280c, 0x21001b05,   // sq.ig.en_433 zu.sq.lt_332  sw.rw.ig_543 tr.jw.un_330
  0x190b0502, 0x3b00180d, 0x644a07a4, 0x23001811,   // fr.es.gl_222 ga.so.un_540  it.yo.lg_433 ga.ca.un_630
  0x10130f12, 0x0f00101b, 0x09002d08, 0x550c085a,   // lv.et.lt_654 lt.lv.un_770  sk.pl.un_430 no.sv.rw_553
  // [2590]
  0x186b08a0, 0x643b3507, 0x12091109, 0x4a556813,   // no.ceb.ga_322 zu.so.lg_432  ro.pl.hu_444 ig.rw.yo_665
  0x016b3b07, 0x08110407, 0x16210e04, 0x6b3b1b55,   // so.ceb.en_432 ru.ro.uk_432  is.jw.hr_332 tr.so.ceb_442
  0x2d0d18af, 0x08041011, 0x0e001a14, 0x35311b14,   // ga.cs.sk_655 be.ru.uk_653  tl.is.un_660 tr.az.zu_666
  0x082d0c07, 0x214a5507, 0x1e1c0fee, 0x2855010b,   // sv.sk.no_432 rw.yo.jw_432  lv.id.ms_422 en.rw.sw_542
  // [25a0]
  0x10002008, 0x311b3b07, 0x6b1a1007, 0x353155ec,   // sq.lt.un_430 so.tr.az_432  lt.tl.ceb_432 rw.az.zu_644
  0x030408a4, 0x0b2328a7, 0x13002913, 0x1a1113a0,   // no.fi.nl_433 sw.ca.es_532  sl.et.un_650 et.ro.tl_322
  0x05000702, 0x3f1311ec, 0x53002b14, 0x0d2018a0,   // it.fr.un_220 ro.et.af_644  vi.ht.un_660 ga.sq.cs_322
  0x08071011, 0x2d291107, 0x3100230d, 0x3b1b5504,   // be.bg.uk_653 ro.sl.sk_432  ca.az.un_540 rw.tr.so_332
  // [25b0]
  0x040a1755, 0x351f1a05, 0x0200210d, 0x4a3f68a4,   // sr.mk.ru_442 tl.cy.zu_333  jw.da.un_540 ig.af.yo_433
  0x1f130807, 0x042a130c, 0x21002904, 0x27005302,   // no.et.cy_432 et.mt.fi_543  sl.jw.un_320 ht.gd.un_220
  0x2a005212, 0x0d000c04, 0x013b2ba7, 0x1f520404,   // ha.mt.un_640 sv.cs.un_320  vi.so.en_532 fi.ha.cy_332
  0x3b001a0e, 0x130f28ee, 0x1e1c21a4, 0x3b0f1a04,   // tl.so.un_550 sw.lv.et_422  jw.id.ms_433 tl.lv.so_332
  // [25c0]
  0x08001e02, 0x64135511, 0x2a313507, 0x07080a04,   // ms.no.un_220 rw.et.lg_653  zu.az.mt_432 mk.uk.bg_332
  0x043f3bee, 0x05020107, 0x0b0a0805, 0x4a005202,   // so.af.fi_422 en.da.fr_432  no.pt.es_333 ha.yo.un_220
  0x2a0c020c, 0x356428a7, 0x53000302, 0x5535285a,   // da.sv.mt_543 sw.lg.zu_532  nl.ht.un_220 sw.zu.rw_553
  0x06000813, 0x182d0d0d, 0x1e6e1faf, 0x232d1ba0,   // no.de.un_650 cs.sk.ga_554  cy.hmn.ms_655 tr.sk.ca_322
  // [25d0]
  0x02080c55, 0x033f2704, 0x0400550d, 0x04111312,   // sv.no.da_442 gd.af.nl_332  rw.fi.un_540 et.ro.fi_654
  0x0f005207, 0x09005505, 0x231335a7, 0x081117a4,   // ha.lv.un_420 rw.pl.un_330  zu.et.ca_532 sr.ro.uk_433
  0x0c06030c, 0x1e1c210c, 0x04290e0d, 0x1c160407,   // nl.de.sv_543 jw.id.ms_543  is.sl.fi_554 fi.hr.id_432
  0x645528a4, 0x04250f05, 0x0b00070c, 0x046810af,   // sw.rw.lg_433 lv.eu.fi_333  it.es.un_530 lt.ig.fi_655
  // [25e0]
  0x522104ad, 0x643f0655, 0x313b2aad, 0x28201108,   // fi.jw.ha_643 de.af.lg_442  mt.so.az_643 ro.sq.sw_443
  0x4a2835a9, 0x35000613, 0x123f13a0, 0x285311a9,   // zu.sw.yo_544 de.zu.un_650  et.af.hu_322 ro.ht.sw_544
  0x2d0e11a0, 0x033f27a4, 0x18000304, 0x35282aec,   // ro.is.sk_322 gd.af.nl_433  nl.ga.un_320 mt.sw.zu_644
  0x0a000405, 0x25112005, 0x280e200c, 0x16000f04,   // ru.mk.un_330 sq.ro.eu_333  sq.is.sw_543 lv.hr.un_320
  // [25f0]
  0x35001a0b, 0x20522807, 0x642a0705, 0x64255504,   // tl.zu.un_520 sw.ha.sq_432  it.mt.lg_333 rw.eu.lg_332
  0x2d0a180c, 0x292508ee, 0x3b251908, 0x3f00121b,   // ga.pt.sk_543 no.eu.sl_422  gl.eu.so_443 hu.af.un_770
  0x02001a02, 0x180a11a4, 0x351a1c04, 0x0f005513,   // tl.da.un_220 ro.pt.ga_433  id.tl.zu_332 rw.lv.un_650
  0x53006421, 0x1c213f12, 0x31355207, 0x10001709,   // lg.ht.un_860 af.jw.id_654  ha.zu.az_432 sr.lt.un_440
  // [2600]
  0x12292104, 0x230704ad, 0x0d132807, 0x2101130c,   // jw.sl.hu_332 fi.it.ca_643  sw.et.cs_432 et.en.jw_543
  0x4a5253a0, 0x3f001312, 0x52533fa6, 0x0d092d0d,   // ht.ha.yo_322 et.af.un_640  af.ht.ha_521 sk.pl.cs_554
  0x3b312008, 0x23000211, 0x0e002012, 0x3f000a04,   // sq.az.so_443 da.ca.un_630  sq.is.un_640 pt.af.un_320
  0x531a6ba4, 0x033f06ad, 0x0813110c, 0x3b001c08,   // ceb.tl.ht_433 de.af.nl_643  ro.et.no_543 id.so.un_430
  // [2610]
  0x29002507, 0x25123fee, 0x232b11ad, 0x23112b55,   // eu.sl.un_420 af.hu.eu_422  ro.vi.ca_643 vi.ro.ca_442
  0x25003f08, 0x1f3b0702, 0x01001104, 0x353b2104,   // af.eu.un_430 it.so.cy_222  ro.en.un_320 jw.so.zu_332
  0x16000f16, 0x313f03a4, 0x18022302, 0x23112b05,   // lv.hr.un_720 nl.af.az_433  ca.da.ga_222 vi.ro.ca_333
  0x19000504, 0x086b0c08, 0x2d022b07, 0x101705a4,   // fr.gl.un_320 sv.ceb.no_443  vi.da.sk_432 fr.sr.lt_433
  // [2620]
  0x0b0c0607, 0x0f1705ee, 0x213210a4, 0x10002505,   // de.sv.es_432 fr.sr.lv_422  lt.bs.jw_433 eu.lt.un_330
  0x1c090d07, 0x3f6e030b, 0x17000718, 0x0f001609,   // ne.hi.mr_432 nl.hmn.af_542  bg.sr.un_740 hr.lv.un_440
  0x04000908, 0x210c6b04, 0x271b18af, 0x55003518,   // pl.fi.un_430 ceb.sv.jw_332  ga.tr.gd_655 zu.rw.un_740
  0x2400010e, 0x6e000309, 0x04001711, 0x0e001702,   // iw.yi.un_550 nl.hmn.un_440  sr.ru.un_630 sr.is.un_220
  // [2630]
  0x0300250b, 0x2932170c, 0x0e3b6404, 0x10041105,   // eu.nl.un_520 sr.bs.sl_543  lg.so.is_332 ro.ru.be_333
  0x31000c04, 0x191b0da0, 0x07011ea0, 0x23004a02,   // sv.az.un_320 cs.tr.gl_322  ms.en.it_322 yo.ca.un_220
  0x4a1823b3, 0x1f006809, 0x35001f09, 0x0300120c,   // ca.ga.yo_743 ig.cy.un_440  cy.zu.un_440 hu.nl.un_530
  0x084a1f07, 0x52005509, 0x11000113, 0x55000304,   // cy.yo.no_432 rw.ha.un_440  en.ro.un_650 nl.rw.un_320
  // [2640]
  0x17001104, 0x07170aa9, 0x640825a4, 0x0d000e02,   // ro.sr.un_320 mk.sr.bg_544  eu.no.lg_433 is.cs.un_220
  0x2a200307, 0x2a0c0e07, 0x1f000d0d, 0x073101a4,   // nl.sq.mt_432 is.sv.mt_432  cs.cy.un_540 en.az.it_433
  0x18001e05, 0x1c006807, 0x29081ba4, 0x023f08a6,   // ms.ga.un_330 ig.id.un_420  tr.no.sl_433 no.af.da_521
  0x010c0812, 0x1c090d5a, 0x0c002008, 0x19100f04,   // no.sv.en_654 ne.hi.mr_553  sq.sv.un_430 lv.lt.gl_332
  // [2650]
  0x21310107, 0x253f3b0c, 0x10002907, 0x10000d19,   // en.az.jw_432 so.af.eu_543  sl.lt.un_420 cs.lt.un_750
  0x2b006b04, 0x2a005209, 0x355564a6, 0x09002804,   // ceb.vi.un_320 ha.mt.un_440  lg.rw.zu_521 sw.pl.un_320
  0x0802050c, 0x3516250c, 0x10000a07, 0x171108a4,   // fr.da.no_543 eu.hr.zu_543  mk.be.un_420 uk.ro.sr_433
  0x093f0c0e, 0x08040aad, 0x316b20ee, 0x0910045a,   // sv.af.pl_555 mk.ru.uk_643  sq.ceb.az_422 fi.lt.pl_553
  // [2660]
  0x1b003504, 0x01001e02, 0x522103a0, 0x09000402,   // zu.tr.un_320 ms.en.un_220  nl.jw.ha_322 fi.pl.un_220
  0x642835a4, 0x6b001604, 0x28060307, 0x53000e04,   // zu.sw.lg_433 hr.ceb.un_320  nl.de.sw_432 is.ht.un_320
  0x12103109, 0x55533504, 0x18000e18, 0x03005207,   // az.lt.hu_444 zu.ht.rw_332  is.ga.un_740 ha.nl.un_420
  0x136428ac, 0x18122d04, 0x52095502, 0x0c080e0d,   // sw.lg.et_632 sk.hu.ga_332  rw.pl.ha_222 is.no.sv_554
  // [2670]
  0x10000104, 0x4a001218, 0x08063ba7, 0x282029a4,   // en.lt.un_320 hu.yo.un_740  so.de.no_532 sl.sq.sw_433
  0x01000307, 0x55354a11, 0x28215202, 0x4a083fad,   // nl.en.un_420 yo.zu.rw_653  ha.jw.sw_222 af.no.yo_643
  0x23002107, 0x3500060e, 0x29062508, 0x3b1e1c08,   // jw.ca.un_420 de.zu.un_550  eu.de.sl_443 id.ms.so_443
  0x6b1964a4, 0x10000704, 0x0a0708a4, 0x2a290daf,   // lg.gl.ceb_433 bg.be.un_320  uk.bg.mk_433 cs.sl.mt_655
  // [2680]
  0x3f0304a7, 0x20001111, 0x190b1207, 0x0b0a3ba0,   // fi.nl.af_532 ro.sq.un_630  hu.es.gl_432 so.pt.es_322
  0x3b004a0d, 0x52640f0b, 0x01530c0b, 0x64521a08,   // yo.so.un_540 lv.lg.ha_542  sv.ht.en_542 tl.ha.lg_443
  0x3b3f0313, 0x08002304, 0x0b0a01a4, 0x20001904,   // nl.af.so_665 ca.no.un_320  en.pt.es_433 gl.sq.un_320
  0x11001314, 0x01002a02, 0x20230555, 0x0a001014,   // et.ro.un_660 mt.en.un_220  fr.ca.sq_442 be.mk.un_660
  // [2690]
  0x4a033fad, 0x17165302, 0x17000608, 0x2d0d13af,   // af.nl.yo_643 ht.hr.sr_222  de.sr.un_430 et.cs.sk_655
  0x2300200e, 0x354a6404, 0x20002d04, 0x1e211c04,   // sq.ca.un_550 lg.yo.zu_332  sk.sq.un_320 id.jw.ms_332
  0x5305230c, 0x1b002012, 0x080206a9, 0x113f0e04,   // ca.fr.ht_543 sq.tr.un_640  de.da.no_544 is.af.ro_332
  0x02080555, 0x64005304, 0x01001004, 0x1a000704,   // fr.no.da_442 ht.lg.un_320  lt.en.un_320 it.tl.un_320
  // [26a0]
  0x080205ec, 0x282a2905, 0x1c251e04, 0x20120e0e,   // fr.da.no_644 sl.mt.sw_333  ms.eu.id_332 is.hu.sq_555
  0x2d120e05, 0x03253fa0, 0x35134a07, 0x271e1c07,   // is.hu.sk_333 af.eu.nl_322  yo.et.zu_432 id.ms.gd_432
  0x64033f0c, 0x171629a9, 0x27001e0d, 0x192a0aad,   // af.nl.lg_543 sl.hr.sr_544  ms.gd.un_540 pt.mt.gl_643
  0x1b0f20ad, 0x0d003202, 0x1200250b, 0x080c3b55,   // sq.lv.tr_643 bs.cs.un_220  eu.hu.un_520 so.sv.no_442
  // [26b0]
  0x1c000804, 0x0600010c, 0x4a212007, 0x1c4a6b04,   // no.id.un_320 en.de.un_530  sq.jw.yo_432 ceb.yo.id_332
  0x212864ad, 0x6b2301ad, 0x13042da4, 0x6e1835ee,   // lg.sw.jw_643 en.ca.ceb_643  sk.fi.et_433 zu.ga.hmn_422
  0x182d0d05, 0x271f1807, 0x1e1c3ba0, 0x1300070c,   // cs.sk.ga_333 ga.cy.gd_432  so.id.ms_322 it.et.un_530
  0x274a07a0, 0x182d0107, 0x551a6b12, 0x216b1aa0,   // it.yo.gd_322 en.sk.ga_432  ceb.tl.rw_654 tl.ceb.jw_322
  // [26c0]
  0x1a002b12, 0x1c003b07, 0x25002a04, 0x52023ba4,   // vi.tl.un_640 so.id.un_420  mt.eu.un_320 so.da.ha_433
  0x20002d0d, 0x35001819, 0x016b110c, 0x03041312,   // sk.sq.un_540 ga.zu.un_750  ro.ceb.en_543 et.fi.nl_654
  0x320701a4, 0x0b000a0c, 0x27186bee, 0x13070305,   // en.it.bs_433 pt.es.un_530  ceb.ga.gd_422 nl.it.et_333
  0x05214a04, 0x214a13a6, 0x126b27a0, 0x10040612,   // yo.jw.fr_332 et.yo.jw_521  gd.ceb.hu_322 de.fi.lt_654
  // [26d0]
  0x04212502, 0x0e120407, 0x18002d08, 0x21004a07,   // eu.jw.fi_222 fi.hu.is_432  sk.ga.un_430 yo.jw.un_420
  0x06001908, 0x3f000407, 0x64553507, 0x0f002a12,   // gl.de.un_430 fi.af.un_420  zu.rw.lg_432 mt.lv.un_640
  0x081107a4, 0x31130612, 0x190a05a0, 0x041b0802,   // bg.ro.uk_433 de.et.az_654  fr.pt.gl_322 no.tr.fi_222
  0x2d0d0509, 0x120d2807, 0x17201207, 0x190b2302,   // fr.cs.sk_444 sw.cs.hu_432  hu.sq.sr_432 ca.es.gl_222
  // [26e0]
  0x23000308, 0x2000350e, 0x0f001213, 0x02000e07,   // nl.ca.un_430 zu.sq.un_550  hu.lv.un_650 is.da.un_420
  0x3b082a02, 0x233f030d, 0x075564a4, 0x12680107,   // mt.no.so_222 nl.af.ca_554  lg.rw.it_433 en.ig.hu_432
  0x17000402, 0x0a0f1102, 0x201c28ee, 0x283b27a0,   // ru.sr.un_220 ro.lv.pt_222  sw.id.sq_422 gd.so.sw_322
  0x2d0d12ed, 0x08023bee, 0x640d28ee, 0x122a1fee,   // hu.cs.sk_622 so.da.no_422  sw.cs.lg_422 cy.mt.hu_422
  // [26f0]
  0x040a08a4, 0x0c3f1a02, 0x1e213f04, 0x0a0f1208,   // uk.mk.ru_433 tl.af.sv_222  af.jw.ms_332 hu.lv.pt_443
  0x10041305, 0x11001214, 0x010c0504, 0x1b000c0b,   // et.fi.lt_333 hu.ro.un_660  fr.sv.en_332 sv.tr.un_520
  0x2a000104, 0x0a005504, 0x20020ca4, 0x21041b07,   // en.mt.un_320 rw.pt.un_320  sv.da.sq_433 tr.fi.jw_432
  0x6b1a2112, 0x026b35a0, 0x02350813, 0x643568ad,   // jw.tl.ceb_654 zu.ceb.da_322  no.zu.da_665 ig.zu.lg_643
  // [2700]
  0x3b003512, 0x0c254a04, 0x033f23a7, 0x033b3f09,   // zu.so.un_640 yo.eu.sv_332  ca.af.nl_532 af.so.nl_444
  0x35002d08, 0x256435ad, 0x23052104, 0x13002a02,   // sk.zu.un_430 zu.lg.eu_643  jw.fr.ca_332 mt.et.un_220
  0x3b284a0c, 0x111908ee, 0x53230504, 0x2b002102,   // yo.sw.so_543 no.gl.ro_422  fr.ca.ht_332 jw.vi.un_220
  0x2b000708, 0x0f000e04, 0x27002d08, 0x126b1a0c,   // it.vi.un_430 is.lv.un_320  sk.gd.un_430 tl.ceb.hu_543
  // [2710]
  0x29003207, 0x3f080408, 0x532705a7, 0x6b3b320d,   // bs.sl.un_420 fi.no.af_443  fr.gd.ht_532 bs.so.ceb_554
  0x171107a4, 0x203519ee, 0x2d001302, 0x0b0a1fa0,   // bg.ro.sr_433 gl.zu.sq_422  et.sk.un_220 cy.pt.es_322
  0x55001f02, 0x28002b0b, 0x201f0ea9, 0x4a002d0d,   // cy.rw.un_220 vi.sw.un_520  is.cy.sq_544 sk.yo.un_540
  0x13080e0c, 0x080225a0, 0x52173b04, 0x3f001e02,   // is.no.et_543 eu.da.no_322  so.sr.ha_332 ms.af.un_220
  // [2720]
  0x25200e07, 0x1a00280d, 0x132d0da0, 0x131a6b13,   // is.sq.eu_432 sw.tl.un_540  cs.sk.et_322 ceb.tl.et_665
  0x2b192307, 0x32642808, 0x120613a0, 0x120c1bad,   // ca.gl.vi_432 sw.lg.bs_443  et.de.hu_322 tr.sv.hu_643
  0x0d122dad, 0x3216290b, 0x120d09a4, 0x2d6425a0,   // sk.hu.cs_643 sl.hr.bs_542  pl.cs.hu_433 eu.lg.sk_322
  0x21001f0d, 0x190b31a4, 0x06051304, 0x21355355,   // cy.jw.un_540 az.es.gl_433  et.fr.de_332 ht.zu.jw_442
  // [2730]
  0x0c001f12, 0x28101112, 0x12040604, 0x206b1a0c,   // cy.sv.un_640 ro.lt.sw_654  de.fi.hu_332 tl.ceb.sq_543
  0x10281107, 0x313f07a9, 0x6468355a, 0x53001704,   // ro.sw.lt_432 it.af.az_544  zu.ig.lg_553 sr.ht.un_320
  0x17001f04, 0x0407080c, 0x31281b14, 0x0b006b08,   // cy.sr.un_320 uk.bg.ru_543  tr.sw.az_666 ceb.es.un_430
  0x35002007, 0x010a2da0, 0x131b1aa0, 0x213f25ee,   // sq.zu.un_420 sk.pt.en_322  tl.tr.et_322 eu.af.jw_422
  // [2740]
  0x210b05a6, 0x091310ee, 0x1a212004, 0x1b101355,   // fr.es.jw_521 lt.et.pl_422  sq.jw.tl_332 et.lt.tr_442
  0x531903a0, 0x016b3fee, 0x3f0306a7, 0x3105350c,   // nl.gl.ht_322 af.ceb.en_422  de.nl.af_532 zu.fr.az_543
  0x311b2007, 0x2d0d12ac, 0x1a006402, 0x31101b55,   // sq.tr.az_432 hu.cs.sk_632  lg.tl.un_220 tr.lt.az_442
  0x2d091205, 0x1f000e04, 0x1c0720a4, 0x12053bac,   // hu.pl.sk_333 is.cy.un_320  sq.it.id_433 so.fr.hu_632
  // [2750]
  0x532b2807, 0x031c28ee, 0x051b080c, 0x53000418,   // sw.vi.ht_432 sw.id.nl_422  no.tr.fr_543 fi.ht.un_740
  0x520635ad, 0x1800060e, 0x6b0e1a12, 0x2500351a,   // zu.de.ha_643 de.ga.un_550  tl.is.ceb_654 zu.eu.un_760
  0x6b0e1aec, 0x13042507, 0x52002121, 0x3b64200c,   // tl.is.ceb_644 eu.fi.et_432  jw.ha.un_860 sq.lg.so_543
  0x0c190b08, 0x19230b07, 0x2d120dad, 0x13310407,   // es.gl.sv_443 es.ca.gl_432  cs.hu.sk_643 fi.az.et_432
  // [2760]
  0x01352007, 0x29001f18, 0x35552812, 0x3b0d3fa0,   // sq.zu.en_432 cy.sl.un_740  sw.rw.zu_654 af.cs.so_322
  0x3f2111a9, 0x04123509, 0x55112007, 0x122d0408,   // ro.jw.af_544 zu.hu.fi_444  sq.ro.rw_432 fi.sk.hu_443
  0x6b3b1a12, 0x08031104, 0x07002d07, 0x53002a04,   // tl.so.ceb_654 ro.nl.no_332  sk.it.un_420 mt.ht.un_320
  0x056e2007, 0x18000b04, 0x0c003f07, 0x6b521a14,   // sq.hmn.fr_432 es.ga.un_320  af.sv.un_420 tl.ha.ceb_666
  // [2770]
  0x08070aaf, 0x1e1c55a0, 0x07002305, 0x4a230708,   // mk.bg.uk_655 rw.id.ms_322  ca.it.un_330 it.ca.yo_443
  0x292d1108, 0x3f003b0d, 0x0f00040c, 0x2d0d05ec,   // ro.sk.sl_443 so.af.un_540  fi.lv.un_530 fr.cs.sk_644
  0x13041aa0, 0x1000640c, 0x3b356404, 0x2a213fad,   // tl.fi.et_322 lg.lt.un_530  lg.zu.so_332 af.jw.mt_643
  0x17000905, 0x3200520c, 0x112520ad, 0x55002d07,   // pl.sr.un_330 ha.bs.un_530  sq.eu.ro_643 sk.rw.un_420
  // [2780]
  0x3b001a07, 0x3f3b03af, 0x53680107, 0x16001b07,   // tl.so.un_420 nl.so.af_655  en.ig.ht_432 tr.hr.un_420
  0x161f2aa4, 0x0e640a04, 0x1b31040c, 0x23053f04,   // mt.cy.hr_433 pt.lg.is_332  fi.az.tr_543 af.fr.ca_332
  0x05003f07, 0x08021105, 0x4a00270c, 0x10530f07,   // af.fr.un_420 ro.da.no_333  gd.yo.un_530 lv.ht.lt_432
  0x1200080c, 0x28002502, 0x091f18af, 0x3b4a53ac,   // no.hu.un_530 eu.sw.un_220  ga.cy.pl_655 ht.yo.so_632
  // [2790]
  0x4a1235a4, 0x28005507, 0x6b2d0dad, 0x250c04a0,   // zu.hu.yo_433 rw.sw.un_420  cs.sk.ceb_643 fi.sv.eu_322
  0x1c521e04, 0x06010507, 0x0d2d290b, 0x3b0364a7,   // ms.ha.id_332 fr.en.de_432  sl.sk.cs_542 lg.nl.so_532
  0x0c002504, 0x04000312, 0x12080aa7, 0x211c2aa0,   // eu.sv.un_320 nl.fi.un_640  pt.no.hu_532 mt.id.jw_322
  0x64040c08, 0x04006b0c, 0x05002012, 0x2d0d12ec,   // sv.fi.lg_443 ceb.fi.un_530  sq.fr.un_640 hu.cs.sk_644
  // [27a0]
  0x12002504, 0x04021ba0, 0x1b646b04, 0x18005204,   // eu.hu.un_320 tr.da.fi_322  ceb.lg.tr_332 ha.ga.un_320
  0x20230aa7, 0x033f01af, 0x02000e11, 0x32002004,   // pt.ca.sq_532 en.af.nl_655  is.da.un_630 sq.bs.un_320
  0x12005302, 0x18041fa7, 0x0a000407, 0x3f020e0c,   // ht.hu.un_220 cy.fi.ga_532  ru.mk.un_420 is.da.af_543
  0x1c002012, 0x081b0ea7, 0x0b121812, 0x0c53010b,   // sq.id.un_640 is.tr.no_532  ga.hu.es_654 en.ht.sv_542
  // [27b0]
  0x64001113, 0x28003b09, 0x31020811, 0x162d01ee,   // ro.lg.un_650 so.sw.un_440  no.da.az_653 en.sk.hr_422
  0x64001a12, 0x0c001211, 0x68002b0e, 0x6b00010c,   // tl.lg.un_640 hu.sv.un_630  vi.ig.un_550 en.ceb.un_530
  0x07111055, 0x4a002b0c, 0x280118a0, 0x1c0d09ec,   // be.ro.bg_442 vi.yo.un_530  ga.en.sw_322 hi.ne.mr_644
  0x21006402, 0x09005311, 0x05000a07, 0x6b2a3b07,   // lg.jw.un_220 ht.pl.un_630  pt.fr.un_420 so.mt.ceb_432
  // [27c0]
  0x0b120508, 0x0d1c0908, 0x64101a5a, 0x1e313b11,   // fr.hu.es_443 hi.mr.ne_443  tl.lt.lg_553 so.az.ms_653
  0x08645508, 0x1e1c01ee, 0x13002013, 0x13090dee,   // rw.lg.no_443 en.id.ms_422  sq.et.un_650 ne.hi.bh_422
  0x131c09a4, 0x16006b02, 0x552864ad, 0x06230a0c,   // hi.mr.bh_433 ceb.hr.un_220  lg.sw.rw_643 pt.ca.de_543
  0x023f13ec, 0x07002102, 0x12000a0c, 0x020c13a0,   // et.af.da_644 jw.it.un_220  pt.hu.un_530 et.sv.da_322
  // [27d0]
  0x091c13a9, 0x184a27ad, 0x10003f13, 0x0a110408,   // bh.mr.hi_544 gd.yo.ga_643  af.lt.un_650 ru.ro.mk_443
  0x526b1b55, 0x23002d08, 0x31552508, 0x13000d07,   // tr.ceb.ha_442 sk.ca.un_430  eu.rw.az_443 ne.bh.un_420
  0x21001e02, 0x320f1012, 0x4a003112, 0x130c0411,   // ms.jw.un_220 lt.lv.bs_654  az.yo.un_640 fi.sv.et_653
  0x18000f19, 0x111f2512, 0x1f5521ad, 0x23000d08,   // lv.ga.un_750 eu.cy.ro_654  jw.rw.cy_643 cs.ca.un_430
  // [27e0]
  0x0d2d12a9, 0x253f03a4, 0x200f1b07, 0x556801ee,   // hu.sk.cs_544 nl.af.eu_433  tr.lv.sq_432 en.ig.rw_422
  0x271811a4, 0x0d2d2104, 0x172901a4, 0x6b001108,   // ro.ga.gd_433 jw.sk.cs_332  en.sl.sr_433 ro.ceb.un_430
  0x55000112, 0x03023fa7, 0x04252dec, 0x0c00020e,   // en.rw.un_640 af.da.nl_532  sk.eu.fi_644 da.sv.un_550
  0x4a00351a, 0x4a2520ee, 0x0804170e, 0x01003202,   // zu.yo.un_760 sq.eu.yo_422  sr.ru.uk_555 bs.en.un_220
  // [27f0]
  0x311b2004, 0x206b1aa4, 0x2a285504, 0x200c12af,   // sq.tr.az_332 tl.ceb.sq_433  rw.sw.mt_332 hu.sv.sq_655
  0x2a071312, 0x0f2028ad, 0x0d091ca0, 0x23033f0c,   // et.it.mt_654 sw.sq.lv_643  mr.hi.ne_322 af.nl.ca_543
  0x64350da6, 0x35030c02, 0x3b100704, 0x0708170e,   // cs.zu.lg_521 sv.nl.zu_222  it.lt.so_332 sr.uk.bg_555
  0x20212b07, 0x215564af, 0x050f1007, 0x07003504,   // vi.jw.sq_432 lg.rw.jw_655  lt.lv.fr_432 zu.it.un_320

  // [2800]
  0x35256404, 0x18061102, 0x1e1c21a9, 0x06006807,   // lg.eu.zu_332 ro.de.ga_222  jw.id.ms_544 ig.de.un_420
  0x062313ec, 0x310f1b07, 0x25112055, 0x23001107,   // et.ca.de_644 tr.lv.az_432  sq.ro.eu_442 ro.ca.un_420
  0x0f3f28a0, 0x295528af, 0x64552808, 0x4a000208,   // sw.af.lv_322 sw.rw.sl_655  sw.rw.lg_443 da.yo.un_430
  0x2a0f1208, 0x53001b19, 0x1e1c5502, 0x35552855,   // hu.lv.mt_443 tr.ht.un_750  rw.id.ms_222 sw.rw.zu_442
  // [2810]
  0x131a35a0, 0x02041355, 0x2800070e, 0x2164280c,   // zu.tl.et_322 et.fi.da_442  it.sw.un_550 sw.lg.jw_543
  0x190a0b09, 0x321e55a0, 0x35006802, 0x16000f0b,   // es.pt.gl_444 rw.ms.bs_322  ig.zu.un_220 lv.hr.un_520
  0x23002d04, 0x0513110c, 0x190a0b0c, 0x552835a9,   // sk.ca.un_320 ro.et.fr_543  es.pt.gl_543 zu.sw.rw_544
  0x162d2904, 0x1c0d1302, 0x32645512, 0x2855640d,   // sl.sk.hr_332 bh.ne.mr_222  rw.lg.bs_654 lg.rw.sw_554
  // [2820]
  0x2908020d, 0x13002113, 0x0d001604, 0x0e643fa0,   // da.no.sl_554 jw.et.un_650  hr.cs.un_320 af.lg.is_322
  0x0f000912, 0x553f03ad, 0x17080c0e, 0x55532105,   // pl.lv.un_640 nl.af.rw_643  sv.no.sr_555 jw.ht.rw_333
  0x281a3505, 0x55002819, 0x25001b19, 0x09001702,   // zu.tl.sw_333 sw.rw.un_750  tr.eu.un_750 sr.pl.un_220
  0x31001e05, 0x0d001c1b, 0x092a0860, 0x13280408,   // ms.az.un_330 mr.ne.un_770  no.mt.pl_664 fi.sw.et_443
  // [2830]
  0x19120b0c, 0x27001e02, 0x18000e08, 0x231c210c,   // es.hu.gl_543 ms.gd.un_220  is.ga.un_430 jw.id.ca_543
  0x4a002104, 0x080c0307, 0x01522807, 0x040e080b,   // jw.yo.un_320 nl.sv.no_432  sw.ha.en_432 no.is.fi_542
  0x02292d07, 0x0d2d0611, 0x16005507, 0x31006b04,   // sk.sl.da_432 de.sk.cs_653  rw.hr.un_420 ceb.az.un_320
  0x52643bec, 0x35072555, 0x1f6b200d, 0x6b6e2bad,   // so.lg.ha_644 eu.it.zu_442  sq.ceb.cy_554 vi.hmn.ceb_643
  // [2840]
  0x31053b0c, 0x52003b14, 0x110408a4, 0x20210fa0,   // so.fr.az_543 so.ha.un_660  uk.ru.ro_433 lv.jw.sq_322
  0x53006407, 0x276b0908, 0x10552d0c, 0x0c0f3fee,   // lg.ht.un_420 pl.ceb.gd_443  sk.rw.lt_543 af.lv.sv_422
  0x6b3b11a9, 0x4a000613, 0x070c1307, 0x1b5325ad,   // ro.so.ceb_544 de.yo.un_650  et.sv.it_432 eu.ht.tr_643
  0x3b003509, 0x6e3f2b08, 0x11002512, 0x132925a0,   // zu.so.un_440 vi.af.hmn_443  eu.ro.un_640 eu.sl.et_322
  // [2850]
  0x6b2025a0, 0x130d0913, 0x0e2d180c, 0x0d003512,   // eu.sq.ceb_322 hi.ne.bh_665  ga.sk.is_543 zu.cs.un_640
  0x64005314, 0x13041a07, 0x2d032007, 0x1a6b680c,   // ht.lg.un_660 tl.fi.et_432  sq.nl.sk_432 ig.ceb.tl_543
  0x356452a4, 0x21001602, 0x1a1b3b07, 0x060f1b07,   // ha.lg.zu_433 hr.jw.un_220  so.tr.tl_432 tr.lv.de_432
  0x023f08a0, 0x033f130d, 0x080c0204, 0x032911a0,   // no.af.da_322 et.af.nl_554  da.sv.no_332 ro.sl.nl_322
  // [2860]
  0x4a1f5555, 0x04071004, 0x13040c11, 0x1b1007ee,   // rw.cy.yo_442 be.bg.ru_332  sv.fi.et_653 it.lt.tr_422
  0x252135a4, 0x171629ec, 0x32160d0c, 0x3100010c,   // zu.jw.eu_433 sl.hr.sr_644  cs.hr.bs_543 en.az.un_530
  0x1a00030c, 0x1c0913ec, 0x6b2a5504, 0x35531ba4,   // nl.tl.un_530 bh.hi.mr_644  rw.mt.ceb_332 tr.ht.zu_433
  0x1f000c13, 0x211c03a0, 0x3f00050d, 0x09003b09,   // sv.cy.un_650 nl.id.jw_322  fr.af.un_540 so.pl.un_440
  // [2870]
  0x0c6408a4, 0x32161214, 0x1b000b04, 0x120408a0,   // no.lg.sv_433 hu.hr.bs_666  es.tr.un_320 no.fi.hu_322
  0x1716290c, 0x52645508, 0x12130112, 0x643b550c,   // sl.hr.sr_543 rw.lg.ha_443  en.et.hu_654 rw.so.lg_543
  0x1716130c, 0x08122007, 0x53001a02, 0x1c4a5507,   // et.hr.sr_543 sq.hu.no_432  tl.ht.un_220 rw.yo.id_432
  0x646b1a07, 0x08091f04, 0x23000804, 0x2d0d16a0,   // tl.ceb.lg_432 cy.pl.no_332  no.ca.un_320 hr.cs.sk_322
  // [2880]
  0x1f005302, 0x08023fa0, 0x6428010b, 0x682a1bee,   // ht.cy.un_220 af.da.no_322  en.sw.lg_542 tr.mt.ig_422
  0x181c1fee, 0x03353f0d, 0x2d0d4a09, 0x0c0804a4,   // cy.id.ga_422 af.zu.nl_554  yo.cs.sk_444 fi.no.sv_433
  0x1c130909, 0x4a2d0d0d, 0x121b2004, 0x2d1721ad,   // hi.bh.mr_444 cs.sk.yo_554  sq.tr.hu_332 jw.sr.sk_643
  0x0828350d, 0x01000502, 0x1b313fa0, 0x0f000707,   // zu.sw.no_554 fr.en.un_220  af.az.tr_322 it.lv.un_420
  // [2890]
  0x1c3521a4, 0x2a001c02, 0x525535a0, 0x28000807,   // jw.zu.id_433 id.mt.un_220  zu.rw.ha_322 no.sw.un_420
  0x350705af, 0x121b1ca7, 0x321c16a0, 0x55643508,   // fr.it.zu_655 id.tr.hu_532  hr.id.bs_322 zu.lg.rw_443
  0x1b000e13, 0x212964a0, 0x28354a12, 0x20003204,   // is.tr.un_650 lg.sl.jw_322  yo.zu.sw_654 bs.sq.un_320
  0x083f2302, 0x324a35ee, 0x1a003509, 0x0b00011a,   // ca.af.no_222 zu.yo.bs_422  zu.tl.un_440 en.es.un_760
  // [28a0]
  0x04000309, 0x235329a0, 0x522105ee, 0x11311b12,   // nl.fi.un_440 sl.ht.ca_322  fr.jw.ha_422 tr.az.ro_654
  0x17003b04, 0x1c000304, 0x55641aa4, 0x1f0e04a4,   // so.sr.un_320 nl.id.un_320  tl.lg.rw_433 fi.is.cy_433
  0x64202307, 0x230729a0, 0x23201f07, 0x071704a4,   // ca.sq.lg_432 sl.it.ca_322  cy.sq.ca_432 ru.sr.bg_433
  0x53352811, 0x0c0e020c, 0x253f06ec, 0x2d1b13ac,   // sw.zu.ht_653 da.is.sv_543  de.af.eu_644 et.tr.sk_632
  // [28b0]
  0x06020cee, 0x111709ac, 0x0d001e02, 0x170c1b55,   // sv.da.de_422 pl.sr.ro_632  ms.cs.un_220 tr.sv.sr_442
  0x35314aad, 0x0e2d0d5a, 0x131827ec, 0x250831a4,   // yo.az.zu_643 cs.sk.is_553  gd.ga.et_644 az.no.eu_433
  0x03003204, 0x0b0a1905, 0x08020da0, 0x31000c12,   // bs.nl.un_320 gl.pt.es_333  cs.da.no_322 sv.az.un_640
  0x1f3528ee, 0x6b1a3f05, 0x3f050607, 0x0300550d,   // sw.zu.cy_422 af.tl.ceb_333  de.fr.af_432 rw.nl.un_540
  // [28c0]
  0x532931a0, 0x110804a4, 0x27001f04, 0x64004a04,   // az.sl.ht_322 ru.uk.ro_433  cy.gd.un_320 yo.lg.un_320
  0x1e1c28ee, 0x6435125a, 0x523528ec, 0x136455a0,   // sw.id.ms_422 hu.zu.lg_553  sw.zu.ha_644 rw.lg.et_322
  0x641c02a0, 0x3b1b310c, 0x353153ad, 0x080209a4,   // da.id.lg_322 az.tr.so_543  ht.az.zu_643 pl.da.no_433
  0x12002304, 0x4a6b64a0, 0x23002814, 0x0600310e,   // ca.hu.un_320 lg.ceb.yo_322  sw.ca.un_660 az.de.un_550
  // [28d0]
  0x2d0d1214, 0x1c6b2107, 0x29172d05, 0x0a1708a0,   // hu.cs.sk_666 jw.ceb.id_432  sk.sr.sl_333 uk.sr.mk_322
  0x0a002d10, 0x31001105, 0x13002512, 0x53000a07,   // sk.pt.un_620 ro.az.un_330  eu.et.un_640 pt.ht.un_420
  0x53006807, 0x211e1c60, 0x1c2135ec, 0x0c13060d,   // ig.ht.un_420 id.ms.jw_664  zu.jw.id_644 de.et.sv_554
  0x07110455, 0x5352280c, 0x52353105, 0x07002308,   // ru.ro.bg_442 sw.ha.ht_543  az.zu.ha_333 ca.it.un_430
  // [28e0]
  0x1c2128a9, 0x53003b0d, 0x3217290e, 0x16001012,   // sw.jw.id_544 so.ht.un_540  sl.sr.bs_555 lt.hr.un_640
  0x0f000d04, 0x355528ec, 0x080a1104, 0x073511ee,   // cs.lv.un_320 sw.rw.zu_644  ro.mk.uk_332 ro.zu.it_422
  0x061f1305, 0x2b001a12, 0x55535213, 0x0e124aa4,   // et.cy.de_333 tl.vi.un_640  ha.ht.rw_665 yo.hu.is_433
  0x25003505, 0x033f55a0, 0x2d0e1bad, 0x311b5511,   // zu.eu.un_330 rw.af.nl_322  tr.is.sk_643 rw.tr.az_653
  // [28f0]
  0x17293f12, 0x4a190b05, 0x04001213, 0x0c0e0804,   // af.sl.sr_654 es.gl.yo_333  hu.fi.un_650 no.is.sv_332
  0x040717ee, 0x20003f13, 0x063f0804, 0x02123f0c,   // sr.bg.ru_422 af.sq.un_650  no.af.de_332 af.hu.da_543
  0x526e2904, 0x29002504, 0x0e190b08, 0x1e531104,   // sl.hmn.ha_332 eu.sl.un_320  es.gl.is_443 ro.ht.ms_332
  0x06002804, 0x0e001b14, 0x0b00270c, 0x1b003b07,   // sw.de.un_320 tr.is.un_660  gd.es.un_530 so.tr.un_420
  // [2900]
  0x01004a02, 0x531f05ad, 0x27051809, 0x211f3b0e,   // yo.en.un_220 fr.cy.ht_643  ga.fr.gd_444 so.cy.jw_555
  0x0100230b, 0x6b1f01ee, 0x08002504, 0x040f1bad,   // ca.en.un_520 en.cy.ceb_422  eu.no.un_320 tr.lv.fi_643
  0x19230a07, 0x1000350d, 0x32171614, 0x3f082707,   // pt.ca.gl_432 zu.lt.un_540  hr.sr.bs_666 gd.no.af_432
  0x3b5231a4, 0x1a080b04, 0x1e1c1bec, 0x351f5304,   // az.ha.so_433 es.no.tl_332  tr.id.ms_644 ht.cy.zu_332
  // [2910]
  0x643255ee, 0x060c0804, 0x5500641b, 0x063f0312,   // rw.bs.lg_422 no.sv.de_332  lg.rw.un_770 nl.af.de_654
  0x68552507, 0x04023f0c, 0x026b55ad, 0x09002902,   // eu.rw.ig_432 af.da.fi_543  rw.ceb.da_643 sl.pl.un_220
  0x09001f19, 0x110407af, 0x23190a09, 0x08172904,   // cy.pl.un_750 bg.ru.ro_655  pt.gl.ca_444 sl.sr.no_332
  0x170a1bee, 0x0e0c0804, 0x52281fa0, 0x6800520b,   // tr.pt.sr_422 no.sv.is_332  cy.sw.ha_322 ha.ig.un_520
  // [2920]
  0x311b3b09, 0x12002502, 0x0a000805, 0x130d0909,   // so.tr.az_444 eu.hu.un_220  uk.mk.un_330 hi.ne.bh_444
  0x0c0904ee, 0x033f0609, 0x35080ca6, 0x011b12a6,   // fi.pl.sv_422 de.af.nl_444  sv.no.zu_521 hu.tr.en_521
  0x190b1312, 0x09290fa0, 0x32000607, 0x130d09a4,   // et.es.gl_654 lv.sl.pl_322  de.bs.un_420 hi.ne.bh_433
  0x13002a04, 0x190b13a9, 0x16002804, 0x55122807,   // mt.et.un_320 et.es.gl_544  sw.hr.un_320 sw.hu.rw_432
  // [2930]
  0x641e1fac, 0x211a3511, 0x08022309, 0x6b4a1a60,   // cy.ms.lg_632 zu.tl.jw_653  ca.da.no_444 tl.yo.ceb_664
  0x1f002307, 0x04130804, 0x0912060c, 0x6b1f3f04,   // ca.cy.un_420 no.et.fi_332  de.hu.pl_543 af.cy.ceb_332
  0x31001312, 0x2b2128a9, 0x100f1a05, 0x3b351f12,   // et.az.un_640 sw.jw.vi_544  tl.lv.lt_333 cy.zu.so_654
  0x1e3b31a9, 0x0f001a0c, 0x3f1c0eee, 0x17001120,   // az.so.ms_544 tl.lv.un_530  is.id.af_422 ro.sr.un_850
  // [2940]
  0x0e2d1908, 0x0e002b12, 0x171613a4, 0x16100f05,   // gl.sk.is_443 vi.is.un_640  et.hr.sr_433 lv.lt.hr_333
  0x0e0c0811, 0x183b01a0, 0x071320ee, 0x0d3528a0,   // no.sv.is_653 en.so.ga_322  sq.et.it_422 sw.zu.cs_322
  0x1f0128a6, 0x12001005, 0x12001f07, 0x0f006412,   // sw.en.cy_521 lt.hu.un_330  cy.hu.un_420 lg.lv.un_640
  0x093f2104, 0x111004af, 0x070804ec, 0x12131007,   // jw.af.pl_332 ru.be.ro_655  ru.uk.bg_644 lt.et.hu_432
  // [2950]
  0x35642804, 0x3f2a13a4, 0x2d290d07, 0x1e53050c,   // sw.lg.zu_332 et.mt.af_433  cs.sl.sk_432 fr.ht.ms_543
  0x1f001b14, 0x13001011, 0x134a6b04, 0x1b00350d,   // tr.cy.un_660 lt.et.un_630  ceb.yo.et_332 zu.tr.un_540
  0x2b033f05, 0x1b000f04, 0x100112ee, 0x12030404,   // af.nl.vi_333 lv.tr.un_320  hu.en.lt_422 fi.nl.hu_332
  0x17000c04, 0x091c130d, 0x17040713, 0x53130107,   // sv.sr.un_320 bh.mr.hi_554  bg.ru.sr_665 en.et.ht_432
  // [2960]
  0x3f001a02, 0x10170a12, 0x031208ee, 0x1c000107,   // tl.af.un_220 mk.sr.be_654  no.hu.nl_422 en.id.un_420
  0x1b253108, 0x0e3f0305, 0x17110705, 0x0d180ead,   // az.eu.tr_443 nl.af.is_333  bg.ro.sr_333 is.ga.cs_643
  0x07005507, 0x12060c09, 0x1b043109, 0x0a100704,   // rw.it.un_420 sv.de.hu_444  az.fi.tr_444 bg.be.mk_332
  0x04101760, 0x23002a19, 0x0b0a23a0, 0x081103ee,   // sr.be.ru_664 mt.ca.un_750  ca.pt.es_322 nl.ro.no_422
  // [2970]
  0x09130d12, 0x29000704, 0x033f1105, 0x232120a4,   // ne.bh.hi_654 it.sl.un_320  ro.af.nl_333 sq.jw.ca_433
  0x182a06ee, 0x01002d02, 0x27280107, 0x1a35130b,   // de.mt.ga_422 sk.en.un_220  en.sw.gd_432 et.zu.tl_542
  0x100802a4, 0x0f082dee, 0x64002104, 0x64533f11,   // da.no.lt_433 sk.no.lv_422  jw.lg.un_320 af.ht.lg_653
  0x21033f11, 0x1e4a04a4, 0x100411ec, 0x0d120e0c,   // af.nl.jw_653 fi.yo.ms_433  ro.ru.be_644 is.hu.cs_543
  // [2980]
  0x4a002118, 0x53201ba4, 0x28000b04, 0x0e2d0aa9,   // jw.yo.un_740 tr.sq.ht_433  es.sw.un_320 pt.sk.is_544
  0x100820ee, 0x13350855, 0x16000f07, 0x35000704,   // sq.no.lt_422 no.zu.et_442  lv.hr.un_420 it.zu.un_320
  0x0b004a04, 0x13033b04, 0x251e1c08, 0x1632175a,   // yo.es.un_320 so.nl.et_332  id.ms.eu_443 sr.bs.hr_553
  0x111008a4, 0x060828a0, 0x00006e24, 0x05002312,   // uk.be.ro_433 sw.no.de_322  hmn.un.un_900 ca.fr.un_640
  // [2990]
  0x11100804, 0x321623a0, 0x08023f02, 0x2d001104,   // no.lt.ro_332 ca.hr.bs_322  af.da.no_222 ro.sk.un_320
  0x290d0fad, 0x06002707, 0x25282904, 0x0a002502,   // lv.cs.sl_643 gd.de.un_420  sl.sw.eu_332 eu.pt.un_220
  0x18000509, 0x041827ad, 0x1300030d, 0x4a000c07,   // fr.ga.un_440 gd.ga.fi_643  nl.et.un_540 sv.yo.un_420
  0x210c08af, 0x55003508, 0x1732160b, 0x3f031807,   // no.sv.jw_655 zu.rw.un_430  hr.bs.sr_542 ga.nl.af_432
  // [29a0]
  0x28001f13, 0x041c2105, 0x1c1e250d, 0x4a120e0c,   // cy.sw.un_650 jw.id.fi_333  eu.ms.id_554 is.hu.yo_543
  0x210a4aa4, 0x08100aa4, 0x021b08ee, 0x29230f04,   // yo.pt.jw_433 mk.be.uk_433  no.tr.da_422 lv.ca.sl_332
  0x1e211ca0, 0x6e006b05, 0x17001219, 0x235502ee,   // id.jw.ms_322 ceb.hmn.un_330  hu.sr.un_750 da.rw.ca_422
  0x0a1a0208, 0x061e1c05, 0x1f032507, 0x1f3f020b,   // da.tl.pt_443 id.ms.de_333  eu.nl.cy_432 da.af.cy_542
  // [29b0]
  0x06080c0c, 0x29090f05, 0x0e004a04, 0x0e083507,   // sv.no.de_543 lv.pl.sl_333  yo.is.un_320 zu.no.is_432
  0x3b0812a4, 0x0c001308, 0x106409a0, 0x01005207,   // hu.no.so_433 et.sv.un_430  pl.lg.lt_322 ha.en.un_420
  0x6b030ead, 0x121e1c09, 0x12002011, 0x31002704,   // is.nl.ceb_643 id.ms.hu_444  sq.hu.un_630 gd.az.un_320
  0x1e0d25ee, 0x09071304, 0x231e3bad, 0x07351a07,   // eu.cs.ms_422 et.it.pl_332  so.ms.ca_643 tl.zu.it_432
  // [29c0]
  0x013f1a07, 0x641f120c, 0x00004a2d, 0x3f2a0960,   // tl.af.en_432 hu.cy.lg_543  yo.un.un_A00 pl.mt.af_664
  0x06000d05, 0x13081bad, 0x2d0d4aa4, 0x23001a04,   // cs.de.un_330 tr.no.et_643  yo.cs.sk_433 tl.ca.un_320
  0x0c0810ee, 0x120c2dee, 0x09000d02, 0x0f091255,   // lt.no.sv_422 sk.sv.hu_422  ne.hi.un_220 hu.pl.lv_442
  0x0c080a05, 0x290a01a4, 0x111b2aad, 0x282155ee,   // pt.no.sv_333 en.pt.sl_433  mt.tr.ro_643 rw.jw.sw_422
  // [29d0]
  0x12003b09, 0x55353fa0, 0x0d091cad, 0x35001f07,   // so.hu.un_440 af.zu.rw_322  mr.hi.ne_643 cy.zu.un_420
  0x1c003202, 0x12001b07, 0x080f0c08, 0x170810ee,   // bs.id.un_220 tr.hu.un_420  sv.lv.no_443 be.uk.sr_422
  0x6b1b015a, 0x023506a4, 0x132718ad, 0x130e3fa0,   // en.tr.ceb_553 de.zu.da_433  ga.gd.et_643 af.is.et_322
  0x0e6b0807, 0x28643b08, 0x211c1b07, 0x13102807,   // no.ceb.is_432 so.lg.sw_443  tr.id.jw_432 sw.lt.et_432
  // [29e0]
  0x0e001f1a, 0x06133fa9, 0x28352112, 0x07183fa0,   // cy.is.un_760 af.et.de_544  jw.zu.sw_654 af.ga.it_322
  0x2000530d, 0x32161ba0, 0x171b3f07, 0x554a35a0,   // ht.sq.un_540 tr.hr.bs_322  af.tr.sr_432 zu.yo.rw_322
  0x27011207, 0x200f2a02, 0x190b05a0, 0x212b1a02,   // hu.en.gd_432 mt.lv.sq_222  fr.es.gl_322 tl.vi.jw_222
  0x25283504, 0x1b1c0107, 0x01000407, 0x185323a7,   // zu.sw.eu_332 en.id.tr_432  fi.en.un_420 ca.ht.ga_532
  // [29f0]
  0x0e00011a, 0x041918ad, 0x31003204, 0x0c001c04,   // en.is.un_760 ga.gl.fi_643  bs.az.un_320 id.sv.un_320
  0x2b1f3507, 0x0d13290c, 0x18293fee, 0x051f3b11,   // zu.cy.vi_432 sl.et.cs_543  af.sl.ga_422 so.cy.fr_653
  0x03053fa0, 0x2964350c, 0x2a0b0ea0, 0x55003202,   // af.fr.nl_322 zu.lg.sl_543  is.es.mt_322 bs.rw.un_220
  0x3f0e085a, 0x2d230a0c, 0x0b001812, 0x02061bee,   // no.is.af_553 pt.ca.sk_543  ga.es.un_640 tr.de.da_422
  // [2a00]
  0x0e00530e, 0x1b062a07, 0x1b1e3507, 0x033f0705,   // ht.is.un_550 mt.de.tr_432  zu.ms.tr_432 it.af.nl_333
  0x6b1a1fa4, 0x290c06ad, 0x53001c02, 0x0c0408ee,   // cy.tl.ceb_433 de.sv.sl_643  id.ht.un_220 no.fi.sv_422
  0x1b006b07, 0x35001014, 0x531b12a4, 0x53000707,   // ceb.tr.un_420 lt.zu.un_660  hu.tr.ht_433 it.ht.un_420
  0x17070804, 0x050a23a9, 0x0c001807, 0x06351807,   // uk.bg.sr_332 ca.pt.fr_544  ga.sv.un_420 ga.zu.de_432
  // [2a10]
  0x0d2011ee, 0x07000a19, 0x1b311007, 0x5300080e,   // ro.sq.cs_422 mk.bg.un_750  lt.az.tr_432 no.ht.un_550
  0x52006b04, 0x250b0ca0, 0x3b311aee, 0x0d202302,   // ceb.ha.un_320 sv.es.eu_322  tl.az.so_422 ca.sq.cs_222
  0x3b1b1a07, 0x35000c02, 0x04005502, 0x04001111,   // tl.tr.so_432 sv.zu.un_220  rw.fi.un_220 ro.ru.un_630
  0x116807ad, 0x192d0b07, 0x10293507, 0x02002504,   // it.ig.ro_643 es.sk.gl_432  zu.sl.lt_432 eu.da.un_320
  // [2a20]
  0x31004a0c, 0x012b1b04, 0x2d0d0aec, 0x09002505,   // yo.az.un_530 tr.vi.en_332  pt.cs.sk_644 eu.pl.un_330
  0x28001b13, 0x320428ad, 0x27001902, 0x29000d08,   // tr.sw.un_650 sw.fi.bs_643  gl.gd.un_220 cs.sl.un_430
  0x17162907, 0x0a1117a4, 0x19000e0b, 0x120d2dec,   // sl.hr.sr_432 sr.ro.mk_433  is.gl.un_520 sk.cs.hu_644
  0x6b000b07, 0x091b12a7, 0x10081304, 0x04006e0b,   // es.ceb.un_420 hu.tr.pl_532  et.no.lt_332 hmn.fi.un_520
  // [2a30]
  0x171632a9, 0x05000104, 0x21553ba9, 0x0927110e,   // bs.hr.sr_544 en.fr.un_320  so.rw.jw_544 ro.gd.pl_555
  0x0d131cad, 0x09112504, 0x2d120d07, 0x283555a6,   // mr.bh.ne_643 eu.ro.pl_332  cs.hu.sk_432 rw.zu.sw_521
  0x11002009, 0x201304ee, 0x2b001702, 0x17292d55,   // sq.ro.un_440 fi.et.sq_422  sr.vi.un_220 sk.sl.sr_442
  0x1e000307, 0x1300010d, 0x211a3b07, 0x0e180a04,   // nl.ms.un_420 en.et.un_540  so.tl.jw_432 pt.ga.is_332
  // [2a40]
  0x0c080faf, 0x6e2804a0, 0x12100fa7, 0x046b2804,   // lv.no.sv_655 fi.sw.hmn_322  lv.lt.hu_532 sw.ceb.fi_332
  0x2100070e, 0x093528a7, 0x1b08020e, 0x12003202,   // it.jw.un_550 sw.zu.pl_532  da.no.tr_555 bs.hu.un_220
  0x1300060c, 0x163528a7, 0x284a2a12, 0x0100060d,   // de.et.un_530 sw.zu.hr_532  mt.yo.sw_654 de.en.un_540
  0x282a52ee, 0x2d5212a4, 0x041a13a4, 0x04003202,   // ha.mt.sw_422 hu.ha.sk_433  et.tl.fi_433 bs.fi.un_220
  // [2a50]
  0x1e072d0c, 0x1f123fa7, 0x01000612, 0x03000c02,   // sk.it.ms_543 af.hu.cy_532  de.en.un_640 sv.nl.un_220
  0x28295508, 0x0e2821a6, 0x3f001111, 0x121a0f07,   // rw.sl.sw_443 jw.sw.is_521  ro.af.un_630 lv.tl.hu_432
  0x0b4a05af, 0x103568ad, 0x0c2d3ba0, 0x01270c0c,   // fr.yo.es_655 ig.zu.lt_643  so.sk.sv_322 sv.gd.en_543
  0x12182daf, 0x00001324, 0x1c211304, 0x12001112,   // sk.ga.hu_655 bh.un.un_900  et.jw.id_332 ro.hu.un_640
  // [2a60]
  0x1c2d07a6, 0x2a002109, 0x2d001f19, 0x202a11a9,   // it.sk.id_521 jw.mt.un_440  cy.sk.un_750 ro.mt.sq_544
  0x0a09070c, 0x0c001219, 0x2d6e29af, 0x1e000108,   // it.pl.pt_543 hu.sv.un_750  sl.hmn.sk_655 en.ms.un_430
  0x030b050c, 0x1e1c2aee, 0x322725a7, 0x286b1aee,   // fr.es.nl_543 mt.id.ms_422  eu.gd.bs_532 tl.ceb.sw_422
  0x051107a0, 0x350455a9, 0x12136ba6, 0x20000302,   // it.ro.fr_322 rw.fi.zu_544  ceb.et.hu_521 nl.sq.un_220
  // [2a70]
  0x3b1a6bad, 0x09000e05, 0x08021309, 0x060c2010,   // ceb.tl.so_643 is.pl.un_330  et.da.no_444 sq.sv.de_642
  0x52006808, 0x093f03a9, 0x4a000714, 0x29285255,   // ig.ha.un_430 nl.af.pl_544  it.yo.un_660 ha.sw.sl_442
  0x29025307, 0x0312250c, 0x19001813, 0x64281902,   // ht.da.sl_432 eu.hu.nl_543  ga.gl.un_650 gl.sw.lg_222
  0x32002813, 0x08022a0c, 0x13002d12, 0x161b0e55,   // sw.bs.un_650 mt.da.no_543  sk.et.un_640 is.tr.hr_442
  // [2a80]
  0x27002a02, 0x55002704, 0x0a5355a0, 0x321016a4,   // mt.gd.un_220 gd.rw.un_320  rw.ht.pt_322 hr.lt.bs_433
  0x191e2304, 0x0c005512, 0x3b000414, 0x2d120d55,   // ca.ms.gl_332 rw.sv.un_640  fi.so.un_660 cs.hu.sk_442
  0x521e1c13, 0x4a190a5a, 0x05001a04, 0x12000813,   // id.ms.ha_665 pt.gl.yo_553  tl.fr.un_320 no.hu.un_650
  0x53002312, 0x1708020d, 0x201217a0, 0x1c001e13,   // ca.ht.un_640 da.no.sr_554  sr.hu.sq_322 ms.id.un_650
  // [2a90]
  0x080702a6, 0x101704a7, 0x1c004a05, 0x3b1055a4,   // da.it.no_521 ru.sr.be_532  yo.id.un_330 rw.lt.so_433
  0x0d2d0e12, 0x524a28a7, 0x120e180c, 0x06001208,   // is.sk.cs_654 sw.yo.ha_532  ga.is.hu_543 hu.de.un_430
  0x11130107, 0x05000a02, 0x6e000d12, 0x181301a7,   // en.et.ro_432 pt.fr.un_220  cs.hmn.un_640 en.et.ga_532
  0x0c000413, 0x4a35640c, 0x1f3f0607, 0x1c002805,   // fi.sv.un_650 lg.zu.yo_543  de.af.cy_432 sw.id.un_330
  // [2aa0]
  0x1b6b35a4, 0x1b552155, 0x29171608, 0x12000f0c,   // zu.ceb.tr_433 jw.rw.tr_442  hr.sr.sl_443 lv.hu.un_530
  0x0602010c, 0x03001e05, 0x21001e07, 0x171629af,   // en.da.de_543 ms.nl.un_330  ms.jw.un_420 sl.hr.sr_655
  0x0c111602, 0x2a045505, 0x32121ca0, 0x1127180e,   // hr.ro.sv_222 rw.fi.mt_333  id.hu.bs_322 ga.gd.ro_555
  0x10002911, 0x0e006404, 0x04643507, 0x2a291605,   // sl.lt.un_630 lg.is.un_320  zu.lg.fi_432 hr.sl.mt_333
  // [2ab0]
  0x130f12af, 0x1a1b5304, 0x640807a6, 0x121b0c0c,   // hu.lv.et_655 ht.tr.tl_332  it.no.lg_521 sv.tr.hu_543
  0x132a0455, 0x3217160d, 0x212320ac, 0x553521af,   // fi.mt.et_442 hr.sr.bs_554  sq.ca.jw_632 jw.zu.rw_655
  0x4a68350c, 0x131835a4, 0x3b0e13a7, 0x10001904,   // zu.ig.yo_543 zu.ga.et_433  et.is.so_532 gl.lt.un_320
  0x20162955, 0x09112804, 0x2105230c, 0x20005205,   // sl.hr.sq_442 sw.ro.pl_332  ca.fr.jw_543 ha.sq.un_330
  // [2ac0]
  0x283b01a4, 0x251901a4, 0x110128ad, 0x281364ad,   // en.so.sw_433 en.gl.eu_433  sw.en.ro_643 lg.et.sw_643
  0x0a000504, 0x0e5513a0, 0x2d1309af, 0x046b55a0,   // fr.pt.un_320 et.rw.is_322  pl.et.sk_655 rw.ceb.fi_322
  0x32160fed, 0x19232509, 0x53006b07, 0x6400521a,   // lv.hr.bs_622 eu.ca.gl_444  ceb.ht.un_420 ha.lg.un_760
  0x0a0b19a4, 0x090c1f11, 0x3f25050c, 0x130d0905,   // gl.es.pt_433 cy.sv.pl_653  fr.eu.af_543 hi.ne.bh_333
  // [2ad0]
  0x19050ba0, 0x0d3b2da7, 0x2700020c, 0x6e000605,   // es.fr.gl_322 sk.so.cs_532  da.gd.un_530 de.hmn.un_330
  0x06002907, 0x1e1c0605, 0x23001217, 0x550e2105,   // sl.de.un_420 de.id.ms_333  hu.ca.un_730 jw.is.rw_333
  0x13312105, 0x0a000c04, 0x1f000b05, 0x29006b04,   // jw.az.et_333 sv.pt.un_320  es.cy.un_330 ceb.sl.un_320
  0x52004a1a, 0x0d091c55, 0x124a2d0d, 0x1b132508,   // yo.ha.un_760 mr.hi.ne_442  sk.yo.hu_554 eu.et.tr_443
  // [2ae0]
  0x111728a4, 0x2109350c, 0x190b25ee, 0x553513a7,   // sw.sr.ro_433 zu.pl.jw_543  eu.es.gl_422 et.zu.rw_532
  0x1c0d13a4, 0x17100a13, 0x3208020e, 0x0e003511,   // bh.ne.mr_433 mk.be.sr_665  da.no.bs_555 zu.is.un_630
  0x3b5564ad, 0x52003119, 0x523b35af, 0x1e051ca0,   // lg.rw.so_643 az.ha.un_750  zu.so.ha_655 id.fr.ms_322
  0x040e64a4, 0x0c0908a4, 0x0b2d0d0d, 0x06643509,   // lg.is.fi_433 no.pl.sv_433  cs.sk.es_554 zu.lg.de_444
  // [2af0]
  0x03006b05, 0x310f1baf, 0x25231fa9, 0x05000304,   // ceb.nl.un_330 tr.lv.az_655  cy.ca.eu_544 nl.fr.un_320
  0x1100050e, 0x06250107, 0x1a0e2155, 0x6b6808a4,   // fr.ro.un_550 en.eu.de_432  jw.is.tl_442 no.ig.ceb_433
  0x104a25a0, 0x0e311ea0, 0x0e0803ac, 0x35060913,   // eu.yo.lt_322 ms.az.is_322  nl.no.is_632 pl.de.zu_665
  0x23000819, 0x010b3502, 0x3b130207, 0x1e070105,   // no.ca.un_750 zu.es.en_222  da.et.so_432 en.it.ms_333
  // [2b00]
  0x0a12195a, 0x2b006e08, 0x25005507, 0x090d13a0,   // gl.hu.pt_553 hmn.vi.un_430  rw.eu.un_420 bh.ne.hi_322
  0x190b10ee, 0x1208025a, 0x11000e13, 0x644a35af,   // lt.es.gl_422 da.no.hu_553  is.ro.un_650 zu.yo.lg_655
  0x09531107, 0x553528ee, 0x5300030d, 0x6400030e,   // ro.ht.pl_432 sw.zu.rw_422  nl.ht.un_540 nl.lg.un_550
  0x06130412, 0x2a6b6e0c, 0x04020ca4, 0x1e1c3fa4,   // fi.et.de_654 hmn.ceb.mt_543  sv.da.fi_433 af.id.ms_433
  // [2b10]
  0x030e23ee, 0x32005304, 0x0e550a05, 0x19002102,   // ca.is.nl_422 ht.bs.un_320  pt.rw.is_333 jw.gl.un_220
  0x1c003105, 0x21171605, 0x27033f0d, 0x0c0601a6,   // az.id.un_330 hr.sr.jw_333  af.nl.gd_554 en.de.sv_521
  0x32160da4, 0x0b070d09, 0x31556412, 0x1a6b5308,   // cs.hr.bs_433 cs.it.es_444  lg.rw.az_654 ht.ceb.tl_443
  0x25685507, 0x32202904, 0x55001f14, 0x0d232d0d,   // rw.ig.eu_432 sl.sq.bs_332  cy.rw.un_660 sk.ca.cs_554
  // [2b20]
  0x6800642a, 0x3f3b6b02, 0x0d002702, 0x12640404,   // lg.ig.un_970 ceb.so.af_222  gd.cs.un_220 fi.lg.hu_332
  0x02080e04, 0x55351f0e, 0x1700030d, 0x184a0b04,   // is.no.da_332 cy.zu.rw_555  nl.sr.un_540 es.yo.ga_332
  0x321b55a4, 0x3f1303a4, 0x4a005308, 0x1f10270c,   // rw.tr.bs_433 nl.et.af_433  ht.yo.un_430 gd.lt.cy_543
  0x2707010b, 0x103b31a4, 0x5510030b, 0x3f036405,   // en.it.gd_542 az.so.lt_433  nl.lt.rw_542 lg.nl.af_333
  // [2b30]
  0x1f321ba4, 0x25050d07, 0x08001207, 0x0a070813,   // tr.bs.cy_433 cs.fr.eu_432  hu.no.un_420 uk.bg.mk_665
  0x32172902, 0x18002b07, 0x1a4a640c, 0x11532512,   // sl.sr.bs_222 vi.ga.un_420  lg.yo.tl_543 eu.ht.ro_654
  0x16001902, 0x3b1b31a4, 0x110d55a0, 0x35091fa7,   // gl.hr.un_220 az.tr.so_433  rw.cs.ro_322 cy.pl.zu_532
  0x2a2d27ac, 0x18091004, 0x350e110c, 0x010905ee,   // gd.sk.mt_632 lt.pl.ga_332  ro.is.zu_543 fr.pl.en_422
  // [2b40]
  0x29033fa4, 0x1b0910a6, 0x172d0d08, 0x6428550c,   // af.nl.sl_433 lt.pl.tr_521  cs.sk.sr_443 rw.sw.lg_543
  0x020e08a4, 0x08230112, 0x08021fa0, 0x04002502,   // no.is.da_433 en.ca.no_654  cy.da.no_322 eu.fi.un_220
  0x0d1c090b, 0x251b1213, 0x09001005, 0x2864680c,   // hi.mr.ne_542 hu.tr.eu_665  lt.pl.un_330 ig.lg.sw_543
  0x3f351b0e, 0x31001a0e, 0x11002005, 0x1c033ba0,   // tr.zu.af_555 tl.az.un_550  sq.ro.un_330 so.nl.id_322
  // [2b50]
  0x2b003502, 0x112320ee, 0x2d0a09ad, 0x08020605,   // zu.vi.un_220 sq.ca.ro_422  pl.pt.sk_643 de.da.no_333
  0x3f136404, 0x0d001914, 0x17001907, 0x0d3f2a11,   // lg.et.af_332 gl.cs.un_660  gl.sr.un_420 mt.af.cs_653
  0x3b03130c, 0x0c003202, 0x2d0d3f05, 0x2500010d,   // et.nl.so_543 bs.sv.un_220  af.cs.sk_333 en.eu.un_540
  0x122d0aa4, 0x32002b08, 0x3f00290d, 0x291b0da0,   // pt.sk.hu_433 vi.bs.un_430  sl.af.un_540 cs.tr.sl_322
  // [2b60]
  0x2d3129a0, 0x0b2501a0, 0x171b0704, 0x190b2505,   // sl.az.sk_322 en.eu.es_322  it.tr.sr_332 eu.es.gl_333
  0x0b005304, 0x6e05010c, 0x25000804, 0x080c1f0d,   // ht.es.un_320 en.fr.hmn_543  no.eu.un_320 cy.sv.no_554
  0x1e1c12ee, 0x31111baf, 0x1b002519, 0x18010404,   // hu.id.ms_422 tr.ro.az_655  eu.tr.un_750 fi.en.ga_332
  0x1b131f02, 0x11001f07, 0x0b0a19a4, 0x3b003521,   // cy.et.tr_222 cy.ro.un_420  gl.pt.es_433 zu.so.un_860
  // [2b70]
  0x1c211108, 0x522701a4, 0x112a0705, 0x2d000c04,   // ro.jw.id_443 en.gd.ha_433  it.mt.ro_333 sv.sk.un_320
  0x1b353b12, 0x11000d0d, 0x16001a04, 0x19002d0b,   // so.zu.tr_654 cs.ro.un_540  tl.hr.un_320 sk.gl.un_520
  0x52313508, 0x17321607, 0x1b25215a, 0x046b1304,   // zu.az.ha_443 hr.bs.sr_432  jw.eu.tr_553 et.ceb.fi_332
  0x311304ee, 0x6800641a, 0x06010c02, 0x1a2801a7,   // fi.et.az_422 lg.ig.un_760  sv.en.de_222 en.sw.tl_532
  // [2b80]
  0x4a005313, 0x3b3552a0, 0x035320ad, 0x06003504,   // ht.yo.un_650 ha.zu.so_322  sq.ht.nl_643 zu.de.un_320
  0x0e6b04a0, 0x09355507, 0x0a17080b, 0x20131007,   // fi.ceb.is_322 rw.zu.pl_432  uk.sr.mk_542 lt.et.sq_432
  0x160306a0, 0x080e100c, 0x351e1c09, 0x0e1a6b11,   // de.nl.hr_322 lt.is.no_543  id.ms.zu_444 ceb.tl.is_653
  0x190b06ed, 0x23002802, 0x20311b12, 0x01002804,   // de.es.gl_622 sw.ca.un_220  tr.az.sq_654 sw.en.un_320
  // [2b90]
  0x10000a02, 0x09131cad, 0x07005502, 0x0f1b01a4,   // mk.be.un_220 mr.bh.hi_643  rw.it.un_220 en.tr.lv_433
  0x0c001b14, 0x08311bad, 0x18282b11, 0x29000907,   // tr.sv.un_660 tr.az.no_643  vi.sw.ga_653 pl.sl.un_420
  0x5521285a, 0x2000110c, 0x533b31ec, 0x3564280d,   // sw.jw.rw_553 ro.sq.un_530  az.so.ht_644 sw.lg.zu_554
  0x11003512, 0x6455110d, 0x0f3b04a4, 0x190a3ba0,   // zu.ro.un_640 ro.rw.lg_554  fi.so.lv_433 so.pt.gl_322
  // [2ba0]
  0x19051855, 0x321610a4, 0x172d1109, 0x4a6435ec,   // ga.fr.gl_442 lt.hr.bs_433  ro.sk.sr_444 zu.lg.yo_644
  0x1255250c, 0x0b001112, 0x29001019, 0x1c003b0e,   // eu.rw.hu_543 ro.es.un_640  lt.sl.un_750 so.id.un_550
  0x02006b04, 0x071b0a02, 0x1c003b02, 0x19002a02,   // ceb.da.un_320 pt.tr.it_222  so.id.un_220 mt.gl.un_220
  0x0e076407, 0x53002804, 0x1004170d, 0x111c55ee,   // lg.it.is_432 sw.ht.un_320  sr.ru.be_554 rw.id.ro_422
  // [2bb0]
  0x161335ee, 0x0e5513ee, 0x07003507, 0x6b2a01a6,   // zu.et.hr_422 et.rw.is_422  zu.it.un_420 en.mt.ceb_521
  0x3f211c0d, 0x120e1905, 0x2a000204, 0x32206807,   // id.jw.af_554 gl.is.hu_333  da.mt.un_320 ig.sq.bs_432
  0x11080705, 0x21012007, 0x13001902, 0x282718ad,   // bg.uk.ro_333 sq.en.jw_432  gl.et.un_220 ga.gd.sw_643
  0x20002919, 0x04001f18, 0x04002504, 0x03001302,   // sl.sq.un_750 cy.fi.un_740  eu.fi.un_320 et.nl.un_220
  // [2bc0]
  0x20001b04, 0x010a2b04, 0x033f64ec, 0x0d1c13ec,   // tr.sq.un_320 vi.pt.en_332  lg.af.nl_644 bh.mr.ne_644
  0x0817110e, 0x4a53310c, 0x0f271109, 0x0a001305,   // ro.sr.uk_555 az.ht.yo_543  ro.gd.lv_444 et.pt.un_330
  0x19230ba0, 0x1b0e31ee, 0x23001707, 0x3f4a0707,   // es.ca.gl_322 az.is.tr_422  sr.ca.un_420 it.yo.af_432
  0x25003202, 0x00001224, 0x190a1ba4, 0x1b645513,   // bs.eu.un_220 ur.un.un_900  tr.pt.gl_433 rw.lg.tr_665
  // [2bd0]
  0x13003512, 0x0600280c, 0x13000108, 0x0c05010c,   // zu.et.un_640 sw.de.un_530  en.et.un_430 en.fr.sv_543
  0x12004a0c, 0x641b35ee, 0x281a1bee, 0x080e3104,   // yo.hu.un_530 zu.tr.lg_422  tr.tl.sw_422 az.is.no_332
  0x551108af, 0x1a210304, 0x12002302, 0x131204ec,   // no.ro.rw_655 nl.jw.tl_332  ca.hu.un_220 fi.hu.et_644
  0x35171bee, 0x046425ad, 0x20001f02, 0x2b6b01a0,   // tr.sr.zu_422 eu.lg.fi_643  cy.sq.un_220 en.ceb.vi_322
  // [2be0]
  0x23000907, 0x2d0c53a7, 0x53000a09, 0x18006b07,   // pl.ca.un_420 ht.sv.sk_532  pt.ht.un_440 ceb.ga.un_420
  0x1200230d, 0x1c130d04, 0x18002519, 0x1b133507,   // ca.hu.un_540 ne.bh.mr_332  eu.ga.un_750 zu.et.tr_432
  0x095231a7, 0x030604ad, 0x25193107, 0x04006409,   // az.ha.pl_532 fi.de.nl_643  az.gl.eu_432 lg.fi.un_440
  0x6b1f01a0, 0x4a6b1a08, 0x13043b60, 0x25033fa9,   // en.cy.ceb_322 tl.ceb.yo_443  so.fi.et_664 af.nl.eu_544
  // [2bf0]
  0x3b190a08, 0x64006e07, 0x1f1803ee, 0x1e1c1ba4,   // pt.gl.so_443 hmn.lg.un_420  nl.ga.cy_422 tr.id.ms_433
  0x13101ba4, 0x05111002, 0x0a000704, 0x18003b08,   // tr.lt.et_433 lt.ro.fr_222  it.pt.un_320 so.ga.un_430
  0x281b64a7, 0x10002d0e, 0x6b0d2012, 0x2513020c,   // lg.tr.sw_532 sk.lt.un_550  sq.cs.ceb_654 da.et.eu_543
  0x1f0e180e, 0x07001a02, 0x07000e07, 0x23002004,   // ga.is.cy_555 tl.it.un_220  is.it.un_420 sq.ca.un_320

  // [2c00]
  0x0c0225a7, 0x07002907, 0x1e1a1b55, 0x11040a05,   // eu.da.sv_532 sl.it.un_420  tr.tl.ms_442 mk.ru.ro_333
  0x13002504, 0x1a5202a4, 0x00006e03, 0x190b25a7,   // eu.et.un_320 da.ha.tl_433  hmn.un.un_300 eu.es.gl_532
  0x35001e04, 0x4a08020d, 0x19002309, 0x0928550c,   // ms.zu.un_320 da.no.yo_554  ca.gl.un_440 rw.sw.pl_543
  0x550120ee, 0x21005207, 0x6e003b12, 0x646b13a4,   // sq.en.rw_422 ha.jw.un_420  so.hmn.un_640 et.ceb.lg_433
  // [2c10]
  0x060511ee, 0x09310d07, 0x4a00020c, 0x090d13ec,   // ro.fr.de_422 cs.az.pl_432  da.yo.un_530 bh.ne.hi_644
  0x28003502, 0x2b000e09, 0x211c1e12, 0x64211aa7,   // zu.sw.un_220 is.vi.un_440  ms.id.jw_654 tl.jw.lg_532
  0x23001004, 0x321729a0, 0x23051355, 0x17163ba0,   // lt.ca.un_320 sl.sr.bs_322  et.fr.ca_442 so.hr.sr_322
  0x211e5255, 0x2d0d21ec, 0x3f271a05, 0x03060811,   // ha.ms.jw_442 jw.cs.sk_644  tl.gd.af_333 no.de.nl_653
  // [2c20]
  0x1c211e07, 0x2a1e28ac, 0x1a0e07a7, 0x0b001007,   // ms.jw.id_432 sw.ms.mt_632  it.is.tl_532 lt.es.un_420
  0x09553509, 0x311e1b05, 0x042d3b02, 0x1200070e,   // zu.rw.pl_444 tr.ms.az_333  so.sk.fi_222 it.hu.un_550
  0x23180b02, 0x3f0713ee, 0x68006b0d, 0x2d001b0c,   // es.ga.ca_222 et.it.af_422  ceb.ig.un_540 tr.sk.un_530
  0x3f001f07, 0x092a0fec, 0x13033f12, 0x13283b04,   // cy.af.un_420 lv.mt.pl_644  af.nl.et_654 so.sw.et_332
  // [2c30]
  0x31550fa4, 0x21286455, 0x311b2505, 0x64003b0e,   // lv.rw.az_433 lg.sw.jw_442  eu.tr.az_333 so.lg.un_550
  0x033f1304, 0x1c1221ee, 0x190b0a14, 0x2a2b4aa0,   // et.af.nl_332 jw.hu.id_422  pt.es.gl_666 yo.vi.mt_322
  0x29003202, 0x1c1a5207, 0x040d09a6, 0x131b0407,   // bs.sl.un_220 ha.tl.id_432  pl.cs.fi_521 fi.tr.et_432
  0x070b2312, 0x283b640c, 0x0a000c0c, 0x6e356407,   // ca.es.it_654 lg.so.sw_543  sv.pt.un_530 lg.zu.hmn_432
  // [2c40]
  0x0d13090b, 0x53003104, 0x3f130313, 0x1b5312a4,   // hi.bh.ne_542 az.ht.un_320  nl.et.af_665 hu.ht.tr_433
  0x683f1307, 0x0c001c02, 0x0d120c02, 0x3f000807,   // et.af.ig_432 id.sv.un_220  sv.hu.cs_222 no.af.un_420
  0x09130d08, 0x02002909, 0x686b1a0d, 0x2900060c,   // ne.bh.hi_443 sl.da.un_440  tl.ceb.ig_554 de.sl.un_530
  0x07060105, 0x4a0f10a4, 0x08003105, 0x050408a0,   // en.de.it_333 lt.lv.yo_433  az.no.un_330 no.fi.fr_322
  // [2c50]
  0x3b002a02, 0x2a3b2dac, 0x06003f12, 0x1a003504,   // mt.so.un_220 sk.so.mt_632  af.de.un_640 zu.tl.un_320
  0x1e1a3f02, 0x18002802, 0x0b07205a, 0x0b6e2804,   // af.tl.ms_222 sw.ga.un_220  sq.it.es_553 sw.hmn.es_332
  0x20006e07, 0x28000b02, 0x3b000702, 0x1a005519,   // hmn.sq.un_420 es.sw.un_220  it.so.un_220 rw.tl.un_750
  0x12000d11, 0x080e2004, 0x19002318, 0x21002b04,   // cs.hu.un_630 sq.is.no_332  ca.gl.un_740 vi.jw.un_320
  // [2c60]
  0x2700011a, 0x3f6b25ec, 0x04081f11, 0x04002013,   // en.gd.un_760 eu.ceb.af_644  cy.no.fi_653 sq.fi.un_650
  0x64003504, 0x1e3b1fa0, 0x1f00041a, 0x2b1e01a7,   // zu.lg.un_320 cy.so.ms_322  fi.cy.un_760 en.ms.vi_532
  0x131204a7, 0x081202a0, 0x6b4a1a04, 0x3f1b31a0,   // fi.hu.et_532 da.hu.no_322  tl.yo.ceb_332 az.tr.af_322
  0x16002513, 0x11003b17, 0x17126eee, 0x53320504,   // eu.hr.un_650 so.ro.un_730  hmn.hu.sr_422 fr.bs.ht_332
  // [2c70]
  0x060c080c, 0x5200310c, 0x080a11a6, 0x080e0ca4,   // no.sv.de_543 az.ha.un_530  ro.mk.uk_521 sv.is.no_433
  0x17110711, 0x3f003b04, 0x0c06120d, 0x0d0e18ad,   // bg.ro.sr_653 so.af.un_320  hu.de.sv_554 ga.is.cs_643
  0x20006804, 0x1312010c, 0x3f2d0da4, 0x2b005204,   // ig.sq.un_320 en.hu.et_543  cs.sk.af_433 ha.vi.un_320
  0x6409355a, 0x276b010c, 0x28181fac, 0x2100011a,   // zu.pl.lg_553 en.ceb.gd_543  cy.ga.sw_632 en.jw.un_760
  // [2c80]
  0x551b64ee, 0x1f3f0114, 0x2a1a11a4, 0x0105110c,   // lg.tr.rw_422 en.af.cy_666  ro.tl.mt_433 ro.fr.en_543
  0x05202704, 0x53001b1b, 0x3b060112, 0x1f001212,   // gd.sq.fr_332 tr.ht.un_770  en.de.so_654 hu.cy.un_640
  0x0a2313a0, 0x311b6b0c, 0x173528a0, 0x644a55ec,   // et.ca.pt_322 ceb.tr.az_543  sw.zu.sr_322 rw.yo.lg_644
  0x520220ee, 0x13313bec, 0x09005508, 0x3b000c08,   // sq.da.ha_422 so.az.et_644  rw.pl.un_430 sv.so.un_430
  // [2c90]
  0x0e111307, 0x056b1a0c, 0x530802ee, 0x3f0312ee,   // et.ro.is_432 tl.ceb.fr_543  da.no.ht_422 hu.nl.af_422
  0x1c0d09ac, 0x080235ee, 0x182301a4, 0x55001307,   // hi.ne.mr_632 zu.da.no_422  en.ca.ga_433 et.rw.un_420
  0x190b13a4, 0x29110307, 0x10000504, 0x0f6e060b,   // et.es.gl_433 nl.ro.sl_432  fr.lt.un_320 de.hmn.lv_542
  0x0220080d, 0x35684a12, 0x02060804, 0x3b1b0107,   // no.sq.da_554 yo.ig.zu_654  no.de.da_332 en.tr.so_432
  // [2ca0]
  0x010a3fa0, 0x2100550c, 0x251b0608, 0x1a6e6b0c,   // af.pt.en_322 rw.jw.un_530  de.tr.eu_443 ceb.hmn.tl_543
  0x0c0e1305, 0x1225040c, 0x08071b07, 0x53000914,   // et.is.sv_333 fi.eu.hu_543  tr.it.no_432 pl.ht.un_660
  0x52002508, 0x032305a4, 0x213f35a7, 0x2a002504,   // eu.ha.un_430 fr.ca.nl_433  zu.af.jw_532 eu.mt.un_320
  0x190b0e07, 0x6b3b01a7, 0x09080da0, 0x02010807,   // is.es.gl_432 en.so.ceb_532  cs.no.pl_322 no.en.da_432
  // [2cb0]
  0x110525a4, 0x130f0455, 0x04003f09, 0x0e003f04,   // eu.fr.ro_433 fi.lv.et_442  af.fi.un_440 af.is.un_320
  0x6b6435a7, 0x13091c0e, 0x0d033f09, 0x1118270c,   // zu.lg.ceb_532 mr.hi.bh_555  af.nl.cs_444 gd.ga.ro_543
  0x313f5507, 0x0e001314, 0x27181ea0, 0x55000b02,   // rw.af.az_432 et.is.un_660  ms.ga.gd_322 es.rw.un_220
  0x1e311b08, 0x1c033f11, 0x1e2031a7, 0x11042808,   // tr.az.ms_443 af.nl.id_653  az.sq.ms_532 sw.fi.ro_443
  // [2cc0]
  0x0a081711, 0x062a0711, 0x00001e15, 0x641a100c,   // sr.uk.mk_653 it.mt.de_653  ms.un.un_700 lt.tl.lg_543
  0x64683504, 0x07002008, 0x03000a04, 0x1c130d0e,   // zu.ig.lg_332 sq.it.un_430  pt.nl.un_320 ne.bh.mr_555
  0x07170aac, 0x1e002504, 0x090c1004, 0x52004a07,   // mk.sr.bg_632 eu.ms.un_320  lt.sv.pl_332 yo.ha.un_420
  0x0a003b0d, 0x25230407, 0x17290e04, 0x3b281aaf,   // so.pt.un_540 fi.ca.eu_432  is.sl.sr_332 tl.sw.so_655
  // [2cd0]
  0x1a00551b, 0x0f001c02, 0x2d003f04, 0x25060fa0,   // rw.tl.un_770 id.lv.un_220  af.sk.un_320 lv.de.eu_322
  0x060b28a4, 0x1c6b4aee, 0x1704110c, 0x12352d5a,   // sw.es.de_433 yo.ceb.id_422  ro.ru.sr_543 sk.zu.hu_553
  0x07000b04, 0x3b4a1307, 0x13100f0c, 0x64350312,   // es.it.un_320 et.yo.so_432  lv.lt.et_543 nl.zu.lg_654
  0x0c2106ee, 0x5300070e, 0x03001f04, 0x16000d0c,   // de.jw.sv_422 it.ht.un_550  cy.nl.un_320 cs.hr.un_530
  // [2ce0]
  0x19001f12, 0x3b641aa0, 0x6e001313, 0x07200fee,   // cy.gl.un_640 tl.lg.so_322  et.hmn.un_650 lv.sq.it_422
  0x3f032a04, 0x28521ea0, 0x21001312, 0x08002807,   // mt.nl.af_332 ms.ha.sw_322  et.jw.un_640 sw.no.un_420
  0x0500210d, 0x52071105, 0x060e0412, 0x12072807,   // jw.fr.un_540 ro.it.ha_333  fi.is.de_654 sw.it.hu_432
  0x00001a24, 0x35644a0c, 0x53071b04, 0x31110f07,   // tl.un.un_900 yo.lg.zu_543  tr.it.ht_332 lv.ro.az_432
  // [2cf0]
  0x6b002104, 0x0a005302, 0x1e1c28ac, 0x18030f08,   // jw.ceb.un_320 ht.pt.un_220  sw.id.ms_632 lv.nl.ga_443
  0x32000807, 0x1c0a55ee, 0x100835ee, 0x231b3ba0,   // no.bs.un_420 rw.pt.id_422  zu.no.lt_422 so.tr.ca_322
  0x080206a4, 0x1a5210ee, 0x643b040d, 0x1b061213,   // de.da.no_433 lt.ha.tl_422  fi.so.lg_554 hu.de.tr_665
  0x520b3ba9, 0x13640412, 0x121b0cee, 0x0e000c04,   // so.es.ha_544 fi.lg.et_654  sv.tr.hu_422 sv.is.un_320
  // [2d00]
  0x352a280d, 0x1e1c5209, 0x2d0d2b0c, 0x100820a7,   // sw.mt.zu_554 ha.id.ms_444  vi.cs.sk_543 sq.no.lt_532
  0x0c081f05, 0x211b28ee, 0x293113a4, 0x080406a0,   // cy.no.sv_333 sw.tr.jw_422  et.az.sl_433 de.fi.no_322
  0x122a070b, 0x060c05a4, 0x1e001105, 0x120410ad,   // it.mt.hu_542 fr.sv.de_433  ro.ms.un_330 lt.fi.hu_643
  0x1c005219, 0x09003f0d, 0x2a3b3108, 0x0d001113,   // ha.id.un_750 af.pl.un_540  az.so.mt_443 ro.cs.un_650
  // [2d10]
  0x6404520c, 0x354a3ba0, 0x08131a0c, 0x641b28a0,   // ha.fi.lg_543 so.yo.zu_322  tl.et.no_543 sw.tr.lg_322
  0x1a000119, 0x01002104, 0x2b002507, 0x190b2502,   // en.tl.un_750 jw.en.un_320  eu.vi.un_420 eu.es.gl_222
  0x1a2911a0, 0x6b0a0155, 0x0d00110d, 0x0d005208,   // ro.sl.tl_322 en.pt.ceb_442  ro.cs.un_540 ha.cs.un_430
  0x1c641ea4, 0x0a002d13, 0x2b005507, 0x28356412,   // ms.lg.id_433 sk.pt.un_650  rw.vi.un_420 lg.zu.sw_654
  // [2d20]
  0x2a0413af, 0x080613a0, 0x2a0c0205, 0x273f030e,   // et.fi.mt_655 et.de.no_322  da.sv.mt_333 nl.af.gd_555
  0x52002312, 0x100f0eee, 0x0b002312, 0x1b000a02,   // ca.ha.un_640 is.lv.lt_422  ca.es.un_640 pt.tr.un_220
  0x3b006b0e, 0x13042805, 0x3521520c, 0x21083fee,   // ceb.so.un_550 sw.fi.et_333  ha.jw.zu_543 af.no.jw_422
  0x1a00250d, 0x686b01a0, 0x07041f12, 0x17293b04,   // eu.tl.un_540 en.ceb.ig_322  cy.fi.it_654 so.sl.sr_332
  // [2d30]
  0x04251f5a, 0x3500520e, 0x180a2bec, 0x182d4a0c,   // cy.eu.fi_553 ha.zu.un_550  vi.pt.ga_644 yo.sk.ga_543
  0x251e3b07, 0x290813ee, 0x53001e04, 0x53001307,   // so.ms.eu_432 et.no.sl_422  ms.ht.un_320 et.ht.un_420
  0x05000a04, 0x251304af, 0x17100a0c, 0x1c000604,   // pt.fr.un_320 fi.et.eu_655  mk.be.sr_543 de.id.un_320
  0x193b25ec, 0x4a35520c, 0x0c0813ee, 0x106b1a0c,   // eu.so.gl_644 ha.zu.yo_543  et.no.sv_422 tl.ceb.lt_543
  // [2d40]
  0x0400080c, 0x3b355505, 0x271928af, 0x2d0d1602,   // no.fi.un_530 rw.zu.so_333  sw.gl.gd_655 hr.cs.sk_222
  0x20002508, 0x0c083502, 0x0523010c, 0x351a04a7,   // eu.sq.un_430 zu.no.sv_222  en.ca.fr_543 fi.tl.zu_532
  0x27001f1b, 0x23005504, 0x081827ad, 0x0f311b12,   // cy.gd.un_770 rw.ca.un_320  gd.ga.no_643 tr.az.lv_654
  0x0e00121a, 0x0812020c, 0x190118a0, 0x182b1aa0,   // hu.is.un_760 da.hu.no_543  ga.en.gl_322 tl.vi.ga_322
  // [2d50]
  0x3f0364ec, 0x0a00530b, 0x64210412, 0x12000513,   // lg.nl.af_644 ht.pt.un_520  fi.jw.lg_654 fr.hu.un_650
  0x251120a4, 0x13000d0d, 0x080f13a4, 0x0c2311af,   // sq.ro.eu_433 ne.bh.un_540  et.lv.no_433 ro.ca.sv_655
  0x0b10280c, 0x0a113b07, 0x2d0d0fa4, 0x0420250c,   // sw.lt.es_543 so.ro.pt_432  lv.cs.sk_433 eu.sq.fi_543
  0x0f000914, 0x1b001307, 0x2d0d05ee, 0x0e005202,   // pl.lv.un_660 et.tr.un_420  fr.cs.sk_422 ha.is.un_220
  // [2d60]
  0x28041302, 0x131a04a0, 0x32292da0, 0x53110ca0,   // et.fi.sw_222 fi.tl.et_322  sk.sl.bs_322 sv.ro.ht_322
  0x250c080c, 0x2b001818, 0x3b006808, 0x2a100b02,   // no.sv.eu_543 ga.vi.un_740  ig.so.un_430 es.lt.mt_222
  0x3b002502, 0x29000f18, 0x292d0f07, 0x523b2109,   // eu.so.un_220 lv.sl.un_740  lv.sk.sl_432 jw.so.ha_444
  0x3b002d05, 0x531925a0, 0x120d2b04, 0x52001e02,   // sk.so.un_330 eu.gl.ht_322  vi.cs.hu_332 ms.ha.un_220
  // [2d70]
  0x4a000b04, 0x252a07a4, 0x31003518, 0x0d00091a,   // es.yo.un_320 it.mt.eu_433  zu.az.un_740 hi.ne.un_760
  0x28122511, 0x10080faf, 0x6b002807, 0x100a0711,   // eu.hu.sw_653 lv.no.lt_655  sw.ceb.un_420 bg.mk.be_653
  0x0d005302, 0x0e081f04, 0x52311bad, 0x10002014,   // ht.cs.un_220 cy.no.is_332  tr.az.ha_643 sq.lt.un_660
  0x0c001e02, 0x023f0807, 0x02000e04, 0x0a1004ad,   // ms.sv.un_220 no.af.da_432  is.da.un_320 ru.be.mk_643
  // [2d80]
  0x02001213, 0x1008020d, 0x29001108, 0x25002004,   // hu.da.un_650 da.no.lt_554  ro.sl.un_430 sq.eu.un_320
  0x010705a0, 0x2a000808, 0x060302a0, 0x1f003f13,   // fr.it.en_322 no.mt.un_430  da.nl.de_322 af.cy.un_650
  0x55054aee, 0x02002009, 0x2a000405, 0x05003f02,   // yo.fr.rw_422 sq.da.un_440  fi.mt.un_330 af.fr.un_220
  0x070b3fee, 0x68006413, 0x1000250d, 0x132308a4,   // af.es.it_422 lg.ig.un_650  eu.lt.un_540 no.ca.et_433
  // [2d90]
  0x3b1f1ba7, 0x020801ee, 0x04002104, 0x3f060f07,   // tr.cy.so_532 en.no.da_422  jw.fi.un_320 lv.de.af_432
  0x3500060c, 0x03250605, 0x1a126ba4, 0x2d00060e,   // de.zu.un_530 de.eu.nl_333  ceb.hu.tl_433 de.sk.un_550
  0x100613a0, 0x1b002504, 0x1100070d, 0x133f0e07,   // et.de.lt_322 eu.tr.un_320  it.ro.un_540 is.af.et_432
  0x081b1faf, 0x1c1e2807, 0x291b0107, 0x18205307,   // cy.tr.no_655 sw.ms.id_432  en.tr.sl_432 ht.sq.ga_432
  // [2da0]
  0x1c0913ad, 0x522d5309, 0x0a002108, 0x06000204,   // bh.hi.mr_643 ht.sk.ha_444  jw.pt.un_430 da.de.un_320
  0x31112dee, 0x103f35a7, 0x11000813, 0x283b1b08,   // sk.ro.az_422 zu.af.lt_532  uk.ro.un_650 tr.so.sw_443
  0x131123ee, 0x552809a4, 0x2d271855, 0x11005308,   // ca.ro.et_422 pl.sw.rw_433  ga.gd.sk_442 ht.ro.un_430
  0x1b55525a, 0x1e1c13ee, 0x0c060202, 0x23001104,   // ha.rw.tr_553 et.id.ms_422  da.de.sv_222 ro.ca.un_320
  // [2db0]
  0x5506520c, 0x4a072ba4, 0x0e1b3112, 0x2d0d2907,   // ha.de.rw_543 vi.it.yo_433  az.tr.is_654 sl.cs.sk_432
  0x07270907, 0x23004a07, 0x3f030112, 0x03000509,   // pl.gd.it_432 yo.ca.un_420  en.nl.af_654 fr.nl.un_440
  0x4a6b1a11, 0x061c21a7, 0x01002504, 0x21001b12,   // tl.ceb.yo_653 jw.id.de_532  eu.en.un_320 tr.jw.un_640
  0x4a00050c, 0x02001104, 0x1a6b4a13, 0x120d2d0c,   // fr.yo.un_530 ro.da.un_320  yo.ceb.tl_665 sk.cs.hu_543
  // [2dc0]
  0x12101f0c, 0x29000604, 0x25000714, 0x2b003f08,   // cy.lt.hu_543 de.sl.un_320  it.eu.un_660 af.vi.un_430
  0x20001b0c, 0x1c0228ee, 0x25000f13, 0x251104ec,   // tr.sq.un_530 sw.da.id_422  lv.eu.un_650 fi.ro.eu_644
  0x556401ad, 0x17001018, 0x0d072807, 0x25046805,   // en.lg.rw_643 be.sr.un_740  sw.it.cs_432 ig.fi.eu_333
  0x1e0e250c, 0x04002519, 0x52213508, 0x35001219,   // eu.is.ms_543 eu.fi.un_750  zu.jw.ha_443 hu.zu.un_750
  // [2dd0]
  0x16003507, 0x6e000708, 0x552864a9, 0x28006811,   // zu.hr.un_420 it.hmn.un_430  lg.sw.rw_544 ig.sw.un_630
  0x0625350c, 0x4a352812, 0x082b03a7, 0x3f0f0907,   // zu.eu.de_543 sw.zu.yo_654  nl.vi.no_532 pl.lv.af_432
  0x0d354a07, 0x1b5311ee, 0x2b002809, 0x3b0f1ea4,   // yo.zu.cs_432 ro.ht.tr_422  sw.vi.un_440 ms.lv.so_433
  0x64000814, 0x08002b04, 0x3f002a0c, 0x030c060c,   // no.lg.un_660 vi.no.un_320  mt.af.un_530 de.sv.nl_543
  // [2de0]
  0x110b25a0, 0x130625a4, 0x18003507, 0x080213ee,   // eu.es.ro_322 eu.de.et_433  zu.ga.un_420 et.da.no_422
  0x350928ee, 0x21120d09, 0x29230202, 0x321628a4,   // sw.pl.zu_422 cs.hu.jw_444  da.ca.sl_222 sw.hr.bs_433
  0x64006b0d, 0x02000108, 0x0a2718ec, 0x10080a12,   // ceb.lg.un_540 en.da.un_430  ga.gd.pt_644 mk.uk.be_654
  0x3b6835a9, 0x0d002a09, 0x132a0e0e, 0x27003104,   // zu.ig.so_544 mt.cs.un_440  is.mt.et_555 az.gd.un_320
  // [2df0]
  0x101a0404, 0x07002a04, 0x0b0a2302, 0x4a00230e,   // fi.tl.lt_332 mt.it.un_320  ca.pt.es_222 ca.yo.un_550
  0x1c2113a6, 0x20002a02, 0x3b002712, 0x01045507,   // et.jw.id_521 mt.sq.un_220  gd.so.un_640 rw.fi.en_432
  0x2b001104, 0x21003f0d, 0x091b31a4, 0x200f18ee,   // ro.vi.un_320 af.jw.un_540  az.tr.pl_433 ga.lv.sq_422
  0x08001104, 0x1253200d, 0x352a23a7, 0x0b0a0fec,   // ro.uk.un_320 sq.ht.hu_554  ca.mt.zu_532 lv.pt.es_644
  // [2e00]
  0x0c100fa4, 0x1b005504, 0x322817a4, 0x0a00120b,   // lv.lt.sv_433 rw.tr.un_320  sr.sw.bs_433 hu.pt.un_520
  0x3552280c, 0x2b031ea0, 0x1e252707, 0x1b000c04,   // sw.ha.zu_543 ms.nl.vi_322  gd.eu.ms_432 sv.tr.un_320
  0x643521a6, 0x55281212, 0x35000f12, 0x20061b07,   // jw.zu.lg_521 hu.sw.rw_654  lv.zu.un_640 tr.de.sq_432
  0x32003505, 0x3f00070b, 0x01002707, 0x010c2bee,   // zu.bs.un_330 it.af.un_520  gd.en.un_420 vi.sv.en_422
  // [2e10]
  0x190b1fa4, 0x20001a04, 0x132d28a4, 0x533b11a7,   // cy.es.gl_433 tl.sq.un_320  sw.sk.et_433 ro.so.ht_532
  0x0c00120d, 0x120d0aa4, 0x033f0708, 0x213b28ee,   // hu.sv.un_540 pt.cs.hu_433  it.af.nl_443 sw.so.jw_422
  0x20002a08, 0x1a210604, 0x1e1c13a0, 0x6b5301a4,   // mt.sq.un_430 de.jw.tl_332  et.id.ms_322 en.ht.ceb_433
  0x10002b04, 0x0b005302, 0x11072aa4, 0x12002812,   // vi.lt.un_320 ht.es.un_220  mt.it.ro_433 sw.hu.un_640
  // [2e20]
  0x04133fee, 0x06000e13, 0x1b1120ad, 0x1e1320ec,   // af.et.fi_422 is.de.un_650  sq.ro.tr_643 sq.et.ms_644
  0x021220a7, 0x18270304, 0x09000704, 0x080e02ee,   // sq.hu.da_532 nl.gd.ga_332  it.pl.un_320 da.is.no_422
  0x273f0360, 0x551264ec, 0x06002312, 0x050318a0,   // nl.af.gd_664 lg.hu.rw_644  ca.de.un_640 ga.nl.fr_322
  0x68004a09, 0x100411a9, 0x020c2912, 0x07002718,   // yo.ig.un_440 ro.ru.be_544  sl.sv.da_654 gd.it.un_740
  // [2e30]
  0x210468ad, 0x1c270712, 0x55001e02, 0x10005307,   // ig.fi.jw_643 it.gd.id_654  ms.rw.un_220 ht.lt.un_420
  0x2d0d04ec, 0x0f001e07, 0x2a000d1a, 0x13060f07,   // fi.cs.sk_644 ms.lv.un_420  cs.mt.un_760 lv.de.et_432
  0x4a101f04, 0x190b0fa9, 0x04080a55, 0x16321755,   // cy.lt.yo_332 lv.es.gl_544  mk.uk.ru_442 sr.bs.hr_442
  0x35001005, 0x642128ad, 0x6b1a2aa9, 0x1b0d3104,   // lt.zu.un_330 sw.jw.lg_643  mt.tl.ceb_544 az.cs.tr_332
  // [2e40]
  0x0e1301a4, 0x17002505, 0x0c0d1fa7, 0x285231af,   // en.et.is_433 eu.sr.un_330  cy.cs.sv_532 az.ha.sw_655
  0x2a000304, 0x2b1204a9, 0x645553a0, 0x3b25550c,   // nl.mt.un_320 fi.hu.vi_544  ht.rw.lg_322 rw.eu.so_543
  0x09131c08, 0x13090da0, 0x32000204, 0x20001213,   // mr.bh.hi_443 ne.hi.bh_322  da.bs.un_320 hu.sq.un_650
  0x0a1711a6, 0x12040c05, 0x12061ba7, 0x01000602,   // ro.sr.mk_521 sv.fi.hu_333  tr.de.hu_532 de.en.un_220
  // [2e50]
  0x0e001b09, 0x2900100e, 0x190c0808, 0x230b0a0d,   // tr.is.un_440 lt.sl.un_550  no.sv.gl_443 pt.es.ca_554
  0x2a0312ec, 0x35031f0c, 0x21000604, 0x05030604,   // hu.nl.mt_644 cy.nl.zu_543  de.jw.un_320 de.nl.fr_332
  0x1a6b640c, 0x04003107, 0x55002a0d, 0x090d13a7,   // lg.ceb.tl_543 az.fi.un_420  mt.rw.un_540 bh.ne.hi_532
  0x1a643bad, 0x13001e02, 0x1f271812, 0x271b0fee,   // so.lg.tl_643 ms.et.un_220  ga.gd.cy_654 lv.tr.gd_422
  // [2e60]
  0x01003b02, 0x0e002104, 0x282a01a4, 0x0f1801a4,   // so.en.un_220 jw.is.un_320  en.mt.sw_433 en.ga.lv_433
  0x11002a08, 0x1b3f13ee, 0x10530c04, 0x0f001313,   // mt.ro.un_430 et.af.tr_422  sv.ht.lt_332 et.lv.un_650
  0x1a6b130e, 0x1e1c5302, 0x070601ad, 0x525509ee,   // et.ceb.tl_555 ht.id.ms_222  en.de.it_643 pl.rw.ha_422
  0x080206ee, 0x170a07a6, 0x130f04a4, 0x21000e07,   // de.da.no_422 it.pt.sr_521  fi.lv.et_433 is.jw.un_420
  // [2e70]
  0x0200200c, 0x322052a0, 0x126435a9, 0x0d000f13,   // sq.da.un_530 ha.sq.bs_322  zu.lg.hu_544 lv.cs.un_650
  0x32173107, 0x16292d12, 0x0c004a07, 0x07000505,   // az.sr.bs_432 sk.sl.hr_654  yo.sv.un_420 fr.it.un_330
  0x321816ee, 0x31003507, 0x20000b09, 0x0b001804,   // hr.ga.bs_422 zu.az.un_420  es.sq.un_440 ga.es.un_320
  0x08021aee, 0x01002004, 0x0d1c09ac, 0x0f0925ee,   // tl.da.no_422 sq.en.un_320  hi.mr.ne_632 eu.pl.lv_422
  // [2e80]
  0x1a2528a0, 0x1118250c, 0x130d090d, 0x2d000e12,   // sw.eu.tl_322 eu.ga.ro_543  hi.ne.bh_554 is.sk.un_640
  0x230b07ee, 0x356428ec, 0x1c0921ad, 0x0e1b31a4,   // it.es.ca_422 sw.lg.zu_644  jw.pl.id_643 az.tr.is_433
  0x086e1a07, 0x356825ad, 0x09002512, 0x6b6401ec,   // tl.hmn.no_432 eu.ig.zu_643  eu.pl.un_640 en.lg.ceb_644
  0x1e250d14, 0x1e001a07, 0x2d0d25a0, 0x0a1210a0,   // cs.eu.ms_666 tl.ms.un_420  eu.cs.sk_322 lt.hu.pt_322
  // [2e90]
  0x050a03a0, 0x13003f07, 0x010a13ee, 0x6400550b,   // nl.pt.fr_322 af.et.un_420  et.pt.en_422 rw.lg.un_520
  0x1c1e1f11, 0x0f001b07, 0x1f041012, 0x53061aee,   // cy.ms.id_653 tr.lv.un_420  lt.fi.cy_654 tl.de.ht_422
  0x0c000213, 0x31102805, 0x21002514, 0x322916ee,   // da.sv.un_650 sw.lt.az_333  eu.jw.un_660 hr.sl.bs_422
  0x04001f0d, 0x556b6405, 0x080c27a0, 0x642a68ad,   // cy.fi.un_540 lg.ceb.rw_333  gd.sv.no_322 ig.mt.lg_643
  // [2ea0]
  0x032d3ba0, 0x32000d05, 0x061b3111, 0x040a0811,   // so.sk.nl_322 cs.bs.un_330  az.tr.de_653 uk.mk.ru_653
  0x31000513, 0x17001e08, 0x293b1304, 0x2b002802,   // fr.az.un_650 ms.sr.un_430  et.so.sl_332 sw.vi.un_220
  0x0c686b07, 0x2b4a1e07, 0x121a1107, 0x052001ec,   // ceb.ig.sv_432 ms.yo.vi_432  ro.tl.hu_432 en.sq.fr_644
  0x0d002918, 0x25002814, 0x0a00250d, 0x0d1309ad,   // sl.cs.un_740 sw.eu.un_660  eu.pt.un_540 hi.bh.ne_643
  // [2eb0]
  0x20000c12, 0x21001f07, 0x530d0407, 0x29162d0c,   // sv.sq.un_640 cy.jw.un_420  fi.cs.ht_432 sk.hr.sl_543
  0x213b55a7, 0x06002b04, 0x0b000c04, 0x1700350b,   // rw.so.jw_532 vi.de.un_320  sv.es.un_320 zu.sr.un_520
  0x23002012, 0x020520ad, 0x20000119, 0x2d0d27a0,   // sq.ca.un_640 sq.fr.da_643  en.sq.un_750 gd.cs.sk_322
  0x2500350c, 0x034a13a6, 0x10182708, 0x1e0c1b04,   // zu.eu.un_530 et.yo.nl_521  gd.ga.lt_443 tr.sv.ms_332
  // [2ec0]
  0x1c002702, 0x190a08af, 0x0a2301a6, 0x0c5208af,   // gd.id.un_220 no.pt.gl_655  en.ca.pt_521 no.ha.sv_655
  0x530852a0, 0x100a170c, 0x08170a14, 0x0411250c,   // ha.no.ht_322 sr.mk.be_543  mk.sr.uk_666 eu.ro.fi_543
  0x066e0fee, 0x16321707, 0x07030108, 0x050701a4,   // lv.hmn.de_422 sr.bs.hr_432  en.nl.it_443 en.it.fr_433
  0x1200530c, 0x271101a4, 0x23005304, 0x311b060c,   // ht.hu.un_530 en.ro.gd_433  ht.ca.un_320 de.tr.az_543
  // [2ed0]
  0x0527040c, 0x202a3160, 0x28002509, 0x081213a0,   // fi.gd.fr_543 az.mt.sq_664  eu.sw.un_440 et.hu.no_322
  0x3f001702, 0x0f106ea7, 0x0b55530c, 0x190b12ec,   // sr.af.un_220 hmn.lt.lv_532  ht.rw.es_543 hu.es.gl_644
  0x1900120d, 0x28526407, 0x1100101b, 0x07284a04,   // hu.gl.un_540 lg.ha.sw_432  be.ro.un_770 yo.sw.it_332
  0x052a1307, 0x11006407, 0x3f063ba0, 0x0f131004,   // et.mt.fr_432 lg.ro.un_420  so.de.af_322 lt.et.lv_332
  // [2ee0]
  0x03050111, 0x1c0d09a6, 0x6b001313, 0x08020908,   // en.fr.nl_653 hi.ne.mr_521  et.ceb.un_650 pl.da.no_443
  0x2d004a09, 0x0e100f0d, 0x231f0560, 0x0c000d04,   // yo.sk.un_440 lv.lt.is_554  fr.cy.ca_664 cs.sv.un_320
  0x041110af, 0x1e1c2014, 0x551f1012, 0x08020eee,   // be.ro.ru_655 sq.id.ms_666  lt.cy.rw_654 is.da.no_422
  0x061e6ea4, 0x1c1a1e07, 0x011310a7, 0x3f211007,   // hmn.ms.de_433 ms.tl.id_432  lt.et.en_532 lt.jw.af_432
  // [2ef0]
  0x55033f11, 0x0c0213ec, 0x64000c07, 0x3f000f12,   // af.nl.rw_653 et.da.sv_644  sv.lg.un_420 lv.af.un_640
  0x3b2a250c, 0x2a2506a0, 0x3f032508, 0x1f13250c,   // eu.mt.so_543 de.eu.mt_322  eu.nl.af_443 eu.et.cy_543
  0x21053ba0, 0x11002908, 0x53000f02, 0x190a0b0e,   // so.fr.jw_322 sl.ro.un_430  lv.ht.un_220 es.pt.gl_555
  0x551a64ee, 0x356b1aec, 0x13003504, 0x1731100e,   // lg.tl.rw_422 tl.ceb.zu_644  zu.et.un_320 lt.az.sr_555
  // [2f00]
  0x3f0325ee, 0x190a11a9, 0x4a08050c, 0x2300050b,   // eu.nl.af_422 ro.pt.gl_544  fr.no.yo_543 fr.ca.un_520
  0x351a64a4, 0x2a0201ad, 0x066427a0, 0x070a13ee,   // lg.tl.zu_433 en.da.mt_643  gd.lg.de_322 et.pt.it_422
  0x2800110d, 0x4a1f53ee, 0x122310ee, 0x6b001a07,   // ro.sw.un_540 ht.cy.yo_422  lt.ca.hu_422 tl.ceb.un_420
  0x3f031a0c, 0x0d002912, 0x352368ee, 0x124a1902,   // tl.nl.af_543 sl.cs.un_640  ig.ca.zu_422 gl.yo.hu_222
  // [2f10]
  0x211c11a0, 0x6804130d, 0x55001a02, 0x0f00060d,   // ro.id.jw_322 et.fi.ig_554  tl.rw.un_220 de.lv.un_540
  0x061112ec, 0x063525a7, 0x12092da7, 0x0c022005,   // hu.ro.de_644 eu.zu.de_532  sk.pl.hu_532 sq.da.sv_333
  0x070d1ba0, 0x351a1309, 0x31006e07, 0x01000a02,   // tr.cs.it_322 et.tl.zu_444  hmn.az.un_420 pt.en.un_220
  0x311206ee, 0x10320dee, 0x0e001f12, 0x13045207,   // de.hu.az_422 cs.bs.lt_422  cy.is.un_640 ha.fi.et_432
  // [2f20]
  0x052755a0, 0x07033f0c, 0x0c3f1004, 0x52354a12,   // rw.gd.fr_322 af.nl.it_543  lt.af.sv_332 yo.zu.ha_654
  0x1f1806a0, 0x642555af, 0x06000704, 0x2b1f18a7,   // de.ga.cy_322 rw.eu.lg_655  it.de.un_320 ga.cy.vi_532
  0x641a2111, 0x250410ad, 0x182b01ad, 0x552135a4,   // jw.tl.lg_653 lt.fi.eu_643  en.vi.ga_643 zu.jw.rw_433
  0x0e200dad, 0x1f6828ad, 0x52003113, 0x0f191007,   // cs.sq.is_643 sw.ig.cy_643  az.ha.un_650 lt.gl.lv_432
  // [2f30]
  0x0b002307, 0x526b1a08, 0x0d1c09ee, 0x17005202,   // ca.es.un_420 tl.ceb.ha_443  hi.mr.ne_422 ha.sr.un_220
  0x08191f0c, 0x08001f0e, 0x3f001004, 0x3b2031a9,   // cy.gl.no_543 cy.no.un_550  lt.af.un_320 az.sq.so_544
  0x190b0a5a, 0x2a00041b, 0x071827ac, 0x190b21a9,   // pt.es.gl_553 fi.mt.un_770  gd.ga.it_632 jw.es.gl_544
  0x13000d02, 0x04000b05, 0x2a09180c, 0x170c080e,   // ne.bh.un_220 es.fi.un_330  ga.pl.mt_543 no.sv.sr_555
  // [2f40]
  0x55686460, 0x52281007, 0x68643511, 0x32006402,   // lg.ig.rw_664 lt.sw.ha_432  zu.lg.ig_653 lg.bs.un_220
  0x3f030802, 0x27251311, 0x21280fa7, 0x291728a0,   // no.nl.af_222 et.eu.gd_653  lv.sw.jw_532 sw.sr.sl_322
  0x09001107, 0x32003b07, 0x17520f04, 0x1a046b0c,   // ro.pl.un_420 so.bs.un_420  lv.ha.sr_332 ceb.fi.tl_543
  0x04000204, 0x20532809, 0x03250aee, 0x01006404,   // da.fi.un_320 sw.ht.sq_444  pt.eu.nl_422 lg.en.un_320
  // [2f50]
  0x043108a0, 0x533f1aee, 0x0d2a3ba6, 0x3f1303a0,   // no.az.fi_322 tl.af.ht_422  so.mt.cs_521 nl.et.af_322
  0x132a23a4, 0x050b0a05, 0x64000414, 0x3b5201a4,   // ca.mt.et_433 pt.es.fr_333  fi.lg.un_660 en.ha.so_433
  0x3b521f07, 0x3b000420, 0x11250512, 0x2b000607,   // cy.ha.so_432 fi.so.un_850  fr.eu.ro_654 de.vi.un_420
  0x08020aa0, 0x1a6b3fa4, 0x090a2daf, 0x12050eee,   // pt.da.no_322 af.ceb.tl_433  sk.pt.pl_655 is.fr.hu_422
  // [2f60]
  0x1b002812, 0x1e001602, 0x07230105, 0x0c27180c,   // sw.tr.un_640 hr.ms.un_220  en.ca.it_333 ga.gd.sv_543
  0x180106ac, 0x0e2155a4, 0x0b006407, 0x27004a1a,   // de.en.ga_632 rw.jw.is_433  lg.es.un_420 yo.gd.un_760
  0x13000a04, 0x2500290c, 0x0c00130e, 0x1b3112ec,   // pt.et.un_320 sl.eu.un_530  et.sv.un_550 hu.az.tr_644
  0x1e1c6bee, 0x2a1c55ee, 0x35076407, 0x27053ba0,   // ceb.id.ms_422 rw.id.mt_422  lg.it.zu_432 so.fr.gd_322
  // [2f70]
  0x0d2d0c04, 0x0e002007, 0x201e0405, 0x080e2aa6,   // sv.sk.cs_332 sq.is.un_420  fi.ms.sq_333 mt.is.no_521
  0x0c4a53a9, 0x13280405, 0x1f000a04, 0x12190512,   // ht.yo.sv_544 fi.sw.et_333  pt.cy.un_320 fr.gl.hu_654
  0x0802100c, 0x0f1f1307, 0x31002802, 0x1b080305,   // lt.da.no_543 et.cy.lv_432  sw.az.un_220 nl.no.tr_333
  0x0f0906a6, 0x210510a0, 0x07321608, 0x08102004,   // de.pl.lv_521 lt.fr.jw_322  hr.bs.it_443 sq.lt.no_332
  // [2f80]
  0x6b1613a0, 0x25001305, 0x1f001907, 0x1b005312,   // et.hr.ceb_322 et.eu.un_330  gl.cy.un_420 ht.tr.un_640
  0x1f1012af, 0x2725020d, 0x3b5509ad, 0x19002804,   // hu.lt.cy_655 da.eu.gd_554  pl.rw.so_643 sw.gl.un_320
  0x6b1a01ee, 0x2d0d09a9, 0x0b1905ee, 0x0d00290d,   // en.tl.ceb_422 pl.cs.sk_544  fr.gl.es_422 sl.cs.un_540
  0x28003b0d, 0x1e000504, 0x08022902, 0x10170409,   // so.sw.un_540 fr.ms.un_320  sl.da.no_222 ru.sr.be_444
  // [2f90]
  0x25311107, 0x4a000b02, 0x0b00550c, 0x216b06a0,   // ro.az.eu_432 es.yo.un_220  rw.es.un_530 de.ceb.jw_322
  0x3f0e0609, 0x0d001907, 0x1f2301a4, 0x2d0d20a0,   // de.is.af_444 gl.cs.un_420  en.ca.cy_433 sq.cs.sk_322
  0x3f000202, 0x01002807, 0x184a2b08, 0x171629a4,   // da.af.un_220 sw.en.un_420  vi.yo.ga_443 sl.hr.sr_433
  0x021b0ea4, 0x0c061107, 0x01001804, 0x321b20a0,   // is.tr.da_433 ro.de.sv_432  ga.en.un_320 sq.tr.bs_322
  // [2fa0]
  0x061e1bee, 0x3b276bee, 0x0d0a2da4, 0x64525505,   // tr.ms.de_422 ceb.gd.so_422  sk.pt.cs_433 rw.ha.lg_333
  0x101f25ad, 0x1f0d2d11, 0x28355505, 0x13001007,   // eu.cy.lt_643 sk.cs.cy_653  rw.zu.sw_333 lt.et.un_420
  0x251304ee, 0x115301a7, 0x0f000404, 0x13642805,   // fi.et.eu_422 en.ht.ro_532  fi.lv.un_320 sw.lg.et_333
  0x043b13a0, 0x21000a07, 0x0f00090d, 0x19002504,   // et.so.fi_322 pt.jw.un_420  pl.lv.un_540 eu.gl.un_320
  // [2fb0]
  0x0e0208a4, 0x2a080ca9, 0x2b000113, 0x64002905,   // no.da.is_433 sv.no.mt_544  en.vi.un_650 sl.lg.un_330
  0x1e683504, 0x352031a4, 0x076b0a04, 0x2500050c,   // zu.ig.ms_332 az.sq.zu_433  pt.ceb.it_332 fr.eu.un_530
  0x07100aa4, 0x640f13a0, 0x3f6b1a0d, 0x28216813,   // mk.be.bg_433 et.lv.lg_322  tl.ceb.af_554 ig.jw.sw_665
  0x2d0d5509, 0x2100030c, 0x083f0ca4, 0x122d18ee,   // rw.cs.sk_444 nl.jw.un_530  sv.af.no_433 ga.sk.hu_422
  // [2fc0]
  0x27000708, 0x0c022d12, 0x6b00550d, 0x1c211e11,   // it.gd.un_430 sk.da.sv_654  rw.ceb.un_540 ms.jw.id_653
  0x06006b12, 0x28000304, 0x3f001212, 0x25000308,   // ceb.de.un_640 nl.sw.un_320  hu.af.un_640 nl.eu.un_430
  0x6e00200e, 0x1b0d0302, 0x0d002502, 0x20000b04,   // sq.hmn.un_550 nl.cs.tr_222  eu.cs.un_220 es.sq.un_320
  0x190910a0, 0x18310707, 0x531213a7, 0x13003f0d,   // lt.pl.gl_322 it.az.ga_432  et.hu.ht_532 af.et.un_540
  // [2fd0]
  0x3b000907, 0x16003502, 0x1c130d05, 0x12002b08,   // pl.so.un_420 zu.hr.un_220  ne.bh.mr_333 vi.hu.un_430
  0x2300120d, 0x032d010b, 0x060e0107, 0x03002804,   // hu.ca.un_540 en.sk.nl_542  en.is.de_432 sw.nl.un_320
  0x01004a04, 0x53680dec, 0x0d292da0, 0x1c130905,   // yo.en.un_320 cs.ig.ht_644  sk.sl.cs_322 hi.bh.mr_333
  0x283b64ec, 0x10001a02, 0x180a12ac, 0x3f04130c,   // lg.so.sw_644 tl.lt.un_220  hu.pt.ga_632 et.fi.af_543
  // [2fe0]
  0x4a250408, 0x04001b0e, 0x0d1f2d07, 0x0e002111,   // fi.eu.yo_443 tr.fi.un_550  sk.cy.cs_432 jw.is.un_630
  0x096864ee, 0x316b3ba7, 0x12291307, 0x1125010c,   // lg.ig.pl_422 so.ceb.az_532  et.sl.hu_432 en.eu.ro_543
  0x20000e02, 0x0d000a04, 0x052d0305, 0x53055507,   // is.sq.un_220 pt.cs.un_320  nl.sk.fr_333 rw.fr.ht_432
  0x21005202, 0x1e003b0e, 0x0a0e0204, 0x3100030d,   // ha.jw.un_220 so.ms.un_550  da.is.pt_332 nl.az.un_540
  // [2ff0]
  0x554a2802, 0x35003b19, 0x18004a12, 0x3f000611,   // sw.yo.rw_222 so.zu.un_750  yo.ga.un_640 de.af.un_630
  0x1b1a530c, 0x3f1c0302, 0x176813ee, 0x2d0d0e05,   // ht.tl.tr_543 nl.id.af_222  et.ig.sr_422 is.cs.sk_333
  0x1b000104, 0x1b0131ee, 0x0d000407, 0x3b1f53a0,   // en.tr.un_320 az.en.tr_422  fi.cs.un_420 ht.cy.so_322
  0x1635030c, 0x111320ee, 0x1e005504, 0x0413180c,   // nl.zu.hr_543 sq.et.ro_422  rw.ms.un_320 ga.et.fi_543

  // [3000]
  0x53000309, 0x172d29a6, 0x03310fa0, 0x0f0820a0,   // nl.ht.un_440 sl.sk.sr_521  lv.az.nl_322 sq.no.lv_322
  0x320413ad, 0x290d53a0, 0x0a530107, 0x18002512,   // et.fi.bs_643 ht.cs.sl_322  en.ht.pt_432 eu.ga.un_640
  0x1b003b09, 0x12000412, 0x28041aa0, 0x314a1b05,   // so.tr.un_440 fi.hu.un_640  tl.fi.sw_322 tr.yo.az_333
  0x280501a4, 0x2d2b0907, 0x0a0804a0, 0x280d2d11,   // en.fr.sw_433 pl.vi.sk_432  ru.uk.mk_322 sk.cs.sw_653
  // [3010]
  0x3513040c, 0x0e08100c, 0x09006e07, 0x64002a07,   // fi.et.zu_543 lt.no.is_543  hmn.pl.un_420 mt.lg.un_420
  0x20002904, 0x0e130cee, 0x1b313ba7, 0x6b001f04,   // sl.sq.un_320 sv.et.is_422  so.az.tr_532 cy.ceb.un_320
  0x1e005208, 0x100a1705, 0x6e002013, 0x0b000a07,   // ha.ms.un_430 sr.mk.be_333  sq.hmn.un_650 pt.es.un_420
  0x53180d07, 0x1e00040c, 0x06080209, 0x2a5303a7,   // cs.ga.ht_432 fi.ms.un_530  da.no.de_444 nl.ht.mt_532
  // [3020]
  0x55213512, 0x190b0aec, 0x21002802, 0x0f001007,   // zu.jw.rw_654 pt.es.gl_644  sw.jw.un_220 lt.lv.un_420
  0x0e083fa4, 0x0a000d13, 0x1e1c1a0c, 0x3f001e04,   // af.no.is_433 cs.pt.un_650  tl.id.ms_543 ms.af.un_320
  0x122d1304, 0x080235a4, 0x5500350c, 0x0e182308,   // et.sk.hu_332 zu.da.no_433  zu.rw.un_530 ca.ga.is_443
  0x01000607, 0x1e000a07, 0x020c08a0, 0x11001022,   // de.en.un_420 pt.ms.un_420  no.sv.da_322 be.ro.un_870
  // [3030]
  0x2a006413, 0x03103f55, 0x13552808, 0x10003202,   // lg.mt.un_650 af.lt.nl_442  sw.rw.et_443 bs.lt.un_220
  0x2d0d0cee, 0x11000607, 0x1200110e, 0x02001704,   // sv.cs.sk_422 de.ro.un_420  ro.hu.un_550 sr.da.un_320
  0x081704a0, 0x1f28520c, 0x09002702, 0x2d040dee,   // ru.sr.uk_322 ha.sw.cy_543  gd.pl.un_220 cs.fi.sk_422
  0x2d0d180e, 0x3f00110d, 0x04001b13, 0x524a3ba0,   // ga.cs.sk_555 ro.af.un_540  tr.fi.un_650 so.yo.ha_322
  // [3040]
  0x1b1c28a0, 0x0400020c, 0x0e000407, 0x090312ec,   // sw.id.tr_322 da.fi.un_530  fi.is.un_420 hu.nl.pl_644
  0x27002b0e, 0x120e0860, 0x03643b07, 0x2d291207,   // vi.gd.un_550 no.is.hu_664  so.lg.nl_432 hu.sl.sk_432
  0x06001a0b, 0x122d2007, 0x066b13a9, 0x1b001602,   // tl.de.un_520 sq.sk.hu_432  et.ceb.de_544 hr.tr.un_220
  0x35135504, 0x1a280405, 0x53003118, 0x6b001e0d,   // rw.et.zu_332 fi.sw.tl_333  az.ht.un_740 ms.ceb.un_540
  // [3050]
  0x03002507, 0x0e0c080c, 0x2a1206ee, 0x2d030602,   // eu.nl.un_420 no.sv.is_543  de.hu.mt_422 de.nl.sk_222
  0x0c001a0c, 0x20000804, 0x29000d04, 0x1f00030d,   // tl.sv.un_530 no.sq.un_320  cs.sl.un_320 nl.cy.un_540
  0x1f060ea9, 0x05001907, 0x04002019, 0x6800280e,   // is.de.cy_544 gl.fr.un_420  sq.fi.un_750 sw.ig.un_550
  0x09000f0c, 0x0b002302, 0x1928350c, 0x0f1b31a6,   // lv.pl.un_530 ca.es.un_220  zu.sw.gl_543 az.tr.lv_521
  // [3060]
  0x0d172da0, 0x0c000302, 0x182927a0, 0x3f03230c,   // sk.sr.cs_322 nl.sv.un_220  gd.sl.ga_322 ca.nl.af_543
  0x061b31ec, 0x100f31a7, 0x1f000614, 0x160f1bad,   // az.tr.de_644 az.lv.lt_532  de.cy.un_660 tr.lv.hr_643
  0x16002919, 0x016b05a9, 0x04000707, 0x68003108,   // sl.hr.un_750 fr.ceb.en_544  bg.ru.un_420 az.ig.un_430
  0x52002a07, 0x1a6b53af, 0x530f1005, 0x4a001307,   // mt.ha.un_420 ht.ceb.tl_655  lt.lv.ht_333 et.yo.un_420
  // [3070]
  0x043f080c, 0x0c3525a0, 0x08170414, 0x040717a9,   // no.af.fi_543 eu.zu.sv_322  ru.sr.uk_666 sr.bg.ru_544
  0x0d110505, 0x311b35ee, 0x1b312a12, 0x02000611,   // fr.ro.cs_333 zu.tr.az_422  mt.az.tr_654 de.da.un_630
  0x132555a7, 0x09003f07, 0x0d53055a, 0x0600030d,   // rw.eu.et_532 af.pl.un_420  fr.ht.cs_553 nl.de.un_540
  0x05030107, 0x31005504, 0x27000a07, 0x3f033b0d,   // en.nl.fr_432 rw.az.un_320  pt.gd.un_420 so.nl.af_554
  // [3080]
  0x28000702, 0x25355512, 0x2d00180c, 0x3b001b0d,   // it.sw.un_220 rw.zu.eu_654  ga.sk.un_530 tr.so.un_540
  0x0d000f09, 0x6b001105, 0x530e2707, 0x2b001812,   // lv.cs.un_440 ro.ceb.un_330  gd.is.ht_432 ga.vi.un_640
  0x4a002512, 0x32351b04, 0x321355a0, 0x18270660,   // eu.yo.un_640 tr.zu.bs_332  rw.et.bs_322 de.gd.ga_664
  0x321b31a0, 0x19001807, 0x101e1c08, 0x55000e07,   // az.tr.bs_322 ga.gl.un_420  id.ms.lt_443 is.rw.un_420
  // [3090]
  0x13020d0c, 0x1a2a6ba7, 0x090d050d, 0x01000d04,   // cs.da.et_543 ceb.mt.tl_532  fr.cs.pl_554 cs.en.un_320
  0x27002302, 0x53173b07, 0x02001812, 0x08101fad,   // ca.gd.un_220 so.sr.ht_432  ga.da.un_640 cy.lt.no_643
  0x4a00280e, 0x311b11ac, 0x3f005302, 0x110c1fa7,   // sw.yo.un_550 ro.tr.az_632  ht.af.un_220 cy.sv.ro_532
  0x0e002302, 0x6b1701ee, 0x016b04ee, 0x131a3512,   // ca.is.un_220 en.sr.ceb_422  fi.ceb.en_422 zu.tl.et_654
  // [30a0]
  0x0a002a02, 0x254a3fa0, 0x4a1e0fa0, 0x641325a4,   // mt.pt.un_220 af.yo.eu_322  lv.ms.yo_322 eu.et.lg_433
  0x121b13a9, 0x3b350e07, 0x5300290e, 0x06040e0c,   // et.tr.hu_544 is.zu.so_432  sl.ht.un_550 is.fi.de_543
  0x6b0401ee, 0x2d100d12, 0x0b002802, 0x1f001a07,   // en.fi.ceb_422 cs.lt.sk_654  sw.es.un_220 tl.cy.un_420
  0x01002902, 0x3b00130c, 0x13040111, 0x2b000d04,   // sl.en.un_220 et.so.un_530  en.fi.et_653 cs.vi.un_320
  // [30b0]
  0x6b6801a0, 0x0e003b05, 0x06003105, 0x08060ea0,   // en.ig.ceb_322 so.is.un_330  az.de.un_330 is.de.no_322
  0x0d311b12, 0x0a003b07, 0x4a002308, 0x522a4aa7,   // tr.az.cs_654 so.pt.un_420  ca.yo.un_430 yo.mt.ha_532
  0x0d000c02, 0x35554aec, 0x31002512, 0x3100280d,   // sv.cs.un_220 yo.rw.zu_644  eu.az.un_640 sw.az.un_540
  0x21001108, 0x2d0d2905, 0x2a000307, 0x200c2da6,   // ro.jw.un_430 sl.cs.sk_333  nl.mt.un_420 sk.sv.sq_521
  // [30c0]
  0x080c02a9, 0x0f002b0e, 0x0c311b12, 0x126b2802,   // da.sv.no_544 vi.lv.un_550  tr.az.sv_654 sw.ceb.hu_222
  0x09000702, 0x29001a04, 0x01000f07, 0x1b001302,   // it.pl.un_220 tl.sl.un_320  lv.en.un_420 et.tr.un_220
  0x52000504, 0x641b5505, 0x3f4a130b, 0x2b001002,   // fr.ha.un_320 rw.tr.lg_333  et.yo.af_542 lt.vi.un_220
  0x0f002b07, 0x03000204, 0x0f1206ee, 0x6b53010c,   // vi.lv.un_420 da.nl.un_320  de.hu.lv_422 en.ht.ceb_543
  // [30d0]
  0x120609ec, 0x11070805, 0x272818a4, 0x1b00210e,   // pl.de.hu_644 uk.bg.ro_333  ga.sw.gd_433 jw.tr.un_550
  0x00002724, 0x6b000612, 0x556828ad, 0x18280a0c,   // gd.un.un_900 de.ceb.un_640  sw.ig.rw_643 pt.sw.ga_543
  0x3f1368ee, 0x53001e02, 0x23001212, 0x0e001318,   // ig.et.af_422 ms.ht.un_220  hu.ca.un_640 et.is.un_740
  0x1a130f07, 0x0d2d090b, 0x53092d02, 0x0b643ba0,   // lv.et.tl_432 pl.sk.cs_542  sk.pl.ht_222 so.lg.es_322
  // [30e0]
  0x12041bee, 0x2700070c, 0x2d0910ec, 0x051813a7,   // tr.fi.hu_422 it.gd.un_530  lt.pl.sk_644 et.ga.fr_532
  0x53182d04, 0x23110508, 0x135201a4, 0x080e1002,   // sk.ga.ht_332 fr.ro.ca_443  en.ha.et_433 lt.is.no_222
  0x551c05ee, 0x2d0d290c, 0x2d000704, 0x52002504,   // fr.id.rw_422 sl.cs.sk_543  it.sk.un_320 eu.ha.un_320
  0x25002d08, 0x0e002307, 0x321611a9, 0x21272807,   // sk.eu.un_430 ca.is.un_420  ro.hr.bs_544 sw.gd.jw_432
  // [30f0]
  0x12230ea4, 0x02080c5a, 0x04130ca9, 0x2d0d0ea9,   // is.ca.hu_433 sv.no.da_553  sv.et.fi_544 is.cs.sk_544
  0x0200270c, 0x2d090d07, 0x1a003202, 0x092a29a9,   // gd.da.un_530 cs.pl.sk_432  bs.tl.un_220 sl.mt.pl_544
  0x31521ba4, 0x31053ba0, 0x321827a9, 0x181f2760,   // tr.ha.az_433 so.fr.az_322  gd.ga.bs_544 gd.cy.ga_664
  0x25000b04, 0x130304a4, 0x08000319, 0x0e3f030d,   // es.eu.un_320 fi.nl.et_433  nl.no.un_750 nl.af.is_554
  // [3100]
  0x2a033f05, 0x051f0702, 0x1e0f2508, 0x07111f02,   // af.nl.mt_333 it.cy.fr_222  eu.lv.ms_443 cy.ro.it_222
  0x4a1b2807, 0x17291604, 0x1a002d08, 0x5300230d,   // sw.tr.yo_432 hr.sl.sr_332  sk.tl.un_430 ca.ht.un_540
  0x3b1a6b08, 0x322d090c, 0x0d1f31a4, 0x53003513,   // ceb.tl.so_443 pl.sk.bs_543  az.cy.cs_433 zu.ht.un_650
  0x2b006809, 0x20132aad, 0x2b000a07, 0x050409ad,   // ig.vi.un_440 mt.et.sq_643  pt.vi.un_420 pl.fi.fr_643
  // [3110]
  0x2a3b03a0, 0x28182a05, 0x10000809, 0x0c040607,   // nl.so.mt_322 mt.ga.sw_333  uk.be.un_440 de.fi.sv_432
  0x3b6b3508, 0x0d642d0c, 0x07002502, 0x12000407,   // zu.ceb.so_443 sk.lg.cs_543  eu.it.un_220 fi.hu.un_420
  0x270e1812, 0x19010d07, 0x02180c02, 0x1f312705,   // ga.is.gd_654 cs.en.gl_432  sv.ga.da_222 gd.az.cy_333
  0x2a0823ee, 0x10352da0, 0x280503a6, 0x1f00271a,   // ca.no.mt_422 sk.zu.lt_322  nl.fr.sw_521 gd.cy.un_760
  // [3120]
  0x13002a0d, 0x25190a5a, 0x232507a7, 0x070511a4,   // mt.et.un_540 pt.gl.eu_553  it.eu.ca_532 ro.fr.it_433
  0x1b003202, 0x12000a07, 0x280318a0, 0x31000a02,   // bs.tr.un_220 pt.hu.un_420  ga.nl.sw_322 pt.az.un_220
  0x55004a0c, 0x0f2012ad, 0x190a0ba0, 0x0a0d180c,   // yo.rw.un_530 hu.sq.lv_643  es.pt.gl_322 ga.cs.pt_543
  0x251b0107, 0x290f09a4, 0x0700180d, 0x2155280d,   // en.tr.eu_432 pl.lv.sl_433  ga.it.un_540 sw.rw.jw_554
  // [3130]
  0x4a0a050c, 0x18003f07, 0x2a313ba4, 0x1c21550c,   // fr.pt.yo_543 af.ga.un_420  so.az.mt_433 rw.jw.id_543
  0x2300270e, 0x6b1801ee, 0x133f1155, 0x4a253104,   // gd.ca.un_550 en.ga.ceb_422  ro.af.et_442 az.eu.yo_332
  0x18273f04, 0x03133fa0, 0x23001b08, 0x0500230b,   // af.gd.ga_332 af.et.nl_322  tr.ca.un_430 ca.fr.un_520
  0x3f000609, 0x321617af, 0x256455a4, 0x23002710,   // de.af.un_440 sr.hr.bs_655  rw.lg.eu_433 gd.ca.un_620
  // [3140]
  0x1f000a0d, 0x4a001312, 0x1f002b07, 0x35000304,   // pt.cy.un_540 et.yo.un_640  vi.cy.un_420 nl.zu.un_320
  0x35642512, 0x2d0d53a0, 0x084a2807, 0x0f004a0e,   // eu.lg.zu_654 ht.cs.sk_322  sw.yo.no_432 yo.lv.un_550
  0x190c010b, 0x290916a4, 0x642a2802, 0x552528a0,   // en.sv.gl_542 hr.pl.sl_433  sw.mt.lg_222 sw.eu.rw_322
  0x112307ee, 0x55001311, 0x06045309, 0x0d0311a4,   // it.ca.ro_422 et.rw.un_630  ht.fi.de_444 ro.nl.cs_433
  // [3150]
  0x21132aa4, 0x1c121ea9, 0x1b033f05, 0x0811100e,   // mt.et.jw_433 ms.hu.id_544  af.nl.tr_333 be.ro.uk_555
  0x21554a0c, 0x271f6402, 0x031b06a0, 0x0813040e,   // yo.rw.jw_543 lg.cy.gd_222  de.tr.nl_322 fi.et.no_555
  0x08021f04, 0x551225a9, 0x556812ec, 0x1b060305,   // cy.da.no_332 eu.hu.rw_544  hu.ig.rw_644 nl.de.tr_333
  0x2d0d120e, 0x07030612, 0x2300250e, 0x20002312,   // hu.cs.sk_555 de.nl.it_654  eu.ca.un_550 ca.sq.un_640
  // [3160]
  0x0f103104, 0x310e3b55, 0x2500180d, 0x1f000a02,   // az.lt.lv_332 so.is.az_442  ga.eu.un_540 pt.cy.un_220
  0x3120050c, 0x0a002d04, 0x06002d07, 0x1a4a3bee,   // fr.sq.az_543 sk.pt.un_320  sk.de.un_420 so.yo.tl_422
  0x0e002902, 0x07003b07, 0x1f001a02, 0x1c3f030c,   // sl.is.un_220 so.it.un_420  tl.cy.un_220 nl.af.id_543
  0x0a2b0ca0, 0x35535507, 0x13002d04, 0x02090302,   // sv.vi.pt_322 rw.ht.zu_432  sk.et.un_320 nl.pl.da_222
  // [3170]
  0x20006b04, 0x0b0a0605, 0x19002d07, 0x0e0320ee,   // ceb.sq.un_320 de.pt.es_333  sk.gl.un_420 sq.nl.is_422
  0x55001b0e, 0x211c0aa0, 0x35000707, 0x31091b55,   // tr.rw.un_550 pt.id.jw_322  it.zu.un_420 tr.pl.az_442
  0x033f3b07, 0x16133207, 0x4a0912ad, 0x20311155,   // so.af.nl_432 bs.et.hr_432  hu.pl.yo_643 ro.az.sq_442
  0x0d091c04, 0x2000350c, 0x2d190b0c, 0x1f00110e,   // mr.hi.ne_332 zu.sq.un_530  es.gl.sk_543 ro.cy.un_550
  // [3180]
  0x0d292da4, 0x53000113, 0x3f030da0, 0x21231702,   // sk.sl.cs_433 en.ht.un_650  cs.nl.af_322 sr.ca.jw_222
  0x2a00030b, 0x070a05ee, 0x29005302, 0x1e000908,   // nl.mt.un_520 fr.pt.it_422  ht.sl.un_220 pl.ms.un_430
  0x0b191311, 0x29000c0c, 0x3f53030c, 0x0c1810a6,   // et.gl.es_653 sv.sl.un_530  nl.ht.af_543 lt.ga.sv_521
  0x3f000505, 0x3b1827ad, 0x07001307, 0x524a5304,   // fr.af.un_330 gd.ga.so_643  et.it.un_420 ht.yo.ha_332
  // [3190]
  0x3b1b64a0, 0x21002009, 0x2b001a02, 0x280c200c,   // lg.tr.so_322 sq.jw.un_440  tl.vi.un_220 sq.sv.sw_543
  0x1f003f02, 0x1a353b07, 0x13001b0e, 0x07001f0e,   // af.cy.un_220 so.zu.tl_432  tr.et.un_550 cy.it.un_550
  0x0b190a08, 0x3f000e0d, 0x230c55a0, 0x64006814,   // pt.gl.es_443 is.af.un_540  rw.sv.ca_322 ig.lg.un_660
  0x0200050d, 0x1f002012, 0x190b0a02, 0x03310208,   // fr.da.un_540 sq.cy.un_640  pt.es.gl_222 da.az.nl_443
  // [31a0]
  0x25003f04, 0x6e000f05, 0x09123507, 0x0c001102,   // af.eu.un_320 lv.hmn.un_330  zu.hu.pl_432 ro.sv.un_220
  0x0a0711a6, 0x030210ee, 0x35004a1a, 0x35536404,   // ro.bg.mk_521 lt.da.nl_422  yo.zu.un_760 lg.ht.zu_332
  0x1e000f07, 0x13000407, 0x1b3501a4, 0x2700350e,   // lv.ms.un_420 fi.et.un_420  en.zu.tr_433 zu.gd.un_550
  0x13090d05, 0x0e000a02, 0x55523560, 0x13001212,   // ne.hi.bh_333 pt.is.un_220  zu.ha.rw_664 hu.et.un_640
  // [31b0]
  0x130f10a4, 0x0f002312, 0x09100fa9, 0x64001a02,   // lt.lv.et_433 ca.lv.un_640  lv.lt.pl_544 tl.lg.un_220
  0x29101602, 0x130f0dee, 0x31290fec, 0x1c002807,   // hr.lt.sl_222 cs.lv.et_422  lv.sl.az_644 sw.id.un_420
  0x0f2920a4, 0x0100110b, 0x016b05a0, 0x11000b02,   // sq.sl.lv_433 ro.en.un_520  fr.ceb.en_322 es.ro.un_220
  0x110509ee, 0x1e003f04, 0x232a1355, 0x536b28a0,   // pl.fr.ro_422 af.ms.un_320  et.mt.ca_442 sw.ceb.ht_322
  // [31c0]
  0x12550908, 0x192312a7, 0x272018ad, 0x2a000419,   // pl.rw.hu_443 hu.ca.gl_532  ga.sq.gd_643 fi.mt.un_750
  0x5229280e, 0x13000b02, 0x0c001605, 0x23002504,   // sw.sl.ha_555 es.et.un_220  hr.sv.un_330 eu.ca.un_320
  0x190a23a0, 0x1a130fa7, 0x2500230b, 0x3217280c,   // ca.pt.gl_322 lv.et.tl_532  ca.eu.un_520 sw.sr.bs_543
  0x2b2703a0, 0x322d29a7, 0x2b003511, 0x2b001807,   // nl.gd.vi_322 sl.sk.bs_532  zu.vi.un_630 ga.vi.un_420
  // [31d0]
  0x1c00310c, 0x52000302, 0x130e28a4, 0x16352811,   // az.id.un_530 nl.ha.un_220  sw.is.et_433 sw.zu.hr_653
  0x04050fa0, 0x033f0e07, 0x12292307, 0x0d131c08,   // lv.fr.fi_322 is.af.nl_432  ca.sl.hu_432 mr.bh.ne_443
  0x08100712, 0x0c002704, 0x12200eec, 0x0f350d55,   // bg.be.uk_654 gd.sv.un_320  is.sq.hu_644 cs.zu.lv_442
  0x0d2a0e02, 0x09003b02, 0x17280804, 0x17000714,   // is.mt.cs_222 so.pl.un_220  no.sw.sr_332 bg.sr.un_660
  // [31e0]
  0x0508210c, 0x0d12020d, 0x134a35a0, 0x12003f09,   // jw.no.fr_543 da.hu.cs_554  zu.yo.et_322 af.hu.un_440
  0x0e121ba9, 0x03280f0b, 0x2a000412, 0x210908a0,   // tr.hu.is_544 lv.sw.nl_542  fi.mt.un_640 no.pl.jw_322
  0x2b00200c, 0x0f041311, 0x033f0408, 0x6b006809,   // sq.vi.un_530 et.fi.lv_653  fi.af.nl_443 ig.ceb.un_440
  0x202912ee, 0x030413a4, 0x64006809, 0x040625ac,   // hu.sl.sq_422 et.fi.nl_433  ig.lg.un_440 eu.de.fi_632
  // [31f0]
  0x09000809, 0x1e1c0eee, 0x08001212, 0x130d0955,   // no.pl.un_440 is.id.ms_422  hu.no.un_640 hi.ne.bh_442
  0x16000607, 0x6b0820ee, 0x133b640b, 0x4a522908,   // de.hr.un_420 sq.no.ceb_422  lg.so.et_542 sl.ha.yo_443
  0x19002012, 0x190b1ba0, 0x16002d07, 0x0c002302,   // sq.gl.un_640 tr.es.gl_322  sk.hr.un_420 ca.sv.un_220
  0x100e1fee, 0x3f3b01a0, 0x030c08a4, 0x2a2031a7,   // cy.is.lt_422 en.so.af_322  no.sv.nl_433 az.sq.mt_532
  // [3200]
  0x1100130c, 0x0d2a0e07, 0x1a086b0c, 0x07001207,   // et.ro.un_530 is.mt.cs_432  ceb.no.tl_543 hu.it.un_420
  0x55002013, 0x133552ad, 0x2a006404, 0x6400090d,   // sq.rw.un_650 ha.zu.et_643  lg.mt.un_320 pl.lg.un_540
  0x35280604, 0x20060ea0, 0x3b000e02, 0x1109290c,   // de.sw.zu_332 is.de.sq_322  is.so.un_220 sl.pl.ro_543
  0x3f000214, 0x05291111, 0x3100180e, 0x17001002,   // da.af.un_660 ro.sl.fr_653  ga.az.un_550 be.sr.un_220
  // [3210]
  0x0e2708af, 0x321710ee, 0x3b6b6808, 0x130d0960,   // no.gd.is_655 lt.sr.bs_422  ig.ceb.so_443 hi.ne.bh_664
  0x20082aa0, 0x1e552aa0, 0x645328ee, 0x0711040e,   // mt.no.sq_322 mt.rw.ms_322  sw.ht.lg_422 ru.ro.bg_555
  0x03001112, 0x2a006b04, 0x13553511, 0x131102ee,   // ro.nl.un_640 ceb.mt.un_320  zu.rw.et_653 da.ro.et_422
  0x0c030602, 0x12000607, 0x11041705, 0x131108a4,   // de.nl.sv_222 de.hu.un_420  sr.ru.ro_333 no.ro.et_433
  // [3220]
  0x64351207, 0x04033fa6, 0x6b183b05, 0x25001904,   // hu.zu.lg_432 af.nl.fi_521  so.ga.ceb_333 gl.eu.un_320
  0x0f000407, 0x28003b04, 0x01000412, 0x020313ee,   // fi.lv.un_420 so.sw.un_320  fi.en.un_640 et.nl.da_422
  0x64130307, 0x13002818, 0x10001213, 0x0e00050d,   // nl.et.lg_432 sw.et.un_740  hu.lt.un_650 fr.is.un_540
  0x074a53a0, 0x3528640c, 0x1c121fa4, 0x5500250c,   // ht.yo.it_322 lg.sw.zu_543  cy.hu.id_433 eu.rw.un_530
  // [3230]
  0x0c060e0e, 0x1b002d14, 0x04060e0c, 0x641b31ad,   // is.de.sv_555 sk.tr.un_660  is.de.fi_543 az.tr.lg_643
  0x2d31290c, 0x0c001704, 0x11170408, 0x130e2508,   // sl.az.sk_543 sr.sv.un_320  ru.sr.ro_443 eu.is.et_443
  0x3f080309, 0x1200310d, 0x32281609, 0x12200204,   // nl.no.af_444 az.hu.un_540  hr.sw.bs_444 da.sq.hu_332
  0x0f28040d, 0x0e002808, 0x13002308, 0x2d0d01a0,   // fi.sw.lv_554 sw.is.un_430  ca.et.un_430 en.cs.sk_322
  // [3240]
  0x13063f0c, 0x2d080da0, 0x031f01ec, 0x530d2905,   // af.de.et_543 cs.no.sk_322  en.cy.nl_644 sl.cs.ht_333
  0x250623a4, 0x08002a02, 0x0c005504, 0x181364a0,   // ca.de.eu_433 mt.no.un_220  rw.sv.un_320 lg.et.ga_322
  0x6b211aa9, 0x230f010c, 0x28006409, 0x191f28ee,   // tl.jw.ceb_544 en.lv.ca_543  lg.sw.un_440 sw.cy.gl_422
  0x01230f0d, 0x03003b04, 0x1f3b2a05, 0x1e003502,   // lv.ca.en_554 so.nl.un_320  mt.so.cy_333 zu.ms.un_220
  // [3250]
  0x2b1320a7, 0x040820a9, 0x10006407, 0x124a2d09,   // sq.et.vi_532 sq.no.fi_544  lg.lt.un_420 sk.yo.hu_444
  0x4a003508, 0x20000409, 0x2a001104, 0x2112010c,   // zu.yo.un_430 fi.sq.un_440  ro.mt.un_320 en.hu.jw_543
  0x1701080b, 0x4a005319, 0x04003512, 0x1b001a07,   // no.en.sr_542 ht.yo.un_750  zu.fi.un_640 tl.tr.un_420
  0x0f005204, 0x1b311313, 0x060910ad, 0x2d005504,   // ha.lv.un_320 et.az.tr_665  lt.pl.de_643 rw.sk.un_320
  // [3260]
  0x4a002112, 0x0e00180c, 0x10170412, 0x2b1c210c,   // jw.yo.un_640 ga.is.un_530  ru.sr.be_654 jw.id.vi_543
  0x5216050b, 0x1c0b27ee, 0x52006413, 0x13005507,   // fr.hr.ha_542 gd.es.id_422  lg.ha.un_650 rw.et.un_420
  0x19002702, 0x1b005302, 0x20003b0c, 0x10005204,   // gd.gl.un_220 ht.tr.un_220  so.sq.un_530 ha.lt.un_320
  0x080c1fac, 0x55210802, 0x0d001e04, 0x27000702,   // cy.sv.no_632 no.jw.rw_222  ms.cs.un_320 it.gd.un_220
  // [3270]
  0x25100507, 0x0c002507, 0x0d0929a0, 0x20100fee,   // fr.lt.eu_432 eu.sv.un_420  sl.pl.cs_322 lv.lt.sq_422
  0x08130e11, 0x1c351e07, 0x282129ec, 0x050311a4,   // is.et.no_653 ms.zu.id_432  sl.jw.sw_644 ro.nl.fr_433
  0x12002b0c, 0x4a291212, 0x64553505, 0x1c130d08,   // vi.hu.un_530 hu.sl.yo_654  zu.rw.lg_333 ne.bh.mr_443
  0x03233f04, 0x2a3b31ee, 0x0c5564ac, 0x3b4a01a0,   // af.ca.nl_332 az.so.mt_422  lg.rw.sv_632 en.yo.so_322
  // [3280]
  0x6b0f01a4, 0x3b313f0c, 0x08071712, 0x190d0b02,   // en.lv.ceb_433 af.az.so_543  sr.bg.uk_654 es.cs.gl_222
  0x2d101602, 0x1b311307, 0x0d190b0d, 0x2a00230c,   // hr.lt.sk_222 et.az.tr_432  es.gl.cs_554 ca.mt.un_530
  0x2a0609ac, 0x551a64af, 0x2d0d19a4, 0x11080412,   // pl.de.mt_632 lg.tl.rw_655  gl.cs.sk_433 ru.uk.ro_654
  0x0a0711ec, 0x31003f07, 0x55250604, 0x1b0f04ad,   // ro.bg.mk_644 af.az.un_420  de.eu.rw_332 fi.lv.tr_643
  // [3290]
  0x296b1607, 0x0b0a11a9, 0x0f1032a0, 0x0a180707,   // hr.ceb.sl_432 ro.pt.es_544  bs.lt.lv_322 it.ga.pt_432
  0x6b012ba4, 0x23191104, 0x53002521, 0x28090408,   // vi.en.ceb_433 ro.gl.ca_332  eu.ht.un_860 fi.pl.sw_443
  0x0911010c, 0x09013fee, 0x01000f05, 0x01001109,   // en.ro.pl_543 af.en.pl_422  lv.en.un_330 ro.en.un_440
  0x023b3f5a, 0x1b133113, 0x0b0a11ee, 0x536e05a0,   // af.so.da_553 az.et.tr_665  ro.pt.es_422 fr.hmn.ht_322
  // [32a0]
  0x10001602, 0x0a230ea0, 0x08110405, 0x6800250e,   // hr.lt.un_220 is.ca.pt_322  ru.ro.uk_333 eu.ig.un_550
  0x01002812, 0x3b0b28a9, 0x551c21a7, 0x281f01ee,   // sw.en.un_640 sw.es.so_544  jw.id.rw_532 en.cy.sw_422
  0x0000160f, 0x2a06070c, 0x00001824, 0x07001c04,   // hr.un.un_600 it.de.mt_543  ar.un.un_900 id.it.un_320
  0x23001819, 0x2d003204, 0x4a001a14, 0x05033fa4,   // ga.ca.un_750 bs.sk.un_320  tl.yo.un_660 af.nl.fr_433
  // [32b0]
  0x28352702, 0x5300290c, 0x17000407, 0x0a002904,   // gd.zu.sw_222 sl.ht.un_530  ru.sr.un_420 sl.pt.un_320
  0x1a4a25a7, 0x0c1b31a0, 0x211120a7, 0x1c2120ad,   // eu.yo.tl_532 az.tr.sv_322  sq.ro.jw_532 sq.jw.id_643
  0x20102aee, 0x4a2025ad, 0x2500280d, 0x0a1017ec,   // mt.lt.sq_422 eu.sq.yo_643  sw.eu.un_540 sr.be.mk_644
  0x0a001f04, 0x082103a0, 0x120610a0, 0x07002302,   // cy.pt.un_320 nl.jw.no_322  lt.de.hu_322 ca.it.un_220
  // [32c0]
  0x096813a0, 0x1c0d0955, 0x23271fee, 0x1b0631a7,   // et.ig.pl_322 hi.ne.mr_442  cy.gd.ca_422 az.de.tr_532
  0x01212302, 0x1b64310e, 0x05000307, 0x35312aa0,   // ca.jw.en_222 az.lg.tr_555  nl.fr.un_420 mt.az.zu_322
  0x05233faf, 0x12641aa4, 0x640d1104, 0x130823af,   // af.ca.fr_655 tl.lg.hu_433  ro.cs.lg_332 ca.no.et_655
  0x0d001104, 0x3b00280e, 0x55000502, 0x35552b5a,   // ro.cs.un_320 sw.so.un_550  fr.rw.un_220 vi.rw.zu_553
  // [32d0]
  0x110d0a08, 0x0d120508, 0x070810ad, 0x072a0aa4,   // pt.cs.ro_443 fr.hu.cs_443  be.uk.bg_643 pt.mt.it_433
  0x1b0a010c, 0x1b2b0b09, 0x040301ee, 0x13001a02,   // en.pt.tr_543 es.vi.tr_444  en.nl.fi_422 tl.et.un_220
  0x3f6801a0, 0x081b0507, 0x033f10ec, 0x2d000e0d,   // en.ig.af_322 fr.tr.no_432  lt.af.nl_644 is.sk.un_540
  0x353f0608, 0x01001c04, 0x64280fad, 0x280e52a0,   // de.af.zu_443 id.en.un_320  lv.sw.lg_643 ha.is.sw_322
  // [32e0]
  0x233f13ee, 0x214a1304, 0x0a00230c, 0x282135ec,   // et.af.ca_422 et.yo.jw_332  ca.pt.un_530 zu.jw.sw_644
  0x2b535507, 0x1c000105, 0x35003b12, 0x180e2dad,   // rw.ht.vi_432 en.id.un_330  so.zu.un_640 sk.is.ga_643
  0x2d003207, 0x3f035205, 0x21002502, 0x0c133fa0,   // bs.sk.un_420 ha.nl.af_333  eu.jw.un_220 af.et.sv_322
  0x354a1ca0, 0x070a0813, 0x322a17a0, 0x3b2008ee,   // id.yo.zu_322 uk.mk.bg_665  sr.mt.bs_322 no.sq.so_422
  // [32f0]
  0x18000804, 0x552513a4, 0x68003505, 0x293f2d05,   // no.ga.un_320 et.eu.rw_433  zu.ig.un_330 sk.af.sl_333
  0x1b520405, 0x16296eee, 0x210b02a0, 0x13072da7,   // fi.ha.tr_333 hmn.sl.hr_422  da.es.jw_322 sk.it.et_532
  0x1a6b52ec, 0x1c1e0804, 0x03021f04, 0x080c2aa9,   // ha.ceb.tl_644 no.ms.id_332  cy.da.nl_332 mt.sv.no_544
  0x31000a07, 0x18190b5a, 0x0e002804, 0x4a520c07,   // pt.az.un_420 es.gl.ga_553  sw.is.un_320 sv.ha.yo_432
  // [3300]
  0x062009a4, 0x11070414, 0x2100270b, 0x321e5309,   // pl.sq.de_433 ru.bg.ro_666  gd.jw.un_520 ht.ms.bs_444
  0x351255a0, 0x1c090d08, 0x190b1808, 0x0f003f05,   // rw.hu.zu_322 ne.hi.mr_443  ga.es.gl_443 af.lv.un_330
  0x316b0807, 0x0911060c, 0x04001f04, 0x52004a02,   // no.ceb.az_432 de.ro.pl_543  cy.fi.un_320 yo.ha.un_220
  0x3500131a, 0x554a2904, 0x06556408, 0x23002104,   // et.zu.un_760 sl.yo.rw_332  lg.rw.de_443 jw.ca.un_320
  // [3310]
  0x1f1827a7, 0x171606a0, 0x125320ad, 0x55355213,   // gd.ga.cy_532 de.hr.sr_322  sq.ht.hu_643 ha.zu.rw_665
  0x0b1f2bad, 0x29005313, 0x0c1a120c, 0x182704a4,   // vi.cy.es_643 ht.sl.un_650  hu.tl.sv_543 fi.gd.ga_433
  0x04211012, 0x08642711, 0x236b1fad, 0x1329040c,   // lt.jw.fi_654 gd.lg.no_653  cy.ceb.ca_643 fi.sl.et_543
  0x12090804, 0x2700310c, 0x321653ee, 0x12131108,   // no.pl.hu_332 az.gd.un_530  ht.hr.bs_422 ro.et.hu_443
  // [3320]
  0x25313bad, 0x01002302, 0x1f012bee, 0x070e0107,   // so.az.eu_643 ca.en.un_220  vi.en.cy_422 en.is.it_432
  0x13002007, 0x19001818, 0x135535ee, 0x2d0d3202,   // sq.et.un_420 ga.gl.un_740  zu.rw.et_422 bs.cs.sk_222
  0x016b09ee, 0x281e3b0c, 0x27000304, 0x12003507,   // pl.ceb.en_422 so.ms.sw_543  nl.gd.un_320 zu.hu.un_420
  0x13003107, 0x18002309, 0x200e18ee, 0x0e1a55ec,   // az.et.un_420 ca.ga.un_440  ga.is.sq_422 rw.tl.is_644
  // [3330]
  0x27000204, 0x1e1c0405, 0x100428a4, 0x55203504,   // da.gd.un_320 fi.id.ms_333  sw.fi.lt_433 zu.sq.rw_332
  0x10006807, 0x042d0faf, 0x1000171a, 0x101117a4,   // ig.lt.un_420 lv.sk.fi_655  sr.be.un_760 sr.ro.be_433
  0x11201804, 0x200455a0, 0x290d2aa0, 0x2a000919,   // ga.sq.ro_332 rw.fi.sq_322  mt.cs.sl_322 pl.mt.un_750
  0x08111004, 0x2a201204, 0x29200105, 0x1f0c08a7,   // be.ro.uk_332 hu.sq.mt_332  en.sq.sl_333 no.sv.cy_532
  // [3340]
  0x0a000304, 0x030c0202, 0x0f006b07, 0x64000304,   // nl.pt.un_320 da.sv.nl_222  ceb.lv.un_420 nl.lg.un_320
  0x2a35285a, 0x350b1109, 0x551e31a9, 0x131a1bad,   // sw.zu.mt_553 ro.es.zu_444  az.ms.rw_544 tr.tl.et_643
  0x1b6b0f04, 0x551b31a9, 0x1e3b0604, 0x281a0107,   // lv.ceb.tr_332 az.tr.rw_544  de.so.ms_332 en.tl.sw_432
  0x0f23010c, 0x32000707, 0x1a3b13a0, 0x2d0d04ee,   // en.ca.lv_543 it.bs.un_420  et.so.tl_322 fi.cs.sk_422
  // [3350]
  0x201f23a7, 0x211c6405, 0x0c0e3155, 0x1a683512,   // ca.cy.sq_532 lg.id.jw_333  az.is.sv_442 zu.ig.tl_654
  0x06003f0e, 0x01001e04, 0x1b252804, 0x09001b04,   // af.de.un_550 ms.en.un_320  sw.eu.tr_332 tr.pl.un_320
  0x17002902, 0x0912180c, 0x06350e07, 0x0d022dec,   // sl.sr.un_220 ga.hu.pl_543  is.zu.de_432 sk.da.cs_644
  0x010503a4, 0x0b000c07, 0x1e683b07, 0x09002107,   // nl.fr.en_433 sv.es.un_420  so.ig.ms_432 jw.pl.un_420
  // [3360]
  0x08200405, 0x3f001108, 0x1e003b07, 0x203b13a0,   // fi.sq.no_333 ro.af.un_430  so.ms.un_420 et.so.sq_322
  0x120b0e0c, 0x190a23ee, 0x2d100904, 0x526405a0,   // is.es.hu_543 ca.pt.gl_422  pl.lt.sk_332 fr.lg.ha_322
  0x1a005504, 0x1e6b5305, 0x3b000d11, 0x2d0d10a0,   // rw.tl.un_320 ht.ceb.ms_333  cs.so.un_630 lt.cs.sk_322
  0x55353b05, 0x35643b13, 0x356410a7, 0x355528a7,   // so.zu.rw_333 so.lg.zu_665  lt.lg.zu_532 sw.rw.zu_532
  // [3370]
  0x3f0e03af, 0x06100907, 0x322d0d60, 0x082a0aa4,   // nl.is.af_655 pl.lt.de_432  cs.sk.bs_664 pt.mt.no_433
  0x31003b19, 0x04132dee, 0x0f6425ad, 0x0c060eac,   // so.az.un_750 sk.et.fi_422  eu.lg.lv_643 is.de.sv_632
  0x080c02a6, 0x11001f02, 0x02001702, 0x0d23110b,   // da.sv.no_521 cy.ro.un_220  sr.da.un_220 ro.ca.cs_542
  0x070804a7, 0x195223ee, 0x09101f08, 0x28005302,   // ru.uk.bg_532 ca.ha.gl_422  cy.lt.pl_443 ht.sw.un_220
  // [3380]
  0x20001f07, 0x646823a4, 0x13020fee, 0x10071705,   // cy.sq.un_420 ca.ig.lg_433  lv.da.et_422 sr.bg.be_333
  0x040a11a6, 0x2a070907, 0x060c0e12, 0x6b3f06a9,   // ro.mk.ru_521 pl.it.mt_432  is.sv.de_654 de.af.ceb_544
  0x01003b04, 0x1312110c, 0x1c001a02, 0x53001a07,   // so.en.un_320 ro.hu.et_543  tl.id.un_220 tl.ht.un_420
  0x250728a0, 0x060f10a4, 0x0b1b4aa4, 0x09030604,   // sw.it.eu_322 lt.lv.de_433  yo.tr.es_433 de.nl.pl_332
  // [3390]
  0x032d17a4, 0x20001018, 0x07005202, 0x066b03ee,   // sr.sk.nl_433 lt.sq.un_740  ha.it.un_220 nl.ceb.de_422
  0x050c13ee, 0x21081ca0, 0x04002005, 0x0b552507,   // et.sv.fr_422 id.no.jw_322  sq.fi.un_330 eu.rw.es_432
  0x10000d08, 0x6b1a0ca0, 0x1f001012, 0x07050aa9,   // cs.lt.un_430 sv.tl.ceb_322  lt.cy.un_640 pt.fr.it_544
  0x02003f0c, 0x190a09af, 0x0e111ba9, 0x130e1004,   // af.da.un_530 pl.pt.gl_655  tr.ro.is_544 lt.is.et_332
  // [33a0]
  0x35000d08, 0x2d0d1005, 0x21282704, 0x27122802,   // cs.zu.un_430 lt.cs.sk_333  gd.sw.jw_332 sw.hu.gd_222
  0x0b001213, 0x27002119, 0x040605ac, 0x311b5207,   // hu.es.un_650 jw.gd.un_750  fr.de.fi_632 ha.tr.az_432
  0x28004a04, 0x0b192da4, 0x3f001304, 0x6855530e,   // yo.sw.un_320 sk.gl.es_433  et.af.un_320 ht.rw.ig_555
  0x135311ee, 0x3b1a0ba0, 0x11170705, 0x5308230c,   // ro.ht.et_422 es.tl.so_322  bg.sr.ro_333 ca.no.ht_543
  // [33b0]
  0x68000f09, 0x170811ec, 0x2a2501ee, 0x081711a4,   // lv.ig.un_440 ro.uk.sr_644  en.eu.mt_422 ro.sr.uk_433
  0x190f0b0c, 0x1a002113, 0x23052da4, 0x042b200c,   // es.lv.gl_543 jw.tl.un_650  sk.fr.ca_433 sq.vi.fi_543
  0x08030404, 0x25003b13, 0x2d0e0da9, 0x1a000702,   // fi.nl.no_332 so.eu.un_650  cs.is.sk_544 it.tl.un_220
  0x1b002704, 0x04291304, 0x01001a07, 0x190b07af,   // gd.tr.un_320 et.sl.fi_332  tl.en.un_420 it.es.gl_655
  // [33c0]
  0x033f530d, 0x11070105, 0x525355ee, 0x32160e04,   // ht.af.nl_554 en.it.ro_333  rw.ht.ha_422 is.hr.bs_332
  0x2164350c, 0x01070907, 0x211b3502, 0x1a005512,   // zu.lg.jw_543 pl.it.en_432  zu.tr.jw_222 rw.tl.un_640
  0x27203b5a, 0x64000407, 0x2d0d25ec, 0x130e10a7,   // so.sq.gd_553 fi.lg.un_420  eu.cs.sk_644 lt.is.et_532
  0x06001b08, 0x23000502, 0x20191004, 0x291664a0,   // tr.de.un_430 fr.ca.un_220  lt.gl.sq_332 lg.hr.sl_322
  // [33d0]
  0x350b64a0, 0x2000130d, 0x08020eaf, 0x10001305,   // lg.es.zu_322 et.sq.un_540  is.da.no_655 et.lt.un_330
  0x1e1c12a4, 0x2b00120e, 0x64001312, 0x35115502,   // hu.id.ms_433 hu.vi.un_550  et.lg.un_640 rw.ro.zu_222
  0x10292a04, 0x033f23a0, 0x2b0e55a0, 0x0f350405,   // mt.sl.lt_332 ca.af.nl_322  rw.is.vi_322 fi.zu.lv_333
  0x321609a4, 0x1f002a0e, 0x05006408, 0x11002707,   // pl.hr.bs_433 mt.cy.un_550  lg.fr.un_430 gd.ro.un_420
  // [33e0]
  0x0d002107, 0x0b000e0d, 0x3b001318, 0x32000d08,   // jw.cs.un_420 is.es.un_540  et.so.un_740 cs.bs.un_430
  0x31211004, 0x642511a0, 0x061b0302, 0x0e051fa0,   // lt.jw.az_332 ro.eu.lg_322  nl.tr.de_222 cy.fr.is_322
  0x110b0107, 0x4a1a5507, 0x100e02a6, 0x1e002b0d,   // en.es.ro_432 rw.tl.yo_432  da.is.lt_521 vi.ms.un_540
  0x2d0d0fa9, 0x32000e0b, 0x021a25a0, 0x11001005,   // lv.cs.sk_544 is.bs.un_520  eu.tl.da_322 be.ro.un_330
  // [33f0]
  0x04132804, 0x6b0901ec, 0x1f00060e, 0x28000a04,   // sw.et.fi_332 en.pl.ceb_644  de.cy.un_550 pt.sw.un_320
  0x1f350e55, 0x0800350d, 0x18003b04, 0x2a001f05,   // is.zu.cy_442 zu.no.un_540  so.ga.un_320 cy.mt.un_330
  0x190a0802, 0x28552504, 0x0f00130d, 0x64355212,   // no.pt.gl_222 eu.rw.sw_332  et.lv.un_540 ha.zu.lg_654
  0x23001807, 0x0c1325a4, 0x10000e12, 0x0e070807,   // ga.ca.un_420 eu.et.sv_433  is.lt.un_640 no.it.is_432

  // [3400]
  0x1a213b04, 0x64004a0d, 0x29000b02, 0x20005507,   // so.jw.tl_332 yo.lg.un_540  es.sl.un_220 rw.sq.un_420
  0x04003113, 0x120b0a05, 0x3f1a09a4, 0x351e2007,   // az.fi.un_650 pt.es.hu_333  pl.tl.af_433 sq.ms.zu_432
  0x07111012, 0x18170ba0, 0x1f00210c, 0x0b183102,   // be.ro.bg_654 es.sr.ga_322  jw.cy.un_530 az.ga.es_222
  0x12000c02, 0x0f1a6bac, 0x52280e08, 0x2517270c,   // sv.hu.un_220 ceb.tl.lv_632  is.sw.ha_443 gd.sr.eu_543
  // [3410]
  0x2d170d09, 0x01132855, 0x1e1c32a0, 0x6b250aad,   // cs.sr.sk_444 sw.et.en_442  bs.id.ms_322 pt.eu.ceb_643
  0x28003f13, 0x64001a04, 0x1e1c3ba9, 0x0b2319a0,   // af.sw.un_650 tl.lg.un_320  so.id.ms_544 gl.ca.es_322
  0x1b002904, 0x280308a0, 0x011927a0, 0x0f1e35a0,   // sl.tr.un_320 no.nl.sw_322  gd.gl.en_322 zu.ms.lv_322
  0x091c13ec, 0x3b280404, 0x1e1a0405, 0x12003204,   // bh.mr.hi_644 fi.sw.so_332  fi.tl.ms_333 bs.hu.un_320
  // [3420]
  0x293216a6, 0x090d1312, 0x1f003b1a, 0x20311c02,   // hr.bs.sl_521 bh.ne.hi_654  so.cy.un_760 id.az.sq_222
  0x11001308, 0x19002b13, 0x64251ea0, 0x2a003518,   // et.ro.un_430 vi.gl.un_650  ms.eu.lg_322 zu.mt.un_740
  0x31081ba4, 0x1303060d, 0x4a0413ec, 0x1e2a3b12,   // tr.no.az_433 de.nl.et_554  et.fi.yo_644 so.mt.ms_654
  0x1a002913, 0x3b522860, 0x0c001602, 0x08023fa4,   // sl.tl.un_650 sw.ha.so_664  hr.sv.un_220 af.da.no_433
  // [3430]
  0x3f001a12, 0x100708a6, 0x3b00060c, 0x010335a0,   // tl.af.un_640 uk.bg.be_521  de.so.un_530 zu.nl.en_322
  0x28002a0c, 0x1c000a04, 0x03023f08, 0x0b11205a,   // mt.sw.un_530 pt.id.un_320  af.da.nl_443 sq.ro.es_553
  0x031f3ba4, 0x10081714, 0x17002007, 0x21002b13,   // so.cy.nl_433 sr.uk.be_666  sq.sr.un_420 vi.jw.un_650
  0x03003b13, 0x0b1223ee, 0x03130111, 0x0c002b08,   // so.nl.un_650 ca.hu.es_422  en.et.nl_653 vi.sv.un_430
  // [3440]
  0x1e006412, 0x2a550707, 0x3f2d0d60, 0x210b2055,   // lg.ms.un_640 it.rw.mt_432  cs.sk.af_664 sq.es.jw_442
  0x0a2d0d13, 0x35551aa4, 0x19180a55, 0x3f002d04,   // cs.sk.pt_665 tl.rw.zu_433  pt.ga.gl_442 sk.af.un_320
  0x21000302, 0x2b00350c, 0x2a210ea4, 0x0b005505,   // nl.jw.un_220 zu.vi.un_530  is.jw.mt_433 rw.es.un_330
  0x110407a4, 0x282164a4, 0x01210607, 0x3f070904,   // bg.ru.ro_433 lg.jw.sw_433  de.jw.en_432 pl.it.af_332
  // [3450]
  0x3f271607, 0x321701a4, 0x2a0728ac, 0x29000914,   // hr.gd.af_432 en.sr.bs_433  sw.it.mt_632 pl.sl.un_660
  0x10003b13, 0x08023f07, 0x011911ee, 0x041213a0,   // so.lt.un_650 af.da.no_432  ro.gl.en_422 et.hu.fi_322
  0x0e000307, 0x1a1e10a9, 0x68523513, 0x12092d08,   // nl.is.un_420 lt.ms.tl_544  zu.ha.ig_665 sk.pl.hu_443
  0x1827010c, 0x081323ee, 0x32001e02, 0x020c08a7,   // en.gd.ga_543 ca.et.no_422  ms.bs.un_220 no.sv.da_532
  // [3460]
  0x2035130c, 0x271301ee, 0x1827130c, 0x19001f04,   // et.zu.sq_543 en.et.gd_422  et.gd.ga_543 cy.gl.un_320
  0x6b2701ad, 0x12002b18, 0x120420af, 0x03073f09,   // en.gd.ceb_643 vi.hu.un_740  sq.fi.hu_655 af.it.nl_444
  0x64071305, 0x0f551b0c, 0x55040112, 0x02112007,   // et.it.lg_333 tr.rw.lv_543  en.fi.rw_654 sq.ro.da_432
  0x081f0ca0, 0x550f11a0, 0x17003204, 0x25211007,   // sv.cy.no_322 ro.lv.rw_322  bs.sr.un_320 lt.jw.eu_432
  // [3470]
  0x211202a0, 0x08350d0c, 0x190a2502, 0x3500550b,   // da.hu.jw_322 cs.zu.no_543  eu.pt.gl_222 rw.zu.un_520
  0x11000614, 0x112705ee, 0x642a10af, 0x1800270b,   // de.ro.un_660 fr.gd.ro_422  lt.mt.lg_655 gd.ga.un_520
  0x1c002b07, 0x1b311fec, 0x251c21ee, 0x64001005,   // vi.id.un_420 cy.az.tr_644  jw.id.eu_422 lt.lg.un_330
  0x2023110c, 0x13001104, 0x2800100e, 0x0d1c0907,   // ro.ca.sq_543 ro.et.un_320  lt.sw.un_550 hi.mr.ne_432
  // [3480]
  0x3f000804, 0x1c000307, 0x0a3504a6, 0x21005313,   // no.af.un_320 nl.id.un_420  fi.zu.pt_521 ht.jw.un_650
  0x2b550504, 0x06130fa0, 0x06090112, 0x133f6408,   // fr.rw.vi_332 lv.et.de_322  en.pl.de_654 lg.af.et_443
  0x0f002004, 0x55645308, 0x08070a10, 0x1b006418,   // sq.lv.un_320 ht.lg.rw_443  mk.bg.uk_642 lg.tr.un_740
  0x041c2502, 0x12002804, 0x2153050d, 0x3f643ba9,   // eu.id.fi_222 sw.hu.un_320  fr.ht.jw_554 so.lg.af_544
  // [3490]
  0x1c005307, 0x092a4aee, 0x25000c0b, 0x1e2835ac,   // ht.id.un_420 yo.mt.pl_422  sv.eu.un_520 zu.sw.ms_632
  0x6b1a08a0, 0x130c08ec, 0x05003b02, 0x131b04ec,   // no.tl.ceb_322 no.sv.et_644  so.fr.un_220 fi.tr.et_644
  0x0e004a07, 0x1e1c1004, 0x182704af, 0x1b000508,   // yo.is.un_420 lt.id.ms_332  fi.gd.ga_655 fr.tr.un_430
  0x1b00040d, 0x0f0610a0, 0x3f00680b, 0x6b211005,   // fi.tr.un_540 lt.de.lv_322  ig.af.un_520 lt.jw.ceb_333
  // [34a0]
  0x1c1a21a0, 0x190528a4, 0x06003f0b, 0x086b31a0,   // jw.tl.id_322 sw.fr.gl_433  af.de.un_520 az.ceb.no_322
  0x11002509, 0x20551107, 0x3525550c, 0x280b2b0b,   // eu.ro.un_440 ro.rw.sq_432  rw.eu.zu_543 vi.es.sw_542
  0x283b18a0, 0x535528a7, 0x1b005512, 0x0d165307,   // ga.so.sw_322 sw.rw.ht_532  rw.tr.un_640 ht.hr.cs_432
  0x16001c07, 0x020c0807, 0x11001804, 0x351b64ee,   // id.hr.un_420 no.sv.da_432  ga.ro.un_320 lg.tr.zu_422
  // [34b0]
  0x2d0d01a9, 0x12000d08, 0x1c001212, 0x3b001a02,   // en.cs.sk_544 cs.hu.un_430  hu.id.un_640 tl.so.un_220
  0x354a64a7, 0x52552812, 0x270d1812, 0x3f0403a4,   // lg.yo.zu_532 sw.rw.ha_654  ga.cs.gd_654 nl.fi.af_433
  0x0d292d0c, 0x1f000512, 0x18000111, 0x02000e1a,   // sk.sl.cs_543 fr.cy.un_640  en.ga.un_630 is.da.un_760
  0x1b002307, 0x642855af, 0x06001707, 0x316b0ead,   // ca.tr.un_420 rw.sw.lg_655  sr.de.un_420 is.ceb.az_643
  // [34c0]
  0x20353205, 0x311b520e, 0x1e1c55a4, 0x0e005204,   // bs.zu.sq_333 ha.tr.az_555  rw.id.ms_433 ha.is.un_320
  0x556410af, 0x12002719, 0x120e18ad, 0x08000e07,   // lt.lg.rw_655 gd.hu.un_750  ga.is.hu_643 is.no.un_420
  0x10132509, 0x53052b04, 0x1a213fad, 0x2a005513,   // eu.et.lt_444 vi.fr.ht_332  af.jw.tl_643 rw.mt.un_650
  0x2d0d21a0, 0x2b2d2504, 0x20522812, 0x014a29a7,   // jw.cs.sk_322 eu.sk.vi_332  sw.ha.sq_654 sl.yo.en_532
  // [34d0]
  0x20003504, 0x2a1a21a4, 0x0c0e080d, 0x2800080e,   // zu.sq.un_320 jw.tl.mt_433  no.is.sv_554 no.sw.un_550
  0x28001312, 0x642506ad, 0x17311ba4, 0x3b002721,   // et.sw.un_640 de.eu.lg_643  tr.az.sr_433 gd.so.un_860
  0x53201eee, 0x1c002302, 0x1e002a04, 0x3b2501a0,   // ms.sq.ht_422 ca.id.un_220  mt.ms.un_320 en.eu.so_322
  0x181f3f0b, 0x3f1b08a7, 0x28001112, 0x0c040812,   // af.cy.ga_542 no.tr.af_532  ro.sw.un_640 no.fi.sv_654
  // [34e0]
  0x6b103b04, 0x0b000e07, 0x0d1020ee, 0x1c2a0d02,   // so.lt.ceb_332 is.es.un_420  sq.lt.cs_422 cs.mt.id_222
  0x190b0605, 0x1b000908, 0x171629ee, 0x1a6b5507,   // de.es.gl_333 pl.tr.un_430  sl.hr.sr_422 rw.ceb.tl_432
  0x0d2d2955, 0x28553b5a, 0x03000f02, 0x0607250d,   // sl.sk.cs_442 so.rw.sw_553  lv.nl.un_220 eu.it.de_554
  0x52005513, 0x1b2053a9, 0x25000708, 0x21000304,   // rw.ha.un_650 ht.sq.tr_544  it.eu.un_430 nl.jw.un_320
  // [34f0]
  0x0c130412, 0x111827ac, 0x3b6b5512, 0x1632170c,   // fi.et.sv_654 gd.ga.ro_632  rw.ceb.so_654 sr.bs.hr_543
  0x216811ee, 0x28001102, 0x1b1112a4, 0x124a210c,   // ro.ig.jw_422 ro.sw.un_220  hu.ro.tr_433 jw.yo.hu_543
  0x23002807, 0x25640c02, 0x2a001904, 0x19000113,   // sw.ca.un_420 sv.lg.eu_222  gl.mt.un_320 en.gl.un_650
  0x53210511, 0x1c0d13ee, 0x0c1b28ee, 0x52002721,   // fr.jw.ht_653 bh.ne.mr_422  sw.tr.sv_422 gd.ha.un_860
  // [3500]
  0x250906a0, 0x04230508, 0x31002808, 0x21312da0,   // de.pl.eu_322 fr.ca.fi_443  sw.az.un_430 sk.az.jw_322
  0x3b6404a7, 0x012b12a6, 0x13041ba4, 0x17160205,   // fi.lg.so_532 hu.vi.en_521  tr.fi.et_433 da.hr.sr_333
  0x321629a9, 0x1a001319, 0x190a2709, 0x05061005,   // sl.hr.bs_544 et.tl.un_750  gd.pt.gl_444 lt.de.fr_333
  0x31000302, 0x1f000c0d, 0x19312a11, 0x23530c04,   // nl.az.un_220 sv.cy.un_540  mt.az.gl_653 sv.ht.ca_332
  // [3510]
  0x0a190b07, 0x070810ee, 0x2900520c, 0x02001807,   // es.gl.pt_432 be.uk.bg_422  ha.sl.un_530 ga.da.un_420
  0x1e002804, 0x101b06af, 0x1e005304, 0x283b01a0,   // sw.ms.un_320 de.tr.lt_655  ht.ms.un_320 en.so.sw_322
  0x6b005212, 0x3f000a12, 0x19006405, 0x2d0920a9,   // ha.ceb.un_640 pt.af.un_640  lg.gl.un_330 sq.pl.sk_544
  0x035501a4, 0x18001f04, 0x27000619, 0x52253207,   // en.rw.nl_433 cy.ga.un_320  de.gd.un_750 bs.eu.ha_432
  // [3520]
  0x06002119, 0x052755a9, 0x1c1309ac, 0x21006b04,   // jw.de.un_750 rw.gd.fr_544  hi.bh.mr_632 ceb.jw.un_320
  0x285564ad, 0x0e00010d, 0x0b522112, 0x17071108,   // lg.rw.sw_643 en.is.un_540  jw.ha.es_654 ro.bg.sr_443
  0x0000281c, 0x5300640d, 0x641a3ba7, 0x0e003202,   // sw.un.un_800 lg.ht.un_540  so.tl.lg_532 bs.is.un_220
  0x554a2aec, 0x190b13af, 0x28532055, 0x12003f07,   // mt.yo.rw_644 et.es.gl_655  sq.ht.sw_442 af.hu.un_420
  // [3530]
  0x531c3fa0, 0x2b1f0611, 0x230605af, 0x042a1baf,   // af.id.ht_322 de.cy.vi_653  fr.de.ca_655 tr.mt.fi_655
  0x01250605, 0x321711a0, 0x312519a7, 0x28003519,   // de.eu.en_333 ro.sr.bs_322  gl.eu.az_532 zu.sw.un_750
  0x320520a0, 0x12002307, 0x1c2501a0, 0x20006e05,   // sq.fr.bs_322 ca.hu.un_420  en.eu.id_322 hmn.sq.un_330
  0x25002a12, 0x53053f09, 0x3b0e6b04, 0x132108af,   // mt.eu.un_640 af.fr.ht_444  ceb.is.so_332 no.jw.et_655
  // [3540]
  0x55002107, 0x0e000820, 0x28000704, 0x052a55ee,   // jw.rw.un_420 no.is.un_850  it.sw.un_320 rw.mt.fr_422
  0x211c0c07, 0x6e686b04, 0x0f6b02ec, 0x09000412,   // sv.id.jw_432 ceb.ig.hmn_332  da.ceb.lv_644 fi.pl.un_640
  0x4a535511, 0x0e001602, 0x013f09ac, 0x28524a09,   // rw.ht.yo_653 hr.is.un_220  pl.af.en_632 yo.ha.sw_444
  0x06002519, 0x03000118, 0x100f1304, 0x182a2d11,   // eu.de.un_750 en.nl.un_740  et.lv.lt_332 sk.mt.ga_653
  // [3550]
  0x06001a08, 0x03002d13, 0x356425a7, 0x08020eec,   // tl.de.un_430 sk.nl.un_650  eu.lg.zu_532 is.da.no_644
  0x530c6b02, 0x535213ad, 0x01640f04, 0x132a20ee,   // ceb.sv.ht_222 et.ha.ht_643  lv.lg.en_332 sq.mt.et_422
  0x290910a9, 0x6400530e, 0x1e53100c, 0x11081013,   // lt.pl.sl_544 ht.lg.un_550  lt.ht.ms_543 be.uk.ro_665
  0x35001b0d, 0x190b11a4, 0x183552a0, 0x101b2d07,   // tr.zu.un_540 ro.es.gl_433  ha.zu.ga_322 sk.tr.lt_432
  // [3560]
  0x31003f04, 0x1c002d08, 0x1a252807, 0x0f202a0c,   // af.az.un_320 sk.id.un_430  sw.eu.tl_432 mt.sq.lv_543
  0x6b681aad, 0x32110aa0, 0x091f1804, 0x2d00530c,   // tl.ig.ceb_643 pt.ro.bs_322  ga.cy.pl_332 ht.sk.un_530
  0x0e280607, 0x272b18a0, 0x11003b07, 0x0e192d05,   // de.sw.is_432 ga.vi.gd_322  so.ro.un_420 sk.gl.is_333
  0x19001704, 0x18006414, 0x213f0313, 0x321620ec,   // sr.gl.un_320 lg.ga.un_660  nl.af.jw_665 sq.hr.bs_644
  // [3570]
  0x08000104, 0x052d12a7, 0x0e2a0c11, 0x1e00080d,   // en.no.un_320 hu.sk.fr_532  sv.mt.is_653 no.ms.un_540
  0x080c02a4, 0x355513af, 0x1a214a04, 0x09000f02,   // da.sv.no_433 et.rw.zu_655  yo.jw.tl_332 lv.pl.un_220
  0x0c0102ee, 0x08023107, 0x1b00550c, 0x55001805,   // da.en.sv_422 az.da.no_432  rw.tr.un_530 ga.rw.un_330
  0x08060202, 0x090c530c, 0x071710a7, 0x1113040e,   // da.de.no_222 ht.sv.pl_543  be.sr.bg_532 fi.et.ro_555
  // [3580]
  0x113b0405, 0x21180504, 0x552a1b08, 0x19005309,   // fi.so.ro_333 fr.ga.jw_332  tr.mt.rw_443 ht.gl.un_440
  0x11000504, 0x23000f12, 0x070f0a04, 0x23010e09,   // fr.ro.un_320 lv.ca.un_640  pt.lv.it_332 is.en.ca_444
  0x011c21ee, 0x53001304, 0x080211a0, 0x071108af,   // jw.id.en_422 et.ht.un_320  ro.da.no_322 uk.ro.bg_655
  0x08020c55, 0x0e001f04, 0x092910a6, 0x092d0dee,   // sv.da.no_442 cy.is.un_320  lt.sl.pl_521 cs.sk.pl_422
  // [3590]
  0x0c0803af, 0x1f062da6, 0x2a006402, 0x25001107,   // nl.no.sv_655 sk.de.cy_521  lg.mt.un_220 ro.eu.un_420
  0x6b080209, 0x4a000414, 0x1f050ca0, 0x643b1b07,   // da.no.ceb_444 fi.yo.un_660  sv.fr.cy_322 tr.so.lg_432
  0x0600640c, 0x2a3220a7, 0x041a3ba9, 0x32162da9,   // lg.de.un_530 sq.bs.mt_532  so.tl.fi_544 sk.hr.bs_544
  0x25000108, 0x12080eaf, 0x321b250d, 0x32642a04,   // en.eu.un_430 is.no.hu_655  eu.tr.bs_554 mt.lg.bs_332
  // [35a0]
  0x3b031fa6, 0x065520a6, 0x07292da0, 0x052d2b12,   // cy.nl.so_521 sq.rw.de_521  sk.sl.it_322 vi.sk.fr_654
  0x190b2da7, 0x06002d0e, 0x356b0804, 0x13091c07,   // sk.es.gl_532 sk.de.un_550  no.ceb.zu_332 mr.hi.bh_432
  0x100e0fa7, 0x1f1827af, 0x25070908, 0x212025a0,   // lv.is.lt_532 gd.ga.cy_655  pl.it.eu_443 eu.sq.jw_322
  0x042313ac, 0x1b2904ee, 0x020806ad, 0x29040d08,   // et.ca.fi_632 fi.sl.tr_422  de.no.da_643 cs.fi.sl_443
  // [35b0]
  0x0f00030d, 0x5300020d, 0x213155ee, 0x04100e0c,   // nl.lv.un_540 da.ht.un_540  rw.az.jw_422 is.lt.fi_543
  0x033f6ea7, 0x250e1011, 0x0600050c, 0x18000a08,   // hmn.af.nl_532 lt.is.eu_653  fr.de.un_530 pt.ga.un_430
  0x1f0d0fa7, 0x230a05ad, 0x0f003204, 0x231929ee,   // lv.cs.cy_532 fr.pt.ca_643  bs.lv.un_320 sl.gl.ca_422
  0x292705ad, 0x531f0fa0, 0x0a000514, 0x53212312,   // fr.gd.sl_643 lv.cy.ht_322  fr.pt.un_660 ca.jw.ht_654
  // [35c0]
  0x17003b07, 0x52001c02, 0x6b1a3ba9, 0x1a0d01a4,   // so.sr.un_420 id.ha.un_220  so.tl.ceb_544 en.cs.tl_433
  0x0a08040d, 0x52110aa0, 0x03000e12, 0x081031ee,   // ru.uk.mk_554 pt.ro.ha_322  is.nl.un_640 az.lt.no_422
  0x08001a04, 0x0f06120d, 0x2d000b07, 0x08020405,   // tl.no.un_320 hu.de.lv_554  es.sk.un_420 fi.da.no_333
  0x08252007, 0x2a1a20a0, 0x4a643bee, 0x0717080c,   // sq.eu.no_432 sq.tl.mt_322  so.lg.yo_422 uk.sr.bg_543
  // [35d0]
  0x0e2d18ec, 0x1f2b0a09, 0x04000614, 0x20003b13,   // ga.sk.is_644 pt.vi.cy_444  de.fi.un_660 so.sq.un_650
  0x0c001905, 0x08071755, 0x0a0911a7, 0x1c0913a9,   // gl.sv.un_330 sr.bg.uk_442  ro.pl.pt_532 bh.hi.mr_544
  0x0d2d1260, 0x28001005, 0x0e000d0e, 0x182720ad,   // hu.sk.cs_664 lt.sw.un_330  cs.is.un_550 sq.gd.ga_643
  0x0f0728a0, 0x31001c02, 0x06233fad, 0x3f001f0e,   // sw.it.lv_322 id.az.un_220  af.ca.de_643 cy.af.un_550
  // [35e0]
  0x01251c04, 0x1c1e2b12, 0x311b2908, 0x0e1f6bee,   // id.eu.en_332 vi.ms.id_654  sl.tr.az_443 ceb.cy.is_422
  0x04001f12, 0x0d2d09a7, 0x01000b04, 0x10001b04,   // cy.fi.un_640 pl.sk.cs_532  es.en.un_320 tr.lt.un_320
  0x20002b0c, 0x01000c02, 0x2d0d1ba0, 0x29682dec,   // vi.sq.un_530 sv.en.un_220  tr.cs.sk_322 sk.ig.sl_644
  0x08000f18, 0x5200290d, 0x27005504, 0x08003b19,   // lv.no.un_740 sl.ha.un_540  rw.gd.un_320 so.no.un_750
  // [35f0]
  0x0e004a12, 0x13090d55, 0x100a080d, 0x4a001908,   // yo.is.un_640 ne.hi.bh_442  uk.mk.be_554 gl.yo.un_430
  0x120a2da9, 0x0a00080c, 0x0b003f11, 0x080f0c04,   // sk.pt.hu_544 uk.mk.un_530  af.es.un_630 sv.lv.no_332
  0x2d0d28a6, 0x12006b04, 0x1f0501ee, 0x0c6b25a0,   // sw.cs.sk_521 ceb.hu.un_320  en.fr.cy_422 eu.ceb.sv_322
  0x520553a0, 0x0e1b3ba4, 0x0e1b0404, 0x13000802,   // ht.fr.ha_322 so.tr.is_433  fi.tr.is_332 no.et.un_220
  // [3600]
  0x130d090e, 0x190b0a0c, 0x10000a0e, 0x211e1b04,   // hi.ne.bh_555 pt.es.gl_543  mk.be.un_550 tr.ms.jw_332
  0x0c271802, 0x0f000c0c, 0x6455350d, 0x0c0f3fa0,   // ga.gd.sv_222 sv.lv.un_530  zu.rw.lg_554 af.lv.sv_322
  0x0e081bad, 0x09281807, 0x6864350c, 0x1c530808,   // tr.no.is_643 ga.sw.pl_432  zu.lg.ig_543 no.ht.id_443
  0x100428ac, 0x04000a0b, 0x072a1212, 0x13000202,   // sw.fi.lt_632 mk.ru.un_520  hu.mt.it_654 da.et.un_220
  // [3610]
  0x0a110405, 0x12281807, 0x0c060e02, 0x1f002b19,   // ru.ro.mk_333 ga.sw.hu_432  is.de.sv_222 vi.cy.un_750
  0x530504a0, 0x23001f18, 0x0d282da7, 0x18000507,   // fi.fr.ht_322 cy.ca.un_740  sk.sw.cs_532 fr.ga.un_420
  0x17000307, 0x3f12030c, 0x1b000704, 0x0d291605,   // nl.sr.un_420 nl.hu.af_543  it.tr.un_320 hr.sl.cs_333
  0x04093bee, 0x2d160d0d, 0x170f0307, 0x18003514,   // so.pl.fi_422 cs.hr.sk_554  nl.lv.sr_432 zu.ga.un_660
  // [3620] --- double_langprob_start=3627 ---
  0x52000813, 0x0b001807, 0x083f03ec, 0x011809a4,   // no.ha.un_650 ga.es.un_420  nl.af.no_644 pl.ga.en_433
  0x042810a0, 0x131e53a7, 0x0e133f04,               // lt.sw.fi_322 ht.ms.et_532  af.et.is_332
                                                    //
  };

//  COMPILE_ASSERT(13863 <= 16384, k_indirectbits_too_small);

extern const CLD2TableSummary kQuad_obj2 = {
  kQuadChrome0122_19_2,
  kQuadChrome0122_19_2Ind,
  kQuadChrome0122_19_2SizeOne,
  kQuadChrome0122_19_2Size,
  kQuadChrome0122_19_2KeyMask,
  kQuadChrome0122_19BuildDate,
  kQuadChrome0122_19RecognizedLangScripts,
};

}       // End namespace CLD2

// End of generated tables
